try {
  this["Module"] = Module;
} catch (e) {
  this["Module"] = Module = {};
}

var ENVIRONMENT_IS_NODE = typeof process === "object";

var ENVIRONMENT_IS_WEB = typeof window === "object";

var ENVIRONMENT_IS_WORKER = typeof importScripts === "function";

var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  Module["print"] = (function(x) {
    process["stdout"].write(x + "\n");
  });
  Module["printErr"] = (function(x) {
    process["stderr"].write(x + "\n");
  });
  var nodeFS = require("fs");
  var nodePath = require("path");
  Module["read"] = (function(filename) {
    filename = nodePath["normalize"](filename);
    var ret = nodeFS["readFileSync"](filename).toString();
    if (!ret && filename != nodePath["resolve"](filename)) {
      filename = path.join(__dirname, "..", "src", filename);
      ret = nodeFS["readFileSync"](filename).toString();
    }
    return ret;
  });
  Module["load"] = (function(f) {
    globalEval(read(f));
  });
  if (!Module["arguments"]) {
    Module["arguments"] = process["argv"].slice(2);
  }
} else if (ENVIRONMENT_IS_SHELL) {
  Module["print"] = print;
  Module["printErr"] = printErr;
  if (typeof read != "undefined") {
    Module["read"] = read;
  } else {
    Module["read"] = (function(f) {
      snarf(f);
    });
  }
  if (!Module["arguments"]) {
    if (typeof scriptArgs != "undefined") {
      Module["arguments"] = scriptArgs;
    } else if (typeof arguments != "undefined") {
      Module["arguments"] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WEB) {
  if (!Module["print"]) {
    Module["print"] = (function(x) {
      console.log(x);
    });
  }
  if (!Module["printErr"]) {
    Module["printErr"] = (function(x) {
      console.log(x);
    });
  }
  Module["read"] = (function(url) {
    var xhr = new XMLHttpRequest;
    xhr.open("GET", url, false);
    xhr.send(null);
    return xhr.responseText;
  });
  if (!Module["arguments"]) {
    if (typeof arguments != "undefined") {
      Module["arguments"] = arguments;
    }
  }
} else if (ENVIRONMENT_IS_WORKER) {
  Module["load"] = importScripts;
} else {
  throw "Unknown runtime environment. Where are we?";
}

function globalEval(x) {
  eval.call(null, x);
}

if (!Module["load"] == "undefined" && Module["read"]) {
  Module["load"] = (function(f) {
    globalEval(Module["read"](f));
  });
}

if (!Module["printErr"]) {
  Module["printErr"] = (function() {});
}

if (!Module["print"]) {
  Module["print"] = Module["printErr"];
}

if (!Module["arguments"]) {
  Module["arguments"] = [];
}

Module.print = Module["print"];

Module.printErr = Module["printErr"];

var Runtime = {
  stackSave: (function() {
    return STACKTOP;
  }),
  stackRestore: (function(stackTop) {
    STACKTOP = stackTop;
  }),
  forceAlign: (function(target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target / quantum) * quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return "((((" + target + ")+" + (quantum - 1) + ")>>" + logg + ")<<" + logg + ")";
    }
    return "Math.ceil((" + target + ")/" + quantum + ")*" + quantum;
  }),
  isNumberType: (function(type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  }),
  isPointerType: function isPointerType(type) {
    return type[type.length - 1] == "*";
  },
  isStructType: function isStructType(type) {
    if (isPointerType(type)) return false;
    if (/^\[\d+\ x\ (.*)\]/.test(type)) return true;
    if (/<?{ ?[^}]* ?}>?/.test(type)) return true;
    return type[0] == "%";
  },
  INT_TYPES: {
    "i1": 0,
    "i8": 0,
    "i16": 0,
    "i32": 0,
    "i64": 0
  },
  FLOAT_TYPES: {
    "float": 0,
    "double": 0
  },
  bitshift64: (function(low, high, op, bits) {
    var ander = Math.pow(2, bits) - 1;
    if (bits < 32) {
      switch (op) {
       case "shl":
        return [ low << bits, high << bits | (low & ander << 32 - bits) >>> 32 - bits ];
       case "ashr":
        return [ (low >>> bits | (high & ander) << 32 - bits) >> 0 >>> 0, high >> bits >>> 0 ];
       case "lshr":
        return [ (low >>> bits | (high & ander) << 32 - bits) >>> 0, high >>> bits ];
      }
    } else if (bits == 32) {
      switch (op) {
       case "shl":
        return [ 0, low ];
       case "ashr":
        return [ high, (high | 0) < 0 ? ander : 0 ];
       case "lshr":
        return [ high, 0 ];
      }
    } else {
      switch (op) {
       case "shl":
        return [ 0, low << bits - 32 ];
       case "ashr":
        return [ high >> bits - 32 >>> 0, (high | 0) < 0 ? ander : 0 ];
       case "lshr":
        return [ high >>> bits - 32, 0 ];
      }
    }
    abort("unknown bitshift64 op: " + [ value, op, bits ]);
  }),
  or64: (function(x, y) {
    var l = x | 0 | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  and64: (function(x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  xor64: (function(x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  }),
  getNativeTypeSize: (function(type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      "%i1": 1,
      "%i8": 1,
      "%i16": 2,
      "%i32": 4,
      "%i64": 8,
      "%float": 4,
      "%double": 8
    }["%" + type];
    if (!size) {
      if (type[type.length - 1] == "*") {
        size = Runtime.QUANTUM_SIZE;
      } else if (type[0] == "i") {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits / 8;
      }
    }
    return size;
  }),
  getNativeFieldSize: (function(type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  }),
  dedup: function dedup(items, ident) {
    var seen = {};
    if (ident) {
      return items.filter((function(item) {
        if (seen[item[ident]]) return false;
        seen[item[ident]] = true;
        return true;
      }));
    } else {
      return items.filter((function(item) {
        if (seen[item]) return false;
        seen[item] = true;
        return true;
      }));
    }
  },
  set: function set() {
    var args = typeof arguments[0] === "object" ? arguments[0] : arguments;
    var ret = {};
    for (var i = 0; i < args.length; i++) {
      ret[args[i]] = 0;
    }
    return ret;
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    type.flatIndexes = type.fields.map((function(field) {
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field);
        alignSize = size;
      } else if (Runtime.isStructType(field)) {
        size = Types.types[field].flatSize;
        alignSize = Types.types[field].alignSize;
      } else {
        throw "Unclear type in struct: " + field + ", in " + type.name_ + " :: " + dump(Types.types[type.name_]);
      }
      alignSize = type.packed ? 1 : Math.min(alignSize, Runtime.QUANTUM_SIZE);
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize);
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr - prev);
      }
      prev = curr;
      return curr;
    }));
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = type.flatFactor != 1;
    return type.flatIndexes;
  },
  generateStructInfo: (function(struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === "undefined" ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      assert(type.fields.length === struct.length, "Number of named fields must match the type for " + typeName);
      alignment = type.flatIndexes;
    } else {
      var type = {
        fields: struct.map((function(item) {
          return item[0];
        }))
      };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach((function(item, i) {
        if (typeof item === "string") {
          ret[item] = alignment[i] + offset;
        } else {
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      }));
    } else {
      struct.forEach((function(item, i) {
        ret[item[1]] = alignment[i];
      }));
    }
    return ret;
  }),
  addFunction: (function(func) {
    var ret = FUNCTION_TABLE.length;
    FUNCTION_TABLE.push(func);
    FUNCTION_TABLE.push(0);
    return ret;
  }),
  stackAlloc: function stackAlloc(size) {
    var ret = STACKTOP;
    STACKTOP += size;
    STACKTOP = STACKTOP + 3 >> 2 << 2;
    return ret;
  },
  staticAlloc: function staticAlloc(size) {
    var ret = STATICTOP;
    STATICTOP += size;
    STATICTOP = STATICTOP + 3 >> 2 << 2;
    if (STATICTOP >= TOTAL_MEMORY) enlargeMemory();
    return ret;
  },
  alignMemory: function alignMemory(size, quantum) {
    var ret = size = Math.ceil(size / (quantum ? quantum : 4)) * (quantum ? quantum : 4);
    return ret;
  },
  makeBigInt: function makeBigInt(low, high, unsigned) {
    var ret = unsigned ? (low >>> 0) + (high >>> 0) * 4294967296 : (low >>> 0) + (high | 0) * 4294967296;
    return ret;
  },
  QUANTUM_SIZE: 4,
  __dummy__: 0
};

var CorrectionsMonitor = {
  MAX_ALLOWED: 0,
  corrections: 0,
  sigs: {},
  note: (function(type, succeed, sig) {
    if (!succeed) {
      this.corrections++;
      if (this.corrections >= this.MAX_ALLOWED) abort("\n\nToo many corrections!");
    }
  }),
  print: (function() {})
};

var __THREW__ = false;

var ABORT = false;

var undef = 0;

var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;

var tempI64, tempI64b;

function abort(text) {
  Module.print(text + ":\n" + (new Error).stack);
  ABORT = true;
  throw "Assertion: " + text;
}

function assert(condition, text) {
  if (!condition) {
    abort("Assertion failed: " + text);
  }
}

var globalScope = this;

function ccall(ident, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == "string") {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length + 1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == "array") {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == "string") {
      return Pointer_stringify(value);
    }
    assert(type != "array");
    return value;
  }
  try {
    var func = eval("_" + ident);
  } catch (e) {
    try {
      func = globalScope["Module"]["_" + ident];
    } catch (e) {}
  }
  assert(func, "Cannot call unknown function " + ident + " (perhaps LLVM optimizations or closure removed it?)");
  var i = 0;
  var cArgs = args ? args.map((function(arg) {
    return toC(arg, argTypes[i++]);
  })) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

Module["ccall"] = ccall;

function cwrap(ident, returnType, argTypes) {
  return (function() {
    return ccall(ident, returnType, argTypes, Array.prototype.slice.call(arguments));
  });
}

Module["cwrap"] = cwrap;

function setValue(ptr, value, type, noSafe) {
  type = type || "i8";
  if (type[type.length - 1] === "*") type = "i32";
  switch (type) {
   case "i1":
    HEAP8[ptr] = value;
    break;
   case "i8":
    HEAP8[ptr] = value;
    break;
   case "i16":
    HEAP16[ptr >> 1] = value;
    break;
   case "i32":
    HEAP32[ptr >> 2] = value;
    break;
   case "i64":
    HEAP32[ptr >> 2] = value;
    break;
   case "float":
    HEAPF32[ptr >> 2] = value;
    break;
   case "double":
    tempDoubleF64[0] = value, HEAP32[ptr >> 2] = tempDoubleI32[0], HEAP32[ptr + 4 >> 2] = tempDoubleI32[1];
    break;
   default:
    abort("invalid type for setValue: " + type);
  }
}

Module["setValue"] = setValue;

function getValue(ptr, type, noSafe) {
  type = type || "i8";
  if (type[type.length - 1] === "*") type = "i32";
  switch (type) {
   case "i1":
    return HEAP8[ptr];
   case "i8":
    return HEAP8[ptr];
   case "i16":
    return HEAP16[ptr >> 1];
   case "i32":
    return HEAP32[ptr >> 2];
   case "i64":
    return HEAP32[ptr >> 2];
   case "float":
    return HEAPF32[ptr >> 2];
   case "double":
    return tempDoubleI32[0] = HEAP32[ptr >> 2], tempDoubleI32[1] = HEAP32[ptr + 4 >> 2], tempDoubleF64[0];
   default:
    abort("invalid type for setValue: " + type);
  }
  return null;
}

Module["getValue"] = getValue;

var ALLOC_NORMAL = 0;

var ALLOC_STACK = 1;

var ALLOC_STATIC = 2;

Module["ALLOC_NORMAL"] = ALLOC_NORMAL;

Module["ALLOC_STACK"] = ALLOC_STACK;

Module["ALLOC_STATIC"] = ALLOC_STATIC;

function allocate(slab, types, allocator) {
  var zeroinit, size;
  if (typeof slab === "number") {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === "string" ? types : null;
  var ret = [ _malloc, Runtime.stackAlloc, Runtime.staticAlloc ][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  if (zeroinit) {
    _memset(ret, 0, size);
    return ret;
  }
  var i = 0, type;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === "function") {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == "i64") type = "i32";
    setValue(ret + i, curr, type);
    i += Runtime.getNativeTypeSize(type);
  }
  return ret;
}

Module["allocate"] = allocate;

function Pointer_stringify(ptr, length) {
  var nullTerminated = typeof length == "undefined";
  var ret = "";
  var i = 0;
  var t;
  var nullByte = String.fromCharCode(0);
  while (1) {
    t = String.fromCharCode(HEAPU8[ptr + i]);
    if (nullTerminated && t == nullByte) {
      break;
    } else {}
    ret += t;
    i += 1;
    if (!nullTerminated && i == length) {
      break;
    }
  }
  return ret;
}

Module["Pointer_stringify"] = Pointer_stringify;

function Array_stringify(array) {
  var ret = "";
  for (var i = 0; i < array.length; i++) {
    ret += String.fromCharCode(array[i]);
  }
  return ret;
}

Module["Array_stringify"] = Array_stringify;

var FUNCTION_TABLE;

var PAGE_SIZE = 4096;

function alignMemoryPage(x) {
  return x + 4095 >> 12 << 12;
}

var HEAP;

var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STACK_ROOT, STACKTOP, STACK_MAX;

var STATICTOP;

function enlargeMemory() {
  while (TOTAL_MEMORY <= STATICTOP) {
    TOTAL_MEMORY = alignMemoryPage(2 * TOTAL_MEMORY);
  }
  var oldHEAP8 = HEAP8;
  var buffer = new ArrayBuffer(TOTAL_MEMORY);
  HEAP8 = new Int8Array(buffer);
  HEAP16 = new Int16Array(buffer);
  HEAP32 = new Int32Array(buffer);
  HEAPU8 = new Uint8Array(buffer);
  HEAPU16 = new Uint16Array(buffer);
  HEAPU32 = new Uint32Array(buffer);
  HEAPF32 = new Float32Array(buffer);
  HEAPF64 = new Float64Array(buffer);
  HEAP8.set(oldHEAP8);
}

var TOTAL_STACK = Module["TOTAL_STACK"] || 5242880;

var TOTAL_MEMORY = Module["TOTAL_MEMORY"] || 10485760;

var FAST_MEMORY = Module["FAST_MEMORY"] || 2097152;

assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1))["subarray"] && !!(new Int32Array(1))["set"], "Cannot fallback to non-typed array case: Code is too specialized");

var buffer = new ArrayBuffer(TOTAL_MEMORY);

HEAP8 = new Int8Array(buffer);

HEAP16 = new Int16Array(buffer);

HEAP32 = new Int32Array(buffer);

HEAPU8 = new Uint8Array(buffer);

HEAPU16 = new Uint16Array(buffer);

HEAPU32 = new Uint32Array(buffer);

HEAPF32 = new Float32Array(buffer);

HEAPF64 = new Float64Array(buffer);

HEAP32[0] = 255;

assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, "Typed arrays 2 must be run on a little-endian system");

var base = intArrayFromString("(null)");

STATICTOP = base.length;

for (var i = 0; i < base.length; i++) {
  HEAP8[i] = base[i];
}

Module["HEAP"] = HEAP;

Module["HEAP8"] = HEAP8;

Module["HEAP16"] = HEAP16;

Module["HEAP32"] = HEAP32;

Module["HEAPU8"] = HEAPU8;

Module["HEAPU16"] = HEAPU16;

Module["HEAPU32"] = HEAPU32;

Module["HEAPF32"] = HEAPF32;

Module["HEAPF64"] = HEAPF64;

STACK_ROOT = STACKTOP = Runtime.alignMemory(STATICTOP);

STACK_MAX = STACK_ROOT + TOTAL_STACK;

var tempDoublePtr = Runtime.alignMemory(STACK_MAX, 8);

var tempDoubleI8 = HEAP8.subarray(tempDoublePtr);

var tempDoubleI32 = HEAP32.subarray(tempDoublePtr >> 2);

var tempDoubleF32 = HEAPF32.subarray(tempDoublePtr >> 2);

var tempDoubleF64 = HEAPF64.subarray(tempDoublePtr >> 3);

function copyTempFloat(ptr) {
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr + 1];
  tempDoubleI8[2] = HEAP8[ptr + 2];
  tempDoubleI8[3] = HEAP8[ptr + 3];
}

function copyTempDouble(ptr) {
  tempDoubleI8[0] = HEAP8[ptr];
  tempDoubleI8[1] = HEAP8[ptr + 1];
  tempDoubleI8[2] = HEAP8[ptr + 2];
  tempDoubleI8[3] = HEAP8[ptr + 3];
  tempDoubleI8[4] = HEAP8[ptr + 4];
  tempDoubleI8[5] = HEAP8[ptr + 5];
  tempDoubleI8[6] = HEAP8[ptr + 6];
  tempDoubleI8[7] = HEAP8[ptr + 7];
}

STACK_MAX = tempDoublePtr + 8;

STATICTOP = alignMemoryPage(STACK_MAX);

function callRuntimeCallbacks(callbacks) {
  while (callbacks.length > 0) {
    var callback = callbacks.shift();
    var func = callback.func;
    if (typeof func === "number") {
      func = FUNCTION_TABLE[func];
    }
    func(callback.arg === undefined ? null : callback.arg);
  }
}

var __ATINIT__ = [];

var __ATMAIN__ = [];

var __ATEXIT__ = [];

function initRuntime() {
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  CorrectionsMonitor.print();
}

function Array_copy(ptr, num) {
  return Array.prototype.slice.call(HEAP8.subarray(ptr, ptr + num));
  return HEAP.slice(ptr, ptr + num);
}

Module["Array_copy"] = Array_copy;

function TypedArray_copy(ptr, num, offset) {
  if (offset === undefined) {
    offset = 0;
  }
  var arr = new Uint8Array(num - offset);
  for (var i = offset; i < num; ++i) {
    arr[i - offset] = HEAP8[ptr + i];
  }
  return arr.buffer;
}

Module["TypedArray_copy"] = TypedArray_copy;

function String_len(ptr) {
  var i = 0;
  while (HEAP8[ptr + i]) i++;
  return i;
}

Module["String_len"] = String_len;

function String_copy(ptr, addZero) {
  var len = String_len(ptr);
  if (addZero) len++;
  var ret = Array_copy(ptr, len);
  if (addZero) ret[len - 1] = 0;
  return ret;
}

Module["String_copy"] = String_copy;

function intArrayFromString(stringy, dontAddNull, length) {
  var ret = [];
  var t;
  var i = 0;
  if (length === undefined) {
    length = stringy.length;
  }
  while (i < length) {
    var chr = stringy.charCodeAt(i);
    if (chr > 255) {
      chr &= 255;
    }
    ret.push(chr);
    i = i + 1;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}

Module["intArrayFromString"] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 255) {
      chr &= 255;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join("");
}

Module["intArrayToString"] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var i = 0;
  while (i < string.length) {
    var chr = string.charCodeAt(i);
    if (chr > 255) {
      chr &= 255;
    }
    HEAP8[buffer + i] = chr;
    i = i + 1;
  }
  if (!dontAddNull) {
    HEAP8[buffer + i] = 0;
  }
}

Module["writeStringToMemory"] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[buffer + i] = array[i];
  }
}

Module["writeArrayToMemory"] = writeArrayToMemory;

var STRING_TABLE = [];

function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2 * Math.abs(1 << bits - 1) + value : Math.pow(2, bits) + value;
}

function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << bits - 1) : Math.pow(2, bits - 1);
  if (value >= half && (bits <= 32 || value > half)) {
    value = -2 * half + value;
  }
  return value;
}

var runDependencies = 0;

function addRunDependency() {
  runDependencies++;
  if (Module["monitorRunDependencies"]) {
    Module["monitorRunDependencies"](runDependencies);
  }
}

function removeRunDependency() {
  runDependencies--;
  if (Module["monitorRunDependencies"]) {
    Module["monitorRunDependencies"](runDependencies);
  }
  if (runDependencies == 0) run();
}

function __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 2 || ($thingKind | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 4 || ($thingKind | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 6 || ($thingKind | 0) == 7) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 8 || ($thingKind | 0) == 9) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 11 || ($thingKind | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 7;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 7;
    break;
   case 5:
    var $_0 = 12;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite9recompileEP9JSContextb($this, $cx, $forTrap) {
  return 1;
}

function __ZNK8JSObject10fixedSlotsEv($this) {
  return $this + 40 | 0;
}

function __ZN8JSObject6asCallEv($this) {
  return $this;
}

function __ZNK2js8Bindings16countArgsAndVarsEv($this) {
  return (HEAPU16[$this + 6 >> 1] & 65535) + (HEAPU16[$this + 4 >> 1] & 65535) | 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext20typeInferenceEnabledEv($this) {
  return (HEAP8[$this + 232 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN8JSObject10makeVarObjEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 4096;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _BUILD_JSVAL($agg_result, $tag) {
  HEAP32[$agg_result + 4 >> 2] = $tag;
  HEAP32[$agg_result >> 2] = 0;
  return;
}

function _OBJECT_TO_JSVAL_IMPL($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZNK2js8Bindings9lastShapeEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js8Bindings17extensibleParentsEv($this) {
  return (HEAP8[$this + 10 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN8JSObject11setOwnShapeEj($this, $s) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 128;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 12 >> 2] = $s;
  return;
}

function __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($this, $newType) {
  HEAP32[$this + 36 >> 2] = $newType;
  return;
}

function __ZN8JSObject11setDelegateEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _MAGIC_TO_JSVAL_IMPL($agg_result, $why) {
  HEAP32[$agg_result + 4 >> 2] = -124;
  HEAP32[$agg_result >> 2] = $why;
  return;
}

function __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind) {
  return HEAP32[__ZN2js2gc5Arena10ThingSizesE + ($kind << 2) >> 2];
}

function __ZN8JSObject9earlyInitEj($this, $capacity) {
  HEAP32[$this + 28 >> 2] = $capacity;
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js2gc8FreeSpan8allocateEj($this, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $2 + $thingSize | 0;
    __label__ = 5;
    break;
   case 3:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = $2;
    var $12 = $this;
    var $13$0 = HEAP32[$11 >> 2];
    var $13$1 = HEAP32[$11 + 4 >> 2];
    HEAP32[$12 >> 2] = $13$0;
    HEAP32[$12 + 4 >> 2] = $13$1;
    __label__ = 5;
    break;
   case 5:
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite3incEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $12 = $2;
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $12 = $2;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[HEAP32[$this + 4 >> 2]] = 83;
    var $12 = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $12;
    HEAP32[$1 >> 2] = $12 + 1 | 0;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite3decEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[HEAP32[$this + 4 >> 2]] = HEAP32[$this + 8 >> 2] & 255;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_($this, $cx, $handler, $closure) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 24 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[HEAP32[$this + 4 >> 2]] = 83;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 28 >> 2] = $handler;
    var $9 = $closure | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $this + 32 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($links) {
  return $links - 24 + 4 | 0;
}

function __ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject($this, $debugger, $site, $handler) {
  HEAP32[$this >> 2] = $debugger;
  HEAP32[$this + 4 >> 2] = $site;
  HEAP32[$this + 8 >> 2] = $handler;
  var $5 = $this + 12 | 0;
  HEAP32[$5 >> 2] = $debugger + 44 | 0;
  var $7 = $debugger + 48 | 0;
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$this + 16 >> 2] = $8;
  var $11 = HEAP32[$7 >> 2] | 0;
  HEAP32[$11 >> 2] = $5;
  HEAP32[$7 >> 2] = $5;
  var $13 = $this + 20 | 0;
  HEAP32[$13 >> 2] = $site + 16 | 0;
  var $15 = $site + 20 | 0;
  var $16 = HEAP32[$15 >> 2];
  HEAP32[$this + 24 >> 2] = $16;
  var $19 = HEAP32[$15 >> 2] | 0;
  HEAP32[$19 >> 2] = $13;
  HEAP32[$15 >> 2] = $13;
  return;
}

function __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($links) {
  return $links - 16 + 4 | 0;
}

function __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $script, $scopeChain, $callee) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 64 | 0;
    var $2 = __ZNK2js8Bindings16countArgsAndVarsEv($1);
    var $3 = $2 + 2 | 0;
    var $4 = __ZN2js2gcL15GetGCObjectKindEjb($3);
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $kind_0 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($4);
    if ($7 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $kind_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js2gcL15GetGCObjectKindEjb(2);
    var $kind_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $kind_0;
    var $12 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind_0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_($12, $cx, $1, $scopeChain);
    __ZN8JSObject10makeVarObjEv($12);
    var $15 = $12;
    var $16 = $cx;
    var $17 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($15, $16, $2);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN8JSObject6asCallEv($12);
    __ZN2js10CallObject9setCalleeEP8JSObject($19, $callee);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind);
    var $2 = __Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE($kind);
    __ZN8JSObject9earlyInitEj($2, $5);
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_($this, $cx, $bindings, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($this, undef, __ZN2js9CallClassE, __ZN2js5types15emptyTypeObjectE, $parent, 0, 0);
    var $1 = __ZNK2js8Bindings9lastShapeEv($bindings);
    HEAP32[$this >> 2] = $1;
    var $3 = __ZNK2js8Bindings17extensibleParentsEv($bindings);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __Z16js_GenerateShapeP9JSContext($cx);
    __ZN8JSObject11setOwnShapeEj($this, $5);
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[$1 >> 2];
    HEAP32[$this + 12 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10CallObject9setCalleeEP8JSObject($this, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL17ObjectOrNullValueEP8JSObject($1, $callee);
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, $slot, $value) {
  var $1 = __ZNK8JSObject10fixedSlotsEv($this);
  var $2 = $value | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 + ($slot << 3) | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2JS5Value15setObjectOrNullEP8JSObject($this, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($arg | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($this, $arg);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value7setNullEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value9setObjectER8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _OBJECT_TO_JSVAL_IMPL($1, $obj);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JS5Value7setNullEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL($1, -122);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($this, $cx, $aclasp, $type, $parent, $priv, $denseArray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 4 >> 2] = $aclasp;
    var $3 = HEAP32[$this + 28 >> 2];
    var $4 = $3 << 27;
    var $5 = $this + 8 | 0;
    HEAP32[$5 >> 2] = $4;
    HEAP32[$this + 24 >> 2] = $priv;
    var $7 = $this + 32 | 0;
    HEAP32[$7 >> 2] = 0;
    var $8 = __ZNK8JSObject10fixedSlotsEv($this);
    if ($denseArray) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$7 >> 2] = $8;
    var $10 = $4 | 16384;
    HEAP32[$5 >> 2] = $10;
    __label__ = 4;
    break;
   case 3:
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb($8, $3, 0);
    __label__ = 4;
    break;
   case 4:
    HEAP32[$this + 16 >> 2] = 0;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($this, $type);
    __ZN8JSObject9setParentEPS_($this, $parent);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb($vec, $len, $useHoles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($len | 0) == 0;
    if ($useHoles) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_04;
    var $2 = $vec + ($i_04 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_04 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $i1_01;
    var $4 = $vec + ($i1_01 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($4);
    var $5 = $i1_01 + 1 | 0;
    if (($5 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = $5;
      __label__ = 5;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9setParentEPS_($this, $newParent) {
  __ZN8JSObject19setDelegateNullSafeEPS_($newParent);
  HEAP32[$this + 20 >> 2] = $newParent;
  return;
}

function __ZN8JSObject19setDelegateNullSafeEPS_($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject11setDelegateEv($obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value8setMagicE10JSWhyMagic($this, $why) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _MAGIC_TO_JSVAL_IMPL($1, $why);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JS5Value12setUndefinedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL($1, -126);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($this, $thingKind, $thingSize) {
  var $1 = $this + ($thingKind << 3) | 0;
  var $2 = __ZN2js2gc8FreeSpan8allocateEj($1, $thingSize);
  return $2;
}

function __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, $name, $required) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $s = __stackBase__;
  var $3 = $s | 0;
  HEAP8[$3] = $required + 47 & 255;
  HEAP8[$s + 1 | 0] = 0;
  var $6 = ($required | 0) == 1 ? __str93064 | 0 : STRING_TABLE.__str74084 | 0;
  _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $name, HEAP32[tempInt + 4 >> 2] = $3, HEAP32[tempInt + 8 >> 2] = $6, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __Z20ReportObjectRequiredP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js14BreakpointSiteC2EP8JSScriptPh($this, $script, $pc) {
  HEAP32[$this >> 2] = $script;
  HEAP32[$this + 4 >> 2] = $pc;
  HEAP32[$this + 8 >> 2] = HEAPU8[$pc] & 255;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $9 = $this + 32 | 0;
  __ZN2JSL14UndefinedValueEv($9);
  var $10 = $this + 16 | 0;
  HEAP32[$10 >> 2] = $10;
  HEAP32[$this + 20 >> 2] = $10;
  return;
}

function __ZN2JSL14UndefinedValueEv($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($this, $cx, $e, $handlerp, $closurep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($handlerp | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 28 >> 2];
    HEAP32[$handlerp >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    if (($closurep | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $this + 32 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $closurep | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 5;
    break;
   case 5:
    HEAP32[$this + 28 >> 2] = 0;
    var $13 = $this + 32 | 0;
    __ZN2JS5Value12setUndefinedEv($13);
    if ((HEAP32[$this + 24 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP8[HEAP32[$this + 4 >> 2]] = HEAP32[$this + 8 >> 2] & 255;
    var $24 = HEAP32[$cx + 52 >> 2];
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($this, $24, $e);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($this, $rt, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    if ((HEAP32[$1 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    if (($e | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 5:
    var $15 = HEAP32[$this >> 2];
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    var $17 = $16 + 1956 | 0;
    var $18 = $this + 4 | 0;
    __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_($17, $18);
    __label__ = 6;
    break;
   case 6:
    __ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_(undef, $this);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZNK2js2gc4Cell11compartmentEv($this) {
  var $1 = __ZNK2js2gc4Cell11arenaHeaderEv($this);
  return HEAP32[$1 >> 2];
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($p, $this, $l);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSRuntime5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js14BreakpointSite15firstBreakpointEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $3 = HEAP32[$1 >> 2];
    if (($3 | 0) == ($1 | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($3);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE($this, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js14BreakpointSite15firstBreakpointEv($this);
    var $p_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($p_0 | 0) == ($bp | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js10Breakpoint10nextInSiteEv($p_0);
    var $p_0 = $7;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint10nextInSiteEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == (HEAP32[$this + 4 >> 2] + 16 | 0)) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr($2);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($this, $cx, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_pre = $this + 4 | 0;
    if ((HEAP8[HEAP32[$this >> 2] + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$_pre >> 2];
    __ZN2js14BreakpointSite3decEP9JSContext($8, undef);
    __label__ = 3;
    break;
   case 3:
    var $9 = $this + 12 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $this + 16 | 0;
    var $13 = HEAP32[$11 >> 2] | 0;
    HEAP32[$13 >> 2] = $10;
    var $14 = HEAP32[$11 >> 2];
    var $16 = HEAP32[$9 >> 2] + 4 | 0;
    HEAP32[$16 >> 2] = $14;
    var $17 = $this + 20 | 0;
    var $18 = HEAP32[$17 >> 2];
    var $19 = $this + 24 | 0;
    var $21 = HEAP32[$19 >> 2] | 0;
    HEAP32[$21 >> 2] = $18;
    var $22 = HEAP32[$19 >> 2];
    var $24 = HEAP32[$17 >> 2] + 4 | 0;
    HEAP32[$24 >> 2] = $22;
    var $26 = HEAP32[$cx + 52 >> 2];
    var $27 = HEAP32[$_pre >> 2];
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($27, $26, $e);
    __ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_(undef, $this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSRuntime5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Breakpoint14nextInDebuggerEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    if (($2 | 0) == (HEAP32[$this >> 2] + 44 | 0)) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($2);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8DebuggerC2EP9JSContextP8JSObject($this, $cx, $dbg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $lock = __stackBase__ + 12;
  HEAP32[$this + 8 >> 2] = $dbg;
  var $5 = $this + 12 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($5, $1);
  HEAP32[$this + 36 >> 2] = 0;
  HEAP8[$this + 40 | 0] = 1;
  var $8 = $this + 52 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($2, $cx);
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($8, $2);
  var $9 = $this + 80 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($9, $cx);
  var $10 = $this + 116 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($10, $cx);
  var $11 = $this + 152 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($3, $cx);
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($11, $3);
  var $13 = HEAP32[$cx + 52 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $13);
  var $14 = $13 + 144228 | 0;
  var $15 = $this | 0;
  HEAP32[$this >> 2] = $14;
  var $17 = $13 + 144232 | 0;
  var $18 = HEAP32[$17 >> 2];
  HEAP32[$this + 4 >> 2] = $18;
  var $21 = HEAP32[$17 >> 2] | 0;
  HEAP32[$21 >> 2] = $15;
  HEAP32[$17 >> 2] = $15;
  var $22 = $this + 44 | 0;
  HEAP32[$22 >> 2] = $22;
  HEAP32[$this + 48 >> 2] = $22;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18RuntimeAllocPolicyC1EP9JSContext($this, $cx) {
  __ZN2js18RuntimeAllocPolicyC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext($this, $cx) {
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10AutoLockGCC1EP9JSRuntime($this, $rt) {
  __ZN2js10AutoLockGCC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js8DebuggerD2Ev($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $this + 4 | 0;
  var $5 = HEAP32[$3 >> 2] | 0;
  HEAP32[$5 >> 2] = $2;
  var $6 = HEAP32[$3 >> 2];
  var $8 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$8 >> 2] = $6;
  var $9 = $this + 152 | 0;
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($9);
  var $10 = $this + 116 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($10);
  var $11 = $this + 80 | 0;
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($11);
  var $12 = $this + 52 | 0;
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($12);
  var $13 = $this + 12 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($13);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev($this) {
  __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8Debugger4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 52 | 0;
    var $2 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($1, 0);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = $this + 88 | 0;
    var $5 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($4, 0);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = $this + 12 | 0;
    var $8 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($7, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $this + 124 | 0;
    var $11 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($10, 0);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $this + 152 | 0;
    var $14 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($13, 0);
    if ($14) {
      var $16 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $16 = 0;
    __label__ = 7;
    break;
   case 7:
    var $16;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setPrivateEPv($this, $data) {
  HEAP32[$this + 24 >> 2] = $data;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js14BreakpointSite15getScriptObjectEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js8Debugger10toJSObjectEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js10StackFrame13isScriptFrameEv($this) {
  return (HEAP32[$this >> 2] & 3 | 0) != 0;
}

function __ZNK2js10StackFrame11isEvalFrameEv($this) {
  return (HEAP32[$this >> 2] & 8 | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK8JSObject8getClassEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK8JSObject10getPrivateEv($this) {
  return HEAP32[$this + 24 >> 2];
}

function __ZN9JSContext18isExceptionPendingEv($this) {
  return (HEAP32[$this + 20 >> 2] | 0) != 0;
}

function __ZN9JSContext19getPendingExceptionEv($agg_result, $this) {
  var $1 = $this + 24 | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $agg_result | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN2js8Debugger17fromChildJSObjectEP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK8JSObject15getReservedSlotEj($1, $obj, 0);
  var $2 = __ZNK2JS5Value8toObjectEv($1);
  var $3 = __ZN2js8Debugger12fromJSObjectEP8JSObject($2);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZNK8JSObject15getReservedSlotEj($agg_result, $this, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($this);
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($this, $index);
    var $5 = $4 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $agg_result | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8toObjectEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_OBJECT_IMPL($2$0, $2$1);
  return $3;
}

function __ZN2js8Debugger12fromJSObjectEP8JSObject($obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $fp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $frameobj = __stackBase__ + 28;
    var $4 = __stackBase__ + 32;
    HEAP32[$1 >> 2] = $fp;
    var $5 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $5, $1);
    var $6 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $6);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $11 = $this + 8 | 0;
    var $12 = HEAP32[$11 >> 2];
    __ZNK8JSObject15getReservedSlotEj($3, $12, 0);
    var $13 = __ZNK2JS5Value8toObjectEv($3);
    var $14 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerFrame_class, $13, 0);
    HEAP32[$frameobj >> 2] = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($14, $cx);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $20 = HEAP32[$1 >> 2];
    __ZN8JSObject10setPrivateEPv($14, $20);
    var $21 = HEAP32[$11 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($4, $21);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 0, $4);
    var $22 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($5, $p, $1, $frameobj);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($6);
    var $27 = HEAP32[$25 + 4 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $27);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 4,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb1($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject11nativeEmptyEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($this, $cx);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($this, $index, $v) {
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $index, $v);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger7getHookENS0_4HookE($this, $hook) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$this + 8 >> 2];
    var $4 = $hook + 3 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $3, $4);
    var $5 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($5) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2JS5Value8toObjectEv($1);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value11isUndefinedEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_UNDEFINED_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 8;
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 0);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 3:
    var $10 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 1);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 4:
    var $13 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 2);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 5:
    var $16 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 3);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 6:
    var $19 = __ZNK2js8Debugger15firstBreakpointEv($this);
    var $bp_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = HEAP32[$bp_0 + 4 >> 2];
    var $25 = __ZNK2js14BreakpointSite15getScriptObjectEv($24);
    if (($25 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $25;
    var $29 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $28);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 10:
    var $31 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_0);
    var $bp_0 = $31;
    __label__ = 7;
    break;
   case 11:
    var $33 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $33);
    __label__ = 12;
    break;
   case 12:
    var $35 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($35) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $37 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r);
    var $39 = HEAP32[$37 + 4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($1, $39, 2);
    var $40 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    __label__ = 12;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger15firstBreakpointEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 44 | 0;
    var $3 = HEAP32[$1 >> 2];
    if (($3 | 0) == ($1 | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr($3);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $1 = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    var $2 = __ZNK9JSContext2fpEv($cx);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject9getGlobalEv($4);
    HEAP32[$global >> 2] = $5;
    var $7 = $5;
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $triggered | 0;
    __label__ = 8;
    break;
   case 3:
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($8);
    var $12 = $triggered | 0;
    var $p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($p_0 | 0) == ($14 | 0)) {
      var $_pre_phi = $12;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$p_0 >> 2];
    var $18 = __ZNK2js8Debugger18observesEnterFrameEv($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __ZNK2js8Debugger10toJSObjectEv($17);
    __ZN2JSL11ObjectValueER8JSObject($1, $20);
    var $21 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($12, $1);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_pre_phi;
    var $24 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($_pre_phi);
    var $25 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($24 | 0) == ($25 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $p1_03 = $24;
      __label__ = 9;
      break;
    }
   case 9:
    var $p1_03;
    var $27 = __ZNK2JS5Value8toObjectEv($p1_03);
    var $28 = __ZN2js8Debugger12fromJSObjectEP8JSObject($27);
    var $29 = $28 + 12 | 0;
    var $30 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($29, $global);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $32 = __ZNK2js8Debugger18observesEnterFrameEv($28);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2js8Debugger14fireEnterFrameEP9JSContext($28, $cx);
    __label__ = 12;
    break;
   case 12:
    var $35 = $p1_03 + 8 | 0;
    var $36 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($35 | 0) == ($36 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $p1_03 = $35;
      __label__ = 9;
      break;
    }
   case 13:
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext["X"] = 1;

function __ZN2js15AutoValueVectorC1EP9JSContext($this, $cx) {
  __ZN2js15AutoValueVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZNK9JSContext2fpEv($this) {
  var $1 = $this + 60 | 0;
  var $2 = __ZNK2js12ContextStack2fpEv($1);
  return $2;
}

function __ZNK2js10StackFrame10scopeChainEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 & 524288 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$this + 12 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js10StackFrame6calleeEv($this);
    var $7 = __ZNK8JSObject9getParentEv($6);
    HEAP32[$this + 12 >> 2] = $7;
    var $9 = $2 | 524288;
    HEAP32[$1 >> 2] = $9;
    var $11 = $7;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger18observesEnterFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 3);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($this, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this + 12 | 0;
  var $3 = $v | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $1 | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  var $6 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($2, $1);
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($1);
  return $2;
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($1, $3, $l);
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $1);
  var $6 = (HEAP32[$2 >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js8Debugger14fireEnterFrameEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 3);
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $5 = $this + 8 | 0;
    var $6 = HEAP32[$5 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $9 = $argv | 0;
    var $10 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $4, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 0);
    __label__ = 6;
    break;
   case 4:
    var $14 = HEAP32[$5 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $14);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $15 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $9, $rv);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 1);
    __label__ = 6;
    break;
   case 6:
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueVectorD1Ev($this) {
  __ZN2js15AutoValueVectorD2Ev($this);
  return;
}

function __ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp = __stackBase__;
    var $p1 = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __ZNK9JSContext2fpEv($cx);
    HEAP32[$fp >> 2] = $4;
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $6 = $5;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $8 = $7;
    var $9 = __ZN2js12GlobalObject12getDebuggersEv($8);
    if (($9 | 0) == 0) {
      var $43 = $4;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($9);
    var $13 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($9);
    if (($12 | 0) == ($13 | 0)) {
      var $43 = $4;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $1 | 0;
    var $16 = $p1 | 0;
    var $17 = $3 | 0;
    var $18 = $cx;
    var $p_01 = $12;
    __label__ = 4;
    break;
   case 4:
    var $p_01;
    var $21 = HEAP32[$p_01 >> 2] + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p1, $21, $fp);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p1);
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p1);
    var $27 = HEAP32[$25 >> 2];
    var $29 = HEAP32[$25 + 4 >> 2];
    __ZN8JSObject10setPrivateEPv($29, 0);
    __ZNK8JSObject15getReservedSlotEj($2, $29, 2);
    var $30 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = __ZNK2js10StackFrame13isScriptFrameEv($27);
    if ($32) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $34 = __ZNK2js10StackFrame6scriptEv($27);
    var $35 = $34;
    var $36 = __ZN8JSScript19changeStepModeCountEP9JSContexti($35, $18, -1);
    __label__ = 8;
    break;
   case 8:
    var $38 = HEAP32[$16 >> 2];
    HEAP32[$17 >> 2] = $38;
    __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($21, $3);
    __label__ = 9;
    break;
   case 9:
    var $40 = $p_01 + 4 | 0;
    var $41 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($9);
    if (($40 | 0) == ($41 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $p_01 = $40;
      __label__ = 4;
      break;
    }
   case 10:
    var $43 = HEAP32[$fp >> 2];
    __label__ = 11;
    break;
   case 11:
    var $43;
    var $44 = __ZNK2js10StackFrame11isEvalFrameEv($43);
    if ($44) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $46 = __ZNK2js10StackFrame6scriptEv($43);
    var $47 = $46;
    var $48 = __ZNK2js2gc4Cell11compartmentEv($47);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($48, $cx, 0, $46, 0);
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext["X"] = 1;

function __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js10StackFrame6scriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame15isFunctionFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame11isEvalFrameEv($this);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAP32[$this + 8 >> 2];
    __label__ = 6;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame3funEv($this);
    var $10 = __ZNK10JSFunction6scriptEv($9);
    var $15 = $10;
    __label__ = 6;
    break;
   case 5:
    var $15 = HEAP32[$this + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $dobj = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $4 = $this + 8 | 0;
    var $5 = __ZNK2JS5Value8isObjectEv($vp);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = __ZNK2JS5Value8toObjectEv($vp);
    HEAP32[$obj >> 2] = $7;
    var $8 = $this + 88 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $8, $obj);
    var $9 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $9);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($9);
    var $16 = HEAP32[$14 + 4 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $16);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 4:
    var $18 = HEAP32[$4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($2, $18, 1);
    var $19 = __ZNK2JS5Value8toObjectEv($2);
    var $20 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerObject_class, $19, 0);
    HEAP32[$dobj >> 2] = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($20, $cx);
    if ($23) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $26 = HEAP32[$obj >> 2];
    __ZN8JSObject10setPrivateEPv($20, $26);
    var $27 = HEAP32[$4 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($3, $27);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($20, 0, $3);
    var $28 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($8, $p, $obj, $dobj);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $31 = HEAP32[$dobj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $31);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $34 = HEAP32[$cx + 56 >> 2];
    var $35 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($34, $cx, $vp);
    if ($35) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value8isObjectEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_OBJECT_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 6,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_($1, $k, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $owner = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = __ZNK2JS5Value8isObjectEv($vp);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($vp);
    var $5 = __ZNK8JSObject8getClassEv($4);
    if (($5 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 255, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 8 >> 2] = $9, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    __ZNK8JSObject15getReservedSlotEj($owner, $4, 0);
    var $11 = __ZNK2JS5Value14toObjectOrNullEv($owner);
    if (($11 | 0) == (HEAP32[$1 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2JS5Value6isNullEv($owner);
    var $16 = $15 ? 279 : 278;
    _JS_ReportErrorNumber($cx, 2, 0, $16, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $18 = __ZNK8JSObject10getPrivateEv($4);
    var $19 = $18;
    __ZN2JS5Value9setObjectER8JSObject($vp, $19);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value14toObjectOrNullEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_OBJECT_IMPL($2$0, $2$1);
  return $3;
}

function __ZNK2JS5Value6isNullEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_NULL_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $exc = __stackBase__ + 8;
    var $rv = __stackBase__ + 16;
    var $1 = __stackBase__ + 24;
    var $3 = HEAP32[$ac >> 2];
    var $4 = __ZN9JSContext18isExceptionPendingEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if ($callHook) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = HEAP32[$this + 36 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JSL11ObjectValueER8JSObject($fval, $8);
    __ZN9JSContext19getPendingExceptionEv($exc, $3);
    __ZN9JSContext21clearPendingExceptionEv($3);
    var $12 = HEAP32[$this + 8 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $12);
    var $13 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($3, $1, $fval, 1, $exc, $rv);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    if (($vp | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, 1, $rv, $vp, 0);
    var $_0 = $17;
    __label__ = 10;
    break;
   case 7:
    var $19 = __ZN9JSContext18isExceptionPendingEv($3);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = _JS_ReportPendingException($3);
    __ZN9JSContext21clearPendingExceptionEv($3);
    __label__ = 9;
    break;
   case 9:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext21clearPendingExceptionEv($this) {
  HEAP32[$this + 20 >> 2] = 0;
  var $2 = $this + 24 | 0;
  __ZN2JS5Value12setUndefinedEv($2);
  return;
}

function __ZNK8JSObject8isObjectEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js11ObjectClassE | 0);
}

function __ZNK8JSObject12lastPropertyEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js5Shape8previousEv($this) {
  return HEAP32[$this + 32 >> 2];
}

function __ZNK2js5Shape16isDataDescriptorEv($this) {
  return (HEAP8[$this + 28 | 0] & 48) << 24 >> 24 == 0;
}

function __ZN9JSContext19setPendingExceptionEN2JS5ValueE($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $_03 = $0 | 0;
  var $tmp$0 = HEAP32[$_03 >> 2];
  var $tmp$1 = HEAP32[$_03 + 4 >> 2];
  HEAP32[$this + 20 >> 2] = 1;
  var $_04 = $this + 24 | 0;
  HEAP32[$_04 >> 2] = $tmp$0;
  HEAP32[$_04 + 4 >> 2] = $tmp$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN13JSCompartment12getDebuggeesEv($this) {
  return $this + 1932 | 0;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $ok, $rv, $vp, $callHook) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($ok) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $2;
    __label__ = 21;
    break;
   case 3:
    var $4 = __ZNK2JS5Value11isUndefinedEv($rv);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 5:
    var $7 = __ZNK2JS5Value6isNullEv($rv);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 7:
    var $11 = HEAPU32[$ac >> 2];
    var $13 = HEAP32[$11 + 52 >> 2];
    var $16 = HEAP32[$13 + 210488 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom($16);
    var $20 = HEAP32[$13 + 210492 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom($20);
    var $22 = __ZNK2JS5Value8isObjectEv($rv);
    var $23 = $22 & 1;
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $okResumption_0 = $23;
      var $obj_0 = undef;
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = __ZNK2JS5Value8toObjectEv($rv);
    var $26 = __ZNK8JSObject8isObjectEv($25);
    var $okResumption_0 = $26 & 1;
    var $obj_0 = $25;
    __label__ = 9;
    break;
   case 9:
    var $obj_0;
    var $okResumption_0;
    if ($okResumption_0 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZNK8JSObject12lastPropertyEv($obj_0);
    var $32 = __ZNK2js5Shape8previousEv($31);
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZNK2js5Shape8previousEv($32);
    if (($35 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $38 = $31 + 12 | 0;
    var $39 = HEAP32[$38 >> 2];
    if (($39 | 0) == ($17 | 0) | ($39 | 0) == ($21 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $43 = __ZNK2js5Shape16isDataDescriptorEv($31);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($11, 2, 0, 275, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $44 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $44;
    __label__ = 21;
    break;
   case 15:
    var $46 = $11;
    var $47 = $obj_0;
    var $48 = $31;
    var $49 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($46, $47, $47, $48, 0, $vp);
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $11, $vp);
    if ($52) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, $callHook);
    var $_0 = $54;
    __label__ = 21;
    break;
   case 18:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $57 = HEAP32[$11 + 56 >> 2];
    var $58 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($57, $11, $vp);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $63 = (HEAP32[$38 >> 2] | 0) == ($17 | 0) ? 2 : 3;
    var $_0 = $63;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b["X"] = 1;

function __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($this, $ac, $ok, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $0 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $val | 0;
    var $st$8$0 = $5 | 0;
    HEAP32[$st$8$0 >> 2] = $4$0;
    var $st$8$1 = $5 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4$1;
    var $7 = HEAP32[$ac >> 2];
    if ($ok) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $13 = HEAP32[HEAP32[$7 + 52 >> 2] + 210488 >> 2] | 0;
    var $14 = __ZL12ATOM_TO_JSIDP6JSAtom($13);
    var $key_0 = $14;
    __label__ = 6;
    break;
   case 3:
    var $16 = __ZN9JSContext18isExceptionPendingEv($7);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $22 = HEAP32[HEAP32[$7 + 52 >> 2] + 210492 >> 2] | 0;
    var $23 = __ZL12ATOM_TO_JSIDP6JSAtom($22);
    __ZN9JSContext19getPendingExceptionEv($2, $7);
    var $24 = $2 | 0;
    var $st$8$0 = $24 | 0;
    var $25$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$8$1 >> 2];
    HEAP32[$5 >> 2] = $25$0;
    HEAP32[$5 + 4 >> 2] = $25$1;
    __ZN9JSContext21clearPendingExceptionEv($7);
    __ZN2js15AutoCompartment5leaveEv($ac);
    var $key_0 = $23;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($ac);
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $key_0;
    var $28 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE($7);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $7, $val);
    if ($31) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $33 = $7;
    var $34 = $28;
    var $35 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($33, $34, $key_0, $val, 10, 12, 1, 0, 0, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $28);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE($cx, $4);
  return $5;
}

function __Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_($cx, $obj, $name, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2JS5Value12setUndefinedEv($rval);
    var $2 = _strlen($name);
    var $3 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL12ATOM_TO_JSIDP6JSAtom($3);
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($7, $8, $6, 2, $fval);
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE($fval);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $16 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL11ObjectValueER8JSObject($1, $obj);
    var $14 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
    var $16 = $14;
    __label__ = 5;
    break;
   case 5:
    var $16;
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 0);
    var $4 = __ZNK9JSContext2fpEv($cx);
    var $5 = $this + 8 | 0;
    var $6 = HEAP32[$5 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $argv | 0;
    var $10 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $4, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, 0);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 4:
    var $14 = HEAP32[$5 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $14);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $15 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $9, $rv);
    var $16 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $15, $rv, $vp, 1);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exc = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $argv = __stackBase__ + 60;
    var $rv = __stackBase__ + 76;
    var $1 = __stackBase__ + 84;
    var $2 = __stackBase__ + 92;
    var $3 = __stackBase__ + 100;
    var $4 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 1);
    var $5 = __ZNK9JSContext2fpEv($cx);
    __ZN9JSContext19getPendingExceptionEv($exc, $cx);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $6 = $this + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $8 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = $argv + 8 | 0;
    var $11 = $exc | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $10 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = $argv | 0;
    var $15 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($this, $cx, $5, $14);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $10);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, $vp, 0);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 5:
    var $21 = HEAP32[$6 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $21);
    __ZN2JSL11ObjectValueER8JSObject($2, $4);
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 2, $14, $rv);
    var $23 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($this, $ac, $22, $rv, $vp, 1);
    if (($23 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $23;
      __label__ = 7;
      break;
    }
   case 6:
    var $26 = $3 | 0;
    HEAP32[$26 >> 2] = $12$0;
    HEAP32[$26 + 4 >> 2] = $12$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $3);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($this, $cx, $script, $obj, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $argv = __stackBase__ + 52;
    var $rv = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $2 = __stackBase__ + 76;
    var $3 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 2);
    var $4 = $this + 8 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $5);
    var $6 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $obj);
    var $14 = $10;
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($this, $cx, $script);
    var $14 = $12;
    __label__ = 5;
    break;
   case 5:
    var $14;
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 0);
    __label__ = 9;
    break;
   case 7:
    var $19 = $argv | 0;
    __ZN2JS5Value9setObjectER8JSObject($19, $14);
    var $20 = HEAP32[$4 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($1, $20);
    __ZN2JSL11ObjectValueER8JSObject($2, $3);
    var $21 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, 1, $19, $rv);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($this, $ac, 0, 1);
    __label__ = 9;
    break;
   case 9:
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $scriptobj = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $obj;
    var $3 = $this + 124 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $3, $1);
    var $4 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $4);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$1 >> 2];
    var $10 = __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $9);
    HEAP32[$scriptobj >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_($3, $p, $1, $scriptobj);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($4);
    var $_0 = HEAP32[$15 + 4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($this, $cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $scriptobj = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $script;
    var $3 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $3, $1);
    var $4 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $4);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$1 >> 2];
    var $10 = __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $9, 0);
    HEAP32[$scriptobj >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($3, $p, $1, $scriptobj);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($4);
    var $_0 = HEAP32[$15 + 4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $1 = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    var $2 = __ZNK9JSContext2fpEv($cx);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject9getGlobalEv($4);
    HEAP32[$global >> 2] = $5;
    var $7 = $5;
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $triggered | 0;
    __label__ = 9;
    break;
   case 3:
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($8);
    var $12 = $triggered | 0;
    var $p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($p_0 | 0) == ($14 | 0)) {
      var $_pre_phi = $12;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$p_0 >> 2];
    if ((HEAP8[$17 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZNK2js8Debugger7getHookENS0_4HookE($17, $which);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = __ZNK2js8Debugger10toJSObjectEv($17);
    __ZN2JSL11ObjectValueER8JSObject($1, $26);
    var $27 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($12, $1);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 8:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 4;
    break;
   case 9:
    var $_pre_phi;
    var $30 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($_pre_phi);
    var $31 = ($which | 0) == 0;
    var $p1_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $p1_0;
    var $33 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($_pre_phi);
    if (($p1_0 | 0) == ($33 | 0)) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZNK2JS5Value8toObjectEv($p1_0);
    var $37 = __ZN2js8Debugger12fromJSObjectEP8JSObject($36);
    var $38 = $37 + 12 | 0;
    var $39 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($38, $global);
    if ($39) {
      __label__ = 12;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 12:
    if ((HEAP8[$37 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __ZNK2js8Debugger7getHookENS0_4HookE($37, $which);
    if (($46 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($31) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $50 = __ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE($37, $cx, $vp);
    var $54 = $50;
    __label__ = 17;
    break;
   case 16:
    var $52 = __ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE($37, $cx, $vp);
    var $54 = $52;
    __label__ = 17;
    break;
   case 17:
    var $54;
    if (($54 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $54;
      __label__ = 19;
      break;
    }
   case 18:
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 10;
    break;
   case 19:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE["X"] = 1;

function __ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $triggered = __stackBase__;
    var $global = __stackBase__ + 92;
    var $r = __stackBase__ + 96;
    __ZN2js15AutoValueVectorC1EP9JSContext($triggered, $cx);
    if ((HEAP8[$script + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $obj;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $8 = $7;
    HEAP32[$global >> 2] = $8;
    var $9 = $7;
    var $10 = __ZN2js12GlobalObject12getDebuggersEv($9);
    if (($10 | 0) == 0) {
      var $27 = $8;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($10, $triggered);
    if ($13) {
      var $27 = $8;
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 4:
    HEAP32[$global >> 2] = 0;
    var $15 = $script;
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    var $17 = __ZN13JSCompartment12getDebuggeesEv($16);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $17);
    __label__ = 5;
    break;
   case 5:
    var $19 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($19) {
      var $27 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $23 = HEAP32[$21 >> 2];
    var $24 = __ZN2js12GlobalObject12getDebuggersEv($23);
    var $25 = __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($24, $triggered);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    __label__ = 5;
    break;
   case 8:
    var $27;
    var $28 = $triggered | 0;
    var $29 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($28);
    var $30 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($28);
    if (($29 | 0) == ($30 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $p_01 = $29;
      var $32 = $27;
      __label__ = 9;
      break;
    }
   case 9:
    var $32;
    var $p_01;
    var $33 = __ZNK2JS5Value8toObjectEv($p_01);
    var $34 = __ZN2js8Debugger12fromJSObjectEP8JSObject($33);
    if (($32 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $34 + 12 | 0;
    var $38 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($37, $global);
    if ($38) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if ((HEAP8[$34 + 40 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $45 = __ZNK2js8Debugger7getHookENS0_4HookE($34, 2);
    if (($45 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($34, $cx, $script, $obj, $kind);
    __label__ = 14;
    break;
   case 14:
    var $49 = $p_01 + 8 | 0;
    var $50 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($28);
    if (($49 | 0) == ($50 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $p_01 = $49;
    var $32 = HEAP32[$global >> 2];
    __label__ = 9;
    break;
   case 16:
    __ZN2js15AutoValueVectorD1Ev($triggered);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE["X"] = 1;

function __ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE($src, $dest) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $dest | 0;
    var $2 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($1);
    var $3 = ($2 | 0) == 0;
    var $4 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($src);
    var $p_0 = $4;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    var $6 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($src);
    if (($p_0 | 0) == ($6 | 0)) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$p_0 >> 2];
    var $10 = __ZNK2js8Debugger10toJSObjectEv($9);
    __ZN2JSL11ObjectValueER8JSObject($v, $10);
    var $11 = __ZNK2js8Debugger17observesNewScriptEv($9);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($1);
    var $15 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($1);
    var $16 = __ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_($14, $15, $v);
    if (($16 | 0) == ($15 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($1, $v);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 2;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 120;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scriptGlobal = __stackBase__;
    var $triggered = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 32;
    var $3 = __stackBase__ + 36;
    var $ac = __stackBase__ + 44;
    var $argv = __stackBase__ + 96;
    var $rv = __stackBase__ + 104;
    var $4 = __stackBase__ + 112;
    var $5 = __ZNK9JSContext2fpEv($cx);
    var $6 = __ZNK2js10StackFrame10scopeChainEv($5);
    var $7 = $6;
    var $8 = __ZNK8JSObject9getGlobalEv($7);
    HEAP32[$scriptGlobal >> 2] = $8;
    var $10 = __ZNK9JSContext4regsEv($cx);
    var $12 = HEAP32[$10 + 4 >> 2];
    var $13 = $cx + 56 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = __ZN13JSCompartment17getBreakpointSiteEPh($14, $12);
    var $17 = HEAP32[$15 + 8 >> 2];
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_($triggered, $1);
    var $18 = __ZNK2js14BreakpointSite15firstBreakpointEv($15);
    var $bp_0 = $18;
    __label__ = 2;
    break;
   case 2:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $22 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($triggered, $bp_0);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      var $_3 = 0;
      __label__ = 22;
      break;
    }
   case 4:
    var $24 = __ZN2js10Breakpoint10nextInSiteEv($bp_0);
    var $bp_0 = $24;
    __label__ = 2;
    break;
   case 5:
    var $26 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv($triggered);
    var $27 = $3 | 0;
    var $28 = $argv | 0;
    var $p_0 = $26;
    var $site_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $site_0;
    var $p_0;
    var $30 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv($triggered);
    if (($p_0 | 0) == ($30 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = HEAP32[$p_0 >> 2];
    if (($site_0 | 0) == 0) {
      var $site_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = __ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE($site_0, $33);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    }
   case 9:
    var $39 = HEAP32[$33 >> 2];
    if ((HEAP8[$39 + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $45 = $39 + 12 | 0;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($2, $45, $scriptGlobal);
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($3, $2);
    if ((HEAP32[$27 >> 2] | 0) == 0) {
      var $site_2 = $site_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = HEAP32[$39 + 8 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $50);
    var $51 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($51) {
      __label__ = 12;
      break;
    } else {
      var $_1_ph = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $53 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($39, $cx, $5, $28);
    if ($53) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $55 = __ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb($39, $ac, $vp, 0);
    var $_1_ph = $55;
    __label__ = 15;
    break;
   case 14:
    var $58 = HEAP32[$33 + 8 >> 2];
    var $59 = __Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_($cx, $58, STRING_TABLE.__str4 | 0, 1, $28, $rv);
    var $60 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($39, $ac, $59, $rv, $vp, 1);
    if (($60 | 0) == 1) {
      __label__ = 16;
      break;
    } else {
      var $_1_ph = $60;
      __label__ = 15;
      break;
    }
   case 15:
    var $_1_ph;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = $_1_ph;
    __label__ = 22;
    break;
   case 16:
    var $63 = HEAP32[$13 >> 2];
    var $64 = __ZN13JSCompartment17getBreakpointSiteEPh($63, $12);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $site_2 = $64;
    __label__ = 17;
    break;
   case 17:
    var $site_2;
    var $p_0 = $p_0 + 4 | 0;
    var $site_0 = $site_2;
    __label__ = 6;
    break;
   case 18:
    if (($site_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = HEAP32[$site_0 + 28 >> 2];
    if (($71 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $74 = __ZNK2js10StackFrame6scriptEv($5);
    var $75 = $site_0 + 32 | 0;
    var $76$0 = HEAP32[$75 >> 2];
    var $76$1 = HEAP32[$75 + 4 >> 2];
    var $77 = $4 | 0;
    HEAP32[$77 >> 2] = $76$0;
    HEAP32[$77 + 4 >> 2] = $76$1;
    var $78 = FUNCTION_TABLE[$71]($cx, $74, $12, $vp, $4);
    if (($78 | 0) == 1) {
      __label__ = 21;
      break;
    } else {
      var $_3 = $78;
      __label__ = 22;
      break;
    }
   case 21:
    __ZN2JS5Value8setInt32Ei($vp, $17);
    var $_3 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_3;
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev($triggered);
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK9JSContext4regsEv($this) {
  var $1 = $this + 60 | 0;
  var $2 = __ZNK2js12ContextStack4regsEv($1);
  return $2;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15TempAllocPolicyC1EP9JSContext($this, $cx) {
  __ZN2js15TempAllocPolicyC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 8,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js8Debugger9fromLinksEP10JSCListStr($links) {
  return $links;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js10Breakpoint10getHandlerEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZNK2js12CallReceiver5thisvEv($this) {
  return HEAP32[$this >> 2] - 8 | 0;
}

function __ZNK2js12CallReceiver4rvalEv($this) {
  return HEAP32[$this >> 2] - 16 | 0;
}

function __ZN2JS5Value8setInt32Ei($this, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL($1, $i);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 180;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fp = __stackBase__;
    var $exception = __stackBase__ + 4;
    var $frames = __stackBase__ + 12;
    var $p = __stackBase__ + 72;
    var $1 = __stackBase__ + 76;
    var $frame = __stackBase__ + 84;
    var $2 = __stackBase__ + 88;
    var $ac = __stackBase__ + 96;
    var $3 = __stackBase__ + 148;
    var $rval = __stackBase__ + 156;
    var $4 = __stackBase__ + 164;
    var $5 = __stackBase__ + 172;
    var $6 = __ZNK9JSContext2fpEv($cx);
    HEAP32[$fp >> 2] = $6;
    __ZN2JSL14UndefinedValueEv($exception);
    var $7 = __ZN9JSContext18isExceptionPendingEv($cx);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext19getPendingExceptionEv($exception, $cx);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    __label__ = 3;
    break;
   case 3:
    __ZN2js16AutoObjectVectorC1EP9JSContext($frames, $cx);
    var $10 = __ZNK2js10StackFrame10scopeChainEv($6);
    var $11 = $10;
    var $12 = __ZNK8JSObject9getGlobalEv($11);
    var $13 = $12;
    var $14 = __ZN2js12GlobalObject12getDebuggersEv($13);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_pre_phi = $frames | 0;
    __label__ = 11;
    break;
   case 5:
    var $17 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($14);
    var $18 = $1 | 0;
    var $19 = $frames | 0;
    var $d_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $d_0;
    var $21 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($14);
    if (($d_0 | 0) == ($21 | 0)) {
      var $_pre_phi = $19;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAP32[$d_0 >> 2] + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p, $25, $fp);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p);
    if ((HEAP32[$18 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p);
    var $31 = HEAP32[$29 + 4 >> 2];
    HEAP32[$frame >> 2] = $31;
    __ZNK8JSObject15getReservedSlotEj($2, $31, 2);
    var $32 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = __ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_($19, $frame);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $d_0 = $d_0 + 4 | 0;
    __label__ = 6;
    break;
   case 11:
    var $_pre_phi;
    var $37 = __ZN2js16AutoVectorRooterIP8JSObjectE5beginEv($_pre_phi);
    var $_0 = undef;
    var $p1_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $p1_0;
    var $_0;
    var $39 = __ZN2js16AutoVectorRooterIP8JSObjectE3endEv($_pre_phi);
    if (($p1_0 | 0) == ($39 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $42 = HEAP32[$p1_0 >> 2];
    var $43 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($42);
    var $45 = HEAP32[$43 + 8 >> 2];
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $45);
    var $46 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 15:
    __ZNK8JSObject15getReservedSlotEj($3, $42, 2);
    __ZN2JSL11ObjectValueER8JSObject($4, $42);
    var $48 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $4, $3, 0, 0, $rval);
    var $49 = __ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b($43, $ac, $48, $rval, $vp, 1);
    var $50 = ($49 | 0) == 1;
    var $_0_ = $50 ? $_0 : $49;
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($50) {
      __label__ = 16;
      break;
    } else {
      var $_2 = $_0_;
      __label__ = 19;
      break;
    }
   case 16:
    var $_0 = $_0_;
    var $p1_0 = $p1_0 + 4 | 0;
    __label__ = 12;
    break;
   case 17:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      __label__ = 18;
      break;
    } else {
      var $_2 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $55 = $exception | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = $5 | 0;
    HEAP32[$57 >> 2] = $56$0;
    HEAP32[$57 + 4 >> 2] = $56$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $5);
    var $_2 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_2;
    __ZN2js16AutoObjectVectorD1Ev($frames);
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2js16AutoObjectVectorC1EP9JSContext($this, $cx) {
  __ZN2js16AutoObjectVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_($this, $v) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$v >> 2];
  var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $2);
  return $3;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE5beginEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIP8JSObjectE3endEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv($1);
  return $2;
}

function __ZN2js16AutoObjectVectorD1Ev($this) {
  __ZN2js16AutoObjectVectorD2Ev($this);
  return;
}

function __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $tracer | 0;
    var $6 = HEAP32[HEAP32[HEAP32[$1 >> 2] + 52 >> 2] + 144080 >> 2];
    var $7 = $map + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $7);
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $11 = HEAP32[$9 >> 2];
    var $12 = $11;
    var $13 = __ZNK2js2gc4Cell11compartmentEv($12);
    if (($13 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $16 = HEAP32[$1 >> 2];
    var $17 = $11;
    var $18 = __Z20IsAboutToBeFinalizedP9JSContextPKv($16, $17);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($tracer, $11, undef);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $21 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$tracer >> 2] + 52 >> 2];
    var $6 = HEAP32[$4 + 144080 >> 2];
    var $7 = $4 + 144228 | 0;
    var $9 = HEAP32[$7 >> 2];
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $11 = $9;
      __label__ = 2;
      break;
    }
   case 2:
    var $11;
    var $12 = __ZN2js8Debugger9fromLinksEP10JSCListStr($11);
    var $15 = HEAP32[$12 + 8 >> 2];
    var $16 = __ZNK2js2gc4Cell11compartmentEv($15);
    if (($16 | 0) == ($6 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $12 + 80 | 0;
    __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $19);
    var $20 = $12 + 116 | 0;
    __ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE($tracer, $20);
    __label__ = 4;
    break;
   case 4:
    var $22 = HEAP32[$11 >> 2];
    if (($22 | 0) == ($7 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $11 = $22;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $trc | 0;
    var $3 = HEAPU32[$trc >> 2];
    var $5 = HEAP32[$3 + 52 >> 2];
    var $7 = HEAPU32[$5 + 144080 >> 2];
    var $8 = $5 + 4 | 0;
    var $9 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($8);
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($9 | 0) == ($10 | 0)) {
      var $markedAny_0_lcssa = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = ($7 | 0) != 0;
    var $_not = $12 ^ 1;
    var $c_015 = $9;
    var $markedAny_016 = 0;
    __label__ = 3;
    break;
   case 3:
    var $markedAny_016;
    var $c_015;
    var $14 = HEAPU32[$c_015 >> 2];
    var $15 = ($14 | 0) == ($7 | 0);
    if ($15 | $_not) {
      __label__ = 4;
      break;
    } else {
      var $markedAny_1 = $markedAny_016;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $markedAny_016 & 1;
    var $18 = __ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer($14, $1);
    var $markedAny_1 = $18 & 1 | $17;
    __label__ = 5;
    break;
   case 5:
    var $markedAny_1;
    if ($12 & $15) {
      var $markedAny_8 = $markedAny_1;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZN13JSCompartment12getDebuggeesEv($14);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $23);
    var $24 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($24) {
      var $markedAny_8 = $markedAny_1;
      __label__ = 21;
      break;
    } else {
      var $markedAny_211 = $markedAny_1;
      __label__ = 7;
      break;
    }
   case 7:
    var $markedAny_211;
    var $25 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $27 = HEAP32[$25 >> 2];
    var $28 = __ZN2js12GlobalObject12getDebuggersEv($27);
    var $29 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($28);
    var $30 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($28);
    if (($29 | 0) == ($30 | 0)) {
      var $markedAny_3_lcssa = $markedAny_211;
      __label__ = 20;
      break;
    } else {
      var $p_06 = $29;
      var $markedAny_37 = $markedAny_211;
      __label__ = 8;
      break;
    }
   case 8:
    var $markedAny_37;
    var $p_06;
    var $32 = HEAP32[$p_06 >> 2];
    var $33 = __ZNK2js8Debugger10toJSObjectEv($32);
    if ($12) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $35 = $33;
    var $36 = __ZNK2js2gc4Cell11compartmentEv($35);
    if (($7 | 0) == ($36 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $markedAny_7 = $markedAny_37;
      __label__ = 19;
      break;
    }
   case 10:
    var $39 = $33;
    var $40 = __Z20IsAboutToBeFinalizedP9JSContextPKv($3, $39);
    if ($40) {
      __label__ = 11;
      break;
    } else {
      var $markedAny_42 = $markedAny_37;
      __label__ = 13;
      break;
    }
   case 11:
    var $42 = __ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext($32, $3);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      var $markedAny_7 = $markedAny_37;
      __label__ = 19;
      break;
    }
   case 12:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($1, $33, undef);
    var $markedAny_42 = 1;
    __label__ = 13;
    break;
   case 13:
    var $markedAny_42;
    var $43 = __ZNK2js8Debugger15firstBreakpointEv($32);
    if (($43 | 0) == 0) {
      var $markedAny_7 = $markedAny_42;
      __label__ = 19;
      break;
    } else {
      var $markedAny_53 = $markedAny_42;
      var $bp_04 = $43;
      __label__ = 14;
      break;
    }
   case 14:
    var $bp_04;
    var $markedAny_53;
    var $46 = HEAP32[$bp_04 + 4 >> 2];
    var $47 = __ZNK2js14BreakpointSite15getScriptObjectEv($46);
    if (($47 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = $47;
    var $51 = __Z20IsAboutToBeFinalizedP9JSContextPKv($3, $50);
    if ($51) {
      var $markedAny_6 = $markedAny_53;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $53 = __ZNK2js10Breakpoint10getHandlerEv($bp_04);
    var $54 = $53;
    var $55 = __Z20IsAboutToBeFinalizedP9JSContextPKv($3, $54);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      var $markedAny_6 = $markedAny_53;
      __label__ = 18;
      break;
    }
   case 17:
    var $57 = __ZNK2js10Breakpoint10getHandlerEv($bp_04);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($1, $57, undef);
    var $markedAny_6 = 1;
    __label__ = 18;
    break;
   case 18:
    var $markedAny_6;
    var $59 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_04);
    if (($59 | 0) == 0) {
      var $markedAny_7 = $markedAny_6;
      __label__ = 19;
      break;
    } else {
      var $markedAny_53 = $markedAny_6;
      var $bp_04 = $59;
      __label__ = 14;
      break;
    }
   case 19:
    var $markedAny_7;
    var $61 = $p_06 + 4 | 0;
    var $62 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($28);
    if (($61 | 0) == ($62 | 0)) {
      var $markedAny_3_lcssa = $markedAny_7;
      __label__ = 20;
      break;
    } else {
      var $p_06 = $61;
      var $markedAny_37 = $markedAny_7;
      __label__ = 8;
      break;
    }
   case 20:
    var $markedAny_3_lcssa;
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $64 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($64) {
      var $markedAny_8 = $markedAny_3_lcssa;
      __label__ = 21;
      break;
    } else {
      var $markedAny_211 = $markedAny_3_lcssa;
      __label__ = 7;
      break;
    }
   case 21:
    var $markedAny_8;
    var $65 = $c_015 + 4 | 0;
    var $66 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($65 | 0) == ($66 | 0)) {
      var $markedAny_0_lcssa = $markedAny_8;
      __label__ = 22;
      break;
    } else {
      var $c_015 = $65;
      var $markedAny_016 = $markedAny_8;
      __label__ = 3;
      break;
    }
   case 22:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return ($markedAny_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE["X"] = 1;

function __ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js8Debugger12fromJSObjectEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8Debugger5traceEP8JSTracer($1, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger5traceEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $2 = HEAP32[$this + 36 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $2, undef);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 52 | 0;
    __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $6);
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r);
    var $10 = HEAP32[$8 + 4 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $10, undef);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $12 = $this + 80 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($12, $trc);
    var $13 = $this + 116 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($13, $trc);
    var $14 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r1, $14);
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r1);
    var $18 = HEAP32[$16 + 4 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $18, undef);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r1);
    var $19 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r1);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11WeakMapBase5traceEP8JSTracer($this, $tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$tracer + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 | 0;
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$this + 4 >> 2] = $10;
    HEAP32[$9 >> 2] = $this;
    __label__ = 5;
    break;
   case 3:
    if ((HEAP32[$tracer + 20 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$this >> 2] >> 2];
    FUNCTION_TABLE[$19]($this, $tracer);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger8sweepAllEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $e1 = __stackBase__ + 16;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 144228 | 0;
    var $5 = HEAP32[$3 >> 2];
    if (($5 | 0) == ($3 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $e | 0;
    var $9 = $5;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $10 = __ZN2js8Debugger9fromLinksEP10JSCListStr($9);
    var $13 = HEAP32[$10 + 8 >> 2];
    var $14 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = $10 + 12 | 0;
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $16);
    var $17 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($7);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    __label__ = 6;
    break;
   case 6:
    var $19 = HEAP32[$9 >> 2];
    if (($19 | 0) == ($3 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $9 = $19;
      __label__ = 3;
      break;
    }
   case 7:
    var $21 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($7);
    var $22 = HEAP32[$21 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($10, $cx, $22, 0, $e);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($7);
    var $23 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($7);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 8:
    var $24 = $2 + 4 | 0;
    var $25 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($24);
    var $26 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($24);
    if (($25 | 0) == ($26 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $e1 | 0;
    var $c_01 = $25;
    __label__ = 10;
    break;
   case 10:
    var $c_01;
    var $30 = HEAP32[$c_01 >> 2];
    var $31 = __ZN13JSCompartment12getDebuggeesEv($30);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e1, $31);
    var $32 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($28);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e1);
    var $33 = $c_01 + 4 | 0;
    var $34 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($24);
    if (($33 | 0) == ($34 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $c_01 = $33;
      __label__ = 10;
      break;
    }
   case 12:
    var $36 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($28);
    var $37 = HEAP32[$36 >> 2];
    var $38 = $37;
    var $39 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $38);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($cx, $37, $e1);
    __label__ = 14;
    break;
   case 14:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($28);
    var $42 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($28);
    if ($42) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger8sweepAllEP9JSContext["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($this, $cx, $global, $compartmentEnum, $debugEnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $e = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $global;
    var $2 = $this + 52 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_($e, $2);
    var $3 = $e | 0;
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($e);
    var $5 = $global;
    var $6 = __ZN2js12GlobalObject12getDebuggersEv($5);
    var $7 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($6);
    var $8 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($6);
    var $p_0 = $7;
    __label__ = 6;
    break;
   case 3:
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($3);
    var $11 = HEAP32[$9 >> 2];
    var $12 = __ZNK2js10StackFrame10scopeChainEv($11);
    var $13 = $12;
    var $14 = __ZNK8JSObject9getGlobalEv($13);
    if (($14 | 0) == ($global | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($3);
    var $20 = HEAP32[$18 + 4 >> 2];
    __ZN8JSObject10setPrivateEPv($20, 0);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($e);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($3);
    var $22 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($3);
    if ($22) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 6:
    var $p_0;
    if (($p_0 | 0) == ($8 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$p_0 >> 2] | 0) == ($this | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_($6, $p_0);
    var $31 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($6);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = $global;
    var $34 = __ZNK2js2gc4Cell11compartmentEv($33);
    __ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($34, $cx, $global, $compartmentEnum);
    __label__ = 11;
    break;
   case 11:
    if (($debugEnum | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($debugEnum);
    __label__ = 14;
    break;
   case 13:
    var $39 = $this + 12 | 0;
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($39, $1);
    __label__ = 14;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this);
  return;
}

function __ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($cx, $global, $compartmentEnum) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = __ZN2js12GlobalObject12getDebuggersEv($1);
    var $3 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv($2);
    var $5 = HEAP32[$4 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($5, $cx, $global, $compartmentEnum, 0);
    var $6 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($2);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv($this) {
  var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN2js8Debugger8finalizeEP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = __ZN2js8Debugger12fromJSObjectEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $4);
    var $7 = $e | 0;
    var $8 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    __label__ = 6;
    break;
   case 5:
    var $9 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($7);
    var $10 = HEAP32[$9 >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($1, $cx, $10, 0, $e);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($7);
    var $11 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($7);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 6:
    __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($cx, $1);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv($1);
  return $2;
}

function __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8DebuggerD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, $fnname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $args | 0;
    var $2 = __ZNK2js12CallReceiver5thisvEv($1);
    var $3 = __ZNK2JS5Value8isObjectEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($2);
    var $8 = __ZNK8JSObject8getClassEv($7);
    if (($8 | 0) == (__ZN2js8Debugger7jsclassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$8 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $14 = __ZN2js8Debugger12fromJSObjectEP8JSObject($7);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $14;
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str12 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $args | 0;
    var $5 = __ZNK2js12CallReceiver4rvalEv($4);
    var $9 = (HEAP8[$1 + 40 | 0] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($5, $9);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14CallArgsFromVpEjPN2JS5ValueE($agg_result, $argc, $vp) {
  var $1 = $vp + 16 | 0;
  __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $1);
  return;
}

function __ZN2JS5Value10setBooleanEb($this, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $b & 1;
  _BOOLEAN_TO_JSVAL_IMPL($1, $2);
  var $3 = $1 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $this | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js8CallArgsixEj($this, $i) {
  return HEAP32[$this >> 2] + ($i << 3) | 0;
}

function __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($this, $idx, $val) {
  var $3 = $val | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = HEAP32[$this + 32 >> 2] + ($idx << 3) | 0;
  var $st$8$0 = $5 | 0;
  HEAP32[$st$8$0 >> 2] = $4$0;
  var $st$8$1 = $5 + 4 | 0;
  HEAP32[$st$8$1 >> 2] = $4$1;
  return;
}

function __ZNK2js12ContextStack5spaceEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js13AllFramesIter4doneEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZNK2js13AllFramesIter2fpEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK13JSCompartment9debugModeEv($this) {
  return (HEAP32[$this + 804 >> 2] | 0) != 0;
}

function __ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str13 | 0, 1);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str14 | 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js8CallArgsixEj($args, 0);
    var $9 = __Z17js_ValueToBooleanRKN2JS5ValueE($8);
    var $10 = ($9 | 0) != 0;
    var $12 = $5 + 40 | 0;
    if (($10 & 1 | 0) == (HEAP8[$12] & 1 & 255 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK2js8Debugger15firstBreakpointEv($5);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $bp_01 = $18;
      __label__ = 6;
      break;
    }
   case 6:
    var $bp_01;
    var $21 = HEAP32[$bp_01 + 4 >> 2];
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = __ZN2js14BreakpointSite3incEP9JSContext($21, undef);
    __label__ = 9;
    break;
   case 8:
    __ZN2js14BreakpointSite3decEP9JSContext($21, undef);
    __label__ = 9;
    break;
   case 9:
    var $26 = __ZN2js10Breakpoint14nextInDebuggerEv($bp_01);
    if (($26 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $bp_01 = $26;
      __label__ = 6;
      break;
    }
   case 10:
    HEAP8[$12] = $10 & 1;
    var $29 = $args | 0;
    var $30 = __ZNK2js12CallReceiver4rvalEv($29);
    __ZN2JS5Value12setUndefinedEv($30);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str15 | 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $args | 0;
    var $6 = __ZNK2js12CallReceiver4rvalEv($5);
    var $8 = HEAP32[$2 + 8 >> 2];
    var $9 = $which + 3 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $8, $9);
    var $10 = $1 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $6 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, $which) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str16 | 0, 1);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str17 | 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js8CallArgsixEj($args, 0);
    var $9 = __ZNK2JS5Value8isObjectEv($8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $11 = __ZNK2JS5Value8toObjectEv($8);
    var $12 = __ZN8JSObject10isCallableEv($11);
    if ($12) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, 65536);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 7:
    var $15 = __ZNK2JS5Value11isUndefinedEv($8);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _JS_ReportErrorNumber($cx, 2, 0, 230, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $19 = HEAP32[$5 + 8 >> 2];
    var $20 = $which + 3 | 0;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($19, $20, $8);
    var $21 = $args | 0;
    var $22 = __ZNK2js12CallReceiver4rvalEv($21);
    __ZN2JS5Value12setUndefinedEv($22);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10isCallableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10isFunctionEv($this);
    if ($1) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8getClassEv($this);
    var $8 = (HEAP32[$3 + 48 >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 0);
  return $1;
}

function __ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 0);
  return $1;
}

function __ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 1);
  return $1;
}

function __ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 1);
  return $1;
}

function __ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 2);
  return $1;
}

function __ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 2);
  return $1;
}

function __ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 3);
  return $1;
}

function __ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE($cx, $argc, $vp, 3);
  return $1;
}

function __ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str18 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $args | 0;
    var $5 = __ZNK2js12CallReceiver4rvalEv($4);
    var $7 = HEAP32[$1 + 36 >> 2];
    __ZN2JS5Value15setObjectOrNullEP8JSObject($5, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str19 | 0, 1);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str20 | 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js8CallArgsixEj($args, 0);
    var $9 = __ZNK2JS5Value6isNullEv($8);
    if ($9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZNK2JS5Value8isObjectEv($8);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $13 = __ZNK2JS5Value8toObjectEv($8);
    var $14 = __ZN8JSObject10isCallableEv($13);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 276, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str21 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $17 = __ZNK2JS5Value14toObjectOrNullEv($8);
    HEAP32[$5 + 36 >> 2] = $17;
    var $19 = $args | 0;
    var $20 = __ZNK2js12CallReceiver4rvalEv($19);
    __ZN2JS5Value12setUndefinedEv($20);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rv = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($1, $v);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject8getClassEv($3);
    if (($6 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $rv | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($this, $cx, $rv);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $14 = __ZNK2JS5Value8toObjectEv($rv);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 5:
    var $16 = __ZNK8JSObject25isCrossCompartmentWrapperEv($3);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZNK8JSObject15getProxyPrivateEv($3);
    var $19 = __ZNK2JS5Value8toObjectEv($18);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject15getProxyPrivateEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 1);
  return $1;
}

function __ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $v = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str22 | 0, 1);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str23 | 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js8CallArgsixEj($args, 0);
    var $9 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($5, $cx, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZNK8JSObject9getGlobalEv($12);
    var $14 = $13;
    var $15 = __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($5, $cx, $14);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject($v, $9);
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $v);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $args | 0;
    var $20 = __ZNK2js12CallReceiver4rvalEv($19);
    var $21 = $v | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $20 | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($this, $cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $visited = __stackBase__ + 4;
    var $2 = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $next = __stackBase__ + 40;
    var $ac = __stackBase__ + 44;
    HEAP32[$1 >> 2] = $global;
    var $3 = $this + 12 | 0;
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($3, $1);
    if ($4) {
      var $_2 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$1 >> 2];
    var $7 = $6;
    var $8 = __ZNK2js2gc4Cell11compartmentEv($7);
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $cx);
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_($visited, $2);
    var $11 = HEAP32[$this + 8 >> 2];
    var $12 = __ZNK2js2gc4Cell11compartmentEv($11);
    var $13 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($visited, $12);
    if ($13) {
      var $i_0 = 0;
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 29;
      break;
    }
   case 3:
    var $i_0;
    var $14 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv($visited);
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $17 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj($visited, $i_0);
    var $18 = HEAPU32[$17 >> 2];
    if (($18 | 0) == ($8 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 280, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 29;
    break;
   case 6:
    var $22 = __ZN13JSCompartment12getDebuggeesEv($18);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $22);
    __label__ = 7;
    break;
   case 7:
    var $24 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($24) {
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $28 = HEAP32[$26 >> 2];
    var $29 = __ZN2js12GlobalObject12getDebuggersEv($28);
    var $30 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($29);
    var $p_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $p_0;
    var $32 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($29);
    if (($p_0 | 0) == ($32 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[HEAP32[$p_0 >> 2] + 8 >> 2];
    var $39 = __ZNK2js2gc4Cell11compartmentEv($38);
    HEAP32[$next >> 2] = $39;
    var $40 = __ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_($visited, $next);
    var $41 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($visited);
    if (($40 | 0) == ($41 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $44 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($visited, $39);
    if ($44) {
      __label__ = 12;
      break;
    } else {
      var $_1 = 0;
      __label__ = 29;
      break;
    }
   case 12:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 9;
    break;
   case 13:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    __label__ = 7;
    break;
   case 14:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 15:
    var $51 = __ZNK13JSCompartment9debugModeEv($8);
    if ($51) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $53 = __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($8, $cx);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    _JS_ReportErrorNumber($cx, 2, 0, 281, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 29;
    break;
   case 18:
    var $56 = $6 | 0;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $56);
    var $57 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($57) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 19:
    var $59 = $6;
    var $60 = $cx;
    var $61 = __ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext($59, $60);
    if (($61 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $64 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($61, $this);
    if ($64) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 28;
    break;
   case 22:
    var $67 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($3, $1);
    if (($67 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 27;
    break;
   case 24:
    var $71 = HEAPU32[$1 >> 2];
    var $72 = $71;
    var $73 = __ZN2js12GlobalObject12getDebuggersEv($72);
    var $74 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv($73);
    if ($74 >>> 0 > 1) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $77 = __ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE($8, $cx, $71);
    if ($77) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($3, $1);
    __label__ = 27;
    break;
   case 27:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($61);
    var $_0 = 0;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 29;
    break;
   case 29:
    var $_1;
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev($visited);
    var $_2 = $_1;
    __label__ = 30;
    break;
   case 30:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE["X"] = 1;

function __ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $global = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str24 | 0, 1);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str25 | 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js8CallArgsixEj($args, 0);
    var $9 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($5, $cx, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZNK8JSObject9getGlobalEv($12);
    HEAP32[$global >> 2] = $13;
    var $15 = $5 + 12 | 0;
    var $16 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($15, $global);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = HEAP32[$global >> 2];
    __ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_($5, $cx, $18, 0, 0);
    __label__ = 7;
    break;
   case 7:
    var $20 = $args | 0;
    var $21 = __ZNK2js12CallReceiver4rvalEv($20);
    __ZN2JS5Value12setUndefinedEv($21);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str26 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $8 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str27 | 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js8CallArgsixEj($args, 0);
    var $12 = __ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE($8, $cx, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $args | 0;
    var $16 = __ZNK2js12CallReceiver4rvalEv($15);
    var $17 = $8 + 12 | 0;
    var $18 = $12;
    var $19 = __ZNK8JSObject9getGlobalEv($18);
    HEAP32[$1 >> 2] = $19;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($2, $17, $1);
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($3, $2);
    var $23 = (HEAP32[$3 >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($16, $23);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $e = __stackBase__ + 8;
    var $v = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str28 | 0);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($4);
    var $6 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $5, 0);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($4);
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($6, $cx, 0, $9);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $4);
    var $10 = $e | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $12 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($10);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($10);
    var $16 = HEAP32[$14 >> 2] | 0;
    __ZN2JSL11ObjectValueER8JSObject($v, $16);
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($1, $cx, $v);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = $i_0 + 1 | 0;
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($6, $i_0, $v);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($10);
    var $i_0 = $19;
    __label__ = 4;
    break;
   case 7:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    var $21 = $args | 0;
    var $22 = __ZNK2js12CallReceiver4rvalEv($21);
    __ZN2JS5Value9setObjectER8JSObject($22, $6);
    var $_1 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($1);
  return $2;
}

function __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = $1;
    var $3 = HEAPU32[$2 >> 2];
    if ($3 >>> 0 < $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $12 = $3;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx);
    var $8 = HEAP32[$2 >> 2];
    var $9 = HEAP32[$this + 32 >> 2] + ($8 << 3) | 0;
    var $10 = $index - $8 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2($9, $10);
    var $12 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $13 = $extra + $index | 0;
    if ($12 >>> 0 < $13 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$1 >> 2] = $13;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $i = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str29 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx + 60 | 0;
    var $5 = __ZNK2js12ContextStack5spaceEv($4);
    var $6 = $i;
    var $7 = $5;
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($6, $7);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZNK2js13AllFramesIter4doneEv($i);
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js13AllFramesIter2fpEv($i);
    var $12 = __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($1, $11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZNK2js13AllFramesIter2fpEv($i);
    var $15 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($1, $cx, $14, $vp);
    var $_0 = $15 & 1;
    __label__ = 8;
    break;
   case 6:
    var $18 = __ZN2js13AllFramesIterppEv($6);
    __label__ = 3;
    break;
   case 7:
    var $20 = $args | 0;
    var $21 = __ZNK2js12CallReceiver4rvalEv($20);
    __ZN2JS5Value7setNullEv($21);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($this, $fp) {
  var $1 = __ZNK2js10StackFrame10scopeChainEv($fp);
  var $2 = __ZNK2js8Debugger13observesScopeEP8JSObject($this, $1);
  return $2;
}

function __ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $r = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc($cx, $args, STRING_TABLE.__str30 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 + 12 | 0;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $4);
    var $5 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($5) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $8 = HEAP32[$6 >> 2];
    var $9 = __ZNK2js2gc4Cell11compartmentEv($8);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($9, $cx, $1, 0, 0);
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $10 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($10) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $v = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $5 = __ZNK2js8CallArgsixEj($args, $i_0);
    var $6 = __ZNK2JS5Value8isObjectEv($5);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 5:
    var $10 = __ZNK2JS5Value8toObjectEv($5);
    var $11 = __ZNK8JSObject25isCrossCompartmentWrapperEv($10);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 274, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2 | 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $16 = $args | 0;
    var $17 = __ZNK2js12CallReceiver6calleeEv($16);
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $22 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($17, $cx, $21, $v);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZNK2JS5Value8toObjectEv($v);
    var $26 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js8Debugger7jsclassE, $25, 0);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($26, $cx);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    __ZNK8JSObject15getReservedSlotEj($1, $25, 0);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($26, 0, $1);
    __ZNK8JSObject15getReservedSlotEj($1, $25, 1);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($26, 1, $1);
    __ZNK8JSObject15getReservedSlotEj($1, $25, 2);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($26, 2, $1);
    var $30 = __ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_($cx, $cx, $26);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = $30;
    __ZN8JSObject10setPrivateEPv($26, $33);
    var $34 = __ZN2js8Debugger4initEP9JSContext($30, $cx);
    if ($34) {
      var $i1_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN9JSContext7delete_IN2js8DebuggerEEEvPT_($cx, $30);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 14:
    var $i1_0;
    if ($i1_0 >>> 0 < $argc >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $38 = __ZNK2js8CallArgsixEj($args, $i1_0);
    var $39 = __ZNK2JS5Value8toObjectEv($38);
    var $40 = __ZNK8JSObject15getProxyPrivateEv($39);
    var $41 = __ZNK2JS5Value8toObjectEv($40);
    var $42 = $41;
    var $43 = __ZNK8JSObject9getGlobalEv($42);
    var $44 = $43;
    var $45 = __ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE($30, $cx, $44);
    if ($45) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 14;
    break;
   case 17:
    var $49 = __ZNK2js12CallReceiver4rvalEv($16);
    __ZN2JS5Value9setObjectER8JSObject($49, $26);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js12CallReceiver6calleeEv($this) {
  var $3 = HEAP32[$this >> 2] - 16 | 0;
  var $4 = __ZNK2JS5Value8toObjectEv($3);
  return $4;
}

function __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($this, $cx, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom($1);
  var $3 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $2, $vp);
  return $3;
}

function __ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 180);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js8DebuggerC2EP9JSContextP8JSObject($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_($c, $v) {
  var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($c);
  var $2 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv($c);
  var $3 = __ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_($1, $2, $v);
  return $3;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK10JSFunction6scriptEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $t);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($2);
    var $13 = $7;
    __label__ = 5;
    break;
   case 3:
    var $9 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $13 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($2);
    var $13 = $11;
    __label__ = 5;
    break;
   case 5:
    var $13;
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $this, $l);
    __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_($this, $it) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $it + 4 | 0;
    var $2 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this);
    if (($1 | 0) == ($2 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $it;
      var $4 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $_01;
    var $5 = HEAP32[$4 >> 2];
    HEAP32[$_01 >> 2] = $5;
    var $6 = $4 + 4 | 0;
    var $7 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($this);
    if (($6 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $4;
      var $4 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZL20DebuggerScript_traceP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    if ((HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZNK8JSObject15getReservedSlotEj($v, $obj, 1);
    var $9 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5Value9toPrivateEv($v);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $14, undef);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $script, $holder) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = $this + 8 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZNK8JSObject15getReservedSlotEj($1, $5, 2);
    var $6 = __ZNK2JS5Value8toObjectEv($1);
    var $7 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerScript_class, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($7, $cx);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $script;
    __ZN8JSObject10setPrivateEPv($7, $12);
    var $13 = HEAP32[$4 >> 2];
    __ZN2JSL11ObjectValueER8JSObject($2, $13);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($7, 0, $2);
    var $14 = $holder;
    __ZN2JSL12PrivateValueEPv($3, $14);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($7, 1, $3);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($this, $cx, $fun) {
  var $1 = __ZNK10JSFunction6scriptEv($fun);
  var $2 = $fun | 0;
  var $3 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $1, $2);
  return $3;
}

function __ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject($this, $cx, $obj) {
  var $1 = __ZNK8JSObject9getScriptEv($obj);
  var $2 = __ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject($this, $cx, $1, $obj);
  return $2;
}

function __ZNK8JSObject9getScriptEv($this) {
  var $1 = __ZNK8JSObject10getPrivateEv($this);
  return $1;
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 14,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_($1, $k, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript($script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($r, $3);
    var $4 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $7 = HEAP32[$5 >> 2];
    var $8 = __ZN2js12GlobalObject12getDebuggersEv($7);
    var $9 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv($8);
    var $10 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($9 | 0) == ($10 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $p_01 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $p_01;
    var $12 = HEAP32[$p_01 >> 2];
    __ZN2js8Debugger20destroyNonHeldScriptEP8JSScript($12, $script);
    var $13 = $p_01 + 4 | 0;
    var $14 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv($8);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $p_01 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $16 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger20destroyNonHeldScriptEP8JSScript($this, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $script;
    var $4 = $this + 152 | 0;
    __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($p, $4, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p);
    var $11 = HEAP32[$9 + 4 >> 2];
    __ZL19ClearScriptReferentP8JSObject($11);
    var $13 = HEAP32[$p >> 2];
    HEAP32[$3 >> 2] = $13;
    __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($4, $3);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZL19ClearScriptReferentP8JSObject($obj) {
  __ZN8JSObject10setPrivateEPv($obj, 0);
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str120 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17GetScriptReferentP8JSObject($1);
    var $6 = HEAP32[$4 + 52 >> 2];
    var $7 = $cx;
    var $8 = __Z17js_NewStringCopyZP9JSContextPKc($7, $6);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8 | 0;
    var $12 = $args | 0;
    var $13 = __ZNK2js12CallReceiver4rvalEv($12);
    __ZN2JS5Value9setStringEP8JSString($13, $11);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str119 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17GetScriptReferentP8JSObject($1);
    var $5 = $args | 0;
    var $6 = __ZNK2js12CallReceiver4rvalEv($5);
    var $8 = HEAP32[$4 + 28 >> 2];
    var $9 = __ZN2JS5Value9setNumberEj($6, $8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str118 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17GetScriptReferentP8JSObject($1);
    var $5 = $4;
    var $6 = __Z22js_GetScriptLineExtentP8JSScript($5);
    var $7 = $args | 0;
    var $8 = __ZNK2js12CallReceiver4rvalEv($7);
    var $9 = $6 >>> 0;
    var $10 = __ZN2JS5Value9setNumberEd($8, $9);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17GetScriptReferentP8JSObject($1);
    var $5 = $args | 0;
    var $6 = __ZNK2js12CallReceiver4rvalEv($5);
    var $7 = ($4 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($6, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL17GetScriptReferentP8JSObject($2);
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $7 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP8[$5 + 16 | 0];
    var $12 = __ZN8JSScript13isValidOffsetEh($11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $14 = __ZN8JSScript7objectsEv($5);
    var $20 = $14 + 4 | 0;
    var $21 = $14 | 0;
    var $i_0 = (HEAPU8[$5 + 36 | 0] & 255) >>> 1 & 1 & 255;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $28 = HEAP32[HEAP32[$21 >> 2] + ($i_0 << 2) >> 2];
    var $29 = __ZNK8JSObject10isFunctionEv($28);
    if ($29) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $31 = $28;
    var $32 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($6, $cx, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JSL11ObjectValueER8JSObject($1, $32);
    var $35 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $7, $1);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 10:
    var $39 = $args | 0;
    var $40 = __ZNK2js12CallReceiver4rvalEv($39);
    __ZN2JS5Value9setObjectER8JSObject($40, $7);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $flowData = __stackBase__ + 8;
    var $r = __stackBase__ + 32;
    var $offsetsv = __stackBase__ + 60;
    var $id = __stackBase__ + 68;
    var $1 = __stackBase__ + 72;
    var $2 = __stackBase__ + 80;
    var $3 = __stackBase__ + 88;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str42 | 0, 1);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL17GetScriptReferentP8JSObject($4);
    __ZN16FlowGraphSummaryC1EP9JSContext($flowData, $cx);
    var $8 = __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($flowData, $cx, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $10 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $7);
    var $13 = $r | 0;
    var $14 = $flowData | 0;
    __label__ = 5;
    break;
   case 5:
    var $16 = __ZNK2js13BytecodeRange5emptyEv($13);
    if ($16) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK2js13BytecodeRange11frontOffsetEv($13);
    var $19 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r);
    var $20 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($14, $18);
    var $21 = HEAP32[$20 >> 2];
    if (($21 | 0) == -1 | ($21 | 0) == ($19 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE($10, $cx, $19, $offsetsv);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $27 = __ZNK2JS5Value8isObjectEv($offsetsv);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $29 = __ZNK2JS5Value8toObjectEv($offsetsv);
    var $offsets_0 = $29;
    __label__ = 13;
    break;
   case 10:
    var $31 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $19 >>> 0;
    __ZN2JSL11NumberValueEd($1, $34);
    var $35 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 12:
    var $37 = HEAP32[$id >> 2];
    __ZN2JSL11ObjectValueER8JSObject($2, $31);
    var $38 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($10, $cx, $37, $2, 10, 12, 1);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      var $offsets_0 = $31;
      __label__ = 13;
      break;
    }
   case 13:
    var $offsets_0;
    var $41 = $18 >>> 0;
    __ZN2JSL11NumberValueEd($3, $41);
    var $42 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $offsets_0, $3);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    __label__ = 5;
    break;
   case 15:
    var $46 = $args | 0;
    var $47 = __ZNK2js12CallReceiver4rvalEv($46);
    __ZN2JS5Value9setObjectER8JSObject($47, $10);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN16FlowGraphSummaryD1Ev($flowData);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $flowData = __stackBase__ + 8;
    var $r = __stackBase__ + 32;
    var $1 = __stackBase__ + 60;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str42 | 0, 1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL17GetScriptReferentP8JSObject($2);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str117 | 0, 1);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 4:
    var $10 = __ZNK2js8CallArgsixEj($args, 0);
    var $11 = __ZNK2JS5Value8isNumberEv($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZNK2JS5Value8toNumberEv($10);
    var $14 = $13 >= 0 ? Math.floor($13) : Math.ceil($13);
    if ($14 >>> 0 == $13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 283, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 17;
    break;
   case 7:
    __ZN16FlowGraphSummaryC1EP9JSContext($flowData, $cx);
    var $18 = __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($flowData, $cx, $5);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $20 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $5);
    var $23 = $r | 0;
    var $24 = $flowData | 0;
    __label__ = 10;
    break;
   case 10:
    var $26 = __ZNK2js13BytecodeRange5emptyEv($23);
    if ($26) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2js13BytecodeRange11frontOffsetEv($23);
    var $29 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r);
    if (($29 | 0) == ($14 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $32 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($24, $28);
    var $33 = HEAP32[$32 >> 2];
    if (($33 | 0) == -1 | ($33 | 0) == ($14 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $37 = $28 >>> 0;
    __ZN2JSL11NumberValueEd($1, $37);
    var $38 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $20, $1);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    __label__ = 10;
    break;
   case 15:
    var $42 = $args | 0;
    var $43 = __ZNK2js12CallReceiver4rvalEv($42);
    __ZN2JS5Value9setObjectER8JSObject($43, $20);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN16FlowGraphSummaryD1Ev($flowData);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str116 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str44 | 0, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZL17GetScriptReferentP8JSObject($5);
    var $9 = __ZNK2js8CallArgsixEj($args, 0);
    var $10 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $8, $9, $offset);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[$8 >> 2] + HEAP32[$offset >> 2] | 0;
    var $16 = $cx;
    var $17 = $8;
    var $18 = _JS_PCToLineNumber($16, $17, $15);
    var $19 = $args | 0;
    var $20 = __ZNK2js12CallReceiver4rvalEv($19);
    var $21 = __ZN2JS5Value9setNumberEj($20, $18);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str115 | 0, 2);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str45 | 0, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZL17GetScriptReferentP8JSObject($5);
    var $9 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($5);
    var $10 = __ZL15GetScriptHolderP8JSObject($5);
    var $11 = __ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject($cx, $8, $10);
    var $12 = __ZNK2js8Debugger13observesScopeEP8JSObject($9, $11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 284, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $15 = __ZNK2js8CallArgsixEj($args, 0);
    var $16 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $8, $15, $offset);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $18 = __ZNK2js8CallArgsixEj($args, 1);
    var $19 = $cx;
    var $20 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($19, $18);
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = $8;
    var $25 = __ZNK2js2gc4Cell11compartmentEv($24);
    var $29 = HEAP32[$8 >> 2] + HEAP32[$offset >> 2] | 0;
    var $30 = __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($25, $cx, $8, $29, $10);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZN2js14BreakpointSite3incEP9JSContext($30, undef);
    var $34 = $cx + 52 | 0;
    var $35 = HEAP32[$34 >> 2];
    var $36 = __ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_($35, $9, $30, $21);
    if (($36 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = $args | 0;
    var $40 = __ZNK2js12CallReceiver4rvalEv($39);
    __ZN2JS5Value12setUndefinedEv($40);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    __ZN2js14BreakpointSite3decEP9JSContext($30, undef);
    var $42 = HEAP32[$34 >> 2];
    __ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE($30, $42, 0);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $offset = __stackBase__ + 8;
    var $r = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str46 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL17GetScriptReferentP8JSObject($2);
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    if (($argc | 0) == 0) {
      var $pc_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js8CallArgsixEj($args, 0);
    var $10 = __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $5, $9, $offset);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $pc_0 = HEAP32[$5 >> 2] + HEAP32[$offset >> 2] | 0;
    __label__ = 5;
    break;
   case 5:
    var $pc_0;
    var $17 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $5;
    var $21 = __ZNK2js2gc4Cell11compartmentEv($20);
    var $22 = $21 + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $22);
    var $23 = ($pc_0 | 0) == 0;
    __label__ = 7;
    break;
   case 7:
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r);
    if ($25) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r);
    var $29 = HEAP32[$27 + 4 >> 2];
    if ((HEAP32[$29 >> 2] | 0) == ($5 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    if ($23) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$29 + 4 >> 2] | 0) == ($pc_0 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $39 = __ZNK2js14BreakpointSite15firstBreakpointEv($29);
    var $bp_0 = $39;
    __label__ = 12;
    break;
   case 12:
    var $bp_0;
    if (($bp_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$bp_0 >> 2] | 0) == ($6 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $47 = __ZNK2js10Breakpoint10getHandlerEv($bp_0);
    __ZN2JSL11ObjectValueER8JSObject($1, $47);
    var $48 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $17, $1);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $51 = __ZN2js10Breakpoint10nextInSiteEv($bp_0);
    var $bp_0 = $51;
    __label__ = 12;
    break;
   case 16:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    __label__ = 7;
    break;
   case 17:
    var $53 = $args | 0;
    var $54 = __ZNK2js12CallReceiver4rvalEv($53);
    __ZN2JS5Value9setObjectER8JSObject($54, $17);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str114 | 0, 1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str47 | 0, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZL17GetScriptReferentP8JSObject($5);
    var $9 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($5);
    var $10 = __ZNK2js8CallArgsixEj($args, 0);
    var $11 = $cx;
    var $12 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($11, $10);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $12;
    var $16 = $8;
    var $17 = __ZNK2js2gc4Cell11compartmentEv($16);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($17, $cx, $9, $8, $15);
    var $18 = $args | 0;
    var $19 = __ZNK2js12CallReceiver4rvalEv($18);
    __ZN2JS5Value12setUndefinedEv($19);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str47 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17GetScriptReferentP8JSObject($1);
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $6 = $4;
    var $7 = __ZNK2js2gc4Cell11compartmentEv($6);
    __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($7, $cx, $5, $4, 0);
    var $8 = $args | 0;
    var $9 = __ZNK2js12CallReceiver4rvalEv($8);
    __ZN2JS5Value12setUndefinedEv($9);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($cx, $scobj, $fp, $chars, $length, $filename, $lineno, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $4 = __ZN8JSObject10principalsEP9JSContext($3, $cx);
    var $5 = __ZNK9JSContext11findVersionEv($cx);
    var $6 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $scobj, $fp, $4, 1073750016, $chars, $length, $filename, $lineno, $5, 0, 16);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame9thisValueEv($fp);
    var $10 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $6, $scobj, $9, 24, $fp, $rval);
    var $_0 = $10 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame9thisValueEv($fp);
    var $3 = __ZNK2JS5Value8isObjectEv($2);
    if ($3) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js10StackFrame15isFunctionFrameEv($fp);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame3funEv($fp);
    var $8 = __ZNK10JSFunction12inStrictModeEv($7);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK2js10StackFrame12callReceiverEv($1, $fp);
    var $10 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $1);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10principalsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_GetSecurityCallbacks($cx);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 + 8 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = FUNCTION_TABLE[$5]($cx, $this);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 4:
    var $10 = HEAP32[$cx + 56 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = HEAP32[$10 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext11findVersionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 12 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $9 = $this + 60 | 0;
    var $10 = __ZNK2js12ContextStack5hasfpEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $12 = __ZNK9JSContext2fpEv($this);
    var $f_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $f_0;
    if (($f_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2js10StackFrame13isScriptFrameEv($f_0);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZNK2js10StackFrame4prevEv($f_0);
    var $f_0 = $18;
    __label__ = 5;
    break;
   case 8:
    var $19 = __ZNK2js10StackFrame6scriptEv($f_0);
    var $20 = __ZNK8JSScript10getVersionEv($19);
    var $_0 = $20;
    __label__ = 10;
    break;
   case 9:
    var $_0 = HEAP32[$this + 8 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame9thisValueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $8;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 8 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $argumentsv = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __stackBase__ + 44;
    var $5 = __stackBase__ + 52;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $6 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str111 | 0, 1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject10getPrivateEv($6);
    var $10 = $9;
    __ZNK8JSObject15getReservedSlotEj($argumentsv, $6, 1);
    var $11 = __ZNK2JS5Value11isUndefinedEv($argumentsv);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $args | 0;
    var $14 = __ZNK2js12CallReceiver4rvalEv($13);
    var $15 = $argumentsv | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $14 | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 4:
    var $19 = __ZNK2js10StackFrame7hasArgsEv($10);
    var $20 = $args | 0;
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $argsobj_0 = 0;
      var $_pre_phi = $20;
      __label__ = 14;
      break;
    }
   case 5:
    var $22 = __ZNK2js12CallReceiver6calleeEv($20);
    var $23 = $22;
    var $24 = __ZNK8JSObject9getGlobalEv($23);
    var $25 = $24;
    var $26 = $cx;
    var $27 = $24 | 0;
    var $28 = $proto;
    var $29 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($26, $27, 3, $28, 0);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = HEAP32[$proto >> 2];
    var $33 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, _DebuggerArguments_class, $32, $25);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject($1, $6);
    var $36 = $33;
    var $37 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($26, $36, 0, $1);
    if ($37) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 8:
    var $39 = __ZNK2js10StackFrame13numActualArgsEv($10);
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom($44);
    __ZN2JSL10Int32ValueEi($2, $39);
    var $46 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($26, $36, $45, $2, 0, 0, 6, 0, 0, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0;
    if (($i_0 | 0) < ($39 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $argsobj_0 = $33;
      var $_pre_phi = $20;
      __label__ = 14;
      break;
    }
   case 10:
    var $50 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 16, 0, 0, $25, 0);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL10Int32ValueEi($3, $i_0);
    var $53 = $50;
    var $54 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($26, $53, 0, $3);
    if ($54) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $56 = _INT_TO_JSID($i_0);
    __ZN2JSL14UndefinedValueEv($4);
    var $57 = $50;
    var $58 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($26, $36, $56, $4, $57, 0, 81, 0, 0, 0);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 14:
    var $_pre_phi;
    var $argsobj_0;
    var $62 = __ZNK2js12CallReceiver4rvalEv($_pre_phi);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($5, $argsobj_0);
    var $63 = $5 | 0;
    var $64$0 = HEAP32[$63 >> 2];
    var $64$1 = HEAP32[$63 + 4 >> 2];
    var $65 = $62 | 0;
    HEAP32[$65 >> 2] = $64$0;
    HEAP32[$65 + 4 >> 2] = $64$1;
    var $66 = __ZNK2js12CallReceiver4rvalEv($_pre_phi);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($6, 1, $66);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $calleev = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str110 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = __ZNK2js10StackFrame15isFunctionFrameEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK2js10StackFrame11isEvalFrameEv($5);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2js10StackFrame7calleevEv($5);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $calleev | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL9NullValueEv($calleev);
    __label__ = 6;
    break;
   case 6:
    var $16 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $17 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($16, $cx, $calleev);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $args | 0;
    var $20 = __ZNK2js12CallReceiver4rvalEv($19);
    var $21 = $calleev | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $20 | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str109 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = $args | 0;
    var $7 = __ZNK2js12CallReceiver4rvalEv($6);
    var $8 = __ZNK2js10StackFrame15isFunctionFrameEv($5);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $12 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZNK2js10StackFrame14isConstructingEv($5);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    __ZN2JS5Value10setBooleanEb($7, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str108 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = $args | 0;
    var $7 = __ZNK2js12CallReceiver4rvalEv($6);
    var $8 = __ZNK2js10StackFrame16isGeneratorFrameEv($5);
    __ZN2JS5Value10setBooleanEb($7, $8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str107 | 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $args | 0;
    var $6 = __ZNK2js12CallReceiver4rvalEv($5);
    var $7 = ($4 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($6, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str106 | 0, 1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject10getPrivateEv($2);
    var $6 = $5;
    var $7 = __ZNK2js10StackFrame13isScriptFrameEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame6scriptEv($6);
    var $10 = $cx;
    __ZN2js12ContextStackC2EP9JSContext($1, $10);
    var $11 = $5;
    var $12 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($11, $1, 0, 0);
    var $17 = $12 - HEAP32[$9 >> 2] | 0;
    var $18 = $args | 0;
    var $19 = __ZNK2js12CallReceiver4rvalEv($18);
    var $20 = $17 >>> 0;
    var $21 = __ZN2JS5Value9setNumberEd($19, $20);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $23 = $args | 0;
    var $24 = __ZNK2js12CallReceiver4rvalEv($23);
    __ZN2JS5Value12setUndefinedEv($24);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str105 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $7 = __ZNK2js10StackFrame4prevEv($5);
    var $fp_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $fp_0;
    if (($fp_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZNK2js8Debugger13observesFrameEPNS_10StackFrameE($6, $fp_0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = __ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE($6, $cx, $fp_0, $vp);
    var $_0 = $15 & 1;
    __label__ = 9;
    break;
   case 7:
    var $18 = __ZNK2js10StackFrame4prevEv($fp_0);
    var $fp_0 = $18;
    __label__ = 3;
    break;
   case 8:
    var $20 = $args | 0;
    var $21 = __ZNK2js12CallReceiver4rvalEv($20);
    __ZN2JS5Value7setNullEv($21);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str89 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $7 = __ZNK2js10StackFrame15isFunctionFrameEv($5);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame11isEvalFrameEv($5);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame6calleeEv($5);
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($11);
    var $13 = __ZNK10JSFunction13isInterpretedEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $scriptObject_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $15 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($6, $cx, $12);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $scriptObject_0 = $15;
      __label__ = 11;
      break;
    }
   case 6:
    var $18 = __ZNK2js10StackFrame13isScriptFrameEv($5);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $scriptObject_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $20 = __ZNK2js10StackFrame6scriptEv($5);
    var $22 = HEAP32[$20 + 84 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject($6, $cx, $22);
    var $29 = $25;
    __label__ = 10;
    break;
   case 9:
    var $27 = __ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript($6, $cx, $20);
    var $29 = $27;
    __label__ = 10;
    break;
   case 10:
    var $29;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $scriptObject_0 = $29;
      __label__ = 11;
      break;
    }
   case 11:
    var $scriptObject_0;
    var $32 = $args | 0;
    var $33 = __ZNK2js12CallReceiver4rvalEv($32);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($33, $scriptObject_0);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $thisv = __stackBase__ + 8;
    var $ac = __stackBase__ + 16;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str105 | 0, 1);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = __ZNK2js10StackFrame10scopeChainEv($5);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $5);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js10StackFrame9thisValueEv($5);
    var $11 = $10 | 0;
    var $st$2$0 = $11 | 0;
    var $12$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$2$1 >> 2];
    var $13 = $thisv | 0;
    var $st$7$0 = $13 | 0;
    HEAP32[$st$7$0 >> 2] = $12$0;
    var $st$7$1 = $13 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $12$1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $14 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $15 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($14, $cx, $thisv);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = 0;
    __label__ = 7;
    break;
   case 6:
    var $18 = $args | 0;
    var $19 = __ZNK2js12CallReceiver4rvalEv($18);
    var $st$2$0 = $13 | 0;
    var $20$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $13 + 4 | 0;
    var $20$1 = HEAP32[$st$2$1 >> 2];
    var $21 = $19 | 0;
    var $st$7$0 = $21 | 0;
    HEAP32[$st$7$0 >> 2] = $20$0;
    var $st$7$1 = $21 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $20$1;
    var $_1 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str104 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = $args | 0;
    var $7 = __ZNK2js12CallReceiver4rvalEv($6);
    var $8 = __ZNK2js10StackFrame11isEvalFrameEv($5);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_in = HEAP32[$cx + 52 >> 2] + 210212 | 0;
    __label__ = 7;
    break;
   case 4:
    var $14 = __ZNK2js10StackFrame13isGlobalFrameEv($5);
    var $16 = HEAP32[$cx + 52 >> 2];
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_in = $16 + 210224 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_in = $16 + 210188 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_in;
    var $23 = HEAP32[$_in >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($7, $23);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $handler = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str103 | 0, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK8JSObject15getReservedSlotEj($handler, $1, 2);
    var $4 = $args | 0;
    var $5 = __ZNK2js12CallReceiver4rvalEv($4);
    var $6 = $handler | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $5 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $prior = __stackBase__ + 8;
    var $ac = __stackBase__ + 16;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str101 | 0, 1);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 3:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $5 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, STRING_TABLE.__str102 | 0, 1);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject10getPrivateEv($5);
    var $9 = $8;
    var $10 = __ZNK2js10StackFrame13isScriptFrameEv($9);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 286, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 6:
    var $13 = __ZNK2js8CallArgsixEj($args, 0);
    var $14 = __ZL11IsValidHookRKN2JS5ValueE($13);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 230, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 8:
    __ZNK8JSObject15getReservedSlotEj($prior, $5, 2);
    var $17 = __ZNK2js8CallArgsixEj($args, 0);
    var $18 = __ZNK2JS5Value11isUndefinedEv($17);
    var $20 = $18 & 1 ^ 1;
    var $21 = __ZNK2JS5Value11isUndefinedEv($prior);
    var $24 = $20 - ($21 & 1 ^ 1) | 0;
    if ($18 ^ $21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $27 = __ZNK2js10StackFrame10scopeChainEv($9);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $27);
    var $28 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $30 = __ZNK2js10StackFrame6scriptEv($9);
    var $31 = $30;
    var $32 = $cx;
    var $33 = __ZN8JSScript19changeStepModeCountEP9JSContexti($31, $32, $24);
    __ZN2js15AutoCompartmentD2Ev($ac);
    __label__ = 11;
    break;
   case 11:
    var $35 = __ZNK2js8CallArgsixEj($args, 0);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($5, 2, $35);
    var $36 = $args | 0;
    var $37 = __ZNK2js12CallReceiver4rvalEv($36);
    __ZN2JS5Value12setUndefinedEv($37);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 12:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, 0);
  return $1;
}

function __ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, 1);
  return $1;
}

function __ZL20DebuggerObject_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject10getPrivateEv($obj);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $12, undef);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $protov = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str94 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    var $7 = __ZNK8JSObject8getProtoEv($6);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($protov, $7);
    var $8 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($4, $cx, $protov);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $args | 0;
    var $11 = __ZNK2js12CallReceiver4rvalEv($10);
    var $12 = $protov | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $11 | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str93 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = __ZNK8JSObject8getClassEv($5);
    var $8 = HEAP32[$6 >> 2];
    var $9 = _strlen($8);
    var $10 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $8, $9, 0, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $args | 0;
    var $14 = __ZNK2js12CallReceiver4rvalEv($13);
    var $15 = $10 | 0;
    __ZN2JS5Value9setStringEP8JSString($14, $15);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str92 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    var $5 = $4;
    var $6 = $args | 0;
    var $7 = __ZNK2js12CallReceiver4rvalEv($6);
    var $8 = __ZN8JSObject10isCallableEv($5);
    __ZN2JS5Value10setBooleanEb($7, $8);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $namev = __stackBase__ + 8;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str91 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    var $7 = __ZNK8JSObject10isFunctionEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $args | 0;
    var $10 = __ZNK2js12CallReceiver4rvalEv($9);
    __ZN2JS5Value12setUndefinedEv($10);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($6);
    var $14 = HEAP32[$12 + 72 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $args | 0;
    var $18 = __ZNK2js12CallReceiver4rvalEv($17);
    __ZN2JS5Value12setUndefinedEv($18);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $20 = $14 | 0;
    __ZN2JSL11StringValueEP8JSString($namev, $20);
    var $21 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($4, $cx, $namev);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $args | 0;
    var $24 = __ZNK2js12CallReceiver4rvalEv($23);
    var $25 = $namev | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $24 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $names = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 36;
    var $3 = __stackBase__ + 44;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $4 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str90 | 0);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject10getPrivateEv($4);
    var $8 = $7;
    var $9 = __ZNK8JSObject10isFunctionEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $args | 0;
    var $12 = __ZNK2js12CallReceiver4rvalEv($11);
    __ZN2JS5Value12setUndefinedEv($12);
    var $_1 = 1;
    __label__ = 18;
    break;
   case 4:
    var $14 = __ZNK8JSObject18getFunctionPrivateEv($8);
    var $15 = $14 + 56 | 0;
    var $17 = HEAPU16[$15 >> 1] & 65535;
    var $18 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $17, 0);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = HEAPU16[$15 >> 1] & 65535;
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($18, $cx, 0, $22);
    var $23 = __ZNK10JSFunction13isInterpretedEv($14);
    var $25 = HEAP16[$15 >> 1] << 16 >> 16 == 0;
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($25) {
      __label__ = 16;
      break;
    } else {
      var $i1_02 = 0;
      __label__ = 15;
      break;
    }
   case 7:
    if ($25) {
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($names, $1);
    var $28 = __ZNK10JSFunction6scriptEv($14);
    var $30 = $28 + 64 | 0;
    var $31 = $names;
    var $32 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($30, undef, $31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 9:
    if (HEAP16[$15 >> 1] << 16 >> 16 == 0) {
      __label__ = 14;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_04;
    var $35 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($names, $i_04);
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $39 = $36 | 0;
    __ZN2JSL11StringValueEP8JSString($2, $39);
    __label__ = 13;
    break;
   case 12:
    __ZN2JSL14UndefinedValueEv($2);
    __label__ = 13;
    break;
   case 13:
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($18, $i_04, $2);
    var $42 = $i_04 + 1 | 0;
    if ($42 >>> 0 < (HEAPU16[$15 >> 1] & 65535) >>> 0) {
      var $i_04 = $42;
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    __label__ = 16;
    break;
   case 15:
    var $i1_02;
    __ZN2JSL14UndefinedValueEv($3);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($18, $i1_02, $3);
    var $46 = $i1_02 + 1 | 0;
    if ($46 >>> 0 < (HEAPU16[$15 >> 1] & 65535) >>> 0) {
      var $i1_02 = $46;
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $50 = $args | 0;
    var $51 = __ZNK2js12CallReceiver4rvalEv($50);
    __ZN2JS5Value9setObjectER8JSObject($51, $18);
    var $_1 = 1;
    __label__ = 18;
    break;
   case 17:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str89 | 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    var $7 = $args | 0;
    var $8 = __ZNK2js12CallReceiver4rvalEv($7);
    __ZN2JS5Value12setUndefinedEv($8);
    var $9 = __ZNK8JSObject10isFunctionEv($6);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $11 = __ZNK8JSObject18getFunctionPrivateEv($6);
    var $12 = __ZNK10JSFunction13isInterpretedEv($11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = __ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction($4, $cx, $11);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK2js12CallReceiver4rvalEv($7);
    __ZN2JS5Value9setObjectER8JSObject($17, $14);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 144;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $id = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $desc = __stackBase__ + 20;
    var $ac = __stackBase__ + 68;
    var $ec = __stackBase__ + 120;
    var $get = __stackBase__ + 128;
    var $set = __stackBase__ + 136;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str102207 | 0);
    if (($2 | 0) == 0) {
      var $_3 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $6 = __ZNK8JSObject10getPrivateEv($2);
    var $7 = $6;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK2js8CallArgsixEj($args, 0);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv($1);
    __label__ = 5;
    break;
   case 5:
    var $16 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_3 = 0;
      __label__ = 20;
      break;
    }
   case 6:
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $18 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = HEAP32[$cx + 56 >> 2];
    var $22 = __ZN13JSCompartment6wrapIdEP9JSContextPi($21, $cx, $id);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 19;
    break;
   case 9:
    var $24 = __ZNK2js8Debugger10toJSObjectEv($5);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $24);
    var $25 = HEAP32[$id >> 2];
    var $26 = $desc + 16 | 0;
    var $phitmp3 = $26;
    var $27 = $cx;
    var $28 = $6;
    var $29 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($27, $28, $25, $phitmp3);
    var $30 = $ec;
    __ZN2js11ErrorCopierD2Ev($30);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    if ((HEAP32[$26 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $desc + 32 | 0;
    var $37 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $36);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 12:
    var $39 = $desc + 20 | 0;
    var $40 = HEAP32[$39 >> 2];
    if (($40 & 16 | 0) == 0) {
      var $52 = $40;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = $desc + 24 | 0;
    var $45 = HEAP32[$44 >> 2];
    var $46 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($45);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($get, $46);
    var $47 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $get);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    var $49 = __ZNK2JS5Value14toObjectOrNullEv($get);
    var $50 = __ZN2jsL16CastAsPropertyOpEP8JSObject($49);
    HEAP32[$44 >> 2] = $50;
    var $52 = HEAP32[$39 >> 2];
    __label__ = 15;
    break;
   case 15:
    var $52;
    if (($52 & 32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $56 = $desc + 28 | 0;
    var $57 = HEAP32[$56 >> 2];
    var $58 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($57);
    __ZN2JSL17ObjectOrNullValueEP8JSObject5($set, $58);
    var $59 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $set);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      var $_2 = 0;
      __label__ = 19;
      break;
    }
   case 17:
    var $61 = __ZNK2JS5Value14toObjectOrNullEv($set);
    var $62 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject($61);
    HEAP32[$56 >> 2] = $62;
    __label__ = 18;
    break;
   case 18:
    var $64 = $args | 0;
    var $65 = __ZNK2js12CallReceiver4rvalEv($64);
    var $66 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($27, $phitmp3, $65);
    var $_2 = $66 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_2;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $_3 = $_2;
    __label__ = 20;
    break;
   case 20:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 228;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $keys = __stackBase__ + 8;
    var $ac = __stackBase__ + 68;
    var $ec = __stackBase__ + 120;
    var $vals = __stackBase__ + 128;
    var $1 = __stackBase__ + 220;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str152212 | 0);
    if (($2 | 0) == 0) {
      var $_4 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $6 = __ZNK8JSObject10getPrivateEv($2);
    var $7 = $6;
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $8 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = 0;
    __label__ = 18;
    break;
   case 4:
    var $10 = __ZNK2js8Debugger10toJSObjectEv($5);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $10);
    var $11 = $cx;
    var $12 = $6;
    var $13 = $keys;
    var $14 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($11, $12, 24, $13);
    var $15 = $ec;
    __ZN2js11ErrorCopierD2Ev($15);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_3 = 0;
      __label__ = 18;
      break;
    }
   case 5:
    __ZN2js15AutoValueVectorC1EP9JSContext($vals, $cx);
    var $17 = $vals | 0;
    var $18 = $keys | 0;
    var $19 = __ZNK2js16AutoVectorRooterIiE6lengthEv($18);
    var $20 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($17, $19);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 6:
    var $22 = __ZNK2js16AutoVectorRooterIiE6lengthEv($18);
    var $23 = $cx + 56 | 0;
    var $24 = $cx;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $22 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    var $28 = __ZN2js16AutoVectorRooterIiEixEj($18, $i_0);
    var $29 = HEAPU32[$28 >> 2];
    var $30 = _JSID_IS_INT($29);
    if (($30 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = _JSID_TO_INT($29);
    __ZN2JSL10Int32ValueEi($1, $33);
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($24, $1);
    if (($34 | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    __ZN2JS5Value9setStringEP8JSString($37, $34);
    __label__ = 14;
    break;
   case 11:
    var $39 = __ZL12JSID_IS_ATOMi($29);
    var $40 = ($39 | 0) == 0;
    var $41 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = _JSID_TO_STRING($29);
    __ZN2JS5Value9setStringEP8JSString($41, $43);
    var $44 = HEAP32[$23 >> 2];
    var $45 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    var $46 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($44, $cx, $45);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 13:
    var $48 = _JSID_TO_OBJECT($29);
    __ZN2JS5Value9setObjectER8JSObject($41, $48);
    var $49 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($17, $i_0);
    var $50 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $49);
    if ($50) {
      __label__ = 14;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 14:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 15:
    var $54 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($17);
    var $55 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($17);
    var $56 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $54, $55, 0);
    if (($56 | 0) == 0) {
      var $_2 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = $args | 0;
    var $60 = __ZNK2js12CallReceiver4rvalEv($59);
    __ZN2JS5Value9setObjectER8JSObject($60, $56);
    var $_2 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($vals);
    var $_3 = $_2;
    __label__ = 18;
    break;
   case 18:
    var $_3;
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_4 = $_3;
    __label__ = 19;
    break;
   case 19:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 144;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $id = __stackBase__ + 8;
    var $descs = __stackBase__ + 12;
    var $ac = __stackBase__ + 80;
    var $ec = __stackBase__ + 132;
    var $dummy = __stackBase__ + 140;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str122209 | 0);
    if (($1 | 0) == 0) {
      var $_3 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str88 | 0, 2);
    var $_3 = 0;
    __label__ = 14;
    break;
   case 4:
    var $11 = __ZNK2js8CallArgsixEj($args, 0);
    var $12 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $11, $id);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $_3 = 0;
      __label__ = 14;
      break;
    }
   case 5:
    var $14 = __ZNK2js8CallArgsixEj($args, 1);
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $15 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($15 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $cx;
    var $19 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($15, $18, $14, 0);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $21 = $15 | 0;
    __ZN2JS5Value12setUndefinedEv($21);
    var $22 = __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $4, $6, $15);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $24 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $6, $id, $15);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 13;
    break;
   case 11:
    var $28 = __ZNK2js8Debugger10toJSObjectEv($4);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $28);
    var $29 = $5;
    var $30 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($18, $29, $id, $15, 1, $dummy);
    var $31 = $ec;
    __ZN2js11ErrorCopierD2Ev($31);
    __ZN2js15AutoCompartmentD2Ev($ac);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $_2 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $33 = $args | 0;
    var $34 = __ZNK2js12CallReceiver4rvalEv($33);
    __ZN2JS5Value12setUndefinedEv($34);
    var $_2 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    var $_3 = $_2;
    __label__ = 14;
    break;
   case 14:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 200;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ids = __stackBase__ + 8;
    var $descs = __stackBase__ + 68;
    var $ac = __stackBase__ + 136;
    var $ec = __stackBase__ + 188;
    var $dummy = __stackBase__ + 196;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str132210 | 0);
    if (($1 | 0) == 0) {
      var $_3 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str84 | 0, 1);
    var $_3 = 0;
    __label__ = 22;
    break;
   case 4:
    var $11 = __ZNK2js8CallArgsixEj($args, 0);
    var $12 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $11);
    if (($12 | 0) == 0) {
      var $_3 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js12AutoIdVectorC1EP9JSContext($ids, $cx);
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $15 = $cx;
    var $16 = $12;
    var $17 = $ids;
    var $18 = $descs;
    var $19 = __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($15, $16, 0, $17, $18);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_2 = 0;
      __label__ = 21;
      break;
    }
   case 6:
    var $21 = $ids | 0;
    var $22 = __ZNK2js16AutoVectorRooterIiE6lengthEv($21);
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $22 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i_0);
    var $27 = __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $4, $6, $26);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 10:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $31 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($31) {
      var $i1_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $i1_0;
    if ($i1_0 >>> 0 < $22 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $34 = __ZN2js16AutoVectorRooterIiEixEj($21, $i1_0);
    var $35 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i1_0);
    var $36 = __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $6, $34, $35);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 13:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $40 = __ZNK2js8Debugger10toJSObjectEv($4);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $40);
    var $41 = $5;
    var $i2_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i2_0;
    if ($i2_0 >>> 0 < $22 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $45 = __ZN2js16AutoVectorRooterIiEixEj($21, $i2_0);
    var $46 = __ZN2js23AutoPropDescArrayRooterixEj($descs, $i2_0);
    var $47 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($15, $41, $45, $46, 1, $dummy);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 15;
    break;
   case 18:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 21;
    break;
   case 19:
    var $51 = $ec;
    __ZN2js11ErrorCopierD2Ev($51);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $52 = $args | 0;
    var $53 = __ZNK2js12CallReceiver4rvalEv($52);
    __ZN2JS5Value12setUndefinedEv($53);
    var $_2 = 1;
    __label__ = 21;
    break;
   case 20:
    var $54 = $ec;
    __ZN2js11ErrorCopierD2Ev($54);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_2;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    __ZN2js12AutoIdVectorD1Ev($ids);
    var $_3 = $_2;
    __label__ = 22;
    break;
   case 22:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $arg = __stackBase__ + 8;
    var $id = __stackBase__ + 16;
    var $ac = __stackBase__ + 20;
    var $ec = __stackBase__ + 72;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE.__str72 | 0);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js8CallArgsixEj($args, 0);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $arg | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv($arg);
    __label__ = 5;
    break;
   case 5:
    var $15 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $arg, $id);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $17 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = HEAP32[$cx + 56 >> 2];
    var $21 = __ZN13JSCompartment6wrapIdEP9JSContextPi($20, $cx, $id);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = __ZNK2js8Debugger10toJSObjectEv($4);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $23);
    var $24 = HEAP32[$id >> 2];
    var $25 = $args | 0;
    var $26 = __ZNK2js12CallReceiver4rvalEv($25);
    var $27 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($6, $cx, $24, $26, 0);
    var $28 = $ec;
    __ZN2js11ErrorCopierD2Ev($28);
    var $_0 = $27;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 0, STRING_TABLE.__str202217 | 0);
  return $1;
}

function __ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 1, STRING_TABLE.__str182215 | 0);
  return $1;
}

function __ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 2, STRING_TABLE.__str172214 | 0);
  return $1;
}

function __ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 0, STRING_TABLE.__str212218 | 0);
  return $1;
}

function __ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 1, STRING_TABLE.__str192216 | 0);
  return $1;
}

function __ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, 2, STRING_TABLE.__str162213 | 0);
  return $1;
}

function __ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, 0);
  return $1;
}

function __ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, 1);
  return $1;
}

function _JS_DefineDebuggerObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objProto = __stackBase__;
    var $debugCtor = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $cx;
    var $5 = $obj;
    var $6 = $objProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$objProto >> 2];
    var $12 = $debugCtor;
    var $13 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $5, $11, __ZN2js8Debugger7jsclassE, 18, 1, __ZN2js8Debugger10propertiesE, __ZN2js8Debugger7methodsE, 0, 0, $12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($14, $cx);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $20 = HEAP32[$debugCtor >> 2];
    var $21 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $20, $11, _DebuggerFrame_class, 20, 0, __ZL24DebuggerFrame_properties, __ZL21DebuggerFrame_methods, 0, 0, 0);
    var $22 = $21;
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = HEAP32[$debugCtor >> 2];
    var $27 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $26, $11, _DebuggerScript_class, 22, 0, __ZL25DebuggerScript_properties, __ZL22DebuggerScript_methods, 0, 0, 0);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = HEAP32[$debugCtor >> 2];
    var $33 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($4, $32, $11, _DebuggerObject_class, 24, 0, __ZL25DebuggerObject_properties, __ZL22DebuggerObject_methods, 0, 0, 0);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = $33;
    __ZN2JSL11ObjectValueER8JSObject($1, $22);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 0, $1);
    __ZN2JSL11ObjectValueER8JSObject($2, $36);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 1, $2);
    __ZN2JSL11ObjectValueER8JSObject($3, $28);
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 2, $3);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($12, $10);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $18 = $this + 16 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    HEAP32[$2 >> 2] = $14;
    var $21 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $23 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($src_01);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv($src_01);
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv($src_01);
    var $26 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $25);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE($26, $1);
    __label__ = 6;
    break;
   case 6:
    var $28 = $src_01 + 12 | 0;
    if (($28 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $28;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($12, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js18RuntimeAllocPolicy5free_EPv($this, $p) {
  __ZN9JSRuntime5free_EPv(undef, $p);
  return;
}

function __ZN9JSRuntime5free_EPv($this, $p) {
  __ZN2js10Foreground5free_EPv($p);
  return;
}

function __ZN2js10Foreground5free_EPv($p) {
  _js_free($p);
  return;
}

function _js_free($p) {
  _free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSScriptEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSObjectEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIP8JSObjectEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP8JSScriptEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_($this, $k, $v) {
  var $2 = HEAP32[$k >> 2];
  HEAP32[$this >> 2] = $2;
  var $4 = HEAP32[$v >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7MoveRefIP8JSObjectEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSObjectEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIP8JSScriptEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSScriptEC2ERS2_($this, $t);
  return;
}

function __ZN2js18RuntimeAllocPolicy7malloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN9JSRuntime7malloc_EjP9JSContext($2, $bytes, 0);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev($this);
  return;
}

function __ZN9JSRuntime7malloc_EjP9JSContext($this, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    var $1 = _js_malloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $6 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext(undef, undef, undef, $cx);
    var $6 = 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime19updateMallocCounterEj($this, $nbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 144096 | 0;
    var $3 = HEAP32[$1 >> 2] - $nbytes | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime15onTooMuchMallocEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_malloc($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $2, 1);
    var $4 = $p | 0;
    HEAP32[$p >> 2] = $3;
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($4);
    if ($6) {
      var $10 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_($this, $p, $t);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_($this, $k, $v) {
  __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_($this, $k, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($1);
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($this) {
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $this | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($13, $10);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $18 = $this + 16 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    HEAP32[$2 >> 2] = $14;
    var $21 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $23 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($src_01);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv($src_01);
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv($src_01);
    var $26 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $25);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE($26, $1);
    __label__ = 6;
    break;
   case 6:
    var $28 = $src_01 + 12 | 0;
    if (($28 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $28;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $2);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZNK7mozilla14AlignedStorageILj1EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj1EE4addrEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_($beg, $end, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p_0 = $beg;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == ($end | 0)) {
      var $_0 = $end;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$p_0 >> 2] | 0) == (HEAP32[$v >> 2] | 0)) {
      var $_0 = $p_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $p_0 = $p_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_($1, $7);
  var $8 = __ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js17SystemAllocPolicy5free_EPv($this, $p) {
  _js_free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_($this, $t);
  return;
}

function __ZN2js17SystemAllocPolicy7malloc_Ej($this, $bytes) {
  var $1 = _js_malloc($bytes);
  return $1;
}

function __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev($this);
  return;
}

function __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l) {
  var $1 = __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = __ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17SystemAllocPolicy8realloc_EPvjj($this, $p, $oldBytes, $bytes) {
  var $1 = _js_realloc($p, $bytes);
  return $1;
}

function _js_realloc($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __ZN2js11RoundUpPow2Ej($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x >>> 0 < 2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $x - 1 | 0;
    var $4 = _llvm_ctlz_i32($3);
    var $7 = 32 - $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return 1 << $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy8realloc_EPvjj($this, $p, $oldBytes, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_realloc($p, $bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $p2_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this, undef, undef);
    var $p2_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $p2_0;
    return $p2_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy7malloc_Ej($this, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $p_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this, undef, undef);
    var $p_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $p_0;
    return $p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15TempAllocPolicy5free_EPv($this, $p) {
  _js_free($p);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN9JSContext7malloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime7malloc_EjP9JSContext($2, $bytes, $this);
  return $3;
}

function __ZN9JSContext5free_EPv($this, $p) {
  __ZN9JSRuntime5free_EPv(undef, $p);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK7mozilla14AlignedStorageILj32EE4addrEv($this) {
  return $this;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_($this, $k, $v) {
  var $2 = HEAP32[$k >> 2];
  HEAP32[$this >> 2] = $2;
  var $4 = HEAP32[$v >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $2, 1);
    var $4 = $p | 0;
    HEAP32[$p >> 2] = $3;
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($4);
    if ($6) {
      var $10 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_($this, $p, $t);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_($this, $k, $v) {
  __ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_($this, $k, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $this | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($13, $10);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $18 = $this + 16 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    HEAP32[$2 >> 2] = $14;
    var $21 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $23 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv($src_01);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv($src_01);
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv($src_01);
    var $26 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $25);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE($26, $1);
    __label__ = 6;
    break;
   case 6:
    var $28 = $src_01 + 12 | 0;
    if (($28 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $28;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZNK7mozilla14AlignedStorageILj64EE4addrEv($this) {
  return $this;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIN2JS5ValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject9getParentEv($this) {
  return HEAP32[$this + 20 >> 2];
}

function __ZNK2js5Class8isNativeEv($this) {
  return (HEAP32[$this + 4 >> 2] & 524288 | 0) == 0;
}

function __ZN8JSObject6setMapEPN2js5ShapeE($this, $amap) {
  HEAP32[$this >> 2] = $amap;
  var $3 = HEAP32[$amap >> 2];
  HEAP32[$this + 12 >> 2] = $3;
  return;
}

function __ZNK8JSObject8numSlotsEv($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZN2js11KidsPointer7setNullEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSObjectEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($1);
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_04 = $2 | 0;
    HEAP32[$_04 >> 2] = $tmp$0;
    HEAP32[$_04 + 4 >> 2] = $tmp$1;
    __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_02 = $0 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $_03 = $2 | 0;
    HEAP32[$_03 >> 2] = $tmp$0;
    HEAP32[$_03 + 4 >> 2] = $tmp$1;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $14 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($1);
    var $15 = $14 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $6 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($1);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIN2JS5ValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK8JSObject9getParentEv($proto);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, $clasp, $5, $12, 0, $13);
    var $14 = __ZNK2js5Class8isNativeEv($clasp);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $markUnknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isDenseArrayEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($this, $cx);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $this + 16 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 + 16 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == ($fun | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($7, $cx);
    __label__ = 7;
    break;
   case 7:
    if ($markUnknown) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $20 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $22 = HEAP32[$6 >> 2];
    var $23 = __ZN2js5types10TypeObject17unknownPropertiesEv($22);
    if ($23) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($22, $cx);
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $markUnknown);
    __label__ = 12;
    break;
   case 12:
    var $_0 = HEAP32[$6 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = __ZNK8JSObject8numSlotsEv($obj);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21setSharedNonNativeMapEv($this) {
  __ZN8JSObject6setMapEPN2js5ShapeE($this, __ZN2js5Shape15sharedNonNativeE);
  return;
}

function __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($this, $aclasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] | 0) == 0) {
      var $17 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$this + 4 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$this + 8 >> 2];
    if (($10 | 0) == 0) {
      var $17 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$10 >> 2];
    var $14 = __ZNK2js10EmptyShape8getClassEv($13);
    var $17 = ($14 | 0) == ($aclasp | 0);
    __label__ = 5;
    break;
   case 5:
    var $17;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($this, $cx, $aclasp, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $17 = $2;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext7calloc_Ej($cx, 48);
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $aclasp);
    var $10 = HEAP32[$1 >> 2];
    HEAP32[$10 >> 2] = $9;
    var $11 = HEAP32[$1 >> 2];
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $17 = $11;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $11;
    __ZN9JSContext5free_EPv(undef, $15);
    HEAP32[$1 >> 2] = 0;
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $17;
    var $19 = HEAP32[$17 + ($kind << 2) >> 2];
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $30 = $19;
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $aclasp);
    var $24 = HEAP32[$1 >> 2] + ($kind << 2) | 0;
    HEAP32[$24 >> 2] = $22;
    var $27 = HEAP32[HEAP32[$1 >> 2] + ($kind << 2) >> 2];
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $30 = $27;
      __label__ = 7;
      break;
    }
   case 7:
    var $30;
    var $_0 = $30;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN2js12PropertyTree8newShapeEP9JSContext(undef, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2;
    var $7 = HEAP32[$cx + 56 >> 2];
    __ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE($6, $7, $clasp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE($this, $comp, $aclasp) {
  __ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp, $aclasp);
  return;
}

function __ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp, $aclasp) {
  var $1 = $this | 0;
  __ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE($1, $comp, $aclasp);
  return;
}

function __ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE($this, $comp, $aclasp) {
  var $1 = $this | 0;
  var $3 = HEAP32[$comp >> 2];
  var $4 = __Z16js_GenerateShapeP9JSRuntime($3);
  HEAP32[$1 >> 2] = $4;
  HEAP32[$this + 4 >> 2] = HEAPU32[$aclasp + 4 >> 2] >>> 8 & 255;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 4;
  HEAP32[$this + 16 >> 2] = $aclasp;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = -1;
  HEAP8[$this + 28 | 0] = 0;
  HEAP8[$this + 29 | 0] = 1;
  HEAP16[$this + 30 >> 1] = 0;
  HEAP32[$this + 32 >> 2] = 0;
  var $19 = $this + 36 | 0;
  __ZN2js11KidsPointer7setNullEv($19);
  return;
}

function __ZN9JSContext7calloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime7calloc_EjP9JSContext($2, $bytes, $this);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js10EmptyShape8getClassEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK8JSObject12isDenseArrayEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js10ArrayClassE | 0);
}

function __ZN2js5types10TypeObject17unknownPropertiesEv($this) {
  return (HEAP32[$this + 12 >> 2] & 16777216 | 0) != 0;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11WeakMapBaseC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVN2js11WeakMapBaseE + 8 | 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPhEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIPhEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN9JSRuntime7calloc_EjP9JSContext($this, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    var $1 = _js_calloc($bytes);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $6 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext(undef, undef, undef, $cx);
    var $6 = 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_calloc($bytes) {
  var $1 = _calloc($bytes, 1);
  return $1;
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2($vec, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $2 = $vec + ($i_01 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_01 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = $this | 0;
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($10, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = $this | 0;
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($10, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = $this | 0;
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($10, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_($2, $1);
  var $3 = $this | 0;
  __ZN2js11WeakMapBaseC2Ev($3);
  HEAP32[$this >> 2] = __ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE + 8 | 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $5 = HEAP32[$3 + 4 >> 2];
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_($t, $5);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($2) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $markedAny_01;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $5 = HEAP32[$3 >> 2];
    var $7 = HEAP32[$3 + 4 >> 2];
    var $8 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_($t, $5, $7);
    var $markedAny_1 = $8 ? 1 : $markedAny_01;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_01 = $markedAny_1;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $e = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($t, $tracer);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($e, $this);
    var $1 = $e | 0;
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($1);
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($t, $5);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($1);
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($1);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer($this, $t) {
  __ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map);
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($this, $k) {
  var $4 = HEAP32[HEAP32[$this >> 2] >> 2];
  var $5 = $k;
  var $6 = __Z20IsAboutToBeFinalizedP9JSContextPKv($4, $5);
  return $6 ^ 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $map + 8 | 0;
  __ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $2);
  var $3 = $1;
  var $4 = $this;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  HEAP32[$this + 8 >> 2] = $2 | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_($this, $k, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_($this, $k);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_($this, $v);
    if ($3) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$this >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($6, $v, undef);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_($this, $v) {
  var $4 = HEAP32[HEAP32[$this >> 2] >> 2];
  var $5 = $v;
  var $6 = __Z20IsAboutToBeFinalizedP9JSContextPKv($4, $5);
  return $6 ^ 1;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_($this, $v) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($2, $v, undef);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 26,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $this | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($13, $10);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $18 = $this + 16 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    HEAP32[$2 >> 2] = $14;
    var $21 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $23 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($src_01);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv($src_01);
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv($src_01);
    var $26 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $25);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE($26, $1);
    __label__ = 6;
    break;
   case 6:
    var $28 = $src_01 + 12 | 0;
    if (($28 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $28;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_($1, $8);
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefIPhEcvRS1_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefIPhEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIPhEC1ERS1_($this, $t) {
  __ZN2js7MoveRefIPhEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIPhLj2EE4hashERKS1_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZNK2js5Shape8isNativeEv($this) {
  return ($this | 0) != (__ZN2js5Shape15sharedNonNativeE | 0);
}

function __ZN7mozilla14AlignedStorageILj32EE4addrEv($this) {
  return $this;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js8CallArgs4argvEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK8JSObject12isExtensibleEv($this) {
  return (HEAP32[$this + 8 >> 2] & 4 | 0) == 0;
}

function __ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope) {
  HEAP32[$this >> 2] = $ac;
  HEAP32[$this + 4 >> 2] = $scope;
  return;
}

function __ZN2js12AutoGCRooterD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  var $5 = HEAP32[$this + 8 >> 2] + 196 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js12AutoGCRooterC2EP9JSContexti($this, $cx, $tag) {
  var $2 = $cx + 196 | 0;
  var $3 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $3;
  HEAP32[$this + 4 >> 2] = $tag;
  HEAP32[$this + 8 >> 2] = $cx;
  HEAP32[$2 >> 2] = $this;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($this) {
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($1);
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev($1);
  __ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l) {
  var $1 = __ZN2js13PointerHasherIPhLj2EE4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE($1);
  var $3 = __ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode($cx, $argc, $vp, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 180;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $calleev = __stackBase__ + 8;
    var $thisv = __stackBase__ + 16;
    var $callArgc = __stackBase__ + 24;
    var $argv = __stackBase__ + 28;
    var $ac = __stackBase__ + 120;
    var $1 = __stackBase__ + 172;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, STRING_TABLE._js_apply_str | 0);
    if (($2 | 0) == 0) {
      var $_2 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($2);
    var $6 = __ZNK8JSObject10getPrivateEv($2);
    var $7 = $6;
    __ZN2JSL11ObjectValueER8JSObject($calleev, $7);
    var $8 = __ZN8JSObject10isCallableEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject8getClassEv($7);
    var $12 = HEAP32[$10 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_apply_str | 0, HEAP32[tempInt + 8 >> 2] = $12, tempInt));
    var $_2 = 0;
    __label__ = 34;
    break;
   case 4:
    var $14 = ($argc | 0) != 0;
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZNK2js8CallArgsixEj($args, 0);
    var $17 = $16 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $thisv | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JSL14UndefinedValueEv($thisv);
    __label__ = 7;
    break;
   case 7:
    var $22 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $thisv);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $_2 = 0;
      __label__ = 34;
      break;
    }
   case 8:
    HEAP32[$callArgc >> 2] = 0;
    __ZN2js15AutoValueVectorC1EP9JSContext($argv, $cx);
    if (($mode | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 9:
    if ($argc >>> 0 > 1) {
      __label__ = 10;
      break;
    } else {
      var $callArgv_0 = 0;
      var $58 = 0;
      __label__ = 21;
      break;
    }
   case 10:
    var $28 = __ZNK2js8CallArgsixEj($args, 1);
    var $29 = __ZNK2JS5Value17isNullOrUndefinedEv($28);
    if ($29) {
      var $callArgv_0 = 0;
      var $58 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = __ZNK2JS5Value8isObjectEv($28);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 154, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_apply_str | 0, tempInt));
    var $_1 = 0;
    __label__ = 33;
    break;
   case 13:
    var $34 = __ZNK2JS5Value8toObjectEv($28);
    var $35 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $34, $callArgc);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $38 = HEAPU32[$callArgc >> 2];
    var $40 = $38 >>> 0 < 491520 ? $38 : 491520;
    HEAP32[$callArgc >> 2] = $40;
    var $41 = $argv | 0;
    var $42 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($41, $40);
    if ($42) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 15:
    var $44 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($41);
    var $45 = __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $34, $40, $44);
    if ($45) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 16:
    var $47 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($41);
    var $callArgv_0 = $47;
    var $58 = $40;
    __label__ = 21;
    break;
   case 17:
    if ($14) {
      __label__ = 18;
      break;
    } else {
      var $54 = 0;
      __label__ = 20;
      break;
    }
   case 18:
    var $50 = $argc - 1 | 0;
    if ($50 >>> 0 < 491520) {
      __label__ = 19;
      break;
    } else {
      var $54 = 491520;
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = $50;
    __label__ = 20;
    break;
   case 20:
    var $54;
    HEAP32[$callArgc >> 2] = $54;
    var $55 = __ZNK2js8CallArgs4argvEv($args);
    var $callArgv_0 = $55 + 8 | 0;
    var $58 = $54;
    __label__ = 21;
    break;
   case 21:
    var $58;
    var $callArgv_0;
    var $i_0 = 0;
    var $60 = $58;
    __label__ = 22;
    break;
   case 22:
    var $60;
    var $i_0;
    if ($i_0 >>> 0 < $60 >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $64 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($5, $cx, $callArgv_0 + ($i_0 << 3) | 0);
    if ($64) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 24:
    var $i_0 = $i_0 + 1 | 0;
    var $60 = HEAP32[$callArgc >> 2];
    __label__ = 22;
    break;
   case 25:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $7);
    var $68 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($68) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 26:
    var $70 = $cx + 56 | 0;
    var $71 = HEAP32[$70 >> 2];
    var $72 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($71, $cx, $calleev);
    if ($72) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 27:
    var $74 = HEAP32[$70 >> 2];
    var $75 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($74, $cx, $thisv);
    if ($75) {
      var $i1_0 = 0;
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 28:
    var $i1_0;
    if ($i1_0 >>> 0 < $60 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $78 = HEAP32[$70 >> 2];
    var $80 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($78, $cx, $callArgv_0 + ($i1_0 << 3) | 0);
    if ($80) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 30:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 28;
    break;
   case 31:
    var $84 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $thisv, $calleev, $60, $callArgv_0, $1);
    var $85 = $args | 0;
    var $86 = __ZNK2js12CallReceiver4rvalEv($85);
    var $87 = __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($5, $ac, $84, $1, $86);
    var $_0 = $87 & 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 33;
    break;
   case 33:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($argv);
    var $_2 = $_1;
    __label__ = 34;
    break;
   case 34:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode["X"] = 1;

function __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $fnname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $args | 0;
    var $2 = __ZNK2js12CallReceiver5thisvEv($1);
    var $3 = __ZNK2JS5Value8isObjectEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($2);
    var $8 = __ZNK8JSObject8getClassEv($7);
    if (($8 | 0) == (_DebuggerObject_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$8 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $14 = __ZNK8JSObject10getPrivateEv($7);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $7;
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str3 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value17isNullOrUndefinedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value6isNullEv($this);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value11isUndefinedEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($this, $inc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($1);
    var $3 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $inc);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($1);
    var $6 = $5 + ($2 << 3) | 0;
    var $7 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($1);
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($6, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($beg, $end) {
  var $4 = $end - $beg >> 3;
  __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j($beg, $4);
  return;
}

function __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, $op, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $ec = __stackBase__ + 60;
    var $r = __stackBase__ + 68;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $name);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $9 = __ZNK2js8Debugger10toJSObjectEv($4);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $9);
    if (($op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject8isSealedEP9JSContextPb($6, $cx, $r);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $13 = __ZN8JSObject8isFrozenEP9JSContextPb($6, $cx, $r);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $15 = __ZNK8JSObject12isExtensibleEv($6);
    HEAP8[$r] = $15 & 1;
    __label__ = 7;
    break;
   case 7:
    var $17 = $args | 0;
    var $18 = __ZNK2js12CallReceiver4rvalEv($17);
    var $21 = (HEAP8[$r] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($18, $21);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    var $23 = $ec;
    __ZN2js11ErrorCopierD2Ev($23);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = $_1;
    __label__ = 10;
    break;
   case 10:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope) {
  __ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject($this, $ac, $scope);
  return;
}

function __ZN8JSObject8isSealedEP9JSContextPb($this, $cx, $resultp) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($1, $2, 0, $resultp);
  return $3;
}

function __ZN8JSObject8isFrozenEP9JSContextPb($this, $cx, $resultp) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($1, $2, 1, $resultp);
  return $3;
}

function __ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc($cx, $argc, $vp, $op, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 128;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ac = __stackBase__ + 8;
    var $ec = __stackBase__ + 60;
    var $props = __stackBase__ + 68;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $1 = __ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc($cx, $args, $name);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($1);
    var $5 = __ZNK8JSObject10getPrivateEv($1);
    var $6 = $5;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $6);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $9 = __ZNK2js8Debugger10toJSObjectEv($4);
    __ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject($ec, $ac, $9);
    if (($op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject4sealEP9JSContext($6, $cx);
    var $ok_0 = $11 & 1;
    __label__ = 9;
    break;
   case 5:
    var $14 = __ZN8JSObject6freezeEP9JSContext($6, $cx);
    var $ok_0 = $14 & 1;
    __label__ = 9;
    break;
   case 6:
    var $17 = __ZNK8JSObject12isExtensibleEv($6);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $args | 0;
    var $20 = __ZNK2js12CallReceiver4rvalEv($19);
    __ZN2JS5Value12setUndefinedEv($20);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 8:
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $22 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($6, $cx, $props);
    var $23 = $22 & 1;
    __ZN2js12AutoIdVectorD1Ev($props);
    var $ok_0 = $23;
    __label__ = 9;
    break;
   case 9:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = $args | 0;
    var $28 = __ZNK2js12CallReceiver4rvalEv($27);
    __ZN2JS5Value12setUndefinedEv($28);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    var $30 = $ec;
    __ZN2js11ErrorCopierD2Ev($30);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_2 = $_1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc["X"] = 1;

function __ZN8JSObject4sealEP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($1, $2, 0);
  return $3;
}

function __ZN8JSObject6freezeEP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($1, $2, 1);
  return $3;
}

function __ZN2js12AutoIdVectorC1EP9JSContext($this, $cx) {
  __ZN2js12AutoIdVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($this, $cx, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $success = __stackBase__;
    var $1 = __ZNK8JSObject6getOpsEv($this);
    var $3 = HEAP32[$1 + 120 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this, $success, $props);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$success] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 259, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $14 = $cx;
    var $15 = $this;
    var $16 = $props;
    var $17 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($14, $15, 24, $16);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $19 = __ZNK8JSObject8isNativeEv($this);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN8JSObject21extensibleShapeChangeEP9JSContext($this, $cx);
    __label__ = 8;
    break;
   case 8:
    var $22 = $this + 8 | 0;
    var $24 = HEAP32[$22 >> 2] | 4;
    HEAP32[$22 >> 2] = $24;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoIdVectorD1Ev($this) {
  __ZN2js12AutoIdVectorD2Ev($this);
  return;
}

function __ZN2js12AutoIdVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIiED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIiED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($2);
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZNK8JSObject6getOpsEv($this) {
  var $1 = __ZNK8JSObject8getClassEv($this);
  return $1 + 92 | 0;
}

function __ZNK8JSObject8isNativeEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js5Shape8isNativeEv($2);
  return $3;
}

function __ZN8JSObject21extensibleShapeChangeEP9JSContext($this, $cx) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
  return;
}

function __ZN2js12AutoIdVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIiEC2EP9JSContexti($1, $cx, -15);
  return;
}

function __ZN2js16AutoVectorRooterIiEC2EP9JSContexti($this, $cx, $tag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, $tag);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types4Type13UndefinedTypeEv($1);
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $id, $1);
  __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $id);
  var $2 = __ZNK8JSObject6getOpsEv($this);
  var $4 = HEAP32[$2 + 100 >> 2];
  var $6 = ($4 | 0) != 0 ? $4 : 28;
  var $7 = FUNCTION_TABLE[$6]($cx, $this, $id, $rval, $strict);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $obj, $id, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $6 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx, $obj, $_0);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject4typeEv($obj);
    var $10 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $10;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($8, $cx, $_0, $1);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13UndefinedTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 2);
  return;
}

function __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $5 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx, $obj, $_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject4typeEv($obj);
    __ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti($7, $cx, $_0);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types8Property7keyBitsEi($id) {
  return $id;
}

function _JSID_IS_INT($iden) {
  return $iden & 1;
}

function _JSID_IS_STRING($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_FLAT_STRING($id) {
  return $id;
}

function __ZN8JSString6asFlatEv($this) {
  return $this;
}

function __ZN8JSString11asDependentEv($this) {
  return $this;
}

function __ZN8JSString6asRopeEv($this) {
  return $this;
}

function __ZNK7mozilla14AlignedStorageILj40EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj40EE4addrEv($this) {
  return $this;
}

function __ZNK8JSObject4typeEv($this) {
  return HEAP32[$this + 36 >> 2];
}

function __ZNK8JSObject11hasLazyTypeEv($this) {
  return (HEAP32[$this + 8 >> 2] & 131072 | 0) != 0;
}

function __ZNK8JSObject16hasSingletonTypeEv($this) {
  return (HEAP32[$this + 8 >> 2] & 65536 | 0) != 0;
}

function __ZNK2js5types10TypeObject17basePropertyCountEv($this) {
  return HEAPU32[$this + 12 >> 2] >>> 4 & 4095;
}

function __ZN2js5types8Property6getKeyEPS1_($p) {
  return HEAP32[$p >> 2];
}

function __ZNK14JSLinearString5charsEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK8JSString6isFlatEv($this) {
  return (HEAP32[$this >> 2] & 3 | 0) == 0;
}

function __ZNK8JSString11isDependentEv($this) {
  return (HEAP32[$this >> 2] & 2 | 0) != 0;
}

function __ZN2js5types4TypeC2Ej($this, $data) {
  HEAP32[$this >> 2] = $data;
  return;
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + HEAP32[$this + 8 >> 2] * 40 | 0;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK8JSObject13isObjectProxyEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  return ($2 | 0) == (__ZN2js16ObjectProxyClassE | 0) | ($2 | 0) == (__ZN2js21OuterWindowProxyClassE | 0);
}

function __ZNK8JSObject15isFunctionProxyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js18FunctionProxyClassE | 0);
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + HEAP32[$this + 8 >> 2] * 40 | 0;
}

function __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_8PropDescEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT($id);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 2;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = _JSID_IS_STRING($id);
    if (($4 | 0) == 0) {
      var $_0 = 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_FLAT_STRING($id);
    var $8 = $7 | 0;
    var $9 = __ZN8JSString9getCharsZEP9JSContext($8, $cx);
    var $10 = HEAPU16[$9 >> 1];
    if ((($10 & 65535) - 48 | 0) >>> 0 < 10 | $10 << 16 >> 16 == 45) {
      var $_pn = $9;
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_pn;
    var $cp_0 = $_pn + 2 | 0;
    var $15 = HEAPU16[$cp_0 >> 1];
    if ((($15 & 65535) - 48 | 0) >>> 0 < 10) {
      var $_pn = $cp_0;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($15 << 16 >> 16 == 0) {
      var $_0 = 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $id;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject11hasLazyTypeEv($obj);
    if ($3) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject4typeEv($obj);
    var $6 = __ZN2js5types10TypeObject17unknownPropertiesEv($5);
    if ($6) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject16hasSingletonTypeEv($obj);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($5, undef, $id);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($this, $cx, $id) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $3 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
  var $4 = __ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_($2, $3, $id);
  var $7 = ($4 | 0) == 0 ? 0 : $4 + 4 | 0;
  return $7;
}

function __ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_($values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($count | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $values;
    var $3 = __ZN2js5types8Property6getKeyEPS1_($2);
    var $5 = ($3 | 0) == ($key | 0) ? $2 : 0;
    var $_0 = $5;
    __label__ = 11;
    break;
   case 3:
    if ($count >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $count >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $11 = HEAPU32[$values + ($i_0 << 2) >> 2];
    var $12 = __ZN2js5types8Property6getKeyEPS1_($11);
    if (($12 | 0) == ($key | 0)) {
      var $_0 = $11;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $17 = __ZN2js5typesL15HashSetCapacityEj($count);
    var $18 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_($key);
    var $19 = $17 - 1 | 0;
    var $_pn = $18;
    __label__ = 8;
    break;
   case 8:
    var $_pn;
    var $pos_0 = $_pn & $19;
    var $22 = HEAP32[$values + ($pos_0 << 2) >> 2];
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZN2js5types8Property6getKeyEPS1_($22);
    if (($25 | 0) == ($key | 0)) {
      var $_0 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_pn = $pos_0 + 1 | 0;
    __label__ = 8;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN8JSString9getCharsZEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString10ensureFlatEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZNK14JSLinearString5charsEv($4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSString10ensureFlatEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6isFlatEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString6asFlatEv($this);
    var $14 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = __ZNK8JSString11isDependentEv($this);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZN8JSString11asDependentEv($this);
    var $8 = __ZN17JSDependentString8undependEP9JSContext($7, $cx);
    var $14 = $8 | 0;
    __label__ = 6;
    break;
   case 5:
    var $11 = __ZN8JSString6asRopeEv($this);
    var $12 = __ZN6JSRope7flattenEP9JSContext($11, $cx);
    var $14 = $12;
    __label__ = 6;
    break;
   case 6:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4TypeC1Ej($this, $data) {
  __ZN2js5types4TypeC2Ej($this, $data);
  return;
}

function __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = $cx;
    var $6 = __ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE($5, $vp);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($this, $cx) {
  __ZN2js23AutoPropDescArrayRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js16AutoVectorRooterIiE6lengthEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($1);
  return $2;
}

function __ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE($cx, $dbg, $obj, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $desc + 33 | 0;
    var $2 = HEAP8[$1];
    if (($2 & 4) << 24 >> 24 == 0) {
      var $11 = $2;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $desc + 8 | 0;
    var $7 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $6, STRING_TABLE._js_value_str | 0);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $11 = HEAP8[$1];
    __label__ = 5;
    break;
   case 5:
    var $11;
    if (($11 & 1) << 24 >> 24 == 0) {
      var $22 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $desc + 16 | 0;
    var $16 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $15);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $18 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $15, STRING_TABLE._js_get_str | 0);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $20 = __ZN2js8PropDesc11checkGetterEP9JSContext($desc, $cx);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $22 = HEAP8[$1];
    __label__ = 10;
    break;
   case 10:
    var $22;
    if (($22 & 2) << 24 >> 24 == 0) {
      var $33 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = $desc + 24 | 0;
    var $27 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($dbg, $cx, $26);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $29 = __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $26, STRING_TABLE._js_set_str | 0);
    if ($29) {
      __label__ = 13;
      break;
    } else {
      var $33 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $31 = __ZN2js8PropDesc11checkSetterEP9JSContext($desc, $cx);
    var $33 = $31;
    __label__ = 14;
    break;
   case 14:
    var $33;
    return $33;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPropDescArrayRooterixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE($cx, $obj, $idp, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment6wrapIdEP9JSContextPi($2, $cx, $idp);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = $desc + 8 | 0;
    var $6 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = $desc + 16 | 0;
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $11 = $desc + 24 | 0;
    var $12 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $19 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = __ZNK8JSObject7isProxyEv($obj);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $19 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = $cx;
    var $17 = __ZN2js8PropDesc10makeObjectEP9JSContext($desc, $16);
    var $19 = $17;
    __label__ = 7;
    break;
   case 7:
    var $19;
    return $19;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIiEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZN2js23AutoPropDescArrayRooterD1Ev($this) {
  __ZN2js23AutoPropDescArrayRooterD2Ev($this);
  return;
}

function __ZN2js23AutoPropDescArrayRooterD2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($2);
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj40EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZNK8JSObject7isProxyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13isObjectProxyEv($this);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject15isFunctionProxyEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + $i * 40 | 0;
}

function __ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_($cx, $obj, $v, $propname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = $3;
    var $5 = __ZNK2js2gc4Cell11compartmentEv($4);
    var $6 = $obj;
    var $7 = __ZNK2js2gc4Cell11compartmentEv($6);
    if (($5 | 0) == ($7 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 285, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE.__str122209 | 0, HEAP32[tempInt + 4 >> 2] = $propname, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc11checkGetterEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 33 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 16 | 0;
    var $7 = __ZL13js_IsCallableRKN2JS5ValueE($6);
    if ($7) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2JS5Value11isUndefinedEv($6);
    if ($9) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 248, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_getter_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc11checkSetterEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 33 | 0] & 2) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 24 | 0;
    var $7 = __ZL13js_IsCallableRKN2JS5ValueE($6);
    if ($7) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2JS5Value11isUndefinedEv($6);
    if ($9) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 248, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_setter_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPropDescArrayRooterC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, -7);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj40EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js23AutoPropDescArrayRooter6appendEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 12 | 0;
    __ZN2js8PropDescC2Ev($1);
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_($2, $1);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv($2);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 40;
  for (var $$src = tempParam >> 2, $$dest = $0 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
    HEAP32[$$dest] = HEAP32[$$src];
  }
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_040 = $0 | 0;
    var $tmp41$0 = HEAP32[$_040 >> 2];
    var $tmp41$1 = HEAP32[$_040 + 4 >> 2];
    var $_1434_0 = $0 + 8 | 0;
    var $tmp35$0 = HEAP32[$_1434_0 >> 2];
    var $tmp35$1 = HEAP32[$_1434_0 + 4 >> 2];
    var $_2530_0 = $0 + 16 | 0;
    var $tmp31$0 = HEAP32[$_2530_0 >> 2];
    var $tmp31$1 = HEAP32[$_2530_0 + 4 >> 2];
    var $_3626_0 = $0 + 24 | 0;
    var $tmp27$0 = HEAP32[$_3626_0 >> 2];
    var $tmp27$1 = HEAP32[$_3626_0 + 4 >> 2];
    var $4 = HEAPU32[$0 + 32 >> 2];
    var $6 = $4 & 255;
    var $8 = ($4 & 65535 & 65535) >>> 8 & 255;
    var $10 = $4 >>> 16 & 255;
    var $12 = $4 >>> 24 & 255;
    var $tmp14 = HEAPU16[$0 + 36 >> 1];
    var $14 = $tmp14 & 255;
    var $16 = ($tmp14 & 65535) >>> 8 & 255;
    var $tmp16 = HEAPU16[$0 + 38 >> 1];
    var $18 = $tmp16 & 255;
    var $20 = ($tmp16 & 65535) >>> 8 & 255;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $27 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($27) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_038 = $2 | 0;
    HEAP32[$_038 >> 2] = $tmp41$0;
    HEAP32[$_038 + 4 >> 2] = $tmp41$1;
    var $_132_0 = $2 + 8 | 0;
    HEAP32[$_132_0 >> 2] = $tmp35$0;
    HEAP32[$_132_0 + 4 >> 2] = $tmp35$1;
    var $_228_0 = $2 + 16 | 0;
    HEAP32[$_228_0 >> 2] = $tmp31$0;
    HEAP32[$_228_0 + 4 >> 2] = $tmp31$1;
    var $_324_0 = $2 + 24 | 0;
    HEAP32[$_324_0 >> 2] = $tmp27$0;
    HEAP32[$_324_0 + 4 >> 2] = $tmp27$1;
    HEAP8[$2 + 32 | 0] = $6;
    HEAP8[$2 + 33 | 0] = $8;
    HEAP8[$2 + 34 | 0] = $10;
    HEAP8[$2 + 35 | 0] = $12;
    HEAP8[$2 + 36 | 0] = $14;
    HEAP8[$2 + 37 | 0] = $16;
    HEAP8[$2 + 38 | 0] = $18;
    HEAP8[$2 + 39 | 0] = $20;
    __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_["X"] = 1;

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 40 | 0;
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 40;
  for (var $$src = tempParam >> 2, $$dest = $0 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
    HEAP32[$$dest] = HEAP32[$$src];
  }
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_3525_0 = $0 + 24 | 0;
    var $_2429_0 = $0 + 16 | 0;
    var $_1333_0 = $0 + 8 | 0;
    var $_038 = $0 | 0;
    var $tmp16 = HEAP8[$0 + 39 | 0];
    var $tmp15 = HEAP8[$0 + 38 | 0];
    var $tmp14 = HEAP8[$0 + 37 | 0];
    var $tmp13 = HEAP8[$0 + 36 | 0];
    var $tmp12 = HEAP8[$0 + 35 | 0];
    var $tmp11 = HEAP8[$0 + 34 | 0];
    var $tmp9 = HEAP8[$0 + 33 | 0];
    var $tmp7 = HEAP8[$0 + 32 | 0];
    var $tmp26$0 = HEAP32[$_3525_0 >> 2];
    var $tmp26$1 = HEAP32[$_3525_0 + 4 >> 2];
    var $tmp30$0 = HEAP32[$_2429_0 >> 2];
    var $tmp30$1 = HEAP32[$_2429_0 + 4 >> 2];
    var $tmp34$0 = HEAP32[$_1333_0 >> 2];
    var $tmp34$1 = HEAP32[$_1333_0 + 4 >> 2];
    var $tmp39$0 = HEAP32[$_038 >> 2];
    var $tmp39$1 = HEAP32[$_038 + 4 >> 2];
    var $_0 = $2 | 0;
    HEAP32[$_0 >> 2] = $tmp39$0;
    HEAP32[$_0 + 4 >> 2] = $tmp39$1;
    var $_131_0 = $2 + 8 | 0;
    HEAP32[$_131_0 >> 2] = $tmp34$0;
    HEAP32[$_131_0 + 4 >> 2] = $tmp34$1;
    var $_227_0 = $2 + 16 | 0;
    HEAP32[$_227_0 >> 2] = $tmp30$0;
    HEAP32[$_227_0 + 4 >> 2] = $tmp30$1;
    var $_323_0 = $2 + 24 | 0;
    HEAP32[$_323_0 >> 2] = $tmp26$0;
    HEAP32[$_323_0 + 4 >> 2] = $tmp26$1;
    HEAP8[$2 + 32 | 0] = $tmp7;
    HEAP8[$2 + 33 | 0] = $tmp9;
    HEAP8[$2 + 34 | 0] = $tmp11;
    HEAP8[$2 + 35 | 0] = $tmp12;
    HEAP8[$2 + 36 | 0] = $tmp13;
    HEAP8[$2 + 37 | 0] = $tmp14;
    HEAP8[$2 + 38 | 0] = $tmp15;
    HEAP8[$2 + 39 | 0] = $tmp16;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_["X"] = 1;

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 40 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 33554431) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 33554431) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 40 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $13 = __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($1);
    var $14 = $dst_01;
    var $15 = $13;
    for (var $$src = $15 >> 2, $$dest = $14 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __label__ = 5;
    break;
   case 5:
    var $17 = $dst_01 + 40 | 0;
    var $18 = $src_02 + 40 | 0;
    var $19 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($18 | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      __label__ = 3;
      break;
    }
   case 6:
    var $21 = $v + 4 | 0;
    var $23 = HEAP32[$21 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $23);
    HEAP32[$21 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC2ERS1_($this, $t);
  return;
}

function _JSID_TO_INT($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING($iden) {
  return $iden;
}

function _JSID_TO_OBJECT($iden) {
  return $iden & -8;
}

function _JSVAL_TO_STRING_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _INT_TO_JSID($i) {
  return $i << 1 | 1;
}

function __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($op) {
  return $op;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject($object) {
  return $object;
}

function __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($op) {
  return $op;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject($object) {
  return $object;
}

function __ZN8JSString8asLinearEv($this) {
  return $this;
}

function _DOUBLE_TO_JSVAL_IMPL($agg_result, $d) {
  var $1 = $agg_result;
  tempDoubleF64[0] = $d, HEAP32[$1 >> 2] = tempDoubleI32[0], HEAP32[$1 + 4 >> 2] = tempDoubleI32[1];
  return;
}

function _JSDOUBLE_IS_NEGZERO($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _STRING_TO_JSVAL_IMPL($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK8JSObject10isFunctionEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js13FunctionClassE | 0);
}

function __ZNK10JSFunction4kindEv($this) {
  return HEAP16[$this + 58 >> 1] & -16384;
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK8JSObject8getProtoEv($this) {
  return HEAP32[HEAP32[$this + 36 >> 2] >> 2];
}

function __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($this) {
  return (HEAP32[$this >> 2] & 10 | 0) == 2;
}

function __ZNK2js10StackFrame10hasCallObjEv($this) {
  return (HEAP32[$this >> 2] & 16384 | 0) != 0;
}

function __ZNK8JSString6lengthEv($this) {
  return HEAPU32[$this >> 2] >>> 4;
}

function __ZN2JS6AnchorIP8JSStringEC2ES2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK8JSString8isLinearEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) == 0;
}

function __ZNK2js10StackFrame13isGlobalFrameEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js10StackFrame15isFunctionFrameEv($this) {
  return (HEAP32[$this >> 2] & 2 | 0) != 0;
}

function __ZNK2js10StackFrame3funEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js10StackFrame4prevEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js10StackFrame12isDummyFrameEv($this) {
  return (HEAP32[$this >> 2] & 4 | 0) != 0;
}

function __ZNK2js10StackFrame16isGeneratorFrameEv($this) {
  return (HEAP32[$this >> 2] & 32 | 0) != 0;
}

function __ZNK2js10StackFrame14isConstructingEv($this) {
  return (HEAP32[$this >> 2] & 128 | 0) != 0;
}

function __ZNK2js10StackFrame10hasArgsObjEv($this) {
  return (HEAP32[$this >> 2] & 32768 | 0) != 0;
}

function __ZNK2js10StackFrame7argsObjEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $5 = __ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev($1);
    var $6 = $_02;
    var $7 = $5;
    for (var $$src = $7 >> 2, $$dest = $6 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __label__ = 4;
    break;
   case 4:
    var $9 = $p_01 + 40 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 40 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8PropDescEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($1);
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - $newLength | 0;
    __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj($1, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $7 = $newLength - $2 | 0;
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($1);
    var $11 = $10 + ($2 << 3) | 0;
    var $12 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($1);
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_($11, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZN2JS5Value9setStringEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL($1, $str);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZL12JSID_IS_ATOMi($id) {
  var $1 = _JSID_IS_STRING($id);
  return $1;
}

function __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($1);
  return $2;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($this, $cx) {
  __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject5($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterD1Ev($this) {
  __ZN2js28AutoPropertyDescriptorRooterD2Ev($this);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -13);
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $6 = $this + 32 | 0;
  __ZN2JS5Value12setUndefinedEv($6);
  return;
}

function __ZNK8JSObject18getFunctionPrivateEv($this) {
  var $1 = __ZNK8JSObject10getPrivateEv($this);
  return $1;
}

function __ZNK10JSFunction13isInterpretedEv($this) {
  var $1 = __ZNK10JSFunction4kindEv($this);
  return ($1 & 65535) > 16383;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2JSL11StringValueEP8JSString($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode($cx, $argc, $vp, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 224;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $keys = __stackBase__ + 8;
    var $values = __stackBase__ + 68;
    var $ac = __stackBase__ + 160;
    var $anchor = __stackBase__ + 212;
    var $1 = __stackBase__ + 216;
    var $2 = ($mode | 0) == 1;
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str96 | 0, 2);
    var $_2 = 0;
    __label__ = 33;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __Z20ReportMoreArgsNeededP9JSContextPKcj($cx, STRING_TABLE.__str97 | 0, 1);
    var $_2 = 0;
    __label__ = 33;
    break;
   case 6:
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $12 = $2 ? STRING_TABLE.__str61 | 0 : STRING_TABLE._js_eval_str | 0;
    var $13 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $12, 1);
    if (($13 | 0) == 0) {
      var $_2 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK8JSObject10getPrivateEv($13);
    var $17 = $16;
    var $18 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($13);
    var $19 = __ZNK2js8CallArgsixEj($args, 0);
    var $20 = __ZNK2JS5Value8isStringEv($19);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN2js21InformalValueTypeNameERKN2JS5ValueE($19);
    _JS_ReportErrorNumber($cx, 2, 0, 255, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str97 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str22179 | 0, HEAP32[tempInt + 8 >> 2] = $22, tempInt));
    var $_2 = 0;
    __label__ = 33;
    break;
   case 9:
    var $24 = __ZNK2JS5Value8toStringEv($19);
    var $25 = __ZN8JSString12ensureLinearEP9JSContext($24, $cx);
    if (($25 | 0) == 0) {
      var $_2 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    __ZN2js15AutoValueVectorC1EP9JSContext($values, $cx);
    if ($2) {
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $29 = __ZNK2js8CallArgsixEj($args, 1);
    var $30 = $cx;
    var $31 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($30, $29);
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = $cx;
    var $36 = $31;
    var $37 = $keys;
    var $38 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($35, $36, 8, $37);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 13:
    var $40 = $values | 0;
    var $41 = $keys | 0;
    var $42 = __ZNK2js16AutoVectorRooterIiE6lengthEv($41);
    var $43 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj($40, $42);
    if ($43) {
      var $i_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 14:
    var $i_0;
    var $44 = __ZNK2js16AutoVectorRooterIiE6lengthEv($41);
    if ($i_0 >>> 0 < $44 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $47 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($40, $i_0);
    var $48 = __ZN2js16AutoVectorRooterIiEixEj($41, $i_0);
    var $49 = HEAP32[$48 >> 2];
    var $50 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($32, $cx, $32, $49, $47);
    if (($50 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $53 = __ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE($18, $cx, $47);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      var $_1 = 0;
      __label__ = 32;
      break;
    }
   case 17:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 14;
    break;
   case 18:
    var $56 = __ZNK2js10StackFrame10scopeChainEv($17);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $56);
    var $57 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($57) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 19:
    var $59 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($17);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $61 = __ZNK2js10StackFrame10hasCallObjEv($17);
    if ($61) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $63 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $17);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $66 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $17);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ($2) {
      __label__ = 24;
      break;
    } else {
      var $scobj_0 = $66;
      __label__ = 30;
      break;
    }
   case 24:
    var $70 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js11ObjectClassE, 0, $66);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $72 = $keys | 0;
    var $73 = $cx + 56 | 0;
    var $74 = $values | 0;
    var $75 = $cx;
    var $76 = $70;
    var $i1_0 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i1_0;
    var $78 = __ZNK2js16AutoVectorRooterIiE6lengthEv($72);
    if ($i1_0 >>> 0 < $78 >>> 0) {
      __label__ = 27;
      break;
    } else {
      var $scobj_0 = $70;
      __label__ = 30;
      break;
    }
   case 27:
    var $81 = HEAP32[$73 >> 2];
    var $82 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($74, $i1_0);
    var $83 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($81, $cx, $82);
    if ($83) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 28:
    var $85 = __ZN2js16AutoVectorRooterIiEixEj($72, $i1_0);
    var $86 = HEAP32[$85 >> 2];
    var $87 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($74, $i1_0);
    var $88 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($75, $76, $86, $87, 0, 0, 0, 0, 0, 0);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 26;
    break;
   case 30:
    var $scobj_0;
    var $92 = $25 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $92);
    var $93 = __ZNK14JSLinearString5charsEv($25);
    var $94 = __ZNK8JSString6lengthEv($92);
    var $95 = __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($cx, $scobj_0, $17, $93, $94, STRING_TABLE.__str99 | 0, 1, $1);
    var $96 = ($95 | 0) != 0;
    var $97 = __ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_($18, $ac, $96, $1, $vp);
    var $_0 = $97 & 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($values);
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_2 = $_1;
    __label__ = 33;
    break;
   case 33:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode["X"] = 1;

function __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $fnname, $checkLive) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $args | 0;
    var $3 = __ZNK2js12CallReceiver5thisvEv($2);
    var $4 = __ZNK2JS5Value8isObjectEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8toObjectEv($3);
    var $9 = __ZNK8JSObject8getClassEv($8);
    if (($9 | 0) == (_DebuggerFrame_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$9 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $13, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    var $15 = __ZNK8JSObject10getPrivateEv($8);
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $8;
      __label__ = 10;
      break;
    }
   case 6:
    __ZNK8JSObject15getReservedSlotEj($1, $8, 0);
    var $18 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($checkLive) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $8;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 277, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str83 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str100 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isStringEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_STRING_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZNK2JS5Value8toStringEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_STRING_IMPL($2$0, $2$1);
  return $3;
}

function __ZN8JSString12ensureLinearEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString8isLinearEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString8asLinearEv($this);
    var $9 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN8JSString6asRopeEv($this);
    var $6 = __ZN6JSRope7flattenEP9JSContext($5, $cx);
    var $9 = $6 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($this, $cx, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject6getOpsEv($this);
    var $3 = HEAP32[$1 + 32 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this, $receiver, $id, $vp);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $cx;
    var $10 = $this;
    var $11 = $receiver;
    var $12 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($9, $10, $11, $id, $vp);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSStringEC1ES2_($this, $t) {
  __ZN2JS6AnchorIP8JSStringEC2ES2_($this, $t);
  return;
}

function __ZL11IsValidHookRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($1) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8isObjectEv($v);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($v);
    var $6 = __ZN8JSObject10isCallableEv($5);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame6calleeEv($this) {
  var $1 = __ZNK2js10StackFrame7calleevEv($this);
  var $2 = __ZNK2JS5Value8toObjectEv($1);
  return $2;
}

function __ZNK2js10StackFrame7calleevEv($this) {
  var $1 = __ZNK2js10StackFrame14mutableCalleevEv($this);
  return $1;
}

function __ZNK2js10StackFrame14mutableCalleevEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 16 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame10formalArgsEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame13numFormalArgsEv($this);
  return $1 + (-$2 << 3) | 0;
}

function __ZNK2js10StackFrame13numFormalArgsEv($this) {
  var $1 = __ZNK2js10StackFrame3funEv($this);
  return HEAPU16[$1 + 56 >> 1] & 65535;
}

function __ZN2JS5Value9setNumberEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = _JSDOUBLE_IS_INT32($d, $i);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$i >> 2];
    __ZN2JS5Value8setInt32Ei($this, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($this, $d);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT32($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value9setDoubleEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _DOUBLE_TO_JSVAL_IMPL($1, $d);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL9NullValueEv($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZNK2js10StackFrame7hasArgsEv($this) {
  var $1 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($this);
  return $1;
}

function __ZNK2js10StackFrame13numActualArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 6144 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame10hasArgsObjEv($this);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2js10StackFrame7argsObjEv($this);
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 4:
    var $_0 = HEAP32[$this + 8 >> 2];
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZNK2js10StackFrame13numFormalArgsEv($this);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $ca2 = __stackBase__ + 24;
    var $arg = __stackBase__ + 32;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $3 = $args | 0;
    var $4 = __ZNK2js12CallReceiver6calleeEv($3);
    __ZNK8JSObject15getReservedSlotEj($1, $4, 0);
    var $5 = __ZNK2JS5Value7toInt32Ev($1);
    var $6 = __ZNK2js12CallReceiver5thisvEv($3);
    var $7 = __ZNK2JS5Value8isObjectEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $11 = __ZNK2JS5Value8toObjectEv($6);
    var $12 = __ZNK8JSObject8getClassEv($11);
    if (($12 | 0) == (_DebuggerArguments_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$12 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str1263 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str112 | 0, HEAP32[tempInt + 8 >> 2] = $16, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 5:
    __ZNK8JSObject15getReservedSlotEj($2, $11, 0);
    var $18 = $2 | 0;
    var $st$2$0 = $18 | 0;
    var $19$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$2$1 >> 2];
    var $20 = $6 | 0;
    var $st$7$0 = $20 | 0;
    HEAP32[$st$7$0 >> 2] = $19$0;
    var $st$7$1 = $20 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $19$1;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($ca2, $argc, $vp);
    var $21 = __ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb($cx, $ca2, STRING_TABLE.__str113 | 0, 1);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = __ZNK8JSObject10getPrivateEv($21);
    var $25 = $24;
    var $26 = __ZNK2js10StackFrame13numActualArgsEv($25);
    if ($5 >>> 0 < $26 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = __ZNK2js10StackFrame18canonicalActualArgEj($25, $5);
    var $30 = $29 | 0;
    var $st$2$0 = $30 | 0;
    var $31$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $30 + 4 | 0;
    var $31$1 = HEAP32[$st$2$1 >> 2];
    var $32 = $arg | 0;
    var $st$7$0 = $32 | 0;
    HEAP32[$st$7$0 >> 2] = $31$0;
    var $st$7$1 = $32 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $31$1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JS5Value12setUndefinedEv($arg);
    __label__ = 9;
    break;
   case 9:
    var $35 = __ZN2js8Debugger17fromChildJSObjectEP8JSObject($21);
    var $36 = __ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE($35, $cx, $arg);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = __ZNK2js12CallReceiver4rvalEv($3);
    var $39 = $arg | 0;
    var $st$2$0 = $39 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $41 = $38 | 0;
    var $st$7$0 = $41 | 0;
    HEAP32[$st$7$0 >> 2] = $40$0;
    var $st$7$1 = $41 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value7toInt32Ev($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_INT32_IMPL($2$0, $2$1);
  return $3;
}

function __ZNK2js10StackFrame18canonicalActualArgEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame13numFormalArgsEv($this);
    if ($1 >>> 0 > $i >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame9formalArgEj($this, $i);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js10StackFrame10actualArgsEv($this);
    var $_0 = $6 + ($i << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame9formalArgEj($this, $i) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZNK2js10StackFrame10actualArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
    if ((HEAP32[$this >> 2] & 2048 | 0) == 0) {
      var $_0 = $1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js10StackFrame10hasArgsObjEv($this);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame7argsObjEv($this);
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    var $15 = $10;
    __label__ = 5;
    break;
   case 4:
    var $15 = HEAP32[$this + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $15;
    var $_0 = $1 + (-2 - $15 << 3) | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject13initialLengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = __ZNK2JS5Value7toInt32Ev($2);
  return $3 >>> 1;
}

function _JSVAL_TO_INT32_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZN2js13FlowsIntoNextE4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 197 || ($op | 0) == 155 || ($op | 0) == 141 || ($op | 0) == 112 || ($op | 0) == 6 || ($op | 0) == 5 || ($op | 0) == 117) {
      var $2 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 1;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_DOUBLE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_IS_NUMBER_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967170 & 1;
}

function _JSVAL_TO_PRIVATE_PTR_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2JS5Value8toDoubleEv($this) {
  var $1 = $this;
  var $2 = (tempDoubleI32[0] = HEAP32[$1 >> 2], tempDoubleI32[1] = HEAP32[$1 + 4 >> 2], tempDoubleF64[0]);
  return $2;
}

function __ZNK8JSObject13numFixedSlotsEv($this) {
  return HEAPU32[$this + 8 >> 2] >>> 27;
}

function __ZNK8JSScript10getVersionEv($this) {
  return HEAPU16[$this + 12 >> 1] & 65535;
}

function __ZNK2js12StackSegment9maybeRegsEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $argv) {
  HEAP32[$agg_result >> 2] = $argv;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js13BytecodeRange5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0);
}

function __ZNK2js13BytecodeRange11frontOffsetEv($this) {
  return HEAP32[$this + 8 >> 2] - HEAP32[HEAP32[$this + 4 >> 2] >> 2] | 0;
}

function __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js13BytecodeRange7frontPCEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($this, $cx, $script) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $script;
  var $5 = HEAP32[$script >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  var $9 = $5 + HEAP32[$script + 8 >> 2] | 0;
  HEAP32[$this + 12 >> 2] = $9;
  return;
}

function __ZN8JSScript5notesEv($this) {
  return HEAP32[$this >> 2] + HEAP32[$this + 8 >> 2] | 0;
}

function __ZNK10JSCodeSpec4typeEv($this) {
  return HEAP32[$this + 4 >> 2] & 31;
}

function __ZNK8JSObject7getSlotEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13numFixedSlotsEv($this);
    if ($1 >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10fixedSlotsEv($this);
    var $_0 = $4 + ($slot << 3) | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this + 32 >> 2] + ($slot - $1 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack5hasfpEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js12StackSegment9maybeRegsEv($2);
    var $8 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction12inStrictModeEv($this) {
  var $1 = __ZNK10JSFunction6scriptEv($this);
  return (HEAP8[$1 + 36 | 0] & 8) << 24 >> 24 != 0;
}

function __ZNK2js10StackFrame12callReceiverEv($agg_result, $this) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $1);
  return;
}

function __ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb($cx, $args, $fnname, $checkLive) {
  var $1 = $args | 0;
  var $2 = __ZNK2js12CallReceiver5thisvEv($1);
  var $3 = __ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b($cx, $2, $fnname, $checkLive);
  return $3;
}

function __ZL17GetScriptReferentP8JSObject($obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function __ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b($cx, $v, $fnname, $checkLive) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value8isObjectEv($v);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z20ReportObjectRequiredP9JSContext($cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($v);
    var $7 = __ZNK8JSObject8getClassEv($6);
    if (($7 | 0) == (_DebuggerScript_class | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = $11, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    __ZNK8JSObject15getReservedSlotEj($1, $6, 1);
    var $13 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str11 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 7:
    if ($checkLive) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $6;
      __label__ = 10;
      break;
    }
   case 8:
    var $17 = __ZL17GetScriptReferentP8JSObject($6);
    if (($17 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $6;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 277, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str82 | 0, HEAP32[tempInt + 4 >> 2] = $fnname, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str33670 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj($cx, $script, $v, $offsetp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isNumberEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toNumberEv($v);
    var $4 = $3 >= 0 ? Math.floor($3) : Math.ceil($3);
    if ($4 >>> 0 != $3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj($cx, $script, $4);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 282, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$offsetp >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isNumberEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_NUMBER_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZNK2JS5Value8toNumberEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isDoubleEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($this);
    var $8 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2JS5Value7toInt32Ev($this);
    var $8 = $5 | 0;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value8isDoubleEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_DOUBLE_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZL15GetScriptHolderP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  __ZNK8JSObject15getReservedSlotEj($v, $obj, 1);
  var $1 = __ZNK2JS5Value9toPrivateEv($v);
  var $2 = $1;
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js8Debugger13observesScopeEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 12 | 0;
  var $3 = $obj;
  var $4 = __ZNK8JSObject9getGlobalEv($3);
  HEAP32[$1 >> 2] = $4;
  var $6 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_($2, $1);
  STACKTOP = __stackBase__;
  return $6;
}

function __ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject($cx, $script, $holder) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    if (($holder | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $holder;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $cx + 60 | 0;
    var $4 = __ZNK2js12ContextStack5spaceEv($3);
    var $5 = $i;
    var $6 = $4;
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($5, $6);
    var $7 = __ZNK2js13AllFramesIter2fpEv($i);
    var $8 = __ZNK2js10StackFrame11maybeScriptEv($7);
    if (($8 | 0) == ($script | 0)) {
      var $_lcssa = $7;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_lcssa;
    var $10 = __ZNK2js10StackFrame10scopeChainEv($_lcssa);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 4:
    var $11 = __ZN2js13AllFramesIterppEv($5);
    var $12 = __ZNK2js13AllFramesIter2fpEv($i);
    var $13 = __ZNK2js10StackFrame11maybeScriptEv($12);
    if (($13 | 0) == ($script | 0)) {
      var $_lcssa = $12;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_($this, $p1, $p2, $p3) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 28, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject($4, $p1, $p2, $p3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame11maybeScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame13isScriptFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6scriptEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value9toPrivateEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_PRIVATE_PTR_IMPL($2$0, $2$1);
  return $3;
}

function __ZN2JS5Value9setNumberEj($this, $ui) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ui | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $ui >>> 0;
    __ZN2JS5Value9setDoubleEd($this, $3);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value8setInt32Ei($this, $ui);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16FlowGraphSummaryC1EP9JSContext($this, $cx) {
  __ZN16FlowGraphSummaryC2EP9JSContext($this, $cx);
  return;
}

function __ZN16FlowGraphSummary8populateEP9JSContextP8JSScript($this, $cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this | 0;
    var $2 = $script + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 2:
    var $6 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($1, 0);
    HEAP32[$6 >> 2] = -2;
    if (HEAPU32[$2 >> 2] >>> 0 > 1) {
      var $i_017 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $i_017;
    var $9 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($1, $i_017);
    HEAP32[$9 >> 2] = -1;
    var $10 = $i_017 + 1 | 0;
    if ($10 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      var $i_017 = $10;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$script + 28 >> 2];
    __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($r, $cx, $script);
    var $15 = $r | 0;
    var $16 = __ZNK2js13BytecodeRange5emptyEv($15);
    if ($16) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      var $prevLine_014 = $14;
      var $prevOp_015 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $prevOp_015;
    var $prevLine_014;
    var $17 = __ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv($r);
    var $18 = __ZNK2js13BytecodeRange11frontOpcodeEv($15);
    var $19 = __ZN2js13FlowsIntoNextE4JSOp($prevOp_015);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZNK2js13BytecodeRange11frontOffsetEv($15);
    __ZN16FlowGraphSummary7addEdgeEjj($this, $prevLine_014, $21);
    __label__ = 7;
    break;
   case 7:
    var $23 = _js_CodeSpec + ($18 << 3) | 0;
    var $24 = __ZNK10JSCodeSpec4typeEv($23);
    if (($24 | 0) == 1) {
      __label__ = 8;
      break;
    } else if (($24 | 0) == 9) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = __ZNK2js13BytecodeRange11frontOffsetEv($15);
    var $27 = __ZNK2js13BytecodeRange7frontPCEv($15);
    var $37 = (((HEAPU8[$27 + 1 | 0] & 255) << 8 | HEAPU8[$27 + 2 | 0] & 255) << 16 >> 16) + $26 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $17, $37);
    __label__ = 22;
    break;
   case 9:
    var $39 = __ZNK2js13BytecodeRange11frontOffsetEv($15);
    var $40 = __ZNK2js13BytecodeRange7frontPCEv($15);
    var $59 = ((HEAPU8[$40 + 2 | 0] & 255) << 16 | (HEAPU8[$40 + 1 | 0] & 255) << 24 | HEAPU8[$40 + 4 | 0] & 255 | (HEAPU8[$40 + 3 | 0] & 255) << 8) + $39 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $17, $59);
    __label__ = 22;
    break;
   case 10:
    var $61 = ($18 | 0) == 149;
    if (($18 | 0) == 71 || ($18 | 0) == 149 || ($18 | 0) == 150) {
      __label__ = 11;
      break;
    } else if (($18 | 0) == 70) {
      var $64 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 11:
    var $64 = $61;
    __label__ = 12;
    break;
   case 12:
    var $64;
    var $65 = ($18 - 149 | 0) >>> 0 < 2;
    var $66 = __ZNK2js13BytecodeRange7frontPCEv($15);
    var $67 = __ZNK2js13BytecodeRange11frontOffsetEv($15);
    var $68 = $65 ? 4 : 2;
    var $71 = HEAPU8[$66 + 1 | 0] & 255;
    if ($65) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $96 = (HEAPU8[$66 + 2 | 0] & 255) << 16 | $71 << 24 | HEAPU8[$66 + 4 | 0] & 255 | (HEAPU8[$66 + 3 | 0] & 255) << 8;
    __label__ = 15;
    break;
   case 14:
    var $96 = (HEAPU8[$66 + 2 | 0] & 255 | $71 << 8) << 16 >> 16;
    __label__ = 15;
    break;
   case 15:
    var $96;
    var $97 = $96 + $67 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $17, $97);
    var $102 = $68 + ($66 + 2) | 0;
    var $105 = (HEAPU8[$66 + ($68 | 1) | 0] & 255) << 8 | HEAPU8[$102] & 255;
    if ($64) {
      __label__ = 16;
      break;
    } else {
      var $ncases_0 = $105;
      var $pc_0 = $102;
      __label__ = 17;
      break;
    }
   case 16:
    var $112 = $68 + ($66 + 4) | 0;
    var $ncases_0 = 1 - ($105 << 16 >> 16) + (((HEAPU8[$68 + ($66 + 3) | 0] & 255) << 8 | HEAPU8[$112] & 255) << 16 >> 16) | 0;
    var $pc_0 = $112;
    __label__ = 17;
    break;
   case 17:
    var $pc_0;
    var $ncases_0;
    if (($ncases_0 | 0) > 0) {
      var $pc_111 = $pc_0;
      var $i1_012 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 18:
    var $i1_012;
    var $pc_111;
    var $pc_2 = $64 ? $pc_111 : $pc_111 + 2 | 0;
    var $124 = HEAPU8[$pc_2 + 1 | 0] & 255;
    if ($65) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $149 = (HEAPU8[$pc_2 + 2 | 0] & 255) << 16 | $124 << 24 | HEAPU8[$pc_2 + 4 | 0] & 255 | (HEAPU8[$pc_2 + 3 | 0] & 255) << 8;
    __label__ = 21;
    break;
   case 20:
    var $149 = (HEAPU8[$pc_2 + 2 | 0] & 255 | $124 << 8) << 16 >> 16;
    __label__ = 21;
    break;
   case 21:
    var $149;
    var $150 = $149 + $67 | 0;
    __ZN16FlowGraphSummary7addEdgeEjj($this, $17, $150);
    var $151 = $pc_2 + $68 | 0;
    var $152 = $i1_012 + 1 | 0;
    if (($152 | 0) == ($ncases_0 | 0)) {
      __label__ = 22;
      break;
    } else {
      var $pc_111 = $151;
      var $i1_012 = $152;
      __label__ = 18;
      break;
    }
   case 22:
    __ZN28BytecodeRangeWithLineNumbers8popFrontEv($r);
    var $153 = __ZNK2js13BytecodeRange5emptyEv($15);
    if ($153) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      var $prevLine_014 = $17;
      var $prevOp_015 = $18;
      __label__ = 5;
      break;
    }
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN16FlowGraphSummary8populateEP9JSContextP8JSScript["X"] = 1;

function __ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript($this, $cx, $script) {
  __ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript($this, $cx, $script);
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2JSL11NumberValueEd($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN28BytecodeRangeWithLineNumbers8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js13BytecodeRange8popFrontEv($1);
    var $2 = __ZNK2js13BytecodeRange5emptyEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16FlowGraphSummaryD1Ev($this) {
  __ZN16FlowGraphSummaryD2Ev($this);
  return;
}

function __ZN16FlowGraphSummaryD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js13BytecodeRange8popFrontEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $4 = HEAP32[$this + 4 >> 2];
  var $5 = $this + 8 | 0;
  var $6 = HEAP32[$5 >> 2];
  var $7 = __ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh($2, $4, $6);
  var $9 = HEAP32[$5 >> 2] + $7 | 0;
  HEAP32[$5 >> 2] = $9;
  return;
}

function __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = $this + 20 | 0;
    var $3 = $this | 0;
    var $4 = $this + 16 | 0;
    var $6 = HEAP32[$2 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $6;
    var $7 = HEAPU8[$6];
    if ($7 << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAPU32[$1 >> 2];
    var $11 = __ZNK2js13BytecodeRange7frontPCEv($3);
    if ($10 >>> 0 > $11 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($7 & 255) > 191) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = ($7 & 255) >>> 3;
    if (($17 | 0) == 23) {
      __label__ = 6;
      break;
    } else if (($17 | 0) == 22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = _js_GetSrcNoteOffset($6, 0);
    HEAP32[$4 >> 2] = $19;
    __label__ = 8;
    break;
   case 7:
    var $22 = HEAP32[$4 >> 2] + 1 | 0;
    HEAP32[$4 >> 2] = $22;
    __label__ = 8;
    break;
   case 8:
    var $23 = HEAPU8[$6];
    if (($23 & 255) > 191) {
      var $29 = 24;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = ($23 & 255) >>> 3;
    __label__ = 10;
    break;
   case 10:
    var $29;
    if (HEAP8[_js_SrcNoteSpec + ($29 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $36 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = _js_SrcNoteLength($6);
    var $36 = $34;
    __label__ = 12;
    break;
   case 12:
    var $36;
    var $37 = $6 + $36 | 0;
    HEAP32[$2 >> 2] = $37;
    var $38 = HEAPU8[$37];
    var $_v = ($38 & 255) > 191 ? 63 : 7;
    HEAP32[$1 >> 2] = $10 + ($_v & ($38 & 255)) | 0;
    var $6 = $37;
    __label__ = 2;
    break;
   case 13:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN28BytecodeRangeWithLineNumbers10updateLineEv["X"] = 1;

function __ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript($this, $cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($1, $cx, $script);
    var $4 = HEAP32[$script + 28 >> 2];
    HEAP32[$this + 16 >> 2] = $4;
    var $5 = $this + 20 | 0;
    var $6 = __ZN8JSScript5notesEv($script);
    HEAP32[$5 >> 2] = $6;
    var $7 = $this + 24 | 0;
    var $9 = HEAPU32[$script >> 2];
    HEAP32[$7 >> 2] = $9;
    var $10 = HEAPU8[$6];
    if ($10 << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_v = ($10 & 255) > 191 ? 63 : 7;
    HEAP32[$7 >> 2] = $9 + ($_v & ($10 & 255)) | 0;
    __label__ = 3;
    break;
   case 3:
    __ZN28BytecodeRangeWithLineNumbers10updateLineEv($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj($this, $incr) {
  var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr);
  return $1;
}

function __ZNK2js13BytecodeRange11frontOpcodeEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $4 = HEAP32[$this + 8 >> 2];
  var $5 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh($2, $4);
  return $5;
}

function __ZN16FlowGraphSummary7addEdgeEjj($this, $sourceLine, $targetOffset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($1, $targetOffset);
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = $sourceLine;
    __label__ = 5;
    break;
   case 3:
    if (($3 | 0) == ($sourceLine | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$2 >> 2] = -2;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    if ((HEAP32[$this + 12 >> 2] - HEAP32[$3 >> 2] | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    var $11 = $10 + ($incr << 2) | 0;
    __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_($10, $11);
    var $13 = HEAP32[$3 >> 2] + $incr | 0;
    HEAP32[$3 >> 2] = $13;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj($bits) {
  return $bits;
}

function __ZN8JSScript13isValidOffsetEh($offset) {
  return $offset << 24 >> 24 != -1;
}

function _JSVAL_IS_NULL_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JSVAL_TO_OBJECT_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_OBJECT_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -121) & 1;
}

function _JSVAL_IS_UNDEFINED_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function __ZNK2js2gc4Cell7addressEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj64EE4addrEv($this) {
  return $this;
}

function __ZN8JSObject8asGlobalEv($this) {
  return $this;
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$p_01 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $5 = $p_01 + 4 | 0;
    if (($5 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $5;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript7objectsEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 16 | 0] & 255) | 0;
}

function _PRIVATE_PTR_TO_JSVAL_IMPL($agg_result, $ptr) {
  HEAP32[$agg_result + 4 >> 2] = 0;
  HEAP32[$agg_result >> 2] = $ptr;
  return;
}

function __ZN2js5types10TypeObject11hasAllFlagsEj($this, $flags) {
  return (HEAP32[$this + 12 >> 2] & $flags | 0) == ($flags | 0);
}

function _BOOLEAN_TO_JSVAL_IMPL($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $argv) {
  HEAP32[$agg_result >> 2] = $argv;
  HEAP32[$agg_result + 4 >> 2] = $argc;
  return;
}

function _INT32_TO_JSVAL_IMPL($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZN2js15TempAllocPolicyC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZNK2js12StackSegment4regsEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2JS5ValueeqERKS0_($this, $rhs) {
  var $1 = $this | 0;
  var $3 = $rhs | 0;
  return HEAP32[$1 >> 2] == HEAP32[$3 >> 2] && HEAP32[$1 + 4 >> 2] == HEAP32[$3 + 4 >> 2];
}

function __ZNK2js9FrameRegs2fpEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZNK2js5Shape12isEmptyShapeEv($this) {
  return (HEAP32[$this + 32 >> 2] | 0) == 0;
}

function __ZN2js10AutoLockGCC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js18RuntimeAllocPolicyC2EP9JSContext($this, $cx) {
  var $3 = HEAP32[$cx + 52 >> 2];
  HEAP32[$this >> 2] = $3;
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN16FlowGraphSummaryC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($this, $cx, $id, $value, $getter, $setter, $attrs) {
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 20 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 30;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $value, $getter, $setter, $attrs);
  return $6;
}

function __ZN2JS5Value10setPrivateEPv($this, $ptr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _PRIVATE_PTR_TO_JSVAL_IMPL($1, $ptr);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $id, $vp) {
  var $1 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($this, $cx, $this, $id, $vp);
  return $1;
}

function __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 & 16384 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 ^ 16384;
    HEAP32[$1 >> 2] = $6;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 131072);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $obj, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject11hasLazyTypeEv($obj);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject4typeEv($obj);
    var $6 = __ZN2js5types10TypeObject11hasAllFlagsEj($5, $flags);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($5, $cx, $flags);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIP8JSObjectED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($2);
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti($1, $cx, -16);
  return;
}

function __ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti($this, $cx, $tag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, $tag);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js12ContextStack4regsEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js12StackSegment4regsEv($2);
  return $3;
}

function __ZNK2js8Debugger17observesNewScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 40 | 0] & 1) << 24 >> 24 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js8Debugger7getHookENS0_4HookE($this, 2);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_($beg, $end, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p_0 = $beg;
    __label__ = 2;
    break;
   case 2:
    var $p_0;
    if (($p_0 | 0) == ($end | 0)) {
      var $_0 = $end;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK2JS5ValueeqERKS0_($p_0, $v);
    if ($4) {
      var $_0 = $p_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext5hasfpEv($this) {
  var $1 = $this + 60 | 0;
  var $2 = __ZNK2js12ContextStack5hasfpEv($1);
  return $2;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($2);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack2fpEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js12StackSegment2fpEv($2);
  return $3;
}

function __ZNK2js12StackSegment2fpEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $3 = __ZNK2js9FrameRegs2fpEv($2);
  return $3;
}

function __ZN2js15AutoValueVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti($1, $cx, -12);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti($this, $cx, $tag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $cx, $tag);
  var $3 = $this + 12 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $slot, $value) {
  var $1 = __ZN8JSObject10getSlotRefEj($this, $slot);
  var $2 = $value | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZN8JSObject10getSlotRefEj($this, $slot) {
  var $1 = __ZN8JSObject14getSlotAddressEj($this, $slot);
  return $1;
}

function __ZN8JSObject14getSlotAddressEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13numFixedSlotsEv($this);
    if ($1 >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10fixedSlotsEv($this);
    var $_0 = $4 + ($slot << 3) | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$this + 32 >> 2] + ($slot - $1 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11nativeEmptyEv($this) {
  var $1 = __ZNK8JSObject12lastPropertyEv($this);
  var $2 = __ZNK2js5Shape12isEmptyShapeEv($1);
  return $2;
}

function __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev($this) {
  var $1 = $this + 8 | 0;
  __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($5, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell11arenaHeaderEv($this) {
  var $1 = __ZNK2js2gc4Cell7addressEv($this);
  return $1 & -4096;
}

function __Z18js_InitObjectClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject8asGlobalEv($obj);
    var $2 = __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($1, $cx);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js12GlobalObject18getObjectPrototypeEv($1);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $3 = __ZNK2JS5Value11isUndefinedEv($2);
  return $3 ^ 1;
}

function __ZN10JSFunction19setConstructorClassEPN2js5ClassE($this, $clasp) {
  HEAP32[$this + 64 >> 2] = $clasp;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb135($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    if ((HEAP32[$cx + 132 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $this;
    _JS_SetGlobalObject($5, $6);
    __label__ = 3;
    break;
   case 3:
    var $8 = $this | 0;
    var $9 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, __ZN2js11ObjectClassE, 0, $8);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN8JSObject16setSingletonTypeEP9JSContext($9, $cx);
    var $13 = $9;
    var $14 = $cx;
    var $15 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($13, $14, 0, 1);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($15, $14, __ZN2js11ObjectClassE, 0);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $9, $8);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN8JSObject16setSingletonTypeEP9JSContext($21, $cx);
    var $25 = $21;
    var $26 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($25, $14, 0, 1);
    if (($26 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($26, $14, __ZN2js13FunctionClassE, 0);
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $this;
    var $33 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($14, $25, 0, 0, 16384, $32, 0);
    var $34 = $33;
    if (($33 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $33 + 58 | 0;
    var $39 = HEAP16[$37 >> 1] | 2048;
    HEAP16[$37 >> 1] = $39;
    var $40 = $cx;
    var $41 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($40, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0);
    if (($41 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $41 + 36 | 0;
    var $46 = HEAP8[$44] | 1;
    HEAP8[$44] = $46;
    var $47 = $41 | 0;
    HEAP8[HEAP32[$47 >> 2]] = -59;
    HEAP8[HEAP32[$47 >> 2] + 1 | 0] = 0;
    HEAP32[$33 + 60 >> 2] = $41;
    var $52 = $33;
    var $53 = __ZN8JSObject7getTypeEP9JSContext($52, $cx);
    HEAP32[$53 + 28 >> 2] = $34;
    var $55 = $41 + 37 | 0;
    var $57 = HEAP8[$55] | 4;
    HEAP8[$55] = $57;
    var $58 = $cx + 52 | 0;
    var $62 = HEAP32[HEAP32[$58 >> 2] + 210024 >> 2] | 0;
    var $63 = __ZL12ATOM_TO_JSIDP6JSAtom124($62);
    var $64 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $52, $8);
    if (($64 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $67 = __ZL12JSID_TO_ATOMi($63);
    var $68 = $64;
    var $69 = $67;
    var $70 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($14, $68, 32, 1, 512, $32, $69);
    var $71 = $70;
    if (($70 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($71, __ZN2js11ObjectClassE);
    __ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject($this, $71, $9);
    var $77 = HEAP32[HEAP32[$58 >> 2] + 210028 >> 2] | 0;
    var $78 = __ZL12ATOM_TO_JSIDP6JSAtom124($77);
    var $79 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js13FunctionClassE, $52, $8);
    if (($79 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $82 = __ZL12JSID_TO_ATOMi($78);
    var $83 = $79;
    var $84 = $82;
    var $85 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($14, $83, 34, 1, 512, $32, $84);
    var $86 = $85;
    if (($85 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($86, __ZN2js13FunctionClassE);
    __ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject($this, $86, $52);
    var $89 = $70;
    var $90 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $89, $9);
    if ($90) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 16:
    var $92 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $9, _object_props, _object_methods);
    if ($92) {
      __label__ = 17;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 17:
    var $94 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $89, 0, _object_static_methods);
    if ($94) {
      __label__ = 18;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 18:
    var $96 = $85;
    var $97 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $96, $52);
    if ($97) {
      __label__ = 19;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 19:
    var $99 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $52, 0, __ZN2js16function_methodsE);
    if ($99) {
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 20:
    var $101 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $96, 0, 0);
    if ($101) {
      __label__ = 21;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 21:
    var $103 = __ZN8JSObject15addDataPropertyEP9JSContextijj($8, $cx, $63, 75, 0);
    if (($103 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $106 = __ZN8JSObject15addDataPropertyEP9JSContextijj($8, $cx, $78, 76, 0);
    if (($106 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $112 = HEAP32[HEAP32[$58 >> 2] + 210212 >> 2] | 0;
    var $113 = __ZL12ATOM_TO_JSIDP6JSAtom124($112);
    var $114 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($14, $32, $113, 36, 1, 4096);
    if (($114 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $117 = $114;
    __ZN2js12GlobalObject15setOriginalEvalEP8JSObject($this, $117);
    var $118 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($14, 0, 38, 0, 0, $32, 0);
    var $119 = $118;
    if (($118 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN2js12AutoIdVectorC1EP9JSContext($ids, $14);
    var $122 = $118 | 0;
    var $123 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($122, $14, $ids);
    if ($123) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 26:
    __ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction($this, $119);
    var $125 = __ZN8JSObject21shouldSplicePrototypeEP9JSContext($32, $14);
    if ($125) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    var $127 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($32, $14, $13);
    if ($127) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 28:
    var $129 = __ZNK10JSFunction6scriptEv($33);
    var $130 = $129;
    var $131 = $33;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($40, $130, $131);
    var $_0 = $52;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($ids);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext["X"] = 1;

function __ZNK2js12GlobalObject18getObjectPrototypeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 38);
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  return $3;
}

function __Z20js_InitFunctionClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject8asGlobalEv($obj);
    var $2 = __ZNK2js12GlobalObject32functionObjectClassesInitializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js12GlobalObject20getFunctionPrototypeEv($1);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($1, $cx);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12GlobalObject20getFunctionPrototypeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 39);
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  return $3;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb135($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject16setSingletonTypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] | 196608;
    HEAP32[$4 >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb135($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN8JSObject7getTypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject11hasLazyTypeEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    __ZN8JSObject12makeLazyTypeEP9JSContext($1, $4);
    __label__ = 3;
    break;
   case 3:
    return HEAP32[$this + 36 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom124($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj151($1);
  return $2;
}

function __ZL12JSID_TO_ATOMi($id) {
  var $1 = _JSID_TO_STRING150($id);
  return $1;
}

function __ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject($this, $ctor, $proto) {
  var $1 = $ctor | 0;
  __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, 1, $1, $proto);
  return;
}

function __ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject($this, $ctor, $proto) {
  var $1 = $ctor | 0;
  __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, 2, $1, $proto);
  return;
}

function __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($cx, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $cx + 52 | 0;
    var $7 = HEAP32[HEAP32[$3 >> 2] + 210200 >> 2] | 0;
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom124($7);
    __ZN2JSL11ObjectValueER8JSObject125($1, $proto);
    var $9 = $ctor;
    var $10 = $cx;
    var $11 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $10, $8, $1, 10, 12, 6);
    if (($11 | 0) == 0) {
      var $23 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = HEAP32[HEAP32[$3 >> 2] + 210204 >> 2] | 0;
    var $18 = __ZL12ATOM_TO_JSIDP6JSAtom124($17);
    __ZN2JSL11ObjectValueER8JSObject125($2, $ctor);
    var $19 = $proto;
    var $20 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($19, $10, $18, $2, 10, 12, 0);
    var $23 = ($20 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $23;
    STACKTOP = __stackBase__;
    return $23;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($cx, $obj, $ps, $fs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ps | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $ps;
    var $6 = _JS_DefineProperties($3, $4, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_pre = $cx;
    if (($fs | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $obj;
    var $12 = $fs;
    var $13 = _JS_DefineFunctions($_pre, $11, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $15 = __ZN9JSContext20typeInferenceEnabledEv($_pre_phi);
    if ($15) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZN8JSObject5brandEP9JSContext($obj, $cx);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15addDataPropertyEP9JSContextijj($this, $cx, $id, $slot, $attrs) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($1, $2, $id, 0, 0, $slot, $attrs, 0, 0);
  return $3;
}

function __ZN2js12GlobalObject15setOriginalEvalEP8JSObject($this, $evalobj) {
  var $1 = $this;
  var $2 = __ZN8JSObject10getSlotRefEj($1, 116);
  var $3 = $evalobj;
  __ZN2JS5Value9setObjectER8JSObject($2, $3);
  return;
}

function __ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  var $1 = $cx;
  var $2 = _JS_ReportErrorFlagsAndNumber($1, 0, 2, 0, 252, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction($this, $fun) {
  var $1 = $this;
  var $2 = __ZN8JSObject10getSlotRefEj($1, 111);
  var $3 = $fun;
  __ZN2JS5Value9setObjectER8JSObject($2, $3);
  return;
}

function __ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE($cx, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject16setSingletonTypeEP9JSContext($2, $cx);
    var $6 = __ZN8JSObject8asGlobalEv($2);
    var $7 = $6 | 0;
    var $8 = $6;
    __ZN8JSObject10makeVarObjEv($8);
    __ZN8JSObject19syncSpecialEqualityEv($7);
    var $9 = __ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE($cx, $6);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject125($1, $9);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, 113, $1);
    __ZN2js12GlobalObject8setFlagsEi($6, 0);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19syncSpecialEqualityEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject8getClassEv($1);
    if ((HEAP32[$2 + 68 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] | 2048;
    HEAP32[$8 >> 2] = $10;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE($cx, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $parent | 0;
    var $2 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZN2js20regexp_statics_classE, 0, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v($cx);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = $2;
    __ZN8JSObject10setPrivateEPv($9, $8);
    var $_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject125($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2js12GlobalObject8setFlagsEi($this, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL10Int32ValueEi127($1, $flags);
  var $2 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 117, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12GlobalObject19initStandardClassesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom124($6);
    __ZN2JSL14UndefinedValueEv126($1);
    var $8 = $this;
    var $9 = $cx;
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($8, $9, $7, $1, 10, 12, 6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext($this, $cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __Z17js_InitArrayClassP9JSContextP8JSObject($9, $8);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $cx;
    var $20 = $this;
    var $21 = __Z19js_InitBooleanClassP9JSContextP8JSObject($19, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $cx;
    var $25 = $this;
    var $26 = __Z23js_InitExceptionClassesP9JSContextP8JSObject($24, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $cx;
    var $30 = $this;
    var $31 = __Z16js_InitMathClassP9JSContextP8JSObject($29, $30);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $34 = __Z18js_InitNumberClassP9JSContextP8JSObject($9, $8);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = __Z16js_InitJSONClassP9JSContextP8JSObject($29, $30);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = $cx;
    var $41 = $this;
    var $42 = __Z18js_InitRegExpClassP9JSContextP8JSObject($40, $41);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $45 = $cx;
    var $46 = $this;
    var $47 = __Z18js_InitStringClassP9JSContextP8JSObject($45, $46);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = __Z24js_InitTypedArrayClassesP9JSContextP8JSObject($9, $8);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $53 = __Z17js_InitXMLClassesP9JSContextP8JSObject($40, $41);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $56 = __Z22js_InitIteratorClassesP9JSContextP8JSObject($29, $30);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $59 = $cx;
    var $60 = $this;
    var $61 = __Z16js_InitDateClassP9JSContextP8JSObject($59, $60);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $64 = _js_InitProxyClass($9, $8);
    var $_0 = ($64 | 0) != 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12GlobalObject19initStandardClassesEP9JSContext["X"] = 1;

function __ZN2JSL14UndefinedValueEv126($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js12GlobalObject5clearEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = $this | 0;
    var $7 = __ZN8JSObject7unbrandEP9JSContext($6, $cx);
    var $8 = $this;
    var $key_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $key_01;
    __ZN2JSL14UndefinedValueEv126($1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, $key_01, $1);
    var $10 = $key_01 + 1 | 0;
    if (($10 | 0) == 111) {
      __label__ = 3;
      break;
    } else {
      var $key_01 = $10;
      __label__ = 2;
      break;
    }
   case 3:
    var $12 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($this);
    __ZN2js13RegExpStatics5clearEv($12);
    __ZN2JSL14UndefinedValueEv126($2);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, 115, $2);
    __ZN2JSL14UndefinedValueEv126($3);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, 116, $3);
    __ZN2JSL14UndefinedValueEv126($4);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, 111, $4);
    var $13 = __ZNK8JSObject7getSlotEj($8, 117);
    var $14 = __ZNK2JS5Value7toInt32Ev($13);
    var $15 = $14 | 1;
    __ZN2JSL10Int32ValueEi127($5, $15);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($8, 117, $5);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject7unbrandEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject7brandedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this;
    var $4 = $cx;
    __ZN8JSObject16generateOwnShapeEP9JSContext($3, $4);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $5 = __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_idx_val);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] & -9;
    HEAP32[$8 >> 2] = $10;
    __label__ = 4;
    break;
   case 4:
    __ZN8JSObject10setGenericEv($this);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($globalObj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $resVal = __stackBase__;
  __ZNK2js12GlobalObject16getRegExpStaticsEv($resVal, $globalObj);
  var $1 = __ZNK2JS5Value8toObjectEv($resVal);
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  var $3 = $2;
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js13RegExpStatics5clearEv($this) {
  __ZN2js13RegExpStatics12aboutToWriteEv($this);
  HEAP32[$this + 100 >> 2] = 0;
  HEAP32[$this + 96 >> 2] = 0;
  HEAP32[$this + 92 >> 2] = 0;
  var $4 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($4);
  return;
}

function __ZN2JSL10Int32ValueEi127($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZN8JSObject10getSlotRefEj($2, 115);
    var $4 = __ZNK2JS5Value11isUndefinedEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $cx;
    var $7 = _JS_GetSecurityCallbacks($6);
    if (($7 | 0) == 0) {
      var $18 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$7 + 12 >> 2];
    if (($11 | 0) == 0) {
      var $18 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    var $15 = FUNCTION_TABLE[$14]($cx);
    var $18 = ($15 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $18;
    __ZN2JSL12BooleanValueEb($1, $18);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $3 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    __label__ = 6;
    break;
   case 6:
    var $23 = __ZNK2JS5Value7isFalseEv($3);
    var $24 = $23 ^ 1;
    STACKTOP = __stackBase__;
    return $24;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZNK2JS5Value7isFalseEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_SPECIFIC_BOOLEAN($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($this, $cx, $ctor, $clasp, $name, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $ctor;
    var $3 = $this;
    var $4 = $name;
    var $5 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($1, 0, $2, $length, 512, $3, $4);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($6, $clasp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($this, $cx, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectProto = __stackBase__;
    var $1 = $cx;
    var $2 = $this;
    var $3 = $objectProto;
    var $4 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, $2, 1, $3, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$objectProto >> 2];
    var $8 = __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, $clasp, $7, $this);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, $clasp, $proto, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global | 0;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, $clasp, $proto, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject16setSingletonTypeEP9JSContext($2, $cx);
    var $6 = $2;
    var $7 = $cx;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $7, 0, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $clasp;
    var $12 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($8, $7, $11, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject($this, $cx, $clasp, $proto) {
  var $1 = __ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE($cx, $clasp, $proto, $this);
  return $1;
}

function __ZN8JSObject5brandEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = $cx;
    __ZN8JSObject16generateOwnShapeEP9JSContext($1, $2);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $3 = __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_idx_val);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] | 8;
    HEAP32[$6 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject($cx, $obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  var $3 = $2;
  __ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_($cx, $3);
  return;
}

function __ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject12getDebuggersEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $debuggers = __stackBase__;
    var $1 = $this;
    __ZNK8JSObject15getReservedSlotEj($debuggers, $1, 118);
    var $2 = __ZNK2JS5Value11isUndefinedEv($debuggers);
    if ($2) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($debuggers);
    var $5 = __ZNK8JSObject10getPrivateEv($4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js12GlobalObject12getDebuggersEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123($cx, __ZN2jsL21GlobalDebuggees_classE, 0, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = $6;
    __ZN8JSObject10setPrivateEPv($13, $12);
    __ZN2JSL11ObjectValueER8JSObject125($1, $6);
    var $14 = $this;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($14, 118, $1);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZN9JSContext7malloc_Ej($2, 20);
    if (($3 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_($6, $1);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject11addDebuggerEP9JSContextPNS_8DebuggerE($this, $cx, $dbg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv($1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $this;
    var $7 = __ZNK2js2gc4Cell11compartmentEv($6);
    var $8 = $cx;
    var $9 = $this;
    var $10 = __ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE($7, $8, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($1, $dbg);
    if ($12) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $this;
    var $15 = __ZNK2js2gc4Cell11compartmentEv($14);
    var $16 = $cx;
    var $17 = $this;
    __ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($15, $16, $17, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj151($bits) {
  return $bits;
}

function __ZN2js12ParseMapPool15checkInvariantsEv($this) {
  return;
}

function _JSVAL_IS_SPECIFIC_BOOLEAN($l_0$0, $l_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_TO_STRING150($iden) {
  return $iden;
}

function __ZN7mozilla14AlignedStorageILj80EE4addrEv($this) {
  return $this;
}

function __ZN2js12ParseMapPool9asAtomMapEPv($ptr) {
  return $ptr;
}

function __ZNK2js12DefnOrHeader8isHeaderEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js12DefnOrHeader6headerEv($this) {
  return HEAP32[$this >> 2] & -2;
}

function __ZL26js_IsPropertyCacheDisabledP9JSContext($cx_0_11_val) {
  return HEAPU32[$cx_0_11_val + 209944 >> 2] >>> 0 > 16777215 & 1;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject7brandedEv($this) {
  return (HEAP32[$this + 8 >> 2] & 8 | 0) != 0;
}

function __ZN8JSObject10setGenericEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 16;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js12DefnOrHeader4defnEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = $proto;
    var $15 = __ZNK8JSObject9getParentEv($14);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, undef, $20, $8, $18, 0, $19);
    var $23 = __ZNK2js5Class8isNativeEv($20);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $10, $clasp, $8, $kind);
    if ($25) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $6 = __ZNK8JSObject8numSlotsEv($5);
    if ($4 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $4);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = $type;
    var $14 = $clasp;
    var $15 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($13, $14);
    var $16 = $cx;
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($13, $16, $14, $kind);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 5:
    var $20 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($16, $14);
    var $empty_0_in = $20;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $8 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $8;
    var $9 = __Z16js_NewGCFunctionP9JSContext($cx);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $proto;
    var $15 = __ZNK8JSObject9getParentEv($14);
    var $18 = $15;
    __label__ = 6;
    break;
   case 6:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $9;
    var $21 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($20, undef, $21, $8, $18, 0, $19);
    var $24 = __ZNK2js5Class8isNativeEv($21);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $26 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139($cx, $10, $clasp, $8, $kind);
    if ($26) {
      var $_0 = $10;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($20);
    var $_0 = $10;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_NewGCFunctionP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj($cx, 12, 80);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 28 >> 2] = 2;
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, $kind, $thingSize);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, $kind);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics12aboutToWriteEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$2 + 108 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js13RegExpStatics6copyToERS0_($this, $2);
    HEAP8[HEAP32[$1 >> 2] + 108 | 0] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics6copyToERS0_($this, $dst) {
  var $1 = $dst | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv($1);
  var $2 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($1, $2);
  var $4 = HEAP32[$this + 92 >> 2];
  HEAP32[$dst + 92 >> 2] = $4;
  var $7 = HEAP32[$this + 96 >> 2];
  HEAP32[$dst + 96 >> 2] = $7;
  var $10 = HEAP32[$this + 100 >> 2];
  HEAP32[$dst + 100 >> 2] = $10;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other) {
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE($this, $other) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($other);
  var $2 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($other);
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j($this, $1, $2);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j($this, $insBegin, $length) {
  var $1 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
  var $2 = $insBegin + ($length << 2) | 0;
  __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($1, $insBegin, $2);
  var $3 = $this + 4 | 0;
  var $5 = HEAP32[$3 >> 2] + $length | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZNK2js12GlobalObject16getRegExpStaticsEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 113);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 112);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js13RegExpStaticsC1Ev($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStaticsC1Ev($this) {
  __ZN2js13RegExpStaticsC2Ev($this);
  return;
}

function __ZN2js13RegExpStaticsC2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($2, $1);
  HEAP32[$this + 104 >> 2] = 0;
  HEAP8[$this + 108 | 0] = 0;
  __ZN2js13RegExpStatics5clearEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj80EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 20;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_($this, $key, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  var $3 = $this;
  var $4 = __ZN8JSObject10getSlotRefEj($3, $key);
  var $5 = $key + 37 | 0;
  var $6 = __ZN8JSObject10getSlotRefEj($3, $5);
  var $7 = $key + 74 | 0;
  var $8 = __ZN8JSObject10getSlotRefEj($3, $7);
  __ZN2JSL11ObjectValueER8JSObject125($1, $ctor);
  var $9 = $1 | 0;
  var $10$0 = HEAP32[$9 >> 2];
  var $10$1 = HEAP32[$9 + 4 >> 2];
  var $11 = $4 | 0;
  HEAP32[$11 >> 2] = $10$0;
  HEAP32[$11 + 4 >> 2] = $10$1;
  __ZN2JSL11ObjectValueER8JSObject125($2, $proto);
  var $12 = $2 | 0;
  var $13$0 = HEAP32[$12 >> 2];
  var $13$1 = HEAP32[$12 + 4 >> 2];
  var $14 = $6 | 0;
  HEAP32[$14 >> 2] = $13$0;
  HEAP32[$14 + 4 >> 2] = $13$1;
  var $15$0 = HEAP32[$11 >> 2];
  var $15$1 = HEAP32[$11 + 4 >> 2];
  var $16 = $8 | 0;
  HEAP32[$16 >> 2] = $15$0;
  HEAP32[$16 + 4 >> 2] = $15$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12ParseMapPool8purgeAllEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv($1);
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_01 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $it_01;
    var $5 = HEAP32[$it_01 >> 2];
    var $6 = __ZN2js12ParseMapPool9asAtomMapEPv($5);
    __ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_(undef, $6);
    var $7 = $it_01 + 4 | 0;
    if (($7 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $it_01 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($1);
    var $9 = $this + 140 | 0;
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($9);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv($this);
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    var $5 = $this + 12 | 0;
    var $6 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($5);
    HEAP32[$this >> 2] = $6;
    HEAP32[$this + 8 >> 2] = 32;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool13allocateFreshEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this | 0;
    var $3 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv($2);
    var $4 = $3 + 1 | 0;
    var $5 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($2, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = $this + 140 | 0;
    var $8 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($7, $4);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$this + 280 >> 2];
    var $12 = __ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_($11, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $12;
    HEAP32[$1 >> 2] = $15;
    __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($2, $1);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 228);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($this, $t) {
  var $1 = HEAP32[$t >> 2];
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_($this, $1);
  return;
}

function __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 8 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $25 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($25);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $27 = $_p_0;
    __ZN2js12AtomDeclNodeC1EP12JSDefinition($27, $defn);
    var $_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AtomDeclNodeC1EP12JSDefinition($this, $defn) {
  __ZN2js12AtomDeclNodeC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $atom;
    var $4 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAP32[$7 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $8, $1);
    var $9 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$7 >> 2];
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($2, $4);
    var $13 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($12, $p, $1, $2);
    var $_0 = $13;
    __label__ = 8;
    break;
   case 4:
    var $15 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    var $16 = __ZNK2js12DefnOrHeader8isHeaderEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2js12DefnOrHeader6headerEv($15);
    var $toShadow_0 = $18;
    __label__ = 7;
    break;
   case 6:
    var $20 = __ZNK2js12DefnOrHeader4defnEv($15);
    var $21 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $toShadow_0 = $21;
      __label__ = 7;
      break;
    }
   case 7:
    var $toShadow_0;
    HEAP32[$4 + 4 >> 2] = $toShadow_0;
    var $25 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($3, $4);
    var $27 = HEAP32[$3 >> 2];
    HEAP32[$25 >> 2] = $27;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $9 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($9 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($agg_result, $9, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $17 = HEAP32[$value >> 2];
    var $18 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$18 >> 2] = $17;
    var $19 = $this + 4 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    var $22 = $this | 0;
    var $24 = HEAP32[$22 >> 2] + 1 | 0;
    HEAP32[$22 >> 2] = $24;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $26 = $this + 200 | 0;
    var $27 = $p | 0;
    var $28 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($26, $27, $key, $value);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($this, $node) {
  __ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE($this, $node);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($10);
    var $_0 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE($this, $doh) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js12DefnOrHeader8isHeaderEv($doh);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js12DefnOrHeader6headerEv($doh);
    var $last_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $last_0;
    var $7 = HEAP32[$last_0 + 4 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = $last_0;
      __label__ = 6;
      break;
    } else {
      var $last_0 = $7;
      __label__ = 3;
      break;
    }
   case 4:
    var $10 = __ZNK2js12DefnOrHeader4defnEv($doh);
    var $11 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($1, $11);
    var $15 = HEAP32[$1 >> 2];
    HEAP32[$doh >> 2] = $15;
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $3 = __ZN2js9AtomDecls9allocNodeEP12JSDefinition($this, $defn);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 4 | 0;
    var $7 = HEAP32[$6 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $7, $1);
    var $8 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    var $12 = __ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE($this, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$12 + 4 >> 2] = $3;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $17 = HEAP32[$6 >> 2];
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($2, $3);
    var $18 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($17, $p, $1, $2);
    var $_0 = $18;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($this, $cx) {
  __ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  var $4 = $this + 200 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($4, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZNK7mozilla14AlignedStorageILj128EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj128EE4addrEv($this) {
  return $this;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP6JSAtomEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12DefnOrHeaderC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($e) {
  return $e | 0;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this) {
  return HEAPU32[$this >> 2] >>> 0 > 24;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv($this) {
  return (HEAP32[$this + 24 >> 2] | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_($8, $11, $12);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($this) {
  __ZN2js9InlineMapIP6JSAtomjLj24EED2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EED2Ev($this) {
  var $1 = $this + 200 | 0;
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = HEAP32[$v >> 2];
    var $9 = $5 + 4 | 0;
    HEAP32[$9 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE($27, $1);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_($1, $8);
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_($2, $9);
  var $10 = __ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev($2);
  var $12 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $12;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP6JSAtomEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_($this, $t);
  return;
}

function __ZN2js7MoveRefIP6JSAtomEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP6JSAtomEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12DefnOrHeaderC1Ev($2);
  return;
}

function __ZN2js12DefnOrHeaderC1Ev($this) {
  __ZN2js12DefnOrHeaderC2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($1);
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv($1);
  return $2;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj($1, $len);
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($3);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv($1);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($11);
    var $14 = $12;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($2);
  return $3;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZN2js10StackFrame10prevpcSlowEPPNS_13JSInlinedSiteE($this, $pinlined) {
  return 0;
}

function __ZN2js12ContextStackD2Ev($this) {
  return;
}

function __ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_($t1, $t2) {
  var $2 = $t1 >>> 0 > $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE($this, $node) {
  HEAP32[$this >> 2] = $node | 1;
  return;
}

function __ZN2js12AtomDeclNodeC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = $defn;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js9FrameRegs7inlinedEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js10StackFrame10annotationEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 131072 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$this + 48 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame13setAnnotationEPv($this, $annot) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 131072;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 48 >> 2] = $annot;
  return;
}

function __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 524288;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __Z16js_IsNamedLambdaP10JSFunction($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = (HEAP32[$fun + 72 >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject17isNormalArgumentsEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js26NormalArgumentsObjectClassE | 0);
}

function __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($this, $pinlined) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1048576 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($pinlined | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 36 >> 2];
    HEAP32[$pinlined >> 2] = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0 = HEAP32[$this + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment10slotsBeginEv($this) {
  return $this + 16 | 0;
}

function __ZNK2js8CallArgs3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 3) | 0;
}

function __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($this, $regs) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $regs;
  return $2;
}

function __ZN2js12StackSegment7popRegsEPNS_9FrameRegsE($this, $regs) {
  HEAP32[$this + 8 >> 2] = $regs;
  return;
}

function __ZN2js12StackSegment8pushCallERNS_12CallArgsListE($this, $callList) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$callList + 8 >> 2] = $2;
  HEAP32[$1 >> 2] = $callList;
  return;
}

function __ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE($this, $callList) {
  HEAP32[$this + 12 >> 2] = $callList;
  return;
}

function __ZN2js12StackSegment7popCallEv($this) {
  var $1 = $this + 12 | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZN2js10StackSpaceC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZNK2js12StackSegment12prevInMemoryEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js10StackFrame5slotsEv($this) {
  return $this + 56 | 0;
}

function __ZNK9JSRuntime17trustedPrincipalsEv($this) {
  return HEAP32[$this + 209940 >> 2];
}

function __ZN2js10StackSpace13committedSizeEv($this) {
  return HEAP32[$this + 16 >> 2] - HEAP32[$this + 4 >> 2] | 0;
}

function __ZN2js12ContextStack11threadResetEv($this) {
  var $5 = HEAP32[HEAP32[$this + 8 >> 2] + 52 >> 2] + 144284 | 0;
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZNK2js12StackSegment13prevInContextEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js12StackSegment10maybeCallsEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE($this, $script, $prev, $regs, $thisv, $scopeChain, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $type | 1572864;
    var $3 = $this | 0;
    HEAP32[$3 >> 2] = $2;
    if (($type & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$prev >> 2] & 3 | $2;
    HEAP32[$3 >> 2] = $10;
    __label__ = 3;
    break;
   case 3:
    var $12 = $this - 56 + 40 | 0;
    var $14 = $thisv | 0;
    var $15 = $12 + 8 | 0;
    var $st$4$0 = $14 | 0;
    var $16$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $14 + 4 | 0;
    var $16$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $15 | 0;
    HEAP32[$st$8$0 >> 2] = $16$0;
    var $st$8$1 = $15 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $16$1;
    var $17 = $this;
    var $18 = __ZNK2js10StackFrame15isFunctionFrameEv($17);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = $prev;
    var $21 = __ZNK2js10StackFrame7calleevEv($20);
    var $22 = $21 | 0;
    var $23 = $12;
    var $st$4$0 = $22 | 0;
    var $24$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $22 + 4 | 0;
    var $24$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $23 | 0;
    HEAP32[$st$8$0 >> 2] = $24$0;
    var $st$8$1 = $23 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $24$1;
    var $26 = HEAP32[$prev + 4 >> 2];
    HEAP32[$this + 4 >> 2] = $26;
    HEAP32[$this + 8 >> 2] = $script;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL9NullValueEv158($1);
    var $30 = $1 | 0;
    var $31 = $12;
    var $32$0 = HEAP32[$30 >> 2];
    var $32$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$31 >> 2] = $32$0;
    HEAP32[$31 + 4 >> 2] = $32$1;
    HEAP32[$this + 4 >> 2] = $script;
    __label__ = 6;
    break;
   case 6:
    HEAP32[$this + 12 >> 2] = $scopeChain;
    HEAP32[$this + 16 >> 2] = $prev;
    if (($regs | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $40 = HEAP32[$regs + 4 >> 2];
    HEAP32[$this + 32 >> 2] = $40;
    var $42 = __ZNK2js9FrameRegs7inlinedEv($regs);
    var $45 = $42;
    __label__ = 9;
    break;
   case 8:
    HEAP32[$this + 32 >> 2] = 2989;
    var $45 = 0;
    __label__ = 9;
    break;
   case 9:
    var $45;
    HEAP32[$this + 36 >> 2] = $45;
    if (($prev | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = __ZNK2js10StackFrame10annotationEv($prev);
    if (($49 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js10StackFrame13setAnnotationEPv($this, $49);
    __label__ = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE["X"] = 1;

function __ZN2JSL9NullValueEv158($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject($this, $cx, $chain) {
  __ZN2jsL7PodZeroINS_10StackFrameEEEvPT_($this);
  HEAP32[$this >> 2] = 1572868;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($this, $chain);
  return;
}

function __ZN2jsL7PodZeroINS_10StackFrameEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 56, 1);
  return;
}

function __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext9maybeRegsEv($cx);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZNK2js9FrameRegs2fpEv($4);
    HEAP32[$this + 16 >> 2] = $5;
    var $9 = HEAP32[$1 + 4 >> 2];
    HEAP32[$this + 32 >> 2] = $9;
    var $11 = __ZNK2js9FrameRegs7inlinedEv($1);
    HEAP32[$this + 36 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$this + 16 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($this, $vp, $otherfp, $othervp, $othersp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = $othersp - $othervp >> 3;
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($vp, $othervp, $4);
    var $5 = $this;
    var $6 = __ZNK2js10StackFrame10hasCallObjEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame7callObjEv($this);
    var $9 = $this;
    var $10 = $8;
    __ZN8JSObject10setPrivateEPv($10, $9);
    var $11 = $otherfp | 0;
    var $13 = HEAP32[$11 >> 2] & -16385;
    HEAP32[$11 >> 2] = $13;
    var $14 = __ZNK2js10StackFrame3funEv($5);
    var $15 = $14;
    var $16 = __Z16js_IsNamedLambdaP10JSFunction($15);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $18 = __ZNK8JSObject9getParentEv($10);
    __ZN8JSObject10setPrivateEPv($18, $9);
    __label__ = 4;
    break;
   case 4:
    var $20 = __ZNK2js10StackFrame10hasArgsObjEv($5);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $22 = __ZNK2js10StackFrame7argsObjEv($5);
    var $23 = $22;
    var $24 = __ZNK8JSObject17isNormalArgumentsEv($23);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $26 = $22;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($26, $this);
    __label__ = 7;
    break;
   case 7:
    var $27 = $otherfp | 0;
    var $29 = HEAP32[$27 >> 2] & -32769;
    HEAP32[$27 >> 2] = $29;
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $_03 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame7callObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
    var $pobj_01 = $2;
    var $3 = __ZNK8JSObject6isCallEv($pobj_01);
    if ($3) {
      var $pobj_0_in_lcssa = $2;
      __label__ = 3;
      break;
    } else {
      var $pobj_0_in2 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $pobj_0_in2;
    var $4 = __ZNK8JSObject9getParentEv($pobj_0_in2);
    var $pobj_0 = $4;
    var $5 = __ZNK8JSObject6isCallEv($pobj_0);
    if ($5) {
      var $pobj_0_in_lcssa = $4;
      __label__ = 3;
      break;
    } else {
      var $pobj_0_in2 = $4;
      __label__ = 2;
      break;
    }
   case 3:
    var $pobj_0_in_lcssa;
    var $6 = __ZN8JSObject6asCallEv($pobj_0_in_lcssa);
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($this, $frame) {
  var $1 = $frame;
  var $2 = $this;
  __ZN8JSObject10setPrivateEPv($2, $1);
  return;
}

function __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($this, $stack, $next, $pinlined) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $stack;
    var $2 = __ZNK2js12ContextStack5spaceEv($1);
    var $3 = $2;
    var $4 = __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($3, $this);
    var $5 = $4;
    var $6 = __ZNK2js12StackSegment4regsEv($5);
    var $7 = $6;
    var $8 = __ZNK2js9FrameRegs2fpEv($6);
    if (($8 | 0) == ($this | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if (($pinlined | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = __ZNK2js9FrameRegs7inlinedEv($7);
    HEAP32[$pinlined >> 2] = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0 = HEAP32[$6 + 4 >> 2];
    __label__ = 8;
    break;
   case 5:
    if (($next | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $next;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($4, $this);
    var $_01 = $21;
    __label__ = 7;
    break;
   case 7:
    var $_01;
    var $23 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($_01, $pinlined);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($this, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $s_0 = HEAP32[$this >> 2];
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    if (($s_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($s_0, $target);
    if ($6) {
      var $_0 = $s_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js12StackSegment12prevInMemoryEv($s_0);
    var $s_0 = $8;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($this, $f) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12StackSegment2fpEv($1);
    var $next_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $next_0;
    var $6 = __ZNK2js10StackFrame4prevEv($next_0);
    var $7 = $6;
    if (($7 | 0) == ($f | 0)) {
      __label__ = 3;
      break;
    } else {
      var $next_0 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    return $next_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($this, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js12StackSegment10slotsBeginEv($this);
    if ($1 >>> 0 < $2 >>> 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js12StackSegment7maybefpEv($this);
    var $8 = $5 >>> 0 >= $fp >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment7maybefpEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 8 >> 2];
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = __ZNK2js9FrameRegs2fpEv($5);
    var $9 = $6;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment8containsEPKNS_9FrameRegsE($this, $regs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($regs | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $regs;
    var $4 = __ZNK2js9FrameRegs2fpEv($3);
    var $5 = $4;
    var $6 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($this, $call) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($call | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$this + 12 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $call | 0;
    var $8 = __ZNK2js8CallArgs4argvEv($7);
    var $9 = __ZNK2js12StackSegment10slotsBeginEv($this);
    if ($8 >>> 0 > $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $4 | 0;
    var $13 = __ZNK2js8CallArgs4argvEv($12);
    var $_0 = $8 >>> 0 <= $13 >>> 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StackSegment3endEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $6 = ($5 | 0) != 0;
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$5 >> 2];
    var $11 = $2 | 0;
    var $12 = __ZNK2js8CallArgs3endEv($11);
    var $13 = __ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_($10, $12);
    var $24 = $13;
    __label__ = 8;
    break;
   case 4:
    var $15 = $2 | 0;
    var $16 = __ZNK2js8CallArgs3endEv($15);
    var $24 = $16;
    __label__ = 8;
    break;
   case 5:
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = HEAP32[$5 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $22 = __ZNK2js12StackSegment10slotsBeginEv($this);
    var $24 = $22;
    __label__ = 8;
    break;
   case 8:
    var $24;
    return $24;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpace4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _mmap(0, 4194304, 3, 4098, -1, 0);
    if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = $1;
    HEAP32[$this + 16 >> 2] = $1 + 4194304 | 0;
    var $10 = $1 + 4063232 | 0;
    HEAP32[$this + 12 >> 2] = $10;
    HEAP32[$this + 8 >> 2] = $10;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpaceD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = _munmap($5, 4194304);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpace4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackSpace11firstUnusedEv($this);
    var $5 = $trc;
    var $seg_03 = $2;
    var $nextSegEnd_04 = $4;
    __label__ = 3;
    break;
   case 3:
    var $nextSegEnd_04;
    var $seg_03;
    var $7 = __ZNK2js12StackSegment7maybefpEv($seg_03);
    if ($7 >>> 0 > $seg_03 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $slotsEnd_0_lcssa = $nextSegEnd_04;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $seg_03;
    var $slotsEnd_01 = $nextSegEnd_04;
    var $fp_02 = $7;
    __label__ = 5;
    break;
   case 5:
    var $fp_02;
    var $slotsEnd_01;
    var $11 = $fp_02;
    var $12 = __ZNK2js10StackFrame5slotsEv($fp_02);
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($5, $12, $slotsEnd_01);
    var $13 = $fp_02;
    __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($5, $13);
    var $14 = __ZNK2js10StackFrame4prevEv($13);
    if ($14 >>> 0 > $10 >>> 0) {
      var $slotsEnd_01 = $11;
      var $fp_02 = $14;
      __label__ = 5;
      break;
    } else {
      var $slotsEnd_0_lcssa = $11;
      __label__ = 6;
      break;
    }
   case 6:
    var $slotsEnd_0_lcssa;
    var $17 = $seg_03;
    var $18 = __ZNK2js12StackSegment10slotsBeginEv($seg_03);
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($5, $18, $slotsEnd_0_lcssa);
    var $19 = __ZNK2js12StackSegment12prevInMemoryEv($seg_03);
    if (($19 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $seg_03 = $19;
      var $nextSegEnd_04 = $17;
      __label__ = 3;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace11firstUnusedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js12StackSegment3endEv($2);
    var $10 = $5;
    __label__ = 4;
    break;
   case 3:
    var $10 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $report, $from, $nvals, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($dest | 0) == 12) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $dest;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01 = HEAP32[$cx + 56 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_01;
    if (($_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = HEAP32[$_01 + 4 >> 2];
    var $11 = HEAP32[$cx + 52 >> 2];
    var $12 = __ZNK9JSRuntime17trustedPrincipalsEv($11);
    if (($9 | 0) == ($12 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_in = $this + 16 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_in = $this + 12 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_in;
    if ((HEAP32[$_in >> 2] - $from >> 3 | 0) < ($nvals | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 8:
    if (($report | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($27);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackSpace12tryBumpLimitEP9JSContextPN2JS5ValueEjPS5_($this, $cx, $from, $nvals, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, 1, $from, $nvals, 12);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 8 >> 2];
    HEAP32[$limit >> 2] = $4;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $report, $from, $nvals, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] - $from >> 3 | 0) < ($nvals | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($this, $cx, $report, $from, $nvals, $dest);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStackC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = 0;
  var $5 = HEAP32[$cx + 52 >> 2] + 144284 | 0;
  HEAP32[$this + 4 >> 2] = $5;
  HEAP32[$this + 8 >> 2] = $cx;
  __ZN2js12ContextStack11threadResetEv($this);
  return;
}

function __ZNK2js12ContextStack5onTopEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = __ZNK2js12ContextStack5spaceEv($5);
    var $11 = ($2 | 0) == (HEAP32[$6 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack12containsSlowEPKNS_10StackFrameE($this, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $s_0 = HEAP32[$this >> 2];
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    if (($s_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($s_0, $target);
    if ($6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js12StackSegment13prevInContextEv($s_0);
    var $s_0 = $8;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, $report, $nvars, $extend, $pushedSeg, $dest) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12ContextStack5spaceEv($1);
    var $3 = $2;
    var $4 = __ZNK2js10StackSpace11firstUnusedEv($3);
    var $5 = __ZNK2js12ContextStack5onTopEv($this);
    var $6 = ($extend | 0) == 0;
    if ($6 | $5 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($3, $cx, $report, $4, $nvars, $dest);
    var $_ = $8 ? $4 : 0;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 3:
    var $10 = $nvars + 2 | 0;
    var $11 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($3, $cx, $report, $4, $10, $dest);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$13 >> 2];
    if (($14 | 0) == 0 | $6) {
      var $calls_0 = 0;
      var $regs_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $14;
    var $18 = __ZNK2js12StackSegment9maybeRegsEv($17);
    var $19 = $18;
    var $20 = __ZNK2js12StackSegment10maybeCallsEv($14);
    var $calls_0 = $20;
    var $regs_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $regs_0;
    var $calls_0;
    if (($4 | 0) == 0) {
      var $29 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $4;
    var $25 = __ZNK2js12ContextStack5spaceEv($1);
    var $27 = HEAP32[$25 >> 2];
    __ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($24, $14, $27, $regs_0, $calls_0);
    var $29 = $24;
    __label__ = 8;
    break;
   case 8:
    var $29;
    HEAP32[$13 >> 2] = $29;
    var $30 = __ZNK2js12ContextStack5spaceEv($1);
    HEAP32[$30 >> 2] = $29;
    HEAP8[$pushedSeg] = 1;
    var $32 = HEAP32[$13 >> 2];
    var $33 = __ZNK2js12StackSegment10slotsBeginEv($32);
    var $_0 = $33;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE($initial) {
  return $initial;
}

function __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($u) {
  return $u | 0;
}

function __ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE($this, $stack) {
  HEAP32[$this + 16 >> 2] = $stack;
  return;
}

function __ZNK2js8CallArgs4argcEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($this, $stack) {
  HEAP32[$this >> 2] = $stack;
  return;
}

function __ZNK2js9StackIter8isScriptEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 1;
}

function __ZNK2js9StackIter2fpEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN9JSContext14setCompartmentEP13JSCompartment($this, $compartment) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 56 >> 2] = $compartment;
    if (($compartment | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP8[$compartment + 376 | 0] & 1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    HEAP8[$this + 232 | 0] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSGenerator13floatingFrameEv($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZN2js10StackFrame22unsetFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -65;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10StackFrame20setFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 64;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js9StackIter10poisonRegsEv($this) {
  HEAP32[$this + 24 >> 2] = 2989;
  HEAP32[$this + 28 >> 2] = 2989;
  return;
}

function __ZNK2js10StackFrame22isFramePushedByExecuteEv($this) {
  return (HEAP32[$this >> 2] & 9 | 0) != 0;
}

function __ZNK2js12CallArgsList4prevEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js12CallReceiver4baseEv($this) {
  return HEAP32[$this >> 2] - 16 | 0;
}

function __ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls) {
  __ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls);
  return;
}

function __ZN2js12ContextStack10popSegmentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZNK2js12StackSegment12prevInMemoryEv($2);
    var $4 = $this;
    var $5 = __ZNK2js12ContextStack5spaceEv($4);
    var $_c = $3;
    HEAP32[$5 >> 2] = $_c;
    var $7 = HEAP32[$1 >> 2];
    var $8 = __ZNK2js12StackSegment13prevInContextEv($7);
    HEAP32[$1 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext27maybeMigrateVersionOverrideEv($12);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext27maybeMigrateVersionOverrideEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext19isVersionOverriddenEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 12 >> 2];
    HEAP32[$this + 8 >> 2] = $4;
    __ZN9JSContext20clearVersionOverrideEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($this, $cx, $argc, $iag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $argc + 2 | 0;
    var $3 = $iag + 20 | 0;
    var $4 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, 1, $2, 1, $3, 12);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($iag);
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($1, $argc, $4);
    var $8 = $1;
    var $9 = $7;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    HEAP32[$9 >> 2] = $10$0;
    HEAP32[$9 + 4 >> 2] = $10$1;
    var $12 = HEAP32[$this >> 2];
    var $13 = $iag | 0;
    __ZN2js12StackSegment8pushCallERNS_12CallArgsListE($12, $13);
    __ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE($iag, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE($this, $iag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    __ZN2js12StackSegment7popCallEv($2);
    if ((HEAP8[$iag + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js12ContextStack10popSegmentEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE($this, $cx, $args, $initial, $ifg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $1 = $args | 0;
    var $2 = __ZNK2js12CallReceiver6calleeEv($1);
    var $3 = __ZNK8JSObject18getFunctionPrivateEv($2);
    var $4 = $3;
    var $5 = __ZNK10JSFunction6scriptEv($3);
    var $6 = $5;
    var $7 = __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE($initial);
    HEAP32[$flags >> 2] = $7;
    var $8 = __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($this, $cx, 1, $args, $4, $6, $flags);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2;
    var $12 = __ZNK2js8CallArgs4argcEv($args);
    var $13 = HEAP32[$flags >> 2];
    __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($8, $cx, $11, $4, $6, $12, $13);
    var $14 = $ifg | 0;
    var $15 = $ifg + 8 | 0;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($15, $8, $6);
    var $17 = HEAP32[$this >> 2];
    var $18 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($17, $15);
    HEAP32[$ifg + 24 >> 2] = $18;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($14, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($this, $cx, $report, $args, $fun, $script, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU16[$fun + 56 >> 1] & 65535;
    var $4 = __ZNK2js8CallArgs3endEv($args);
    var $8 = (HEAPU16[$script + 44 >> 1] & 65535) + 257 | 0;
    var $9 = __ZNK2js8CallArgs4argcEv($args);
    if (($9 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $12 = $this;
    var $13 = __ZNK2js12ContextStack5spaceEv($12);
    var $14 = $13;
    var $15 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($14, $cx, $report, $4, $8, 12);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $_0 = $4;
    __label__ = 9;
    break;
   case 4:
    var $20 = HEAPU32[$flags >> 2];
    if ($9 >>> 0 < $3 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    HEAP32[$flags >> 2] = $20 | 4096;
    var $23 = __ZNK2js8CallArgs4argcEv($args);
    var $24 = $3 - $23 | 0;
    var $25 = $this;
    var $26 = __ZNK2js12ContextStack5spaceEv($25);
    var $27 = $26;
    var $28 = $24 + $8 | 0;
    var $29 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($27, $cx, $report, $4, $28, 12);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($4, $24);
    var $_0 = $4 + ($24 << 3) | 0;
    __label__ = 9;
    break;
   case 7:
    HEAP32[$flags >> 2] = $20 | 2048;
    var $35 = $3 + 2 | 0;
    var $36 = $this;
    var $37 = __ZNK2js12ContextStack5spaceEv($36);
    var $38 = $37;
    var $39 = $8 + $35 | 0;
    var $40 = __ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment($38, $cx, $report, $4, $39, 12);
    if ($40) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $42 = $args | 0;
    var $43 = __ZNK2js12CallReceiver4baseEv($42);
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j($4, $43, $35);
    var $_0 = $4 + ($35 << 3) | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE["X"] = 1;

function __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($this, $cx, $callee, $fun, $script, $nactual, $flagsArg) {
  HEAP32[$this >> 2] = $flagsArg | 1572866;
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = $nactual;
  var $5 = $callee;
  var $6 = __ZNK8JSObject9getParentEv($5);
  HEAP32[$this + 12 >> 2] = $6;
  HEAP32[$this + 20 >> 2] = 0;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  var $10 = __ZNK2js10StackFrame5slotsEv($this);
  var $13 = HEAPU16[$script + 14 >> 1] & 65535;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($10, $13);
  return;
}

function __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($this, $fp, $script) {
  var $2 = HEAP32[$script >> 2];
  HEAP32[$this + 4 >> 2] = $2;
  var $4 = __ZNK2js10StackFrame5slotsEv($fp);
  HEAP32[$this >> 2] = $4 + ((HEAPU16[$script + 14 >> 1] & 65535) << 3) | 0;
  HEAP32[$this + 12 >> 2] = $fp;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE($this, $cx, $script, $thisv, $scopeChain, $type, $evalInFrame, $efg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = ($evalInFrame | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($iter, $cx, 1);
    __label__ = 3;
    break;
   case 3:
    var $4 = __ZNK2js9StackIter8isScriptEv($iter);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $6 = __ZNK2js9StackIter2fpEv($iter);
    if (($6 | 0) == ($evalInFrame | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $8 = __ZN2js9StackIterppEv($iter);
    __label__ = 3;
    break;
   case 6:
    var $extend_0 = 0;
    var $prev_0 = $evalInFrame;
    var $evalInFrameCalls_0 = HEAP32[$iter + 16 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $13 = __ZNK2js12ContextStack7maybefpEv($this);
    var $extend_0 = 1;
    var $prev_0 = $13;
    var $evalInFrameCalls_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $evalInFrameCalls_0;
    var $prev_0;
    var $extend_0;
    var $18 = (HEAPU16[$script + 44 >> 1] & 65535) + 9 | 0;
    var $19 = $efg | 0;
    var $20 = $efg + 4 | 0;
    var $21 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, 1, $18, $extend_0, $20, 12);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = $21 + 16 | 0;
    var $26 = $this | 0;
    var $28 = HEAP32[$26 >> 2];
    var $29 = __ZNK2js12StackSegment9maybeRegsEv($28);
    var $30 = $29;
    __ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE($25, $script, $prev_0, $30, $thisv, $scopeChain, $type);
    var $31 = __ZNK2js10StackFrame5slotsEv($25);
    var $34 = HEAPU16[$script + 14 >> 1] & 65535;
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($31, $34);
    var $35 = $efg + 8 | 0;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($35, $25, $script);
    if (($evalInFrameCalls_0 | 0) == 0 | $1 ^ 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$26 >> 2];
    __ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE($38, $evalInFrameCalls_0);
    __label__ = 11;
    break;
   case 11:
    var $40 = HEAP32[$26 >> 2];
    var $41 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($40, $35);
    HEAP32[$efg + 24 >> 2] = $41;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($19, $this);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE["X"] = 1;

function __ZN2js9StackIterppEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0 || ($2 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 2) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZN2js9StackIter8popFrameEv($this);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 5;
    break;
   case 3:
    __ZN2js9StackIter7popCallEv($this);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 5;
    break;
   case 4:
    HEAP32[$1 >> 2] = 1;
    __label__ = 5;
    break;
   case 5:
    return $this;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12ContextStack7maybefpEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js12StackSegment7maybefpEv($2);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj($vec, $len) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_($vec, $1);
  return;
}

function __ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE($this, $cx, $dest, $scopeChain, $dfg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dfg + 4 | 0;
    var $2 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, 1, 7, 1, $1, $dest);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $dfg | 0;
    var $6 = $2;
    __ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject($6, $cx, $scopeChain);
    var $7 = $dfg + 8 | 0;
    __ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE($7, $6);
    __ZN9JSContext14setCompartmentEP13JSCompartment($cx, $dest);
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($9, $7);
    HEAP32[$dfg + 24 >> 2] = $10;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($5, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE($this, $fp) {
  HEAP32[$this + 4 >> 2] = 0;
  var $2 = __ZNK2js10StackFrame5slotsEv($fp);
  HEAP32[$this >> 2] = $2;
  HEAP32[$this + 12 >> 2] = $fp;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js12ContextStack8popFrameERKNS_10FrameGuardE($this, $fg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $fg + 8 | 0;
    var $3 = __ZNK2js9FrameRegs2fpEv($2);
    var $4 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2js10StackFrame16functionEpilogueEv($6);
    __label__ = 3;
    break;
   case 3:
    var $9 = HEAP32[$this >> 2];
    var $11 = HEAP32[$fg + 24 >> 2];
    __ZN2js12StackSegment7popRegsEPNS_9FrameRegsE($9, $11);
    if ((HEAP8[$fg + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js12ContextStack10popSegmentEv($this);
    __label__ = 5;
    break;
   case 5:
    var $18 = $this;
    var $19 = __ZNK2js12ContextStack5hasfpEv($18);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext16resetCompartmentEv($23);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16functionEpilogueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 49152 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this;
    var $7 = __ZNK2js10StackFrame10hasCallObjEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z16js_PutCallObjectPN2js10StackFrameE($6);
    __label__ = 6;
    break;
   case 4:
    var $10 = __ZNK2js10StackFrame10hasArgsObjEv($6);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z16js_PutArgsObjectPN2js10StackFrameE($6);
    __label__ = 6;
    break;
   case 6:
    var $13 = __ZNK2js10StackFrame20maintainNestingStateEv($this);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = $this;
    __ZN2js5types15NestingEpilogueEPNS_10StackFrameE($15);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE($this, $cx, $gen, $gfg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSGenerator13floatingFrameEv($gen);
    var $2 = $gen + 32 | 0;
    var $6 = $1 - $2 >> 3;
    var $7 = __ZNK2js10StackFrame8numSlotsEv($1);
    var $9 = $6 + ($7 + 7) | 0;
    var $10 = $gfg + 4 | 0;
    var $11 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $cx, 1, $9, 1, $10, 12);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $gfg | 0;
    var $16 = $11 + ($6 << 3) | 0;
    HEAP32[$gfg + 28 >> 2] = $gen;
    HEAP32[$gfg + 32 >> 2] = $11;
    var $19 = $gen + 8 | 0;
    var $21 = HEAP32[$19 >> 2];
    __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($16, $11, $1, $2, $21);
    __ZN2js10StackFrame18resetGeneratorPrevEP9JSContext($16, $cx);
    __ZN2js10StackFrame22unsetFloatingGeneratorEv($16);
    var $22 = $gfg + 8 | 0;
    __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($22, $19, $16);
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZN2js12StackSegment8pushRegsERNS_9FrameRegsE($24, $22);
    HEAP32[$gfg + 24 >> 2] = $25;
    __ZN2js10FrameGuard9setPushedERNS_12ContextStackE($14, $this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame8numSlotsEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame6scriptEv($1);
  return HEAPU16[$2 + 44 >> 1] & 65535;
}

function __ZN2js10StackFrame18resetGeneratorPrevEP9JSContext($this, $cx) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1048576;
  HEAP32[$1 >> 2] = $3;
  __ZN2js10StackFrame8initPrevEP9JSContext($this, $cx);
  return;
}

function __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($this, $from, $to) {
  HEAP32[$this + 12 >> 2] = $to;
  var $2 = __ZNK2js10StackFrame5slotsEv($to);
  var $4 = HEAP32[$from >> 2];
  var $6 = HEAP32[$from + 12 >> 2];
  var $7 = __ZNK2js10StackFrame5slotsEv($6);
  var $12 = $2 + ($4 - $7 >> 3 << 3) | 0;
  HEAP32[$this >> 2] = $12;
  var $15 = HEAP32[$from + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $15;
  var $18 = HEAP32[$from + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $18;
  return;
}

function __ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE($this, $gfg) {
  var $2 = HEAP32[$gfg + 28 >> 2];
  var $3 = __ZN11JSGenerator13floatingFrameEv($2);
  var $4 = $2 + 32 | 0;
  var $5 = $gfg + 8 | 0;
  var $6 = $5;
  var $7 = __ZNK2js9FrameRegs2fpEv($6);
  var $8 = $7;
  var $10 = HEAP32[$gfg + 32 >> 2];
  var $11 = $2 + 8 | 0;
  __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($11, $5, $3);
  var $13 = HEAP32[$5 >> 2];
  __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($3, $4, $8, $10, $13);
  __ZN2js10StackFrame20setFloatingGeneratorEv($3);
  return;
}

function __ZN2js12ContextStack14saveFrameChainEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pushedSeg = __stackBase__;
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment($this, $2, 1, 0, 0, $pushedSeg, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$1 >> 2];
    __ZN9JSContext16resetCompartmentEv($7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack17restoreFrameChainEv($this) {
  __ZN2js12ContextStack10popSegmentEv($this);
  var $3 = HEAP32[$this + 8 >> 2];
  __ZN9JSContext16resetCompartmentEv($3);
  return;
}

function __ZN2js9StackIter8popFrameEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inline_ = __stackBase__;
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2;
    var $4 = __ZNK2js10StackFrame4prevEv($3);
    var $5 = $4;
    HEAP32[$1 >> 2] = $5;
    var $7 = HEAP32[$this + 20 >> 2];
    var $8 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($7, $5);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $10 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($2, $inline_);
    HEAP32[$this + 28 >> 2] = $10;
    var $12 = __ZNK2js10StackFrame16isGeneratorFrameEv($3);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = __ZNK2js10StackFrame10actualArgsEv($3);
    var $15 = $14 - 16 | 0;
    HEAP32[$this + 24 >> 2] = $15;
    __label__ = 10;
    break;
   case 4:
    var $18 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($3);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = __ZNK2js10StackFrame13actualArgsEndEv($2);
    HEAP32[$this + 24 >> 2] = $20;
    __label__ = 10;
    break;
   case 6:
    var $23 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($2);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $26 = $2 - 56 + 40 | 0;
    HEAP32[$this + 24 >> 2] = $26;
    __label__ = 10;
    break;
   case 8:
    var $29 = $2;
    HEAP32[$this + 24 >> 2] = $29;
    __label__ = 10;
    break;
   case 9:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13actualArgsEndEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = (HEAP32[$this >> 2] & 2048 | 0) == 0;
    var $5 = $this;
    var $6 = __ZNK2js10StackFrame10formalArgsEv($5);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $6 - 16 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZNK2js10StackFrame13numActualArgsEv($5);
    var $_0 = $6 + ($10 << 3) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter7popCallEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZNK2js12CallArgsList4prevEv($2);
    HEAP32[$1 >> 2] = $3;
    var $5 = HEAP32[$this + 20 >> 2];
    var $7 = HEAP32[$this + 12 >> 2];
    var $8 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($5, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $11 = __ZNK2js12CallReceiver4baseEv($10);
    HEAP32[$this + 24 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter18settleOnNewSegmentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 20 >> 2];
    var $4 = __ZNK2js12StackSegment9maybeRegsEv($3);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$this + 24 >> 2] = $8;
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$this + 28 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    __ZN2js9StackIter10poisonRegsEv($this);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $seg) {
  HEAP32[$this + 20 >> 2] = $seg;
  var $2 = __ZNK2js12StackSegment7maybefpEv($seg);
  HEAP32[$this + 12 >> 2] = $2;
  var $4 = __ZNK2js12StackSegment10maybeCallsEv($seg);
  HEAP32[$this + 16 >> 2] = $4;
  __ZN2js9StackIter18settleOnNewSegmentEv($this);
  return;
}

function __ZN8JSString19buildLengthAndFlagsEjj($this, $length, $flags) {
  return $length << 4 | $flags;
}

function __ZNK8JSString12asExtensibleEv($this) {
  return $this;
}

function __ZN8JSString7asFixedEv($this) {
  return $this;
}

function __ZNK2js12CallArgsList6activeEv($this) {
  return (HEAP8[$this + 12 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js12CallReceiver7calleevEv($this) {
  return HEAP32[$this >> 2] - 16 | 0;
}

function __ZNK2js9StackIter4doneEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZNK2js9StackIter10nativeArgsEv($agg_result, $this) {
  var $2 = $this + 32 | 0;
  var $3 = $agg_result;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  return;
}

function __ZNK8JSScript7nestingEv($this) {
  return HEAP32[HEAP32[$this + 100 >> 2] + 12 >> 2];
}

function __ZNK9JSContext19isVersionOverriddenEv($this) {
  return (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN9JSContext20clearVersionOverrideEv($this) {
  HEAP8[$this + 16 | 0] = 0;
  return;
}

function __ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE($this, $prevInContext, $prevInMemory, $regs, $calls) {
  HEAP32[$this >> 2] = $prevInContext;
  HEAP32[$this + 4 >> 2] = $prevInMemory;
  HEAP32[$this + 8 >> 2] = $regs;
  HEAP32[$this + 12 >> 2] = $calls;
  return;
}

function __ZNK8JSObject6isCallEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js9CallClassE | 0);
}

function __ZNK8JSString12isExtensibleEv($this) {
  return (HEAP32[$this >> 2] & 15 | 0) == 12;
}

function __ZNK17JSDependentString4baseEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK8JSString6isRopeEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK18JSExtensibleString8capacityEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK6JSRope9leftChildEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js9StackIter16settleOnNewStateEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $3 = $this + 12 | 0;
    var $4 = $this + 16 | 0;
    var $5 = $this + 4 | 0;
    var $6 = $this + 20 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAPU32[$4 >> 2];
    if (($7 | 0) == 0 & ($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$5 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $15 = HEAP32[$6 >> 2];
    var $16 = __ZNK2js12StackSegment13prevInContextEv($15);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $16);
    __label__ = 2;
    break;
   case 6:
    HEAP32[$this + 8 >> 2] = 0;
    __label__ = 35;
    break;
   case 7:
    var $21 = HEAPU32[$6 >> 2];
    var $22 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($21, $7);
    var $23 = $22 & 1;
    var $24 = __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($21, $9);
    var $containsFrame_0 = $23;
    var $containsCall_0 = $24 & 1;
    __label__ = 8;
    break;
   case 8:
    var $containsCall_0;
    var $containsFrame_0;
    var $27 = $containsFrame_0 << 24 >> 24 != 0;
    var $28 = $containsCall_0 << 24 >> 24 == 0;
    if ($28 & ($27 ^ 1)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 9:
    var $30 = HEAP32[$6 >> 2];
    var $31 = __ZNK2js12StackSegment13prevInContextEv($30);
    HEAP32[$6 >> 2] = $31;
    var $32 = HEAPU32[$3 >> 2];
    var $33 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($31, $32);
    var $34 = $33 & 1;
    var $35 = HEAP32[$4 >> 2];
    var $36 = __ZNK2js12StackSegment8containsEPKNS_12CallArgsListE($31, $35);
    var $37 = $36 & 1;
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 10:
    var $39 = $31;
    var $40 = __ZNK2js12StackSegment2fpEv($39);
    if (($40 | 0) == ($32 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $tmp;
    var $45 = $this;
    for (var $$src = $45 >> 2, $$dest = $44 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($tmp, $31);
    __label__ = 12;
    break;
   case 12:
    var $47 = __ZNK2js9StackIter8isScriptEv($tmp);
    if ($47) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $49 = __ZNK2js9StackIter2fpEv($tmp);
    if (($49 | 0) == (HEAP32[$3 >> 2] | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = __ZN2js9StackIterppEv($tmp);
    __label__ = 12;
    break;
   case 15:
    for (var $$src = $44 >> 2, $$dest = $45 >> 2, $$stop = $$src + 10; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    __label__ = 35;
    break;
   case 16:
    __ZN2js9StackIter18settleOnNewSegmentEv($this);
    var $containsFrame_0 = $34;
    var $containsCall_0 = $37;
    __label__ = 8;
    break;
   case 17:
    if ($27) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $135 = HEAP32[$4 >> 2];
    __label__ = 31;
    break;
   case 19:
    var $_pre1 = HEAPU32[$3 >> 2];
    if ($28) {
      var $62 = $_pre1;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $57 = $_pre1;
    var $58 = HEAPU32[$4 >> 2];
    var $59 = $58 | 0;
    var $60 = __ZNK2js8CallArgs4argvEv($59);
    if ($57 >>> 0 < $60 >>> 0) {
      var $135 = $58;
      __label__ = 31;
      break;
    } else {
      var $62 = $_pre1;
      __label__ = 21;
      break;
    }
   case 21:
    var $62;
    var $63 = $62;
    var $64 = __ZNK2js10StackFrame12isDummyFrameEv($63);
    if ($64) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2js9StackIter8popFrameEv($this);
    __label__ = 2;
    break;
   case 23:
    var $67 = __ZNK2js10StackFrame6scriptEv($63);
    var $68 = $67;
    var $69 = $this + 28 | 0;
    var $70 = HEAP32[$69 >> 2];
    var $71 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh161($68, $70);
    if (($71 | 0) == 108 || ($71 | 0) == 58) {
      __label__ = 24;
      break;
    } else if (($71 | 0) == 79) {
      __label__ = 26;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 24:
    var $73 = HEAPU32[$69 >> 2];
    var $81 = (HEAPU8[$73 + 1 | 0] & 255) << 8 | HEAPU8[$73 + 2 | 0] & 255;
    var $85 = HEAP32[$this + 24 >> 2] + (-2 - $81 << 3) | 0;
    var $86 = HEAP32[$3 >> 2];
    __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($86, $85);
    var $87 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($85);
    if ($87) {
      __label__ = 25;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 25:
    HEAP32[$this + 8 >> 2] = 3;
    var $89 = $this + 32 | 0;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($1, $81, $85);
    var $90 = $1;
    var $91 = $89;
    var $st$6$0 = $90 | 0;
    var $92$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $90 + 4 | 0;
    var $92$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $91 | 0;
    HEAP32[$st$10$0 >> 2] = $92$0;
    var $st$10$1 = $91 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $92$1;
    __label__ = 35;
    break;
   case 26:
    var $95 = HEAPU32[$69 >> 2];
    var $103 = (HEAPU8[$95 + 1 | 0] & 255) << 8 | HEAPU8[$95 + 2 | 0] & 255;
    var $104 = HEAP32[$this >> 2];
    var $106 = HEAP32[$3 >> 2];
    var $107 = __ZNK2js10StackFrame6scriptEv($106);
    var $108 = $104;
    var $109 = _js_ReconstructStackDepth($108, $107, $95);
    var $110 = HEAP32[$3 >> 2];
    var $111 = __ZNK2js10StackFrame4baseEv($110);
    var $_sum = $109 + (-2 - $103) | 0;
    var $113 = $111 + ($_sum << 3) | 0;
    __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($110, $113);
    var $114 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($113);
    if ($114) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $118 = HEAP32[$this + 24 >> 2];
    if (($118 | 0) == ($111 + ($109 << 3) | 0)) {
      var $argc1_0 = $103;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $argc1_0 = $118 - ($111 + ($_sum + 2 << 3)) >> 3;
    __label__ = 29;
    break;
   case 29:
    var $argc1_0;
    HEAP32[$this + 8 >> 2] = 3;
    var $128 = $this + 32 | 0;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($2, $argc1_0, $113);
    var $129 = $2;
    var $130 = $128;
    var $131$0 = HEAP32[$129 >> 2];
    var $131$1 = HEAP32[$129 + 4 >> 2];
    HEAP32[$130 >> 2] = $131$0;
    HEAP32[$130 + 4 >> 2] = $131$1;
    __label__ = 35;
    break;
   case 30:
    HEAP32[$this + 8 >> 2] = 1;
    __label__ = 35;
    break;
   case 31:
    var $135;
    var $136 = __ZNK2js12CallArgsList6activeEv($135);
    if ($136) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $139 = __ZNK2js12CallReceiver7calleevEv($135 | 0);
    var $140 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($139);
    if ($140) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    HEAP32[$this + 8 >> 2] = 2;
    var $145 = HEAP32[$4 >> 2];
    var $146 = $this + 32 | 0;
    var $st$6$0 = $145 | 0;
    var $147$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $145 + 4 | 0;
    var $147$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $146 | 0;
    HEAP32[$st$10$0 >> 2] = $147$0;
    var $st$10$1 = $146 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $147$1;
    __label__ = 35;
    break;
   case 34:
    __ZN2js9StackIter7popCallEv($this);
    __label__ = 2;
    break;
   case 35:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js9StackIter16settleOnNewStateEv["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh161($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame4baseEv($this) {
  var $1 = __ZNK2js10StackFrame5slotsEv($this);
  var $2 = $this;
  var $3 = __ZNK2js10StackFrame6scriptEv($2);
  return $1 + ((HEAPU16[$3 + 14 >> 1] & 65535) << 3) | 0;
}

function __ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE($fp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame5slotsEv($fp);
    if ($1 >>> 0 > $vp >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $fp;
    var $5 = __ZNK2js10StackFrame6scriptEv($4);
    if (($1 + ((HEAPU16[$5 + 44 >> 1] & 65535) << 3) | 0) >>> 0 > $vp >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[2989 >> 2] = 0;
    _JS_Assert(STRING_TABLE.__str156 | 0, STRING_TABLE.__str1157 | 0, 967);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueE($v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction($v, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$fun >> 2];
    var $4 = __ZNK10JSFunction8isNativeEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    STACKTOP = __stackBase__;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($this, $cx, $savedOption) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    HEAP32[$this + 4 >> 2] = $savedOption;
    var $4 = HEAP32[$cx + 60 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE($this, $4);
    __ZN2js9StackIter16settleOnNewStateEv($this);
    __label__ = 4;
    break;
   case 3:
    HEAP32[$this + 8 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9StackItereqERKS0_($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __ZNK2js9StackIter4doneEv($this);
    var $4 = __ZNK2js9StackIter4doneEv($rhs);
    if ($3 | $4) {
      var $20 = $3 ^ $4 ^ 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js9StackIter8isScriptEv($this);
    var $7 = __ZNK2js9StackIter8isScriptEv($rhs);
    if ($6 ^ $7) {
      var $20 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = __ZNK2js9StackIter2fpEv($this);
    var $11 = __ZNK2js9StackIter2fpEv($rhs);
    if (($10 | 0) == ($11 | 0)) {
      var $20 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = 0;
    __label__ = 7;
    break;
   case 6:
    __ZNK2js9StackIter10nativeArgsEv($1, $this);
    var $14 = $1 | 0;
    var $15 = __ZNK2js12CallReceiver4baseEv($14);
    __ZNK2js9StackIter10nativeArgsEv($2, $rhs);
    var $16 = $2 | 0;
    var $17 = __ZNK2js12CallReceiver4baseEv($16);
    var $20 = ($15 | 0) == ($17 | 0);
    __label__ = 7;
    break;
   case 7:
    var $20;
    STACKTOP = __stackBase__;
    return $20;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($this, $space) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$space >> 2];
    HEAP32[$this >> 2] = $3;
    var $4 = $this + 4 | 0;
    if (($3 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js12StackSegment7maybefpEv($3);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    HEAP32[$4 >> 2] = $9;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AllFramesIterppEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $3 = HEAP32[$1 >> 2];
    var $4 = __ZNK2js10StackFrame4prevEv($3);
    var $5 = $4;
    HEAP32[$1 >> 2] = $5;
    var $6 = $this | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZNK2js12StackSegment8containsEPKNS_10StackFrameE($7, $5);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK2js12StackSegment12prevInMemoryEv($7);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    HEAP32[$6 >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK2js12StackSegment7maybefpEv($12);
    HEAP32[$1 >> 2] = $15;
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2js12StackSegment12prevInMemoryEv($12);
    var $12 = $18;
    __label__ = 3;
    break;
   case 6:
    return $this;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction($v, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction($v, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK10JSFunction8isNativeEv($this) {
  var $1 = $this;
  var $2 = __ZNK10JSFunction13isInterpretedEv($1);
  return $2 ^ 1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction($v, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject($v, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$funobj >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($4);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $5 = __ZNK8JSObject10isFunctionEv($3);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame20maintainNestingStateEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame16isGeneratorFrameEv($1);
    if ($4) {
      var $11 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js10StackFrame6scriptEv($1);
    var $7 = $6;
    var $8 = __ZNK8JSScript7nestingEv($7);
    var $11 = ($8 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext9maybeRegsEv($this) {
  var $1 = $this + 60 | 0;
  var $2 = __ZNK2js12ContextStack9maybeRegsEv($1);
  return $2;
}

function __ZNK2js12ContextStack9maybeRegsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = __ZNK2js12StackSegment9maybeRegsEv($5);
    var $9 = $6;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSString7isShortEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
  return ($2 | 0) == 17;
}

function __ZNK2js2gc4Cell12getAllocKindEv($this) {
  var $1 = __ZNK2js2gc4Cell11arenaHeaderEv($this);
  var $2 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($1);
  return $2;
}

function __ZNK8JSString7isFixedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6isFlatEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSString12isExtensibleEv($this);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSString8isInlineEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString7isFixedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$this + 4 >> 2] | 0) == ($this + 8 | 0)) {
      var $11 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSString7isShortEv($this);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSString10isExternalEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
  return ($2 | 0) == 19;
}

function __ZN14JSLinearString4markEP8JSTracer($this, $0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __label__ = 2;
    break;
   case 2:
    var $str_0;
    var $4 = __ZNK2js2gc4Cell14markIfUnmarkedEj($str_0, 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = $str_0 | 0;
    var $7 = __ZNK8JSString11isDependentEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN8JSString11asDependentEv($6);
    var $10 = __ZNK17JSDependentString4baseEv($9);
    var $str_0 = $10;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell14markIfUnmarkedEj($this, $color) {
  var $1 = __ZNK2js2gc4Cell5chunkEv($this);
  var $2 = $1 + 1032192 | 0;
  var $3 = __ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj($2, $this, $color);
  return $3;
}

function __ZN8JSString13charsHeapSizeEPFjPvE($this, $usf) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6isRopeEv($this);
    if ($1) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSString11isDependentEv($this);
    if ($3) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSString12isExtensibleEv($this);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK8JSString12asExtensibleEv($this);
    var $8 = $7 | 0;
    var $9 = __ZNK14JSLinearString5charsEv($8);
    var $10 = $9;
    var $11 = FUNCTION_TABLE[$usf]($10);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $11;
      __label__ = 10;
      break;
    }
   case 5:
    var $14 = __ZNK18JSExtensibleString8capacityEv($7);
    var $_0 = $14 << 1;
    __label__ = 10;
    break;
   case 6:
    var $17 = __ZNK8JSString10isExternalEv($this);
    if ($17) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK8JSString8isInlineEv($this);
    if ($19) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN8JSString7asFixedEv($this);
    var $22 = $21 | 0;
    var $23 = __ZNK14JSLinearString5charsEv($22);
    var $24 = $23;
    var $25 = FUNCTION_TABLE[$usf]($24);
    if (($25 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $25;
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZNK8JSString6lengthEv($this);
    var $_0 = $28 << 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN6JSRope7flattenEP9JSContext($this, $maybecx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $wholeCapacity = __stackBase__;
    var $wholeChars = __stackBase__ + 4;
    var $1 = $this | 0;
    var $2 = __ZNK8JSString6lengthEv($1);
    var $3 = __ZNK6JSRope9leftChildEv($this);
    var $4 = __ZNK8JSString12isExtensibleEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = __ZNK8JSString12asExtensibleEv($3);
    var $7 = __ZNK18JSExtensibleString8capacityEv($6);
    if ($7 >>> 0 < $2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$wholeCapacity >> 2] = $7;
    var $10 = $6 | 0;
    var $11 = __ZNK14JSLinearString5charsEv($10);
    HEAP32[$wholeChars >> 2] = $11;
    var $12 = $6 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $15 = $11 + ($13 >>> 4 << 1) | 0;
    HEAP32[$12 >> 2] = $13 ^ 14;
    var $17 = $this;
    HEAP32[$6 + 8 >> 2] = $17;
    var $pos_1_ph = $15;
    var $str_1_ph = $1;
    var $_pre_phi = $17;
    __label__ = 9;
    break;
   case 4:
    var $20 = __ZL10AllocCharsP9JSContextjPPtPj($maybecx, $2, $wholeChars, $wholeCapacity);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    var $pos_0_ph = HEAP32[$wholeChars >> 2];
    var $str_0_ph = $1;
    __label__ = 6;
    break;
   case 6:
    var $str_0_ph;
    var $pos_0_ph;
    var $23 = $str_0_ph + 4 | 0;
    var $25 = HEAPU32[$23 >> 2];
    HEAP32[$23 >> 2] = $pos_0_ph;
    var $27 = __ZNK8JSString6isRopeEv($25);
    if ($27) {
      var $str_09 = $str_0_ph;
      var $28 = $25;
      __label__ = 7;
      break;
    } else {
      var $str_0_lcssa = $str_0_ph;
      var $_lcssa8 = $25;
      __label__ = 8;
      break;
    }
   case 7:
    var $28;
    var $str_09;
    HEAP32[$28 + 12 >> 2] = $str_09;
    HEAP32[$28 >> 2] = 512;
    var $31 = $28 + 4 | 0;
    var $33 = HEAP32[$31 >> 2];
    HEAP32[$31 >> 2] = $pos_0_ph;
    var $35 = __ZNK8JSString6isRopeEv($33);
    if ($35) {
      var $str_09 = $28;
      var $28 = $33;
      __label__ = 7;
      break;
    } else {
      var $str_0_lcssa = $28;
      var $_lcssa8 = $33;
      __label__ = 8;
      break;
    }
   case 8:
    var $_lcssa8;
    var $str_0_lcssa;
    var $36 = __ZNK8JSString6lengthEv($_lcssa8);
    var $38 = HEAP32[$_lcssa8 + 4 >> 2];
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($pos_0_ph, $38, $36);
    var $pos_1_ph = $pos_0_ph + ($36 << 1) | 0;
    var $str_1_ph = $str_0_lcssa;
    var $_pre_phi = $this;
    __label__ = 9;
    break;
   case 9:
    var $_pre_phi;
    var $str_1_ph;
    var $pos_1_ph;
    var $pos_1 = $pos_1_ph;
    var $str_1 = $str_1_ph;
    __label__ = 10;
    break;
   case 10:
    var $str_1;
    var $pos_1;
    var $42 = HEAP32[$str_1 + 8 >> 2];
    var $43 = __ZNK8JSString6isRopeEv($42);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $45 = $42 + 12 | 0;
    HEAP32[$45 >> 2] = $str_1;
    var $46 = $42 | 0;
    HEAP32[$46 >> 2] = 768;
    var $pos_0_ph = $pos_1;
    var $str_0_ph = $42;
    __label__ = 6;
    break;
   case 12:
    var $48 = __ZNK8JSString6lengthEv($42);
    var $50 = HEAP32[$42 + 4 >> 2];
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($pos_1, $50, $48);
    var $51 = $pos_1 + ($48 << 1) | 0;
    var $52 = $51;
    var $str_2 = $str_1;
    __label__ = 13;
    break;
   case 13:
    var $str_2;
    if (($str_2 | 0) == ($1 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP16[$51 >> 1] = 0;
    var $56 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $2, 12);
    HEAP32[$str_2 >> 2] = $56;
    var $58 = HEAP32[$wholeChars >> 2];
    HEAP32[$str_2 + 4 >> 2] = $58;
    var $_c = HEAP32[$wholeCapacity >> 2];
    HEAP32[$str_2 + 8 >> 2] = $_c;
    var $62 = __ZN8JSString6asFlatEv($1);
    var $_0 = $62;
    __label__ = 16;
    break;
   case 15:
    var $64 = $str_2 | 0;
    var $65 = HEAP32[$64 >> 2];
    var $70 = $52 - HEAP32[$str_2 + 4 >> 2] >> 1;
    var $71 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $70, 2);
    HEAP32[$64 >> 2] = $71;
    HEAP32[$str_2 + 8 >> 2] = $_pre_phi;
    var $74 = HEAP32[$str_2 + 12 >> 2];
    if (($65 | 0) == 512) {
      var $pos_1 = $51;
      var $str_1 = $74;
      __label__ = 10;
      break;
    } else {
      var $str_2 = $74;
      __label__ = 13;
      break;
    }
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN6JSRope7flattenEP9JSContext["X"] = 1;

function __ZL10AllocCharsP9JSContextjPPtPj($maybecx, $length, $chars, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $length + 1 | 0;
    if ($1 >>> 0 > 1048576) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = ($1 >>> 3) + $1 | 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    var $9 = $7;
    __label__ = 4;
    break;
   case 4:
    var $9;
    HEAP32[$capacity >> 2] = $9 - 1 | 0;
    var $11 = $9 << 1;
    if (($maybecx | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN9JSContext7malloc_Ej($maybecx, $11);
    var $18 = $14;
    __label__ = 7;
    break;
   case 6:
    var $16 = __ZN2js11OffTheBooks7malloc_Ej($11);
    var $18 = $16;
    __label__ = 7;
    break;
   case 7:
    var $18;
    HEAP32[$chars >> 2] = $18;
    return ($18 | 0) != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyItEEvPT_PKS1_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 1) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = HEAP16[$_012 >> 1];
    HEAP16[$_03 >> 1] = $5;
    var $6 = $_012 + 2 | 0;
    if (($6 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $6;
      var $_03 = $_03 + 2 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $10 = $dst;
    var $11 = $src;
    var $12 = $nelem << 1;
    _memcpy($10, $11, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSShortString10lengthFitsEj($length) {
  return $length >>> 0 < 12;
}

function __ZNK2js2gc4Cell5chunkEv($this) {
  return $this & -1048576;
}

function __ZNK8JSString6asAtomEv($this) {
  return $this;
}

function __ZNK7mozilla9RangedPtrIKtEdeEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js13StaticStrings15fitsInSmallCharEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c & 65535) | 0;
    var $8 = HEAP8[$4] << 24 >> 24 != -1;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($this, $other) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$other >> 2] | 0);
}

function __ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE($this, $p) {
  var $2 = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $2;
  return $this;
}

function __ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j($this, $p, $start, $length) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN7mozilla9RangedPtrIKtEC2EPS1_j($this, $p, $length) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN2js19PreserveCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this | 0;
  var $5 = HEAP32[$3 >> 2] + 56 | 0;
  HEAP32[$5 >> 2] = $2;
  var $8 = HEAP8[$this + 8 | 0] & 1;
  HEAP8[HEAP32[$3 >> 2] + 232 | 0] = $8;
  return;
}

function __ZN2js19PreserveCompartmentC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $3 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  var $7 = HEAP8[$cx + 232 | 0] & 1;
  HEAP8[$this + 8 | 0] = $7;
  return;
}

function __ZNK2js2gc11ArenaHeader12getAllocKindEv($this) {
  return HEAP32[$this + 12 >> 2] & 255;
}

function __ZN2v88internal6VectorIcEC2EPci($this, $data, $length) {
  HEAP32[$this >> 2] = $data;
  HEAP32[$this + 4 >> 2] = $length;
  return;
}

function __ZNK2v88internal13StringBuilder12is_finalizedEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) < 0;
}

function __ZNK2v88internal6VectorIcEixEi($this, $index) {
  return HEAP32[$this >> 2] + $index | 0;
}

function __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $left, $right) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($left);
    if (($1 | 0) == 0) {
      var $_0 = $right;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($right);
    if (($4 | 0) == 0) {
      var $_0 = $left;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 + $1 | 0;
    var $8 = __ZN13JSShortString10lengthFitsEj($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $10 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZN8JSString8getCharsEP9JSContext($left, $cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN8JSString8getCharsEP9JSContext($right, $cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $10 | 0;
    var $20 = __ZN14JSInlineString4initEj($19, $7);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($20, $13, $1);
    var $21 = $20 + ($1 << 1) | 0;
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($21, $16, $4);
    HEAP16[$20 + ($7 << 1) >> 1] = 0;
    var $_0 = $10 | 0;
    __label__ = 11;
    break;
   case 8:
    if ($7 >>> 0 > 268435455) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $28 = __ZN6JSRope4new_EP9JSContextP8JSStringS3_j($cx, $left, $right, $7);
    var $_0 = $28 | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_NewGCShortStringP9JSContext($cx) {
  var $1 = __Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, 17, 32);
  return $1;
}

function __ZN8JSString8getCharsEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK14JSLinearString5charsEv($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14JSInlineString4initEj($this, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 4);
  HEAP32[$this >> 2] = $1;
  var $4 = $this + 8 | 0;
  HEAP32[$this + 4 >> 2] = $4;
  return $4;
}

function __ZN6JSRope4new_EP9JSContextP8JSStringS3_j($cx, $left, $right, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z14js_NewGCStringP9JSContext($cx);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN6JSRope4initEP8JSStringS1_j($2, $left, $right, $length);
    var $_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17JSDependentString8undependEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK8JSString6lengthEv($1);
    var $4 = ($2 << 1) + 2 | 0;
    var $5 = __ZN9JSContext7malloc_Ej($cx, $4);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $this | 0;
    var $10 = __ZNK14JSLinearString5charsEv($9);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j($6, $10, $2);
    HEAP16[$6 + ($2 << 1) >> 1] = 0;
    var $12 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $2, 4);
    HEAP32[$this >> 2] = $12;
    HEAP32[$this + 4 >> 2] = $6;
    var $15 = __ZN8JSString7asFixedEv($1);
    var $_0 = $15;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK12JSFlatString7isIndexEPj($this, $indexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = __ZNK12JSFlatString6charsZEv($this);
    if (((HEAPU16[$3 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $9 = $this | 0;
    var $10 = __ZNK8JSString6lengthEv($9);
    if ($10 >>> 0 > 10) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN7mozilla9RangedPtrIKtEC1EPS1_j($cp, $3, undef);
    var $13 = $3 + ($10 << 1) | 0;
    __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($end, $13, undef, undef);
    __ZN7mozilla9RangedPtrIKtEppEi($1, $cp, undef);
    var $14 = __ZNK7mozilla9RangedPtrIKtEdeEv($1);
    var $17 = (HEAPU16[$14 >> 1] & 65535) - 48 | 0;
    if (($17 | 0) == 0) {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZNK7mozilla9RangedPtrIKtEdeEv($cp);
    var $21 = HEAPU16[$19 >> 1] & 65535;
    if (($21 - 48 | 0) >>> 0 < 10) {
      var $index_01 = $17;
      var $24 = $21;
      __label__ = 5;
      break;
    } else {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = $17;
      __label__ = 6;
      break;
    }
   case 5:
    var $24;
    var $index_01;
    var $25 = $24 - 48 | 0;
    var $27 = $25 + $index_01 * 10 | 0;
    __ZN7mozilla9RangedPtrIKtEppEi($2, $cp, undef);
    var $28 = __ZNK7mozilla9RangedPtrIKtEdeEv($cp);
    var $30 = HEAPU16[$28 >> 1] & 65535;
    if (($30 - 48 | 0) >>> 0 < 10) {
      var $index_01 = $27;
      var $24 = $30;
      __label__ = 5;
      break;
    } else {
      var $c_1 = $25;
      var $oldIndex_1 = $index_01;
      var $index_1 = $27;
      __label__ = 6;
      break;
    }
   case 6:
    var $index_1;
    var $oldIndex_1;
    var $c_1;
    var $33 = __ZNK7mozilla9RangedPtrIKtEneIS1_EEbRKNS0_IT_EE($cp, $end);
    if ($33) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($oldIndex_1 >>> 0 < 429496729) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($oldIndex_1 | 0) == 429496729 & $c_1 >>> 0 < 6) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$indexp >> 2] = $index_1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK12JSFlatString7isIndexEPj["X"] = 1;

function __ZNK12JSFlatString6charsZEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK14JSLinearString5charsEv($1);
  return $2;
}

function __ZN7mozilla9RangedPtrIKtEC1EPS1_j($this, $p, $length) {
  __ZN7mozilla9RangedPtrIKtEC2EPS1_j($this, $p, undef);
  return;
}

function __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($this, $p, $start, $length) {
  __ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j($this, $p, undef, undef);
  return;
}

function __ZN7mozilla9RangedPtrIKtEppEi($agg_result, $this, $0) {
  var $3 = HEAP32[$this >> 2];
  HEAP32[$agg_result >> 2] = $3;
  var $5 = __ZN7mozilla9RangedPtrIKtEppEv($this);
  return;
}

function __ZNK7mozilla9RangedPtrIKtEneIS1_EEbRKNS0_IT_EE($this, $other) {
  var $1 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($this, $other);
  return $1 ^ 1;
}

function __ZN2js13StaticStrings4initEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sc = __stackBase__;
    var $buffer = __stackBase__ + 12;
    var $buffer2 = __stackBase__ + 16;
    var $buffer5 = __stackBase__ + 24;
    var $4 = HEAP32[HEAP32[$cx + 52 >> 2] >> 2];
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, $4);
    var $5 = $buffer | 0;
    var $6 = $buffer + 2 | 0;
    var $7 = $cx;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < 256) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $buffer2 | 0;
    var $11 = $buffer2 + 2 | 0;
    var $12 = $buffer2 + 4 | 0;
    var $i1_0 = 0;
    __label__ = 6;
    break;
   case 4:
    HEAP16[$5 >> 1] = $i_0 & 65535;
    HEAP16[$6 >> 1] = 0;
    var $15 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $5, 1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($15);
    HEAP32[$this + 17412 + ($i_0 << 2) >> 2] = $18;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $i1_0;
    if ($i1_0 >>> 0 < 4096) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $buffer5 | 0;
    var $24 = $buffer5 + 2 | 0;
    var $25 = $buffer5 + 4 | 0;
    var $26 = $buffer5 + 6 | 0;
    var $i4_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $28 = $i1_0 >>> 6;
    if ($i1_0 >>> 0 < 640) {
      var $34 = 48;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $i1_0 >>> 0 < 2304 ? 87 : 29;
    var $34 = $32;
    __label__ = 10;
    break;
   case 10:
    var $34;
    HEAP16[$10 >> 1] = $34 + $28 & 65535;
    var $37 = $i1_0 & 63;
    if ($37 >>> 0 < 10) {
      var $43 = 48;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = $37 >>> 0 < 36 ? 87 : 29;
    var $43 = $41;
    __label__ = 12;
    break;
   case 12:
    var $43;
    HEAP16[$11 >> 1] = $43 + $37 & 65535;
    HEAP16[$12 >> 1] = 0;
    var $46 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $10, 2);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($46);
    HEAP32[$this + 4 + ($i1_0 << 2) >> 2] = $49;
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 6;
    break;
   case 14:
    var $i4_0;
    if ($i4_0 >>> 0 < 256) {
      __label__ = 15;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    if ($i4_0 >>> 0 < 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $59 = HEAP32[$this + 17412 + ($i4_0 + 48 << 2) >> 2];
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $59;
    __label__ = 26;
    break;
   case 17:
    if ($i4_0 >>> 0 < 100) {
      __label__ = 18;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 18:
    var $64 = Math.floor(($i4_0 >>> 0) / 10);
    var $65 = $64 + 48 | 0;
    if ($65 >>> 0 < 58) {
      var $77 = $64;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($64 - 49 | 0) >>> 0 < 26) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $77 = $64 - 39 | 0;
    __label__ = 23;
    break;
   case 21:
    if ($65 >>> 0 > 64) {
      __label__ = 22;
      break;
    } else {
      var $77 = 255;
      __label__ = 23;
      break;
    }
   case 22:
    var $_ = $65 >>> 0 < 91 ? $64 + 19 | 0 : 255;
    var $77 = $_;
    __label__ = 23;
    break;
   case 23:
    var $77;
    var $79 = ($i4_0 >>> 0) % 10;
    var $82 = ($79 | 48) >>> 0 < 58 ? $79 : 255;
    var $85 = HEAP32[$this + 4 + ($82 + ($77 << 6) << 2) >> 2];
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $85;
    __label__ = 26;
    break;
   case 24:
    var $88 = Math.floor(($i4_0 >>> 0) / 100);
    HEAP16[$23 >> 1] = $88 + 48 & 65535;
    var $91 = Math.floor(($i4_0 >>> 0) / 10);
    HEAP16[$24 >> 1] = (($91 >>> 0) % 10 | 48) & 65535;
    HEAP16[$25 >> 1] = (($i4_0 >>> 0) % 10 | 48) & 65535;
    HEAP16[$26 >> 1] = 0;
    var $98 = __Z17js_NewStringCopyNP9JSContextPKtj($7, $23, 3);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $101 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($98);
    HEAP32[$this + 16388 + ($i4_0 << 2) >> 2] = $101;
    __label__ = 26;
    break;
   case 26:
    var $i4_0 = $i4_0 + 1 | 0;
    __label__ = 14;
    break;
   case 27:
    HEAP8[$this | 0] = 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13StaticStrings4initEP9JSContext["X"] = 1;

function __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($this, $cx, $newCompartment) {
  __ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment($this, $cx, $newCompartment);
  return;
}

function __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($this) {
  var $1 = $this | 0;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] ^ 12;
  HEAP32[$2 >> 2] = $4;
  var $5 = __ZNK8JSString6asAtomEv($1);
  return $5;
}

function __ZN2js19SwitchToCompartmentD1Ev($this) {
  __ZN2js19SwitchToCompartmentD2Ev($this);
  return;
}

function __ZN2js13StaticStrings5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_05;
    var $7 = HEAP32[$this + 17412 + ($i_05 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $7, undef);
    var $8 = $i_05 + 1 | 0;
    if (($8 | 0) == 256) {
      var $i1_03 = 0;
      __label__ = 3;
      break;
    } else {
      var $i_05 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    var $i1_03;
    var $11 = HEAP32[$this + 4 + ($i1_03 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $11, undef);
    var $12 = $i1_03 + 1 | 0;
    if (($12 | 0) == 4096) {
      var $i2_01 = 0;
      __label__ = 4;
      break;
    } else {
      var $i1_03 = $12;
      __label__ = 3;
      break;
    }
   case 4:
    var $i2_01;
    var $15 = HEAP32[$this + 16388 + ($i2_01 << 2) >> 2] | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $15, undef);
    var $16 = $i2_01 + 1 | 0;
    if (($16 | 0) == 256) {
      __label__ = 5;
      break;
    } else {
      var $i2_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StaticStrings8isStaticEP6JSAtom($atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $atom | 0;
    var $2 = __ZNK14JSLinearString5charsEv($1);
    var $3 = $atom | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    if (($4 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($4 | 0) == 2) {
      __label__ = 3;
      break;
    } else if (($4 | 0) == 3) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $_0 = (HEAPU16[$2 >> 1] & 65535) < 256;
    __label__ = 9;
    break;
   case 3:
    var $9 = HEAP16[$2 >> 1];
    var $10 = __ZN2js13StaticStrings15fitsInSmallCharEt($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $13 = HEAP16[$2 + 2 >> 1];
    var $14 = __ZN2js13StaticStrings15fitsInSmallCharEt($13);
    var $_0 = $14;
    __label__ = 9;
    break;
   case 5:
    var $16 = HEAPU16[$2 >> 1];
    var $17 = $16 & 65535;
    if (($16 - 49 & 65535 & 65535) < 9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = HEAPU16[$2 + 2 >> 1];
    var $22 = $21 & 65535;
    if (($21 - 48 & 65535 & 65535) < 10) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $26 = HEAPU16[$2 + 4 >> 1];
    if (($26 - 48 & 65535 & 65535) < 10) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $_0 = ($17 * 100 - 5328 + $22 * 10 + ($26 & 65535) | 0) >>> 0 < 256;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIKtEppEv($this) {
  var $1 = __ZN7mozilla9RangedPtrIKtEpLEj($this, 1);
  return $1;
}

function __ZN7mozilla9RangedPtrIKtEpLEj($this, $inc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN7mozilla9RangedPtrIKtEplEj($1, $this, $inc);
  var $2 = __ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE($this, $1);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrIKtEplEj($agg_result, $this, $inc) {
  var $3 = HEAP32[$this >> 2] + ($inc << 1) | 0;
  __ZNK7mozilla9RangedPtrIKtE6createEPS1_($agg_result, undef, $3);
  return;
}

function __ZNK7mozilla9RangedPtrIKtE6createEPS1_($agg_result, $this, $ptr) {
  __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($agg_result, $ptr, undef, undef);
  return;
}

function __ZN2js19SwitchToCompartmentD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js19PreserveCompartmentD2Ev($1);
  return;
}

function __ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment($this, $cx, $newCompartment) {
  var $1 = $this | 0;
  __ZN2js19PreserveCompartmentC2EP9JSContext($1, $cx);
  var $2 = $cx;
  var $3 = $newCompartment;
  __ZN9JSContext14setCompartmentEP13JSCompartment($2, $3);
  return;
}

function _js_malloc181($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __Z14js_NewGCStringP9JSContext($cx) {
  var $1 = __Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, 18, 16);
  return $1;
}

function __ZN6JSRope4initEP8JSStringS1_j($this, $left, $right, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 1);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $left;
  HEAP32[$this + 8 >> 2] = $right;
  return;
}

function __Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks7malloc_Ej($bytes) {
  var $1 = _js_malloc181($bytes);
  return $1;
}

function __ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj($this, $cell, $color) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $word = __stackBase__;
    var $mask = __stackBase__ + 4;
    __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, 0, $word, $mask);
    var $1 = HEAP32[$word >> 2];
    var $2 = HEAP32[$1 >> 2];
    var $3 = HEAP32[$mask >> 2];
    if (($3 & $2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = $3 | $2;
    HEAP32[$1 >> 2] = $7;
    if (($color | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, $color, $word, $mask);
    var $10 = HEAP32[$word >> 2];
    var $11 = HEAP32[$10 >> 2];
    var $12 = HEAP32[$mask >> 2];
    if (($12 & $11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $12 | $11;
    HEAP32[$10 >> 2] = $16;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, $color, $wordp, $maskp) {
  var $1 = __ZNK2js2gc4Cell7addressEv($cell);
  var $2 = $1 >>> 3;
  var $4 = ($2 & 131071) + $color | 0;
  HEAP32[$maskp >> 2] = 1 << ($2 + $color & 31);
  HEAP32[$wordp >> 2] = $this + ($4 >>> 5 << 2) | 0;
  return;
}

function _V8_Fatal($file, $line, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $arguments = __stackBase__;
    var $1 = HEAP32[_stdout >> 2];
    var $2 = _fflush($1);
    var $3 = HEAP32[_stderr >> 2];
    var $4 = _fflush($3);
    var $6 = HEAP32[__ZL33fatal_error_handler_nesting_depth >> 2] + 1 | 0;
    HEAP32[__ZL33fatal_error_handler_nesting_depth >> 2] = $6;
    if (($6 | 0) < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[_stderr >> 2];
    var $10 = _fprintf($9, STRING_TABLE.__str182 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $file, HEAP32[tempInt + 4 >> 2] = $line, tempInt));
    HEAP32[$arguments >> 2] = arguments[_V8_Fatal.length];
    var $12 = HEAP32[_stderr >> 2];
    var $13 = HEAP32[$arguments >> 2];
    var $14 = _vfprintf($12, $format, $13);
    var $15 = HEAP32[_stderr >> 2];
    var $16 = _fwrite(STRING_TABLE.__str1183 | 0, 4, 1, $15);
    __label__ = 3;
    break;
   case 3:
    __ZN2v88internal2OS5AbortEv();
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal15DoubleToCStringEdPci($v, $buffer, $buflen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $decimal_point = __stackBase__ + 12;
    var $sign = __stackBase__ + 16;
    var $v8_dtoa_buffer = __stackBase__ + 20;
    var $length = __stackBase__ + 40;
    var $1 = __stackBase__ + 44;
    __ZN2v88internal13StringBuilderC1EPci($builder, $buffer, $buflen);
    var $2 = ___fpclassifyd($v);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE._js_NaN_str | 0);
    __label__ = 19;
    break;
   case 3:
    if ($v < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str1185 | 0);
    __label__ = 19;
    break;
   case 5:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE._js_Infinity_str | 0);
    __label__ = 19;
    break;
   case 6:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 48);
    __label__ = 19;
    break;
   case 7:
    var $10 = $v8_dtoa_buffer | 0;
    __ZN2v88internal6VectorIcEC1EPci($1, $10, 18);
    var $11 = __ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_($v, 0, 0, $1, $sign, $length, $decimal_point);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 8:
    if ((HEAP32[$sign >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 45);
    __label__ = 10;
    break;
   case 10:
    var $17 = HEAPU32[$length >> 2];
    var $18 = HEAPU32[$decimal_point >> 2];
    if (($17 | 0) <= ($18 | 0) & ($18 | 0) < 22) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $10);
    var $22 = $18 - $17 | 0;
    __ZN2v88internal13StringBuilder10AddPaddingEci($builder, 48, $22);
    __label__ = 19;
    break;
   case 12:
    var $_off = $18 - 1 | 0;
    if ($_off >>> 0 < 21) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2v88internal13StringBuilder12AddSubstringEPKci($builder, $10, $18);
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 46);
    var $26 = $v8_dtoa_buffer + $18 | 0;
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $26);
    __label__ = 19;
    break;
   case 14:
    if (($18 + 5 | 0) >>> 0 < 6) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, STRING_TABLE.__str3187 | 0);
    var $30 = -$18 | 0;
    __ZN2v88internal13StringBuilder10AddPaddingEci($builder, 48, $30);
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $10);
    __label__ = 19;
    break;
   case 16:
    var $32 = HEAP8[$10];
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, $32);
    if (($17 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 46);
    var $35 = $v8_dtoa_buffer + 1 | 0;
    __ZN2v88internal13StringBuilder9AddStringEPKc($builder, $35);
    __label__ = 18;
    break;
   case 18:
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, 101);
    var $38 = ($18 | 0) > -1 ? 43 : 45;
    __ZN2v88internal13StringBuilder12AddCharacterEc($builder, $38);
    var $_ = ($_off | 0) < 0 ? 1 - $18 | 0 : $_off;
    __ZN2v88internal13StringBuilder10AddIntegerEi($builder, $_);
    __label__ = 19;
    break;
   case 19:
    var $42 = __ZN2v88internal13StringBuilder8FinalizeEv($builder);
    var $_0 = $42;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    __ZN2v88internal13StringBuilderD1Ev($builder);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal15DoubleToCStringEdPci["X"] = 1;

function __ZN2v88internal13StringBuilderC1EPci($this, $buffer, $size) {
  __ZN2v88internal13StringBuilderC2EPci($this, $buffer, $size);
  return;
}

function __ZN2v88internal13StringBuilder12AddCharacterEc($this, $c) {
  var $1 = $this | 0;
  var $2 = $this + 8 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $4 = $3 + 1 | 0;
  HEAP32[$2 >> 2] = $4;
  var $5 = __ZNK2v88internal6VectorIcEixEi($1, $3);
  HEAP8[$5] = $c;
  return;
}

function __ZN2v88internal6VectorIcEC1EPci($this, $data, $length) {
  __ZN2v88internal6VectorIcEC2EPci($this, $data, $length);
  return;
}

function __ZN2v88internal13StringBuilderD1Ev($this) {
  __ZN2v88internal13StringBuilderD2Ev($this);
  return;
}

function __ZN2v88internal13StringBuilderD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2v88internal13StringBuilder12is_finalizedEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2v88internal13StringBuilder8FinalizeEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilderC2EPci($this, $buffer, $size) {
  var $1 = $this | 0;
  __ZN2v88internal6VectorIcEC1EPci($1, $buffer, $size);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2v88internalL15BiggestPowerTenEjiPjPi($number, $number_bits, $power, $exponent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($number_bits | 0) == 32 || ($number_bits | 0) == 31 || ($number_bits | 0) == 30) {
      __label__ = 2;
      break;
    } else if (($number_bits | 0) == 29 || ($number_bits | 0) == 28 || ($number_bits | 0) == 27) {
      __label__ = 4;
      break;
    } else if (($number_bits | 0) == 26 || ($number_bits | 0) == 25 || ($number_bits | 0) == 24) {
      __label__ = 6;
      break;
    } else if (($number_bits | 0) == 23 || ($number_bits | 0) == 22 || ($number_bits | 0) == 21 || ($number_bits | 0) == 20) {
      __label__ = 8;
      break;
    } else if (($number_bits | 0) == 19 || ($number_bits | 0) == 18 || ($number_bits | 0) == 17) {
      __label__ = 10;
      break;
    } else if (($number_bits | 0) == 16 || ($number_bits | 0) == 15 || ($number_bits | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($number_bits | 0) == 13 || ($number_bits | 0) == 12 || ($number_bits | 0) == 11 || ($number_bits | 0) == 10) {
      __label__ = 14;
      break;
    } else if (($number_bits | 0) == 9 || ($number_bits | 0) == 8 || ($number_bits | 0) == 7) {
      __label__ = 16;
      break;
    } else if (($number_bits | 0) == 6 || ($number_bits | 0) == 5 || ($number_bits | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($number_bits | 0) == 3 || ($number_bits | 0) == 2 || ($number_bits | 0) == 1) {
      __label__ = 20;
      break;
    } else if (($number_bits | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 2:
    if ($number >>> 0 > 999999999) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$power >> 2] = 1e9;
    HEAP32[$exponent >> 2] = 9;
    __label__ = 24;
    break;
   case 4:
    if ($number >>> 0 > 99999999) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$power >> 2] = 1e8;
    HEAP32[$exponent >> 2] = 8;
    __label__ = 24;
    break;
   case 6:
    if ($number >>> 0 > 9999999) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$power >> 2] = 1e7;
    HEAP32[$exponent >> 2] = 7;
    __label__ = 24;
    break;
   case 8:
    if ($number >>> 0 > 999999) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$power >> 2] = 1e6;
    HEAP32[$exponent >> 2] = 6;
    __label__ = 24;
    break;
   case 10:
    if ($number >>> 0 > 99999) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$power >> 2] = 1e5;
    HEAP32[$exponent >> 2] = 5;
    __label__ = 24;
    break;
   case 12:
    if ($number >>> 0 > 9999) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$power >> 2] = 1e4;
    HEAP32[$exponent >> 2] = 4;
    __label__ = 24;
    break;
   case 14:
    if ($number >>> 0 > 999) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP32[$power >> 2] = 1e3;
    HEAP32[$exponent >> 2] = 3;
    __label__ = 24;
    break;
   case 16:
    if ($number >>> 0 > 99) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$power >> 2] = 100;
    HEAP32[$exponent >> 2] = 2;
    __label__ = 24;
    break;
   case 18:
    if ($number >>> 0 > 9) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$power >> 2] = 10;
    HEAP32[$exponent >> 2] = 1;
    __label__ = 24;
    break;
   case 20:
    if (($number | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$power >> 2] = 1;
    HEAP32[$exponent >> 2] = 0;
    __label__ = 24;
    break;
   case 22:
    HEAP32[$power >> 2] = 0;
    HEAP32[$exponent >> 2] = -1;
    __label__ = 24;
    break;
   case 23:
    HEAP32[$power >> 2] = 0;
    HEAP32[$exponent >> 2] = 0;
    __label__ = 24;
    break;
   case 24:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internalL15BiggestPowerTenEjiPjPi["X"] = 1;

function __ZN2js7analyzeL7ArgSlotEj($arg) {
  return $arg + 2 | 0;
}

function __ZN2v88internal5DiyFp8MultiplyERKS1_($this, $other) {
  var $1 = $this | 0;
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3$0 = $2$1;
  var $3$1 = 0;
  var $4$0 = HEAP32[$1 >> 2] & -1;
  var $4$1 = $2$1 & 0;
  var $5 = $other | 0;
  var $6$1 = HEAP32[$5 + 4 >> 2];
  var $7$0 = $6$1;
  var $7$1 = 0;
  var $8$0 = HEAP32[$5 >> 2] & -1;
  var $8$1 = $6$1 & 0;
  var $9$0 = (i64Math.multiply($7$0, $7$1, $3$0, $3$1), i64Math.result[0]);
  var $9$1 = i64Math.result[1];
  var $10$0 = (i64Math.multiply($7$0, $7$1, $4$0, $4$1), i64Math.result[0]);
  var $10$1 = i64Math.result[1];
  var $11$0 = (i64Math.multiply($8$0, $8$1, $3$0, $3$1), i64Math.result[0]);
  var $11$1 = i64Math.result[1];
  var $12$0 = (i64Math.multiply($8$0, $8$1, $4$0, $4$1), i64Math.result[0]);
  var $12$1 = i64Math.result[1];
  var $13$0 = $12$1;
  var $13$1 = 0;
  var $14$0 = $11$0 & -1;
  var $14$1 = $11$1 & 0;
  var $15$0 = $10$0 & -1;
  var $15$1 = $10$1 & 0;
  var $16$0 = (i64Math.add($15$0, $15$1, -2147483648, 0), i64Math.result[0]);
  var $16$1 = i64Math.result[1];
  var $17$0 = (i64Math.add($16$0, $16$1, $14$0, $14$1), i64Math.result[0]);
  var $17$1 = i64Math.result[1];
  var $18$0 = (i64Math.add($17$0, $17$1, $13$0, $13$1), i64Math.result[0]);
  var $18$1 = i64Math.result[1];
  var $19$0 = $11$1;
  var $19$1 = 0;
  var $20$0 = $10$1;
  var $21$0 = $18$1;
  var $21$1 = 0;
  var $22$0 = (i64Math.add($20$0, 0, $9$0, $9$1), i64Math.result[0]);
  var $22$1 = i64Math.result[1];
  var $23$0 = (i64Math.add($22$0, $22$1, $19$0, $19$1), i64Math.result[0]);
  var $23$1 = i64Math.result[1];
  var $24$0 = (i64Math.add($23$0, $23$1, $21$0, $21$1), i64Math.result[0]);
  var $24$1 = i64Math.result[1];
  var $27 = $this + 8 | 0;
  var $30 = HEAP32[$other + 8 >> 2] + 64 + HEAP32[$27 >> 2] | 0;
  HEAP32[$27 >> 2] = $30;
  HEAP32[$1 >> 2] = $24$0;
  HEAP32[$1 + 4 >> 2] = $24$1;
  return;
}

__ZN2v88internal5DiyFp8MultiplyERKS1_["X"] = 1;

function __ZNK2v88internal5DiyFp1fEv($this) {
  var $1 = $this | 0;
  return [ HEAP32[$1 >> 2], HEAP32[$1 + 4 >> 2] ];
}

function __ZNK2v88internal5DiyFp1eEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2v88internal5DiyFp5set_fEy($this, $new_value$0, $new_value$1) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $new_value$0;
  HEAP32[$1 + 4 >> 2] = $new_value$1;
  return;
}

function __ZN2v88internal5DiyFp5set_eEi($this, $new_value) {
  HEAP32[$this + 8 >> 2] = $new_value;
  return;
}

function __ZN2v88internal5DiyFp9NormalizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $$emscripten$temp$0$1 = 4194304;
    if ($2$1 >>> 0 < $$emscripten$temp$0$1 >>> 0 || $2$1 >>> 0 == $$emscripten$temp$0$1 >>> 0 && $2$0 >>> 0 < 0 >>> 0) {
      var $f_04$1 = $2$1;
      var $f_04$0 = $2$0;
      var $e_05 = $4;
      __label__ = 3;
      break;
    } else {
      var $f_0_lcssa$1 = $2$1;
      var $f_0_lcssa$0 = $2$0;
      var $e_0_lcssa = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $e_0_lcssa;
    var $f_0_lcssa$0;
    var $f_0_lcssa$1;
    var $$emscripten$temp$1$1 = -1;
    if (($f_0_lcssa$1 | 0) > ($$emscripten$temp$1$1 | 0) || ($f_0_lcssa$1 | 0) == ($$emscripten$temp$1$1 | 0) && $f_0_lcssa$0 >>> 0 > -1 >>> 0) {
      var $f_11$1 = $f_0_lcssa$1;
      var $f_11$0 = $f_0_lcssa$0;
      var $e_12 = $e_0_lcssa;
      __label__ = 4;
      break;
    } else {
      var $f_1_lcssa$1 = $f_0_lcssa$1;
      var $f_1_lcssa$0 = $f_0_lcssa$0;
      var $e_1_lcssa = $e_0_lcssa;
      __label__ = 5;
      break;
    }
   case 3:
    var $e_05;
    var $f_04$0;
    var $f_04$1;
    var $7$0 = $f_04$0 << 10 | 0 >>> 22;
    var $7$1 = $f_04$1 << 10 | $f_04$0 >>> 22;
    var $8 = $e_05 - 10 | 0;
    var $$emscripten$temp$2$1 = 4194304;
    if ($7$1 >>> 0 < $$emscripten$temp$2$1 >>> 0 || $7$1 >>> 0 == $$emscripten$temp$2$1 >>> 0 && $7$0 >>> 0 < 0 >>> 0) {
      var $f_04$1 = $7$1;
      var $f_04$0 = $7$0;
      var $e_05 = $8;
      __label__ = 3;
      break;
    } else {
      var $f_0_lcssa$1 = $7$1;
      var $f_0_lcssa$0 = $7$0;
      var $e_0_lcssa = $8;
      __label__ = 2;
      break;
    }
   case 4:
    var $e_12;
    var $f_11$0;
    var $f_11$1;
    var $10$0 = $f_11$0 << 1 | 0 >>> 31;
    var $10$1 = $f_11$1 << 1 | $f_11$0 >>> 31;
    var $11 = $e_12 - 1 | 0;
    var $$emscripten$temp$3$1 = -1;
    if (($10$1 | 0) > ($$emscripten$temp$3$1 | 0) || ($10$1 | 0) == ($$emscripten$temp$3$1 | 0) && $10$0 >>> 0 > -1 >>> 0) {
      var $f_11$1 = $10$1;
      var $f_11$0 = $10$0;
      var $e_12 = $11;
      __label__ = 4;
      break;
    } else {
      var $f_1_lcssa$1 = $10$1;
      var $f_1_lcssa$0 = $10$0;
      var $e_1_lcssa = $11;
      __label__ = 5;
      break;
    }
   case 5:
    var $e_1_lcssa;
    var $f_1_lcssa$0;
    var $f_1_lcssa$1;
    HEAP32[$1 >> 2] = $f_1_lcssa$0;
    HEAP32[$1 + 4 >> 2] = $f_1_lcssa$1;
    HEAP32[$3 >> 2] = $e_1_lcssa;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2v88internal6Double8AsUint64Ev($this) {
  var $1 = $this | 0;
  return [ HEAP32[$1 >> 2], HEAP32[$1 + 4 >> 2] ];
}

function __ZN2v88internal5DiyFpC2Ev($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2v88internal7BitCastIydEET_RKT0_($source) {
  var $1 = $source;
  var $st$1$0 = $1 | 0;
  var $st$1$1 = $1 + 4 | 0;
  return [ HEAPU8[$st$1$0] | HEAPU8[$st$1$0 + 1] << 8 | HEAPU8[$st$1$0 + 2] << 16 | HEAPU8[$st$1$0 + 3] << 24 | 0, HEAPU8[$st$1$1] | HEAPU8[$st$1$1 + 1] << 8 | HEAPU8[$st$1$1 + 2] << 16 | HEAPU8[$st$1$1 + 3] << 24 | 0 ];
}

function __ZN2v88internal5DiyFp8SubtractERKS1_($this, $other) {
  var $1 = $other | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5$0 = (i64Math.subtract($4$0, $4$1, $2$0, $2$1), i64Math.result[0]);
  var $5$1 = i64Math.result[1];
  HEAP32[$3 >> 2] = $5$0;
  HEAP32[$3 + 4 >> 2] = $5$1;
  return;
}

function __ZN2v88internal5DiyFpC2Eyi($this, $f$0, $f$1, $e) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $f$0;
  HEAP32[$1 + 4 >> 2] = $f$1;
  HEAP32[$this + 8 >> 2] = $e;
  return;
}

function __ZN8JSScript7getAtomEj($this, $index) {
  return HEAP32[HEAP32[$this + 56 >> 2] + ($index << 2) >> 2];
}

function __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($buffer, $length, $distance_too_high_w$0, $distance_too_high_w$1, $unsafe_interval$0, $unsafe_interval$1, $rest$0, $rest$1, $ten_kappa$0, $ten_kappa$1, $unit$0, $unit$1) {
  var __stackBase__ = STACKTOP;
  var tempParam = $buffer;
  $buffer = STACKTOP;
  STACKTOP += 8;
  HEAP32[$buffer >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$buffer + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1$0 = (i64Math.subtract($distance_too_high_w$0, $distance_too_high_w$1, $unit$0, $unit$1), i64Math.result[0]);
    var $1$1 = i64Math.result[1];
    var $2$0 = (i64Math.add($unit$0, $unit$1, $distance_too_high_w$0, $distance_too_high_w$1), i64Math.result[0]);
    var $2$1 = i64Math.result[1];
    var $3 = $length - 1 | 0;
    var $_03$1 = $rest$1;
    var $_03$0 = $rest$0;
    __label__ = 2;
    break;
   case 2:
    var $_03$0;
    var $_03$1;
    if ($_03$1 >>> 0 < $1$1 >>> 0 || $_03$1 >>> 0 == $1$1 >>> 0 && $_03$0 >>> 0 < $1$0 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $7$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $_03$0, $_03$1), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    if ($7$1 >>> 0 < $ten_kappa$1 >>> 0 || $7$1 >>> 0 == $ten_kappa$1 >>> 0 && $7$0 >>> 0 < $ten_kappa$0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10$0 = (i64Math.add($_03$0, $_03$1, $ten_kappa$0, $ten_kappa$1), i64Math.result[0]);
    var $10$1 = i64Math.result[1];
    if ($10$1 >>> 0 < $1$1 >>> 0 || $10$1 >>> 0 == $1$1 >>> 0 && $10$0 >>> 0 < $1$0 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13$0 = (i64Math.subtract($1$0, $1$1, $_03$0, $_03$1), i64Math.result[0]);
    var $13$1 = i64Math.result[1];
    var $14$0 = (i64Math.subtract($10$0, $10$1, $1$0, $1$1), i64Math.result[0]);
    var $14$1 = i64Math.result[1];
    if ($13$1 >>> 0 < $14$1 >>> 0 || $13$1 >>> 0 == $14$1 >>> 0 && $13$0 >>> 0 < $14$0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2v88internal6VectorIcEixEi($buffer, $3);
    var $18 = HEAP8[$16] - 1 & 255;
    HEAP8[$16] = $18;
    var $_03$1 = $10$1;
    var $_03$0 = $10$0;
    __label__ = 2;
    break;
   case 7:
    if ($_03$1 >>> 0 < $2$1 >>> 0 || $_03$1 >>> 0 == $2$1 >>> 0 && $_03$0 >>> 0 < $2$0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $21$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $_03$0, $_03$1), i64Math.result[0]);
    var $21$1 = i64Math.result[1];
    if ($21$1 >>> 0 < $ten_kappa$1 >>> 0 || $21$1 >>> 0 == $ten_kappa$1 >>> 0 && $21$0 >>> 0 < $ten_kappa$0 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24$0 = (i64Math.add($_03$0, $_03$1, $ten_kappa$0, $ten_kappa$1), i64Math.result[0]);
    var $24$1 = i64Math.result[1];
    if ($24$1 >>> 0 < $2$1 >>> 0 || $24$1 >>> 0 == $2$1 >>> 0 && $24$0 >>> 0 < $2$0 >>> 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = (i64Math.subtract($2$0, $2$1, $_03$0, $_03$1), i64Math.result[0]);
    var $27$1 = i64Math.result[1];
    var $28$0 = (i64Math.subtract($24$0, $24$1, $2$0, $2$1), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $30$1 = $unit$1 << 1 | $unit$0 >>> 31;
    if (($27$1 >>> 0 > $28$1 >>> 0 || $27$1 >>> 0 == $28$1 >>> 0 && $27$0 >>> 0 > $28$0 >>> 0) | ($30$1 >>> 0 > $_03$1 >>> 0 || $30$1 >>> 0 == $_03$1 >>> 0 && ($unit$0 << 1 | 0 >>> 31) >>> 0 > $_03$0 >>> 0)) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_old$1 = $unit$1 << 1 | $unit$0 >>> 31;
    if ($_old$1 >>> 0 > $_03$1 >>> 0 || $_old$1 >>> 0 == $_03$1 >>> 0 && ($unit$0 << 1 | 0 >>> 31) >>> 0 > $_03$0 >>> 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34$0 = $unit$0 << 2 | 0 >>> 30;
    var $34$1 = $unit$1 << 2 | $unit$0 >>> 30;
    var $35$0 = (i64Math.subtract($unsafe_interval$0, $unsafe_interval$1, $34$0, $34$1), i64Math.result[0]);
    var $35$1 = i64Math.result[1];
    var $_0 = $_03$1 >>> 0 <= $35$1 >>> 0 && ($_03$1 >>> 0 < $35$1 >>> 0 || $_03$0 >>> 0 <= $35$0 >>> 0);
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy["X"] = 1;

function __ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_($low, $w, $high, $buffer, $length, $kappa) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var tempParam = $low;
  $low = STACKTOP;
  STACKTOP += 12;
  HEAP32[$low >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$low + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$low + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var tempParam = $w;
  $w = STACKTOP;
  STACKTOP += 12;
  HEAP32[$w >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$w + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$w + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var tempParam = $high;
  $high = STACKTOP;
  STACKTOP += 12;
  HEAP32[$high >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$high + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$high + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var tempParam = $buffer;
  $buffer = STACKTOP;
  STACKTOP += 8;
  HEAP32[$buffer >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$buffer + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $too_low = __stackBase__;
    var $too_high = __stackBase__ + 12;
    var $unsafe_interval = __stackBase__ + 24;
    var $one = __stackBase__ + 36;
    var $divider = __stackBase__ + 48;
    var $divider_exponent = __stackBase__ + 52;
    var $1 = __stackBase__ + 56;
    var $2 = __stackBase__ + 64;
    var $3 = __stackBase__ + 76;
    var $4 = __stackBase__ + 84;
    var $5 = __ZNK2v88internal5DiyFp1fEv($low);
    var $5$0 = $5[0];
    var $5$1 = $5[1];
    var $6$0 = (i64Math.add($5$0, $5$1, -1, -1), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    var $7 = __ZNK2v88internal5DiyFp1eEv($low);
    __ZN2v88internal5DiyFpC1Eyi($too_low, $6$0, $6$1, $7);
    var $8 = __ZNK2v88internal5DiyFp1fEv($high);
    var $8$0 = $8[0];
    var $8$1 = $8[1];
    var $9$0 = (i64Math.add($8$0, $8$1, 1, 0), i64Math.result[0]);
    var $9$1 = i64Math.result[1];
    var $10 = __ZNK2v88internal5DiyFp1eEv($high);
    __ZN2v88internal5DiyFpC1Eyi($too_high, $9$0, $9$1, $10);
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($unsafe_interval, $too_high, $too_low);
    var $11 = __ZNK2v88internal5DiyFp1eEv($w);
    var $13$0 = -$11 | 0;
    var $14 = Runtime.bitshift64(1, 0, "shl", $13$0);
    var $14$0 = $14[0], $14$1 = $14[1];
    __ZN2v88internal5DiyFpC1Eyi($one, $14$0, $14$1, $11);
    var $15 = __ZNK2v88internal5DiyFp1fEv($too_high);
    var $15$0 = $15[0];
    var $15$1 = $15[1];
    var $16 = __ZNK2v88internal5DiyFp1eEv($one);
    var $18$0 = -$16 | 0;
    var $19 = Runtime.bitshift64($15$0, $15$1, "lshr", $18$0);
    var $20 = $19[0];
    var $21 = __ZNK2v88internal5DiyFp1fEv($one);
    var $21$0 = $21[0];
    var $21$1 = $21[1];
    var $22$0 = (i64Math.add($21$0, $21$1, -1, -1), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    var $23$0 = $22$0 & $15$0;
    var $23$1 = $22$1 & $15$1;
    var $24 = $16 + 64 | 0;
    __ZN2v88internalL15BiggestPowerTenEjiPjPi($20, $24, $divider, $divider_exponent);
    var $26 = HEAP32[$divider_exponent >> 2] + 1 | 0;
    HEAP32[$kappa >> 2] = $26;
    HEAP32[$length >> 2] = 0;
    var $integrals_0 = $20;
    var $28 = HEAP32[$kappa >> 2];
    __label__ = 2;
    break;
   case 2:
    var $28;
    var $integrals_0;
    if (($28 | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      var $fractionals_0$1 = $23$1;
      var $fractionals_0$0 = $23$0;
      var $unit_0$1 = 0;
      var $unit_0$0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $31 = HEAPU32[$divider >> 2];
    var $32 = Math.floor(($integrals_0 >>> 0) / ($31 >>> 0));
    var $34 = $32 + 48 & 255;
    var $35 = HEAP32[$length >> 2];
    var $36 = __ZNK2v88internal6VectorIcEixEi($buffer, $35);
    HEAP8[$36] = $34;
    var $38 = HEAP32[$length >> 2] + 1 | 0;
    HEAP32[$length >> 2] = $38;
    var $39 = ($integrals_0 >>> 0) % ($31 >>> 0);
    var $41 = HEAP32[$kappa >> 2] - 1 | 0;
    HEAP32[$kappa >> 2] = $41;
    var $42$0 = $39;
    var $42$1 = 0;
    var $43 = __ZNK2v88internal5DiyFp1eEv($one);
    var $45$0 = -$43 | 0;
    var $46 = Runtime.bitshift64($42$0, $42$1, "shl", $45$0);
    var $46$0 = $46[0], $46$1 = $46[1];
    var $47$0 = (i64Math.add($46$0, $46$1, $23$0, $23$1), i64Math.result[0]);
    var $47$1 = i64Math.result[1];
    var $48 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval);
    var $48$1 = $48[1];
    if ($47$1 >>> 0 < $48$1 >>> 0 || $47$1 >>> 0 == $48$1 >>> 0 && $47$0 >>> 0 < $48[0] >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $51 = $buffer;
    var $52 = $1;
    var $st$2$0 = $51 | 0;
    var $53$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $51 + 4 | 0;
    var $53$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $52 | 0;
    HEAP32[$st$6$0 >> 2] = $53$0;
    var $st$6$1 = $52 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $53$1;
    var $54 = HEAP32[$length >> 2];
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($2, $too_high, $w);
    var $55 = __ZNK2v88internal5DiyFp1fEv($2);
    var $55$0 = $55[0];
    var $55$1 = $55[1];
    var $56 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval);
    var $56$0 = $56[0];
    var $56$1 = $56[1];
    var $57$0 = $31;
    var $57$1 = 0;
    var $58 = __ZNK2v88internal5DiyFp1eEv($one);
    var $60$0 = -$58 | 0;
    var $61 = Runtime.bitshift64($57$0, $57$1, "shl", $60$0);
    var $61$0 = $61[0], $61$1 = $61[1];
    var $62 = __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($1, $54, $55$0, $55$1, $56$0, $56$1, $47$0, $47$1, $61$0, $61$1, 1, 0);
    var $_0 = $62;
    __label__ = 8;
    break;
   case 5:
    var $64 = Math.floor(($31 >>> 0) / 10);
    HEAP32[$divider >> 2] = $64;
    var $integrals_0 = $39;
    var $28 = $41;
    __label__ = 2;
    break;
   case 6:
    var $unit_0$0;
    var $unit_0$1;
    var $fractionals_0$0;
    var $fractionals_0$1;
    var $65$0 = (i64Math.multiply($fractionals_0$0, $fractionals_0$1, 5, 0), i64Math.result[0]);
    var $65$1 = i64Math.result[1];
    var $66$0 = (i64Math.multiply($unit_0$0, $unit_0$1, 5, 0), i64Math.result[0]);
    var $66$1 = i64Math.result[1];
    var $67 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval);
    var $67$0 = $67[0];
    var $67$1 = $67[1];
    var $68$0 = (i64Math.multiply($67$0, $67$1, 5, 0), i64Math.result[0]);
    var $68$1 = i64Math.result[1];
    __ZN2v88internal5DiyFp5set_fEy($unsafe_interval, $68$0, $68$1);
    var $69 = __ZNK2v88internal5DiyFp1eEv($unsafe_interval);
    var $70 = $69 + 1 | 0;
    __ZN2v88internal5DiyFp5set_eEi($unsafe_interval, $70);
    var $71 = __ZNK2v88internal5DiyFp1fEv($one);
    var $71$1 = $71[1];
    var $72$0 = $71[0] >>> 1 | $71$1 << 31;
    var $72$1 = $71$1 >>> 1 | 0 << 31;
    __ZN2v88internal5DiyFp5set_fEy($one, $72$0, $72$1);
    var $73 = __ZNK2v88internal5DiyFp1eEv($one);
    var $74 = $73 + 1 | 0;
    __ZN2v88internal5DiyFp5set_eEi($one, $74);
    var $75 = __ZNK2v88internal5DiyFp1eEv($one);
    var $77$0 = -$75 | 0;
    var $78 = Runtime.bitshift64($65$0, $65$1, "lshr", $77$0);
    var $80 = ($78[0] & 255) + 48 & 255;
    var $81 = HEAP32[$length >> 2];
    var $82 = __ZNK2v88internal6VectorIcEixEi($buffer, $81);
    HEAP8[$82] = $80;
    var $84 = HEAP32[$length >> 2] + 1 | 0;
    HEAP32[$length >> 2] = $84;
    var $85 = __ZNK2v88internal5DiyFp1fEv($one);
    var $85$0 = $85[0];
    var $85$1 = $85[1];
    var $86$0 = (i64Math.add($85$0, $85$1, -1, -1), i64Math.result[0]);
    var $86$1 = i64Math.result[1];
    var $87$0 = $86$0 & $65$0;
    var $87$1 = $86$1 & $65$1;
    var $89 = HEAP32[$kappa >> 2] - 1 | 0;
    HEAP32[$kappa >> 2] = $89;
    var $90 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval);
    var $90$1 = $90[1];
    if ($87$1 >>> 0 < $90$1 >>> 0 || $87$1 >>> 0 == $90$1 >>> 0 && $87$0 >>> 0 < $90[0] >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $fractionals_0$1 = $87$1;
      var $fractionals_0$0 = $87$0;
      var $unit_0$1 = $66$1;
      var $unit_0$0 = $66$0;
      __label__ = 6;
      break;
    }
   case 7:
    var $93 = $buffer;
    var $94 = $3;
    var $st$2$0 = $93 | 0;
    var $95$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $93 + 4 | 0;
    var $95$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $94 | 0;
    HEAP32[$st$6$0 >> 2] = $95$0;
    var $st$6$1 = $94 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $95$1;
    var $96 = HEAP32[$length >> 2];
    __ZN2v88internal5DiyFp5MinusERKS1_S3_($4, $too_high, $w);
    var $97 = __ZNK2v88internal5DiyFp1fEv($4);
    var $97$0 = $97[0];
    var $97$1 = $97[1];
    var $98$0 = (i64Math.multiply($97$0, $97$1, $66$0, $66$1), i64Math.result[0]);
    var $98$1 = i64Math.result[1];
    var $99 = __ZNK2v88internal5DiyFp1fEv($unsafe_interval);
    var $99$0 = $99[0];
    var $99$1 = $99[1];
    var $100 = __ZNK2v88internal5DiyFp1fEv($one);
    var $100$0 = $100[0];
    var $100$1 = $100[1];
    var $101 = __ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy($3, $96, $98$0, $98$1, $99$0, $99$1, $87$0, $87$1, $100$0, $100$1, $66$0, $66$1);
    var $_0 = $101;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_["X"] = 1;

function __ZN2v88internal5DiyFpC1Eyi($this, $f$0, $f$1, $e) {
  __ZN2v88internal5DiyFpC2Eyi($this, $f$0, $f$1, $e);
  return;
}

function __ZN2v88internal5DiyFp5MinusERKS1_S3_($agg_result, $a, $b) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp8SubtractERKS1_($agg_result, $b);
  return;
}

function __ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_($v, $buffer, $length, $decimal_exponent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var tempParam = $buffer;
  $buffer = STACKTOP;
  STACKTOP += 8;
  HEAP32[$buffer >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$buffer + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $w = __stackBase__;
  var $1 = __stackBase__ + 12;
  var $boundary_minus = __stackBase__ + 20;
  var $boundary_plus = __stackBase__ + 32;
  var $2 = __stackBase__ + 44;
  var $ten_mk = __stackBase__ + 52;
  var $mk = __stackBase__ + 64;
  var $kappa = __stackBase__ + 68;
  var $3 = __stackBase__ + 72;
  var $4 = __stackBase__ + 84;
  var $5 = __stackBase__ + 96;
  var $6 = __stackBase__ + 108;
  __ZN2v88internal6DoubleC1Ed($1, $v);
  __ZNK2v88internal6Double17AsNormalizedDiyFpEv($w, $1);
  __ZN2v88internal5DiyFpC1Ev($boundary_minus);
  __ZN2v88internal5DiyFpC1Ev($boundary_plus);
  __ZN2v88internal6DoubleC1Ed($2, $v);
  __ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_($2, $boundary_minus, $boundary_plus);
  __ZN2v88internal5DiyFpC1Ev($ten_mk);
  var $7 = __ZNK2v88internal5DiyFp1eEv($w);
  var $8 = $7 + 64 | 0;
  __ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE($8, $mk, $ten_mk);
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($4, $w, $ten_mk);
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($3, $boundary_minus, $ten_mk);
  __ZN2v88internal5DiyFp5TimesERKS1_S3_($5, $boundary_plus, $ten_mk);
  var $9 = $buffer;
  var $10 = $6;
  var $11$0 = HEAP32[$9 >> 2];
  var $11$1 = HEAP32[$9 + 4 >> 2];
  HEAP32[$10 >> 2] = $11$0;
  HEAP32[$10 + 4 >> 2] = $11$1;
  var $12 = __ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_($3, $4, $5, $6, $length, $kappa);
  var $15 = HEAP32[$kappa >> 2] - HEAP32[$mk >> 2] | 0;
  HEAP32[$decimal_exponent >> 2] = $15;
  STACKTOP = __stackBase__;
  return $12;
}

function __ZN2v88internal6DoubleC1Ed($this, $d) {
  __ZN2v88internal6DoubleC2Ed($this, $d);
  return;
}

function __ZNK2v88internal6Double17AsNormalizedDiyFpEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2v88internal6Double11SignificandEv($this);
    var $1$0 = $1[0];
    var $1$1 = $1[1];
    var $2 = __ZNK2v88internal6Double8ExponentEv($this);
    if (($1$0 & 0) == 0 && ($1$1 & 1048576) == 0) {
      var $f_01$1 = $1$1;
      var $f_01$0 = $1$0;
      var $e_02 = $2;
      __label__ = 2;
      break;
    } else {
      var $f_0_lcssa$1 = $1$1;
      var $f_0_lcssa$0 = $1$0;
      var $e_0_lcssa = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $e_02;
    var $f_01$0;
    var $f_01$1;
    var $5$0 = $f_01$0 << 1 | 0 >>> 31;
    var $5$1 = $f_01$1 << 1 | $f_01$0 >>> 31;
    var $6 = $e_02 - 1 | 0;
    if (($5$0 & 0) == 0 && ($5$1 & 1048576) == 0) {
      var $f_01$1 = $5$1;
      var $f_01$0 = $5$0;
      var $e_02 = $6;
      __label__ = 2;
      break;
    } else {
      var $f_0_lcssa$1 = $5$1;
      var $f_0_lcssa$0 = $5$0;
      var $e_0_lcssa = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_0_lcssa;
    var $f_0_lcssa$0;
    var $f_0_lcssa$1;
    __ZN2v88internal5DiyFpC1Eyi($agg_result, $f_0_lcssa$0 << 11 | 0 >>> 21, $f_0_lcssa$1 << 11 | $f_0_lcssa$0 >>> 21, $e_0_lcssa - 11 | 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal5DiyFpC1Ev($this) {
  __ZN2v88internal5DiyFpC2Ev($this);
  return;
}

function __ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_($this, $out_m_minus, $out_m_plus) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $m_plus = __stackBase__ + 12;
    var $1 = __stackBase__ + 24;
    var $m_minus = __stackBase__ + 36;
    __ZNK2v88internal6Double7AsDiyFpEv($v, $this);
    var $2 = __ZNK2v88internal5DiyFp1fEv($v);
    var $2$0 = $2[0];
    var $2$1 = $2[1];
    var $3 = $2$0 == 0 && $2$1 == 1048576;
    var $5$0 = $2$0 << 1 | 0 >>> 31 | 1;
    var $5$1 = $2$1 << 1 | $2$0 >>> 31 | 0;
    var $6 = __ZNK2v88internal5DiyFp1eEv($v);
    var $7 = $6 - 1 | 0;
    __ZN2v88internal5DiyFpC1Eyi($1, $5$0, $5$1, $7);
    __ZN2v88internal5DiyFp9NormalizeERKS1_($m_plus, $1);
    __ZN2v88internal5DiyFpC1Ev($m_minus);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = __ZNK2v88internal5DiyFp1eEv($v);
    if (($9 | 0) == -1074) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2v88internal5DiyFp1fEv($v);
    var $12$0 = $12[0];
    var $13$0 = $12$0 << 2 | 0 >>> 30;
    var $13$1 = $12[1] << 2 | $12$0 >>> 30;
    var $14$0 = (i64Math.add($13$0, $13$1, -1, -1), i64Math.result[0]);
    var $14$1 = i64Math.result[1];
    var $15 = $9 - 2 | 0;
    __ZN2v88internal5DiyFpC1Eyi($m_minus, $14$0, $14$1, $15);
    __label__ = 5;
    break;
   case 4:
    var $17 = __ZNK2v88internal5DiyFp1fEv($v);
    var $17$0 = $17[0];
    var $18$0 = $17$0 << 1 | 0 >>> 31;
    var $18$1 = $17[1] << 1 | $17$0 >>> 31;
    var $19$0 = (i64Math.add($18$0, $18$1, -1, -1), i64Math.result[0]);
    var $19$1 = i64Math.result[1];
    var $20 = __ZNK2v88internal5DiyFp1eEv($v);
    var $21 = $20 - 1 | 0;
    __ZN2v88internal5DiyFpC1Eyi($m_minus, $19$0, $19$1, $21);
    __label__ = 5;
    break;
   case 5:
    var $23 = __ZNK2v88internal5DiyFp1fEv($m_minus);
    var $23$0 = $23[0];
    var $23$1 = $23[1];
    var $24 = __ZNK2v88internal5DiyFp1eEv($m_minus);
    var $25 = __ZNK2v88internal5DiyFp1eEv($m_plus);
    var $27$0 = $24 - $25 | 0;
    var $28 = Runtime.bitshift64($23$0, $23$1, "shl", $27$0);
    var $28$0 = $28[0], $28$1 = $28[1];
    __ZN2v88internal5DiyFp5set_fEy($m_minus, $28$0, $28$1);
    var $29 = __ZNK2v88internal5DiyFp1eEv($m_plus);
    __ZN2v88internal5DiyFp5set_eEi($m_minus, $29);
    var $30 = $out_m_plus;
    var $31 = $m_plus;
    HEAP32[$30 >> 2] = HEAP32[$31 >> 2];
    HEAP32[$30 + 4 >> 2] = HEAP32[$31 + 4 >> 2];
    HEAP32[$30 + 8 >> 2] = HEAP32[$31 + 8 >> 2];
    var $32 = $out_m_minus;
    var $33 = $m_minus;
    HEAP32[$32 >> 2] = HEAP32[$33 >> 2];
    HEAP32[$32 + 4 >> 2] = HEAP32[$33 + 4 >> 2];
    HEAP32[$32 + 8 >> 2] = HEAP32[$33 + 8 >> 2];
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_["X"] = 1;

function __ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE($e, $mk, $c_mk) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $4 = (3 - $e | 0) * .30102999566398114;
  var $5 = __ZN2v88internal7ceilingEd($4);
  var $9 = ((($5 & -1) + 307 | 0) / 8 & -1) + 1 | 0;
  var $_039 = __ZN2v88internalL14kCachedPowers8E + $9 * 12 | 0;
  var $tmp40$0 = HEAP32[$_039 >> 2];
  var $tmp40$1 = HEAP32[$_039 + 4 >> 2];
  var $phitmp = HEAP16[__ZN2v88internalL14kCachedPowers8E + $9 * 12 + 8 >> 1] << 16 >> 16;
  var $phitmp1 = HEAP16[__ZN2v88internalL14kCachedPowers8E + $9 * 12 + 10 >> 1] << 16 >> 16;
  __ZN2v88internal5DiyFpC1Eyi($1, $tmp40$0, $tmp40$1, $phitmp);
  var $10 = $c_mk;
  var $11 = $1;
  HEAP32[$10 >> 2] = HEAP32[$11 >> 2];
  HEAP32[$10 + 4 >> 2] = HEAP32[$11 + 4 >> 2];
  HEAP32[$10 + 8 >> 2] = HEAP32[$11 + 8 >> 2];
  HEAP32[$mk >> 2] = $phitmp1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2v88internal5DiyFp5TimesERKS1_S3_($agg_result, $a, $b) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp8MultiplyERKS1_($agg_result, $b);
  return;
}

function __ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_($v, $buffer, $length, $point) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $buffer;
  $buffer = STACKTOP;
  STACKTOP += 8;
  HEAP32[$buffer >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$buffer + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $decimal_exponent = __stackBase__;
  var $1 = __stackBase__ + 4;
  var $2 = $buffer;
  var $3 = $1;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  var $5 = __ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_($v, $1, $length, $decimal_exponent);
  var $8 = HEAP32[$decimal_exponent >> 2] + HEAP32[$length >> 2] | 0;
  HEAP32[$point >> 2] = $8;
  var $9 = HEAP32[$length >> 2];
  var $10 = __ZNK2v88internal6VectorIcEixEi($buffer, $9);
  HEAP8[$10] = 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __ZNK2v88internal6Double7AsDiyFpEv($agg_result, $this) {
  var $1 = __ZNK2v88internal6Double11SignificandEv($this);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZNK2v88internal6Double8ExponentEv($this);
  __ZN2v88internal5DiyFpC1Eyi($agg_result, $1$0, $1$1, $2);
  return;
}

function __ZN2v88internal5DiyFp9NormalizeERKS1_($agg_result, $a) {
  var $1 = $agg_result;
  var $2 = $a;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  __ZN2v88internal5DiyFp9NormalizeEv($agg_result);
  return;
}

function __ZNK2v88internal6Double11SignificandEv($this) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this);
  var $2$0 = $1[0] & -1;
  var $2$1 = $1[1] & 1048575;
  var $3 = __ZNK2v88internal6Double10IsDenormalEv($this);
  var $_0$0 = $3 ? $2$0 : $2$0 | 0;
  var $_0$1 = $3 ? $2$1 : $2$1 | 1048576;
  return [ $_0$0, $_0$1 ];
}

function __ZNK2v88internal6Double8ExponentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2v88internal6Double10IsDenormalEv($this);
    if ($1) {
      var $_0 = -1074;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2v88internal6Double8AsUint64Ev($this);
    var $_0 = (($3[1] >>> 20 | 0 << 12) & 2047) - 1075 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2v88internal6Double10IsDenormalEv($this) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this);
  return ($1[0] & 0) == 0 && ($1[1] & 2146435072) == 0;
}

function __ZN2v88internal6DoubleC2Ed($this, $d) {
  var $1 = $this | 0;
  var $2 = __ZN2v88internalL16double_to_uint64Ed($d);
  var $2$1 = $2[1];
  HEAP32[$1 >> 2] = $2[0];
  HEAP32[$1 + 4 >> 2] = $2$1;
  return;
}

function __ZN2v88internalL16double_to_uint64Ed($d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  tempDoubleF64[0] = $d, HEAP32[$1 >> 2] = tempDoubleI32[0], HEAP32[$1 + 4 >> 2] = tempDoubleI32[1];
  var $2 = __ZN2v88internal7BitCastIydEET_RKT0_($1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  STACKTOP = __stackBase__;
  return [ $2$0, $2$1 ];
}

function __ZN2js15TempAllocPolicy13onOutOfMemoryEPvj($this, $p, $nbytes) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext(undef, undef, undef, $2);
  return 0;
}

function __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($this) {
  var $2 = HEAP32[$this >> 2];
  __Z27js_ReportAllocationOverflowP9JSContext($2);
  return;
}

function __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($this, $cx, $script, $initial, $newDepth, $newArray, $newCount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($initial) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = $newDepth;
    HEAP32[$this + 12 >> 2] = $newArray;
    HEAP32[$this + 8 >> 2] = $newCount;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 3:
    if ((HEAP8[$this | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 4:
    var $10 = $this + 8 | 0;
    var $11 = ($newCount | 0) == 0;
    var $12 = $cx + 56 | 0;
    var $13 = $this + 12 | 0;
    var $i_0 = 0;
    var $owned_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $owned_0;
    var $i_0;
    var $15 = HEAPU32[$10 >> 2];
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 6:
    if ($11) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = HEAP32[HEAP32[$13 >> 2] + ($i_0 << 2) >> 2];
    var $found_01 = 0;
    var $j_02 = 0;
    __label__ = 8;
    break;
   case 8:
    var $j_02;
    var $found_01;
    var $found_1 = (HEAP32[$newArray + ($j_02 << 2) >> 2] | 0) == ($19 | 0) ? 1 : $found_01;
    var $24 = $j_02 + 1 | 0;
    if (($24 | 0) == ($newCount | 0)) {
      __label__ = 9;
      break;
    } else {
      var $found_01 = $found_1;
      var $j_02 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($found_1 & 1) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      var $i_1 = $i_0;
      var $owned_2 = $owned_0;
      __label__ = 16;
      break;
    }
   case 10:
    if (($owned_0 & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $owned_1 = $owned_0;
    var $42 = $15;
    var $41 = HEAP32[$13 >> 2];
    __label__ = 15;
    break;
   case 12:
    var $30 = HEAP32[$12 >> 2] + 344 | 0;
    var $31 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($30, $15);
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($script, $cx);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 14:
    var $35 = $31;
    var $37 = HEAP32[$13 >> 2];
    var $39 = HEAP32[$10 >> 2] << 2;
    _memcpy($35, $37, $39, 1);
    HEAP32[$13 >> 2] = $31;
    var $owned_1 = 1;
    var $42 = HEAP32[$10 >> 2];
    var $41 = $31;
    __label__ = 15;
    break;
   case 15:
    var $41;
    var $42;
    var $owned_1;
    var $43 = $42 - 1 | 0;
    HEAP32[$10 >> 2] = $43;
    var $45 = HEAP32[$41 + ($43 << 2) >> 2];
    HEAP32[$41 + ($i_0 << 2) >> 2] = $45;
    var $i_1 = $i_0 - 1 | 0;
    var $owned_2 = $owned_1;
    __label__ = 16;
    break;
   case 16:
    var $owned_2;
    var $i_1;
    var $i_0 = $i_1 + 1 | 0;
    var $owned_0 = $owned_2;
    __label__ = 5;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj["X"] = 1;

function __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$1] = 1;
    HEAP8[$this + 13 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $2 = HEAP8[$pc] << 24 >> 24 == 127;
    var $3 = $this | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = _js_GetIndexFromBytecode($cx, $4, $pc, 0);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN8JSScript11getFunctionEj($4, $5);
    var $atom_0 = HEAP32[$7 + 72 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN8JSScript7getAtomEj($4, $5);
    var $atom_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $atom_0;
    var $15 = HEAP32[$3 >> 2] + 64 | 0;
    var $16 = $cx;
    var $17 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($15, $16, $atom_0, $index);
    if (($17 | 0) == 1) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $19 = HEAP32[$index >> 2];
    var $20 = __ZN2js7analyzeL7ArgSlotEj($19);
    HEAP8[HEAP32[$this + 16 >> 2] + $20 | 0] = 1;
    __label__ = 7;
    break;
   case 6:
    var $25 = HEAP32[$3 >> 2];
    var $26 = HEAP32[$index >> 2];
    var $27 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($25, $26);
    HEAP8[HEAP32[$this + 16 >> 2] + $27 | 0] = 1;
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript11getFunctionEj($this, $index) {
  var $1 = __ZN8JSScript9getObjectEj($this, $index);
  return $1;
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSScript8functionEv($script);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $forwardJump = __stackBase__;
    var $nextOffset = __stackBase__ + 4;
    var $untrap = __stackBase__ + 8;
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = $this | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $7 = HEAPU32[$5 + 8 >> 2];
    if ((HEAP8[$5 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $18 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZNK8JSScript8functionEv($5);
    var $18 = HEAPU16[$13 + 56 >> 1] & 65535;
    __label__ = 3;
    break;
   case 3:
    var $18;
    var $19 = __ZN2js7analyzeL10TotalSlotsEP8JSScript($5);
    var $20 = $this + 8 | 0;
    HEAP32[$20 >> 2] = $19;
    var $21 = __ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj($3, $7);
    var $22 = $this + 4 | 0;
    HEAP32[$22 >> 2] = $21;
    var $26 = HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535;
    var $27 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($3, $26);
    var $28 = $this + 32 | 0;
    HEAP32[$28 >> 2] = $27;
    var $29 = HEAP32[$20 >> 2];
    var $30 = __ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj($3, $29);
    var $31 = $this + 16 | 0;
    HEAP32[$31 >> 2] = $30;
    var $32 = HEAPU32[$22 >> 2];
    if (($32 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $35 = HEAPU32[$28 >> 2];
    if (($35 | 0) == 0 | ($30 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 135;
    break;
   case 6:
    __ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j($32, $7);
    var $40 = HEAPU32[$4 >> 2];
    if (HEAP16[$40 + 14 >> 1] << 16 >> 16 == 0) {
      var $53 = $30;
      var $52 = $40;
      __label__ = 10;
      break;
    } else {
      var $i_053 = 0;
      var $44 = $35;
      __label__ = 7;
      break;
    }
   case 7:
    var $44;
    var $i_053;
    HEAP32[$44 + ($i_053 << 2) >> 2] = -2;
    var $46 = $i_053 + 1 | 0;
    var $47 = HEAPU32[$4 >> 2];
    if ($46 >>> 0 < (HEAPU16[$47 + 14 >> 1] & 65535) >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $i_053 = $46;
    var $44 = HEAP32[$28 >> 2];
    __label__ = 7;
    break;
   case 9:
    var $53 = HEAP32[$31 >> 2];
    var $52 = $47;
    __label__ = 10;
    break;
   case 10:
    var $52;
    var $53;
    var $54 = HEAP32[$20 >> 2];
    __ZN2jsL7PodZeroIhEEvPT_j($53, $54);
    if ((HEAP8[$52 + 36 | 0] & 96) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $61 = __ZNK2js2gc4Cell11compartmentEv($52);
    var $62 = __ZNK13JSCompartment9debugModeEv($61);
    if ($62) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    if (($18 | 0) == 0) {
      var $82 = $52;
      __label__ = 19;
      break;
    } else {
      var $i1_051 = 0;
      var $67 = $53;
      __label__ = 14;
      break;
    }
   case 13:
    if (HEAP16[$52 + 48 >> 1] << 16 >> 16 == 0) {
      var $82 = $52;
      __label__ = 19;
      break;
    } else {
      var $i2_028 = 0;
      var $72 = $52;
      var $71 = $53;
      __label__ = 16;
      break;
    }
   case 14:
    var $67;
    var $i1_051;
    var $68 = __ZN2js7analyzeL7ArgSlotEj($i1_051);
    HEAP8[$67 + $68 | 0] = 1;
    var $70 = $i1_051 + 1 | 0;
    if (($70 | 0) == ($18 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $i1_051 = $70;
    var $67 = HEAP32[$31 >> 2];
    __label__ = 14;
    break;
   case 16:
    var $71;
    var $72;
    var $i2_028;
    var $73 = __ZN8JSScript12getClosedArgEj($72, $i2_028);
    var $74 = __ZN2js7analyzeL7ArgSlotEj($73);
    HEAP8[$71 + $74 | 0] = 1;
    var $76 = $i2_028 + 1 | 0;
    var $77 = HEAPU32[$4 >> 2];
    if ($76 >>> 0 < (HEAPU16[$77 + 48 >> 1] & 65535) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $82 = $77;
      __label__ = 19;
      break;
    }
   case 17:
    var $i2_028 = $76;
    var $72 = $77;
    var $71 = HEAP32[$31 >> 2];
    __label__ = 16;
    break;
   case 18:
    var $82 = HEAP32[$4 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $82;
    if ((HEAP8[$82 + 36 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $89 = __ZNK2js2gc4Cell11compartmentEv($82);
    var $90 = __ZNK13JSCompartment9debugModeEv($89);
    if ($90) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    if (HEAP16[$82 + 14 >> 1] << 16 >> 16 == 0) {
      var $118 = $82;
      __label__ = 25;
      break;
    } else {
      var $i3_047 = 0;
      var $97 = $82;
      __label__ = 23;
      break;
    }
   case 22:
    if (HEAP16[$82 + 50 >> 1] << 16 >> 16 == 0) {
      var $118 = $82;
      __label__ = 25;
      break;
    } else {
      var $i4_031 = 0;
      var $107 = $82;
      __label__ = 24;
      break;
    }
   case 23:
    var $97;
    var $i3_047;
    var $98 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($97, $i3_047);
    HEAP8[HEAP32[$31 >> 2] + $98 | 0] = 1;
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $i3_047, -1);
    var $101 = $i3_047 + 1 | 0;
    var $102 = HEAPU32[$4 >> 2];
    if ($101 >>> 0 < (HEAPU16[$102 + 14 >> 1] & 65535) >>> 0) {
      var $i3_047 = $101;
      var $97 = $102;
      __label__ = 23;
      break;
    } else {
      var $118 = $102;
      __label__ = 25;
      break;
    }
   case 24:
    var $107;
    var $i4_031;
    var $108 = __ZN8JSScript12getClosedVarEj($107, $i4_031);
    var $109 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($107, $108);
    HEAP8[HEAP32[$31 >> 2] + $109 | 0] = 1;
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $108, -1);
    var $112 = $i4_031 + 1 | 0;
    var $113 = HEAPU32[$4 >> 2];
    if ($112 >>> 0 < (HEAPU16[$113 + 50 >> 1] & 65535) >>> 0) {
      var $i4_031 = $112;
      var $107 = $113;
      __label__ = 24;
      break;
    } else {
      var $118 = $113;
      __label__ = 25;
      break;
    }
   case 25:
    var $118;
    if ((HEAPU16[$118 + 14 >> 1] & 65535) > 50) {
      var $i5_043 = 50;
      __label__ = 26;
      break;
    } else {
      var $128 = $118;
      __label__ = 27;
      break;
    }
   case 26:
    var $i5_043;
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $i5_043, -1);
    var $122 = $i5_043 + 1 | 0;
    var $123 = HEAPU32[$4 >> 2];
    if ($122 >>> 0 < (HEAPU16[$123 + 14 >> 1] & 65535) >>> 0) {
      var $i5_043 = $122;
      __label__ = 26;
      break;
    } else {
      var $128 = $123;
      __label__ = 27;
      break;
    }
   case 27:
    var $128;
    var $129 = HEAP32[$1 >> 2];
    var $130 = __ZNK13JSCompartment9debugModeEv($129);
    if ($130) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $_phi_trans_insert = $this + 25 | 0;
    var $140 = HEAP8[$_phi_trans_insert];
    var $_pre_phi = $_phi_trans_insert;
    __label__ = 30;
    break;
   case 29:
    var $132 = $this + 24 | 0;
    var $134 = HEAPU16[$132 >> 1];
    HEAP8[$132] = $134 & 255 | 1;
    var $140 = ($134 & 65535) >>> 8 & 255;
    var $_pre_phi = $this + 25 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_pre_phi;
    var $140;
    HEAP8[$_pre_phi] = $140 | 1;
    var $142 = $128 + 48 | 0;
    if (HEAP16[$142 >> 1] << 16 >> 16 == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 31:
    if (HEAP16[$128 + 50 >> 1] << 16 >> 16 == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 32:
    if ((HEAPU16[$128 + 14 >> 1] & 65535) > 49) {
      __label__ = 37;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if ((HEAP8[$128 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $159 = __ZNK8JSScript8functionEv($128);
    var $160 = __ZNK10JSFunction13isHeavyweightEv($159);
    if ($160) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if ((HEAP8[$128 + 36 | 0] & 96) << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $167 = HEAP32[$1 >> 2];
    var $168 = __ZNK13JSCompartment9debugModeEv($167);
    if ($168) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP8[$_pre_phi] = $140 & -2;
    __label__ = 38;
    break;
   case 38:
    var $171 = $this + 24 | 0;
    var $172 = $171;
    var $173 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $173 & 255 & -17;
    var $179 = ($173 & 65535) >>> 8 & 255;
    if (HEAP16[$142 >> 1] << 16 >> 16 == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    if ((HEAP8[$128 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $195 = $179;
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $186 = __ZNK8JSScript8functionEv($128);
    var $187 = __ZNK10JSFunction13isHeavyweightEv($186);
    if ($187) {
      __label__ = 41;
      break;
    } else {
      var $195 = $179;
      __label__ = 42;
      break;
    }
   case 41:
    var $189 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $189 & 255 | 16;
    var $195 = ($189 & 65535) >>> 8 & 255;
    __label__ = 42;
    break;
   case 42:
    var $195;
    HEAP8[$_pre_phi] = $195 | 2;
    HEAP32[$forwardJump >> 2] = 0;
    var $197 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($3);
    if (($197 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 135;
    break;
   case 44:
    var $201 = $197 + 4 | 0;
    HEAP32[$201 >> 2] = 0;
    var $202 = HEAP32[$22 >> 2];
    HEAP32[$202 >> 2] = $197;
    var $205 = HEAP32[HEAP32[$4 >> 2] + 100 >> 2];
    var $206 = __ZN2js5types10TypeScript9typeArrayEv($205);
    HEAP32[$nextOffset >> 2] = 0;
    var $207 = $untrap + 4 | 0;
    var $208 = $this + 28 | 0;
    var $forwardCatch_0 = 0;
    var $nTypeSets_0 = 0;
    var $210 = 0;
    __label__ = 45;
    break;
   case 45:
    var $210;
    var $nTypeSets_0;
    var $forwardCatch_0;
    if ($210 >>> 0 < $7 >>> 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 46:
    var $213 = HEAPU32[$forwardJump >> 2];
    if (($213 | 0) != 0 & ($213 | 0) == ($210 | 0)) {
      __label__ = 47;
      break;
    } else {
      var $217 = $213;
      __label__ = 48;
      break;
    }
   case 47:
    HEAP32[$forwardJump >> 2] = 0;
    var $217 = 0;
    __label__ = 48;
    break;
   case 48:
    var $217;
    var $forwardCatch_1 = ($forwardCatch_0 | 0) != 0 & ($forwardCatch_0 | 0) == ($210 | 0) ? 0 : $forwardCatch_0;
    var $220 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $210);
    var $221 = HEAP32[$4 >> 2];
    var $223 = HEAPU32[$221 >> 2];
    var $224 = $223 + $210 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $221, $224);
    var $225 = HEAPU8[$224];
    var $226 = $225 & 255;
    var $227 = __ZN2js7analyzeL17GetBytecodeLengthEPh($224);
    var $228 = $227 + $210 | 0;
    HEAP32[$nextOffset >> 2] = $228;
    if (($220 | 0) == 0) {
      var $forwardCatch_6 = $forwardCatch_1;
      var $nTypeSets_2 = $nTypeSets_0;
      __label__ = 133;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $231 = $220 | 0;
    var $233 = HEAPU16[$220 >> 1];
    var $234 = $233 & 255;
    var $238 = ($233 & 65535) >>> 8 & 255;
    if (($234 & 64) << 24 >> 24 == 0) {
      __label__ = 50;
      break;
    } else {
      var $forwardCatch_6 = $forwardCatch_1;
      var $nTypeSets_2 = $nTypeSets_0;
      __label__ = 133;
      break;
    }
   case 50:
    HEAP8[$231] = $234 | 64;
    if (($forwardCatch_1 | 0) == 0) {
      var $246 = $238;
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $244 = $238 | 1;
    HEAP8[$231 + 1 | 0] = $244;
    var $246 = $244;
    __label__ = 52;
    break;
   case 52:
    var $246;
    if ((HEAP8[$207] & 1) << 24 >> 24 == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    HEAP8[$231 + 1 | 0] = $246 | 2;
    var $254 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $254;
    __label__ = 54;
    break;
   case 54:
    var $257 = HEAP32[$220 + 4 >> 2];
    var $258 = $220 + 12 | 0;
    var $259 = HEAPU32[$258 >> 2];
    var $260 = $220 + 8 | 0;
    var $261 = HEAP32[$260 >> 2];
    var $262 = ($217 | 0) == 0;
    if ($262) {
      __label__ = 55;
      break;
    } else {
      var $defineCount_0 = $261;
      var $defineArray_0 = $259;
      __label__ = 60;
      break;
    }
   case 55:
    var $265 = HEAP8[$231] | 32;
    HEAP8[$231] = $265;
    if (($261 | 0) == 0) {
      __label__ = 59;
      break;
    } else {
      var $i6_039 = 0;
      __label__ = 56;
      break;
    }
   case 56:
    var $i6_039;
    var $268 = HEAP32[$259 + ($i6_039 << 2) >> 2];
    if ((HEAP32[HEAP32[$28 >> 2] + ($268 << 2) >> 2] | 0) == -2) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $268, $210);
    __label__ = 58;
    break;
   case 58:
    var $275 = $i6_039 + 1 | 0;
    if (($275 | 0) == ($261 | 0)) {
      __label__ = 59;
      break;
    } else {
      var $i6_039 = $275;
      __label__ = 56;
      break;
    }
   case 59:
    HEAP32[$258 >> 2] = 0;
    HEAP32[$260 >> 2] = 0;
    var $defineCount_0 = 0;
    var $defineArray_0 = 0;
    __label__ = 60;
    break;
   case 60:
    var $defineArray_0;
    var $defineCount_0;
    var $278 = HEAPU32[_js_CodeSpec + ($226 << 3) + 4 >> 2];
    if (($278 & 134217728 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      var $stackDepth_0 = $257;
      __label__ = 62;
      break;
    }
   case 61:
    var $282 = HEAP32[$4 >> 2];
    var $_idx_val = HEAP32[$282 >> 2];
    var $283 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj($_idx_val, $210);
    var $284 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($282, $210);
    var $stackDepth_0 = $257 - $283 + $284 | 0;
    __label__ = 62;
    break;
   case 62:
    var $stackDepth_0;
    if (($278 & 67108864 | 0) == 0) {
      var $nTypeSets_1 = $nTypeSets_0;
      __label__ = 67;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $291 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($291) {
      __label__ = 64;
      break;
    } else {
      var $nTypeSets_1 = $nTypeSets_0;
      __label__ = 67;
      break;
    }
   case 64:
    if ($nTypeSets_0 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 22 >> 1] & 65535) >>> 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $300 = $206 + $nTypeSets_0 * 12 | 0;
    HEAP32[$220 + 16 >> 2] = $300;
    var $nTypeSets_1 = $nTypeSets_0 + 1 | 0;
    __label__ = 67;
    break;
   case 66:
    var $304 = $206 + ($nTypeSets_0 - 1) * 12 | 0;
    HEAP32[$220 + 16 >> 2] = $304;
    var $nTypeSets_1 = $nTypeSets_0;
    __label__ = 67;
    break;
   case 67:
    var $nTypeSets_1;
    if (($226 | 0) == 5 || ($226 | 0) == 197) {
      __label__ = 68;
      break;
    } else if (($226 | 0) == 154 || ($226 | 0) == 2) {
      __label__ = 69;
      break;
    } else if (($226 | 0) == 59 || ($226 | 0) == 57 || ($226 | 0) == 110 || ($226 | 0) == 111 || ($226 | 0) == 36 || ($226 | 0) == 165 || ($226 | 0) == 166) {
      __label__ = 70;
      break;
    } else if (($226 | 0) == 127 || ($226 | 0) == 129 || ($226 | 0) == 128 || ($226 | 0) == 14) {
      __label__ = 71;
      break;
    } else if (($226 | 0) == 123) {
      __label__ = 72;
      break;
    } else if (($226 | 0) == 3) {
      __label__ = 73;
      break;
    } else if (($226 | 0) == 201 || ($226 | 0) == 202) {
      __label__ = 74;
      break;
    } else if (($226 | 0) == 65) {
      __label__ = 75;
      break;
    } else if (($226 | 0) == 58 || ($226 | 0) == 82) {
      __label__ = 76;
      break;
    } else if (($226 | 0) == 70 || ($226 | 0) == 149) {
      __label__ = 77;
      break;
    } else if (($226 | 0) == 71 || ($226 | 0) == 150) {
      __label__ = 83;
      break;
    } else if (($226 | 0) == 134) {
      __label__ = 88;
      break;
    } else if (($226 | 0) == 86) {
      __label__ = 95;
      break;
    } else if (($226 | 0) == 215 || ($226 | 0) == 101 || ($226 | 0) == 102 || ($226 | 0) == 103 || ($226 | 0) == 104) {
      __label__ = 101;
      break;
    } else if (($226 | 0) == 87) {
      __label__ = 105;
      break;
    } else if (($226 | 0) == 85 || ($226 | 0) == 97 || ($226 | 0) == 98 || ($226 | 0) == 99 || ($226 | 0) == 100) {
      __label__ = 115;
      break;
    } else if (($226 | 0) == 9 || ($226 | 0) == 112 || ($226 | 0) == 118 || ($226 | 0) == 140 || ($226 | 0) == 223 || ($226 | 0) == 130 || ($226 | 0) == 224 || ($226 | 0) == 136 || ($226 | 0) == 137 || ($226 | 0) == 138 || ($226 | 0) == 139 || ($226 | 0) == 115 || ($226 | 0) == 108 || ($226 | 0) == 79) {
      __label__ = 116;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 68:
    var $309 = HEAP32[$208 >> 2] + 1 | 0;
    HEAP32[$208 >> 2] = $309;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 69:
    var $311 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $311 & 255 | 1;
    HEAP8[$_pre_phi] = ($311 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 70:
    __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $224);
    var $318 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $318 & 255 | 2;
    HEAP8[$_pre_phi] = ($318 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 71:
    __ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh($this, $cx, $224);
    var $325 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $325 & 255 | 32;
    HEAP8[$_pre_phi] = ($325 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 72:
    var $332 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $332 & 255 | 32;
    HEAP8[$_pre_phi] = ($332 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 73:
    var $339 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $339 & 255 | 64;
    HEAP8[$_pre_phi] = ($339 & 65535) >>> 8 & 255 & -4;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 74:
    var $346 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $346 & 255 | 64;
    HEAP8[$_pre_phi] = ($346 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 75:
    var $354 = HEAP8[$171] | 4;
    HEAP8[$171] = $354;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 76:
    var $357 = HEAP8[$171] | 8;
    HEAP8[$171] = $357;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 77:
    var $359 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $359;
    var $361 = $225 << 24 >> 24 == 70 ? 2 : 4;
    var $_val4 = HEAP8[$224];
    var $362 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val4, $224);
    var $363 = $362 + $210 | 0;
    var $_sum16 = $361 + $210 | 0;
    var $365 = HEAPU8[$_sum16 + ($223 + 1) | 0];
    var $367 = HEAPU8[$_sum16 + ($223 + 2) | 0];
    var $372 = $_sum16 + ($223 + 4) | 0;
    var $376 = ((HEAPU8[$_sum16 + ($223 + 3) | 0] & 255) << 8 | HEAPU8[$372] & 255) << 16 >> 16;
    var $377 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $363, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($377) {
      __label__ = 78;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 78:
    var $383 = (($365 & 255) << 8 | $367 & 255) << 16 >> 16;
    var $384 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $363);
    var $385 = $384 | 0;
    var $387 = HEAP8[$385] | 16;
    HEAP8[$385] = $387;
    var $388 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $363);
    var $390 = $388 + 1 | 0;
    var $392 = HEAP8[$390] | 2;
    HEAP8[$390] = $392;
    var $i8_0 = $383;
    var $pc2_0 = $372;
    __label__ = 79;
    break;
   case 79:
    var $pc2_0;
    var $i8_0;
    if (($i8_0 | 0) > ($376 | 0)) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $_val3 = HEAP8[$224];
    var $396 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val3, $pc2_0);
    var $397 = $396 + $210 | 0;
    if (($396 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $400 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $397, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($400) {
      __label__ = 82;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 82:
    var $402 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $397);
    var $403 = $402 | 0;
    var $405 = HEAP8[$403] | 16;
    HEAP8[$403] = $405;
    var $406 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $397);
    var $408 = $406 + 1 | 0;
    var $410 = HEAP8[$408] | 2;
    HEAP8[$408] = $410;
    var $i8_0 = $i8_0 + 1 | 0;
    var $pc2_0 = $pc2_0 + $361 | 0;
    __label__ = 79;
    break;
   case 83:
    var $414 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $414;
    var $416 = $225 << 24 >> 24 == 71 ? 2 : 4;
    var $_val2 = HEAP8[$224];
    var $417 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val2, $224);
    var $418 = $417 + $210 | 0;
    var $_sum12 = $416 + $210 | 0;
    var $420 = HEAPU8[$_sum12 + ($223 + 1) | 0];
    var $421 = $_sum12 + ($223 + 2) | 0;
    var $422 = HEAPU8[$421];
    var $423 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $418, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($423) {
      __label__ = 84;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 84:
    var $428 = ($420 & 255) << 8 | $422 & 255;
    var $429 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $418);
    var $430 = $429 | 0;
    var $432 = HEAP8[$430] | 16;
    HEAP8[$430] = $432;
    var $433 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $418);
    var $435 = $433 + 1 | 0;
    var $437 = HEAP8[$435] | 2;
    HEAP8[$435] = $437;
    var $_sum15 = $416 + 2 | 0;
    var $npairs_0 = $428;
    var $pc29_0 = $421;
    __label__ = 85;
    break;
   case 85:
    var $pc29_0;
    var $npairs_0;
    if (($npairs_0 | 0) == 0) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $_val1 = HEAP8[$224];
    var $442 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val1, $pc29_0 + 2 | 0);
    var $443 = $442 + $210 | 0;
    var $444 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $443, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($444) {
      __label__ = 87;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 87:
    var $446 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $443);
    var $447 = $446 | 0;
    var $449 = HEAP8[$447] | 16;
    HEAP8[$447] = $449;
    var $450 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $443);
    var $452 = $450 + 1 | 0;
    var $454 = HEAP8[$452] | 2;
    HEAP8[$452] = $454;
    var $npairs_0 = $npairs_0 - 1 | 0;
    var $pc29_0 = $pc29_0 + $_sum15 | 0;
    __label__ = 85;
    break;
   case 88:
    var $459 = HEAP8[$_pre_phi] & -4;
    HEAP8[$_pre_phi] = $459;
    var $460 = HEAP32[$4 >> 2];
    var $461 = __ZN8JSScript8trynotesEv($460);
    var $463 = HEAP32[$461 >> 2];
    var $466 = $463 + HEAP32[$461 + 4 >> 2] * 12 | 0;
    var $467 = $210 + 1 | 0;
    var $tn_0 = $463;
    var $forwardCatch_2 = $forwardCatch_1;
    __label__ = 89;
    break;
   case 89:
    var $forwardCatch_2;
    var $tn_0;
    if ($tn_0 >>> 0 < $466 >>> 0) {
      __label__ = 90;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_2;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 90:
    var $476 = HEAP32[$tn_0 + 4 >> 2] + HEAP32[HEAP32[$4 >> 2] + 32 >> 2] | 0;
    if (($476 | 0) == ($467 | 0)) {
      __label__ = 91;
      break;
    } else {
      var $forwardCatch_4 = $forwardCatch_2;
      __label__ = 94;
      break;
    }
   case 91:
    var $481 = HEAP32[$tn_0 + 8 >> 2] + $476 | 0;
    var $forwardCatch_3 = $481 >>> 0 > $forwardCatch_2 >>> 0 ? $481 : $forwardCatch_2;
    if (HEAP8[$tn_0 | 0] << 24 >> 24 == 2) {
      var $forwardCatch_4 = $forwardCatch_3;
      __label__ = 94;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $487 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $481, $nextOffset, $forwardJump, $stackDepth_0, $defineArray_0, $defineCount_0);
    if ($487) {
      __label__ = 93;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 93:
    var $489 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $481);
    var $490 = $489 | 0;
    var $492 = HEAP8[$490] | -128;
    HEAP8[$490] = $492;
    var $493 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $481);
    var $495 = $493 + 1 | 0;
    var $497 = HEAP8[$495] | 2;
    HEAP8[$495] = $497;
    var $forwardCatch_4 = $forwardCatch_3;
    __label__ = 94;
    break;
   case 94:
    var $forwardCatch_4;
    var $tn_0 = $tn_0 + 12 | 0;
    var $forwardCatch_2 = $forwardCatch_4;
    __label__ = 89;
    break;
   case 95:
    var $501 = $210 + ($223 + 3) | 0;
    if (HEAP8[$501] << 24 >> 24 == 81) {
      __label__ = 96;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 96:
    var $505 = __ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh($this, $501);
    if ($505) {
      __label__ = 97;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 97:
    var $514 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($514 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535) >>> 0) {
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $522 = HEAP8[$171] | -128;
    HEAP8[$171] = $522;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 99:
    var $524 = __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $514, $210);
    if ($524) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $514, -1);
    var $527 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $527;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 101:
    var $536 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($536 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535) >>> 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $544 = HEAP8[$171] | -128;
    HEAP8[$171] = $544;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 103:
    var $546 = __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $536, $210);
    if ($546) {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $536, -1);
    var $549 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $549;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 105:
    var $558 = (HEAPU8[$210 + ($223 + 1) | 0] & 255) << 8 | HEAPU8[$210 + ($223 + 2) | 0] & 255;
    if ($558 >>> 0 < (HEAPU16[HEAP32[$4 >> 2] + 14 >> 1] & 65535) >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $566 = HEAP8[$171] | -128;
    HEAP8[$171] = $566;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 107:
    if ((HEAP32[HEAP32[$28 >> 2] + ($558 << 2) >> 2] | 0) == -2) {
      __label__ = 108;
      break;
    } else {
      var $forwardCatch_5 = $forwardCatch_1;
      var $defineCount_1 = $defineCount_0;
      var $defineArray_1 = $defineArray_0;
      __label__ = 117;
      break;
    }
   case 108:
    if ($262) {
      __label__ = 114;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $574 = $defineCount_0 + 1 | 0;
    var $575 = __ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj($3, $574);
    if (($575 | 0) == 0) {
      __label__ = 110;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 110:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 132;
    break;
   case 111:
    if (($defineCount_0 | 0) == 0) {
      __label__ = 113;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $581 = $575;
    _memcpy($581, $defineArray_0, $defineCount_0 << 2, 1);
    __label__ = 113;
    break;
   case 113:
    var $585 = $575 + ($defineCount_0 << 2) | 0;
    HEAP32[$585 >> 2] = $558;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $574;
    var $defineArray_1 = $575;
    __label__ = 117;
    break;
   case 114:
    __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $558, $210);
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 115:
    var $588 = HEAPU16[$172 >> 1];
    HEAP8[$171] = $588 & 255 | 16;
    HEAP8[$_pre_phi] = ($588 & 65535) >>> 8 & 255 & -2;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 116:
    var $595 = HEAP8[$_pre_phi] & -2;
    HEAP8[$_pre_phi] = $595;
    var $forwardCatch_5 = $forwardCatch_1;
    var $defineCount_1 = $defineCount_0;
    var $defineArray_1 = $defineArray_0;
    __label__ = 117;
    break;
   case 117:
    var $defineArray_1;
    var $defineCount_1;
    var $forwardCatch_5;
    var $596 = $278 & 31;
    if (($596 | 0) == 9 || ($596 | 0) == 1) {
      __label__ = 118;
      break;
    } else {
      var $stackDepth_2 = $stackDepth_0;
      __label__ = 122;
      break;
    }
   case 118:
    if (($226 | 0) == 68 || ($226 | 0) == 69 || ($226 | 0) == 144 || ($226 | 0) == 145) {
      __label__ = 119;
      break;
    } else if (($226 | 0) == 121 || ($226 | 0) == 147) {
      __label__ = 120;
      break;
    } else {
      var $newStackDepth_0 = $stackDepth_0;
      var $stackDepth_1 = $stackDepth_0;
      __label__ = 121;
      break;
    }
   case 119:
    var $newStackDepth_0 = $stackDepth_0;
    var $stackDepth_1 = $stackDepth_0 - 1 | 0;
    __label__ = 121;
    break;
   case 120:
    var $newStackDepth_0 = $stackDepth_0 - 1 | 0;
    var $stackDepth_1 = $stackDepth_0;
    __label__ = 121;
    break;
   case 121:
    var $stackDepth_1;
    var $newStackDepth_0;
    var $_val = HEAP8[$224];
    var $603 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val, $224);
    var $604 = $603 + $210 | 0;
    var $605 = __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $604, $nextOffset, $forwardJump, $newStackDepth_0, $defineArray_1, $defineCount_1);
    if ($605) {
      var $stackDepth_2 = $stackDepth_1;
      __label__ = 122;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 122:
    var $stackDepth_2;
    var $607 = __ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp($226);
    if ($607) {
      var $forwardCatch_6 = $forwardCatch_5;
      var $nTypeSets_2 = $nTypeSets_1;
      __label__ = 133;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $610 = HEAP32[$22 >> 2] + ($228 << 2) | 0;
    var $611 = HEAP32[$610 >> 2];
    var $612 = ($611 | 0) == 0;
    if ($612) {
      __label__ = 124;
      break;
    } else {
      var $618 = $611;
      __label__ = 126;
      break;
    }
   case 124:
    var $614 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($3);
    HEAP32[$610 >> 2] = $614;
    if (($614 | 0) == 0) {
      __label__ = 125;
      break;
    } else {
      var $618 = $614;
      __label__ = 126;
      break;
    }
   case 125:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 132;
    break;
   case 126:
    var $618;
    if (($596 | 0) == 9 || ($596 | 0) == 1) {
      __label__ = 127;
      break;
    } else {
      var $624 = $618;
      __label__ = 128;
      break;
    }
   case 127:
    var $620 = $618 | 0;
    var $622 = HEAP8[$620] | 8;
    HEAP8[$620] = $622;
    var $624 = HEAP32[$610 >> 2];
    __label__ = 128;
    break;
   case 128:
    var $624;
    var $625 = __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($624, $cx, $this, $612, $stackDepth_2, $defineArray_1, $defineCount_1);
    if ($625) {
      __label__ = 129;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 129:
    var $628 = HEAP32[$610 >> 2] | 0;
    var $629 = HEAP8[$628];
    if (($596 | 0) == 9 || ($596 | 0) == 1) {
      __label__ = 130;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 130:
    var $631 = $629 | 1;
    HEAP8[$628] = $631;
    var $forwardCatch_6 = $forwardCatch_5;
    var $nTypeSets_2 = $nTypeSets_1;
    __label__ = 133;
    break;
   case 131:
    var $633 = $629 | 4;
    HEAP8[$628] = $633;
    var $forwardCatch_6 = $forwardCatch_5;
    var $nTypeSets_2 = $nTypeSets_1;
    __label__ = 133;
    break;
   case 132:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 135;
    break;
   case 133:
    var $nTypeSets_2;
    var $forwardCatch_6;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $forwardCatch_0 = $forwardCatch_6;
    var $nTypeSets_0 = $nTypeSets_2;
    var $210 = HEAP32[$nextOffset >> 2];
    __label__ = 45;
    break;
   case 134:
    HEAP8[$this + 20 | 0] = 1;
    __label__ = 135;
    break;
   case 135:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext["X"] = 1;

function __ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 116 || ($op | 0) == 146) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 6 || ($op | 0) == 141 || ($op | 0) == 122 || ($op | 0) == 148 || ($op | 0) == 5 || ($op | 0) == 197 || ($op | 0) == 155 || ($op | 0) == 112 || ($op | 0) == 70 || ($op | 0) == 149 || ($op | 0) == 71 || ($op | 0) == 150 || ($op | 0) == 176) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript9typeArrayEv($this) {
  return $this + 20 | 0;
}

function __ZNK8JSScript8functionEv($this) {
  return HEAP32[HEAP32[$this + 100 >> 2] + 4 >> 2];
}

function __ZN8JSScript12getClosedArgEj($this, $index) {
  return HEAP32[HEAP32[$this + 88 >> 2] + ($index << 2) >> 2];
}

function __ZN2js7analyze14ScriptAnalysis8setLocalEjj($this, $local, $offset) {
  var $3 = HEAP32[$this + 32 >> 2] + ($local << 2) | 0;
  HEAP32[$3 >> 2] = $offset;
  return;
}

function __ZN8JSScript12getClosedVarEj($this, $index) {
  return HEAP32[HEAP32[$this + 88 >> 2] + ((HEAPU16[$this + 48 >> 1] & 65535) + $index << 2) >> 2];
}

function __ZNK10JSFunction13isHeavyweightEv($this) {
  return (HEAP16[$this + 58 >> 1] & 128) << 16 >> 16 != 0;
}

function __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $offset) {
  return HEAP32[HEAP32[$this + 4 >> 2] + ($offset << 2) >> 2];
}

function __ZN2js7analyzeL13GetJumpOffsetEPhS1_($pc_val, $pc2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $9 = HEAPU8[$pc2 + 1 | 0] & 255;
    if (((HEAP32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2] & 31) - 9 | 0) >>> 0 < 3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255) << 16 | $9 << 24 | HEAPU8[$pc2 + 4 | 0] & 255 | (HEAPU8[$pc2 + 3 | 0] & 255) << 8;
    __label__ = 4;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255 | $9 << 8) << 16 >> 16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset) {
  return HEAP32[HEAP32[$this + 4 >> 2] + ($offset << 2) >> 2];
}

function __ZN8JSScript8trynotesEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 19 | 0] & 255) | 0;
}

function __ZN2js7analyzeL10TotalSlotsEP8JSScript($script) {
  var $1 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, 0);
  return (HEAPU16[$script + 14 >> 1] & 65535) + $1 | 0;
}

function __ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + $count & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2jsL7PodZeroIhEEvPT_j($t, $nelem) {
  _memset($t, 0, $nelem, 1);
  return;
}

function __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 44 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze8BytecodeC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($this, $cx, $script, $pc) {
  __ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh($this, $cx, $script, $pc);
  return;
}

function __ZN2js7analyzeL17GetBytecodeLengthEPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU8[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) | 0];
    if ($4 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $4 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $9 = __Z28js_GetVariableBytecodeLengthPh($pc);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11GetUseCountEP8JSScriptj($script_0_0_val, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script_0_0_val + $offset | 0;
    var $2 = HEAPU8[$1];
    var $3 = $2 & 255;
    if ($2 << 24 >> 24 == -123) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$offset + ($script_0_0_val + 1) | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = HEAPU8[_js_CodeSpec + ($3 << 3) + 1 | 0];
    if ($12 << 24 >> 24 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = _js_GetVariableStackUses($3, $1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $_0 = $12 << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11GetDefCountEP8JSScriptj($script, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $5 = HEAPU8[$3] & 255;
    var $7 = HEAPU8[_js_CodeSpec + ($5 << 3) + 2 | 0];
    var $8 = $7 << 24 >> 24;
    if ($7 << 24 >> 24 == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = _js_GetEnterBlockStackDefs(0, $script, $3);
    var $_0 = $11;
    __label__ = 7;
    break;
   case 3:
    if (($5 | 0) == 176) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == 133) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 68 || ($5 | 0) == 144 || ($5 | 0) == 69 || ($5 | 0) == 145) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 5:
    var $_0 = (HEAPU8[$offset + ($2 + 1) | 0] & 255) + 1 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $8;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j($this, $cx, $offset, $currentOffset, $forwardJump, $stackDepth, $defineArray, $defineCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $3 = HEAP32[$this + 4 >> 2] + ($offset << 2) | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $14 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $10 = __ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool($9);
    HEAP32[$3 >> 2] = $10;
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $14 = $10;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 4:
    var $14;
    var $15 = __ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj($14, $cx, $this, $5, $stackDepth, $defineArray, $defineCount);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $18 = HEAP32[$3 >> 2] | 0;
    var $20 = HEAP8[$18] | 1;
    HEAP8[$18] = $20;
    if (HEAPU32[$currentOffset >> 2] >>> 0 > $offset >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $25 = HEAPU32[$this >> 2];
    var $28 = HEAP32[$25 >> 2] + $offset | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $25, $28);
    var $29 = HEAP8[$28];
    if ($29 << 24 >> 24 == 109 || $29 << 24 >> 24 == -74) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = HEAP32[$3 >> 2] | 0;
    var $34 = HEAP8[$32] | 2;
    HEAP8[$32] = $34;
    __label__ = 8;
    break;
   case 8:
    var $36 = $this + 25 | 0;
    var $38 = HEAP8[$36] & -2;
    HEAP8[$36] = $38;
    if ((HEAP8[HEAP32[$3 >> 2] | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    if ((HEAP32[$forwardJump >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $48 = HEAP32[$currentOffset >> 2];
    HEAP32[$forwardJump >> 2] = $48;
    __label__ = 11;
    break;
   case 11:
    HEAP32[$currentOffset >> 2] = $offset;
    __label__ = 12;
    break;
   case 12:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 13:
    if (HEAPU32[$forwardJump >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$forwardJump >> 2] = $offset;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh($this, $pc) {
  var $7 = $pc - HEAP32[HEAP32[$this >> 2] >> 2] | 0;
  var $8 = __ZN2js7analyze14ScriptAnalysis10jumpTargetEj($this, $7);
  return $8;
}

function __ZN2js7analyze14ScriptAnalysis12localDefinedEjj($this, $local, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj($this, $local);
    if ($1) {
      var $12 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[HEAP32[$this + 32 >> 2] + ($local << 2) >> 2] >>> 0 > $offset >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $12 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
    var $10 = __ZN2js7analyze8Bytecode9isDefinedEj($9, $local);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeD1Ev($this) {
  __ZN2js7analyze12UntrapOpcodeD2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis11ranBytecodeEv($this) {
  return (HEAP8[$this + 20 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis6failedEv($this) {
  return (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj($this, $var, $until) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $var + 11 | 0;
    if (HEAP8[$1] << 24 >> 24 < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$var >> 2] | 0;
    HEAP32[$7 >> 2] = $until;
    var $9 = HEAP8[$1] | -128;
    HEAP8[$1] = $9;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP8[HEAP32[$this + 16 >> 2] + $slot | 0] << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $saved = __stackBase__;
    var $savedCount = __stackBase__ + 4;
    var $offset = __stackBase__ + 8;
    var $untrap = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $untrap7 = __stackBase__ + 24;
    var $2 = __stackBase__ + 32;
    var $3 = __ZN2js7analyze14ScriptAnalysis11ranBytecodeEv($this);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($this, $cx);
    var $5 = __ZN2js7analyze14ScriptAnalysis6failedEv($this);
    if ($5) {
      __label__ = 91;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $10 = $this + 8 | 0;
    var $11 = HEAP32[$10 >> 2];
    var $12 = __ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj($9, $11);
    var $13 = $this + 36 | 0;
    HEAP32[$13 >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 91;
    break;
   case 5:
    var $17 = HEAP32[$10 >> 2];
    __ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j($12, $17);
    var $18 = $17 << 2;
    var $19 = __ZN9JSContext7calloc_Ej($cx, $18);
    var $20 = $19;
    HEAP32[$saved >> 2] = $20;
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 91;
    break;
   case 7:
    HEAP32[$savedCount >> 2] = 0;
    var $24 = $this | 0;
    var $25 = HEAP32[$24 >> 2];
    var $27 = HEAP32[$25 + 8 >> 2];
    var $28 = $27 - 1 | 0;
    HEAP32[$offset >> 2] = $28;
    var $loop_0_ph = 0;
    var $31 = $25;
    var $30 = $27;
    var $29 = $28;
    __label__ = 8;
    break;
   case 8:
    var $29;
    var $30;
    var $31;
    var $loop_0_ph;
    var $33 = $29;
    __label__ = 9;
    break;
   case 9:
    var $33;
    if ($33 >>> 0 < $30 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 10:
    var $36 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $33);
    if (($36 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $39 = $33 - 1 | 0;
    HEAP32[$offset >> 2] = $39;
    var $33 = $39;
    __label__ = 9;
    break;
   case 12:
    if (($loop_0_ph | 0) == 0) {
      var $52 = $31;
      var $51 = $33;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP8[$36 + 1 | 0] & 2) << 24 >> 24 == 0) {
      var $52 = $31;
      var $51 = $33;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP8[$loop_0_ph + 20 | 0] = 1;
    var $52 = HEAP32[$24 >> 2];
    var $51 = HEAP32[$offset >> 2];
    __label__ = 15;
    break;
   case 15:
    var $51;
    var $52;
    var $55 = HEAP32[$52 >> 2] + $51 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $52, $55);
    var $56 = HEAPU8[$55];
    var $57 = $56 & 255;
    if ($56 << 24 >> 24 == -74 || $56 << 24 >> 24 == 109) {
      __label__ = 16;
      break;
    } else {
      var $loop_1 = $loop_0_ph;
      __label__ = 22;
      break;
    }
   case 16:
    var $61 = HEAP32[$36 + 16 >> 2];
    if (($61 | 0) == 0) {
      var $loop_1 = $loop_0_ph;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = HEAP32[$61 + 8 >> 2];
    var $66 = HEAP32[$10 >> 2];
    if (($66 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $i_014 = 0;
      var $68 = $66;
      __label__ = 18;
      break;
    }
   case 18:
    var $68;
    var $i_014;
    var $70 = HEAP32[$13 >> 2] + $i_014 * 12 | 0;
    if ((HEAP32[$70 >> 2] | 0) == 0) {
      var $76 = $68;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj($this, $cx, $70, $51, $65);
    var $76 = HEAP32[$10 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $76;
    var $77 = $i_014 + 1 | 0;
    if ($77 >>> 0 < $76 >>> 0) {
      var $i_014 = $77;
      var $68 = $76;
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $loop_1 = HEAP32[$loop_0_ph >> 2];
    __label__ = 22;
    break;
   case 22:
    var $loop_1;
    var $82 = ($loop_1 | 0) != 0;
    var $83 = $36 | 0;
    if ($82) {
      __label__ = 23;
      break;
    } else {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    }
   case 23:
    if ((HEAP8[$83] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if (($51 | 0) == (HEAP32[$loop_1 + 12 >> 2] | 0)) {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $93 = $loop_1 + 16 | 0;
    if ($51 >>> 0 > HEAPU32[$93 >> 2] >>> 0) {
      __label__ = 26;
      break;
    } else {
      var $_pre_phi = $83;
      __label__ = 27;
      break;
    }
   case 26:
    HEAP32[$93 >> 2] = $51;
    var $_pre_phi = $83;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi;
    if (HEAP8[$_pre_phi] << 24 >> 24 < 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 28:
    var $100 = HEAPU32[$24 >> 2];
    var $101 = __ZN8JSScript8trynotesEv($100);
    var $103 = HEAP32[$101 >> 2];
    var $106 = $103 + HEAP32[$101 + 4 >> 2] * 12 | 0;
    var $107 = HEAP32[$offset >> 2];
    var $tn_0 = $103;
    __label__ = 29;
    break;
   case 29:
    var $tn_0;
    if ($tn_0 >>> 0 < $106 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 30:
    var $115 = HEAP32[$tn_0 + 4 >> 2] + HEAP32[$100 + 32 >> 2] | 0;
    if (($115 + HEAP32[$tn_0 + 8 >> 2] | 0) == ($107 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 31:
    var $120 = HEAP32[$10 >> 2];
    if (($120 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $122 = $115 - 1 | 0;
    var $i1_012 = 0;
    var $123 = $120;
    __label__ = 33;
    break;
   case 33:
    var $123;
    var $i1_012;
    var $125 = HEAP32[$13 >> 2] + $i1_012 * 12 | 0;
    if ((HEAP32[$125 >> 2] | 0) == 0) {
      var $131 = $123;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj(undef, $125, $122);
    var $131 = HEAP32[$10 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $131;
    var $132 = $i1_012 + 1 | 0;
    if ($132 >>> 0 < $131 >>> 0) {
      var $i1_012 = $132;
      var $123 = $131;
      __label__ = 33;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $tn_0 = $tn_0 + 12 | 0;
    __label__ = 29;
    break;
   case 37:
    if (($57 | 0) == 71 || ($57 | 0) == 150 || ($57 | 0) == 70 || ($57 | 0) == 149) {
      __label__ = 38;
      break;
    } else if (($57 | 0) == 134) {
      __label__ = 39;
      break;
    } else if (($57 | 0) == 84 || ($57 | 0) == 216 || ($57 | 0) == 86 || ($57 | 0) == 215 || ($57 | 0) == 65) {
      __label__ = 41;
      break;
    } else if (($57 | 0) == 85 || ($57 | 0) == 87 || ($57 | 0) == 132 || ($57 | 0) == 140 || ($57 | 0) == 223) {
      __label__ = 43;
      break;
    } else if (($57 | 0) == 97 || ($57 | 0) == 98 || ($57 | 0) == 99 || ($57 | 0) == 100 || ($57 | 0) == 101 || ($57 | 0) == 102 || ($57 | 0) == 103 || ($57 | 0) == 104) {
      __label__ = 45;
      break;
    } else if (($57 | 0) == 82 || ($57 | 0) == 58 || ($57 | 0) == 123 || ($57 | 0) == 79 || ($57 | 0) == 108) {
      __label__ = 56;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 38:
    var $136 = HEAPU32[$saved >> 2];
    var $164 = HEAP32[$savedCount >> 2];
    __label__ = 47;
    break;
   case 39:
    var $137 = HEAPU32[$10 >> 2];
    if (($137 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $139 = HEAP32[$offset >> 2];
    var $i5_07 = 0;
    var $183 = $137;
    __label__ = 52;
    break;
   case 41:
    var $140 = HEAP32[$24 >> 2];
    var $141 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($140, $55);
    var $142 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $141);
    if ($142) {
      __label__ = 58;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $145 = HEAP32[$13 >> 2] + $141 * 12 | 0;
    var $146 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $145, $146, $saved, $savedCount);
    __label__ = 58;
    break;
   case 43:
    var $147 = HEAP32[$24 >> 2];
    var $148 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($147, $55);
    var $149 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $148);
    if ($149) {
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $152 = HEAP32[$13 >> 2] + $148 * 12 | 0;
    var $153 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $152, $153, $saved, $savedCount);
    __label__ = 58;
    break;
   case 45:
    var $154 = HEAP32[$24 >> 2];
    var $155 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($154, $55);
    var $156 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $155);
    if ($156) {
      __label__ = 58;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $159 = HEAP32[$13 >> 2] + $155 * 12 | 0;
    var $160 = HEAP32[$offset >> 2];
    __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $159, $160, $saved, $savedCount);
    var $162 = HEAP32[$13 >> 2] + $155 * 12 | 0;
    __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $162, $160, $saved, $savedCount);
    __label__ = 58;
    break;
   case 47:
    var $164;
    if (($164 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $167 = HEAP32[$136 >> 2];
    var $171 = HEAP32[$167 + 8 >> 2] & 2147483647;
    HEAP32[$1 >> 2] = $171;
    var $172 = $167 + 4 | 0;
    var $173 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($9, $offset, $1, $172);
    var $174 = $167 | 0;
    HEAP32[$174 >> 2] = $173;
    if (($173 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $177 = $136;
    __ZN9JSContext5free_EPv(undef, $177);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 88;
    break;
   case 50:
    HEAP32[$172 >> 2] = 0;
    var $179 = $164 - 1 | 0;
    HEAP32[$savedCount >> 2] = $179;
    var $181 = HEAP32[$136 + ($179 << 2) >> 2];
    HEAP32[$136 >> 2] = $181;
    var $164 = $179;
    __label__ = 47;
    break;
   case 51:
    HEAP32[$savedCount >> 2] = 0;
    __label__ = 58;
    break;
   case 52:
    var $183;
    var $i5_07;
    var $184 = HEAP32[$13 >> 2];
    var $185 = $184 + $i5_07 * 12 + 11 | 0;
    var $186 = HEAP8[$185];
    if ($186 << 24 >> 24 < 0) {
      __label__ = 53;
      break;
    } else {
      var $197 = $183;
      __label__ = 55;
      break;
    }
   case 53:
    if ((HEAP32[HEAP32[$184 + $i5_07 * 12 >> 2] >> 2] | 0) == ($139 | 0)) {
      __label__ = 54;
      break;
    } else {
      var $197 = $183;
      __label__ = 55;
      break;
    }
   case 54:
    var $195 = $186 & 127;
    HEAP8[$185] = $195;
    var $197 = HEAP32[$10 >> 2];
    __label__ = 55;
    break;
   case 55:
    var $197;
    var $198 = $i5_07 + 1 | 0;
    if ($198 >>> 0 < $197 >>> 0) {
      var $i5_07 = $198;
      var $183 = $197;
      __label__ = 52;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 56:
    if ($82) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP8[$loop_1 + 21 | 0] = 1;
    __label__ = 58;
    break;
   case 58:
    var $205 = HEAP32[_js_CodeSpec + ($57 << 3) + 4 >> 2] & 31;
    if (($205 | 0) == 9 || ($205 | 0) == 1) {
      __label__ = 59;
      break;
    } else {
      var $loop_2 = $loop_1;
      __label__ = 89;
      break;
    }
   case 59:
    var $206 = HEAP32[$24 >> 2];
    var $207 = HEAPU32[$offset >> 2];
    var $208 = __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($cx, $206, $207);
    if ($82) {
      __label__ = 60;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 60:
    var $211 = HEAPU32[$loop_1 + 12 >> 2];
    if (($211 | 0) == ($208 | 0)) {
      __label__ = 61;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 61:
    var $214 = $loop_1 + 16 | 0;
    if ($211 >>> 0 > HEAPU32[$214 >> 2] >>> 0) {
      __label__ = 62;
      break;
    } else {
      var $219 = $207;
      __label__ = 63;
      break;
    }
   case 62:
    HEAP32[$214 >> 2] = $211;
    var $219 = HEAP32[$offset >> 2];
    __label__ = 63;
    break;
   case 63:
    var $219;
    if ($208 >>> 0 < $219 >>> 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $221 = HEAP32[$saved >> 2];
    var $i8_0 = 0;
    var $266 = HEAP32[$savedCount >> 2];
    __label__ = 79;
    break;
   case 65:
    if ($82) {
      __label__ = 66;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 66:
    var $225 = HEAPU32[$loop_1 + 12 >> 2];
    var $226 = $loop_1 + 16 | 0;
    if ($225 >>> 0 > HEAPU32[$226 >> 2] >>> 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    HEAP32[$226 >> 2] = $225;
    __label__ = 68;
    break;
   case 68:
    var $231 = __ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool($9);
    if (($231 | 0) == 0) {
      __label__ = 69;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 69:
    var $235 = HEAP32[$saved >> 2];
    __ZN9JSContext5free_EPv(undef, $235);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 88;
    break;
   case 70:
    __ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_($231);
    if ($82) {
      __label__ = 71;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 71:
    HEAP8[$loop_1 + 21 | 0] = 1;
    __label__ = 72;
    break;
   case 72:
    var $239 = $231 | 0;
    HEAP32[$239 >> 2] = $loop_1;
    var $240 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $208);
    var $241 = $240 + 16 | 0;
    var $_c = $231;
    HEAP32[$241 >> 2] = $_c;
    var $242 = $231 + 4 | 0;
    HEAP32[$242 >> 2] = $208;
    var $243 = HEAP32[$offset >> 2];
    var $244 = $231 + 8 | 0;
    HEAP32[$244 >> 2] = $243;
    var $245 = $231 + 16 | 0;
    HEAP32[$245 >> 2] = $208;
    if (($208 | 0) == 0) {
      __label__ = 78;
      break;
    } else {
      var $entry_0 = $208;
      __label__ = 73;
      break;
    }
   case 73:
    var $entry_0;
    var $247 = $entry_0 - 1 | 0;
    var $248 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $247);
    if (($248 | 0) == 0) {
      var $entry_0 = $247;
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $251 = HEAP32[$24 >> 2];
    var $254 = HEAP32[$251 >> 2] + $247 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap7, $cx, $251, $254);
    var $255 = HEAP8[$254];
    if ($255 << 24 >> 24 == 6 || $255 << 24 >> 24 == -115) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    var $257 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($255, $254);
    var $258 = $257 + $247 | 0;
    var $259 = $231 + 12 | 0;
    HEAP32[$259 >> 2] = $258;
    __label__ = 77;
    break;
   case 76:
    var $261 = $231 + 12 | 0;
    HEAP32[$261 >> 2] = $208;
    __label__ = 77;
    break;
   case 77:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap7);
    var $loop_2 = $231;
    __label__ = 89;
    break;
   case 78:
    var $264 = $231 + 12 | 0;
    HEAP32[$264 >> 2] = 0;
    var $loop_2 = $231;
    __label__ = 89;
    break;
   case 79:
    var $266;
    var $i8_0;
    if ($i8_0 >>> 0 < $266 >>> 0) {
      __label__ = 80;
      break;
    } else {
      var $loop_2 = $loop_1;
      __label__ = 89;
      break;
    }
   case 80:
    var $269 = $221 + ($i8_0 << 2) | 0;
    var $270 = HEAPU32[$269 >> 2];
    var $271 = __ZNK2js7analyze16LifetimeVariable4liveEj($270, $208);
    if (($271 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $277 = HEAP32[$270 + 8 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $277;
    var $278 = $270 + 4 | 0;
    var $279 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($9, $offset, $2, $278);
    var $280 = $270 | 0;
    HEAP32[$280 >> 2] = $279;
    if (($279 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    var $283 = $221;
    __ZN9JSContext5free_EPv(undef, $283);
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 88;
    break;
   case 83:
    HEAP32[$278 >> 2] = 0;
    var $285 = $266 - 1 | 0;
    HEAP32[$savedCount >> 2] = $285;
    var $287 = HEAP32[$221 + ($285 << 2) >> 2];
    HEAP32[$269 >> 2] = $287;
    var $i8_1 = $i8_0 - 1 | 0;
    var $302 = $285;
    __label__ = 87;
    break;
   case 84:
    if ($82) {
      __label__ = 85;
      break;
    } else {
      var $i8_1 = $i8_0;
      var $302 = $266;
      __label__ = 87;
      break;
    }
   case 85:
    var $292 = $270 + 8 | 0;
    var $293 = HEAP32[$292 >> 2];
    if (($293 & 2147483647 | 0) == 0) {
      __label__ = 86;
      break;
    } else {
      var $i8_1 = $i8_0;
      var $302 = $266;
      __label__ = 87;
      break;
    }
   case 86:
    var $300 = HEAP32[$offset >> 2] & 2147483647 | $293 & -2147483648;
    HEAP32[$292 >> 2] = $300;
    var $i8_1 = $i8_0;
    var $302 = $266;
    __label__ = 87;
    break;
   case 87:
    var $302;
    var $i8_1;
    var $i8_0 = $i8_1 + 1 | 0;
    var $266 = $302;
    __label__ = 79;
    break;
   case 88:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 91;
    break;
   case 89:
    var $loop_2;
    var $305 = HEAP32[$offset >> 2] - 1 | 0;
    HEAP32[$offset >> 2] = $305;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_pre = HEAPU32[$24 >> 2];
    var $loop_0_ph = $loop_2;
    var $31 = $_pre;
    var $30 = HEAP32[$_pre + 8 >> 2];
    var $29 = $305;
    __label__ = 8;
    break;
   case 90:
    var $308 = HEAP32[$saved >> 2];
    __ZN9JSContext5free_EPv(undef, $308);
    HEAP8[$this + 22 | 0] = 1;
    __label__ = 91;
    break;
   case 91:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext["X"] = 1;

function __ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj($this, $cx, $var, $start, $end) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $savedEnd = __stackBase__;
    var $1 = __stackBase__ + 4;
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $var | 0;
    var $8 = HEAP32[$6 >> 2] | 0;
    HEAP32[$8 >> 2] = $start;
    var $9 = $cx + 56 | 0;
    var $segment_0_in = $6;
    __label__ = 3;
    break;
   case 3:
    var $segment_0_in;
    var $segment_0 = HEAPU32[$segment_0_in >> 2];
    if (($segment_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAPU32[$segment_0 >> 2] >>> 0 < $end >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $16 = $segment_0 + 8 | 0;
    var $17 = HEAPU32[$16 >> 2];
    HEAP32[$savedEnd >> 2] = $17;
    var $18 = $segment_0 + 16 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAPU32[$19 >> 2] >>> 0 < $end >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = $17;
    var $31 = HEAP32[$segment_0 + 4 >> 2];
    __label__ = 10;
    break;
   case 8:
    var $27 = HEAPU32[$segment_0 + 4 >> 2];
    if ($27 >>> 0 < $end >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    HEAP32[$savedEnd >> 2] = $end;
    var $32 = $end;
    var $31 = $27;
    __label__ = 10;
    break;
   case 10:
    var $31;
    var $32;
    var $33 = $segment_0 + 4 | 0;
    if ($32 >>> 0 > $31 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $segment_0_in = $18;
      __label__ = 3;
      break;
    }
   case 11:
    var $37 = HEAP32[$9 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = 0;
    var $38 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($37, $savedEnd, $1, $18);
    if (($38 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 16;
    break;
   case 13:
    var $42 = HEAP32[$33 >> 2];
    var $43 = $38 | 0;
    HEAP32[$43 >> 2] = $42;
    HEAP8[$38 + 12 | 0] = 1;
    var $45 = HEAPU32[$16 >> 2];
    if ($45 >>> 0 > $end >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $48 = $38 + 8 | 0;
    HEAP32[$48 >> 2] = $45;
    __label__ = 15;
    break;
   case 15:
    HEAP32[$16 >> 2] = 0;
    HEAP32[$18 >> 2] = $38;
    var $segment_0_in = $38 + 16 | 0;
    __label__ = 3;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj["X"] = 1;

function __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$pc] & 255;
    if (($2 | 0) == 84 || ($2 | 0) == 216 || ($2 | 0) == 85 || ($2 | 0) == 97 || ($2 | 0) == 98 || ($2 | 0) == 99 || ($2 | 0) == 100) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 86 || ($2 | 0) == 215 || ($2 | 0) == 87 || ($2 | 0) == 132 || ($2 | 0) == 140 || ($2 | 0) == 223 || ($2 | 0) == 101 || ($2 | 0) == 102 || ($2 | 0) == 103 || ($2 | 0) == 104) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 65) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $12 = __ZN2js7analyzeL7ArgSlotEj($11);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 3:
    var $21 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $22 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($script, $21);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $var, $offset, $saved, $savedCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $offset;
    var $3 = $var | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $4 | 0;
    HEAP32[$11 >> 2] = $offset;
    __label__ = 13;
    break;
   case 4:
    var $13 = $var + 4 | 0;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = HEAPU32[$savedCount >> 2];
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $16 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if ((HEAP32[HEAP32[$saved >> 2] + ($i_0 << 2) >> 2] | 0) == ($var | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = $16 - 1 | 0;
    HEAP32[$savedCount >> 2] = $25;
    var $26 = HEAP32[$saved >> 2];
    var $28 = HEAP32[$26 + ($25 << 2) >> 2];
    var $29 = $26 + ($i_0 << 2) | 0;
    HEAP32[$29 >> 2] = $28;
    __label__ = 10;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 10:
    var $34 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $38 = HEAP32[$var + 8 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $38;
    var $39 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($34, $1, $2, $13);
    HEAP32[$3 >> 2] = $39;
    if (($39 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 13;
    break;
   case 12:
    HEAP32[$13 >> 2] = 0;
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj["X"] = 1;

function __ZNK2js7analyze16LifetimeVariable4liveEj($this, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[$2 + 4 >> 2] >>> 0 < $offset >>> 0) {
      var $segment_0 = $2;
      __label__ = 4;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 3:
    var $segment_0 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $segment_0;
    if (($segment_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (HEAPU32[$segment_0 >> 2] >>> 0 > $offset >>> 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAPU32[$segment_0 + 4 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $segment_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $segment_0 = HEAP32[$segment_0 + 16 >> 2];
    __label__ = 4;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj($this, $cx, $var, $offset, $saved, $savedCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $offset;
    var $3 = $var | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = $var + 4 | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = HEAP32[$savedCount >> 2];
    var $12 = $11 + 1 | 0;
    HEAP32[$savedCount >> 2] = $12;
    var $14 = HEAP32[$saved >> 2] + ($11 << 2) | 0;
    HEAP32[$14 >> 2] = $var;
    __label__ = 4;
    break;
   case 4:
    var $18 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $20 = $var + 8 | 0;
    var $22 = HEAP32[$20 >> 2] & 2147483647;
    HEAP32[$2 >> 2] = $22;
    var $23 = __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($18, $1, $2, $7);
    HEAP32[$7 >> 2] = $23;
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 9;
    break;
   case 6:
    HEAP8[$23 + 13 | 0] = 1;
    var $29 = HEAP32[$20 >> 2] & -2147483648;
    HEAP32[$20 >> 2] = $29;
    __label__ = 9;
    break;
   case 7:
    if (HEAP8[$var + 11 | 0] << 24 >> 24 < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $4 | 0;
    HEAP32[$35 >> 2] = $offset;
    HEAP8[HEAP32[$3 >> 2] + 13 | 0] = 1;
    var $38 = HEAP32[$3 >> 2];
    HEAP32[$var + 4 >> 2] = $38;
    var $41 = $var + 8 | 0;
    var $43 = HEAP32[$41 >> 2] & -2147483648;
    HEAP32[$41 >> 2] = $43;
    HEAP32[$3 >> 2] = 0;
    var $44 = HEAP32[$savedCount >> 2];
    var $45 = $44 + 1 | 0;
    HEAP32[$savedCount >> 2] = $45;
    var $47 = HEAP32[$saved >> 2] + ($44 << 2) | 0;
    HEAP32[$47 >> 2] = $var;
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj["X"] = 1;

function __ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN2js7analyze8LifetimeC1EjjPS1_($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($cx, $script, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $2 = HEAP32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $_val1 = HEAP8[$3];
    var $4 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val1, $3);
    var $uadd = _llvm_uadd_with_overflow_i32($4, $offset);
    var $5 = $uadd.f0;
    var $6 = $uadd.f1;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $5;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = $2 + $5 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $8);
    var $9 = HEAP8[$8];
    if ($9 << 24 >> 24 == -115 || $9 << 24 >> 24 == 6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($9, $8);
    var $11 = $10 + $5 | 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $11;
    __label__ = 5;
    break;
   case 4:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $5;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $_p_0;
    HEAP32[$24 >> 2] = 0;
    HEAP32[$24 + 4 >> 2] = 0;
    HEAP32[$24 + 8 >> 2] = 0;
    HEAP32[$24 + 12 >> 2] = 0;
    HEAP32[$24 + 16 >> 2] = 0;
    HEAP32[$24 + 20 >> 2] = 0;
    var $26 = $_p_0;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 24, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis16clearAllocationsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if ((HEAP32[$2 + 8 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      var $6 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $6;
    var $i_01;
    var $7 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $i_01);
    if (($7 | 0) == 0) {
      var $12 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$7 + 20 >> 2] = 0;
    var $12 = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $12;
    var $13 = $i_01 + 1 | 0;
    if ($13 >>> 0 < HEAPU32[$12 + 8 >> 2] >>> 0) {
      var $i_01 = $13;
      var $6 = $12;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12ranLifetimesEv($this) {
  return (HEAP8[$this + 22 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $free = __stackBase__;
    var $branchTargets = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $untrap = __stackBase__ + 36;
    var $ov = __stackBase__ + 44;
    var $ov2 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $3 = __ZN2js7analyze14ScriptAnalysis12ranLifetimesEv($this);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext($this, $cx);
    var $5 = __ZN2js7analyze14ScriptAnalysis6failedEv($this);
    if ($5) {
      __label__ = 115;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cx + 56 | 0;
    var $9 = HEAP32[$7 >> 2] + 344 | 0;
    var $10 = $this | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $18 = $this + 8 | 0;
    var $22 = HEAP32[$18 >> 2] + (HEAPU16[$11 + 44 >> 1] & 65535) - (HEAPU16[$11 + 14 >> 1] & 65535) << 3;
    var $23 = __ZN9JSContext7calloc_Ej($cx, $22);
    var $24 = $23;
    if (($23 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 115;
    break;
   case 5:
    __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE($free, $cx, $24);
    var $28 = HEAPU32[$18 >> 2];
    var $29 = __ZN2js7analyzeL7ArgSlotEj(0);
    if ($29 >>> 0 < $28 >>> 0) {
      var $slot_067 = $29;
      var $31 = $28;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $31;
    var $slot_067;
    var $32 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot_067);
    if ($32) {
      __label__ = 7;
      break;
    } else {
      var $36 = $31;
      __label__ = 8;
      break;
    }
   case 7:
    var $34 = $24 + ($slot_067 << 3) | 0;
    __ZN2js7analyze8SSAValue11initInitialEj($34, $slot_067);
    var $36 = HEAP32[$18 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $36;
    var $37 = $slot_067 + 1 | 0;
    if ($37 >>> 0 < $36 >>> 0) {
      var $slot_067 = $37;
      var $31 = $36;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($branchTargets, $1);
    var $39 = $28 - 1 | 0;
    var $40 = $28 - 2 | 0;
    var $41 = $28 - 3 | 0;
    var $42 = $28 - 4 | 0;
    var $43 = $ov;
    var $44 = $ov2;
    var $stackDepth_0 = 0;
    var $offset_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $offset_0;
    var $stackDepth_0;
    var $46 = HEAPU32[$10 >> 2];
    if ($offset_0 >>> 0 < HEAPU32[$46 + 8 >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 11:
    var $52 = HEAPU32[$46 >> 2];
    var $53 = $52 + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $46, $53);
    var $54 = HEAPU8[$53];
    var $55 = $54 & 255;
    var $56 = __ZN2js7analyzeL17GetBytecodeLengthEPh($53);
    var $57 = $56 + $offset_0 | 0;
    var $58 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($this, $53);
    if (($58 | 0) == 0) {
      var $stackDepth_1_ph35 = $stackDepth_0;
      __label__ = 112;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $62 = HEAPU32[$58 + 4 >> 2];
    if ($62 >>> 0 > $stackDepth_0 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $65 = $24 + ($stackDepth_0 + $28 << 3) | 0;
    var $66 = $62 - $stackDepth_0 | 0;
    __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j($65, $66);
    __label__ = 14;
    break;
   case 14:
    if ($54 << 24 >> 24 == -74 || $54 << 24 >> 24 == 109) {
      __label__ = 15;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 15:
    var $70 = $58 + 16 | 0;
    if ((HEAP32[$70 >> 2] | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $74 = $58 + 32 | 0;
    var $75 = $74;
    if ((HEAP32[$75 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj(undef, $branchTargets, $offset_0);
    __label__ = 18;
    break;
   case 18:
    var $79 = $58 | 0;
    var $i_0 = 0;
    __label__ = 21;
    break;
   case 19:
    var $81 = __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    HEAP32[$74 >> 2] = $81;
    if (($81 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 20:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 21:
    var $i_0;
    var $86 = HEAPU32[$75 >> 2];
    var $87 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($86);
    if ($i_0 >>> 0 < $87 >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $slot1_0 = $29;
      __label__ = 31;
      break;
    }
   case 22:
    var $90 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($86, $i_0);
    var $91 = $90 | 0;
    var $92 = HEAPU32[$91 >> 2];
    if ($92 >>> 0 < HEAPU32[$18 >> 2] >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 23:
    var $96 = __ZN2js7analyze14ScriptAnalysis8livenessEj($this, $92);
    var $97 = HEAP32[$70 >> 2];
    var $98 = __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($96, $97);
    if (($98 | 0) == -1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $101 = $90 + 4 | 0;
    var $102 = __ZNK2js7analyze8SSAValue4kindEv($101);
    if (($102 | 0) == 3) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $105 = __ZNK2js7analyze8SSAValue9phiOffsetEv($101);
    if ($105 >>> 0 < $offset_0 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $108 = $101;
    var $st$1$0 = $108 | 0;
    var $109$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $108 + 4 | 0;
    var $109$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $43 | 0;
    HEAP32[$st$5$0 >> 2] = $109$0;
    var $st$5$1 = $43 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $109$1;
    var $110 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $92, $offset_0, $ov);
    if ($110) {
      __label__ = 27;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 27:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $ov, $101);
    var $st$1$0 = $43 | 0;
    var $112$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $43 + 4 | 0;
    var $112$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $108 | 0;
    HEAP32[$st$5$0 >> 2] = $112$0;
    var $st$5$1 = $108 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $112$1;
    __label__ = 28;
    break;
   case 28:
    if ((HEAP8[$79] & 12) << 24 >> 24 == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $119 = $24 + (HEAP32[$91 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset_0, $119, $90);
    __label__ = 30;
    break;
   case 30:
    var $120 = HEAP32[$91 >> 2];
    var $121 = $24 + ($120 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $121, $120, $branchTargets);
    var $125 = $90 + 4 | 0;
    var $126 = $24 + (HEAP32[$91 >> 2] << 3) | 0;
    var $st$8$0 = $125 | 0;
    var $127$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $125 + 4 | 0;
    var $127$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $126 | 0;
    HEAP32[$st$12$0 >> 2] = $127$0;
    var $st$12$1 = $126 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $127$1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 21;
    break;
   case 31:
    var $slot1_0;
    var $129 = HEAPU32[$18 >> 2];
    if ($slot1_0 >>> 0 < ($129 + $62 | 0) >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 32:
    if ($slot1_0 >>> 0 < $129 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 33:
    var $135 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot1_0);
    if ($135) {
      __label__ = 34;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 34:
    var $137 = __ZN2js7analyze14ScriptAnalysis8livenessEj($this, $slot1_0);
    var $138 = HEAP32[$70 >> 2];
    var $139 = __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($137, $138);
    if (($139 | 0) == -1) {
      __label__ = 42;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $142 = $24 + ($slot1_0 << 3) | 0;
    var $143 = __ZNK2js7analyze8SSAValue4kindEv($142);
    if (($143 | 0) == 3) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $146 = __ZNK2js7analyze8SSAValue9phiOffsetEv($142);
    if (($146 | 0) == ($offset_0 | 0)) {
      __label__ = 42;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $149 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $slot1_0, $offset_0, $ov2);
    if ($149) {
      __label__ = 38;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 38:
    if ((HEAP8[$79] & 12) << 24 >> 24 == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $ov2, $142);
    __label__ = 40;
    break;
   case 40:
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $142, $slot1_0, $branchTargets);
    var $156 = $142;
    var $157$0 = HEAP32[$44 >> 2];
    var $157$1 = HEAP32[$44 + 4 >> 2];
    var $st$6$0 = $156 | 0;
    HEAP32[$st$6$0 >> 2] = $157$0;
    var $st$6$1 = $156 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $157$1;
    var $158 = HEAP32[$75 >> 2];
    __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($2, $slot1_0, $ov2);
    var $159 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($158, $2);
    if ($159) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 42:
    var $slot1_0 = $slot1_0 + 1 | 0;
    __label__ = 31;
    break;
   case 43:
    var $165 = $58 + 32 | 0;
    if ((HEAP32[$165 >> 2] | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj(undef, $branchTargets, $offset_0);
    var $169 = HEAP32[$165 >> 2];
    var $170 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($169);
    if (($170 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $172 = $58 | 0;
    var $i4_055 = 0;
    __label__ = 46;
    break;
   case 46:
    var $i4_055;
    var $174 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($169, $i4_055);
    var $_pre26 = $174 | 0;
    if ((HEAP8[$172] & 12) << 24 >> 24 == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $180 = $24 + (HEAP32[$_pre26 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset_0, $180, $174);
    __label__ = 48;
    break;
   case 48:
    var $181 = HEAP32[$_pre26 >> 2];
    var $182 = $24 + ($181 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $182, $181, $branchTargets);
    var $186 = $174 + 4 | 0;
    var $187 = $24 + (HEAP32[$_pre26 >> 2] << 3) | 0;
    var $st$8$0 = $186 | 0;
    var $188$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $186 + 4 | 0;
    var $188$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $187 | 0;
    HEAP32[$st$12$0 >> 2] = $188$0;
    var $st$12$1 = $187 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $188$1;
    var $189 = $i4_055 + 1 | 0;
    var $190 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($169);
    if ($189 >>> 0 < $190 >>> 0) {
      var $i4_055 = $189;
      __label__ = 46;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $offset_0);
    __label__ = 50;
    break;
   case 50:
    var $193 = HEAPU32[_js_CodeSpec + ($55 << 3) + 4 >> 2];
    if (($193 & 134217728 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      var $stackDepth_1_ph35 = $62;
      __label__ = 112;
      break;
    }
   case 51:
    var $197 = HEAP32[$10 >> 2];
    var $_idx_val = HEAP32[$197 >> 2];
    var $198 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj($_idx_val, $offset_0);
    var $199 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($197, $offset_0);
    var $_val5 = HEAP8[$53];
    var $200 = __ZN2js7analyzeL11ExtendedUseEPh($_val5);
    var $201 = $200 & 1;
    var $202 = $201 + $198 | 0;
    if (($202 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $205 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($9, $202);
    var $206 = $58 + 24 | 0;
    HEAP32[$206 >> 2] = $205;
    if (($205 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($198 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $209 = $39 + $62 | 0;
    var $i6_049 = 0;
    var $212 = $205;
    __label__ = 56;
    break;
   case 55:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 56:
    var $212;
    var $i6_049;
    var $213 = $24 + ($209 - $i6_049 << 3) | 0;
    var $215 = $213;
    var $216 = $212 + ($i6_049 << 3) | 0;
    var $st$7$0 = $215 | 0;
    var $217$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $215 + 4 | 0;
    var $217$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $216 | 0;
    HEAP32[$st$11$0 >> 2] = $217$0;
    var $st$11$1 = $216 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $217$1;
    __ZN2js7analyze8SSAValue5clearEv($213);
    var $218 = $i6_049 + 1 | 0;
    if (($218 | 0) == ($198 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $i6_049 = $218;
    var $212 = HEAP32[$206 >> 2];
    __label__ = 56;
    break;
   case 58:
    if ($202 >>> 0 > $198 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $221 = HEAP32[$10 >> 2];
    var $222 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($221, $53);
    var $223 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $222);
    var $225 = HEAP32[$206 >> 2] + ($198 << 3) | 0;
    if ($223) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    var $228 = $24 + ($222 << 3) | 0;
    var $229 = $225;
    var $230$0 = HEAP32[$228 >> 2];
    var $230$1 = HEAP32[$228 + 4 >> 2];
    var $st$7$0 = $229 | 0;
    HEAP32[$st$7$0 >> 2] = $230$0;
    var $st$7$1 = $229 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $230$1;
    __label__ = 62;
    break;
   case 61:
    __ZN2js7analyze8SSAValue5clearEv($225);
    __label__ = 62;
    break;
   case 62:
    var $234 = HEAP32[$7 >> 2] + 344 | 0;
    var $235 = __ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($234, $202);
    if (($235 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 64:
    __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j($235, $202);
    var $238 = $offset_0 << 1;
    var $239 = $198 + $201 | 0;
    var $i9_052 = 0;
    __label__ = 65;
    break;
   case 65:
    var $i9_052;
    var $241 = HEAP32[$206 >> 2] + ($i9_052 << 3) | 0;
    var $242 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE(undef, $241);
    if ($242) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    var $244 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $241);
    var $245 = $235 + $i9_052 * 12 | 0;
    var $246 = $245 | 0;
    var $248 = HEAP8[$246] | 1;
    HEAP8[$246] = $248;
    var $249 = $245;
    var $252 = HEAP32[$249 >> 2] & 1 | $238;
    HEAP32[$249 >> 2] = $252;
    var $253 = $235 + $i9_052 * 12 + 4 | 0;
    HEAP32[$253 >> 2] = $i9_052;
    var $254 = HEAP32[$244 >> 2];
    var $255 = $235 + $i9_052 * 12 + 8 | 0;
    HEAP32[$255 >> 2] = $254;
    HEAP32[$244 >> 2] = $245;
    __label__ = 67;
    break;
   case 67:
    var $257 = $i9_052 + 1 | 0;
    if (($257 | 0) == ($239 | 0)) {
      __label__ = 68;
      break;
    } else {
      var $i9_052 = $257;
      __label__ = 65;
      break;
    }
   case 68:
    var $258 = $62 - $198 | 0;
    if (($199 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $260 = $258 + $28 | 0;
    var $i11_063 = 0;
    __label__ = 70;
    break;
   case 70:
    var $i11_063;
    var $262 = $24 + ($260 + $i11_063 << 3) | 0;
    __ZN2js7analyze8SSAValue10initPushedEjj($262, $offset_0, $i11_063);
    var $263 = $i11_063 + 1 | 0;
    if (($263 | 0) == ($199 | 0)) {
      __label__ = 71;
      break;
    } else {
      var $i11_063 = $263;
      __label__ = 70;
      break;
    }
   case 71:
    var $_val4 = HEAP8[$53];
    var $264 = __ZN2js7analyzeL11ExtendedDefEPh($_val4);
    var $266 = ($264 & 1) + $199 | 0;
    if (($266 | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $270 = HEAP32[$7 >> 2] + 344 | 0;
    var $271 = __ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($270, $266);
    HEAP32[$58 + 28 >> 2] = $271;
    if (($271 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 111;
    break;
   case 74:
    __ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j($271, $266);
    __label__ = 75;
    break;
   case 75:
    var $277 = $258 + $199 | 0;
    if (($55 | 0) == 85 || ($55 | 0) == 87 || ($55 | 0) == 132 || ($55 | 0) == 140 || ($55 | 0) == 223 || ($55 | 0) == 97 || ($55 | 0) == 98 || ($55 | 0) == 99 || ($55 | 0) == 100 || ($55 | 0) == 101 || ($55 | 0) == 102 || ($55 | 0) == 103 || ($55 | 0) == 104) {
      __label__ = 76;
      break;
    } else if (($55 | 0) == 84 || ($55 | 0) == 86) {
      __label__ = 78;
      break;
    } else if (($55 | 0) == 216 || ($55 | 0) == 215) {
      __label__ = 80;
      break;
    } else if (($55 | 0) == 76) {
      __label__ = 82;
      break;
    } else if (($55 | 0) == 93 || ($55 | 0) == 227) {
      __label__ = 83;
      break;
    } else if (($55 | 0) == 94) {
      __label__ = 84;
      break;
    } else if (($55 | 0) == 12) {
      __label__ = 85;
      break;
    } else if (($55 | 0) == 13) {
      __label__ = 86;
      break;
    } else if (($55 | 0) == 10 || ($55 | 0) == 133) {
      __label__ = 87;
      break;
    } else if (($55 | 0) == 70 || ($55 | 0) == 149) {
      __label__ = 92;
      break;
    } else if (($55 | 0) == 71 || ($55 | 0) == 150) {
      __label__ = 98;
      break;
    } else if (($55 | 0) == 134) {
      __label__ = 101;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 76:
    var $279 = HEAP32[$10 >> 2];
    var $280 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($279, $53);
    var $281 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $280);
    if ($281) {
      __label__ = 77;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 77:
    var $283 = $24 + ($280 << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $283, $280, $branchTargets);
    __ZN2js7analyze8SSAValue11initWrittenEjj($283, $280, $offset_0);
    __label__ = 108;
    break;
   case 78:
    var $285 = HEAP32[$10 >> 2];
    var $286 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($285, $53);
    var $287 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $286);
    if ($287) {
      __label__ = 79;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 79:
    var $_sum25 = $39 + $277 | 0;
    var $292 = $24 + ($286 << 3) | 0;
    var $293 = HEAP32[$58 + 24 >> 2];
    var $st$6$0 = $292 | 0;
    var $294$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $292 + 4 | 0;
    var $294$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $293 | 0;
    HEAP32[$st$10$0 >> 2] = $294$0;
    var $st$10$1 = $293 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $294$1;
    var $296 = $24 + ($_sum25 << 3) | 0;
    var $st$16$0 = $296 | 0;
    HEAP32[$st$16$0 >> 2] = $294$0;
    var $st$16$1 = $296 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $294$1;
    __label__ = 108;
    break;
   case 80:
    var $298 = HEAP32[$10 >> 2];
    var $299 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh($298, $53);
    var $300 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $299);
    if ($300) {
      __label__ = 81;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 81:
    var $_sum24 = $40 + $277 | 0;
    var $305 = $24 + ($299 << 3) | 0;
    var $306 = HEAP32[$58 + 24 >> 2];
    var $st$6$0 = $305 | 0;
    var $307$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $305 + 4 | 0;
    var $307$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $306 | 0;
    HEAP32[$st$10$0 >> 2] = $307$0;
    var $st$10$1 = $306 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $307$1;
    var $309 = $24 + ($_sum24 << 3) | 0;
    var $st$16$0 = $309 | 0;
    HEAP32[$st$16$0 >> 2] = $307$0;
    var $st$16$1 = $309 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $307$1;
    __label__ = 108;
    break;
   case 82:
    var $314 = HEAP32[$58 + 24 >> 2];
    var $315 = $24 + ($40 + $277 << 3) | 0;
    var $st$6$0 = $314 | 0;
    var $316$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $314 + 4 | 0;
    var $316$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $315 | 0;
    HEAP32[$st$10$0 >> 2] = $316$0;
    var $st$10$1 = $315 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $316$1;
    __label__ = 108;
    break;
   case 83:
    var $321 = HEAP32[$58 + 24 >> 2] + 8 | 0;
    var $322 = $24 + ($39 + $277 << 3) | 0;
    var $st$7$0 = $321 | 0;
    var $323$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $321 + 4 | 0;
    var $323$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $322 | 0;
    HEAP32[$st$11$0 >> 2] = $323$0;
    var $st$11$1 = $322 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $323$1;
    __label__ = 108;
    break;
   case 84:
    var $329 = HEAP32[$58 + 24 >> 2] + 16 | 0;
    var $330 = $24 + ($39 + $277 << 3) | 0;
    var $st$7$0 = $329 | 0;
    var $331$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $329 + 4 | 0;
    var $331$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $330 | 0;
    HEAP32[$st$11$0 >> 2] = $331$0;
    var $st$11$1 = $330 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $331$1;
    __label__ = 108;
    break;
   case 85:
    var $_sum19 = $39 + $277 | 0;
    var $336 = HEAP32[$58 + 24 >> 2];
    var $337 = $24 + ($40 + $277 << 3) | 0;
    var $st$7$0 = $336 | 0;
    var $338$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $336 + 4 | 0;
    var $338$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $337 | 0;
    HEAP32[$st$11$0 >> 2] = $338$0;
    var $st$11$1 = $337 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $338$1;
    var $340 = $24 + ($_sum19 << 3) | 0;
    var $st$17$0 = $340 | 0;
    HEAP32[$st$17$0 >> 2] = $338$0;
    var $st$17$1 = $340 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $338$1;
    __label__ = 108;
    break;
   case 86:
    var $_sum15 = $39 + $277 | 0;
    var $342 = $58 + 24 | 0;
    var $345 = HEAP32[$342 >> 2];
    var $346 = $24 + ($41 + $277 << 3) | 0;
    var $st$7$0 = $345 | 0;
    var $347$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $345 + 4 | 0;
    var $347$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $346 | 0;
    HEAP32[$st$11$0 >> 2] = $347$0;
    var $st$11$1 = $346 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $347$1;
    var $349 = $24 + ($_sum15 << 3) | 0;
    var $st$17$0 = $349 | 0;
    HEAP32[$st$17$0 >> 2] = $347$0;
    var $st$17$1 = $349 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $347$1;
    var $_sum17 = $40 + $277 | 0;
    var $353 = HEAP32[$342 >> 2] + 8 | 0;
    var $354 = $24 + ($42 + $277 << 3) | 0;
    var $355$0 = HEAP32[$353 >> 2];
    var $355$1 = HEAP32[$353 + 4 >> 2];
    var $st$32$0 = $354 | 0;
    HEAP32[$st$32$0 >> 2] = $355$0;
    var $st$32$1 = $354 + 4 | 0;
    HEAP32[$st$32$1 >> 2] = $355$1;
    var $357 = $24 + ($_sum17 << 3) | 0;
    var $st$38$0 = $357 | 0;
    HEAP32[$st$38$0 >> 2] = $355$0;
    var $st$38$1 = $357 + 4 | 0;
    HEAP32[$st$38$1 >> 2] = $355$1;
    __label__ = 108;
    break;
   case 87:
    if ($54 << 24 >> 24 == 10) {
      var $364 = 1;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $364 = HEAPU8[$offset_0 + ($52 + 1) | 0] & 255;
    __label__ = 89;
    break;
   case 89:
    var $364;
    var $365 = $58 + 24 | 0;
    var $369 = HEAP32[$365 >> 2] + ($364 << 3) | 0;
    var $370 = $24 + ($39 + $277 << 3) | 0;
    var $st$8$0 = $369 | 0;
    var $371$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $369 + 4 | 0;
    var $371$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $370 | 0;
    HEAP32[$st$12$0 >> 2] = $371$0;
    var $st$12$1 = $370 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $371$1;
    if (($364 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $373 = $40 + $277 | 0;
    var $i15_047 = 0;
    __label__ = 91;
    break;
   case 91:
    var $i15_047;
    var $378 = HEAP32[$365 >> 2] + ($i15_047 << 3) | 0;
    var $379 = $24 + ($373 - $i15_047 << 3) | 0;
    var $st$7$0 = $378 | 0;
    var $380$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $378 + 4 | 0;
    var $380$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $379 | 0;
    HEAP32[$st$11$0 >> 2] = $380$0;
    var $st$11$1 = $379 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $380$1;
    var $381 = $i15_047 + 1 | 0;
    if (($381 | 0) == ($364 | 0)) {
      __label__ = 108;
      break;
    } else {
      var $i15_047 = $381;
      __label__ = 91;
      break;
    }
   case 92:
    var $383 = $54 << 24 >> 24 == 70 ? 2 : 4;
    var $_val3 = HEAP8[$53];
    var $384 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val3, $53);
    var $385 = $384 + $offset_0 | 0;
    var $_sum7 = $383 + $offset_0 | 0;
    var $393 = (HEAPU8[$_sum7 + ($52 + 1) | 0] & 255) << 8 | HEAPU8[$_sum7 + ($52 + 2) | 0] & 255;
    var $398 = $_sum7 + ($52 + 4) | 0;
    var $401 = (HEAPU8[$_sum7 + ($52 + 3) | 0] & 255) << 8 | HEAPU8[$398] & 255;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $385, $branchTargets, $24, undef);
    if ($393 << 16 >> 16 > $401 << 16 >> 16) {
      __label__ = 108;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $405 = ($401 << 16 >> 16) + 1 | 0;
    var $pc2_037 = $398;
    var $i16_038 = $393 << 16 >> 16;
    __label__ = 94;
    break;
   case 94:
    var $i16_038;
    var $pc2_037;
    var $_val2 = HEAP8[$53];
    var $407 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val2, $pc2_037);
    if (($407 | 0) == 0) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $410 = $407 + $offset_0 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $410, $branchTargets, $24, undef);
    __label__ = 96;
    break;
   case 96:
    var $412 = $i16_038 + 1 | 0;
    if (($412 | 0) == ($405 | 0)) {
      __label__ = 108;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $pc2_037 = $pc2_037 + $383 | 0;
    var $i16_038 = $412;
    __label__ = 94;
    break;
   case 98:
    var $415 = $54 << 24 >> 24 == 71 ? 2 : 4;
    var $_val1 = HEAP8[$53];
    var $416 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val1, $53);
    var $417 = $416 + $offset_0 | 0;
    var $_sum = $415 + $offset_0 | 0;
    var $422 = $_sum + ($52 + 2) | 0;
    var $425 = (HEAPU8[$_sum + ($52 + 1) | 0] & 255) << 8 | HEAPU8[$422] & 255;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $417, $branchTargets, $24, undef);
    if (($425 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $_sum6 = $415 + 2 | 0;
    var $pc217_040 = $422;
    var $npairs_041 = $425;
    __label__ = 100;
    break;
   case 100:
    var $npairs_041;
    var $pc217_040;
    var $_val = HEAP8[$53];
    var $429 = __ZN2js7analyzeL13GetJumpOffsetEPhS1_($_val, $pc217_040 + 2 | 0);
    var $430 = $429 + $offset_0 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $430, $branchTargets, $24, undef);
    var $431 = $pc217_040 + $_sum6 | 0;
    var $432 = $npairs_041 - 1 | 0;
    if (($432 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      var $pc217_040 = $431;
      var $npairs_041 = $432;
      __label__ = 100;
      break;
    }
   case 101:
    var $435 = HEAP32[$10 >> 2];
    var $436 = __ZN8JSScript8trynotesEv($435);
    var $438 = HEAP32[$436 >> 2];
    var $440 = HEAP32[$436 + 4 >> 2];
    var $441 = $438 + $440 * 12 | 0;
    if (($440 | 0) > 0) {
      __label__ = 102;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 102:
    var $443 = $offset_0 + 1 | 0;
    var $tn_044 = $438;
    var $445 = $435;
    __label__ = 103;
    break;
   case 103:
    var $445;
    var $tn_044;
    var $450 = HEAP32[$tn_044 + 4 >> 2] + HEAP32[$445 + 32 >> 2] | 0;
    if (($450 | 0) == ($443 | 0)) {
      __label__ = 104;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 104:
    if (HEAP8[$tn_044 | 0] << 24 >> 24 == 2) {
      __label__ = 106;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $459 = HEAP32[$tn_044 + 8 >> 2] + $450 | 0;
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $459, $branchTargets, $24, undef);
    __label__ = 106;
    break;
   case 106:
    var $461 = $tn_044 + 12 | 0;
    if ($461 >>> 0 < $441 >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 107:
    var $tn_044 = $461;
    var $445 = HEAP32[$10 >> 2];
    __label__ = 103;
    break;
   case 108:
    var $463 = $193 & 31;
    if (($463 | 0) == 9 || ($463 | 0) == 1) {
      __label__ = 109;
      break;
    } else {
      var $stackDepth_1_ph35 = $277;
      __label__ = 112;
      break;
    }
   case 109:
    var $464 = HEAP32[$10 >> 2];
    var $465 = __ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj($cx, $464, $offset_0);
    __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $465, $branchTargets, $24, undef);
    if ($465 >>> 0 < $offset_0 >>> 0) {
      __label__ = 110;
      break;
    } else {
      var $stackDepth_1_ph35 = $277;
      __label__ = 112;
      break;
    }
   case 110:
    __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $465);
    var $stackDepth_1_ph35 = $277;
    __label__ = 112;
    break;
   case 111:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 114;
    break;
   case 112:
    var $stackDepth_1_ph35;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $stackDepth_0 = $stackDepth_1_ph35;
    var $offset_0 = $57;
    __label__ = 10;
    break;
   case 113:
    HEAP8[$this + 21 | 0] = 1;
    __label__ = 114;
    break;
   case 114:
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($branchTargets);
    var $free_idx_val = HEAP32[$free + 4 >> 2];
    __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev($free_idx_val);
    __label__ = 115;
    break;
   case 115:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $slot);
    if ($1) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = (HEAP8[$this + 25 | 0] & 2) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue11initInitialEj($this, $slot) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  var $1 = $this;
  var $4 = HEAP32[$1 >> 2] & -4 | 2;
  HEAP32[$1 >> 2] = $4;
  HEAP8[$this | 0] = $4 & 255 | 4;
  var $10 = HEAP32[$1 >> 2] & 7 | $slot << 3;
  HEAP32[$1 >> 2] = $10;
  return;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($this, $pc) {
  var $7 = $pc - HEAP32[HEAP32[$this >> 2] >> 2] | 0;
  var $8 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $7);
  return $8;
}

function __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j($t, $nelem) {
  var $1 = $t | 0;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyzeL11ExtendedDefEPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pc_val & 255;
    if (($1 | 0) == 85 || ($1 | 0) == 97 || ($1 | 0) == 98 || ($1 | 0) == 99 || ($1 | 0) == 100 || ($1 | 0) == 87 || ($1 | 0) == 132 || ($1 | 0) == 140 || ($1 | 0) == 223 || ($1 | 0) == 101 || ($1 | 0) == 102 || ($1 | 0) == 103 || ($1 | 0) == 104) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7analyze8SSAValue4kindEv($this) {
  return HEAP32[$this >> 2] & 3;
}

function __ZNK2js7analyze8SSAValue9phiOffsetEv($this) {
  return HEAPU32[$this >> 2] >>> 2;
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js7analyze14ScriptAnalysis8livenessEj($this, $slot) {
  return HEAP32[$this + 36 >> 2] + $slot * 12 | 0;
}

function __ZNK2js7analyze8SSAValue7phiNodeEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj($this, $branchTargets, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($branchTargets, $i_0);
    if ((HEAP32[$5 >> 2] | 0) == ($offset | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($branchTargets);
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$5 >> 2] = $10;
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($branchTargets);
    __label__ = 6;
    break;
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($this, $p1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $p1);
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + $i * 12 | 0;
}

function __ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE($this, $loop) {
  var $2 = HEAP32[$loop + 4 >> 2];
  var $4 = HEAP32[$loop + 8 >> 2];
  var $5 = __ZNK2js7analyze16LifetimeVariable10firstWriteEjj($this, $2, $4);
  return $5;
}

function __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $slot, $offset, $pv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = __ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool($3);
    var $6 = HEAP32[$1 >> 2] + 344 | 0;
    var $7 = __ZN2js7analyzeL15PhiNodeCapacityEj(0);
    var $8 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($6, $7);
    if (($4 | 0) == 0 | ($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = $4 + 12 | 0;
    HEAP32[$13 >> 2] = $slot;
    var $14 = $4 + 20 | 0;
    HEAP32[$14 >> 2] = $8;
    __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($pv, $offset, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $phi, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue7phiNodeEv($phi);
    var $2 = $1 + 16 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if ($3 >>> 0 < 9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $1 + 20 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = HEAP32[$5 >> 2] + ($i_0 << 3) | 0;
    var $11 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $10);
    if ($11) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE(undef, $v);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $37 = $3;
      __label__ = 10;
      break;
    }
   case 7:
    var $16 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v);
    var $19 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $20 = __ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool($19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 15;
    break;
   case 9:
    var $24 = $20 | 0;
    var $26 = HEAP8[$24] & -2;
    HEAP8[$24] = $26;
    var $27 = __ZNK2js7analyze8SSAValue9phiOffsetEv($phi);
    var $28 = $20;
    var $32 = HEAP32[$28 >> 2] & 1 | $27 << 1;
    HEAP32[$28 >> 2] = $32;
    var $33 = $20 + 4 | 0;
    HEAP32[$33 >> 2] = $1;
    var $34 = HEAP32[$16 >> 2];
    var $35 = $20 + 8 | 0;
    HEAP32[$35 >> 2] = $34;
    HEAP32[$16 >> 2] = $20;
    var $37 = HEAP32[$2 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $37;
    var $38 = __ZN2js7analyzeL15PhiNodeCapacityEj($37);
    if ($37 >>> 0 < $38 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$2 >> 2] = $37 + 1 | 0;
    var $45 = $v;
    var $46 = HEAP32[$1 + 20 >> 2] + ($37 << 3) | 0;
    var $47$0 = HEAP32[$45 >> 2];
    var $47$1 = HEAP32[$45 + 4 >> 2];
    var $st$11$0 = $46 | 0;
    HEAP32[$st$11$0 >> 2] = $47$0;
    var $st$11$1 = $46 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $47$1;
    __label__ = 15;
    break;
   case 12:
    var $51 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $53 = __ZN2js7analyzeL15PhiNodeCapacityEj($37 + 1 | 0);
    var $54 = __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($51, $53);
    if (($54 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 15;
    break;
   case 14:
    var $58 = $1 + 20 | 0;
    var $59 = HEAP32[$58 >> 2];
    var $60 = HEAP32[$2 >> 2];
    __ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j($54, $59, $60);
    HEAP32[$58 >> 2] = $54;
    var $61 = HEAP32[$2 >> 2];
    var $62 = $61 + 1 | 0;
    HEAP32[$2 >> 2] = $62;
    var $64 = $v;
    var $65 = $54 + ($61 << 3) | 0;
    var $st$11$0 = $64 | 0;
    var $66$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $64 + 4 | 0;
    var $66$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $65 | 0;
    HEAP32[$st$15$0 >> 2] = $66$0;
    var $st$15$1 = $65 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $66$1;
    __label__ = 15;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $offset, $v, $pv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ov = __stackBase__;
    var $1 = $pv + 4 | 0;
    var $2 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $1);
    if ($2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js7analyze8SSAValue4kindEv($1);
    if (($4 | 0) == 3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js7analyze8SSAValue9phiOffsetEv($1);
    if ($7 >>> 0 < $offset >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $1;
    var $11 = $ov;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    var $14 = HEAP32[$pv >> 2];
    var $15 = __ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE($this, $cx, $14, $offset, $1);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $v);
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $ov);
    __label__ = 7;
    break;
   case 6:
    __ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_($this, $cx, $1, $v);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE($this, $cx, $value, $slot, $branchTargets) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > $slot >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_01;
    var $6 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($branchTargets, $i_01);
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $7);
    var $11 = HEAP32[$8 + 32 >> 2];
    __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $value, $slot, $11);
    var $12 = $i_01 + 1 | 0;
    var $13 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv($branchTargets);
    if ($12 >>> 0 < $13 >>> 0) {
      var $i_01 = $12;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($this, $slot, $value) {
  __ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE($this, $slot, $value);
  return;
}

function __ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj($this, $cx, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
    var $2 = $1 + 32 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $2 | 0;
    HEAP32[$5 >> 2] = 0;
    var $6 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($4);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_(undef, $4);
    __label__ = 7;
    break;
   case 3:
    var $12 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $13 = $6 + 1 | 0;
    var $14 = __ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj($12, $13);
    HEAP32[$5 >> 2] = $14;
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = 0;
      var $17 = $14;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 7;
    break;
   case 5:
    var $17;
    var $i_01;
    var $18 = $17 + $i_01 * 12 | 0;
    var $19 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($4, $i_01);
    var $20 = $18;
    var $21 = $19;
    HEAP32[$20 >> 2] = HEAP32[$21 >> 2];
    HEAP32[$20 + 4 >> 2] = HEAP32[$21 + 4 >> 2];
    HEAP32[$20 + 8 >> 2] = HEAP32[$21 + 8 >> 2];
    var $22 = $i_01 + 1 | 0;
    var $23 = HEAP32[$5 >> 2];
    if (($22 | 0) == ($6 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = $22;
      var $17 = $23;
      __label__ = 5;
      break;
    }
   case 6:
    var $24 = $23 + $6 * 12 | 0;
    HEAP32[$24 >> 2] = 0;
    var $26 = HEAP32[$5 >> 2] + $6 * 12 + 4 | 0;
    __ZN2js7analyze8SSAValue5clearEv($26);
    __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_(undef, $4);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11ExtendedUseEPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyzeL11ExtendedDefEPh($pc_val);
    if ($1) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $pc_val & 255;
    if (($3 | 0) == 84 || ($3 | 0) == 216 || ($3 | 0) == 86 || ($3 | 0) == 215) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 3) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue5clearEv($this) {
  __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_($this);
  return;
}

function __ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j($t, $nelem) {
  var $1 = $t | 0;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 0) {
      var $9 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else {
      var $9 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2js7analyze8SSAValue10varInitialEv($v);
    var $9 = $6 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js7analyze8SSAValue11pushedIndexEv($v);
    var $4 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $4);
    var $_0 = HEAP32[$5 + 28 >> 2] + ($3 << 2) | 0;
    __label__ = 5;
    break;
   case 3:
    var $11 = HEAP32[$this >> 2];
    var $12 = __ZNK2js7analyze8SSAValue9varOffsetEv($v);
    var $13 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj($11, $12);
    var $14 = __ZNK2js7analyze8SSAValue9varOffsetEv($v);
    var $15 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $14);
    var $_0 = HEAP32[$15 + 28 >> 2] + ($13 << 2) | 0;
    __label__ = 5;
    break;
   case 4:
    var $20 = __ZNK2js7analyze8SSAValue7phiNodeEv($v);
    var $_0 = $20 + 24 | 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue10initPushedEjj($this, $offset, $index) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  HEAP32[$this >> 2] = $offset << 2 | 1;
  HEAP32[$this + 4 >> 2] = $index;
  return;
}

function __ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js7analyze8SSAValue11initWrittenEjj($this, $slot, $offset) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  var $1 = $this;
  var $4 = HEAP32[$1 >> 2] & -4 | 2;
  HEAP32[$1 >> 2] = $4;
  HEAP8[$this | 0] = $4 & 255 & -6;
  var $10 = HEAP32[$1 >> 2] & 7 | $slot << 3;
  HEAP32[$1 >> 2] = $10;
  HEAP32[$this + 4 >> 2] = $offset;
  return;
}

function __ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj($this, $cx, $targetOffset, $branchTargets, $values, $stackDepth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $targetOffset);
    var $3 = HEAP32[$1 + 4 >> 2];
    var $4 = $1 + 32 | 0;
    var $5 = $4;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($6);
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $i_01 = 0;
      var $10 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $10;
    var $i_01;
    var $11 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($10, $i_01);
    var $14 = $values + (HEAP32[$11 >> 2] << 3) | 0;
    __ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE($this, $cx, $targetOffset, $14, $11);
    var $15 = $i_01 + 1 | 0;
    var $16 = HEAPU32[$5 >> 2];
    var $17 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($16);
    if ($15 >>> 0 < $17 >>> 0) {
      var $i_01 = $15;
      var $10 = $16;
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $20 = __ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    HEAP32[$4 >> 2] = $20;
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($branchTargets, $targetOffset);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 10;
    break;
   case 7:
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = $this | 0;
    var $i1_04 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i1_04;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js7analyzeL9StackSlotEP8JSScriptj($28, $i1_04);
    var $30 = $values + ($29 << 3) | 0;
    var $31 = HEAP32[$5 >> 2];
    __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $30, $29, $31);
    var $32 = $i1_04 + 1 | 0;
    if (($32 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i1_04 = $32;
      __label__ = 9;
      break;
    }
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze10SSAPhiNodeC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL15PhiNodeCapacityEj($length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 < 5) {
      var $_0 = 4;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $length - 1 | 1;
    var $5 = _llvm_ctlz_i32($4);
    var $_0 = 1 << 32 - $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($this, $offset, $node) {
  __ZN2js7analyze8SSAValue5clearEv($this);
  HEAP32[$this >> 2] = $offset << 2 | 3;
  HEAP32[$this + 4 >> 2] = $node;
  return;
}

function __ZNK2js7analyze8SSAValue6equalsERKS1_($this, $o) {
  var $1 = $this | 0;
  var $2 = $o | 0;
  var $3 = _memcmp($1, $2, 8);
  return ($3 | 0) == 0;
}

function __ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js7analyze11SSAUseChainC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012;
    var $6 = $_03;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$6 >> 2] = $7$0;
    HEAP32[$6 + 4 >> 2] = $7$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst | 0;
    var $13 = $src | 0;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $v, $slot, $pending) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv($pending);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj($pending, $i_0);
    if ((HEAP32[$6 >> 2] | 0) == ($slot | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    __ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE($1, $slot, $v);
    var $13 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($pending, $1);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext($this, $cx);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9StackSlotEP8JSScriptj($script, $index) {
  var $1 = __ZN2js7analyzeL10TotalSlotsEP8JSScript($script);
  return $1 + $index | 0;
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7analyze8SSAValue7varSlotEv($this) {
  return HEAPU32[$this >> 2] >>> 3;
}

function __ZNK2js7analyze8SSAValue12pushedOffsetEv($this) {
  return HEAPU32[$this >> 2] >>> 2;
}

function __ZN8JSScript8analysisEv($this) {
  return HEAP32[HEAP32[$this + 100 >> 2] >> 2];
}

function __ZNK2js7analyze8SSAValue10varInitialEv($this) {
  return (HEAP8[$this | 0] & 4) << 24 >> 24 != 0;
}

function __ZNK2js7analyze14ScriptAnalysis14numReturnSitesEv($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZNK2js7analyze8SSAValue11pushedIndexEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + HEAP32[$this + 8 >> 2] * 12 | 0;
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js5types7TypeSetC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js7analyze8LifetimeC2EjjPS1_($this, $offset, $savedEnd, $next) {
  HEAP32[$this >> 2] = $offset;
  HEAP32[$this + 4 >> 2] = $offset;
  HEAP32[$this + 8 >> 2] = $savedEnd;
  HEAP8[$this + 12 | 0] = 0;
  HEAP8[$this + 13 | 0] = 0;
  HEAP32[$this + 16 >> 2] = $next;
  return;
}

function __ZNK2js7analyze8SSAValue9varOffsetEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js7analyze13CrossSSAValueC2EjRKNS0_8SSAValueE($this, $frame, $v) {
  HEAP32[$this >> 2] = $frame;
  var $3 = $v;
  var $4 = $this + 4 | 0;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  return;
}

function __ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_($t) {
  var $1 = $t;
  var $st$3$0 = $1 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$0] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 3] = tempBigInt & 255;
  var $st$3$1 = $1 + 4 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 3] = tempBigInt & 255;
  return;
}

function __ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE($this, $slot, $value) {
  HEAP32[$this >> 2] = $slot;
  var $3 = $value;
  var $4 = $this + 4 | 0;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  return;
}

function __ZNK2js7analyze16LifetimeVariable10firstWriteEjj($this, $start, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $segment_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $segment_0 = HEAP32[$this + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $segment_0;
    if (($segment_0 | 0) == 0) {
      var $_0 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAPU32[$segment_0 >> 2];
    if ($10 >>> 0 > $end >>> 0) {
      var $_0 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($10 >>> 0 < $start >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP8[$segment_0 + 13 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $10;
      __label__ = 8;
      break;
    }
   case 7:
    var $segment_0 = HEAP32[$segment_0 + 16 >> 2];
    __label__ = 3;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE($this, $cx, $values) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $values;
  return;
}

function __ZN2js7analyze12UntrapOpcode6retrapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[HEAP32[$this >> 2]] = 83;
    HEAP8[$1] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $cv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $untrap = __stackBase__ + 20;
    var $thisv = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $untrap3 = __stackBase__ + 48;
    var $3 = __stackBase__ + 56;
    var $4 = __stackBase__ + 68;
    var $toidv = __stackBase__ + 80;
    var $5 = __stackBase__ + 88;
    var $6 = $cv | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN2js7analyze14CrossScriptSSA8getFrameEj($this, $7);
    var $9 = $cv + 4 | 0;
    var $10 = $8 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if (($11 | 0) == -2) {
      var $parentScript_0 = 0;
      var $parentAnalysis_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = __ZN2js7analyze14CrossScriptSSA8getFrameEj($this, $11);
    var $16 = HEAP32[$14 + 4 >> 2];
    var $17 = __ZN8JSScript8analysisEv($16);
    var $parentScript_0 = $16;
    var $parentAnalysis_0 = $17;
    __label__ = 3;
    break;
   case 3:
    var $parentAnalysis_0;
    var $parentScript_0;
    var $19 = __ZNK2js7analyze8SSAValue4kindEv($9);
    if (($19 | 0) == 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $22 = __ZNK2js7analyze8SSAValue10varInitialEv($9);
    if (($parentScript_0 | 0) == 0 | $22 ^ 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZNK2js7analyze8SSAValue7varSlotEv($9);
    var $26 = __ZN2js7analyzeL7ArgSlotEj(0);
    if ($25 >>> 0 < $26 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = HEAP32[$8 + 4 >> 2];
    var $31 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($30, 0);
    if ($25 >>> 0 < $31 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $35 = HEAPU32[$8 + 16 >> 2];
    var $46 = $26 + ($25 ^ -1) + ((HEAPU8[$35 + 1 | 0] & 255) << 8 | HEAPU8[$35 + 2 | 0] & 255) | 0;
    var $47 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($parentAnalysis_0, $35, $46);
    var $48 = $47;
    var $49 = $argv;
    var $50$0 = HEAP32[$48 >> 2];
    var $50$1 = HEAP32[$48 + 4 >> 2];
    HEAP32[$49 >> 2] = $50$0;
    HEAP32[$49 + 4 >> 2] = $50$1;
    __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($1, $11, $argv);
    __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $1);
    __label__ = 35;
    break;
   case 8:
    var $52 = __ZNK2js7analyze8SSAValue4kindEv($9);
    if (($52 | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 9:
    var $55 = $8 + 4 | 0;
    var $56 = HEAP32[$55 >> 2];
    var $58 = HEAP32[$56 >> 2];
    var $59 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($9);
    var $60 = $58 + $59 | 0;
    var $61 = $this | 0;
    var $62 = HEAP32[$61 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $62, $56, $60);
    var $64 = HEAPU8[$60] & 255;
    if (($64 | 0) == 58) {
      __label__ = 10;
      break;
    } else if (($64 | 0) == 65) {
      __label__ = 11;
      break;
    } else if (($64 | 0) == 187) {
      __label__ = 28;
      break;
    } else if (($64 | 0) == 231) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 10:
    var $65 = __ZN2js7analyze14CrossScriptSSA9numFramesEv($this);
    var $i_0 = 0;
    var $calleeFrame_0 = -2;
    var $callee_0 = 0;
    __label__ = 13;
    break;
   case 11:
    if (($parentScript_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $70 = HEAPU32[$8 + 16 >> 2];
    var $78 = (HEAPU8[$70 + 1 | 0] & 255) << 8 | HEAPU8[$70 + 2 | 0] & 255;
    var $79 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($parentAnalysis_0, $70, $78);
    var $80 = $79;
    var $81 = $thisv;
    var $82$0 = HEAP32[$80 >> 2];
    var $82$1 = HEAP32[$80 + 4 >> 2];
    HEAP32[$81 >> 2] = $82$0;
    HEAP32[$81 + 4 >> 2] = $82$1;
    var $83 = HEAP32[$10 >> 2];
    __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($2, $83, $thisv);
    __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $2);
    __label__ = 33;
    break;
   case 13:
    var $callee_0;
    var $calleeFrame_0;
    var $i_0;
    if ($i_0 >>> 0 < $65 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 14:
    var $87 = __ZN2js7analyze14CrossScriptSSA9iterFrameEj($this, $i_0);
    if ((HEAP32[$87 + 12 >> 2] | 0) == (HEAP32[$6 >> 2] | 0)) {
      __label__ = 15;
      break;
    } else {
      var $calleeFrame_1 = $calleeFrame_0;
      var $callee_1 = $callee_0;
      __label__ = 19;
      break;
    }
   case 15:
    if ((HEAP32[$87 + 16 >> 2] | 0) == ($60 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $calleeFrame_1 = $calleeFrame_0;
      var $callee_1 = $callee_0;
      __label__ = 19;
      break;
    }
   case 16:
    if (($callee_0 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $99 = $agg_result;
    var $100 = $cv;
    HEAP32[$99 >> 2] = HEAP32[$100 >> 2];
    HEAP32[$99 + 4 >> 2] = HEAP32[$100 + 4 >> 2];
    HEAP32[$99 + 8 >> 2] = HEAP32[$100 + 8 >> 2];
    __label__ = 33;
    break;
   case 18:
    var $calleeFrame_1 = HEAP32[$87 >> 2];
    var $callee_1 = HEAP32[$87 + 4 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $callee_1;
    var $calleeFrame_1;
    var $i_0 = $i_0 + 1 | 0;
    var $calleeFrame_0 = $calleeFrame_1;
    var $callee_0 = $callee_1;
    __label__ = 13;
    break;
   case 20:
    if (($callee_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $111 = __ZN8JSScript8analysisEv($callee_0);
    var $112 = __ZNK2js7analyze14ScriptAnalysis14numReturnSitesEv($111);
    if (($112 | 0) == 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 22:
    var $114 = $callee_0 + 8 | 0;
    var $115 = $callee_0 | 0;
    var $offset_0 = 0;
    __label__ = 23;
    break;
   case 23:
    var $offset_0;
    if ($offset_0 >>> 0 < HEAPU32[$114 >> 2] >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 24:
    var $121 = HEAP32[$115 >> 2] + $offset_0 | 0;
    var $122 = HEAP32[$61 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap3, $122, $callee_0, $121);
    var $123 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($111, $121);
    if (($123 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (HEAP8[$121] << 24 >> 24 == 5) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $128 = __ZN2js7analyzeL17GetBytecodeLengthEPh($121);
    var $129 = $128 + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap3);
    var $offset_0 = $129;
    __label__ = 23;
    break;
   case 27:
    var $131 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($111, $121, 0);
    __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($3, $calleeFrame_0, $131);
    __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $3);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap3);
    __label__ = 33;
    break;
   case 28:
    var $133 = __ZNK2js7analyze8SSAValue11pushedIndexEv($9);
    if (($133 | 0) == 1) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $136 = HEAP32[$55 >> 2];
    var $137 = __ZN8JSScript8analysisEv($136);
    var $138 = HEAP32[$6 >> 2];
    var $139 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($137, $60, 0);
    __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($4, $138, $139);
    __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $4);
    __label__ = 33;
    break;
   case 30:
    var $141 = HEAP32[$55 >> 2];
    var $142 = __ZN8JSScript8analysisEv($141);
    var $143 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($142, $60, 0);
    var $144 = $143;
    var $145 = $toidv;
    var $146$0 = HEAP32[$144 >> 2];
    var $146$1 = HEAP32[$144 + 4 >> 2];
    HEAP32[$145 >> 2] = $146$0;
    HEAP32[$145 + 4 >> 2] = $146$1;
    var $147 = __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($142, $toidv);
    var $148 = HEAP32[$61 >> 2];
    var $149 = __ZN2js5types7TypeSet15getKnownTypeTagEP9JSContext($147, $148);
    if ($149 << 24 >> 24 == 1) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $152 = HEAP32[$6 >> 2];
    __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($5, $152, $toidv);
    __ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE($agg_result, $this, $5);
    __label__ = 33;
    break;
   case 32:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 34;
    break;
   case 33:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 35;
    break;
   case 34:
    var $154 = $agg_result;
    var $155 = $cv;
    HEAP32[$154 >> 2] = HEAP32[$155 >> 2];
    HEAP32[$154 + 4 >> 2] = HEAP32[$155 + 4 >> 2];
    HEAP32[$154 + 8 >> 2] = HEAP32[$155 + 8 >> 2];
    __label__ = 35;
    break;
   case 35:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE["X"] = 1;

function __ZN2js7analyze14CrossScriptSSA8getFrameEj($this, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($index | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $this + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = $this + 24 | 0;
    var $6 = __ZN2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEEixEj($5, $index);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this, $pc, $which) {
  var $7 = $pc - HEAP32[HEAP32[$this >> 2] >> 2] | 0;
  var $8 = __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this, $7, $which);
  return $8;
}

function __ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE($this, $frame, $v) {
  __ZN2js7analyze13CrossSSAValueC2EjRKNS0_8SSAValueE($this, $frame, $v);
  return;
}

function __ZN2js7analyze14CrossScriptSSA9numFramesEv($this) {
  var $1 = $this + 24 | 0;
  var $2 = __ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE6lengthEv($1);
  return $2 + 1 | 0;
}

function __ZN2js7analyze14CrossScriptSSA9iterFrameEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($i | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $this + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = $this + 24 | 0;
    var $6 = $i - 1 | 0;
    var $7 = __ZN2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEEixEj($5, $6);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    var $4 = __ZNK2js7analyze8SSAValue11pushedIndexEv($v);
    var $5 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $3, $4);
    var $_0 = $5;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2js7analyze8SSAValue10varInitialEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = HEAP32[$this >> 2];
    var $11 = __ZNK2js7analyze8SSAValue7varSlotEv($v);
    var $12 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($10, $11);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 5:
    var $14 = __ZNK2js7analyze8SSAValue9varOffsetEv($v);
    var $15 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $14, 0);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 6:
    var $17 = __ZNK2js7analyze8SSAValue7phiNodeEv($v);
    var $_0 = $17 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze11SSAUseChainC1Ev($this) {
  __ZN2js7analyze11SSAUseChainC2Ev($this);
  return;
}

function __ZN2js7analyze11SSAUseChainC2Ev($this) {
  __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_($t) {
  var $1 = $t | 0;
  for (var $$dest = $1, $$stop = $$dest + 12; $$dest < $$stop; $$dest++) {
    HEAP8[$$dest] = 0;
  }
  return;
}

function __ZN2js7analyze10SSAPhiNodeC1Ev($this) {
  __ZN2js7analyze10SSAPhiNodeC2Ev($this);
  return;
}

function __ZN2js7analyze10SSAPhiNodeC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types7TypeSetC1Ev($1);
  __ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_($this);
  return;
}

function __ZN2js5types7TypeSetC1Ev($this) {
  __ZN2js5types7TypeSetC2Ev($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 28, 1);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    HEAP32[$4 >> 2] = HEAP32[$5 >> 2];
    HEAP32[$4 + 4 >> 2] = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 + 8 >> 2] = HEAP32[$5 + 8 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7 = $this + 8 | 0;
    var $9 = HEAP32[$7 >> 2] + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 12 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 12 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $13 = __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($1);
    var $14 = $dst_01;
    var $15 = $13;
    HEAP32[$14 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$14 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$14 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $17 = $dst_01 + 12 | 0;
    var $18 = $src_02 + 12 | 0;
    var $19 = __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($18 | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      __label__ = 3;
      break;
    }
   case 6:
    var $21 = $v + 4 | 0;
    var $23 = HEAP32[$21 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $23);
    HEAP32[$21 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $5 = __ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev($1);
    var $6 = $_02;
    var $7 = $5;
    HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9 = $p_01 + 12 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 12 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7analyze8LifetimeC1EjjPS1_($this, $offset, $savedEnd, $next) {
  __ZN2js7analyze8LifetimeC2EjjPS1_($this, $offset, $savedEnd, $next);
  return;
}

function __ZN2js7analyze8BytecodeC1Ev($this) {
  __ZN2js7analyze8BytecodeC2Ev($this);
  return;
}

function __ZN2js7analyze8BytecodeC2Ev($this) {
  __ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_($t) {
  var $1 = $t | 0;
  _memset($1, 0, 44, 1);
  return;
}

function __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $offset, $which) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
  return HEAP32[$1 + 36 >> 2] + $which * 12 | 0;
}

function __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($script, $slot) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  return $3 + ((HEAPU16[$script + 22 >> 1] & 65535) + $slot) * 12 | 0;
}

function __ZN2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + $i * 20 | 0;
}

function __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this, $offset, $which) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
  return HEAP32[$1 + 24 >> 2] + ($which << 3) | 0;
}

function __ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev($this_0_1_val) {
  var $1 = $this_0_1_val | 0;
  __ZN9JSContext5free_EPv(undef, $1);
  return;
}

function __ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN2js7analyze8LifetimeC1EjjPS1_($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze12UntrapOpcodeD2Ev($this) {
  __ZN2js7analyze12UntrapOpcode6retrapEv($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj($this, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj($2, $local);
    var $4 = __ZN2js7analyze14ScriptAnalysis11slotEscapesEj($this, $3);
    if ($4) {
      var $12 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = (HEAP32[HEAP32[$this + 32 >> 2] + ($local << 2) >> 2] | 0) == -1;
    __label__ = 3;
    break;
   case 3:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8Bytecode9isDefinedEj($this, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $3 = HEAPU32[$this + 8 >> 2];
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[HEAP32[$1 >> 2] + ($i_0 << 2) >> 2] | 0) == ($slot | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis10jumpTargetEj($this, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$this + 4 >> 2] + ($offset << 2) >> 2];
    if (($4 | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = (HEAP8[$4 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _BUILD_JSVAL225($agg_result, $tag, $payload) {
  HEAP32[$agg_result + 4 >> 2] = $tag;
  HEAP32[$agg_result >> 2] = $payload;
  return;
}

function _JS_GetNaNValue($agg_result, $cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144112 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function _JS_GetNegativeInfinityValue($agg_result, $cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144120 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function _JS_GetPositiveInfinityValue($agg_result, $cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144128 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function _JS_GetEmptyString($rt) {
  return HEAP32[$rt + 144136 >> 2] | 0;
}

function __Z28js_GetVariableBytecodeLengthPh($pc) {
  var $2 = HEAPU8[$pc] & 255;
  var $3 = __Z28js_GetVariableBytecodeLength4JSOpPh($2, $pc);
  return $3;
}

function __ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh($this, $cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $pc;
    var $4 = HEAP8[$pc] << 24 >> 24 == 83;
    var $5 = $4 & 1;
    HEAP8[$this + 4 | 0] = $5;
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $script;
    var $8 = _JS_GetTrapOpcode(undef, $7, $pc);
    HEAP8[$pc] = $8 & 255;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript9getObjectEj($this, $index) {
  var $1 = __ZN8JSScript7objectsEv($this);
  return HEAP32[HEAP32[$1 >> 2] + ($index << 2) >> 2];
}

function ___cxx_global_var_init() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -122, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_NULL, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init1() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -127, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_ZERO, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init2() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -127, 1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_ONE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init3() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -125, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_FALSE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init4() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -125, 1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_TRUE, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function ___cxx_global_var_init5() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BUILD_JSVAL225($1, -126, 0);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout(_JSVAL_VOID, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_Now() {
  var $1 = _PRMJ_Now();
  return [ $1[0], $1[1] ];
}

function _JS_GetEmptyStringValue($agg_result, $cx) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
  _STRING_TO_JSVAL($agg_result, $5);
  return;
}

function _STRING_TO_JSVAL($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL277($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ConvertArguments($cx, $argc, $argv, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ConvertArguments.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_ConvertArgumentsVA($cx, $argc, $argv, $format, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ConvertArgumentsVA($cx, $argc, $argv, $format, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $sp = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $obj = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    var $numBuf = __stackBase__ + 28;
    var $funNameBytes = __stackBase__ + 40;
    var $3 = __stackBase__ + 44;
    var $4 = __stackBase__ + 52;
    var $5 = __stackBase__ + 60;
    var $6 = __stackBase__ + 68;
    var $7 = __stackBase__ + 76;
    var $8 = __stackBase__ + 84;
    var $9 = __stackBase__ + 92;
    var $10 = __stackBase__ + 100;
    var $11 = __stackBase__ + 108;
    HEAP32[$1 >> 2] = $format;
    var $12 = $argv - 16 | 0;
    var $13 = $argc + 2 | 0;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($2, $12, $13);
    HEAP32[$sp >> 2] = $argv;
    var $14 = $argv + ($argc << 3) | 0;
    var $15 = $3 | 0;
    var $16 = $4 | 0;
    var $17 = $5 | 0;
    var $18 = $6 | 0;
    var $19 = $7 | 0;
    var $20 = $8 | 0;
    var $21 = $cx;
    var $22 = $9 | 0;
    var $23 = $cx;
    var $24 = $obj;
    var $25 = $10 | 0;
    var $26 = $11 | 0;
    var $required_0_ph = 1;
    var $_01_ph = $ap;
    var $27 = $format;
    __label__ = 2;
    break;
   case 2:
    var $27;
    var $_01_ph;
    var $required_0_ph;
    var $28 = $_01_ph;
    var $required_0_ph4 = $required_0_ph;
    var $29 = $27;
    __label__ = 3;
    break;
   case 3:
    var $29;
    var $required_0_ph4;
    var $30 = $29;
    __label__ = 4;
    break;
   case 4:
    var $30;
    var $31 = $30 + 1 | 0;
    HEAP32[$1 >> 2] = $31;
    var $32 = HEAP8[$30];
    var $33 = $32 << 24 >> 24;
    if ($32 << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 40;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $36 = _isspace($33);
    if (($36 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $30 = $31;
      __label__ = 4;
      break;
    }
   case 6:
    if ($32 << 24 >> 24 == 47) {
      var $required_0_ph4 = 0;
      var $29 = $31;
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $41 = HEAP32[$sp >> 2];
    if (($41 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    if (($required_0_ph4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 40;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $46 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $12, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = $numBuf | 0;
    var $50 = _JS_snprintf($49, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $argc, tempInt));
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $51 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $46, $funNameBytes);
    if (($51 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $55 = ($argc | 0) == 1 ? __str93064 | 0 : STRING_TABLE.__str74084 | 0;
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $51, HEAP32[tempInt + 4 >> 2] = $49, HEAP32[tempInt + 8 >> 2] = $55, tempInt));
    __label__ = 12;
    break;
   case 12:
    __ZN16JSAutoByteStringD1Ev($funNameBytes);
    var $_0 = 0;
    __label__ = 40;
    break;
   case 13:
    if (($33 | 0) == 98) {
      __label__ = 14;
      break;
    } else if (($33 | 0) == 99) {
      __label__ = 15;
      break;
    } else if (($33 | 0) == 105) {
      __label__ = 17;
      break;
    } else if (($33 | 0) == 117) {
      __label__ = 19;
      break;
    } else if (($33 | 0) == 106) {
      __label__ = 21;
      break;
    } else if (($33 | 0) == 100) {
      __label__ = 23;
      break;
    } else if (($33 | 0) == 73) {
      __label__ = 25;
      break;
    } else if (($33 | 0) == 83 || ($33 | 0) == 87) {
      __label__ = 27;
      break;
    } else if (($33 | 0) == 111) {
      __label__ = 32;
      break;
    } else if (($33 | 0) == 102) {
      __label__ = 34;
      break;
    } else if (($33 | 0) == 118) {
      __label__ = 36;
      break;
    } else if (($33 | 0) == 42) {
      var $_1 = $_01_ph;
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 14:
    var $59 = __Z17js_ValueToBooleanRKN2JS5ValueE($41);
    var $62 = HEAP32[$_01_ph >> 2];
    HEAP32[$62 >> 2] = $59;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 15:
    var $64 = $41 | 0;
    var $st$1$0 = $64 | 0;
    var $65$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $64 + 4 | 0;
    var $65$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $15 | 0;
    HEAP32[$st$5$0 >> 2] = $65$0;
    var $st$5$1 = $15 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $65$1;
    var $67 = HEAP32[$_01_ph >> 2];
    var $68 = _JS_ValueToUint16($cx, $3, $67);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 17:
    var $72 = $41 | 0;
    var $st$1$0 = $72 | 0;
    var $73$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $72 + 4 | 0;
    var $73$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $16 | 0;
    HEAP32[$st$5$0 >> 2] = $73$0;
    var $st$5$1 = $16 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $73$1;
    var $75 = HEAP32[$_01_ph >> 2];
    var $76 = _JS_ValueToECMAInt32($cx, $4, $75);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 19:
    var $80 = $41 | 0;
    var $st$1$0 = $80 | 0;
    var $81$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $80 + 4 | 0;
    var $81$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $17 | 0;
    HEAP32[$st$5$0 >> 2] = $81$0;
    var $st$5$1 = $17 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $81$1;
    var $83 = HEAP32[$_01_ph >> 2];
    var $84 = _JS_ValueToECMAUint32($cx, $5, $83);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 21:
    var $88 = $41 | 0;
    var $st$1$0 = $88 | 0;
    var $89$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $88 + 4 | 0;
    var $89$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $18 | 0;
    HEAP32[$st$5$0 >> 2] = $89$0;
    var $st$5$1 = $18 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $89$1;
    var $91 = HEAP32[$_01_ph >> 2];
    var $92 = _JS_ValueToInt32($cx, $6, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 23:
    var $96 = $41 | 0;
    var $st$1$0 = $96 | 0;
    var $97$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $96 + 4 | 0;
    var $97$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $19 | 0;
    HEAP32[$st$5$0 >> 2] = $97$0;
    var $st$5$1 = $19 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $97$1;
    var $99 = HEAP32[$_01_ph >> 2];
    var $100 = _JS_ValueToNumber($cx, $7, $99);
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 25:
    var $104 = $41 | 0;
    var $st$1$0 = $104 | 0;
    var $105$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $104 + 4 | 0;
    var $105$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $20 | 0;
    HEAP32[$st$5$0 >> 2] = $105$0;
    var $st$5$1 = $20 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $105$1;
    var $106 = _JS_ValueToNumber($cx, $8, $d);
    if (($106 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $109 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $110 = __ZL18js_DoubleToIntegerd($109);
    var $113 = HEAP32[$_01_ph >> 2];
    tempDoubleF64[0] = $110, HEAP32[$113 >> 2] = tempDoubleI32[0], HEAP32[$113 + 4 >> 2] = tempDoubleI32[1];
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 27:
    var $115 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $41);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $118 = HEAP32[$sp >> 2];
    _STRING_TO_JSVAL($9, $115);
    var $st$2$0 = $22 | 0;
    var $119$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $22 + 4 | 0;
    var $119$1 = HEAP32[$st$2$1 >> 2];
    var $120 = $118 | 0;
    var $st$7$0 = $120 | 0;
    HEAP32[$st$7$0 >> 2] = $119$0;
    var $st$7$1 = $120 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $119$1;
    if ($32 << 24 >> 24 == 87) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $123 = __ZN8JSString11ensureFixedEP9JSContext($115, $cx);
    if (($123 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $126 = $123 | 0;
    var $127 = __ZNK14JSLinearString5charsEv($126);
    var $130 = HEAP32[$_01_ph >> 2];
    HEAP32[$130 >> 2] = $127;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 31:
    var $134 = HEAP32[$_01_ph >> 2];
    HEAP32[$134 >> 2] = $115;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 32:
    var $136 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($23, $41, $24);
    if (($136 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $139 = HEAP32[$sp >> 2];
    var $140 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL($10, $140);
    var $141$0 = HEAP32[$25 >> 2];
    var $141$1 = HEAP32[$25 + 4 >> 2];
    var $142 = $139 | 0;
    var $st$8$0 = $142 | 0;
    HEAP32[$st$8$0 >> 2] = $141$0;
    var $st$8$1 = $142 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $141$1;
    var $145 = HEAP32[$_01_ph >> 2];
    HEAP32[$145 >> 2] = $140;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 34:
    var $147 = __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $41, 0);
    HEAP32[$obj >> 2] = $147;
    if (($147 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $150 = HEAP32[$sp >> 2];
    _OBJECT_TO_JSVAL($11, $147);
    var $st$2$0 = $26 | 0;
    var $151$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $26 + 4 | 0;
    var $151$1 = HEAP32[$st$2$1 >> 2];
    var $152 = $150 | 0;
    var $st$7$0 = $152 | 0;
    HEAP32[$st$7$0 >> 2] = $151$0;
    var $st$7$1 = $152 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $151$1;
    var $153 = __ZNK8JSObject18getFunctionPrivateEv($147);
    var $156 = HEAP32[$_01_ph >> 2];
    HEAP32[$156 >> 2] = $153;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 36:
    var $161 = $41 | 0;
    var $162$0 = HEAP32[$161 >> 2];
    var $162$1 = HEAP32[$161 + 4 >> 2];
    var $163 = HEAP32[$_01_ph >> 2] | 0;
    var $st$9$0 = $163 | 0;
    HEAP32[$st$9$0 >> 2] = $162$0;
    var $st$9$1 = $163 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $162$1;
    var $_1 = $_01_ph + 4 | 0;
    __label__ = 39;
    break;
   case 37:
    HEAP32[$1 >> 2] = $30;
    var $165 = __ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc($cx, $1, $sp, $28);
    if (($165 | 0) == 0) {
      var $_0 = 0;
      __label__ = 40;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $30 = HEAP32[$1 >> 2];
    __label__ = 4;
    break;
   case 39:
    var $_1;
    var $168 = HEAP32[$sp >> 2] + 8 | 0;
    HEAP32[$sp >> 2] = $168;
    var $required_0_ph = $required_0_ph4;
    var $_01_ph = $_1;
    var $27 = $31;
    __label__ = 2;
    break;
   case 40:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ConvertArgumentsVA["X"] = 1;

function __ZN12JSValueArrayC1EPN2JS5ValueEj($this, $v, $c) {
  __ZN12JSValueArrayC2EPN2JS5ValueEj($this, $v, $c);
  return;
}

function __ZN16JSAutoByteStringC1Ev($this) {
  __ZN16JSAutoByteStringC2Ev($this);
  return;
}

function __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $fun, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$fun + 72 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = STRING_TABLE._js_anonymous_str | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    var $6 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytes, $cx, $5);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ReportErrorNumber($cx, $errorCallback, $userRef, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorNumber.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, 0, $errorCallback, $userRef, $errorNumber, 1, $2);
  STACKTOP = __stackBase__;
  return;
}

function __ZN16JSAutoByteStringD1Ev($this) {
  __ZN16JSAutoByteStringD2Ev($this);
  return;
}

function _JS_ValueToUint16($cx, $0, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $5 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $6 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($cx, $5, $ip);
  var $7 = $6 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ValueToECMAInt32($cx, $0, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $5 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $6 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $5, $ip);
  var $7 = $6 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ValueToECMAUint32($cx, $0, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $5 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $6 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $5, $ip);
  var $7 = $6 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ValueToInt32($cx, $0, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $5 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $6 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $5, $ip);
  var $7 = $6 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ValueToNumber($cx, $0, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $tvr = __stackBase__ + 8;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $v);
  var $5 = __ZNK2js15AutoValueRooter5valueEv($tvr);
  var $6 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $5, $dp);
  var $7 = $6 & 1;
  __ZN2js15AutoValueRooterD1Ev($tvr);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZL18js_DoubleToIntegerd($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSString11ensureFixedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString10ensureFlatEP9JSContext($this, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString12isExtensibleEv($this);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $this | 0;
    var $8 = HEAP32[$6 >> 2] ^ 8;
    HEAP32[$6 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    var $10 = __ZN8JSString7asFixedEv($this);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL284($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc($cx, $formatp, $vpp, $app) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$formatp >> 2];
    var $map_0_in = $cx + 172 | 0;
    __label__ = 2;
    break;
   case 2:
    var $map_0_in;
    var $map_0 = HEAP32[$map_0_in >> 2];
    if (($map_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$map_0 >> 2];
    var $9 = HEAP32[$map_0 + 4 >> 2];
    var $10 = _strncmp($1, $7, $9);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $1 + $9 | 0;
    HEAP32[$formatp >> 2] = $13;
    var $15 = HEAP32[$map_0 + 8 >> 2];
    var $16 = FUNCTION_TABLE[$15]($cx, $1, 1, $vpp, $app);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 5:
    var $map_0_in = $map_0 + 12 | 0;
    __label__ = 2;
    break;
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 4, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AddArgumentFormatter($cx, $format, $formatter) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($format);
    var $mpp_0 = $cx + 172 | 0;
    __label__ = 2;
    break;
   case 2:
    var $mpp_0;
    var $4 = HEAPU32[$mpp_0 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAPU32[$4 + 4 >> 2];
    if ($8 >>> 0 < $1 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = HEAP32[$4 >> 2];
    var $15 = _strcmp($14, $format);
    if (($15 | 0) == 0) {
      var $map_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $mpp_0 = $4 + 12 | 0;
    __label__ = 2;
    break;
   case 7:
    var $20 = __ZN9JSContext7malloc_Ej($cx, 16);
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$20 >> 2] = $format;
    HEAP32[$20 + 4 >> 2] = $1;
    var $27 = HEAP32[$mpp_0 >> 2];
    HEAP32[$20 + 12 >> 2] = $27;
    HEAP32[$mpp_0 >> 2] = $21;
    var $map_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $map_0;
    HEAP32[$map_0 + 8 >> 2] = $formatter;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_RemoveArgumentFormatter($cx, $format) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($format);
    var $mpp_0 = $cx + 172 | 0;
    __label__ = 2;
    break;
   case 2:
    var $mpp_0;
    var $4 = HEAP32[$mpp_0 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$4 + 4 >> 2] | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = HEAP32[$4 >> 2];
    var $13 = _strcmp($12, $format);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = HEAP32[$4 + 12 >> 2];
    HEAP32[$mpp_0 >> 2] = $17;
    var $18 = $4;
    __ZN9JSContext5free_EPv(undef, $18);
    __label__ = 7;
    break;
   case 6:
    var $mpp_0 = $4 + 12 | 0;
    __label__ = 2;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ConvertValue($cx, $0, $type, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $d = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $4 = __stackBase__ + 36;
    var $5 = __stackBase__ + 44;
    var $6 = __stackBase__ + 52;
    var $numBuf = __stackBase__ + 60;
    var $7 = $0 | 0;
    var $8$0 = HEAPU32[$7 >> 2];
    var $8$1 = HEAPU32[$7 + 4 >> 2];
    var $9 = $v | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    if (($type | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($type | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($type | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($type | 0) == 4) {
      __label__ = 8;
      break;
    } else if (($type | 0) == 5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $11$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $11$1 = HEAP32[$st$1$1 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 3:
    var $14 = $cx;
    var $15 = $obj;
    var $16 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($14, $v, $15);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL($2, $19);
    var $20 = $2 | 0;
    var $st$3$0 = $20 | 0;
    var $21$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$3$1 >> 2];
    var $22 = $vp | 0;
    var $st$8$0 = $22 | 0;
    HEAP32[$st$8$0 >> 2] = $21$0;
    var $st$8$1 = $22 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $21$1;
    var $_0 = $16;
    __label__ = 12;
    break;
   case 5:
    var $24 = $vp | 0;
    var $st$1$0 = $24 | 0;
    HEAP32[$st$1$0 >> 2] = $8$0;
    var $st$1$1 = $24 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $8$1;
    var $25 = __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $vp, 65536);
    HEAP32[$obj >> 2] = $25;
    var $_0 = ($25 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 6:
    var $29 = $cx;
    var $30 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($29, $v);
    var $31 = ($30 | 0) != 0;
    var $32 = $31 & 1;
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $32;
      __label__ = 12;
      break;
    }
   case 7:
    _STRING_TO_JSVAL($3, $30);
    var $34 = $3 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $vp | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $_0 = $32;
    __label__ = 12;
    break;
   case 8:
    var $38 = $4 | 0;
    var $st$1$0 = $38 | 0;
    HEAP32[$st$1$0 >> 2] = $8$0;
    var $st$1$1 = $38 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $8$1;
    var $39 = _JS_ValueToNumber($cx, $4, $d);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $42 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL($5, $42);
    var $43 = $5 | 0;
    var $st$3$0 = $43 | 0;
    var $44$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $43 + 4 | 0;
    var $44$1 = HEAP32[$st$3$1 >> 2];
    var $45 = $vp | 0;
    var $st$8$0 = $45 | 0;
    HEAP32[$st$8$0 >> 2] = $44$0;
    var $st$8$1 = $45 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $44$1;
    var $_0 = $39;
    __label__ = 12;
    break;
   case 10:
    var $47 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    _BOOLEAN_TO_JSVAL($6, $47);
    var $48 = $6 | 0;
    var $st$3$0 = $48 | 0;
    var $49$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $48 + 4 | 0;
    var $49$1 = HEAP32[$st$3$1 >> 2];
    var $50 = $vp | 0;
    var $st$8$0 = $50 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $50 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    var $52 = $numBuf | 0;
    var $53 = _JS_snprintf($52, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $type, tempInt));
    _JS_ReportErrorNumber($cx, 2, 0, 5, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $52, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ConvertValue["X"] = 1;

function _DOUBLE_TO_JSVAL($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL278($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ValueToObject($cx, $0, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = $objp;
  var $7 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($5, $v, $6);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_ValueToFunction($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 65536);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_ValueToConstructor($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 65536);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_ShutDown() {
  return;
}

function _JS_BeginRequest($cx) {
  return;
}

function _JS_EndRequest($cx) {
  return;
}

function _JS_YieldRequest($cx) {
  return;
}

function _JS_SuspendRequest($cx) {
  return 0;
}

function _JS_ResumeRequest($cx, $saveDepth) {
  return;
}

function _JS_IsInRequest($cx) {
  return 0;
}

function _JS_Lock($rt) {
  return;
}

function _JS_Unlock($rt) {
  return;
}

function _JS_GetImplementationVersion() {
  return STRING_TABLE.__str21214 | 0;
}

function _JS_PropertyStub($cx, $obj, $id, $vp) {
  return 1;
}

function _JS_StrictPropertyStub($cx, $obj, $id, $strict, $vp) {
  return 1;
}

function _JS_EnumerateStub($cx, $obj) {
  return 1;
}

function _JS_ResolveStub($cx, $obj, $id) {
  return 1;
}

function __ZN2jsL13VersionNumberE9JSVersion($version) {
  return $version & 4095;
}

function __ZN2js8ValueifyEP12JSStackFrame($fp) {
  return $fp;
}

function __ZNK2js15AutoValueRooter5valueEv($this) {
  return $this + 16 | 0;
}

function _JS_GetTypeName($cx, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($type >>> 0 > 7) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[_js_common_atom_names + ($type + 3 << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetRuntimePrivate($rt) {
  return HEAP32[$rt + 144236 >> 2];
}

function _JS_SetRuntimePrivate($rt, $data) {
  HEAP32[$rt + 144236 >> 2] = $data;
  return;
}

function _JS_SetContextCallback($rt, $cxCallback) {
  var $1 = $rt + 28 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $cxCallback;
  return $2;
}

function _JS_GetContextPrivate($cx) {
  return HEAP32[$cx + 188 >> 2];
}

function _JS_SetContextPrivate($cx, $data) {
  HEAP32[$cx + 188 >> 2] = $data;
  return;
}

function _JS_GetRuntime($cx) {
  return HEAP32[$cx + 52 >> 2];
}

function _JS_VersionToString($version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 12) {
      var $_0 = STRING_TABLE.__str20213 | 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[__ZL6v2smap + ($i_0 << 3) >> 2] | 0) == ($version | 0)) {
      var $_0 = HEAP32[__ZL6v2smap + ($i_0 << 3) + 4 >> 2];
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetCompartmentCallback($rt, $callback) {
  var $1 = $rt + 32 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $callback;
  return $2;
}

function _JS_SetWrapObjectCallbacks($rt, $callback, $precallback) {
  var $1 = $rt + 229020 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $callback;
  HEAP32[$rt + 229024 >> 2] = $precallback;
  return $2;
}

function _JS_SetCompartmentPrivate($cx, $compartment, $data) {
  var $1 = $compartment + 708 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $data;
  return $2;
}

function _JS_GetCompartmentPrivate($cx, $compartment) {
  return HEAP32[$compartment + 708 >> 2];
}

function _JS_ValueToString($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5, $v);
  STACKTOP = __stackBase__;
  return $6;
}

function _JS_ValueToSource($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($5, $v);
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  __ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE($this, $cx, $v);
  return;
}

function __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value8isNumberEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toNumberEv($v);
    tempDoubleF64[0] = $4, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $out);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoValueRooterD1Ev($this) {
  __ZN2js15AutoValueRooterD2Ev($this);
  return;
}

function _JS_DoubleIsInt32($d, $ip) {
  var $1 = _JSDOUBLE_IS_INT32228($d, $ip);
  return $1;
}

function _JSDOUBLE_IS_INT32228($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO301($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DoubleToInt32($d) {
  var $1 = __ZL20js_DoubleToECMAInt32d($d);
  return $1;
}

function __ZL20js_DoubleToECMAInt32d($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DoubleToUint32($d) {
  var $1 = __Z21js_DoubleToECMAUint32d($d);
  return $1;
}

function __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($cx, $v, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP16[$out >> 1] = $3 & 65535;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt($cx, $v, $out);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ValueToBoolean($cx, $0, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
  HEAP32[$bp >> 2] = $5;
  STACKTOP = __stackBase__;
  return 1;
}

function _JS_TypeOfValue($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $v);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_StrictlyEqual($cx, $0, $1, $equal) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v1 = __stackBase__;
  var $v2 = __stackBase__ + 8;
  var $3 = $0 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $v1 | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  var $6 = $1 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $v2 | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  var $9 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $equal);
  var $10 = $9 & 1;
  STACKTOP = __stackBase__;
  return $10;
}

function _JS_LooselyEqual($cx, $0, $1, $equal) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v1 = __stackBase__;
  var $v2 = __stackBase__ + 8;
  var $3 = $0 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $v1 | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  var $6 = $1 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $v2 | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  var $9 = __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $equal);
  var $10 = $9 & 1;
  STACKTOP = __stackBase__;
  return $10;
}

function _JS_SameValue($cx, $0, $1, $same) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v1 = __stackBase__;
  var $v2 = __stackBase__ + 8;
  var $3 = $0 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $v1 | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  var $6 = $1 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $v2 | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  var $9 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $same);
  var $10 = $9 & 1;
  STACKTOP = __stackBase__;
  return $10;
}

function _JS_IsBuiltinEvalFunction($fun) {
  var $1 = $fun;
  var $2 = __ZN2js16IsAnyBuiltinEvalEP10JSFunction($1);
  return $2 & 1;
}

function _JS_IsBuiltinFunctionConstructor($fun) {
  var $1 = __ZN2js28IsBuiltinFunctionConstructorEP10JSFunction($fun);
  return $1 & 1;
}

function __ZN9JSRuntimeC2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = $this + 4 | 0;
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_($5, $1);
  var $6 = $this + 48 | 0;
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_($6, $2);
  var $7 = $this + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($7, $3);
  var $8 = $this + 112 | 0;
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_($8, $4);
  var $9 = $this + 144280 | 0;
  __ZN2js10ThreadDataC2Ev($9);
  HEAP32[$this + 209940 >> 2] = 0;
  var $11 = $this + 209948 | 0;
  __ZN11JSAtomStateC1Ev($11);
  var $12 = $this + 210584 | 0;
  __ZN2js13StaticStringsC1Ev($12);
  var $13 = $this + 144140 | 0;
  HEAP32[$13 >> 2] = $13;
  HEAP32[$this + 144144 >> 2] = $13;
  var $16 = $this + 144228 | 0;
  HEAP32[$16 >> 2] = $16;
  HEAP32[$this + 144232 >> 2] = $16;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN11JSAtomStateC1Ev($this) {
  __ZN11JSAtomStateC2Ev($this);
  return;
}

function __ZN2js13StaticStringsC1Ev($this) {
  __ZN2js13StaticStringsC2Ev($this);
  return;
}

function __ZN9JSRuntime4initEj($this, $maxbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z9js_InitGCP9JSRuntimej($this, $maxbytes);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_($this, $this);
    var $5 = $this | 0;
    HEAP32[$5 >> 2] = $4;
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN13JSCompartment4initEP9JSContext($4, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this + 4 | 0;
    var $11 = HEAP32[$5 >> 2];
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($10, $11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = HEAP32[$5 >> 2];
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($13);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    HEAP8[HEAP32[$5 >> 2] + 341 | 0] = 1;
    var $17 = HEAP32[$5 >> 2];
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($17, 8192, 0);
    var $18 = __Z16js_InitAtomStateP9JSRuntime($this);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$this + 229020 >> 2] = 40;
    HEAP8[$this + 144220 | 0] = 0;
    var $23 = __Z14js_InitThreadsP9JSRuntime($this);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZN2js22InitRuntimeNumberStateEP9JSRuntime($this);
    var $_0 = $26;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 1988, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN13JSCompartmentC2EP9JSRuntime($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSCompartmentD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntimeD2Ev($this) {
  __ZN2js24FinishRuntimeNumberStateEP9JSRuntime($this);
  __Z18js_FinishAtomStateP9JSRuntime($this);
  __Z11js_FinishGCP9JSRuntime($this);
  var $1 = $this + 209948 | 0;
  __ZN11JSAtomStateD1Ev($1);
  var $2 = $this + 144280 | 0;
  __ZN2js10ThreadDataD2Ev($2);
  var $3 = $this + 112 | 0;
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev($3);
  var $4 = $this + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($4);
  var $5 = $this + 48 | 0;
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev($5);
  var $6 = $this + 4 | 0;
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev($6);
  return;
}

function __ZN11JSAtomStateD1Ev($this) {
  __ZN11JSAtomStateD2Ev($this);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function _JS_Init($maxbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[__ZL22js_NewRuntimeWasCalled_b]) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[__ZL22js_NewRuntimeWasCalled_b] = 1;
    __label__ = 3;
    break;
   case 3:
    var $3 = __ZN2js11OffTheBooks7calloc_Ej(234944);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = $3;
    __ZN9JSRuntimeC2Ev($6);
    var $7 = __ZN9JSRuntime4initEj($6, $maxbytes);
    if ($7) {
      var $_0 = $6;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_Finish($6);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks7calloc_Ej($bytes) {
  var $1 = _js_calloc299($bytes);
  return $1;
}

function _JS_Finish($rt) {
  __ZN2js10Foreground7delete_I9JSRuntimeEEvPT_($rt);
  return;
}

function __ZN2js10Foreground7delete_I9JSRuntimeEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSRuntimeD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewContext($rt, $stackChunkSize) {
  var $1 = __Z13js_NewContextP9JSRuntimej($rt, undef);
  return $1;
}

function _JS_DestroyContext($cx) {
  __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, 2);
  return;
}

function _JS_DestroyContextNoGC($cx) {
  __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, 0);
  return;
}

function _JS_DestroyContextMaybeGC($cx) {
  __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, 1);
  return;
}

function _JS_ContextIterator($rt, $iterp) {
  var $1 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($rt, 1, $iterp);
  return $1;
}

function _JS_GetVersion($cx) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __ZN2jsL13VersionNumberE9JSVersion($1);
  return $2;
}

function _JS_SetVersion($cx, $newVersion) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $newVersion;
    var $2 = __ZNK9JSContext11findVersionEv($cx);
    var $3 = __ZN2jsL13VersionNumberE9JSVersion($2);
    if (($3 | 0) == ($newVersion | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($newVersion | 0) != 0 & ($newVersion | 0) < 141) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL16VersionCopyFlagsEP9JSVersionS0_($1, $2);
    var $9 = HEAP32[$1 >> 2];
    var $10 = __ZN9JSContext20maybeOverrideVersionE9JSVersion($cx, $9);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16VersionCopyFlagsEP9JSVersionS0_($version, $from) {
  var $1 = HEAP32[$version >> 2];
  var $2 = __ZN2jsL13VersionNumberE9JSVersion($1);
  var $3 = __ZN2jsL19VersionExtractFlagsE9JSVersion($from);
  var $4 = $3 | $2;
  HEAP32[$version >> 2] = $4;
  return;
}

function __ZN9JSContext20maybeOverrideVersionE9JSVersion($this, $newVersion) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext20canSetDefaultVersionEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext17setDefaultVersionE9JSVersion($this, $newVersion);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN9JSContext15overrideVersionE9JSVersion($this, $newVersion);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_StringToVersion($string) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 12) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAP32[__ZL6v2smap + ($i_0 << 3) + 4 >> 2];
    var $6 = _strcmp($5, $string);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[__ZL6v2smap + ($i_0 << 3) >> 2];
    __label__ = 6;
    break;
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetOptions($cx) {
  var $1 = __ZNK9JSContext10allOptionsEv($cx);
  return $1;
}

function __ZNK9JSContext10allOptionsEv($this) {
  var $1 = __ZNK9JSContext13getRunOptionsEv($this);
  var $2 = __ZNK9JSContext17getCompileOptionsEv($this);
  return $2 | $1;
}

function _JS_SetOptions($cx, $options) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
  var $3 = __ZL16SetOptionsCommonP9JSContextj($cx, $options);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL16SetOptionsCommonP9JSContextj($cx, $options) {
  var $1 = __ZNK9JSContext10allOptionsEv($cx);
  var $2 = $options & 524223;
  var $3 = $options & 64;
  __ZN9JSContext13setRunOptionsEj($cx, $2);
  __ZN9JSContext17setCompileOptionsEj($cx, $3);
  return $1;
}

function _JS_ToggleOptions($cx, $options) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
  var $3 = __ZNK9JSContext10allOptionsEv($cx);
  var $4 = $3 ^ $options;
  var $5 = __ZL16SetOptionsCommonP9JSContextj($cx, $4);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_EnterCrossCompartmentCall($cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_($cx, $cx, $target);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js15AutoCompartment5enterEv($1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($1);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 52);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js15AutoCompartmentD2Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ConvertStub($cx, $obj, $type, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($1, $2, $type, $vp);
  return $3;
}

function _JS_EnterCrossCompartmentCallScript($cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sc = __stackBase__;
    var $2 = HEAP32[$target + 84 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $scriptObject_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $target;
    var $6 = __ZNK2js2gc4Cell11compartmentEv($5);
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, $6);
    var $7 = _JS_NewGlobalObject($cx, _js_dummy_class);
    var $8 = ($7 | 0) == 0;
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    if ($8) {
      var $_1 = 0;
      __label__ = 4;
      break;
    } else {
      var $scriptObject_0 = $7;
      __label__ = 3;
      break;
    }
   case 3:
    var $scriptObject_0;
    var $10 = _JS_EnterCrossCompartmentCall($cx, $scriptObject_0);
    var $_1 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewGlobalObject($cx, $clasp) {
  var $1 = __ZN2jsL8ValueifyEP7JSClass($clasp);
  var $2 = $cx;
  var $3 = $1;
  var $4 = __ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE($2, $3);
  return $4;
}

function _JS_EnterCrossCompartmentCallStackFrame($cx, $target) {
  var $1 = __ZN2js8ValueifyEP12JSStackFrame($target);
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  var $3 = $2;
  var $4 = __ZNK8JSObject9getGlobalEv($3);
  var $5 = $4;
  var $6 = _JS_EnterCrossCompartmentCall($cx, $5);
  return $6;
}

function _JS_LeaveCrossCompartmentCall($call) {
  var $1 = $call;
  __ZN2js15AutoCompartment5leaveEv($1);
  __ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_($1);
  return;
}

function __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($this, $cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZNK8JSObject14getCompartmentEv($target);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $8 = _JS_EnterCrossCompartmentCall($cx, $target);
    HEAP32[$this >> 2] = $8;
    var $_0 = ($8 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject14getCompartmentEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
  return $2;
}

function __ZN22JSAutoEnterCompartment20enterAndIgnoreErrorsEP9JSContextP8JSObject($this, $cx, $target) {
  var $1 = __ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject($this, $cx, $target);
  return;
}

function __ZN2JS26AutoEnterScriptCompartment5enterEP9JSContextP8JSScript($this, $cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = $target;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $9 = _JS_EnterCrossCompartmentCallScript($cx, $target);
    HEAP32[$this >> 2] = $9;
    var $_0 = ($9 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS25AutoEnterFrameCompartment5enterEP9JSContextP12JSStackFrame($this, $cx, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN2js8ValueifyEP12JSStackFrame($target);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK2js2gc4Cell11compartmentEv($5);
    if (($2 | 0) == ($6 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $11 = _JS_EnterCrossCompartmentCallStackFrame($cx, $target);
    HEAP32[$this >> 2] = $11;
    var $_0 = ($11 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_WrapObject($cx, $objp) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($2, $cx, $objp);
  return $3 & 1;
}

function _JS_WrapValue($cx, $vp) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function _JSID_TO_STRING243($iden) {
  return $iden;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function _JS_GetGlobalObject($cx) {
  return HEAP32[$cx + 132 >> 2];
}

function _JS_TransplantObject($cx, $origobj, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 256;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $origv = __stackBase__;
    var $p = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $targetv = __stackBase__ + 24;
    var $toTransplant = __stackBase__ + 32;
    var $wp = __stackBase__ + 124;
    var $3 = __stackBase__ + 128;
    var $ac = __stackBase__ + 136;
    var $tobj = __stackBase__ + 188;
    var $4 = __stackBase__ + 192;
    var $ac4 = __stackBase__ + 200;
    var $tobj5 = __stackBase__ + 252;
    var $5 = __ZNK8JSObject14getCompartmentEv($target);
    var $6 = $5 + 716 | 0;
    __ZN2JSL11ObjectValueER8JSObject239($origv, $origobj);
    var $7 = __ZNK8JSObject14getCompartmentEv($origobj);
    if (($7 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if (($origobj | 0) == ($target | 0)) {
      var $obj_0 = $origobj;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $origobj;
    var $13 = $cx;
    var $14 = $target;
    var $15 = __ZN8JSObject4swapEP9JSContextPS_($12, $13, $14);
    if ($15) {
      var $obj_0 = $origobj;
      __label__ = 6;
      break;
    } else {
      var $_4 = 0;
      __label__ = 26;
      break;
    }
   case 4:
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($p, $6, $origv);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      var $obj_0 = $target;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $22 = $21 + 8 | 0;
    var $23 = __ZNK2JS5Value8toObjectEv($22);
    var $25 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $25;
    __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E3PtrE($6, $2);
    var $27 = $23;
    var $28 = $cx;
    var $29 = $target;
    var $30 = __ZN8JSObject4swapEP9JSContextPS_($27, $28, $29);
    if ($30) {
      var $obj_0 = $23;
      __label__ = 6;
      break;
    } else {
      var $_4 = 0;
      __label__ = 26;
      break;
    }
   case 6:
    var $obj_0;
    __ZN2JSL11ObjectValueER8JSObject239($targetv, $obj_0);
    var $34 = HEAP32[$cx + 52 >> 2] + 4 | 0;
    __ZN2js15AutoValueVectorC1EP9JSContext($toTransplant, $cx);
    var $35 = $toTransplant | 0;
    var $36 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6lengthEv($34);
    var $37 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($35, $36);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_3 = 0;
      __label__ = 25;
      break;
    }
   case 7:
    var $39 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($34);
    var $40 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($34);
    if (($39 | 0) == ($40 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $42 = $3 | 0;
    var $p1_05 = $39;
    __label__ = 9;
    break;
   case 9:
    var $p1_05;
    var $45 = HEAP32[$p1_05 >> 2] + 716 | 0;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($wp, $45, $origv);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($3, $wp);
    if ((HEAP32[$42 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($wp);
    var $50 = $49 + 8 | 0;
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($35, $50);
    __label__ = 11;
    break;
   case 11:
    var $52 = $p1_05 + 4 | 0;
    if (($52 | 0) == ($40 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $p1_05 = $52;
      __label__ = 9;
      break;
    }
   case 12:
    var $54 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($35);
    var $55 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($35);
    var $56 = $cx;
    var $begin_0 = $54;
    __label__ = 13;
    break;
   case 13:
    var $begin_0;
    if (($begin_0 | 0) == ($55 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $60 = __ZNK2JS5Value8toObjectEv($begin_0);
    var $61 = $60;
    var $62 = __ZNK2js2gc4Cell11compartmentEv($61);
    var $63 = $62 + 716 | 0;
    __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeERKS2_($63, $origv);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $60);
    HEAP32[$tobj >> 2] = $obj_0;
    var $64 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($64) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $66 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($62, $cx, $tobj);
    if ($66) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $69 = $60;
    var $70 = HEAP32[$tobj >> 2];
    var $71 = __ZN8JSObject4swapEP9JSContextPS_($69, $56, $70);
    if ($71) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2JSL11ObjectValueER8JSObject239($4, $60);
    var $72 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($63, $targetv, $4);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $begin_0 = $begin_0 + 8 | 0;
    __label__ = 13;
    break;
   case 18:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = 0;
    __label__ = 25;
    break;
   case 19:
    var $76 = __ZNK8JSObject14getCompartmentEv($origobj);
    if (($76 | 0) == ($5 | 0)) {
      var $_3 = $obj_0;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac4, $cx, $origobj);
    HEAP32[$tobj5 >> 2] = $obj_0;
    var $79 = __ZN2js15AutoCompartment5enterEv($ac4);
    if ($79) {
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    var $81 = _JS_WrapObject($cx, $tobj5);
    if (($81 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $85 = $origobj;
    var $86 = HEAP32[$tobj5 >> 2];
    var $87 = __ZN8JSObject4swapEP9JSContextPS_($85, $56, $86);
    if ($87) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $88 = __ZNK8JSObject14getCompartmentEv($origobj);
    var $89 = $88 + 716 | 0;
    var $90 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($89, $targetv, $origv);
    __ZN2js15AutoCompartmentD2Ev($ac4);
    var $_3 = $obj_0;
    __label__ = 25;
    break;
   case 24:
    __ZN2js15AutoCompartmentD2Ev($ac4);
    var $_3 = 0;
    __label__ = 25;
    break;
   case 25:
    var $_3;
    __ZN2js15AutoValueVectorD1Ev($toTransplant);
    var $_4 = $_3;
    __label__ = 26;
    break;
   case 26:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_TransplantObject["X"] = 1;

function __ZN2JSL11ObjectValueER8JSObject239($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 42,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeENSB_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($this, $newLength) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj($1, $newLength);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($this, $v) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($1, $v);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($p, $this, $l);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($2);
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $7 + 8 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($2);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_($this, $p, $k, $v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($2);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_TransplantObjectWithWrapper($cx, $origobj, $origwrapper, $targetobj, $targetwrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 264;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $origv = __stackBase__;
    var $p = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $targetv = __stackBase__ + 24;
    var $toTransplant = __stackBase__ + 32;
    var $wp = __stackBase__ + 124;
    var $3 = __stackBase__ + 128;
    var $ac = __stackBase__ + 136;
    var $tobj = __stackBase__ + 188;
    var $4 = __stackBase__ + 192;
    var $ac4 = __stackBase__ + 200;
    var $tobj5 = __stackBase__ + 252;
    var $5 = __stackBase__ + 256;
    var $6 = __ZNK8JSObject14getCompartmentEv($targetobj);
    var $7 = $6 + 716 | 0;
    __ZN2JSL11ObjectValueER8JSObject239($origv, $origobj);
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($p, $7, $origv);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      var $obj_0 = $targetwrapper;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $13 = $12 + 8 | 0;
    var $14 = __ZNK2JS5Value8toObjectEv($13);
    var $16 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $16;
    __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E3PtrE($7, $2);
    var $18 = $14;
    var $19 = $cx;
    var $20 = $targetwrapper;
    var $21 = __ZN8JSObject4swapEP9JSContextPS_($18, $19, $20);
    if ($21) {
      var $obj_0 = $14;
      __label__ = 3;
      break;
    } else {
      var $_4 = 0;
      __label__ = 22;
      break;
    }
   case 3:
    var $obj_0;
    __ZN2JSL11ObjectValueER8JSObject239($targetv, $targetobj);
    var $25 = HEAP32[$cx + 52 >> 2] + 4 | 0;
    __ZN2js15AutoValueVectorC1EP9JSContext($toTransplant, $cx);
    var $26 = $toTransplant | 0;
    var $27 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6lengthEv($25);
    var $28 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($26, $27);
    if ($28) {
      __label__ = 4;
      break;
    } else {
      var $_3 = 0;
      __label__ = 21;
      break;
    }
   case 4:
    var $30 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($25);
    var $31 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($25);
    if (($30 | 0) == ($31 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $33 = $3 | 0;
    var $p1_05 = $30;
    __label__ = 6;
    break;
   case 6:
    var $p1_05;
    var $36 = HEAP32[$p1_05 >> 2] + 716 | 0;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($wp, $36, $origv);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($3, $wp);
    if ((HEAP32[$33 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $40 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($wp);
    var $41 = $40 + 8 | 0;
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($26, $41);
    __label__ = 8;
    break;
   case 8:
    var $43 = $p1_05 + 4 | 0;
    if (($43 | 0) == ($31 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $p1_05 = $43;
      __label__ = 6;
      break;
    }
   case 9:
    var $45 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($26);
    var $46 = __ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv($26);
    var $47 = $cx;
    var $begin_0 = $45;
    __label__ = 10;
    break;
   case 10:
    var $begin_0;
    if (($begin_0 | 0) == ($46 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = __ZNK2JS5Value8toObjectEv($begin_0);
    var $52 = $51;
    var $53 = __ZNK2js2gc4Cell11compartmentEv($52);
    var $54 = $53 + 716 | 0;
    __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeERKS2_($54, $origv);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $cx, $51);
    HEAP32[$tobj >> 2] = $targetobj;
    var $55 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($55) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $57 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($53, $cx, $tobj);
    if ($57) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $60 = $51;
    var $61 = HEAP32[$tobj >> 2];
    var $62 = __ZN8JSObject4swapEP9JSContextPS_($60, $47, $61);
    if ($62) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2JSL11ObjectValueER8JSObject239($4, $51);
    var $63 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($54, $targetv, $4);
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $begin_0 = $begin_0 + 8 | 0;
    __label__ = 10;
    break;
   case 15:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_3 = 0;
    __label__ = 21;
    break;
   case 16:
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac4, $cx, $origobj);
    HEAP32[$tobj5 >> 2] = $obj_0;
    var $67 = __ZN2js15AutoCompartment5enterEv($ac4);
    if ($67) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $69 = _JS_WrapObject($cx, $tobj5);
    if (($69 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $73 = $origwrapper;
    var $74 = HEAP32[$tobj5 >> 2];
    var $75 = __ZN8JSObject4swapEP9JSContextPS_($73, $47, $74);
    if ($75) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $76 = __ZNK8JSObject14getCompartmentEv($origwrapper);
    var $77 = $76 + 716 | 0;
    __ZN2JSL11ObjectValueER8JSObject239($5, $origwrapper);
    var $78 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($77, $targetv, $5);
    __ZN2js15AutoCompartmentD2Ev($ac4);
    var $_3 = $obj_0;
    __label__ = 21;
    break;
   case 20:
    __ZN2js15AutoCompartmentD2Ev($ac4);
    var $_3 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_3;
    __ZN2js15AutoValueVectorD1Ev($toTransplant);
    var $_4 = $_3;
    __label__ = 22;
    break;
   case 22:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_TransplantObjectWithWrapper["X"] = 1;

function _JS_SetGlobalObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$cx + 132 >> 2] = $obj;
    var $2 = __ZNK9JSContext5hasfpEv($cx);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext16resetCompartmentEv($cx);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_InitStandardClasses($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$cx + 132 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_SetGlobalObject($cx, $obj);
    __label__ = 3;
    break;
   case 3:
    var $6 = $obj;
    var $7 = __ZN8JSObject8asGlobalEv($6);
    var $8 = $cx;
    var $9 = __ZN2js12GlobalObject19initStandardClassesEP9JSContext($7, $8);
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ResolveStandardClass($cx, $obj, $id, $resolved) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$resolved >> 2] = 0;
    var $3 = HEAP32[$cx + 52 >> 2];
    if ((HEAP32[$3 + 24 >> 2] | 0) == 3) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZL12JSID_IS_ATOMi242($id);
    if (($8 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JSID_TO_STRING243($id);
    var $13 = HEAP32[$3 + 209984 >> 2];
    if (($11 | 0) == ($13 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $3 + 209948 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $19 = $13 | 0;
    HEAP32[$resolved >> 2] = 1;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom244($19);
    __ZN2JSL14UndefinedValueEv245($1);
    var $21 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $20, $1, 10, 12, 6);
    var $_0 = $21;
    __label__ = 25;
    break;
   case 6:
    var $i_0;
    var $23 = __ZL20standard_class_atoms + ($i_0 << 4) | 0;
    if ((HEAP32[$23 >> 2] | 0) == 0) {
      var $i_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($11 | 0) == (HEAP32[$17 + HEAP32[__ZL20standard_class_atoms + ($i_0 << 4) + 4 >> 2] >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    if (($23 | 0) == 0) {
      var $i_1 = 0;
      __label__ = 10;
      break;
    } else {
      var $stdnm_23 = $23;
      __label__ = 21;
      break;
    }
   case 10:
    var $i_1;
    var $39 = __ZL20standard_class_names + ($i_1 << 4) | 0;
    if ((HEAP32[$39 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $39);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($11 | 0) == ($44 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 10;
    break;
   case 14:
    if (($39 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $stdnm_23 = $39;
      __label__ = 21;
      break;
    }
   case 15:
    var $53 = __ZNK8JSObject8getProtoEv($obj);
    if (($53 | 0) == 0) {
      var $i_2 = 0;
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 16:
    var $i_2;
    var $55 = __ZL22object_prototype_names + ($i_2 << 4) | 0;
    if ((HEAP32[$55 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $60 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $55);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($11 | 0) == ($60 | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 16;
    break;
   case 20:
    if (($55 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      var $stdnm_23 = $55;
      __label__ = 21;
      break;
    }
   case 21:
    var $stdnm_23;
    var $70 = HEAP32[$stdnm_23 + 12 >> 2];
    if ((HEAP32[$70 + 4 >> 2] & 131072 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 22:
    var $76 = $obj;
    var $77 = $70;
    var $78 = __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($76, $77);
    if ($78) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $81 = HEAP32[$stdnm_23 >> 2];
    var $82 = FUNCTION_TABLE[$81]($cx, $obj);
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$resolved >> 2] = 1;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ResolveStandardClass["X"] = 1;

function __ZL12JSID_IS_ATOMi242($id) {
  var $1 = _JSID_IS_STRING293($id);
  return $1;
}

function __ZL12ATOM_TO_JSIDP6JSAtom244($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj300($1);
  return $2;
}

function __ZN2JSL14UndefinedValueEv245($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $stdn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$stdn + 4 >> 2];
    var $3 = $cx + 52 | 0;
    var $9 = HEAP32[HEAP32[$3 >> 2] + 209948 + $2 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $atom_0 = $9;
      __label__ = 4;
      break;
    }
   case 2:
    var $13 = HEAP32[$stdn + 8 >> 2];
    if (($13 | 0) == 0) {
      var $atom_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = _strlen($13);
    var $17 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $13, $16, 1, 0);
    var $22 = HEAP32[$3 >> 2] + 209948 + $2 | 0;
    HEAP32[$22 >> 2] = $17;
    var $atom_0 = $17;
    __label__ = 4;
    break;
   case 4:
    var $atom_0;
    return $atom_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EnumerateStandardClasses($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $8 = __ZN8JSObject14nativeContainsEP9JSContexti($obj, $cx, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv245($1);
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $7, $1, 10, 12, 6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $obj;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $14 = __ZL20standard_class_atoms + ($i_0 << 4) | 0;
    if (($i_0 | 0) == 17) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = HEAP32[__ZL20standard_class_atoms + ($i_0 << 4) + 12 >> 2];
    var $20 = __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($12, $19);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = HEAP32[$14 >> 2];
    var $23 = FUNCTION_TABLE[$22]($cx, $obj);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject14nativeContainsEP9JSContexti($this, $cx, $id) {
  var $1 = __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $id);
  return ($1 | 0) != 0;
}

function __ZN2js10NewIdArrayEP9JSContexti($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $length << 3 | 4;
    var $3 = __ZN9JSContext7calloc_Ej($cx, $2);
    var $4 = $3;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $length;
    __label__ = 3;
    break;
   case 3:
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EnumerateResolvedStandardClasses($cx, $obj, $ida) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $found = __stackBase__ + 4;
    var $2 = HEAP32[$cx + 52 >> 2];
    if (($ida | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_01 = $ida;
    var $storemerge = HEAP32[$ida >> 2];
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZN2js10NewIdArrayEP9JSContexti($cx, 8);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $_01 = $8;
      var $storemerge = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $storemerge;
    var $_01;
    HEAP32[$i >> 2] = $storemerge;
    var $13 = HEAP32[$2 + 209984 >> 2] | 0;
    var $14 = __ZL19EnumerateIfResolvedP9JSContextP8JSObjectP6JSAtomP9JSIdArrayPiS7_($cx, $obj, $13, $_01, $i, $found);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $2 + 209948 | 0;
    var $_1 = $14;
    var $j_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $j_0;
    var $_1;
    var $19 = __ZL20standard_class_atoms + ($j_0 << 4) | 0;
    if (($j_0 | 0) == 17) {
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$17 + HEAP32[__ZL20standard_class_atoms + ($j_0 << 4) + 4 >> 2] >> 2];
    var $27 = __ZL19EnumerateIfResolvedP9JSContextP8JSObjectP6JSAtomP9JSIdArrayPiS7_($cx, $obj, $26, $_1, $i, $found);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$found >> 2] | 0) == 0) {
      var $_5 = $27;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = HEAP32[$19 >> 2];
    var $k_0 = 0;
    var $_2 = $27;
    __label__ = 10;
    break;
   case 10:
    var $_2;
    var $k_0;
    var $35 = __ZL20standard_class_names + ($k_0 << 4) | 0;
    var $37 = HEAP32[$35 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($37 | 0) == ($33 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_3 = $_2;
      __label__ = 13;
      break;
    }
   case 12:
    var $42 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $35);
    var $43 = __ZL14AddAtomToArrayP9JSContextP6JSAtomP9JSIdArrayPi($cx, $42, $_2, $i);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $_3 = $43;
      __label__ = 13;
      break;
    }
   case 13:
    var $_3;
    var $k_0 = $k_0 + 1 | 0;
    var $_2 = $_3;
    __label__ = 10;
    break;
   case 14:
    if (($33 | 0) == 44) {
      var $k_1 = 0;
      var $_4 = $_2;
      __label__ = 15;
      break;
    } else {
      var $_5 = $_2;
      __label__ = 18;
      break;
    }
   case 15:
    var $_4;
    var $k_1;
    var $49 = __ZL22object_prototype_names + ($k_1 << 4) | 0;
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      var $_5 = $_4;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $54 = __ZL13StdNameToAtomP9JSContextP9JSStdName($cx, $49);
    var $55 = __ZL14AddAtomToArrayP9JSContextP6JSAtomP9JSIdArrayPi($cx, $54, $_4, $i);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $k_1 = $k_1 + 1 | 0;
    var $_4 = $55;
    __label__ = 15;
    break;
   case 18:
    var $_5;
    var $_1 = $_5;
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 6;
    break;
   case 19:
    var $61 = HEAP32[$i >> 2];
    var $62 = __ZL16SetIdArrayLengthP9JSContextP9JSIdArrayi($cx, $_1, $61);
    var $_0 = $62;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_EnumerateResolvedStandardClasses["X"] = 1;

function __ZL19EnumerateIfResolvedP9JSContextP8JSObjectP6JSAtomP9JSIdArrayPiS7_($cx, $obj, $atom, $ida, $ip, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12ATOM_TO_JSIDP6JSAtom244($atom);
    var $2 = __ZN8JSObject14nativeContainsEP9JSContexti($obj, $cx, $1);
    HEAP32[$foundp >> 2] = $2 & 1;
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $ida;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZL14AddAtomToArrayP9JSContextP6JSAtomP9JSIdArrayPi($cx, $atom, $ida, $ip);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14AddAtomToArrayP9JSContextP6JSAtomP9JSIdArrayPi($cx, $atom, $ida, $ip) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$ip >> 2];
    var $3 = HEAP32[$ida >> 2];
    if (($1 | 0) < ($3 | 0)) {
      var $_01 = $ida;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 << 1;
    var $8 = ($6 | 0) > 8 ? $6 : 8;
    var $9 = __ZL16SetIdArrayLengthP9JSContextP9JSIdArrayi($cx, $ida, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $_01 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom244($atom);
    var $13 = $_01 + 4 + ($1 << 2) | 0;
    HEAP32[$13 >> 2] = $12;
    var $14 = $1 + 1 | 0;
    HEAP32[$ip >> 2] = $14;
    var $_0 = $_01;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16SetIdArrayLengthP9JSContextP9JSIdArrayi($cx, $ida, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ida;
    var $3 = $length << 3 | 4;
    var $4 = _JS_realloc($cx, $1, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_DestroyIdArray(undef, $ida);
    __label__ = 4;
    break;
   case 3:
    HEAP32[$4 >> 2] = $length;
    __label__ = 4;
    break;
   case 4:
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetClassObject($cx, $obj, $key, $objp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = $objp;
  var $4 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($1, $2, $key, $3);
  return $4;
}

function _JS_GetScopeChain($cx) {
  var $1 = __ZN2js13GetScopeChainEP9JSContext($cx);
  return $1;
}

function _JS_GetGlobalForObject($cx, $obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject9getGlobalEv($1);
  return $2;
}

function _JS_GetGlobalForScopeChain($cx) {
  var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext($cx);
  return $1 | 0;
}

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($cx);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $_0 = $6;
    __label__ = 5;
    break;
   case 3:
    var $10 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $10;
    var $11 = $cx;
    var $12 = $scope;
    var $13 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($11, $12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$scope >> 2];
    var $17 = __ZN8JSObject8asGlobalEv($16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AnchorPtr($p) {
  return;
}

function _JS_SetGCParameterForThread($cx, $key, $value) {
  return;
}

function _JS_GetGCParameterForThread($cx, $key) {
  return 0;
}

function _JS_FlushCaches($cx) {
  return;
}

function _JS_FinalizeStub($cx, $obj) {
  return;
}

function _JS_CANONICALIZE_NAN($d) {
  var $1 = isNaN($d) || isNaN(0);
  var $_d = $1 ? NaN : $d;
  return $_d;
}

function _OBJECT_TO_JSID($obj) {
  return $obj | 4;
}

function __ZN8JSString10asExternalEv($this) {
  return $this;
}

function __ZN2jsL8ValueifyEP7JSClass($c) {
  return $c;
}

function _JS_SetExtraGCRoots($rt, $traceOp, $data) {
  HEAP32[$rt + 144100 >> 2] = $traceOp;
  HEAP32[$rt + 144104 >> 2] = $data;
  return;
}

function _JS_IsGCMarkingTracer($trc) {
  return (HEAP32[$trc + 4 >> 2] | 0) == 0 & 1;
}

function _JS_SetGCCallbackRT($rt, $cb) {
  var $1 = $rt + 144092 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $cb;
  return $2;
}

function __ZN16JSExternalString15changeFinalizerEPFvP9JSContextP8JSStringES5_($oldop, $newop) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 8) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZN16JSExternalString14str_finalizersE + ($i_0 << 2) | 0;
    if ((HEAP32[$4 >> 2] | 0) == ($oldop | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$4 >> 2] = $newop;
    var $_0 = $i_0;
    __label__ = 6;
    break;
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK16JSExternalString15externalClosureEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function _JS_SetThreadStackLimit($cx, $limitAddr) {
  var $_0 = ($limitAddr | 0) == 0 ? -1 : $limitAddr;
  HEAP32[$cx + 48 >> 2] = $_0;
  return;
}

function _JS_SetNativeStackQuota($cx, $stackSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($stackSize | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$cx + 48 >> 2] = -1;
    __label__ = 4;
    break;
   case 3:
    var $11 = $stackSize - 1 + HEAP32[HEAP32[$cx + 52 >> 2] + 209880 >> 2] | 0;
    HEAP32[$cx + 48 >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject9isNewbornEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZNK8JSObject8slotSpanEv($this) {
  return HEAP32[HEAP32[$this >> 2] + 4 >> 2];
}

function _JS_ComputeThis($agg_result, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 8;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $vp, 2);
    __ZN2js18CallReceiverFromVpEPN2JS5ValueE($call, $vp);
    var $2 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $call);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $4$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $4$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $5 = $agg_result | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZNK2js12CallReceiver5thisvEv($call);
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $agg_result | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18CallReceiverFromVpEPN2JS5ValueE($agg_result, $vp) {
  var $1 = $vp + 16 | 0;
  __ZN2js20CallReceiverFromArgvEPN2JS5ValueE($agg_result, $1);
  return;
}

function _JS_malloc($cx, $nbytes) {
  var $1 = __ZN9JSContext7malloc_Ej($cx, $nbytes);
  return $1;
}

function _JS_realloc($cx, $p, $nbytes) {
  var $1 = __ZN9JSContext8realloc_EPvj($cx, $p, $nbytes);
  return $1;
}

function __ZN9JSContext8realloc_EPvj($this, $p, $bytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime8realloc_EPvjP9JSContext($2, $p, $bytes, $this);
  return $3;
}

function _JS_free($cx, $p) {
  __ZN9JSContext5free_EPv(undef, $p);
  return;
}

function _JS_updateMallocCounter($cx, $nbytes) {
  var $2 = HEAP32[$cx + 52 >> 2];
  __ZN9JSRuntime19updateMallocCounterEj($2, $nbytes);
  return;
}

function _JS_strdup($cx, $s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($s);
    var $2 = $1 + 1 | 0;
    var $3 = __ZN9JSContext7malloc_Ej($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memcpy($3, $s, $2, 1);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewNumberValue($cx, $d, $rval) {
  var $1 = _JS_CANONICALIZE_NAN($d);
  var $2 = __ZN2JS5Value9setNumberEd($rval, $1);
  return 1;
}

function _JS_AddValueRoot($cx, $vp) {
  var $1 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $vp, 0);
  return $1;
}

function _JS_AddStringRoot($cx, $rp) {
  var $1 = $rp;
  var $2 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1, 0);
  return $2;
}

function _JS_AddObjectRoot($cx, $rp) {
  var $1 = $rp;
  var $2 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1, 0);
  return $2;
}

function _JS_AddGCThingRoot($cx, $rp) {
  var $1 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $rp, 0);
  return $1;
}

function _JS_AddNamedValueRoot($cx, $vp, $name) {
  var $1 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $vp, $name);
  return $1;
}

function _JS_AddNamedStringRoot($cx, $rp, $name) {
  var $1 = $rp;
  var $2 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1, $name);
  return $2;
}

function _JS_AddNamedObjectRoot($cx, $rp, $name) {
  var $1 = $rp;
  var $2 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1, $name);
  return $2;
}

function _JS_AddNamedScriptRoot($cx, $rp, $name) {
  var $1 = $rp;
  var $2 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $1, $name);
  return $2;
}

function _JS_AddNamedGCThingRoot($cx, $rp, $name) {
  var $1 = __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $rp, $name);
  return $1;
}

function _JS_RemoveValueRoot($cx, $vp) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $vp;
  var $4 = _js_RemoveRoot($2, $3);
  return 1;
}

function _JS_RemoveStringRoot($cx, $rp) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $rp;
  var $4 = _js_RemoveRoot($2, $3);
  return 1;
}

function _JS_RemoveObjectRoot($cx, $rp) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $rp;
  var $4 = _js_RemoveRoot($2, $3);
  return 1;
}

function _JS_RemoveScriptRoot($cx, $rp) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $rp;
  var $4 = _js_RemoveRoot($2, $3);
  return 1;
}

function _JS_RemoveGCThingRoot($cx, $rp) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $rp;
  var $4 = _js_RemoveRoot($2, $3);
  return 1;
}

function _JS_MapGCRoots($rt, $map, $data) {
  var $1 = __Z13js_MapGCRootsP9JSRuntimePFiPv12JSGCRootTypePKcS1_ES1_($rt, $map, $data);
  return $1;
}

function _JS_LockGCThing($cx, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = __Z16js_LockGCThingRTP9JSRuntimePv($2, $thing);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportOutOfMemory($cx);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ReportOutOfMemory($cx) {
  __Z20js_ReportOutOfMemoryP9JSContext($cx);
  return;
}

function _JS_LockGCThingRT($rt, $thing) {
  var $1 = __Z16js_LockGCThingRTP9JSRuntimePv($rt, $thing);
  return $1;
}

function _JS_UnlockGCThing($cx, $thing) {
  var $2 = HEAP32[$cx + 52 >> 2];
  __Z18js_UnlockGCThingRTP9JSRuntimePv($2, $thing);
  return 1;
}

function _JS_UnlockGCThingRT($rt, $thing) {
  __Z18js_UnlockGCThingRTP9JSRuntimePv($rt, $thing);
  return 1;
}

function _JS_TraceRuntime($trc) {
  __ZN2js12TraceRuntimeEP8JSTracer($trc);
  return;
}

function _JS_CallTracer($trc, $thing, $kind) {
  __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind);
  return;
}

function _JS_CompartmentGC($cx, $comp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 72 | 0;
    if ((HEAP32[$cx + 88 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_FinishArenaPool($1);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[__ZN2js8gcReasonE >> 2] = 0;
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $12;
    __label__ = 6;
    break;
   case 6:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $comp, 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GC($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $5;
    __label__ = 4;
    break;
   case 4:
    _JS_CompartmentGC($cx, 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_MaybeGC($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 72 | 0;
    if ((HEAP32[$cx + 88 >> 2] | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_FinishArenaPool($1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7MaybeGCEP9JSContext($cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetGCCallback($cx, $cb) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = _JS_SetGCCallbackRT($2, $cb);
  return $3;
}

function _JS_IsAboutToBeFinalized($cx, $thing) {
  var $1 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $thing);
  return $1 & 1;
}

function _JS_SetGCParameter($rt, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($key | 0) == 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    HEAP32[$rt + 152 >> 2] = $value;
    __label__ = 6;
    break;
   case 3:
    __ZN9JSRuntime19setGCMaxMallocBytesEj($rt, $value);
    __label__ = 6;
    break;
   case 4:
    HEAP32[$rt + 160 >> 2] = $value;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$rt + 192 >> 2] = $value;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime19setGCMaxMallocBytesEj($this, $value) {
  var $2 = ($value | 0) > -1 ? $value : 2147483647;
  HEAP32[$this + 156 >> 2] = $2;
  __ZN9JSRuntime18resetGCMallocBytesEv($this);
  return;
}

function _JS_GetGCParameter($rt, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($key | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($key | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($key | 0) == 6) {
      __label__ = 6;
      break;
    } else if (($key | 0) == 7) {
      __label__ = 7;
      break;
    } else if (($key | 0) == 8) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $_0 = HEAP32[$rt + 152 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $_0 = HEAP32[$rt + 156 >> 2];
    __label__ = 10;
    break;
   case 4:
    var $_0 = HEAP32[$rt + 160 >> 2];
    __label__ = 10;
    break;
   case 5:
    var $_0 = HEAP32[$rt + 140 >> 2];
    __label__ = 10;
    break;
   case 6:
    var $_0 = HEAP32[$rt + 192 >> 2];
    __label__ = 10;
    break;
   case 7:
    var $_0 = HEAP32[$rt + 84 >> 2];
    __label__ = 10;
    break;
   case 8:
    var $20 = $rt + 48 | 0;
    var $21 = __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv($20);
    var $_0 = HEAP32[$rt + 84 >> 2] + $21 | 0;
    __label__ = 10;
    break;
   case 9:
    var $_0 = HEAP32[$rt + 164 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($1);
  return $2;
}

function _JS_AddExternalStringFinalizer($finalizer) {
  var $1 = __ZN16JSExternalString15changeFinalizerEPFvP9JSContextP8JSStringES5_(0, $finalizer);
  return $1;
}

function _JS_RemoveExternalStringFinalizer($finalizer) {
  var $1 = __ZN16JSExternalString15changeFinalizerEPFvP9JSContextP8JSStringES5_($finalizer, 0);
  return $1;
}

function _JS_NewExternalString($cx, $chars, $length, $type) {
  var $1 = __ZN16JSExternalString4new_EP9JSContextPKtjiPv($cx, $chars, $length, $type, 0);
  return $1 | 0;
}

function __ZN16JSExternalString4new_EP9JSContextPKtjiPv($cx, $chars, $length, $type, $closure) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z22js_NewGCExternalStringP9JSContext($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN16JSExternalString4initEPKtjiPv($1, $chars, $length, $type, $closure);
    var $5 = HEAP32[$cx + 52 >> 2];
    var $7 = ($length << 1) + 2 | 0;
    __ZN9JSRuntime19updateMallocCounterEj($5, $7);
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewExternalStringWithClosure($cx, $chars, $length, $type, $closure) {
  var $1 = __ZN16JSExternalString4new_EP9JSContextPKtjiPv($cx, $chars, $length, $type, $closure);
  return $1 | 0;
}

function _JS_IsExternalString($cx, $str) {
  var $1 = __ZNK8JSString10isExternalEv($str);
  return $1 & 1;
}

function _JS_GetExternalStringClosure($cx, $str) {
  var $1 = __ZN8JSString10asExternalEv($str);
  var $2 = __ZNK16JSExternalString15externalClosureEv($1);
  return $2;
}

function _JS_DestroyIdArray($cx, $ida) {
  var $1 = $ida;
  __ZN9JSContext5free_EPv(undef, $1);
  return;
}

function _JS_ValueToId($cx, $0, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $v, $idp);
  var $6 = $5 & 1;
  STACKTOP = __stackBase__;
  return $6;
}

function _JS_IdToValue($cx, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2jsL9IdToJsvalEi($1, $id);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $vp | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN2jsL9IdToJsvalEi($agg_result, $id) {
  __ZN2jsL9IdToValueEi($agg_result, $id);
  return;
}

function _JS_InitClass($cx, $obj, $parent_proto, $clasp, $constructor, $nargs, $ps, $fs, $static_ps, $static_fs) {
  var $1 = __ZN2jsL8ValueifyEP7JSClass($clasp);
  var $2 = $cx;
  var $3 = $obj;
  var $4 = $parent_proto;
  var $5 = $1;
  var $6 = $constructor;
  var $7 = $ps;
  var $8 = $fs;
  var $9 = $static_ps;
  var $10 = $static_fs;
  var $11 = __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($2, $3, $4, $5, $6, $nargs, $7, $8, $9, $10, 0);
  return $11;
}

function _JS_GetClass($obj) {
  var $1 = __ZNK8JSObject10getJSClassEv($obj);
  return $1;
}

function __ZNK8JSObject10getJSClassEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = __ZN2jsL8JsvalifyEPNS_5ClassE($2);
  return $3;
}

function _JS_InstanceOf($cx, $obj, $clasp, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject10getJSClassEv($obj);
    if (($3 | 0) == ($clasp | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argv | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $argv - 16 | 0;
    var $9 = __ZN2jsL8ValueifyEP7JSClass($clasp);
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $8, $9);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HasInstance($cx, $obj, $0, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp);
  STACKTOP = __stackBase__;
  return $5;
}

function _JS_GetPrivate($cx, $obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function _JS_SetPrivate($cx, $obj, $data) {
  __ZN8JSObject10setPrivateEPv($obj, $data);
  return 1;
}

function _JS_GetInstancePrivate($cx, $obj, $clasp, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_InstanceOf($cx, $obj, $clasp, $argv);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($obj);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPrototype($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8getProtoEv($obj);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject9isNewbornEv($1);
    if ($4) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetPrototype($cx, $obj, $proto) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = $proto;
  var $4 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($1, $2, $3, 0);
  return $4 & 1;
}

function _JS_GetParent($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9getParentEv($obj);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject9isNewbornEv($1);
    if ($4) {
      var $7 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetParent($cx, $obj, $parent) {
  __ZN8JSObject9setParentEPS_($obj, $parent);
  return 1;
}

function _JS_GetConstructor($cx, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cval = __stackBase__;
    var $rf = __stackBase__ + 8;
    var $funobj = __stackBase__ + 16;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
    var $4 = HEAP32[HEAP32[$cx + 52 >> 2] + 210204 >> 2];
    var $5 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($proto, $cx, $4, $cval);
    var $6 = ($5 | 0) == 0;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    if ($6) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246($cval, $funobj);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject8getClassEv($proto);
    var $12 = HEAP32[$10 >> 2];
    _JS_ReportErrorNumber($cx, 2, 0, 9, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_1 = 0;
    __label__ = 5;
    break;
   case 4:
    var $14 = __ZNK2JS5Value8toObjectEv($cval);
    var $_1 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSAutoResolveFlagsC1EP9JSContextj($this, $cx, $flags) {
  __ZN18JSAutoResolveFlagsC2EP9JSContextj($this, $cx, $flags);
  return;
}

function __ZN18JSAutoResolveFlagsD1Ev($this) {
  __ZN18JSAutoResolveFlagsD2Ev($this);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetObjectId($cx, $obj, $idp) {
  var $1 = _OBJECT_TO_JSID($obj);
  HEAP32[$idp >> 2] = $1;
  return 1;
}

function _JS_NewCompartmentAndGlobalObject($cx, $clasp, $principals) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hold = __stackBase__;
    var $1 = __ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals($cx, $principals);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN19AutoHoldCompartmentC1EP13JSCompartment($hold, $1);
    var $5 = HEAP32[$cx + 56 >> 2];
    var $6 = $cx;
    var $7 = $1;
    __ZN9JSContext14setCompartmentEP13JSCompartment($6, $7);
    var $8 = _JS_NewGlobalObject($cx, $clasp);
    var $9 = $5;
    __ZN9JSContext14setCompartmentEP13JSCompartment($6, $9);
    __ZN19AutoHoldCompartmentD1Ev($hold);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19AutoHoldCompartmentC1EP13JSCompartment($this, $compartment) {
  __ZN19AutoHoldCompartmentC2EP13JSCompartment($this, $compartment);
  return;
}

function __ZN19AutoHoldCompartmentD1Ev($this) {
  __ZN19AutoHoldCompartmentD2Ev($this);
  return;
}

function _JS_NewObject($cx, $jsclasp, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($1 | 0) == 0 ? __ZN2js11ObjectClassE : $1;
    if (($proto | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 1);
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp_0, $proto, $parent);
    if (($7 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$clasp_0 + 68 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $7, 2097152);
    __label__ = 6;
    break;
   case 6:
    var $15 = $7;
    __ZN8JSObject19syncSpecialEqualityEv($15);
    var $16 = __ZNK8JSObject4typeEv($7);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $16, 0);
    __label__ = 7;
    break;
   case 7:
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $obj, $markSetsUnknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10TypeObject17unknownPropertiesEv($obj);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($obj, $cx);
    __label__ = 4;
    break;
   case 4:
    if ($markSetsUnknown) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    if ((HEAP32[$obj + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE(undef, $cx, $obj);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewObjectWithGivenProto($cx, $jsclasp, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($1 | 0) == 0 ? __ZN2js11ObjectClassE : $1;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247($cx, $clasp_0, $proto, $parent);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN8JSObject19syncSpecialEqualityEv($6);
    var $7 = __ZNK8JSObject4typeEv($3);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $7, 0);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function _JS_NewObjectForConstructor($cx, $vp) {
  var $1 = $vp | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_OBJECT($2$0, $2$1);
  var $4 = $cx;
  var $5 = $3;
  var $6 = __Z13js_CreateThisP9JSContextP8JSObject($4, $5);
  return $6;
}

function _JSVAL_TO_OBJECT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL296($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_IsExtensible($obj) {
  var $1 = __ZNK8JSObject12isExtensibleEv($obj);
  return $1 & 1;
}

function _JS_IsNative($obj) {
  var $1 = __ZNK8JSObject8isNativeEv($obj);
  return $1 & 1;
}

function _JS_FreezeObject($cx, $obj) {
  var $1 = __ZN8JSObject6freezeEP9JSContext($obj, $cx);
  return $1 & 1;
}

function _JS_DeepFreezeObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isExtensibleEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject6freezeEP9JSContext($obj, $cx);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject8slotSpanEv($obj);
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    var $9 = __ZNK8JSObject7getSlotEj($obj, $i_0);
    var $10 = __ZNK2JS5Value11isPrimitiveEv($9);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = __ZNK2JS5Value8toObjectEv($9);
    var $13 = _JS_DeepFreezeObject($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value11isPrimitiveEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_PRIMITIVE_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function _JS_ConstructObject($cx, $jsclasp, $proto, $parent) {
  var $1 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
  var $3 = $cx;
  var $5 = ($1 | 0) == 0 ? __ZN2js11ObjectClassE : $1;
  var $6 = $proto;
  var $7 = $parent;
  var $8 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($3, $5, $6, $7, 0, 0);
  return $8;
}

function _JS_ConstructObjectWithArguments($cx, $jsclasp, $proto, $parent, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $argv, $argc);
  var $2 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
  var $4 = $cx;
  var $6 = ($2 | 0) == 0 ? __ZN2js11ObjectClassE : $2;
  var $7 = $proto;
  var $8 = $parent;
  var $9 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($4, $6, $7, $8, $argc, $argv);
  var $10 = $9;
  STACKTOP = __stackBase__;
  return $10;
}

function _JS_LookupPropertyById($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 1, $obj2, $prop);
    if (($1 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj2 >> 2];
    var $5 = HEAP32[$prop >> 2];
    var $6 = __ZL12LookupResultP9JSContextP8JSObjectS2_iP10JSPropertyPN2JS5ValueE($cx, $4, $id, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, $flags);
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $1, $objp, $propp);
  __ZN18JSAutoResolveFlagsD1Ev($rf);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12LookupResultP9JSContextP8JSObjectS2_iP10JSPropertyPN2JS5ValueE($cx, $obj2, $id, $prop, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    if (($prop | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_1 = 1;
    __label__ = 17;
    break;
   case 3:
    var $4 = __ZNK8JSObject8isNativeEv($obj2);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $6 = $prop;
    var $7 = __ZNK2js5Shape8isMethodEv($6);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $9 = __ZNK2js5Shape12methodObjectEv($6);
    __ZN2JS5Value9setObjectER8JSObject($vp, $9);
    var $10 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($obj2, $cx, $6, $vp);
    var $_1 = ($10 | 0) != 0 & 1;
    __label__ = 17;
    break;
   case 6:
    var $15 = HEAPU32[$6 + 24 >> 2];
    var $16 = __ZNK8JSObject12containsSlotEj($obj2, $15);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 7:
    var $18 = __ZNK8JSObject13nativeGetSlotEj($obj2, $15);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 8:
    var $23 = __ZNK8JSObject12isDenseArrayEv($obj2);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $25 = __Z28js_GetDenseArrayElementValueP9JSContextP8JSObjectiPN2JS5ValueE(undef, $obj2, $id, $vp);
    var $_1 = 1;
    __label__ = 17;
    break;
   case 10:
    var $27 = __ZNK8JSObject7isProxyEv($obj2);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $29 = $desc + 16 | 0;
    var $30 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj2, $id, 0, $29);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$desc + 20 >> 2] & 64 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $37 = $desc + 32 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $vp | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $_0_ph = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0_ph;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $_1 = $_0_ph;
    __label__ = 17;
    break;
   case 15:
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    __label__ = 16;
    break;
   case 16:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_1 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12LookupResultP9JSContextP8JSObjectS2_iP10JSPropertyPN2JS5ValueE["X"] = 1;

function _JS_LookupElement($cx, $obj, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = _JS_LookupPropertyById($cx, $obj, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($index >>> 0 < 1073741824) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _INT_TO_JSID250($index);
    HEAP32[$idp >> 2] = $3;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js13IndexToIdSlowEP9JSContextjPi($cx, $index, $idp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_LookupProperty($cx, $obj, $name, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_LookupPropertyById($cx, $obj, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_LookupUCProperty($cx, $obj, $name, $namelen, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_LookupPropertyById($cx, $obj, $9, $vp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_LookupPropertyWithFlagsById($cx, $obj, $id, $flags, $objp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $prop = __stackBase__;
    var $1 = __ZNK8JSObject8isNativeEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $objp;
    var $6 = $prop;
    var $7 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($3, $4, $id, $flags, $5, $6);
    var $12 = $7 & 1;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $id, $objp, $prop);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    if (($12 | 0) == 0) {
      var $20 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$objp >> 2];
    var $16 = HEAP32[$prop >> 2];
    var $17 = __ZL12LookupResultP9JSContextP8JSObjectS2_iP10JSPropertyPN2JS5ValueE($cx, $15, $id, $16, $vp);
    var $20 = ($17 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $20;
    STACKTOP = __stackBase__;
    return $20 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($this, $cx, $id, $objp, $propp) {
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 4 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 46;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $objp, $propp);
  return $6;
}

function _JS_LookupPropertyWithFlags($cx, $obj, $name, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_LookupPropertyWithFlagsById($cx, $obj, $5, $flags, $obj2, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HasPropertyById($cx, $obj, $id, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $obj2 = __stackBase__;
  var $prop = __stackBase__ + 4;
  var $1 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 5, $obj2, $prop);
  var $4 = (HEAP32[$prop >> 2] | 0) != 0 & 1;
  HEAP32[$foundp >> 2] = $4;
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_HasElement($cx, $obj, $index, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = _JS_HasPropertyById($cx, $obj, $3, $foundp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HasProperty($cx, $obj, $name, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_HasPropertyById($cx, $obj, $5, $foundp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HasUCProperty($cx, $obj, $name, $namelen, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_HasPropertyById($cx, $obj, $9, $foundp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AlreadyHasOwnPropertyById($cx, $obj, $id, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZNK8JSObject8isNativeEv($obj);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 5, $obj2, $prop);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = (HEAP32[$obj2 >> 2] | 0) == ($obj | 0) & 1;
    HEAP32[$foundp >> 2] = $8;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $10 = __ZN8JSObject14nativeContainsEP9JSContexti($obj, $cx, $id);
    HEAP32[$foundp >> 2] = $10 & 1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AlreadyHasOwnElement($cx, $obj, $index, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = _JS_AlreadyHasOwnPropertyById($cx, $obj, $3, $foundp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AlreadyHasOwnProperty($cx, $obj, $name, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_AlreadyHasOwnPropertyById($cx, $obj, $5, $foundp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_AlreadyHasOwnUCProperty($cx, $obj, $name, $namelen, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_AlreadyHasOwnPropertyById($cx, $obj, $9, $foundp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefinePropertyById($cx, $obj, $id, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $value = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $value | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id, $value, $getter, $setter, $attrs, 0, 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id, $value, $getter, $setter, $attrs, $flags, $tinyid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 9);
    if (($flags | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8isNativeEv($obj);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $cx;
    var $6 = $obj;
    var $7 = $getter;
    var $8 = $setter;
    var $9 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5, $6, $id, $value, $7, $8, $attrs, $flags, $tinyid, 0);
    var $_0 = ($9 | 0) != 0 & 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $id, $value, $getter, $setter, $attrs);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineElement($cx, $obj, $index, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $id = __stackBase__ + 8;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $value | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$id >> 2];
    var $8 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $7, $value, $getter, $setter, $attrs, 0, 0);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineProperty($cx, $obj, $name, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $value = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $value | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $value, $getter, $setter, $attrs, 0, 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $value, $getter, $setter, $attrs, $flags, $tinyid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($attrs & 128 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $name;
    var $5 = _INT_TO_JSID250($4);
    var $id_0 = $5;
    var $_01 = $attrs & -129;
    __label__ = 5;
    break;
   case 3:
    var $8 = _strlen($name);
    var $9 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $8, 0, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom244($9);
    var $id_0 = $12;
    var $_01 = $attrs;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $id_0;
    if (($_01 & 8 | 0) == 0) {
      var $_2 = $_01;
      var $_02 = $setter;
      var $_14 = $getter;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $_01 & -9;
    if (($getter | 0) == 0) {
      var $_1 = $17;
      var $_03 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $getter;
    var $21 = $obj;
    var $22 = __ZNK8JSObject9getGlobalEv($21);
    var $23 = $22;
    var $24 = _JS_NewFunction($cx, $20, 0, 0, $23, 0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_1 = $17 | 16;
    var $_03 = $24;
    __label__ = 9;
    break;
   case 9:
    var $_03;
    var $_1;
    if (($setter | 0) == 0) {
      var $_2 = $_1;
      var $_02 = 0;
      var $_14 = $_03;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = $setter;
    var $33 = $obj;
    var $34 = __ZNK8JSObject9getGlobalEv($33);
    var $35 = $34;
    var $36 = _JS_NewFunction($cx, $32, 1, 0, $35, 0);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_2 = $_1 | 32;
    var $_02 = $36;
    var $_14 = $_03;
    __label__ = 12;
    break;
   case 12:
    var $_14;
    var $_02;
    var $_2;
    var $42 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $id_0, $value, $_14, $_02, $_2, $flags, $tinyid);
    var $_0 = $42;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji["X"] = 1;

function _JS_DefinePropertyWithTinyId($cx, $obj, $name, $tinyid, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $value = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $value | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $tinyid << 24 >> 24;
  var $6 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $value, $getter, $setter, $attrs, 64, $5);
  STACKTOP = __stackBase__;
  return $6;
}

function _JS_DefineUCProperty($cx, $obj, $name, $namelen, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $value = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $value | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZL16DefineUCPropertyP9JSContextP8JSObjectPKtjRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $namelen, $value, $getter, $setter, $attrs, 0, 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZL16DefineUCPropertyP9JSContextP8JSObjectPKtjRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $namelen, $value, $getter, $setter, $attrs, $flags, $tinyid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = __ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji($cx, $obj, $9, $value, $getter, $setter, $attrs, $flags, $tinyid);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineUCPropertyWithTinyId($cx, $obj, $name, $namelen, $tinyid, $0, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $value = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $value | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $tinyid << 24 >> 24;
  var $6 = __ZL16DefineUCPropertyP9JSContextP8JSObjectPKtjRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $namelen, $value, $getter, $setter, $attrs, 64, $5);
  STACKTOP = __stackBase__;
  return $6;
}

function _JS_DefineOwnProperty($cx, $obj, $id, $0, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $descriptor = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $descriptor | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = $obj;
  var $7 = __Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi($5, $6, $id, $descriptor, $bp);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_DefineObject($cx, $obj, $name, $jsclasp, $proto, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL8ValueifyEP7JSClass($jsclasp);
    var $clasp_0 = ($2 | 0) == 0 ? __ZN2js11ObjectClassE : $2;
    var $4 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp_0, $proto, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    __ZN8JSObject19syncSpecialEqualityEv($7);
    __ZN2JSL11ObjectValueER8JSObject239($1, $4);
    var $8 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $name, $1, 0, 0, $attrs, 0, 0);
    var $_ = ($8 | 0) == 0 ? 0 : $4;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb264($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function _JS_DefineConstDoubles($cx, $obj, $cds) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $ok_0 = 1;
    var $_0 = $cds;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $ok_0;
    var $2 = $_0 + 8 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $_0 | 0;
    var $7 = (tempDoubleI32[0] = HEAP32[$6 >> 2], tempDoubleI32[1] = HEAP32[$6 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11DoubleValueEd($value, $7);
    var $9 = HEAPU8[$_0 + 12 | 0];
    var $attrs_0 = $9 << 24 >> 24 == 0 ? 6 : $9 & 255;
    var $12 = HEAP32[$2 >> 2];
    var $13 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $12, $value, 0, 0, $attrs_0, 0, 0);
    if (($13 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ok_0 = $13;
    var $_0 = $_0 + 16 | 0;
    __label__ = 2;
    break;
   case 5:
    var $ok_1;
    STACKTOP = __stackBase__;
    return $ok_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function _JS_DefineProperties($cx, $obj, $ps) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $ok_0 = 1;
    var $_0 = $ps;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $ok_0;
    var $4 = HEAPU32[$_0 >> 2];
    if (($4 | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL14UndefinedValueEv245($1);
    var $8 = HEAP32[$_0 + 8 >> 2];
    var $10 = HEAP32[$_0 + 12 >> 2];
    var $13 = HEAPU8[$_0 + 5 | 0] & 255;
    var $16 = HEAP8[$_0 + 4 | 0] << 24 >> 24;
    var $17 = __ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji($cx, $obj, $4, $1, $8, $10, $13, 64, $16);
    if (($17 | 0) == 0) {
      var $ok_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $ok_0 = $17;
    var $_0 = $_0 + 16 | 0;
    __label__ = 2;
    break;
   case 5:
    var $ok_1;
    STACKTOP = __stackBase__;
    return $ok_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyDescriptorById($cx, $obj, $id, $flags, $desc) {
  var $1 = __ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor($cx, $obj, $id, $flags, $desc);
  return $1;
}

function __ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor($cx, $obj, $id, $flags, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $rf = __stackBase__ + 8;
    var $1 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, $flags, $obj2, $prop);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$prop >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$desc >> 2] = 0;
    HEAP32[$desc + 4 >> 2] = 0;
    HEAP32[$desc + 8 >> 2] = 0;
    HEAP32[$desc + 12 >> 2] = 0;
    var $11 = $desc + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($11);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $13 = HEAPU32[$obj2 >> 2];
    HEAP32[$desc >> 2] = $13;
    var $15 = __ZNK8JSObject8isNativeEv($13);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $17 = $4;
    var $18 = __ZNK2js5Shape10attributesEv($17);
    var $19 = $18 & 255;
    HEAP32[$desc + 4 >> 2] = $19;
    var $21 = __ZNK2js5Shape8isMethodEv($17);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$desc + 8 >> 2] = 10;
    HEAP32[$desc + 12 >> 2] = 12;
    var $25 = $desc + 16 | 0;
    var $26 = __ZNK2js5Shape12methodObjectEv($17);
    __ZN2JS5Value9setObjectER8JSObject($25, $26);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 7:
    var $28 = __ZNK2js5Shape6getterEv($17);
    HEAP32[$desc + 8 >> 2] = $28;
    var $30 = __ZNK2js5Shape6setterEv($17);
    HEAP32[$desc + 12 >> 2] = $30;
    var $33 = HEAP32[$17 + 24 >> 2];
    var $34 = __ZNK8JSObject12containsSlotEj($13, $33);
    var $35 = $desc + 16 | 0;
    if ($34) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $37 = __ZNK8JSObject13nativeGetSlotEj($13, $33);
    var $38 = $37 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $35 | 0;
    HEAP32[$40 >> 2] = $39$0;
    HEAP32[$40 + 4 >> 2] = $39$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 9:
    __ZN2JS5Value12setUndefinedEv($35);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 10:
    var $43 = __ZNK8JSObject7isProxyEv($13);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, $flags);
    var $45 = HEAP32[$obj2 >> 2];
    var $46 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $45, $id, 0, $desc);
    var $47 = $46 & 1;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    var $_0 = $47;
    __label__ = 14;
    break;
   case 12:
    var $49 = $desc + 4 | 0;
    var $50 = __ZN8JSObject13getAttributesEP9JSContextiPj($13, $cx, $id, $49);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$desc + 8 >> 2] = 0;
    HEAP32[$desc + 12 >> 2] = 0;
    var $55 = $desc + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($55);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor["X"] = 1;

function _JS_GetPropertyAttrsGetterAndSetterById($cx, $obj, $id, $attrsp, $foundp, $getterp, $setterp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor($cx, $obj, $id, 1, $desc);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$desc + 4 >> 2];
    HEAP32[$attrsp >> 2] = $5;
    var $9 = (HEAP32[$desc >> 2] | 0) != 0 & 1;
    HEAP32[$foundp >> 2] = $9;
    if (($getterp | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$desc + 8 >> 2];
    HEAP32[$getterp >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    if (($setterp | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$desc + 12 >> 2];
    HEAP32[$setterp >> 2] = $18;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyAttributes($cx, $obj, $name, $attrsp, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_GetPropertyAttrsGetterAndSetterById($cx, $obj, $5, $attrsp, $foundp, 0, 0);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetUCPropertyAttributes($cx, $obj, $name, $namelen, $attrsp, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_GetPropertyAttrsGetterAndSetterById($cx, $obj, $9, $attrsp, $foundp, 0, 0);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyAttrsGetterAndSetter($cx, $obj, $name, $attrsp, $foundp, $getterp, $setterp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_GetPropertyAttrsGetterAndSetterById($cx, $obj, $5, $attrsp, $foundp, $getterp, $setterp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetUCPropertyAttrsGetterAndSetter($cx, $obj, $name, $namelen, $attrsp, $foundp, $getterp, $setterp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_GetPropertyAttrsGetterAndSetterById($cx, $obj, $9, $attrsp, $foundp, $getterp, $setterp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetOwnPropertyDescriptor($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE($1, $2, $id, $vp);
  return $3 & 1;
}

function _JS_SetPropertyAttributes($cx, $obj, $name, $attrs, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = __ZL25SetPropertyAttributesByIdP9JSContextP8JSObjectijPi($cx, $obj, $5, $attrs, $foundp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _INT_TO_JSID250($i) {
  return $i << 1 | 1;
}

function __ZNK2js5Shape10enumerableEv($this) {
  return (HEAP8[$this + 28 | 0] & 1) << 24 >> 24 != 0;
}

function _JS_SetRuntimeSecurityCallbacks($rt, $callbacks) {
  var $1 = $rt + 144244 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $callbacks;
  return $2;
}

function _JS_GetRuntimeSecurityCallbacks($rt) {
  return HEAP32[$rt + 144244 >> 2];
}

function _JS_SetContextSecurityCallbacks($cx, $callbacks) {
  var $1 = $cx + 204 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $callbacks;
  return $2;
}

function _JS_GetSecurityCallbacks($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 204 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 144244 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals($this, $p) {
  HEAP32[$this + 209940 >> 2] = $p;
  return;
}

function __ZN8JSScript6upvarsEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 17 | 0] & 255) | 0;
}

function __ZNK2js11UpvarCookie5levelEv($this) {
  return HEAPU32[$this >> 2] >>> 16 & 65535;
}

function __ZNK2js5Shape5Range5frontEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js5Shape5Range8popFrontEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 32 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function _JS_GetFunctionObject($fun) {
  return $fun | 0;
}

function _JS_GetFunctionId($fun) {
  return HEAP32[$fun + 72 >> 2] | 0;
}

function _JS_GetFunctionFlags($fun) {
  return HEAPU16[$fun + 58 >> 1] & 65535;
}

function _JS_GetFunctionArity($fun) {
  return HEAP16[$fun + 56 >> 1];
}

function __ZL25SetPropertyAttributesByIdP9JSContextP8JSObjectijPi($cx, $obj, $id, $attrs, $foundp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $attrs;
    var $2 = __ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, 1, $obj2, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$obj2 >> 2] | 0) == ($obj | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$foundp >> 2] = 0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 5:
    var $12 = __ZNK8JSObject8isNativeEv($obj);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = HEAP32[$1 >> 2];
    var $15 = $cx;
    var $16 = $obj;
    var $17 = $5;
    var $18 = __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($15, $16, $17, $14);
    var $22 = $18;
    __label__ = 8;
    break;
   case 7:
    var $20 = __ZN8JSObject13setAttributesEP9JSContextiPj($obj, $cx, $id, $1);
    var $22 = $20;
    __label__ = 8;
    break;
   case 8:
    var $22;
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$foundp >> 2] = 1;
    var $_0 = $22;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetUCPropertyAttributes($cx, $obj, $name, $namelen, $attrs, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = __ZL25SetPropertyAttributesByIdP9JSContextP8JSObjectijPi($cx, $obj, $9, $attrs, $foundp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyById($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
  var $1 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $id, $vp);
  __ZN18JSAutoResolveFlagsD1Ev($rf);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_GetPropertyByIdDefault($cx, $obj, $id, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $def = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $def | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = $obj;
  var $7 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($5, $6, $id, $def, $vp);
  STACKTOP = __stackBase__;
  return $7;
}

function _JS_GetElement($cx, $obj, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = _JS_GetPropertyById($cx, $obj, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetProperty($cx, $obj, $name, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_GetPropertyById($cx, $obj, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyDefault($cx, $obj, $name, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_02 = $0 | 0;
    var $st$2$0 = $_02 | 0;
    var $tmp$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_02 + 4 | 0;
    var $tmp$1 = HEAP32[$st$2$1 >> 2];
    var $3 = _strlen($name);
    var $4 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $3, 0, 0);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom244($4);
    var $_03 = $2 | 0;
    var $st$2$0 = $_03 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp$0;
    var $st$2$1 = $_03 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp$1;
    var $8 = _JS_GetPropertyByIdDefault($cx, $obj, $7, $2, $vp);
    var $11 = ($8 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    STACKTOP = __stackBase__;
    return $11 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetUCProperty($cx, $obj, $name, $namelen, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_GetPropertyById($cx, $obj, $9, $vp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetMethodById($cx, $obj, $id, $objp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $obj;
    var $3 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($1, $2, $id, 0, $vp);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($objp | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetMethod($cx, $obj, $name, $objp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_GetMethodById($cx, $obj, $5, $objp, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetPropertyById($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 3);
  var $1 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $id, $vp, 0);
  __ZN18JSAutoResolveFlagsD1Ev($rf);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject6getOpsEv($this);
    if ((HEAP32[$1 + 52 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this;
    var $7 = $cx;
    var $8 = __ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi($6, $7, $id, $vp, $strict);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = $cx;
    var $11 = $this;
    var $12 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($10, $11, $id, 0, $vp, $strict);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetElement($cx, $obj, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _INT_TO_JSID250($index);
    var $4 = _JS_SetPropertyById($cx, $obj, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetProperty($cx, $obj, $name, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_SetPropertyById($cx, $obj, $5, $vp);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetUCProperty($cx, $obj, $name, $namelen, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_SetPropertyById($cx, $obj, $9, $vp);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DeletePropertyById2($cx, $obj, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $rf = __stackBase__;
  __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 1);
  var $1 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $id, $rval, 0);
  __ZN18JSAutoResolveFlagsD1Ev($rf);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_DeleteElement2($cx, $obj, $index, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = _JS_DeletePropertyById2($cx, $obj, $3, $rval);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DeleteProperty2($cx, $obj, $name, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = _JS_DeletePropertyById2($cx, $obj, $5, $rval);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DeleteUCProperty2($cx, $obj, $name, $namelen, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $13 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = _JS_DeletePropertyById2($cx, $obj, $9, $rval);
    var $13 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $13;
    return $13 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DeletePropertyById($cx, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $junk = __stackBase__;
  var $1 = _JS_DeletePropertyById2($cx, $obj, $id, $junk);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_DeleteElement($cx, $obj, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $junk = __stackBase__;
  var $1 = _JS_DeleteElement2($cx, $obj, $index, $junk);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_DeleteProperty($cx, $obj, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $junk = __stackBase__;
  var $1 = _JS_DeleteProperty2($cx, $obj, $name, $junk);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_ClearScope($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject6getOpsEv($obj);
    var $3 = HEAP32[$1 + 128 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    FUNCTION_TABLE[$3]($cx, $obj);
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZNK8JSObject8isNativeEv($obj);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $obj;
    var $11 = __Z14js_ClearNativeP9JSContextP8JSObject($9, $10);
    __label__ = 5;
    break;
   case 5:
    var $13 = __ZNK8JSObject8isGlobalEv($obj);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = $obj;
    var $16 = __ZN8JSObject8asGlobalEv($15);
    var $17 = $cx;
    __ZN2js12GlobalObject5clearEP9JSContext($16, $17);
    __label__ = 7;
    break;
   case 7:
    var $19 = $cx;
    __Z13js_InitRandomP9JSContext($19);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject8isGlobalEv($this) {
  var $1 = __ZNK8JSObject8getClassEv($this);
  return (HEAP32[$1 + 4 >> 2] & 262144 | 0) != 0;
}

function _JS_Enumerate($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $ida = __stackBase__ + 60;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $1 = $cx;
    var $2 = $obj;
    var $3 = $props;
    var $4 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($1, $2, 8, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $ida;
    var $7 = __ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray($1, $3, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = HEAP32[$ida >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($props);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18prop_iter_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $5 = __ZNK2JS5Value7toInt32Ev($4);
    if (($5 | 0) > -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $1;
    _JS_DestroyIdArray(undef, $8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15prop_iter_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $5 = __ZNK2JS5Value7toInt32Ev($4);
    if (($5 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $1;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $8, undef);
    __label__ = 5;
    break;
   case 4:
    var $11 = HEAP32[$1 >> 2];
    var $13 = $1 + 4 | 0;
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $11, $13, undef);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewPropertyIterator($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 16;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_($cx, __ZL15prop_iter_class, 0, $obj);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8isNativeEv($obj);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject12lastPropertyEv($obj);
    var $index_1 = -1;
    var $pdata_1 = $7;
    __label__ = 7;
    break;
   case 4:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $2);
    var $10 = _JS_Enumerate($cx, $obj);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 8;
    break;
   case 6:
    var $13 = $10;
    var $15 = HEAP32[$10 >> 2];
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $index_1 = $15;
    var $pdata_1 = $13;
    __label__ = 7;
    break;
   case 7:
    var $pdata_1;
    var $index_1;
    __ZN8JSObject10setPrivateEPv($2, $pdata_1);
    __ZN2JSL10Int32ValueEi251($1, $index_1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
    var $_1 = $2;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZN2js16AutoObjectRooterD1Ev($this) {
  __ZN2js16AutoObjectRooterD2Ev($this);
  return;
}

function __ZN2JSL10Int32ValueEi251($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _JS_NextProperty($cx, $iterobj, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject7getSlotEj($iterobj, 0);
    var $3 = __ZNK2JS5Value7toInt32Ev($2);
    var $4 = ($3 | 0) < 0;
    var $5 = __ZNK8JSObject10getPrivateEv($iterobj);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $shape_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $shape_0;
    var $9 = __ZNK2js5Shape8previousEv($shape_0);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js5Shape10enumerableEv($shape_0);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $shape_0 = $9;
      __label__ = 3;
      break;
    }
   case 5:
    HEAP32[$idp >> 2] = 2;
    __label__ = 10;
    break;
   case 6:
    var $15 = $9;
    __ZN8JSObject10setPrivateEPv($iterobj, $15);
    var $17 = HEAP32[$shape_0 + 12 >> 2];
    HEAP32[$idp >> 2] = $17;
    __label__ = 10;
    break;
   case 7:
    if (($3 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$idp >> 2] = 2;
    __label__ = 10;
    break;
   case 9:
    var $22 = $3 - 1 | 0;
    var $26 = HEAP32[$5 + 4 + ($22 << 2) >> 2];
    HEAP32[$idp >> 2] = $26;
    __ZN2JSL10Int32ValueEi251($1, $22);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($iterobj, 0, $1);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetReservedSlot($cx, $obj, $index, $vp) {
  var $1 = $obj;
  var $2 = __Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
  return 1;
}

function _JS_SetReservedSlot($cx, $obj, $index, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = $obj;
  var $7 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($5, $6, $index, $v);
  var $8 = $7 & 1;
  STACKTOP = __stackBase__;
  return $8;
}

function _JS_NewArrayObject($cx, $length, $vector) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $3 = ($vector | 0) != 0 ? $length : 0;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $vector, $3);
  var $4 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $length, $vector, 0);
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_IsArrayObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7isArrayEv($obj);
    if ($1) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject9isWrapperEv($obj);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZN8JSObject6unwrapEPj($obj, 0);
    var $6 = __ZNK8JSObject7isArrayEv($5);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject7isArrayEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject11isSlowArrayEv($this);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject12isDenseArrayEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetArrayLength($cx, $obj, $lengthp) {
  var $1 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $lengthp);
  return $1;
}

function _JS_SetArrayLength($cx, $obj, $length) {
  var $1 = $length >>> 0;
  var $2 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $1);
  return $2;
}

function _JS_CheckAccess($cx, $obj, $id, $mode, $vp, $attrsp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($1, $2, $id, $mode, $vp, $attrsp);
  return $3;
}

function _JS_SetTrustedPrincipals($rt, $prin) {
  __ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals($rt, $prin);
  return;
}

function _JS_NewFunction($cx, $native, $nargs, $flags, $parent, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($name | 0) == 0) {
      var $atom_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _strlen($name);
    var $4 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $atom_0 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $atom_0;
    var $7 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, $native, $nargs, $flags, $parent, $atom_0);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewFunctionById($cx, $native, $nargs, $flags, $parent, $id) {
  var $1 = __ZL12JSID_TO_ATOMi254($id);
  var $2 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, $native, $nargs, $flags, $parent, $1);
  return $2;
}

function __ZL12JSID_TO_ATOMi254($id) {
  var $1 = _JSID_TO_STRING243($id);
  return $1;
}

function _JS_CloneFunctionObject($cx, $funobj, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $r = __stackBase__ + 8;
    var $v1 = __stackBase__ + 16;
    if (($parent | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $parent;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext5hasfpEv($cx);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK9JSContext2fpEv($cx);
    var $6 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $5);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_1 = $6;
      __label__ = 5;
      break;
    }
   case 4:
    var $_1 = HEAP32[$cx + 132 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_1;
    var $11 = __ZNK8JSObject10isFunctionEv($funobj);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject239($v, $funobj);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 7:
    var $14 = __ZNK8JSObject18getFunctionPrivateEv($funobj);
    var $15 = __ZNK10JSFunction13isInterpretedEv($14);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $14, $_1, 0);
    var $_0 = $17;
    __label__ = 23;
    break;
   case 9:
    var $19 = __ZNK10JSFunction6scriptEv($14);
    if ((HEAP8[$19 + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _JS_ReportErrorNumber($cx, 2, 0, 142, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 11:
    var $26 = __ZNK10JSFunction13isFlatClosureEv($14);
    if ($26) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $28 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $14, $_1, 0);
    var $_0 = $28;
    __label__ = 23;
    break;
   case 13:
    var $30 = __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $14, $_1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $33 = __ZNK10JSFunction6scriptEv($14);
    var $34 = __ZN8JSScript6upvarsEv($33);
    var $36 = HEAP32[$34 + 4 >> 2];
    var $38 = $33 + 64 | 0;
    var $39 = __ZNK2js8Bindings9lastUpvarEv($38);
    var $40 = $39;
    __ZN2js5Shape5RangeC1EPKS0_($r, $40);
    var $41 = $34 | 0;
    var $42 = $v1 | 0;
    var $i_0 = $36;
    __label__ = 15;
    break;
   case 15:
    var $i_0;
    var $44 = $i_0 - 1 | 0;
    if (($i_0 | 0) == 0) {
      var $_0 = $30;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = HEAP32[$41 >> 2] + ($44 << 2) | 0;
    var $49 = __ZNK2js11UpvarCookie5levelEv($48);
    var $skip_0 = $49 & 65535;
    var $obj_0 = $_1;
    __label__ = 17;
    break;
   case 17:
    var $obj_0;
    var $skip_0;
    var $52 = $skip_0 - 1 | 0;
    if (($52 | 0) > 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    if (($obj_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    _JS_ReportErrorNumber($cx, 2, 0, 142, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 20:
    var $58 = __ZNK8JSObject9getParentEv($obj_0);
    var $skip_0 = $52;
    var $obj_0 = $58;
    __label__ = 17;
    break;
   case 21:
    var $60 = __ZNK2js5Shape5Range5frontEv($r);
    var $62 = HEAP32[$60 + 12 >> 2];
    var $63 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj_0, $cx, $62, $v1);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $66 = __ZNK8JSObject20getFlatClosureUpvarsEv($30);
    var $67$0 = HEAP32[$42 >> 2];
    var $67$1 = HEAP32[$42 + 4 >> 2];
    var $68 = $66 + ($44 << 3) | 0;
    HEAP32[$68 >> 2] = $67$0;
    HEAP32[$68 + 4 >> 2] = $67$1;
    __ZN2js5Shape5Range8popFrontEv($r);
    var $i_0 = $44;
    __label__ = 15;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_CloneFunctionObject["X"] = 1;

function __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $fun, $parent, $ignoreSingletonClone) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $cx;
    var $2 = $parent;
    var $3 = $proto;
    var $4 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, $2, 2, $3, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($ignoreSingletonClone) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = $fun | 0;
    var $9 = __ZNK8JSObject16hasSingletonTypeEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject9setParentEPS_($8, $parent);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[$proto >> 2];
    var $13 = __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $parent, $12);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction13isFlatClosureEv($this) {
  var $1 = __ZNK10JSFunction4kindEv($this);
  return $1 << 16 >> 16 == -32768;
}

function __ZN2js5Shape5RangeC1EPKS0_($this, $shape) {
  __ZN2js5Shape5RangeC2EPKS0_($this, $shape);
  return;
}

function __ZNK8JSObject20getFlatClosureUpvarsEv($this) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($this, 0);
  var $2 = __ZNK2JS5Value9toPrivateEv($1);
  return $2;
}

function _JS_ObjectIsFunction($cx, $obj) {
  var $1 = __ZNK8JSObject10isFunctionEv($obj);
  return $1 & 1;
}

function _JS_ObjectIsCallable($cx, $obj) {
  var $1 = __ZN8JSObject10isCallableEv($obj);
  return $1 & 1;
}

function __ZNK14AutoVersionAPI7versionEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function _JS_SetErrorReporter($cx, $er) {
  var $1 = $cx + 180 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $er;
  return $2;
}

function __ZN2js11TokenStream15isUnexpectedEOFEv($this) {
  return (HEAP32[$this + 144 >> 2] & 16 | 0) != 0;
}

function _JS_GetObjectFromScript($script) {
  return HEAP32[$script + 84 >> 2];
}

function __ZNK16JSAutoByteString3ptrEv($this) {
  return HEAP32[$this >> 2];
}

function _JS_SetOperationCallback($cx, $callback) {
  var $1 = $cx + 184 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $callback;
  return $2;
}

function _JS_GetOperationCallback($cx) {
  return HEAP32[$cx + 184 >> 2];
}

function _JS_DefineFunctions($cx, $obj, $fs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $priv = __stackBase__;
    var $1 = $cx;
    var $ctor_0 = 0;
    var $_01 = $fs;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $ctor_0;
    var $4 = HEAPU32[$_01 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU16[$_01 + 10 >> 1] & 65535;
    var $10 = _strlen($4);
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $4, $10, 0, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($9 & 8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_pre = __ZL12ATOM_TO_JSIDP6JSAtom244($11);
    var $ctor_2 = $ctor_0;
    var $flags_0 = $9;
    var $_pre_phi = $_pre;
    var $_pre_phi2 = $_01 + 8 | 0;
    __label__ = 10;
    break;
   case 6:
    if (($ctor_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $ctor_1 = $ctor_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = _JS_GetConstructor($cx, $obj);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $ctor_1 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $ctor_1;
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom244($11);
    var $23 = $_01 + 8 | 0;
    var $26 = (HEAPU16[$23 >> 1] & 65535) + 1 | 0;
    var $27 = $9 & 57335;
    var $28 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $ctor_1, $22, 48, $26, $27);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $9 & 65527;
    __ZN2JSL12PrivateValueEPv257($priv, $_01);
    var $33 = $28;
    var $34 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($1, $33, 0, $priv);
    if ($34) {
      var $ctor_2 = $ctor_1;
      var $flags_0 = $31;
      var $_pre_phi = $22;
      var $_pre_phi2 = $23;
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $_pre_phi2;
    var $_pre_phi;
    var $flags_0;
    var $ctor_2;
    var $37 = HEAP32[$_01 + 4 >> 2];
    var $39 = HEAPU16[$_pre_phi2 >> 1] & 65535;
    var $40 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $_pre_phi, $37, $39, $flags_0);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $ctor_0 = $ctor_2;
    var $_01 = $_01 + 12 | 0;
    __label__ = 2;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DefineFunctions["X"] = 1;

function __ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value8toObjectEv($vp);
    __ZNK8JSObject15getReservedSlotEj($1, $2, 0);
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $vp, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2JS5Value9toPrivateEv($1);
    var $8 = $vp + 8 | 0;
    var $10 = $vp + 16 | 0;
    var $11 = $argc << 3;
    _llvm_memmove_p0i8_p0i8_i32($8, $10, $11, 1, 0);
    var $12 = $argc - 1 | 0;
    var $14 = $vp + ($argc + 1 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($14);
    var $17 = HEAP32[$6 + 4 >> 2];
    var $18 = FUNCTION_TABLE[$17]($cx, $12, $vp);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv257($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function _JS_DefineFunction($cx, $obj, $name, $call, $nargs, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($name);
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $1, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom244($2);
    var $6 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $5, $call, $nargs, $attrs);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineUCFunction($cx, $obj, $name, $namelen, $call, $nargs, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($namelen | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $namelen;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($name);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $name, $5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($6);
    var $10 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $9, $call, $nargs, $attrs);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DefineFunctionById($cx, $obj, $id, $call, $nargs, $attrs) {
  var $1 = __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $id, $call, $nargs, $attrs);
  return $1;
}

function _JS_CompileUCScriptForPrincipalsVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $avi = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($avi, $cx, $version);
  var $1 = __ZNK14AutoVersionAPI7versionEv($avi);
  var $2 = __ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $1);
  __ZN14AutoVersionAPID1Ev($avi);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($this, $cx, $newVersion) {
  __ZN14AutoVersionAPIC2EP9JSContext9JSVersion($this, $cx, $newVersion);
  return;
}

function __ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $1 = __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx);
  var $2 = $1 | 1073872896;
  var $3 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, $principals, $2, $chars, $length, $filename, $lineno, $version, 0, 0);
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN14AutoVersionAPID1Ev($this) {
  __ZN14AutoVersionAPID2Ev($this);
  return;
}

function _JS_CompileUCScriptForPrincipals($cx, $obj, $principals, $chars, $length, $filename, $lineno) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $1);
  return $2;
}

function _JS_CompileUCScript($cx, $obj, $chars, $length, $filename, $lineno) {
  var $1 = _JS_CompileUCScriptForPrincipals($cx, $obj, 0, $chars, $length, $filename, $lineno);
  return $1;
}

function _JS_CompileScriptForPrincipalsVersion($cx, $obj, $principals, $bytes, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $ava = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($ava, $cx, $version);
  var $1 = _JS_CompileScriptForPrincipals($cx, $obj, $principals, $bytes, $length, $filename, $lineno);
  __ZN14AutoVersionAPID1Ev($ava);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_CompileScriptForPrincipals($cx, $obj, $principals, $bytes, $length, $filename, $lineno) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = $cx;
    var $3 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($2, $bytes, $1, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$1 >> 2];
    var $7 = _JS_CompileUCScriptForPrincipals($cx, $obj, $principals, $3, $6, $filename, $lineno);
    var $8 = $3;
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CompileScript($cx, $obj, $bytes, $length, $filename, $lineno) {
  var $1 = _JS_CompileScriptForPrincipals($cx, $obj, 0, $bytes, $length, $filename, $lineno);
  return $1;
}

function _JS_BufferIsCompilableUnit($cx, $bytes_are_utf8, $obj, $bytes, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 996;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $parser = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $length;
    var $3 = $cx;
    if (($bytes_are_utf8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($3, $bytes, $1, 1);
    var $chars_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($3, $bytes, $1, 0);
    var $chars_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $chars_0;
    if (($chars_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = _JS_SaveExceptionState($cx);
    var $12 = $parser;
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($12, $cx, 0, 0, 1);
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZNK9JSContext11findVersionEv($cx);
    var $15 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($12, $chars_0, $13, 0, 1, $14);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $result_1 = 1;
      __label__ = 10;
      break;
    }
   case 6:
    var $17 = _JS_SetErrorReporter($cx, 0);
    var $18 = __ZN2js6Parser5parseEP8JSObject($12, $obj);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $result_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $parser + 40 | 0;
    var $22 = __ZN2js11TokenStream15isUnexpectedEOFEv($21);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      var $result_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $result_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $result_0;
    var $25 = _JS_SetErrorReporter($cx, $17);
    var $result_1 = $result_0;
    __label__ = 10;
    break;
   case 10:
    var $result_1;
    __ZN2js6ParserD2Ev($12);
    __ZN9JSContext5free_EPv(undef, $chars_0);
    _JS_RestoreExceptionState($cx, $11);
    var $_0 = $result_1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SaveExceptionState($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($cx, 16);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1 + 8 | 0;
    var $6 = $5;
    var $7 = _JS_GetPendingException($cx, $6);
    HEAP32[$1 >> 2] = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $5;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = _JSVAL_IS_GCTHING($12$0, $12$1);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $6, STRING_TABLE.__str29222 | 0);
    __label__ = 5;
    break;
   case 5:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_RestoreExceptionState($cx, $state) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($state | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$state >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $state + 8 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $1 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    _JS_SetPendingException($cx, $1);
    __label__ = 5;
    break;
   case 4:
    _JS_ClearPendingException($cx);
    __label__ = 5;
    break;
   case 5:
    _JS_DropExceptionState($cx, $state);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CompileFile($cx, $obj, $filename) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lfc = __stackBase__;
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    if (($filename | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _strcmp($filename, STRING_TABLE.__str243176 | 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $fp_0 = HEAP32[_stdin >> 2];
    __label__ = 6;
    break;
   case 4:
    var $8 = _fopen($filename, STRING_TABLE.__str25218 | 0);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $fp_0 = $8;
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 60, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $filename, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str26219 | 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $fp_0;
    var $12 = __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, 0, $filename, $fp_0);
    if (($fp_0 | 0) == (HEAP32[_stdin >> 2] | 0)) {
      var $_0 = $12;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = _fclose($fp_0);
    var $_0 = $12;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN18AutoLastFrameCheckD1Ev($lfc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18AutoLastFrameCheckC1EP9JSContext($this, $cx) {
  __ZN18AutoLastFrameCheckC2EP9JSContext($this, $cx);
  return;
}

function __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, $principals, $filename, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $st = __stackBase__;
    var $1 = _fileno($fp);
    var $2 = _fstat($1, $st);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    var $6 = HEAPU32[$st + 28 >> 2];
    if ((HEAP32[_stdin >> 2] | 0) == ($fp | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $len_0 = ($6 | 0) == 0 ? 8 : $6;
    var $hitEOF_0 = 0;
    var $i_0 = 0;
    var $len_1 = $len_0;
    var $buf_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $buf_0;
    var $len_1;
    var $i_0;
    var $hitEOF_0;
    if ($hitEOF_0 << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_3 = $i_0;
      var $buf_1 = $buf_0;
      __label__ = 14;
      break;
    }
   case 5:
    var $13 = $len_1 << 1;
    var $14 = $buf_0;
    var $16 = __ZN9JSContext8realloc_EPvj($cx, $14, $len_1 << 2);
    var $17 = $16;
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_1 = $i_0;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv(undef, $14);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    var $i_1;
    if ($i_1 >>> 0 < $13 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $hitEOF_0 = 0;
      var $i_0 = $i_1;
      var $len_1 = $13;
      var $buf_0 = $17;
      __label__ = 4;
      break;
    }
   case 8:
    var $22 = _getc_unlocked($fp);
    if (($22 | 0) == -1) {
      var $hitEOF_0 = 1;
      var $i_0 = $i_1;
      var $len_1 = $13;
      var $buf_0 = $17;
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP16[$17 + ($i_1 << 1) >> 1] = $22 & 65535 & 255;
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 7;
    break;
   case 10:
    var $30 = $6 << 1;
    var $31 = __ZN9JSContext7malloc_Ej($cx, $30);
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $i_2 = 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $i_2;
    if ($i_2 >>> 0 < $6 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $i_3 = $i_2;
      var $buf_1 = $32;
      __label__ = 14;
      break;
    }
   case 12:
    var $36 = _getc_unlocked($fp);
    if (($36 | 0) == -1) {
      var $i_3 = $i_2;
      var $buf_1 = $32;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP16[$32 + ($i_2 << 1) >> 1] = $36 & 65535 & 255;
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $buf_1;
    var $i_3;
    var $43 = __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx);
    var $44 = $43 | 1073872896;
    var $45 = __ZNK9JSContext11findVersionEv($cx);
    var $46 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, $principals, $44, $buf_1, $i_3, $filename, 1, $45, 0, 0);
    __ZN9JSContext5free_EPv(undef, $buf_1);
    var $_0 = $46;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE["X"] = 1;

function __ZN18AutoLastFrameCheckD1Ev($this) {
  __ZN18AutoLastFrameCheckD2Ev($this);
  return;
}

function _JS_CompileFileHandleForPrincipals($cx, $obj, $filename, $file, $principals) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $1 = __ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE($cx, $obj, $principals, $filename, $file);
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_CompileFileHandleForPrincipalsVersion($cx, $obj, $filename, $file, $principals, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $ava = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($ava, $cx, $version);
  var $1 = _JS_CompileFileHandleForPrincipals($cx, $obj, $filename, $file, $principals);
  __ZN14AutoVersionAPID1Ev($ava);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_CompileFileHandle($cx, $obj, $filename, $file) {
  var $1 = _JS_CompileFileHandleForPrincipals($cx, $obj, $filename, $file, 0);
  return $1;
}

function _JS_CompileUCFunctionForPrincipalsVersion($cx, $obj, $principals, $name, $nargs, $argnames, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $avi = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($avi, $cx, $version);
  var $1 = __ZNK14AutoVersionAPI7versionEv($avi);
  var $2 = __ZL36CompileUCFunctionForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKcjPS6_PKtjS6_j9JSVersion($cx, $obj, $principals, $name, $nargs, $argnames, $chars, $length, $filename, $lineno, $1);
  __ZN14AutoVersionAPID1Ev($avi);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL36CompileUCFunctionForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKcjPS6_PKtjS6_j9JSVersion($cx, $obj, $principals, $name, $nargs, $argnames, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lfc = __stackBase__;
    var $bindings = __stackBase__ + 4;
    var $dummy = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    if (($name | 0) == 0) {
      var $funAtom_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strlen($name);
    var $5 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $4, 0, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $funAtom_0 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $funAtom_0;
    __ZN2js8BindingsC1EP9JSContext($bindings, undef);
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $nargs >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = HEAP32[$argnames + ($i_0 << 2) >> 2];
    var $13 = _strlen($12);
    var $14 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $12, $13, 0, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($bindings, $cx, $14, $dummy);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $21 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 0, 0, 16384, $obj, $funAtom_0);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion($cx, $21, $principals, $bindings, $chars, $length, $filename, $lineno, $version);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    if (($obj | 0) == 0 | ($funAtom_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZL12ATOM_TO_JSIDP6JSAtom244($funAtom_0);
    var $30 = $21 | 0;
    __ZN2JSL11ObjectValueER8JSObject239($1, $30);
    var $31 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $29, $1, 0, 0, 1);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = $21;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    __ZN18AutoLastFrameCheckD1Ev($lfc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CompileUCFunctionForPrincipals($cx, $obj, $principals, $name, $nargs, $argnames, $chars, $length, $filename, $lineno) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __ZL36CompileUCFunctionForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKcjPS6_PKtjS6_j9JSVersion($cx, $obj, $principals, $name, $nargs, $argnames, $chars, $length, $filename, $lineno, $1);
  return $2;
}

function _JS_CompileUCFunction($cx, $obj, $name, $nargs, $argnames, $chars, $length, $filename, $lineno) {
  var $1 = _JS_CompileUCFunctionForPrincipals($cx, $obj, 0, $name, $nargs, $argnames, $chars, $length, $filename, $lineno);
  return $1;
}

function _JS_CompileFunctionForPrincipals($cx, $obj, $principals, $name, $nargs, $argnames, $bytes, $length, $filename, $lineno) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = $cx;
    var $3 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($2, $bytes, $1, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$1 >> 2];
    var $7 = _JS_CompileUCFunctionForPrincipals($cx, $obj, $principals, $name, $nargs, $argnames, $3, $6, $filename, $lineno);
    var $8 = $3;
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CompileFunction($cx, $obj, $name, $nargs, $argnames, $bytes, $length, $filename, $lineno) {
  var $1 = _JS_CompileFunctionForPrincipals($cx, $obj, 0, $name, $nargs, $argnames, $bytes, $length, $filename, $lineno);
  return $1;
}

function _JS_DecompileScript($cx, $script, $name, $indent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $indent & -32769;
    var $3 = $indent >>> 15 & 1 ^ 1;
    var $4 = _js_NewPrinter($cx, undef, 0, $1, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = _js_DecompileScript($4, $script);
    if (($7 | 0) == 0) {
      var $str_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _js_GetPrinterOutput($4);
    var $str_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $str_0;
    _js_DestroyPrinter($4);
    var $_0 = $str_0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DecompileFunction($cx, $fun, $indent) {
  var $1 = $indent & -32769;
  var $3 = $indent >>> 15 & 1 ^ 1;
  var $4 = _js_DecompileToString($cx, undef, $fun, $1, $3, 0, 0, 50);
  return $4;
}

function _JS_DecompileFunctionBody($cx, $fun, $indent) {
  var $1 = $indent & -32769;
  var $3 = $indent >>> 15 & 1 ^ 1;
  var $4 = _js_DecompileToString($cx, undef, $fun, $1, $3, 0, 0, 52);
  return $4;
}

function _JS_ExecuteScript($cx, $obj, $script, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lfc = __stackBase__;
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $1 = __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $script, $obj, $rval);
  var $2 = $1 & 1;
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_ExecuteScriptVersion($cx, $obj, $script, $rval, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $ava = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($ava, $cx, $version);
  var $1 = _JS_ExecuteScript($cx, $obj, $script, $rval);
  __ZN14AutoVersionAPID1Ev($ava);
  STACKTOP = __stackBase__;
  return $1;
}

function __Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $rval, $compileVersion) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lfc = __stackBase__;
    var $flags_0 = ($rval | 0) == 0 ? 1073766400 : 1073750016;
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    var $2 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $obj, 0, $principals, $flags_0, $chars, $length, $filename, $lineno, $compileVersion, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $2, $obj, $rval);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN18AutoLastFrameCheckD1Ev($lfc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EvaluateUCScriptForPrincipalsVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $rval, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $avi = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($avi, $cx, $version);
  var $1 = __ZNK14AutoVersionAPI7versionEv($avi);
  var $2 = __Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $rval, $1);
  var $3 = $2 & 1;
  __ZN14AutoVersionAPID1Ev($avi);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_EvaluateUCScriptForPrincipals($cx, $obj, $principals, $chars, $length, $filename, $lineno, $rval) {
  var $1 = __ZNK9JSContext11findVersionEv($cx);
  var $2 = __Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion($cx, $obj, $principals, $chars, $length, $filename, $lineno, $rval, $1);
  return $2 & 1;
}

function _JS_EvaluateUCScript($cx, $obj, $chars, $length, $filename, $lineno, $rval) {
  var $1 = _JS_EvaluateUCScriptForPrincipals($cx, $obj, 0, $chars, $length, $filename, $lineno, $rval);
  return $1;
}

function _JS_EvaluateScriptForPrincipals($cx, $obj, $principals, $bytes, $nbytes, $filename, $lineno, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    HEAP32[$length >> 2] = $nbytes;
    var $1 = $cx;
    var $2 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($1, $bytes, $length, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$length >> 2];
    var $6 = _JS_EvaluateUCScriptForPrincipals($cx, $obj, $principals, $2, $5, $filename, $lineno, $rval);
    var $7 = $2;
    __ZN9JSContext5free_EPv(undef, $7);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EvaluateScriptForPrincipalsVersion($cx, $obj, $principals, $bytes, $nbytes, $filename, $lineno, $rval, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $avi = __stackBase__;
  __ZN14AutoVersionAPIC1EP9JSContext9JSVersion($avi, $cx, $version);
  var $1 = _JS_EvaluateScriptForPrincipals($cx, $obj, $principals, $bytes, $nbytes, $filename, $lineno, $rval);
  __ZN14AutoVersionAPID1Ev($avi);
  STACKTOP = __stackBase__;
  return $1;
}

function _JS_EvaluateScript($cx, $obj, $bytes, $nbytes, $filename, $lineno, $rval) {
  var $1 = _JS_EvaluateScriptForPrincipals($cx, $obj, 0, $bytes, $nbytes, $filename, $lineno, $rval);
  return $1;
}

function _JS_CallFunction($cx, $obj, $fun, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var $1 = __stackBase__;
  var $lfc = __stackBase__ + 8;
  var $2 = __stackBase__ + 12;
  var $3 = __stackBase__ + 20;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $argv, $argc);
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  __ZN2JSL17ObjectOrNullValueEP8JSObject258($2, $obj);
  var $4 = $fun | 0;
  __ZN2JSL11ObjectValueER8JSObject239($3, $4);
  var $5 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $2, $3, $argc, $argv, $rval);
  var $6 = $5 & 1;
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject258($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function _JS_CallFunctionName($cx, $obj, $name, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lfc = __stackBase__ + 8;
    var $v = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $argv, $argc);
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    var $3 = _strlen($name);
    var $4 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $15 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom244($4);
    var $8 = $cx;
    var $9 = $obj;
    var $10 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($8, $9, $7, 2, $v);
    if (($10 | 0) == 0) {
      var $15 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL17ObjectOrNullValueEP8JSObject258($2, $obj);
    var $13 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $2, $v, $argc, $argv, $rval);
    var $15 = $13;
    __label__ = 4;
    break;
   case 4:
    var $15;
    var $16 = $15 & 1;
    __ZN18AutoLastFrameCheckD1Ev($lfc);
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_CallFunctionValue($cx, $obj, $0, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $fval = __stackBase__;
  var $2 = __stackBase__ + 8;
  var $lfc = __stackBase__ + 16;
  var $3 = __stackBase__ + 20;
  var $4 = $0 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $fval | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($2, $argv, $argc);
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  __ZN2JSL17ObjectOrNullValueEP8JSObject258($3, $obj);
  var $7 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $3, $fval, $argc, $argv, $rval);
  var $8 = $7 & 1;
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $8;
}

function __ZN2JS4CallEP9JSContextNS_5ValueES2_jPS2_S3_($cx, $0, $1, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $thisv = __stackBase__;
  var $fval = __stackBase__ + 8;
  var $3 = __stackBase__ + 16;
  var $lfc = __stackBase__ + 24;
  var $4 = $0 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $thisv | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  var $7 = $1 | 0;
  var $8$0 = HEAP32[$7 >> 2];
  var $8$1 = HEAP32[$7 + 4 >> 2];
  var $9 = $fval | 0;
  HEAP32[$9 >> 2] = $8$0;
  HEAP32[$9 + 4 >> 2] = $8$1;
  __ZN12JSValueArrayC1EPN2JS5ValueEj($3, $argv, $argc);
  __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
  var $10 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $thisv, $fval, $argc, $argv, $rval);
  __ZN18AutoLastFrameCheckD1Ev($lfc);
  STACKTOP = __stackBase__;
  return $10;
}

function _JS_New($cx, $ctor, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lfc = __stackBase__ + 8;
    var $args = __stackBase__ + 12;
    var $bytes = __stackBase__ + 36;
    __ZN12JSValueArrayC1EPN2JS5ValueEj($1, $argv, $argc);
    __ZN18AutoLastFrameCheckC1EP9JSContext($lfc, $cx);
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $3 = $cx + 60 | 0;
    var $4 = $cx;
    var $5 = $args;
    var $6 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($3, $4, $argc, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $8 = $args | 0;
    var $9 = __ZNK2js12CallReceiver7calleevEv($8);
    __ZN2JS5Value9setObjectER8JSObject($9, $ctor);
    var $10 = __ZNK2js12CallReceiver5thisvEv($8);
    __ZN2JS5Value7setNullEv($10);
    var $11 = $args | 0;
    var $12 = __ZNK2js8CallArgs4argvEv($11);
    var $13 = $12;
    var $14 = $argv;
    var $15 = $argc << 3;
    _memcpy($13, $14, $15, 1);
    var $16 = __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $18 = __ZNK2js12CallReceiver4rvalEv($8);
    var $19 = __ZNK2JS5Value8isObjectEv($18);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $21 = __ZNK2js12CallReceiver4rvalEv($8);
    var $22 = $cx;
    var $23 = $bytes;
    var $24 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($22, $21, $23, 0);
    if (($24 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($cx, 2, 0, 28, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    __label__ = 6;
    break;
   case 6:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $30 = __ZNK2JS5Value8toObjectEv($18);
    var $_0 = $30;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    __ZN18AutoLastFrameCheckD1Ev($lfc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15InvokeArgsGuardC1Ev($this) {
  __ZN2js15InvokeArgsGuardC2Ev($this);
  return;
}

function __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args) {
  var $1 = $args | 0;
  __ZN2js12CallArgsList9setActiveEv($1);
  var $2 = $args;
  var $3 = __ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_($2);
  var $4 = __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $3);
  __ZN2js12CallArgsList11setInactiveEv($1);
  return $4;
}

function __ZN2js15InvokeArgsGuardD1Ev($this) {
  __ZN2js15InvokeArgsGuardD2Ev($this);
  return;
}

function _JS_TriggerOperationCallback($cx) {
  __ZN2js24TriggerOperationCallbackEP9JSContext($cx);
  return;
}

function _JS_TriggerAllOperationCallbacks($rt) {
  __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt);
  return;
}

function _JS_IsRunning($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext7maybefpEv($cx);
    var $fp_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $fp_0;
    var $3 = ($fp_0 | 0) != 0;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js10StackFrame4prevEv($fp_0);
    var $fp_0 = $7;
    __label__ = 2;
    break;
   case 5:
    return $3 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext7maybefpEv($this) {
  var $2 = $this + 60 | 0;
  var $3 = __ZNK2js12ContextStack7maybefpEv($2);
  return $3;
}

function _JS_SaveFrameChain($cx) {
  var $2 = $cx + 60 | 0;
  var $3 = __ZN2js12ContextStack14saveFrameChainEv($2);
  return $3 & 1;
}

function _JS_SetCStringsAreUTF8() {
  HEAP32[_js_CStringsAreUTF8 >> 2] = 1;
  return;
}

function _JS_CStringsAreUTF8() {
  return HEAP32[_js_CStringsAreUTF8 >> 2];
}

function __ZNK8JSString6isAtomEv($this) {
  return (HEAP32[$this >> 2] & 7 | 0) == 0;
}

function __ZN27JSAutoStructuredCloneBuffer5stealEPPyPjS2_($this, $datap, $nbytesp, $versionp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$datap >> 2] = $2;
    var $3 = $this + 4 | 0;
    var $4 = HEAP32[$3 >> 2];
    HEAP32[$nbytesp >> 2] = $4;
    var $_pre = $this + 8 | 0;
    if (($versionp | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$_pre >> 2];
    HEAP32[$versionp >> 2] = $7;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = 0;
    HEAP32[$3 >> 2] = 0;
    HEAP32[$_pre >> 2] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27JSAutoStructuredCloneBuffer4swapERS_($this, $other) {
  var $1 = $other | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $other + 4 | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = $other + 8 | 0;
  var $6 = HEAP32[$5 >> 2];
  var $7 = $this | 0;
  var $8 = HEAP32[$7 >> 2];
  HEAP32[$1 >> 2] = $8;
  var $9 = $this + 4 | 0;
  var $10 = HEAP32[$9 >> 2];
  HEAP32[$3 >> 2] = $10;
  var $11 = $this + 8 | 0;
  var $12 = HEAP32[$11 >> 2];
  HEAP32[$5 >> 2] = $12;
  HEAP32[$7 >> 2] = $2;
  HEAP32[$9 >> 2] = $4;
  HEAP32[$11 >> 2] = $6;
  return;
}

function _JS_SetStructuredCloneCallbacks($rt, $callbacks) {
  HEAP32[$rt + 144248 >> 2] = $callbacks;
  return;
}

function __ZN23JSStructuredCloneReader5inputEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN23JSStructuredCloneWriter6outputEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK8JSObject6isDateEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js9DateClassE | 0);
}

function _JS_RestoreFrameChain($cx) {
  var $2 = $cx + 60 | 0;
  __ZN2js12ContextStack17restoreFrameChainEv($2);
  return;
}

function _JS_NewStringCopyN($cx, $s, $n) {
  var $1 = $cx;
  var $2 = __Z17js_NewStringCopyNP9JSContextPKcj($1, $s, $n);
  return $2 | 0;
}

function _JS_NewStringCopyZ($cx, $s) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $n = __stackBase__;
    if (($s | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 3:
    var $9 = _strlen($s);
    HEAP32[$n >> 2] = $9;
    var $10 = $cx;
    var $11 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($10, $s, $n, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$n >> 2];
    var $15 = __Z12js_NewStringP9JSContextPtj($10, $11, $14);
    var $16 = $15 | 0;
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $16;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $11;
    __ZN9JSContext5free_EPv(undef, $19);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_StringHasBeenInterned($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6isAtomEv($str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSString6asAtomEv($str);
    var $4 = __Z14AtomIsInternedP9JSContextP6JSAtom($cx, $3);
    var $_0 = $4 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_InternJSString($cx, $str) {
  var $1 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $str, 1);
  return $1 | 0;
}

function _JS_InternString($cx, $s) {
  var $1 = _strlen($s);
  var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $s, $1, 1, 0);
  return $2 | 0;
}

function _JS_NewUCString($cx, $chars, $length) {
  var $1 = $cx;
  var $2 = __Z12js_NewStringP9JSContextPtj($1, $chars, $length);
  return $2 | 0;
}

function _JS_NewUCStringCopyN($cx, $s, $n) {
  var $1 = $cx;
  var $2 = __Z17js_NewStringCopyNP9JSContextPKtj($1, $s, $n);
  return $2 | 0;
}

function _JS_NewUCStringCopyZ($cx, $s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($s | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = $cx;
    var $10 = __Z17js_NewStringCopyZP9JSContextPKt($9, $s);
    var $_0 = $10 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_InternUCStringN($cx, $s, $length) {
  var $1 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $s, $length, 1);
  return $1 | 0;
}

function _JS_InternUCString($cx, $s) {
  var $1 = __Z9js_strlenPKt($s);
  var $2 = _JS_InternUCStringN($cx, $s, $1);
  return $2;
}

function _JS_GetStringLength($str) {
  var $1 = __ZNK8JSString6lengthEv($str);
  return $1;
}

function _JS_GetStringCharsZ($cx, $str) {
  var $1 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
  return $1;
}

function _JS_GetStringCharsZAndLength($cx, $str, $plength) {
  var $1 = __ZNK8JSString6lengthEv($str);
  HEAP32[$plength >> 2] = $1;
  var $2 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
  return $2;
}

function _JS_GetStringCharsAndLength($cx, $str, $plength) {
  var $1 = __ZNK8JSString6lengthEv($str);
  HEAP32[$plength >> 2] = $1;
  var $2 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
  return $2;
}

function _JS_GetInternedStringChars($str) {
  var $1 = __ZNK8JSString6asAtomEv($str);
  var $2 = $1 | 0;
  var $3 = __ZNK14JSLinearString5charsEv($2);
  return $3;
}

function _JS_GetInternedStringCharsAndLength($str, $plength) {
  var $1 = __ZNK8JSString6asAtomEv($str);
  var $2 = $1 | 0;
  var $3 = __ZNK8JSString6lengthEv($2);
  HEAP32[$plength >> 2] = $3;
  var $4 = $1 | 0;
  var $5 = __ZNK14JSLinearString5charsEv($4);
  return $5;
}

function _JS_FlattenString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $str;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFlatStringChars($str) {
  var $1 = $str | 0;
  var $2 = __ZNK14JSLinearString5charsEv($1);
  return $2;
}

function _JS_CompareStrings($cx, $str1, $str2, $result) {
  var $1 = $cx;
  var $2 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($1, $str1, $str2, $result);
  return $2 & 1;
}

function _JS_StringEqualsAscii($cx, $str, $asciiBytes, $match) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($1, $asciiBytes);
    HEAP32[$match >> 2] = $4 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FlatStringEqualsAscii($str, $asciiBytes) {
  var $1 = $str | 0;
  var $2 = __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($1, $asciiBytes);
  return $2 & 1;
}

function _JS_PutEscapedFlatString($buffer, $size, $str, $quote) {
  var $1 = $str | 0;
  var $2 = $quote << 24 >> 24;
  var $3 = __ZN2js16PutEscapedStringEPcjP14JSLinearStringj($buffer, $size, $1, $2);
  return $3;
}

function __ZN2js16PutEscapedStringEPcjP14JSLinearStringj($buffer, $size, $str, $quote) {
  var $1 = __ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj($buffer, $size, 0, $str, $quote);
  return $1;
}

function _JS_PutEscapedString($cx, $buffer, $size, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $quote << 24 >> 24;
    var $5 = __ZN2js16PutEscapedStringEPcjP14JSLinearStringj($buffer, $size, $1, $4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FileEscapedString($fp, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($str, 0);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $quote << 24 >> 24;
    var $5 = __ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj($fp, $1, $4);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj($fp, $str, $quote) {
  var $1 = __ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj(0, 0, $fp, $str, $quote);
  return ($1 | 0) != -1;
}

function _JS_NewGrowableString($cx, $chars, $length) {
  var $1 = $cx;
  var $2 = __Z12js_NewStringP9JSContextPtj($1, $chars, $length);
  return $2 | 0;
}

function _JS_NewDependentString($cx, $str, $start, $length) {
  var $1 = $cx;
  var $2 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($1, $str, $start, $length);
  return $2 | 0;
}

function _JS_ConcatStrings($cx, $left, $right) {
  var $1 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $left, $right);
  return $1;
}

function _JS_UndependString($cx, $str) {
  var $1 = __ZN8JSString9getCharsZEP9JSContext($str, $cx);
  return $1;
}

function _JS_MakeStringImmutable($cx, $str) {
  var $1 = __ZN8JSString11ensureFixedEP9JSContext($str, $cx);
  return ($1 | 0) != 0 & 1;
}

function _JS_EncodeCharacters($cx, $src, $srclen, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $cx;
    if (($dst | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($2, $src, $srclen);
    if (($4 | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$dstlenp >> 2] = 0;
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    HEAP32[$dstlenp >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $9 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($2, $src, $srclen, $dst, $dstlenp);
    var $_0 = $9 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DecodeBytes($cx, $src, $srclen, $dst, $dstlenp) {
  var $1 = $cx;
  var $2 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($1, $src, $srclen, $dst, $dstlenp);
  return $2 & 1;
}

function _JS_DecodeUTF8($cx, $src, $srclen, $dst, $dstlenp) {
  var $1 = $cx;
  var $2 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($1, $src, $srclen, $dst, $dstlenp, 0);
  return $2 & 1;
}

function _JS_EncodeString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($str);
    var $5 = $cx;
    var $6 = __ZN2js13DeflateStringEP9JSContextPKtj($5, $1, $4);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetStringEncodingLength($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($str);
    var $5 = $cx;
    var $6 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($5, $1, $4);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EncodeStringToBuffer($str, $buffer, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $writtenLength = __stackBase__;
    HEAP32[$writtenLength >> 2] = $length;
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, 0);
    if (($1 | 0) == 0) {
      var $_0 = -1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($str);
    var $5 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj(0, $1, $4, $buffer, $writtenLength);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = HEAP32[$writtenLength >> 2];
    __label__ = 7;
    break;
   case 4:
    var $9 = __ZNK8JSString6lengthEv($str);
    var $10 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj(0, $1, $9);
    if (($10 | 0) == -1) {
      var $_0 = -1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = HEAP32[$writtenLength >> 2];
    if (($13 | 0) == ($length | 0)) {
      var $_0 = $10;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $buffer + $13 | 0;
    var $17 = $length - $13 | 0;
    __ZN2jsL7PodZeroIcEEvPT_j($16, $17);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIcEEvPT_j($t, $nelem) {
  _memset($t, 0, $nelem, 1);
  return;
}

function _JS_Stringify($cx, $vp, $replacer, $0, $callback, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $2 = __stackBase__ + 80;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $_07 = $2 | 0;
    HEAP32[$_07 >> 2] = $tmp$0;
    HEAP32[$_07 + 4 >> 2] = $tmp$1;
    var $3 = $cx;
    var $4 = $replacer;
    var $5 = $sb;
    var $6 = __Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE($3, $vp, $4, $2, $5);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js12StringBuffer5emptyEv($sb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210016 >> 2];
    var $15 = $14 | 0;
    var $16 = __ZNK14JSLinearString5charsEv($15);
    var $17 = $14 | 0;
    var $18 = __ZNK8JSString6lengthEv($17);
    var $19 = FUNCTION_TABLE[$callback]($16, $18, $data);
    var $_0 = $19;
    __label__ = 5;
    break;
   case 4:
    var $21 = __ZN2js12StringBuffer5beginEv($sb);
    var $22 = __ZNK2js12StringBuffer6lengthEv($sb);
    var $23 = FUNCTION_TABLE[$callback]($21, $22, $data);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBufferC1EP9JSContext($this, $cx) {
  __ZN2js12StringBufferC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js12StringBuffer5emptyEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($1);
  return $2;
}

function __ZN2js12StringBuffer5beginEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($1);
  return $2;
}

function __ZNK2js12StringBuffer6lengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($1);
  return $2;
}

function __ZN2js12StringBufferD1Ev($this) {
  __ZN2js12StringBufferD2Ev($this);
  return;
}

function _JS_ParseJSON($cx, $chars, $len, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL9NullValueEv259($1);
  var $2 = $cx;
  var $3 = __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($2, $chars, $len, $1, $vp, 0);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2JSL9NullValueEv259($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function _JS_ParseJSONWithReviver($cx, $chars, $len, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $reviver = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $reviver | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $cx;
  var $6 = __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($5, $chars, $len, $reviver, $vp, 0);
  STACKTOP = __stackBase__;
  return $6;
}

function _JS_ReadStructuredClone($cx, $buf, $nbytes, $version, $vp, $optionalCallbacks, $closure) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($version >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 264, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    if (($optionalCallbacks | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $11 = $optionalCallbacks;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 144248 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $12 = __ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($cx, $buf, $nbytes, $vp, $11, $closure);
    var $_0 = $12 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_WriteStructuredClone($cx, $0, $bufp, $nbytesp, $optionalCallbacks, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $v | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    if (($optionalCallbacks | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144248 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $13 = __ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv($cx, $v, $bufp, $nbytesp, $12, $closure);
    var $14 = $13 & 1;
    STACKTOP = __stackBase__;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_StructuredClone($cx, $0, $vp, $optionalCallbacks, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $2 = __stackBase__ + 12;
    var $_02 = $0 | 0;
    var $st$3$0 = $_02 | 0;
    var $tmp$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_02 + 4 | 0;
    var $tmp$1 = HEAP32[$st$3$1 >> 2];
    if (($optionalCallbacks | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 144248 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    __ZN27JSAutoStructuredCloneBufferC1Ev($buf);
    var $_03 = $2 | 0;
    var $st$3$0 = $_03 | 0;
    HEAP32[$st$3$0 >> 2] = $tmp$0;
    var $st$3$1 = $_03 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $tmp$1;
    var $11 = __ZN27JSAutoStructuredCloneBuffer5writeEP9JSContextN2JS5ValueEPK26JSStructuredCloneCallbacksPv($buf, $cx, $2, $10, $closure);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $15 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK27JSAutoStructuredCloneBuffer4readEP9JSContextPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($buf, $cx, $vp, $10, $closure);
    var $15 = $13;
    __label__ = 5;
    break;
   case 5:
    var $15;
    var $16 = $15 & 1;
    __ZN27JSAutoStructuredCloneBufferD1Ev($buf);
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27JSAutoStructuredCloneBufferC1Ev($this) {
  __ZN27JSAutoStructuredCloneBufferC2Ev($this);
  return;
}

function __ZN27JSAutoStructuredCloneBuffer5writeEP9JSContextN2JS5ValueEPK26JSStructuredCloneCallbacksPv($this, $cx, $0, $optionalCallbacks, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_02 = $0 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    __ZN27JSAutoStructuredCloneBuffer5clearEv($this);
    var $_03 = $2 | 0;
    HEAP32[$_03 >> 2] = $tmp$0;
    HEAP32[$_03 + 4 >> 2] = $tmp$1;
    var $3 = $this | 0;
    var $4 = $this + 4 | 0;
    var $5 = _JS_WriteStructuredClone($cx, $2, $3, $4, $optionalCallbacks, $closure);
    var $6 = ($5 | 0) != 0;
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = 0;
    HEAP32[$4 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK27JSAutoStructuredCloneBuffer4readEP9JSContextPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($this, $cx, $vp, $optionalCallbacks, $closure) {
  var $2 = HEAP32[$this >> 2];
  var $4 = HEAP32[$this + 4 >> 2];
  var $6 = HEAP32[$this + 8 >> 2];
  var $7 = _JS_ReadStructuredClone($cx, $2, $4, $6, $vp, $optionalCallbacks, $closure);
  return ($7 | 0) != 0;
}

function __ZN27JSAutoStructuredCloneBufferD1Ev($this) {
  __ZN27JSAutoStructuredCloneBufferD2Ev($this);
  return;
}

function __ZN27JSAutoStructuredCloneBuffer5clearEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js10Foreground5free_EPv($5);
    HEAP32[$1 >> 2] = 0;
    HEAP32[$this + 4 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27JSAutoStructuredCloneBuffer5adoptEPyjj($this, $data, $nbytes, $version) {
  __ZN27JSAutoStructuredCloneBuffer5clearEv($this);
  HEAP32[$this >> 2] = $data;
  HEAP32[$this + 4 >> 2] = $nbytes;
  HEAP32[$this + 8 >> 2] = $version;
  return;
}

function __ZN27JSAutoStructuredCloneBuffer4copyEPKyjj($this, $srcData, $nbytes, $version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11OffTheBooks7malloc_Ej($nbytes);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $srcData;
    _memcpy($1, $5, $nbytes, 1);
    __ZN27JSAutoStructuredCloneBuffer5clearEv($this);
    HEAP32[$this >> 2] = $4;
    HEAP32[$this + 4 >> 2] = $nbytes;
    HEAP32[$this + 8 >> 2] = $version;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ReadUint32Pair($r, $p1, $p2) {
  var $1 = __ZN23JSStructuredCloneReader5inputEv($r);
  var $2 = __ZN2js7SCInput8readPairEPjS1_($1, $p1, $p2);
  return $2 & 1;
}

function _JS_ReadBytes($r, $p, $len) {
  var $1 = __ZN23JSStructuredCloneReader5inputEv($r);
  var $2 = __ZN2js7SCInput9readBytesEPvj($1, $p, $len);
  return $2 & 1;
}

function _JS_WriteUint32Pair($w, $tag, $data) {
  var $1 = __ZN23JSStructuredCloneWriter6outputEv($w);
  var $2 = __ZN2js8SCOutput9writePairEjj($1, $tag, $data);
  return $2 & 1;
}

function _JS_WriteBytes($w, $p, $len) {
  var $1 = __ZN23JSStructuredCloneWriter6outputEv($w);
  var $2 = __ZN2js8SCOutput10writeBytesEPKvj($1, $p, $len);
  return $2 & 1;
}

function _JS_ReportError($cx, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportError.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, 0, $format, $2);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ReportErrorNumberUC($cx, $errorCallback, $userRef, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorNumberUC.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, 0, $errorCallback, $userRef, $errorNumber, 0, $2);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ReportWarning($cx, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportWarning.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, 1, $format, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ReportErrorFlagsAndNumber($cx, $flags, $errorCallback, $userRef, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorFlagsAndNumber.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, $flags, $errorCallback, $userRef, $errorNumber, 1, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ReportErrorFlagsAndNumberUC($cx, $flags, $errorCallback, $userRef, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_ReportErrorFlagsAndNumberUC.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, $flags, $errorCallback, $userRef, $errorNumber, 0, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_ReportAllocationOverflow($cx) {
  __Z27js_ReportAllocationOverflowP9JSContext($cx);
  return;
}

function _JS_NewDateObject($cx, $year, $mon, $mday, $hour, $min, $sec) {
  var $1 = $cx;
  var $2 = __Z16js_NewDateObjectP9JSContextiiiiii($1, $year, $mon, $mday, $hour, $min, $sec);
  return $2;
}

function _JS_NewDateObjectMsec($cx, $msec) {
  var $1 = $cx;
  var $2 = __Z20js_NewDateObjectMsecP9JSContextd($1, $msec);
  return $2;
}

function _JS_ObjectIsDate($cx, $obj) {
  var $1 = __ZNK8JSObject6isDateEv($obj);
  return $1 & 1;
}

function _JS_NewRegExpObject($cx, $obj, $bytes, $length, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = $cx;
    var $3 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($2, $bytes, $1, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $obj;
    var $7 = __ZN8JSObject8asGlobalEv($6);
    var $8 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($7);
    var $9 = $8;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($cx, $9, $3, $10, $flags, 0);
    var $12 = $3;
    __ZN9JSContext5free_EPv(undef, $12);
    var $_0 = $11;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($cx, $res, $chars, $length, $flags, $ts) {
  var $1 = __ZNK2js13RegExpStatics8getFlagsEv($res);
  var $2 = $1 | $flags;
  var $3 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $chars, $length, $2, $ts);
  return $3;
}

function _JS_NewUCRegExpObject($cx, $obj, $chars, $length, $flags) {
  var $1 = $obj;
  var $2 = __ZN8JSObject8asGlobalEv($1);
  var $3 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($2);
  var $4 = $3;
  var $5 = __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($cx, $4, $chars, $length, $flags, 0);
  return $5;
}

function _JS_SetRegExpInput($cx, $obj, $input, $multiline) {
  var $1 = $obj;
  var $2 = __ZN8JSObject8asGlobalEv($1);
  var $3 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($2);
  var $4 = $3;
  var $5 = ($multiline | 0) != 0;
  __ZN2js13RegExpStatics5resetEP8JSStringb($4, $input, $5);
  return;
}

function __ZN2js13RegExpStatics5resetEP8JSStringb($this, $newInput, $newMultiline) {
  var $1 = $this;
  __ZN2js13RegExpStatics12aboutToWriteEv($1);
  __ZN2js13RegExpStatics5clearEv($1);
  HEAP32[$this + 96 >> 2] = $newInput;
  __ZN2js13RegExpStatics12setMultilineEb($this, $newMultiline);
  return;
}

function _JS_ClearRegExpStatics($cx, $obj) {
  var $1 = $obj;
  var $2 = __ZN8JSObject8asGlobalEv($1);
  var $3 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($2);
  __ZN2js13RegExpStatics5clearEv($3);
  return;
}

function _JS_ExecuteRegExp($cx, $obj, $reobj, $chars, $length, $indexp, $test, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6RegExp11extractFromEP8JSObject($reobj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __Z17js_NewStringCopyNP9JSContextPKtj($4, $chars, $length);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5 | 0;
    var $9 = $obj;
    var $10 = __ZN8JSObject8asGlobalEv($9);
    var $11 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($10);
    var $12 = $11;
    var $13 = ($test | 0) != 0;
    var $14 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($1, $cx, $12, $8, $indexp, $13, $rval);
    var $_0 = $14 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp11extractFromEP8JSObject($obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $input, $lastIndex, $test, $rval) {
  var $1 = __ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $input, $lastIndex, $test, $rval);
  return $1;
}

function _JS_NewRegExpObjectNoStatics($cx, $bytes, $length, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = $cx;
    var $3 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($2, $bytes, $1, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$1 >> 2];
    var $7 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $3, $6, $flags, 0);
    var $8 = $3;
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $chars, $length, $flags, $ts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $re = __stackBase__ + 4;
    var $1 = $cx;
    var $2 = __Z17js_NewStringCopyNP9JSContextPKtj($1, $chars, $length);
    var $3 = $2 | 0;
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $3);
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $cx, $3, $flags, $ts);
    var $6 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279($cx);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re);
    var $13 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($9, $cx, $12);
    if ($13) {
      var $_1 = $9;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv($re);
    __ZN2js6RegExp6decrefEP9JSContext($15, $cx);
    var $_1 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewUCRegExpObjectNoStatics($cx, $chars, $length, $flags) {
  var $1 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($cx, $chars, $length, $flags, 0);
  return $1;
}

function _JS_ExecuteRegExpNoStatics($cx, $obj, $chars, $length, $indexp, $test, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6RegExp11extractFromEP8JSObject($obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __Z17js_NewStringCopyNP9JSContextPKtj($4, $chars, $length);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5 | 0;
    var $9 = ($test | 0) != 0;
    var $10 = __ZN2js6RegExp16executeNoStaticsEP9JSContextP8JSStringPjbPN2JS5ValueE($1, $cx, $8, $indexp, $9, $rval);
    var $_0 = $10 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp16executeNoStaticsEP9JSContextP8JSStringPjbPN2JS5ValueE($this, $cx, $input, $lastIndex, $test, $rval) {
  var $1 = __ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, 0, $input, $lastIndex, $test, $rval);
  return $1;
}

function _JS_ObjectIsRegExp($cx, $obj) {
  var $1 = __ZNK8JSObject8isRegExpEv($obj);
  return $1 & 1;
}

function _JS_GetContextThread($cx) {
  return 0;
}

function _JS_SetContextThread($cx) {
  return 0;
}

function _JS_ClearContextThread($cx) {
  return 0;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK8JSObject8isRegExpEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js11RegExpClassE | 0);
}

function __ZNK2js6RegExp8getFlagsEv($this) {
  return $this + 16 | 0;
}

function __ZNK2js6RegExp9getSourceEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function _JS_SetLocaleCallbacks($cx, $callbacks) {
  HEAP32[$cx + 36 >> 2] = $callbacks;
  return;
}

function _JS_GetLocaleCallbacks($cx) {
  return HEAP32[$cx + 36 >> 2];
}

function __ZN2js2gcL15GetGCObjectKindEjb264($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($e) {
  return $e | 0;
}

function _JS_GetRegExpFlags($cx, $obj) {
  var $1 = __ZN2js6RegExp11extractFromEP8JSObject($obj);
  var $2 = __ZNK2js6RegExp8getFlagsEv($1);
  return HEAP32[$2 >> 2];
}

function _JS_GetRegExpSource($cx, $obj) {
  var $1 = __ZN2js6RegExp11extractFromEP8JSObject($obj);
  var $2 = __ZNK2js6RegExp9getSourceEv($1);
  return $2 | 0;
}

function _JS_IsExceptionPending($cx) {
  var $1 = __ZN9JSContext18isExceptionPendingEv($cx);
  return $1 & 1;
}

function _JS_GetPendingException($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext18isExceptionPendingEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext19getPendingExceptionEv($1, $cx);
    var $4 = $1 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $vp | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetPendingException($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $2 = __stackBase__;
  var $_03 = $0 | 0;
  var $tmp$0 = HEAP32[$_03 >> 2];
  var $tmp$1 = HEAP32[$_03 + 4 >> 2];
  var $_06 = $2 | 0;
  HEAP32[$_06 >> 2] = $tmp$0;
  HEAP32[$_06 + 4 >> 2] = $tmp$1;
  __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $2);
  STACKTOP = __stackBase__;
  return;
}

function _JS_ClearPendingException($cx) {
  __ZN9JSContext21clearPendingExceptionEv($cx);
  return;
}

function _JS_ReportPendingException($cx) {
  var $1 = $cx + 44 | 0;
  var $2 = HEAP8[$1];
  HEAP8[$1] = 1;
  var $3 = $cx;
  var $4 = __Z26js_ReportUncaughtExceptionP9JSContext($3);
  HEAP8[$1] = $2;
  return $4;
}

function _JSVAL_IS_GCTHING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_GCTHING_IMPL($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JS_DropExceptionState($cx, $state) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($state | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$state >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $state + 8 | 0;
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = _JSVAL_IS_GCTHING($9$0, $9$1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _JS_RemoveValueRoot($cx, $7);
    __label__ = 5;
    break;
   case 5:
    var $15 = $state;
    __ZN9JSContext5free_EPv(undef, $15);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ErrorFromException($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $2 = __stackBase__;
  var $_03 = $0 | 0;
  var $tmp$0 = HEAP32[$_03 >> 2];
  var $tmp$1 = HEAP32[$_03 + 4 >> 2];
  var $_06 = $2 | 0;
  HEAP32[$_06 >> 2] = $tmp$0;
  HEAP32[$_06 + 4 >> 2] = $tmp$1;
  var $3 = __Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE(undef, $2);
  var $4 = $3;
  STACKTOP = __stackBase__;
  return $4;
}

function _JS_ThrowReportedError($cx, $message, $reportp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_IsRunning($cx);
    if (($1 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $reportp;
    var $6 = __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($4, $message, $5, 0, 0);
    var $9 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ThrowStopIteration($cx) {
  var $1 = $cx;
  var $2 = __Z21js_ThrowStopIterationP9JSContext($1);
  return 0;
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $11 = __ZN2js5types15emptyTypeObjectE;
      var $10 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $cx, 0, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $11 = $8;
      var $10 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $10;
    var $11;
    var $12 = $cx;
    var $13 = __Z16js_NewGCFunctionP9JSContext($12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($parent | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $23 = $parent;
      __label__ = 9;
      break;
    }
   case 7:
    if (($10 | 0) == 0) {
      var $23 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZNK8JSObject9getParentEv($10);
    var $23 = $21;
    __label__ = 9;
    break;
   case 9:
    var $23;
    var $24 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($14, undef, $clasp, $11, $23, 0, $24);
    var $25 = __ZNK2js5Class8isNativeEv($clasp);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $14, $clasp, $11, $kind);
    if ($27) {
      var $_0 = $14;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN8JSObject21setSharedNonNativeMapEv($14);
    var $_0 = $14;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $11 = __ZN2js5types15emptyTypeObjectE;
      var $10 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $cx, 0, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $11 = $8;
      var $10 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $10;
    var $11;
    var $12 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($parent | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $parent;
      __label__ = 9;
      break;
    }
   case 7:
    if (($10 | 0) == 0) {
      var $21 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZNK8JSObject9getParentEv($10);
    var $21 = $19;
    __label__ = 9;
    break;
   case 9:
    var $21;
    var $22 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($12, undef, $clasp, $11, $21, 0, $22);
    var $23 = __ZNK2js5Class8isNativeEv($clasp);
    if ($23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $12, $clasp, $11, $kind);
    if ($25) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN8JSObject21setSharedNonNativeMapEv($12);
    var $_0 = $12;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_($cx, $clasp, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE($clasp_idx_val);
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = $clasp;
    var $6 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = __ZNK8JSObject8numSlotsEv($obj);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK8JSObject9getParentEv($proto);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, $clasp, $5, $12, 0, $13);
    var $14 = __ZNK2js5Class8isNativeEv($clasp);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $4 | 0;
    var $st$7$0 = $7 | 0;
    HEAP32[$st$7$0 >> 2] = $6$0;
    var $st$7$1 = $7 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $6$1;
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $4 + 8 | 0;
    var $st$17$0 = $10 | 0;
    HEAP32[$st$17$0 >> 2] = $9$0;
    var $st$17$1 = $10 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 24 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv($rhs);
  var $8 = $7 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function _js_free272($p) {
  _free($p);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($1);
  var $6 = $5 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $this | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  var $9 = __ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv($rhs);
  var $10 = $9 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $10);
  var $11 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($2);
  var $12 = $11 | 0;
  var $13$0 = HEAP32[$12 >> 2];
  var $13$1 = HEAP32[$12 + 4 >> 2];
  var $14 = $this + 8 | 0;
  HEAP32[$14 >> 2] = $13$0;
  HEAP32[$14 + 4 >> 2] = $13$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($this) {
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $l | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZN2js13WrapperHasher4hashEN2JS5ValueE($1);
  var $6 = $5 * -1640531527 | 0;
  var $7 = $6 - 2 | 0;
  var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($6);
  var $_ = $8 ? $6 : $7;
  var $9 = $_ & -2;
  STACKTOP = __stackBase__;
  return $9;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE($1);
  var $3 = __ZN2js13WrapperHasher5matchERKN2JS5ValueES4_($2, $l);
  return $3;
}

function __ZN2js13WrapperHasher5matchERKN2JS5ValueES4_($l, $k) {
  var $1 = __ZNK2JS5ValueeqERKS0_($l, $k);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function _JSVAL_IS_GCTHING_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967172 & 1;
}

function __ZNK2JS5Value9asRawBitsEv($this) {
  var $1 = $this | 0;
  return [ HEAP32[$1 >> 2], HEAP32[$1 + 4 >> 2] ];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($this, $rhs) {
  var $1 = $rhs | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = $rhs + 8 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $this + 8 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZNK2js6RegExp6stickyEv($this) {
  return (HEAP32[$this + 16 >> 2] & 8 | 0) != 0;
}

function _STRING_TO_JSVAL_IMPL277($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject($this, $cx, $array) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $array;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL278($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js13WrapperHasher4hashEN2JS5ValueE($0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $key = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $key | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = __ZNK2JS5Value9asRawBitsEv($key);
  var $8 = $5[1] ^ $5[0];
  STACKTOP = __stackBase__;
  return $8;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $t | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeENSB_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($1);
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev($1);
  __ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_realloc274($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($this, $cx, $res, $inputstr, $lastIndex, $test, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $aaa = __stackBase__;
    var $anchor = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $5 = HEAP32[$this + 12 >> 2];
    var $6 = $5 + 1 | 0;
    var $7 = $6 * 3 | 0;
    var $8 = $6 << 1;
    var $9 = __ZN2js6RegExp9initArenaEP9JSContext($cx);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 22;
      break;
    }
   case 2:
    var $11 = $cx + 104 | 0;
    __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($aaa, $11);
    var $12 = __ZN2js18AutoArenaAllocator5allocIiEEPT_j($aaa, $7);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = ($8 | 0) == 0;
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = ($5 << 3 | 4) + 4 | 0;
    _memset($13, -1, $18, 4);
    __label__ = 5;
    break;
   case 5:
    var $20 = __ZN8JSString12ensureLinearEP9JSContext($inputstr, $cx);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = $20 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $23);
    var $24 = __ZNK8JSString6lengthEv($23);
    var $25 = __ZNK14JSLinearString5charsEv($20);
    var $26 = __ZNK2js6RegExp6stickyEv($this);
    var $27 = HEAP32[$lastIndex >> 2];
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $inputOffset_0 = 0;
      var $chars_0 = $25;
      var $len_0 = $24;
      var $31 = $27;
      __label__ = 8;
      break;
    }
   case 7:
    var $inputOffset_0 = $27;
    var $chars_0 = $25 + ($27 << 1) | 0;
    var $len_0 = $24 - $27 | 0;
    var $31 = $27;
    __label__ = 8;
    break;
   case 8:
    var $31;
    var $len_0;
    var $chars_0;
    var $inputOffset_0;
    var $33 = HEAP32[$this >> 2];
    var $35 = __Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii($cx, $33, $chars_0, $len_0, $31 - $inputOffset_0 | 0, $12, $7);
    if (($35 | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JSL9NullValueEv259($1);
    var $38 = $1 | 0;
    var $st$2$0 = $38 | 0;
    var $39$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$2$1 >> 2];
    var $40 = $rval | 0;
    var $st$7$0 = $40 | 0;
    HEAP32[$st$7$0 >> 2] = $39$0;
    var $st$7$1 = $40 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $39$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 10:
    if (($35 | 0) < 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $44 = $cx;
    __ZN2js6RegExp15reportPCREErrorEP9JSContexti(undef, $44, $35);
    var $_1 = 0;
    __label__ = 21;
    break;
   case 12:
    if (($inputOffset_0 | 0) == 0 | $15) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = ($5 << 1) + 2 | 0;
    var $i_01 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_01;
    var $50 = $12 + ($i_01 << 2) | 0;
    var $51 = HEAP32[$50 >> 2];
    var $_ = ($51 | 0) < 0 ? -1 : $51 + $inputOffset_0 | 0;
    HEAP32[$50 >> 2] = $_;
    var $54 = $i_01 + 1 | 0;
    if (($54 | 0) == ($48 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $i_01 = $54;
      __label__ = 14;
      break;
    }
   case 15:
    if (($res | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = __ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij($res, $cx, $20, $12, $8);
    __label__ = 17;
    break;
   case 17:
    var $60 = HEAP32[$12 + 4 >> 2];
    HEAP32[$lastIndex >> 2] = $60;
    if ($test) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2JSL12BooleanValueEb275($2, 1);
    var $62 = $2 | 0;
    var $st$2$0 = $62 | 0;
    var $63$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $62 + 4 | 0;
    var $63$1 = HEAP32[$st$2$1 >> 2];
    var $64 = $rval | 0;
    var $st$7$0 = $64 | 0;
    HEAP32[$st$7$0 >> 2] = $63$0;
    var $st$7$1 = $64 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $63$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 19:
    var $66 = __ZN2js6RegExp12createResultEP9JSContextP8JSStringPij($cx, $23, $12, $8);
    if (($66 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JSL11ObjectValueER8JSObject239($3, $66);
    var $69 = $3 | 0;
    var $st$2$0 = $69 | 0;
    var $70$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $69 + 4 | 0;
    var $70$1 = HEAP32[$st$2$1 >> 2];
    var $71 = $rval | 0;
    var $st$7$0 = $71 | 0;
    HEAP32[$st$7$0 >> 2] = $70$0;
    var $st$7$1 = $71 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $70$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_1;
    __ZN2js18AutoArenaAllocatorD1Ev($aaa);
    var $_2 = $_1;
    __label__ = 22;
    break;
   case 22:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE["X"] = 1;

function __ZN2js6RegExp9initArenaEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 104 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 120 >> 2];
    var $9 = HEAP32[$cx + 128 >> 2];
    var $12 = $9 + 8 & ($9 ^ -1);
    var $13 = $7 + 12 | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $16 = HEAPU32[$7 + 8 >> 2];
    if ($12 >>> 0 > $16 >>> 0 | $14 >>> 0 > ($16 - $12 | 0) >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = _JS_ArenaAllocate($1, $12);
    var $_p_0 = $21;
    __label__ = 5;
    break;
   case 4:
    var $24 = $12 + $14 | 0;
    HEAP32[$13 >> 2] = $24;
    var $_p_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $_p_0;
    var $29 = _JS_Now();
    var $29$1 = $29[1];
    HEAP32[$28 >> 2] = $29[0];
    HEAP32[$28 + 4 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($this, $pool) {
  __ZN2js18AutoArenaAllocatorC2EP11JSArenaPool($this, $pool);
  return;
}

function __ZN2js18AutoArenaAllocator5allocIiEEPT_j($this, $elems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    var $4 = HEAP32[$2 + 16 >> 2];
    var $7 = HEAP32[$2 + 24 >> 2];
    var $10 = $7 + ($elems << 2) & ($7 ^ -1);
    var $11 = $4 + 12 | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $14 = HEAPU32[$4 + 8 >> 2];
    if ($10 >>> 0 > $14 >>> 0 | $12 >>> 0 > ($14 - $10 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $19 = _JS_ArenaAllocate($2, $10);
    var $_p_0 = $19;
    __label__ = 4;
    break;
   case 3:
    var $22 = $10 + $12 | 0;
    HEAP32[$11 >> 2] = $22;
    var $_p_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij($this, $cx, $input, $buf, $matchItemCount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    __ZN2js13RegExpStatics12aboutToWriteEv($1);
    HEAP32[$this + 96 >> 2] = $input | 0;
    var $4 = $this | 0;
    var $5 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj($4, $matchItemCount);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if (($matchItemCount | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $i_01;
    var $9 = HEAP32[$buf + ($i_01 << 2) >> 2];
    var $10 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($4, $i_01);
    HEAP32[$10 >> 2] = $9;
    var $11 = $i_01 + 1 | 0;
    if (($11 | 0) == ($matchItemCount | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $11;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP32[$this + 92 >> 2] = $input;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb275($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js6RegExp12createResultEP9JSContextP8JSStringPij($cx, $input, $buf, $matchItemCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __ZN2js17NewSlowEmptyArrayEP9JSContext($cx);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject($builder, $cx, $3);
    var $6 = $cx;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $matchItemCount >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = HEAPU32[$buf + ($i_0 << 2) >> 2];
    if (($11 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = HEAP32[$buf + (($i_0 | 1) << 2) >> 2] - $11 | 0;
    var $18 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($6, $input, $11, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = $18 | 0;
    var $22 = $i_0 >>> 1;
    __ZN2JSL11StringValueEP8JSString276($1, $21);
    var $23 = __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($builder, $22, $1);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $25 = $i_0 >>> 1;
    __ZN2JSL14UndefinedValueEv245($2);
    var $26 = __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($builder, $25, $2);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 2 | 0;
    __label__ = 3;
    break;
   case 9:
    var $30 = HEAP32[$buf >> 2];
    var $31 = __ZN2js18RegExpMatchBuilder8setIndexEi($builder, $30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $33 = __ZN2js18RegExpMatchBuilder8setInputEP8JSString($builder, $input);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = $3;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoArenaAllocatorD1Ev($this) {
  __ZN2js18AutoArenaAllocatorD2Ev($this);
  return;
}

function __ZN2js18AutoArenaAllocatorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$this >> 2];
    var $6 = HEAP32[$4 + 16 >> 2];
    if (($6 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2;
    var $12 = HEAP32[$6 + 4 >> 2];
    var $14 = $6 + 12 | 0;
    if (($10 - $12 | 0) >>> 0 > (HEAP32[$14 >> 2] - $12 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$4 + 24 >> 2];
    var $23 = $20 + $10 & ($20 ^ -1);
    HEAP32[$14 >> 2] = $23;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($4, $2);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject($this, $cx, $array) {
  __ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject($this, $cx, $array);
  return;
}

function __ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE($this, $index, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $9 = HEAP32[$this >> 2];
  var $10 = HEAP32[$this + 4 >> 2];
  var $11 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($9, $10, $index, $v, 10, 12, 1);
  var $12 = ($11 | 0) != 0;
  STACKTOP = __stackBase__;
  return $12;
}

function __ZN2JSL11StringValueEP8JSString276($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js18RegExpMatchBuilder8setIndexEi($this, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $8 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 210232 >> 2] | 0;
  __ZN2JSL10Int32ValueEi251($1, $index);
  var $9 = __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this, $8, $1);
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js18RegExpMatchBuilder8setInputEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $8 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 210236 >> 2] | 0;
  __ZN2JSL11StringValueEP8JSString276($1, $str);
  var $9 = __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this, $8, $1);
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE($this, $name, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $v = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $v | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $6 = HEAP32[$this >> 2];
  var $8 = HEAP32[$this + 4 >> 2];
  var $9 = __ZL12ATOM_TO_JSIDP6JSAtom244($name);
  var $10 = $6;
  var $11 = $8;
  var $12 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($10, $11, $9, $v, 10, 12, 1);
  var $13 = ($12 | 0) != 0;
  STACKTOP = __stackBase__;
  return $13;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $newLength - $2 | 0;
    var $6 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj($this, $5);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = $2 - $newLength | 0;
    __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj($this, $8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 8 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK7mozilla14AlignedStorageILj80EE4addrEv($this) {
  return $this;
}

function __ZN2js18AutoArenaAllocatorC2EP11JSArenaPool($this, $pool) {
  HEAP32[$this >> 2] = $pool;
  var $7 = HEAP32[HEAP32[$pool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZNK2js6RegExp6globalEv($this) {
  return (HEAP32[$this + 16 >> 2] & 2 | 0) != 0;
}

function __ZNK2js6RegExp10ignoreCaseEv($this) {
  return (HEAP32[$this + 16 >> 2] & 1 | 0) != 0;
}

function __ZNK2js6RegExp9multilineEv($this) {
  return (HEAP32[$this + 16 >> 2] & 4 | 0) != 0;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 1) | 0;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv($this) {
  return $this | 0;
}

function __ZNK2js18ContextAllocPolicy7contextEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment($this, $source, $flags, $compartment) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $source;
  HEAP32[$this + 8 >> 2] = 1;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = $flags;
  return;
}

function __ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZNK2js13RegExpStatics8getFlagsEv($this) {
  return HEAP32[$this + 100 >> 2];
}

function __ZN27JSAutoStructuredCloneBufferC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 1;
  return;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN2js18ContextAllocPolicyC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZNK2js15InvokeArgsGuard6pushedEv($this) {
  return (HEAP32[$this + 16 >> 2] | 0) != 0;
}

function __ZN2js12CallArgsList9setActiveEv($this) {
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js12CallArgsList11setInactiveEv($this) {
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function _OBJECT_TO_JSVAL_IMPL284($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj80EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($8, $11, $12);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $cx, $source, $flags, $ts) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString12ensureLinearEP9JSContext($source, $cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 3:
    var $6 = HEAP32[$cx + 56 >> 2];
    var $7 = __ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_($cx, $1, $flags, $6);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 5:
    var $11 = __ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE($7, $cx, undef);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground7delete_INS_6RegExpEEEvPT_($7);
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 8;
    break;
   case 7:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, $7);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279($cx) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb264($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280($cx, $4);
  return $5;
}

function __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($this, $cx, $re) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject11nativeEmptyEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 796 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $15 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this;
    var $10 = $cx;
    var $11 = __ZN8JSObject24assignInitialRegExpShapeEP9JSContext($9, $10);
    var $12 = $11;
    HEAP32[$5 >> 2] = $12;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $15 = $12;
      __label__ = 4;
      break;
    }
   case 4:
    var $15;
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $15);
    __label__ = 5;
    break;
   case 5:
    var $17 = $re;
    __ZN8JSObject10setPrivateEPv($this, $17);
    __ZN8JSObject19zeroRegExpLastIndexEv($this);
    var $18 = __ZNK2js6RegExp9getSourceEv($re);
    var $19 = $18 | 0;
    __ZN8JSObject15setRegExpSourceEP8JSString($this, $19);
    var $20 = __ZNK2js6RegExp6globalEv($re);
    __ZN8JSObject15setRegExpGlobalEb($this, $20);
    var $21 = __ZNK2js6RegExp10ignoreCaseEv($re);
    __ZN8JSObject19setRegExpIgnoreCaseEb($this, $21);
    var $22 = __ZNK2js6RegExp9multilineEv($re);
    __ZN8JSObject18setRegExpMultilineEb($this, $22);
    var $23 = __ZNK2js6RegExp6stickyEv($re);
    __ZN8JSObject15setRegExpStickyEb($this, $23);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp6decrefEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext7delete_IN2js6RegExpEEEvPT_(undef, $this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js6RegExpEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExpD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExpD1Ev($this) {
  __ZN2js6RegExpD2Ev($this);
  return;
}

function __ZN2js6RegExpD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z12jsRegExpFreeP8JSRegExp($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19zeroRegExpLastIndexEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL10Int32ValueEi251($1, 0);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpSourceEP8JSString($this, $source) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11StringValueEP8JSString276($1, $source);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 1, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpGlobalEb($this, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $global);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject19setRegExpIgnoreCaseEb($this, $ignoreCase) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $ignoreCase);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject18setRegExpMultilineEb($this, $multiline) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $multiline);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 4, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject15setRegExpStickyEb($this, $sticky) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL12BooleanValueEb275($1, $sticky);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 5, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11RegExpClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11RegExpClassE, $1, $parent, 0, (__ZN2js11RegExpClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11RegExpClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($this, $obj) {
  __ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_($this, $obj);
  return;
}

function __ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_($this, $p1, $p2, $p3) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 20);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment($4, $p1, $p2, undef);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE($this, $cx, $ts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $1 = $this + 4 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $4 = __ZN8JSString12ensureLinearEP9JSContext($3, $cx);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6RegExp6stickyEv($this);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$1 >> 2];
    var $10 = __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $9, undef);
    var $_1 = $10;
    __label__ = 8;
    break;
   case 4:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $13 = HEAP32[$1 >> 2] | 0;
    var $14 = __ZNK8JSString6lengthEv($13);
    var $15 = $14 + 5 | 0;
    var $16 = __ZN2js12StringBuffer7reserveEj($sb, $15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix | 0, 4);
    var $18 = HEAP32[$1 >> 2];
    var $19 = __ZNK14JSLinearString5charsEv($18);
    var $20 = $18 | 0;
    var $21 = __ZNK8JSString6lengthEv($20);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, $19, $21);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($sb, __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix | 0, 1);
    var $22 = $sb;
    var $23 = __ZN2js12StringBuffer12finishStringEv($22);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = $23 | 0;
    var $27 = __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $26, undef);
    var $_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_6RegExpEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExpD1Ev($p);
    var $3 = $p;
    _js_free272($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE($this, $cx, $pattern, $ts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $error = __stackBase__;
    HEAP32[$error >> 2] = 0;
    var $1 = __ZNK14JSLinearString5charsEv($pattern);
    var $2 = $pattern | 0;
    var $3 = __ZNK8JSString6lengthEv($2);
    var $4 = __ZNK2js6RegExp10ignoreCaseEv($this);
    var $5 = $4 & 1;
    var $6 = __ZNK2js6RegExp9multilineEv($this);
    var $7 = $6 & 1;
    var $8 = $this + 12 | 0;
    var $9 = __Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi($1, $3, $5, $7, $8, $error);
    HEAP32[$this >> 2] = $9;
    var $11 = HEAP32[$error >> 2];
    if (($11 | 0) == 0) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $cx;
    __ZN2js6RegExp15reportPCREErrorEP9JSContexti(undef, $14, $11);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer7reserveEj($this, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js12StringBuffer11checkLengthEj($this, $len);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj($3, $len);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16infallibleAppendEPKtj($this, $chars, $len) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j($1, $chars, $len);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j($this, $begin, $length) {
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $begin, $length);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $length) {
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this);
  var $2 = $insBegin + ($length << 1) | 0;
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($1, $insBegin, $2);
  var $3 = $this + 8 | 0;
  var $5 = HEAP32[$3 >> 2] + $length | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js12StringBuffer11checkLengthEj($this, $length) {
  var $1 = __ZNK2js12StringBuffer7contextEv($this);
  var $2 = __ZN2jsL17CheckStringLengthEP9JSContextj($1, $length);
  return $2;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 1;
    var $8 = __ZN2js18ContextAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v + 12 | 0;
    var $4 = HEAP32[$2 >> 2] << 1;
    var $5 = $v | 0;
    var $6 = $v + 4 | 0;
    var $8 = HEAP32[$6 >> 2];
    var $9 = __ZN2js18ContextAllocPolicy8realloc_EPvjj($5, $8, $4, $1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = $9;
    HEAP32[$6 >> 2] = $12;
    HEAP32[$2 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ContextAllocPolicy8realloc_EPvjj($this, $p, $oldBytes, $bytes) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN9JSContext8realloc_EPvjj($2, $p, $oldBytes, $bytes);
  return $3;
}

function __ZN9JSContext8realloc_EPvjj($this, $p, $oldBytes, $newBytes) {
  var $2 = HEAP32[$this + 52 >> 2];
  var $3 = __ZN9JSRuntime8realloc_EPvjjP9JSContext($2, $p, $oldBytes, $newBytes, $this);
  return $3;
}

function __ZN9JSRuntime8realloc_EPvjjP9JSContext($this, $p, $oldBytes, $newBytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newBytes - $oldBytes | 0;
    __ZN9JSRuntime19updateMallocCounterEj($this, $1);
    var $2 = _js_realloc274($p, $newBytes);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext(undef, undef, undef, $cx);
    var $7 = 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18ContextAllocPolicy19reportAllocOverflowEv($this) {
  var $2 = HEAP32[$this >> 2];
  __Z27js_ReportAllocationOverflowP9JSContext($2);
  return;
}

function __ZN2js18ContextAllocPolicy7malloc_Ej($this, $bytes) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN9JSContext7malloc_Ej($2, $bytes);
  return $3;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2jsL17CheckStringLengthEP9JSContextj($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StringBuffer7contextEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv($1);
  var $3 = __ZNK2js18ContextAllocPolicy7contextEv($2);
  return $3;
}

function __ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment($this, $source, $flags, $compartment) {
  __ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment($this, $source, $flags, undef);
  return;
}

function __ZN2js13RegExpStatics12setMultilineEb($this, $enabled) {
  var $1 = $this;
  __ZN2js13RegExpStatics12aboutToWriteEv($1);
  var $2 = $this + 100 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $storemerge = $enabled ? $3 | 4 : $3 & -5;
  HEAP32[$2 >> 2] = $storemerge;
  return;
}

function __ZN27JSAutoStructuredCloneBufferD2Ev($this) {
  __ZN27JSAutoStructuredCloneBuffer5clearEv($this);
  return;
}

function __ZN2js12StringBufferD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this);
    var $5 = $4;
    __ZN2js18ContextAllocPolicy5free_EPv($3, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ContextAllocPolicy5free_EPv($this, $p) {
  __ZN9JSContext5free_EPv(undef, $p);
  return;
}

function __ZN2js12StringBufferC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js18ContextAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18ContextAllocPolicyC1EP9JSContext($this, $cx) {
  __ZN2js18ContextAllocPolicyC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15InvokeArgsGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js15InvokeArgsGuard6pushedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 16 >> 2];
    var $6 = $this;
    __ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE($5, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj300($bits) {
  return $bits;
}

function _JSID_IS_INT292($iden) {
  return $iden & 1;
}

function _JSID_IS_STRING293($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSVAL_IS_PRIMITIVE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSVAL_TO_OBJECT_IMPL296($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSID_TO_INT297($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT298($iden) {
  return $iden & -8;
}

function __ZN2jsL13VersionSetXMLEP9JSVersionb($version, $enable) {
  var $1 = HEAP32[$version >> 2];
  var $storemerge = $enable ? $1 | 4096 : $1 & -4097;
  HEAP32[$version >> 2] = $storemerge;
  return;
}

function __ZN2jsL13OptionsHasXMLEj($options) {
  return ($options & 64 | 0) != 0;
}

function __ZN2jsL13VersionHasXMLE9JSVersion($version) {
  return ($version & 4096 | 0) != 0;
}

function __ZN2jsL19VersionExtractFlagsE9JSVersion($version) {
  return $version & -4096;
}

function _JSVAL_IS_INT32_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function __ZN2jsL8JsvalifyEPNS_5ClassE($c) {
  return $c;
}

function __ZL18JSDOUBLE_IS_FINITEd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function _JSDOUBLE_IS_NEGZERO301($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZNK9JSContext12hasRunOptionEj($this, $ropt) {
  return (HEAP32[$this + 32 >> 2] & $ropt | 0) != 0;
}

function __ZN18AutoLastFrameCheckC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN9JSContext17setDefaultVersionE9JSVersion($this, $version) {
  HEAP32[$this + 8 >> 2] = $version;
  return;
}

function __ZN9JSContext15overrideVersionE9JSVersion($this, $newVersion) {
  HEAP32[$this + 12 >> 2] = $newVersion;
  HEAP8[$this + 16 | 0] = 1;
  return;
}

function __ZNK9JSContext17getDefaultVersionEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js5Shape5RangeC2EPKS0_($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZNK8JSObject11isSlowArrayEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js14SlowArrayClassE | 0);
}

function __ZNK2js5Shape10attributesEv($this) {
  return HEAP8[$this + 28 | 0];
}

function __ZNK2js5Shape8isMethodEv($this) {
  return HEAP8[$this + 29 | 0] << 24 >> 24 < 0;
}

function __ZNK2js5Shape12methodObjectEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js5Shape6getterEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js5Shape6setterEv($this) {
  return HEAP32[$this + 20 >> 2];
}

function __ZN19AutoHoldCompartmentD2Ev($this) {
  HEAP8[HEAP32[$this >> 2]] = 0;
  return;
}

function __ZN19AutoHoldCompartmentC2EP13JSCompartment($this, $compartment) {
  var $2 = $compartment + 340 | 0;
  HEAP32[$this >> 2] = $2;
  HEAP8[$2] = 1;
  return;
}

function __ZN18JSAutoResolveFlagsD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $5 = HEAP32[$this >> 2] + 208 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZN18JSAutoResolveFlagsC2EP9JSContextj($this, $cx, $flags) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 208 | 0;
  var $4 = HEAP32[$3 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  HEAP32[$3 >> 2] = $flags;
  return;
}

function __ZN9JSRuntime18resetGCMallocBytesEv($this) {
  var $2 = HEAP32[$this + 156 >> 2];
  HEAP32[$this + 144096 >> 2] = $2;
  return;
}

function __ZNK2js5Shape8hasTableEv($this) {
  return HEAPU32[$this + 8 >> 2] >>> 0 > 7;
}

function __ZNK2js5Shape8getTableEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN9JSContext13setRunOptionsEj($this, $ropts) {
  HEAP32[$this + 32 >> 2] = $ropts;
  return;
}

function __ZNK9JSContext13getRunOptionsEv($this) {
  return HEAP32[$this + 32 >> 2];
}

function __ZN2js13StaticStringsC2Ev($this) {
  HEAP8[$this | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN16JSAutoByteStringC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN12JSValueArrayC2EPN2JS5ValueEj($this, $v, $c) {
  HEAP32[$this >> 2] = $v;
  HEAP32[$this + 4 >> 2] = $c;
  return;
}

function _JS_InitArenaPool($pool, $name, $size, $align) {
  var $align_off = $align - 1 | 0;
  var $align_off_ = $align_off >>> 0 < 2 | ($align | 0) == 4 | ($align | 0) == 8 ? $align_off : 7;
  HEAP32[$pool + 24 >> 2] = $align_off_;
  var $5 = $pool | 0;
  HEAP32[$pool >> 2] = 0;
  var $11 = $5 + ($align_off_ + 16) & ($align_off_ ^ -1);
  HEAP32[$pool + 8 >> 2] = $11;
  HEAP32[$pool + 12 >> 2] = $11;
  HEAP32[$pool + 4 >> 2] = $11;
  HEAP32[$pool + 16 >> 2] = $5;
  HEAP32[$pool + 20 >> 2] = $size;
  return;
}

function __ZN2js15InvokeArgsGuardC2Ev($this) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$1 + 8 >> 2] = 0;
  HEAP8[$1 + 12] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP8[$this + 20 | 0] = 0;
  return;
}

function __ZN2js8BindingsC1EP9JSContext($this, $cx) {
  __ZN2js8BindingsC2EP9JSContext($this, undef);
  return;
}

function __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($this, $cx, $name, $slotp) {
  var $2 = HEAP16[$this + 4 >> 1];
  HEAP16[$slotp >> 1] = $2;
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($3, $4, $name, 1);
  return $5;
}

function __ZN2js8BindingsC2EP9JSContext($this, $cx) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP16[$1 + 8 >> 1] = 0;
  HEAP8[$1 + 10] = 0;
  return;
}

function __ZN18AutoLastFrameCheckD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN9JSContext18isExceptionPendingEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = _JS_IsRunning($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK9JSContext12hasRunOptionEj($2, 256);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $2;
    var $11 = __Z26js_ReportUncaughtExceptionP9JSContext($10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext($cx) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($cx, 16);
  var $2 = $1 ? 8192 : 0;
  var $3 = __ZNK9JSContext12hasRunOptionEj($cx, 4096);
  var $4 = $3 ? 16384 : 0;
  return $4 | $2;
}

function __ZN14AutoVersionAPID2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$this + 4 >> 2];
    __ZN9JSContext17setDefaultVersionE9JSVersion($2, $4);
    var $9 = HEAP32[$1 >> 2];
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$this + 12 >> 2];
    __ZN9JSContext15overrideVersionE9JSVersion($9, $12);
    __label__ = 4;
    break;
   case 3:
    var $14 = $9;
    __ZN9JSContext20clearVersionOverrideEv($14);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14AutoVersionAPIC2EP9JSContext9JSVersion($this, $cx, $newVersion) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK9JSContext17getDefaultVersionEv($cx);
    HEAP32[$2 >> 2] = $3;
    var $4 = $this + 8 | 0;
    var $5 = $cx;
    var $6 = __ZNK9JSContext19isVersionOverriddenEv($5);
    HEAP8[$4] = $6 & 1;
    var $8 = $this + 12 | 0;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $12 = -1;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = __ZNK9JSContext11findVersionEv($cx);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    HEAP32[$8 >> 2] = $12;
    HEAP32[$this + 16 >> 2] = $newVersion;
    __ZN9JSContext20clearVersionOverrideEv($5);
    __ZN9JSContext17setDefaultVersionE9JSVersion($cx, $newVersion);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject12getFixedSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject10fixedSlotsEv($this);
  return $1 + ($slot << 3) | 0;
}

function __ZN2js16AutoObjectRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject($this, $cx, $obj) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -10);
  HEAP32[$this + 12 >> 2] = $obj;
  return;
}

function __ZN8JSObject13setAttributesEP9JSContextiPj($this, $cx, $id, $attrsp) {
  __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $id);
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 84 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 54;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $attrsp);
  return $6;
}

function __ZNK8JSObject12containsSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject8slotSpanEv($this);
  return $1 >>> 0 > $slot >>> 0;
}

function __ZNK8JSObject13nativeGetSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject7getSlotEj($this, $slot);
  return $1;
}

function __ZN8JSObject13getAttributesEP9JSContextiPj($this, $cx, $id, $attrsp) {
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 68 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 56;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $id, $attrsp);
  return $6;
}

function __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($this, $cx, $shape, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8toObjectEv($vp);
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($1);
    var $3 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject12setMethodObjERS_($3, $this);
    var $7 = HEAP32[$shape + 24 >> 2];
    var $8 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $7, $vp);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fun | 0;
    var $2 = __ZNK8JSObject16hasSingletonTypeEv($1);
    if ($2) {
      var $_0 = $1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject9getParentEv($1);
    var $5 = __ZNK8JSObject8getProtoEv($1);
    var $6 = __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $4, $5);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12setMethodObjERS_($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject239($1, $obj);
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, 1, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $slot, $value) {
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $slot, $value);
  return;
}

function __ZN2jsL9IdToValueEi($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING293($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING243($id);
    __ZN2JSL11StringValueEP8JSString276($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT292($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT297($id);
    __ZN2JSL10Int32ValueEi251($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT298($id);
    __ZN2JSL11ObjectValueER8JSObject239($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv245($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_NewGCExternalStringP9JSContext($cx) {
  var $1 = __Z10NewGCThingI16JSExternalStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, 19, 16);
  return $1;
}

function __ZN16JSExternalString4initEPKtjiPv($this, $chars, $length, $type, $closure) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 4);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  HEAP32[$this + 8 >> 2] = $type;
  HEAP32[$this + 12 >> 2] = $closure;
  return;
}

function __Z10NewGCThingI16JSExternalStringEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime8realloc_EPvjP9JSContext($this, $p, $bytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSRuntime19updateMallocCounterEj($this, $bytes);
    __label__ = 3;
    break;
   case 3:
    var $4 = _js_realloc274($p, $bytes);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $9 = $4;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext(undef, undef, undef, $cx);
    var $9 = 0;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_calloc299($bytes) {
  var $1 = _calloc($bytes, 1);
  return $1;
}

function __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $id) {
  var $1 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 0);
  return HEAP32[$1 >> 2] & -2;
}

function __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, $adding) {
  var $1 = $this | 0;
  var $2 = __ZN2js5Shape6searchEP9JSContextPPS0_ib($cx, $1, $id, $adding);
  return $2;
}

function __ZN2js5Shape6searchEP9JSContextPPS0_ib($cx, $startp, $id, $adding) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$startp >> 2];
    var $2 = __ZNK2js5Shape8hasTableEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape8getTableEv($1);
    var $5 = __ZN2js13PropertyTable6searchEib($4, $id, $adding);
    var $_0 = $5;
    __label__ = 10;
    break;
   case 3:
    var $7 = $1 + 8 | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN2js5Shape7hashifyEP9JSContext($1, $cx);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $spp_0 = $startp;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = __ZNK2js5Shape8getTableEv($1);
    var $14 = __ZN2js13PropertyTable6searchEib($13, $id, $adding);
    var $_0 = $14;
    __label__ = 10;
    break;
   case 6:
    var $16 = $8 + 1 | 0;
    HEAP32[$7 >> 2] = $16;
    var $spp_0 = $startp;
    __label__ = 7;
    break;
   case 7:
    var $spp_0;
    var $17 = HEAP32[$spp_0 >> 2];
    if (($17 | 0) == 0) {
      var $_0 = $spp_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$17 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $spp_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $spp_0 = $17 + 32 | 0;
    __label__ = 7;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext17setCompileOptionsEj($this, $newcopts) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext17getCompileOptionsEv($this);
    if (($1 | 0) == ($newcopts | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext11findVersionEv($this);
    var $5 = __ZN2jsL20OptionFlagsToVersionEj9JSVersion($newcopts, $4);
    var $6 = __ZN9JSContext20maybeOverrideVersionE9JSVersion($this, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext17getCompileOptionsEv($this) {
  var $1 = __ZNK9JSContext11findVersionEv($this);
  var $2 = __ZN2jsL21VersionFlagsToOptionsE9JSVersion($1);
  return $2;
}

function __ZN2jsL20OptionFlagsToVersionEj9JSVersion($options, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $version;
  var $2 = __ZN2jsL13OptionsHasXMLEj($options);
  __ZN2jsL13VersionSetXMLEP9JSVersionb($1, $2);
  var $3 = HEAP32[$1 >> 2];
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2jsL21VersionFlagsToOptionsE9JSVersion($version) {
  var $1 = __ZN2jsL13VersionHasXMLE9JSVersion($version);
  var $2 = $1 ? 64 : 0;
  return $2;
}

function __ZNK9JSContext20canSetDefaultVersionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 60 | 0;
    var $2 = __ZNK2js12ContextStack5hasfpEv($1);
    if ($2) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN11JSAtomStateD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN11JSAtomStateC2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2JS5Value7isInt32Ev($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_INT32_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js15AutoValueRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE($this, $cx, $v) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -1);
  var $2 = $v | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZN16JSAutoByteStringD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js10Foreground5free_EPv($2);
  return;
}

function __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($this, $cx, $str) {
  var $1 = _JS_EncodeString($cx, $str);
  HEAP32[$this >> 2] = $1;
  return $1;
}

function __GLOBAL__I_a() {
  ___cxx_global_var_init();
  ___cxx_global_var_init1();
  ___cxx_global_var_init2();
  ___cxx_global_var_init3();
  ___cxx_global_var_init4();
  ___cxx_global_var_init5();
  return;
}

function _JS_ArenaAllocate($pool, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pool + 16 | 0;
    var $3 = $pool + 20 | 0;
    var $a_0 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $a_0;
    var $6 = HEAPU32[$a_0 + 8 >> 2];
    if ($6 >>> 0 < $nb >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $a_0 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    if ($10 >>> 0 > ($6 - $nb | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $13 = $a_0 | 0;
    var $14 = HEAPU32[$13 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $a_1 = $14;
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = HEAPU32[$3 >> 2];
    var $nb_ = $17 >>> 0 < $nb >>> 0 ? $nb : $17;
    var $19 = $nb_ + 16 | 0;
    var $20 = __ZN2js11OffTheBooks7malloc_Ej($19);
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$20 >> 2] = 0;
    var $25 = $20;
    var $26 = $25 + 16 | 0;
    HEAP32[$20 + 12 >> 2] = $26;
    HEAP32[$20 + 4 >> 2] = $26;
    HEAP32[$20 + 8 >> 2] = $19 + $25 | 0;
    HEAP32[$13 >> 2] = $21;
    var $a_1 = $21;
    __label__ = 7;
    break;
   case 7:
    var $a_1;
    HEAP32[$1 >> 2] = $a_1;
    var $a_0 = $a_1;
    __label__ = 2;
    break;
   case 8:
    var $36 = $10;
    HEAP32[$9 >> 2] = $10 + $nb | 0;
    var $_0 = $36;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ArenaAllocate["X"] = 1;

function _JS_ArenaFinish() {
  return;
}

function _JS_ArenaShutDown() {
  return;
}

function __ZN8JSObject11asArgumentsEv($this) {
  return $this;
}

function __ZN2js15AutoValueRooter4addrEv($this) {
  return $this + 16 | 0;
}

function __ZN8JSObject30getDenseArrayInitializedLengthEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZN8JSObject21getDenseArrayElementsEv($this) {
  return HEAP32[$this + 32 >> 2];
}

function __ZN8JSObject20getDenseArrayElementEj($this, $idx) {
  return HEAP32[$this + 32 >> 2] + ($idx << 3) | 0;
}

function __ZNK8JSObject9isIndexedEv($this) {
  return (HEAP32[$this + 8 >> 2] & 64 | 0) != 0;
}

function _JS_ArenaRealloc($pool, $p, $size, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pool | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $p;
    var $5 = HEAP32[$2 + 4 >> 2];
    if (($3 - $5 | 0) >>> 0 > (HEAP32[$2 + 12 >> 2] - $5 | 0) >>> 0) {
      var $11 = $2;
      __label__ = 2;
      break;
    } else {
      var $ap_0_lcssa = $1;
      var $_lcssa = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $11;
    var $12 = $11 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $15 = HEAP32[$13 + 4 >> 2];
    if (($3 - $15 | 0) >>> 0 > (HEAP32[$13 + 12 >> 2] - $15 | 0) >>> 0) {
      var $11 = $13;
      __label__ = 2;
      break;
    } else {
      var $ap_0_lcssa = $12;
      var $_lcssa = $13;
      __label__ = 3;
      break;
    }
   case 3:
    var $_lcssa;
    var $ap_0_lcssa;
    var $22 = HEAP32[$pool + 24 >> 2];
    var $27 = ($incr + $size + $22 & ($22 ^ -1)) + 16 | 0;
    var $29 = __ZN2js11OffTheBooks8realloc_EPvj($_lcssa, $27);
    var $30 = $29;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = $29;
    var $34 = $33 + 16 | 0;
    var $36 = $29 + 4 | 0;
    HEAP32[$36 >> 2] = $34;
    var $37 = $27 + $33 | 0;
    var $39 = $29 + 8 | 0;
    HEAP32[$39 >> 2] = $37;
    var $41 = $29 + 12 | 0;
    HEAP32[$41 >> 2] = $37;
    var $42 = HEAP32[$ap_0_lcssa >> 2];
    if (($30 | 0) == ($42 | 0)) {
      var $51 = $34;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $45 = $pool + 16 | 0;
    if ((HEAP32[$45 >> 2] | 0) == ($42 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$45 >> 2] = $30;
    __label__ = 7;
    break;
   case 7:
    HEAP32[$ap_0_lcssa >> 2] = $30;
    var $51 = HEAP32[$36 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $51;
    var $_0 = $51;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_ArenaRealloc["X"] = 1;

function __ZN2js11OffTheBooks8realloc_EPvj($p, $bytes) {
  var $1 = _js_realloc311($p, $bytes);
  return $1;
}

function _JS_ArenaGrow($pool, $p, $size, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$pool + 20 >> 2] >>> 0 < $size >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _JS_ArenaRealloc($pool, $p, $size, $incr);
    var $_0 = $5;
    __label__ = 8;
    break;
   case 3:
    var $8 = HEAP32[$pool + 16 >> 2];
    var $10 = HEAP32[$pool + 24 >> 2];
    var $14 = $incr + $size + $10 & ($10 ^ -1);
    var $15 = $8 + 12 | 0;
    var $16 = HEAPU32[$15 >> 2];
    var $18 = HEAPU32[$8 + 8 >> 2];
    if ($14 >>> 0 > $18 >>> 0 | $16 >>> 0 > ($18 - $14 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = _JS_ArenaAllocate($pool, $14);
    var $_p_0 = $23;
    __label__ = 6;
    break;
   case 5:
    var $26 = $14 + $16 | 0;
    HEAP32[$15 >> 2] = $26;
    var $_p_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    var $28 = $_p_0;
    if (($_p_0 | 0) == 0) {
      var $_0 = $28;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _memcpy($28, $p, $size, 1);
    var $_0 = $28;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ArenaRelease($pool, $mark) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $mark;
    var $a_0 = $pool | 0;
    __label__ = 2;
    break;
   case 2:
    var $a_0;
    if (($a_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$a_0 + 4 >> 2];
    var $9 = $a_0 + 12 | 0;
    if (($2 - $7 | 0) >>> 0 > (HEAP32[$9 >> 2] - $7 | 0) >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$pool + 24 >> 2];
    var $18 = $15 + $2 & ($15 ^ -1);
    HEAP32[$9 >> 2] = $18;
    __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $a_0);
    __label__ = 6;
    break;
   case 5:
    var $a_0 = HEAP32[$a_0 >> 2];
    __label__ = 2;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $head) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $head | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $a_0 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $a_0;
    var $5 = HEAP32[$a_0 >> 2];
    HEAP32[$1 >> 2] = $5;
    __ZN2js10Foreground5free_EPv($a_0);
    var $7 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $a_0 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$pool + 16 >> 2] = $head;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FreeArenaPool($pool) {
  var $1 = $pool | 0;
  __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $1);
  return;
}

function _JS_FinishArenaPool($pool) {
  var $1 = $pool | 0;
  __ZL13FreeArenaListP11JSArenaPoolP7JSArena($pool, $1);
  return;
}

function _js_realloc311($p, $bytes) {
  var $1 = _realloc($p, $bytes);
  return $1;
}

function __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $lengthp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZNK8JSObject7isArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject14getArrayLengthEv($obj);
    HEAP32[$lengthp >> 2] = $3;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZN8JSObject11asArgumentsEv($obj);
    var $8 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($7);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($7);
    HEAP32[$lengthp >> 2] = $10;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 6:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $16 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $17 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($obj, $cx, $15, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $21 = __ZNK2JS5Value7isInt32Ev($20);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($20);
    HEAP32[$lengthp >> 2] = $23;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $25 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $20, $lengthp);
    var $_0 = $25 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject14getArrayLengthEv($this) {
  var $1 = __ZNK8JSObject10getPrivateEv($this);
  return $1;
}

function __ZNK8JSObject11isArgumentsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($1);
    if ($2) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject17isStrictArgumentsEv($this);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = __ZNK2JS5Value7toInt32Ev($2);
  return ($3 & 1 | 0) != 0;
}

function __ZN2js15AutoValueRooterC1EP9JSContext($this, $cx) {
  __ZN2js15AutoValueRooterC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($str, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK14JSLinearString5charsEv($str);
    var $2 = $str | 0;
    var $3 = __ZNK8JSString6lengthEv($2);
    var $4 = $1 + ($3 << 1) | 0;
    if (($3 | 0) == 0 | $3 >>> 0 > 10) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = (HEAPU16[$1 >> 1] & 65535) - 48 | 0;
    if ($10 >>> 0 < 10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    if (($10 | 0) != 0 | ($3 | 0) == 1) {
      var $index_0 = $10;
      var $previous_0 = 0;
      var $s_0_pn = $1;
      var $c_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $c_0;
    var $s_0_pn;
    var $previous_0;
    var $index_0;
    var $s_0 = $s_0_pn + 2 | 0;
    if ($s_0 >>> 0 < $4 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $19 = (HEAPU16[$s_0 >> 1] & 65535) - 48 | 0;
    if ($19 >>> 0 < 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $previous_0 = $index_0;
    var $index_0 = $19 + $index_0 * 10 | 0;
    var $s_0_pn = $s_0;
    var $c_0 = $19;
    __label__ = 4;
    break;
   case 7:
    if ($previous_0 >>> 0 < 429496729) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($previous_0 | 0) == 429496729 & $c_0 >>> 0 < 5) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$indexp >> 2] = $index_0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject22willBeSparseDenseArrayEjj($this, $requiredCapacity, $newElementsHint) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($this);
    if ($requiredCapacity >>> 0 > 536870911) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $requiredCapacity >>> 2;
    if ($4 >>> 0 > $newElementsHint >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $7 = $4 - $newElementsHint | 0;
    if ($7 >>> 0 > $1 >>> 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject30getDenseArrayInitializedLengthEv($this);
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($this);
    var $i_0 = 0;
    var $minimalDenseCount_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $minimalDenseCount_0;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 6:
    var $15 = $11 + ($i_0 << 3) | 0;
    var $16 = __ZNK2JS5Value7isMagicE10JSWhyMagic($15, undef);
    if ($16) {
      var $minimalDenseCount_1 = $minimalDenseCount_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $minimalDenseCount_0 - 1 | 0;
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $minimalDenseCount_1 = $18;
      __label__ = 8;
      break;
    }
   case 8:
    var $minimalDenseCount_1;
    var $i_0 = $i_0 + 1 | 0;
    var $minimalDenseCount_0 = $minimalDenseCount_1;
    __label__ = 5;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isMagicE10JSWhyMagic($this, $why) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_MAGIC_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE($this, $cx, $i, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $id = __stackBase__ + 4;
    var $1 = __ZNK8JSObject12isDenseArrayEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject14getArrayLengthEv($this);
    if ($3 >>> 0 > $i >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value8setMagicE10JSWhyMagic($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 4:
    var $7 = __ZN8JSObject20getDenseArrayElementEj($this, $i);
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 5:
    var $12 = $i >>> 0;
    var $13 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $this, $12, $hole, $id, 0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = HEAP32[$id >> 2];
    var $16 = __ZN8JSObject12nativeLookupEP9JSContexti($this, $cx, $15);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK2js5Shape16isDataDescriptorEv($16);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value8setMagicE10JSWhyMagic($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $23 = HEAP32[$16 + 24 >> 2];
    var $24 = __ZNK8JSObject7getSlotEj($this, $23);
    var $25 = $24 | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $vp | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, $hole, $idp, $createAtom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($index > 1073741823) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $index & -1;
    var $4 = _INT_TO_JSID398($3);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    if ($index > 4294967295) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $9 = __ZL12BigIndexToIdP9JSContextP8JSObjectjiPi($cx, $obj, $8, $createAtom, $idp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($hole | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = HEAP32[$idp >> 2];
    var $15 = _JSID_IS_VOID($14);
    if (($15 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$hole >> 2] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $19 = __ZL18ReallyBigIndexToIdP9JSContextdPi($cx, $index, $idp);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject12isDenseArrayEv($aobj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject30getDenseArrayInitializedLengthEv($aobj);
    if ($4 >>> 0 < $length >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $aobj);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($aobj);
    var $11 = $10 + ($length << 3) | 0;
    if (($length | 0) > 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 5:
    var $13 = $1 | 0;
    var $src_01 = $10;
    var $dst_02 = $vp;
    __label__ = 6;
    break;
   case 6:
    var $dst_02;
    var $src_01;
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($src_01, undef);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2JSL14UndefinedValueEv351($1);
    var $st$1$0 = $13 | 0;
    var $st$1$1 = $13 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $21$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 9;
    break;
   case 8:
    var $18 = $src_01 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$13 >> 2] = $19$0;
    HEAP32[$13 + 4 >> 2] = $19$1;
    var $21$1 = $19$1;
    var $21$0 = $19$0;
    __label__ = 9;
    break;
   case 9:
    var $21$0;
    var $21$1;
    var $22 = $dst_02 | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $24 = $src_01 + 8 | 0;
    if ($24 >>> 0 < $11 >>> 0) {
      var $src_01 = $24;
      var $dst_02 = $dst_02 + 8 | 0;
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 10:
    var $27 = __ZNK8JSObject11isArgumentsEv($aobj);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $29 = __ZN8JSObject11asArgumentsEv($aobj);
    var $30 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($29);
    if ($30) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE($29, 0, $length, $vp);
    if ($32) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp);
    var $_0 = $34;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE["X"] = 1;

function __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $2 = __ZNK8JSObject8getProtoEv($_01);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject8isNativeEv($2);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject9isIndexedEv($2);
    if ($7) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $2;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv351($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE($this, $start, $count, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js15ArgumentsObject13initialLengthEv($this);
    if ($2 >>> 0 < $start >>> 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $count + $start | 0;
    if ($5 >>> 0 > $2 >>> 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($this);
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $11 = __ZNK2js15ArgumentsObject8elementsEv($this);
    var $13 = $11 + ($5 << 3) | 0;
    var $dst_0 = $vp;
    var $src_0 = $11 + ($start << 3) | 0;
    __label__ = 5;
    break;
   case 5:
    var $src_0;
    var $dst_0;
    if ($src_0 >>> 0 < $13 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 6:
    var $17 = __ZNK2JS5Value7isMagicE10JSWhyMagic($src_0, undef);
    if ($17) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $src_0 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $dst_0 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $dst_0 = $dst_0 + 8 | 0;
    var $src_0 = $src_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    var $25 = __ZNK2js15ArgumentsObject7onTraceEv($this);
    if ($25) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE($1, $this, $vp);
    var $27 = __ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj($8, $1, $start, $count);
    var $_0 = $27;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $aobj, $length, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $length >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $4 = $vp + ($i_0 << 3) | 0;
    var $5 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($aobj, $cx, $i_0, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  var $1 = __ZN2JS5Value9setNumberEd($v, $length);
  var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $7 = __ZL12ATOM_TO_JSIDP6JSAtom354($6);
  var $8 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $7, $v, 0);
  STACKTOP = __stackBase__;
  return $8;
}

function __ZL12ATOM_TO_JSIDP6JSAtom354($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj423($1);
  return $2;
}

function __Z28js_GetDenseArrayElementValueP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __Z12js_IdIsIndexiPj($id, $i);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $5 = __ZN2JS5Value9setNumberEj($vp, $4);
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[$i >> 2];
    var $8 = __ZN8JSObject20getDenseArrayElementEj($obj, $7);
    var $9 = $8 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_IdIsIndexiPj($id, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT387($id);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_INT420($id);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$indexp >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $8 = _JSID_IS_STRING388($id);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZL12JSID_TO_ATOMi421($id);
    var $12 = $11 | 0;
    var $13 = __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($12, $indexp);
    var $_0 = $13 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $id, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $cx;
    var $12 = $obj;
    var $13 = $getter;
    var $14 = $setter;
    var $15 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($11, $12, $id, $value, $13, $14, $attrs);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 4:
    HEAP32[$i >> 2] = 0;
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) != 0 & ($attrs | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $21 = HEAPU32[$i >> 2];
    var $22 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $21, 1);
    if (($22 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($22 | 0) == 1) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $24 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($21 >>> 0 < $24 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $21 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $27);
    __label__ = 8;
    break;
   case 8:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $21, $value);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $30 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $cx;
    var $34 = $obj;
    var $35 = $getter;
    var $36 = $setter;
    var $37 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($33, $34, $id, $value, $35, $36, $attrs);
    var $_0 = $37;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom354($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($this, $cx, $index, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($this);
    if (($extra | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, 1);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $7 = $index + 1 | 0;
    if (($7 | 0) == 0) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      var $requiredCapacity_0 = $7;
      __label__ = 8;
      break;
    }
   case 5:
    var $uadd = _llvm_uadd_with_overflow_i32($index, $extra);
    var $10 = $uadd.f0;
    var $11 = $uadd.f1;
    if ($11) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($10 >>> 0 > $1 >>> 0) {
      var $requiredCapacity_0 = $10;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 8:
    var $requiredCapacity_0;
    if ($requiredCapacity_0 >>> 0 > 256) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $18 = __ZN8JSObject22willBeSparseDenseArrayEjj($this, $requiredCapacity_0, $extra);
    if ($18) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $20 = $this;
    var $21 = $cx;
    var $22 = __ZN8JSObject9growSlotsEP9JSContextj($20, $21, $requiredCapacity_0);
    if ($22) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $index, $extra);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19setDenseArrayLengthEj($this, $length) {
  var $1 = $length;
  __ZN8JSObject10setPrivateEPv($this, $1);
  return;
}

function __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($this, $cx, $idx, $val) {
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $this, 2, $val);
  __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($this, $idx, $val);
  return;
}

function __ZL26array_getElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  HEAP32[$attrsp >> 2] = 1;
  return 1;
}

function __ZL12array_typeOfP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN8JSObject18makeDenseArraySlowEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $autoArray = __stackBase__;
    var $id = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 196608);
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($this, $cx);
    var $3 = HEAPU32[$this >> 2];
    var $4 = $this;
    var $5 = __ZNK2js2gc4Cell12getAllocKindEv($4);
    var $6 = __ZNK8JSObject8getProtoEv($this);
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 0);
    var $8 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $this, __ZN2js14SlowArrayClassE, $7, $5);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($this, $cx);
    var $10 = __ZN8JSObject21getDenseArrayCapacityEv($this);
    var $11 = __ZN8JSObject30getDenseArrayInitializedLengthEv($this);
    var $12 = __ZNK8JSObject24denseArrayHasInlineSlotsEv($this);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $14 = __ZNK8JSObject8numSlotsEv($this);
    var $15 = $this;
    var $16 = $cx;
    var $17 = __ZN8JSObject10allocSlotsEP9JSContextj($15, $16, $14);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 5:
    var $20 = __ZNK8JSObject13numFixedSlotsEv($this);
    var $22 = $this + 28 | 0;
    HEAP32[$22 >> 2] = $20 + $10 | 0;
    var $23 = $this + 4 | 0;
    HEAP32[$23 >> 2] = __ZN2js14SlowArrayClassE;
    var $24 = $this + 32 | 0;
    var $25 = HEAP32[$24 >> 2];
    __ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj($autoArray, $cx, $25, $11);
    var $26 = $this + 16 | 0;
    HEAP32[$26 >> 2] = 0;
    var $27 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $this);
    if ($27) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $28 = $this;
    var $29 = $cx;
    var $i_0 = 0;
    var $next_0 = 0;
    __label__ = 8;
    break;
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    HEAP32[$22 >> 2] = $10;
    HEAP32[$26 >> 2] = $11;
    HEAP32[$23 >> 2] = __ZN2js10ArrayClassE;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 8:
    var $next_0;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    __ZN2JSL10Int32ValueEi360($1, $i_0);
    var $34 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $1, $id);
    var $36 = HEAP32[$24 >> 2] + ($i_0 << 3) | 0;
    var $37 = __ZNK2JS5Value7isMagicE10JSWhyMagic($36, undef);
    if ($37) {
      var $next_1 = $next_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $next_0, $36);
    var $39 = HEAP32[$id >> 2];
    var $40 = __ZN8JSObject15addDataPropertyEP9JSContextijj($28, $29, $39, $next_0, 1);
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $3);
    HEAP32[$22 >> 2] = $10;
    HEAP32[$26 >> 2] = $11;
    HEAP32[$23 >> 2] = __ZN2js10ArrayClassE;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 12:
    var $next_1 = $next_0 + 1 | 0;
    __label__ = 13;
    break;
   case 13:
    var $next_1;
    var $i_0 = $i_0 + 1 | 0;
    var $next_0 = $next_1;
    __label__ = 8;
    break;
   case 14:
    var $49 = HEAP32[$22 >> 2] - $next_0 | 0;
    var $50 = $this;
    __ZN8JSObject14clearSlotRangeEjj($50, $next_0, $49);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js14AutoValueArrayD1Ev($autoArray);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject18makeDenseArraySlowEP9JSContext["X"] = 1;

function __ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $index, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $getter;
    var $6 = $setter;
    var $7 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($3, $4, $index, $value, $5, $6, $attrs);
    var $_0 = $7;
    __label__ = 11;
    break;
   case 3:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    if (($attrs | 0) != 1 | ($index | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $index, 1);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 1) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $16 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($16 >>> 0 > $index >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $index + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $19);
    __label__ = 8;
    break;
   case 8:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $index, $value);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $22 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = $cx;
    var $26 = $obj;
    var $27 = $getter;
    var $28 = $setter;
    var $29 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($25, $26, $index, $value, $27, $28, $attrs);
    var $_0 = $29;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($4, $5, $id, $rval, $strict);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $13 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $12);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 5:
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAPU32[$i >> 2];
    var $21 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($20 >>> 0 < $21 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj, $20, $1);
    __label__ = 8;
    break;
   case 8:
    var $25 = $cx;
    var $26 = $obj;
    var $27 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($25, $26, $id);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10MagicValueE10JSWhyMagic($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 0);
  return;
}

function __ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($4, $5, $index, $rval, $strict);
    var $_0 = $6;
    __label__ = 7;
    break;
   case 3:
    var $8 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($8 >>> 0 > $index >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj, $index, $1);
    __label__ = 5;
    break;
   case 5:
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __Z25js_SuppressDeletedElementP9JSContextP8JSObjectj($12, $13, $index);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11array_traceP8JSTracerP8JSObject($trc, $obj) {
  var $1 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
  var $2 = __ZN8JSObject21getDenseArrayElementsEv($obj);
  __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $1, $2, undef);
  return;
}

function __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $objp;
    var $6 = $propp;
    var $7 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($3, $4, $id, $5, $6);
    var $_0 = $7;
    __label__ = 8;
    break;
   case 3:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $9 = __ZL14IsDenseArrayIdP9JSContextP8JSObjecti($cx_idx_val_idx_val, $obj, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $12 = __ZNK8JSObject8getProtoEv($obj);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $16 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($12, $cx, $id, $objp, $propp);
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    var $5 = $objp;
    var $6 = $propp;
    var $7 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($3, $4, $index, $5, $6);
    var $_0 = $7;
    __label__ = 8;
    break;
   case 3:
    var $9 = __ZL17IsDenseArrayIndexP8JSObjectj($obj, $index);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $12 = __ZNK8JSObject8getProtoEv($obj);
    if (($12 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($12, $cx, $index, $objp, $propp);
    var $_0 = $15;
    __label__ = 8;
    break;
   case 7:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($cx, $obj, $1, $value, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $5 = HEAP32[$2 + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $10 = __ZN2JS5Value9setNumberEj($vp, $9);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 3:
    var $14 = HEAP32[$2 + 210292 >> 2] | 0;
    var $15 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $14);
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = __ZNK8JSObject8getProtoEv($obj);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $18);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 5:
    var $20 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp);
    var $_0 = $22;
    __label__ = 17;
    break;
   case 7:
    var $24 = __Z12js_IdIsIndexiPj($id, $i);
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAPU32[$i >> 2];
    var $28 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($27 >>> 0 < $28 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = __ZN8JSObject20getDenseArrayElementEj($obj, $27);
    var $32 = __ZNK2JS5Value7isMagicE10JSWhyMagic($31, undef);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 10:
    var $34 = __ZNK8JSObject8getProtoEv($obj);
    var $35 = ($34 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($35) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = HEAP32[$cx + 208 >> 2];
    var $39 = $cx;
    var $40 = $34;
    var $41 = $obj2;
    var $42 = $prop;
    var $43 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($39, $40, $id, $38, $41, $42);
    if ($43) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $45 = HEAP32[$prop >> 2];
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = HEAP32[$obj2 >> 2];
    var $49 = __ZNK8JSObject8isNativeEv($48);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $51 = $obj;
    var $52 = $48;
    var $53 = $45;
    var $54 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($39, $51, $52, $53, 0, $vp);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 16:
    var $58 = $31 | 0;
    var $59$0 = HEAP32[$58 >> 2];
    var $59$1 = HEAP32[$58 + 4 >> 2];
    var $60 = $vp | 0;
    HEAP32[$60 >> 2] = $59$0;
    HEAP32[$60 + 4 >> 2] = $59$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE["X"] = 1;

function __ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom354($1);
  var $3 = __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $index, $vp);
    var $_0 = $3;
    __label__ = 12;
    break;
   case 3:
    var $5 = __ZN8JSObject21getDenseArrayCapacityEv($obj);
    if ($5 >>> 0 > $index >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZN8JSObject20getDenseArrayElementEj($obj, $index);
    var $9 = __ZNK2JS5Value7isMagicE10JSWhyMagic($8, undef);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $8 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 6:
    var $15 = __ZNK8JSObject8getProtoEv($obj);
    var $16 = ($15 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($16) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $20 = HEAP32[$id >> 2];
    var $22 = HEAP32[$cx + 208 >> 2];
    var $23 = $cx;
    var $24 = $15;
    var $25 = $obj2;
    var $26 = $prop;
    var $27 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($23, $24, $20, $22, $25, $26);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $29 = HEAP32[$prop >> 2];
    if (($29 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = HEAP32[$obj2 >> 2];
    var $33 = __ZNK8JSObject8isNativeEv($32);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $35 = $obj;
    var $36 = $32;
    var $37 = $29;
    var $38 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($23, $35, $36, $37, 0, $vp);
    var $_0 = $38;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE["X"] = 1;

function __ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp);
    var $_0 = $9;
    __label__ = 13;
    break;
   case 3:
    var $11 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $obj;
    var $15 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($13, $14, $id, 0, $vp, $strict);
    var $_0 = $15;
    __label__ = 13;
    break;
   case 5:
    var $17 = __Z12js_IdIsIndexiPj($id, $i);
    if (($17 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $obj);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $23 = HEAPU32[$i >> 2];
    var $24 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $23, 1);
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($24 | 0) == 1) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $26 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($23 >>> 0 < $26 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = $23 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $29);
    __label__ = 10;
    break;
   case 10:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $23, $vp);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 11:
    var $32 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = $cx;
    var $36 = $obj;
    var $37 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($35, $36, $id, 0, $vp, $strict);
    var $_0 = $37;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = HEAP32[$id >> 2];
    var $6 = $cx;
    var $7 = $obj;
    var $8 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($6, $7, $5, 0, $vp, $strict);
    var $_0 = $8;
    __label__ = 12;
    break;
   case 4:
    if (($index | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $obj);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $index, 1);
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($15 | 0) == 1) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($17 >>> 0 > $index >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $index + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $20);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $index, $vp);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 10:
    var $23 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = HEAP32[$id >> 2];
    var $27 = $cx;
    var $28 = $obj;
    var $29 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($27, $28, $26, 0, $vp, $strict);
    var $_0 = $29;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19array_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $5);
  var $8 = ($6 | 0) != 0 ? 4 : 1;
  HEAP32[$attrsp >> 2] = $8;
  return 1;
}

function __ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL19array_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL19array_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL26array_setElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZL19array_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_idx_val);
  var $2 = __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $success, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = $props;
    var $7 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($4, $5, 24, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$success] = 1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __Z12js_IdIsIndexiPj($id, $index);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $5 = HEAPU32[$index >> 2];
    if ($5 >>> 0 < $4 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5 + 1 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $8);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = __ZNK8JSObject8numSlotsEv($obj);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($this, $cx) {
  var $1 = __ZN8JSObject21getDenseArrayCapacityEv($this);
  __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($this, $cx, $1, 0);
  return;
}

function __ZN8JSObject21getDenseArrayCapacityEv($this) {
  var $1 = __ZNK8JSObject8numSlotsEv($this);
  return $1;
}

function __ZNK8JSObject24denseArrayHasInlineSlotsEv($this) {
  var $2 = HEAP32[$this + 32 >> 2];
  var $3 = __ZNK8JSObject10fixedSlotsEv($this);
  return ($2 | 0) == ($3 | 0);
}

function __ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length) {
  __ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length);
  return;
}

function __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $obj) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom354($5);
  var $7 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($obj, $cx, $6, 58, 60, -1, 68, 0, 0);
  return ($7 | 0) != 0;
}

function __ZN2JSL10Int32ValueEi360($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js14AutoValueArrayD1Ev($this) {
  __ZN2js14AutoValueArrayD2Ev($this);
  return;
}

function __ZN2js15AutoArrayRooter12changeLengthEj($this, $newLength) {
  HEAP32[$this + 4 >> 2] = $newLength;
  return;
}

function __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($src, $nel, $elsize, $cmp, $arg, $tmp, $elemType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $msa = __stackBase__;
    var $cmp_result = __stackBase__ + 16;
    var $1 = ($elemType | 0) == 0;
    var $2 = -$elsize | 0;
    var $3 = $tmp;
    var $lo_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $lo_0;
    if ($lo_0 >>> 0 < $nel >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $6 = $lo_0 + 4 | 0;
    var $hi_0 = $6 >>> 0 < $nel >>> 0 ? $6 : $nel;
    var $i_0 = $lo_0 | 1;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $hi_0 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $lo_0 = $6;
      __label__ = 2;
      break;
    }
   case 5:
    var $12 = $i_0 * $elsize | 0;
    var $j_0 = $i_0;
    var $vec2_0 = $src + ($12 - $elsize) | 0;
    var $vec1_0 = $src + $12 | 0;
    __label__ = 6;
    break;
   case 6:
    var $vec1_0;
    var $vec2_0;
    var $j_0;
    if ($j_0 >>> 0 > $lo_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $18 = FUNCTION_TABLE[$cmp]($arg, $vec2_0, $vec1_0, $cmp_result);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$cmp_result >> 2] | 0) < 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $25 = $vec2_0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    HEAP32[$3 >> 2] = $26$0;
    HEAP32[$3 + 4 >> 2] = $26$1;
    var $27 = $vec1_0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    HEAP32[$25 >> 2] = $28$0;
    HEAP32[$25 + 4 >> 2] = $28$1;
    var $29$0 = HEAP32[$3 >> 2];
    var $29$1 = HEAP32[$3 + 4 >> 2];
    HEAP32[$27 >> 2] = $29$0;
    HEAP32[$27 + 4 >> 2] = $29$1;
    __label__ = 12;
    break;
   case 11:
    _memcpy($tmp, $vec2_0, $elsize, 1);
    _memcpy($vec2_0, $vec1_0, $elsize, 1);
    _memcpy($vec1_0, $tmp, $elsize, 1);
    __label__ = 12;
    break;
   case 12:
    var $j_0 = $j_0 - 1 | 0;
    var $vec1_0 = $vec2_0;
    var $vec2_0 = $vec2_0 + $2 | 0;
    __label__ = 6;
    break;
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 14:
    HEAP32[$msa >> 2] = $elsize;
    HEAP32[$msa + 4 >> 2] = $cmp;
    HEAP32[$msa + 8 >> 2] = $arg;
    HEAP32[$msa + 12 >> 2] = $1 & 1;
    var $run_0 = 4;
    var $vec2_1 = $tmp;
    var $vec1_1 = $src;
    __label__ = 15;
    break;
   case 15:
    var $vec1_1;
    var $vec2_1;
    var $run_0;
    if ($run_0 >>> 0 < $nel >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $43 = $run_0 << 1;
    var $lo_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $lo_1;
    if ($lo_1 >>> 0 < $nel >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $vec2_1 = $vec1_1;
      var $vec1_1$phi = $vec2_1;
      var $run_0 = $43;
      var $vec1_1 = $vec1_1$phi;
      __label__ = 15;
      break;
    }
   case 18:
    var $47 = $lo_1 + $run_0 | 0;
    var $49 = $lo_1 * $elsize | 0;
    if ($47 >>> 0 < $nel >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = $vec2_1 + $49 | 0;
    var $52 = $vec1_1 + $49 | 0;
    var $54 = ($nel - $lo_1) * $elsize | 0;
    _memcpy($51, $52, $54, 1);
    var $vec2_1 = $vec1_1;
    var $vec1_1$phi = $vec2_1;
    var $run_0 = $43;
    var $vec1_1 = $vec1_1$phi;
    __label__ = 15;
    break;
   case 20:
    var $56 = $vec1_1 + $49 | 0;
    var $57 = $vec2_1 + $49 | 0;
    var $61 = ($47 + $run_0 | 0) >>> 0 > $nel >>> 0 ? $nel - $47 | 0 : $run_0;
    var $62 = __ZL11MergeArraysP9MSortArgsPvS1_jj($msa, $56, $57, $run_0, $61);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $lo_1 = $lo_1 + $43 | 0;
    __label__ = 17;
    break;
   case 22:
    if (($vec1_1 | 0) == ($src | 0)) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $69 = $elsize * $nel | 0;
    _memcpy($src, $tmp, $69, 1);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType["X"] = 1;

function __ZL11MergeArraysP9MSortArgsPvS1_jj($msa, $src, $dest, $run1, $run2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cmp_result = __stackBase__;
    var $1 = $run2 + $run1 | 0;
    var $3 = HEAPU32[$msa >> 2];
    var $5 = HEAPU32[$msa + 4 >> 2];
    var $7 = HEAPU32[$msa + 8 >> 2];
    var $9 = HEAP32[$msa + 12 >> 2];
    var $10 = $3 * $run1 | 0;
    var $11 = $src + $10 | 0;
    var $12 = $src + ($10 - $3) | 0;
    var $13 = FUNCTION_TABLE[$5]($7, $12, $11, $cmp_result);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$cmp_result >> 2] | 0) < 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = ($9 | 0) != 0;
    var $runtotal_0 = $1;
    var $c_0 = $dest;
    var $_01 = $run1;
    var $_02 = $run2;
    var $b_0 = $11;
    var $a_0 = $src;
    __label__ = 5;
    break;
   case 4:
    var $20 = $3 * $1 | 0;
    _memcpy($dest, $src, $20, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $a_0;
    var $b_0;
    var $_02;
    var $_01;
    var $c_0;
    var $runtotal_0;
    if (($runtotal_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = ($_02 | 0) == 0;
    if ($24 | ($_01 | 0) == 0) {
      var $from_a_0 = $24 & 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = FUNCTION_TABLE[$5]($7, $a_0, $b_0, $cmp_result);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $from_a_0 = (HEAP32[$cmp_result >> 2] | 0) < 1 & 1;
    __label__ = 9;
    break;
   case 9:
    var $from_a_0;
    if (($from_a_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $38 = $a_0;
    var $39 = $c_0;
    var $st$2$0 = $38 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $39 | 0;
    HEAP32[$st$6$0 >> 2] = $40$0;
    var $st$6$1 = $39 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $40$1;
    __label__ = 13;
    break;
   case 12:
    _memcpy($c_0, $a_0, $3, 1);
    __label__ = 13;
    break;
   case 13:
    var $_1 = $_01 - 1 | 0;
    var $_13 = $_02;
    var $b_1 = $b_0;
    var $a_1 = $a_0 + $3 | 0;
    __label__ = 18;
    break;
   case 14:
    if ($18) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $47 = $b_0;
    var $48 = $c_0;
    var $st$2$0 = $47 | 0;
    var $49$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $47 + 4 | 0;
    var $49$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $48 | 0;
    HEAP32[$st$6$0 >> 2] = $49$0;
    var $st$6$1 = $48 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $49$1;
    __label__ = 17;
    break;
   case 16:
    _memcpy($c_0, $b_0, $3, 1);
    __label__ = 17;
    break;
   case 17:
    var $_1 = $_01;
    var $_13 = $_02 - 1 | 0;
    var $b_1 = $b_0 + $3 | 0;
    var $a_1 = $a_0;
    __label__ = 18;
    break;
   case 18:
    var $a_1;
    var $b_1;
    var $_13;
    var $_1;
    var $runtotal_0 = $runtotal_0 - 1 | 0;
    var $c_0 = $c_0 + $3 | 0;
    var $_01 = $_1;
    var $_02 = $_13;
    var $b_0 = $b_1;
    var $a_0 = $a_1;
    __label__ = 5;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11MergeArraysP9MSortArgsPvS1_jj["X"] = 1;

function __ZN2js10array_sortEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $fval = __stackBase__ + 4;
    var $vec = __stackBase__ + 12;
    var $free_ = __stackBase__ + 16;
    var $tvr = __stackBase__ + 24;
    var $hole = __stackBase__ + 40;
    var $ca = __stackBase__ + 44;
    var $1 = __stackBase__ + 84;
    var $2 = __stackBase__ + 92;
    var $3 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2JS5Value11isUndefinedEv($3);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value11isPrimitiveEv($3);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 12, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 57;
    break;
   case 5:
    var $11 = $3 | 0;
    var $st$1$0 = $11 | 0;
    var $12$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    var $13 = $fval | 0;
    var $st$6$0 = $13 | 0;
    HEAP32[$st$6$0 >> 2] = $12$0;
    var $st$6$1 = $13 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $12$1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value7setNullEv($fval);
    __label__ = 7;
    break;
   case 7:
    var $16 = $vp + 8 | 0;
    var $17 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $16);
    if (($17 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $17, $len);
    if (($20 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = HEAPU32[$len >> 2];
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JS5Value9setObjectER8JSObject($vp, $17);
    var $_3 = 1;
    __label__ = 57;
    break;
   case 11:
    if ($23 >>> 0 > 268435455) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_3 = 0;
    __label__ = 57;
    break;
   case 13:
    var $30 = $23 << 4;
    var $31 = __ZN9JSContext7malloc_Ej($cx, $30);
    HEAP32[$vec >> 2] = $31;
    if (($31 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_($free_, $cx, $vec);
    var $35 = HEAP32[$vec >> 2];
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $cx, 0, $35);
    var $36 = $cx + 52 | 0;
    var $allStrings_0 = 1;
    var $newlen_0 = 0;
    var $i_0 = 0;
    var $undefs_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $undefs_0;
    var $i_0;
    var $newlen_0;
    var $allStrings_0;
    if ($i_0 >>> 0 < $23 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 16:
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $45 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($45 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $48 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    __ZN2JS5Value7setNullEv($48);
    var $49 = $newlen_0 + 1 | 0;
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $49);
    var $52 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    var $53 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $17, $i_0 >>> 0, $hole, $52);
    if (($53 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $allStrings_1 = $allStrings_0;
      var $newlen_1 = $newlen_0;
      var $undefs_1 = $undefs_0;
      __label__ = 25;
      break;
    }
   case 20:
    var $60 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    var $61 = __ZNK2JS5Value11isUndefinedEv($60);
    if ($61) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $allStrings_1 = $allStrings_0;
    var $newlen_1 = $newlen_0;
    var $undefs_1 = $undefs_0 + 1 | 0;
    __label__ = 25;
    break;
   case 22:
    if (($allStrings_0 & 1) << 24 >> 24 == 0) {
      var $70 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $68 = __ZNK2JS5Value8isStringEv($60);
    var $70 = $68;
    __label__ = 24;
    break;
   case 24:
    var $70;
    var $allStrings_1 = $70 & 1;
    var $newlen_1 = $49;
    var $undefs_1 = $undefs_0;
    __label__ = 25;
    break;
   case 25:
    var $undefs_1;
    var $newlen_1;
    var $allStrings_1;
    var $allStrings_0 = $allStrings_1;
    var $newlen_0 = $newlen_1;
    var $i_0 = $i_0 + 1 | 0;
    var $undefs_0 = $undefs_1;
    __label__ = 15;
    break;
   case 26:
    if (($newlen_0 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2JS5Value9setObjectER8JSObject($vp, $17);
    var $_2 = 1;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 28:
    var $79 = HEAP32[$vec >> 2] + ($newlen_0 << 3) | 0;
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($79, $newlen_0);
    var $80 = $newlen_0 << 1;
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $80);
    var $81 = __ZNK2JS5Value6isNullEv($fval);
    if ($81) {
      __label__ = 29;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 29:
    var $84 = ($allStrings_0 & 1) << 24 >> 24 != 0;
    if ($84) {
      var $mergesort_tmp_0 = $79;
      var $elemsize_0 = 8;
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($newlen_0 >>> 0 > 134217727) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $87 = $cx;
    var $i_1 = $newlen_0;
    __label__ = 33;
    break;
   case 32:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_2 = 0;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 33:
    var $i_1;
    var $90 = $i_1 - 1 | 0;
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $96 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($96 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $99 = HEAP32[$vec >> 2] + ($90 << 3) | 0;
    var $100 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($87, $99);
    if (($100 | 0) == 0) {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $103 = $90 << 1;
    var $105 = HEAP32[$vec >> 2];
    var $106 = $99 | 0;
    var $st$4$0 = $106 | 0;
    var $107$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $106 + 4 | 0;
    var $107$1 = HEAP32[$st$4$1 >> 2];
    var $108 = $105 + (($103 | 1) << 3) | 0;
    var $st$9$0 = $108 | 0;
    HEAP32[$st$9$0 >> 2] = $107$0;
    var $st$9$1 = $108 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $107$1;
    var $109 = $105 + ($103 << 3) | 0;
    __ZN2JS5Value9setStringEP8JSString($109, $100);
    if (($90 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $i_1 = $90;
      __label__ = 33;
      break;
    }
   case 37:
    var $113 = HEAP32[$vec >> 2];
    var $115 = __ZN9JSContext8realloc_EPvj($cx, $113, $newlen_0 << 5);
    var $116 = $115;
    HEAP32[$vec >> 2] = $116;
    if (($115 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $120 = HEAP32[$tvr + 12 >> 2];
    HEAP32[$vec >> 2] = $120;
    var $_2 = 0;
    var $_16 = 1;
    __label__ = 46;
    break;
   case 39:
    var $122 = $116 + ($80 << 3) | 0;
    __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($122, $80);
    __ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj($tvr, $116, $newlen_0 << 2);
    var $mergesort_tmp_0 = $122;
    var $elemsize_0 = 16;
    __label__ = 40;
    break;
   case 40:
    var $elemsize_0;
    var $mergesort_tmp_0;
    var $126 = HEAP32[$vec >> 2];
    var $127 = $cx;
    var $129 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($126, $newlen_0, $elemsize_0, 62, $127, $mergesort_tmp_0, 1);
    if ($129) {
      __label__ = 41;
      break;
    } else {
      var $_2 = 0;
      var $_16 = 1;
      __label__ = 46;
      break;
    }
   case 41:
    if ($84) {
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $131 = HEAP32[$vec >> 2];
    var $i_2 = 0;
    __label__ = 43;
    break;
   case 43:
    var $i_2;
    var $135 = $131 + (($i_2 << 1 | 1) << 3) | 0;
    var $st$4$0 = $135 | 0;
    var $136$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $135 + 4 | 0;
    var $136$1 = HEAP32[$st$4$1 >> 2];
    var $137 = $131 + ($i_2 << 3) | 0;
    var $st$9$0 = $137 | 0;
    HEAP32[$st$9$0 >> 2] = $136$0;
    var $st$9$1 = $137 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $136$1;
    var $138 = $i_2 + 1 | 0;
    if (($138 | 0) == ($newlen_0 | 0)) {
      __label__ = 45;
      break;
    } else {
      var $i_2 = $138;
      __label__ = 43;
      break;
    }
   case 44:
    var $141 = $fval | 0;
    var $st$1$0 = $141 | 0;
    var $142$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $141 + 4 | 0;
    var $142$1 = HEAP32[$st$1$1 >> 2];
    var $143 = $1 | 0;
    var $st$6$0 = $143 | 0;
    HEAP32[$st$6$0 >> 2] = $142$0;
    var $st$6$1 = $143 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $142$1;
    __ZN11CompareArgsC1EP9JSContextN2JS5ValueE($ca, $cx, $1);
    var $145 = HEAP32[$vec >> 2];
    var $146 = $ca;
    var $147 = $79;
    var $148 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($145, $newlen_0, 8, 64, $146, $147, 0);
    var $_ = $148 & 1 ^ 1;
    __ZN11CompareArgsD1Ev($ca);
    if ($148) {
      __label__ = 45;
      break;
    } else {
      var $_2 = 0;
      var $_16 = $_;
      __label__ = 46;
      break;
    }
   case 45:
    __ZN2js15AutoArrayRooter12changeLengthEj($tvr, $newlen_0);
    var $150 = HEAP32[$vec >> 2];
    var $151 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $17, 0, $newlen_0, $150, 0);
    var $_2 = 0;
    var $_16 = ($151 | 0) == 0 & 1;
    __label__ = 46;
    break;
   case 46:
    var $_16;
    var $_2;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $free__idx_val_val = HEAP32[HEAP32[$free_ + 4 >> 2] >> 2];
    __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev($free__idx_val_val);
    if (($_16 | 0) == 1) {
      var $_3 = $_2;
      __label__ = 57;
      break;
    } else {
      var $newlen_2 = $newlen_0;
      var $undefs_2 = $undefs_0;
      __label__ = 47;
      break;
    }
   case 47:
    var $undefs_2;
    var $newlen_2;
    if (($undefs_2 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $168 = HEAP32[$len >> 2];
    __label__ = 52;
    break;
   case 49:
    var $155 = $undefs_2 - 1 | 0;
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $161 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($161 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $163 = $newlen_2 + 1 | 0;
    var $164 = $newlen_2 >>> 0;
    __ZN2JSL14UndefinedValueEv351($2);
    var $165 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $17, $164, $2);
    if (($165 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      var $newlen_2 = $163;
      var $undefs_2 = $155;
      __label__ = 47;
      break;
    }
   case 52:
    var $168;
    if ($168 >>> 0 > $newlen_2 >>> 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 53:
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $176 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($176 | 0) == 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $179 = HEAP32[$len >> 2] - 1 | 0;
    HEAP32[$len >> 2] = $179;
    var $180 = $179 >>> 0;
    var $181 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $17, $180, 1);
    if (($181 | 0) < 0) {
      var $_3 = 0;
      __label__ = 57;
      break;
    } else {
      var $168 = $179;
      __label__ = 52;
      break;
    }
   case 56:
    __ZN2JS5Value9setObjectER8JSObject($vp, $17);
    var $_3 = 1;
    __label__ = 57;
    break;
   case 57:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10array_sortEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec) {
  __ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec);
  return;
}

function __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $index, $hole, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idr = __stackBase__;
    var $obj2 = __stackBase__ + 16;
    var $prop = __stackBase__ + 20;
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($3 >>> 0 > $index) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $8 = __ZN8JSObject20getDenseArrayElementEj($obj, $7);
    var $9 = $8 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp, undef);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$hole >> 2] = 0;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 5:
    var $15 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $17 = __ZN8JSObject11asArgumentsEv($obj);
    var $18 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $19 = __ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE($17, $18, $vp);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$hole >> 2] = 0;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 8:
    var $22 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $22);
    HEAP32[$hole >> 2] = 0;
    var $23 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $24 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, $hole, $23, 0);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 9:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 11:
    var $30 = __ZN2js12AutoIdRooter2idEv($idr);
    var $31 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $30, $obj2, $prop);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$hole >> 2] = 1;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 14:
    var $38 = __ZN2js12AutoIdRooter2idEv($idr);
    var $39 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $38, $vp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$hole >> 2] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE["X"] = 1;

function __ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj($vec, $len) {
  __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412($vec, $len);
  return;
}

function __ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj($this, $newArray, $newLength) {
  __ZN2js15AutoArrayRooter12changeLengthEj($this, $newLength);
  HEAP32[$this + 12 >> 2] = $newArray;
  return;
}

function __ZL20sort_compare_stringsPvPKvS1_Pi($arg, $a, $b, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = __ZNK2JS5Value8toStringEv($1);
    var $3 = $b;
    var $4 = __ZNK2JS5Value8toStringEv($3);
    if ((HEAP32[HEAP32[$arg + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = $arg;
    var $13 = __Z26js_InvokeOperationCallbackP9JSContext($12);
    if (($13 | 0) == 0) {
      var $18 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $arg;
    var $16 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($15, $2, $4, $result);
    var $18 = $16;
    __label__ = 4;
    break;
   case 4:
    var $18;
    return $18 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompareArgsC1EP9JSContextN2JS5ValueE($this, $cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $fval = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $fval | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN11CompareArgsC2EP9JSContextN2JS5ValueE($this, $cx, $fval);
  STACKTOP = __stackBase__;
  return;
}

function __ZL12sort_comparePvPKvS1_Pi($arg, $a, $b, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cmp = __stackBase__ + 8;
    var $3 = HEAP32[$arg >> 2];
    if ((HEAP32[HEAP32[$3 + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __Z26js_InvokeOperationCallbackP9JSContext($3);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $arg + 4 | 0;
    var $13 = $12;
    var $14 = __ZNK2js15InvokeArgsGuard6pushedEv($13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $3 + 60 | 0;
    var $18 = $3;
    var $19 = $12;
    var $20 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($17, $18, 2, $19);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $22 = $12;
    var $23 = __ZNK2js12CallReceiver7calleevEv($22);
    var $25 = $arg + 32 | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $23 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = __ZNK2js12CallReceiver5thisvEv($22);
    __ZN2JSL14UndefinedValueEv351($1);
    var $29 = $1 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $28 | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $32 = $12;
    var $33 = __ZNK2js8CallArgsixEj($32, 0);
    var $34 = $a;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $33 | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $37 = __ZNK2js8CallArgsixEj($32, 1);
    var $38 = $b;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $37 | 0;
    HEAP32[$40 >> 2] = $39$0;
    HEAP32[$40 + 4 >> 2] = $39$1;
    var $41 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($3, $13, 0);
    if ($41) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $43 = __ZNK2js12CallReceiver4rvalEv($22);
    var $44 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $43, $cmp);
    if ($44) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    HEAP32[$result >> 2] = 0;
    var $46 = (tempDoubleI32[0] = HEAP32[$cmp >> 2], tempDoubleI32[1] = HEAP32[$cmp + 4 >> 2], tempDoubleF64[0]);
    var $47 = __ZL15JSDOUBLE_IS_NaNd397($46);
    if (($47 | 0) == 0 & $46 != 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $52 = $46 > 0 ? 1 : -1;
    HEAP32[$result >> 2] = $52;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12sort_comparePvPKvS1_Pi["X"] = 1;

function __ZN11CompareArgsD1Ev($this) {
  __ZN11CompareArgsD2Ev($this);
  return;
}

function __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $obj, $start, $count, $vector, $updateTypes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $idr = __stackBase__ + 24;
    var $idval = __stackBase__ + 40;
    if (($count | 0) == 0) {
      var $_1 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($updateTypes) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = $obj;
    var $5 = $cx;
    var $6 = __ZN8JSObject7getTypeEP9JSContext($4, $5);
    var $7 = $6;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $7, $vector, $count);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 23;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $12 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $obj);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $start, $count);
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($15 | 0) == 1) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = $count + $start | 0;
    var $18 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($17 >>> 0 > $18 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject19setDenseArrayLengthEj($obj, $17);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($obj, $start, $vector, $count);
    var $_1 = 1;
    __label__ = 23;
    break;
   case 10:
    var $23 = $vector + ($count << 3) | 0;
    var $24 = $cx + 52 | 0;
    var $_02 = $vector;
    var $_04 = $start;
    __label__ = 11;
    break;
   case 11:
    var $_04;
    var $_02;
    var $26 = ($_02 | 0) == ($23 | 0);
    if ($26 | ($_04 | 0) == -1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[HEAP32[$24 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = $_04 + 1 | 0;
    var $38 = $_02 + 8 | 0;
    var $39 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $_04 >>> 0, $_02);
    if (($39 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      var $_02 = $38;
      var $_04 = $36;
      __label__ = 11;
      break;
    }
   case 15:
    if ($26) {
      var $_1 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $44 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $47 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $47);
    __ZN2JSL11DoubleValueEd408($idval, 4294967295);
    var $48 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $49 = $48 | 0;
    var $50 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $_13 = $_02;
    __label__ = 19;
    break;
   case 19:
    var $_13;
    var $52 = $_13 + 8 | 0;
    var $53 = $_13 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    HEAP32[$49 >> 2] = $54$0;
    HEAP32[$49 + 4 >> 2] = $54$1;
    var $55 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval, $50);
    if ($55) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 20:
    var $57 = __ZN2js12AutoIdRooter2idEv($idr);
    var $58 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $57, $48, 1);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = __ZN2JS5Value12getDoubleRefEv($idval);
    var $62 = (tempDoubleI32[0] = HEAP32[$61 >> 2], tempDoubleI32[1] = HEAP32[$61 + 4 >> 2], tempDoubleF64[0]);
    var $63 = $62 + 1;
    tempDoubleF64[0] = $63, HEAP32[$61 >> 2] = tempDoubleI32[0], HEAP32[$61 + 4 >> 2] = tempDoubleI32[1];
    if (($52 | 0) == ($23 | 0)) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      var $_13 = $52;
      __label__ = 19;
      break;
    }
   case 22:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 23;
    break;
   case 23:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb["X"] = 1;

function __ZN2js15AutoArrayRooterD1Ev($this) {
  __ZN2js15AutoArrayRooterD2Ev($this);
  return;
}

function __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $index, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idr = __stackBase__;
    var $tmp = __stackBase__ + 16;
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    if ($index > 4294967295) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $6 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $5, 1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($6 | 0) == 1) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject14getArrayLengthEv($obj);
    if ($5 >>> 0 < $8 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $5 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $11);
    __label__ = 6;
    break;
   case 6:
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $5, $v);
    var $_1 = 1;
    __label__ = 11;
    break;
   case 7:
    var $13 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $16);
    var $17 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $18 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, 0, $17, 1);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $v | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $tmp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $23 = __ZN2js12AutoIdRooter2idEv($idr);
    var $24 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $23, $tmp, 1);
    var $_0 = $24;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $index, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $idr = __stackBase__ + 8;
    var $v = __stackBase__ + 24;
    var $2 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ($index > 4294967295) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $index >= 0 ? Math.floor($index) : Math.ceil($index);
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($6 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj, $6, $1);
    var $10 = $6 + 1 | 0;
    var $11 = $cx;
    var $12 = $obj;
    var $13 = __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($11, $12, $6, $10);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_1 = -1;
      __label__ = 11;
      break;
    }
   case 5:
    var $_1 = 1;
    __label__ = 11;
    break;
   case 6:
    var $16 = _INT_TO_JSID398(0);
    __ZN2js12AutoIdRooterC1EP9JSContexti($idr, $cx, $16);
    var $17 = __ZN2js12AutoIdRooter4addrEv($idr);
    var $18 = __ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i($cx, $obj, $index, 0, $17, 0);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = -1;
      __label__ = 10;
      break;
    }
   case 7:
    var $20 = __ZN2js12AutoIdRooter2idEv($idr);
    var $21 = _JSID_IS_VOID($20);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 8:
    var $24 = $strict & 1;
    var $25 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $20, $v, $24);
    if (($25 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = __ZNK2JS5Value6isTrueEv($v);
    var $_0 = $28 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($idr);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $vp) {
  var $1 = __Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $vp);
  return $1;
}

function __Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $2 = __ZNK8JSObject11isSlowArrayEv($obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $1, $id);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $12 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = HEAP32[$id >> 2];
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($7, $8, $6, $v, 0, 0, 1);
    var $12 = ($9 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $12;
    var $_0 = $12 & 1;
    __label__ = 10;
    break;
   case 5:
    var $15 = __ZN8JSObject21getDenseArrayCapacityEv($obj);
    if (($1 | 0) == ($15 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = $1 + 1 | 0;
    var $19 = __ZN8JSObject11ensureSlotsEP9JSContextj($obj, $cx, $18);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $21 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    var $22 = $1 + 1 | 0;
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $22);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject19setDenseArrayLengthEj($obj, $22);
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $1, $v);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10array_pushEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $vp + 16 | 0;
    var $10 = __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $2, $argc, $9, $vp);
    var $_0 = $10;
    __label__ = 6;
    break;
   case 5:
    var $12 = $vp + 16 | 0;
    var $13 = __ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_($cx, $2, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $1 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $length);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$length >> 2];
    var $5 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $obj, $4, $argc, $argv, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($4 >>> 0) + ($argc >>> 0);
    var $11 = __ZN2JS5Value9setNumberEd($rval, $10);
    var $12 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $10);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_($cx, $obj, $v, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $2 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($obj, $cx, $1, 1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $1 + 1 | 0;
    __ZN8JSObject19setDenseArrayLengthEj($obj, $4);
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj, $cx, $1, $v);
    var $5 = __ZNK8JSObject14getArrayLengthEv($obj);
    var $6 = __ZN2JS5Value9setNumberEj($rval, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $8 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($obj, $cx);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $tmp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, 1, $tmp, $rval);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9array_popEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE($cx, $2, $vp);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE($cx, $2, $vp);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $1 = __ZNK8JSObject14getArrayLengthEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 3:
    var $5 = $1 - 1 | 0;
    var $6 = $5 >>> 0;
    var $7 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $6, $hole, $vp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $6, 1);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $18 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($18 >>> 0 > $5 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $5);
    __label__ = 9;
    break;
   case 9:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $5);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $1 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $index);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$index >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $19 = $4;
    __label__ = 7;
    break;
   case 4:
    var $8 = $4 - 1 | 0;
    HEAP32[$index >> 2] = $8;
    var $9 = $8 >>> 0;
    var $10 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $9, $hole, $vp);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $19 = $8;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $9, 1);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $19 = $8;
      __label__ = 7;
      break;
    }
   case 7:
    var $19;
    var $21 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $obj, $19 >>> 0);
    var $_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14array_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detector = __stackBase__ + 4;
    var $sb = __stackBase__ + 20;
    var $length = __stackBase__ + 100;
    var $hole = __stackBase__ + 104;
    var $tmp = __stackBase__ + 108;
    var $1 = __stackBase__ + 116;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_2 = 0;
    __label__ = 31;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $9 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $8);
    if (($9 | 0) == 0) {
      var $_2 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject7isArrayEv($9);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10ArrayClassE);
    var $_2 = 0;
    __label__ = 31;
    break;
   case 6:
    __ZN18ArraySharpDetectorC1EP9JSContext($detector, $cx);
    var $15 = __ZN18ArraySharpDetector4initEP8JSObject($detector, $9);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $17 = __ZNK18ArraySharpDetector14initiallySharpEv($detector);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = __ZN18ArraySharpDetector14takeSharpCharsEv($detector);
    var $20 = __Z9js_strlenPKt($19);
    __ZN2js12StringBuffer16replaceRawBufferEPtj($sb, $19, $20);
    __label__ = 27;
    break;
   case 9:
    var $22 = __ZNK18ArraySharpDetector13hasSharpCharsEv($detector);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN18ArraySharpDetector9makeSharpEv($detector);
    var $24 = __ZN18ArraySharpDetector14takeSharpCharsEv($detector);
    var $25 = __Z9js_strlenPKt($24);
    __ZN2js12StringBuffer16replaceRawBufferEPtj($sb, $24, $25);
    __label__ = 11;
    break;
   case 11:
    var $27 = __ZN2js12StringBuffer6appendEt($sb, 91);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 12:
    var $29 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $9, $length);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $31 = HEAPU32[$length >> 2];
    var $32 = $cx + 52 | 0;
    var $33 = $cx;
    var $index_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $index_0;
    if ($index_0 >>> 0 < $31 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 15:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $9, $index_0 >>> 0, $hole, $tmp);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $str_0 = HEAP32[HEAP32[$32 >> 2] + 144136 >> 2] | 0;
    __label__ = 21;
    break;
   case 20:
    var $55 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($33, $tmp);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      var $str_0 = $55;
      __label__ = 21;
      break;
    }
   case 21:
    var $str_0;
    var $58 = __ZN2js12StringBuffer6appendEP8JSString($sb, $str_0);
    if ($58) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 22:
    var $60 = $index_0 + 1 | 0;
    if (($60 | 0) == ($31 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($sb, STRING_TABLE.__str332706);
    if ($63) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $68 = __ZN2js12StringBuffer6appendEt($sb, 44);
    if ($68) {
      var $index_0 = $60;
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 26:
    var $70 = __ZN2js12StringBuffer6appendEt($sb, 93);
    if ($70) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 27:
    var $72 = $sb;
    var $73 = __ZN2js12StringBuffer12finishStringEv($72);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $76 = $73 | 0;
    __ZN2JSL11StringValueEP8JSString406($1, $76);
    var $77 = $1 | 0;
    var $78$0 = HEAP32[$77 >> 2];
    var $78$1 = HEAP32[$77 + 4 >> 2];
    var $79 = $vp | 0;
    HEAP32[$79 >> 2] = $78$0;
    HEAP32[$79 + 4 >> 2] = $78$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    __ZN18ArraySharpDetectorD1Ev($detector);
    var $_2 = $_1;
    __label__ = 31;
    break;
   case 31:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14array_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14array_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_1 = 0;
    __label__ = 12;
    break;
   case 3:
    var $7 = $vp + 8 | 0;
    var $8 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $7);
    if (($8 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210248 >> 2];
    var $15 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($8, $cx, $14, $vp);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZL13js_IsCallableRKN2JS5ValueE405($vp);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $cx;
    var $21 = $8;
    var $22 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($20, $21);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $22);
    var $_1 = 1;
    __label__ = 12;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $27 = $cx + 60 | 0;
    var $28 = $cx;
    var $29 = $args;
    var $30 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($27, $28, 0, $29);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $32 = $args | 0;
    var $33 = __ZNK2js12CallReceiver7calleevEv($32);
    var $34 = $vp | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $33 | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $37 = __ZNK2js12CallReceiver5thisvEv($32);
    __ZN2JS5Value9setObjectER8JSObject($37, $8);
    var $38 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($38) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $40 = __ZNK2js12CallReceiver4rvalEv($32);
    var $41 = $40 | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    HEAP32[$34 >> 2] = $42$0;
    HEAP32[$34 + 4 >> 2] = $42$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14array_toStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = $vp + 8 | 0;
    var $8 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $8, 1, 0, $vp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10array_joinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    if (($argc | 0) == 0) {
      var $str_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $vp + 16 | 0;
    var $10 = __ZNK2JS5Value11isUndefinedEv($9);
    if ($10) {
      var $str_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $cx;
    var $13 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($12, $9);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value9setStringEP8JSString($9, $13);
    var $str_0 = $13;
    __label__ = 7;
    break;
   case 7:
    var $str_0;
    var $17 = $vp + 8 | 0;
    var $18 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $18, 0, $str_0, $vp);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13array_reverseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $origlo = __stackBase__ + 4;
    var $orighi = __stackBase__ + 12;
    var $tvr = __stackBase__ + 20;
    var $hole = __stackBase__ + 44;
    var $hole2 = __stackBase__ + 48;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $2, $len);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $8 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $10 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $2);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 5:
    var $13 = HEAP32[$len >> 2];
    if (($13 | 0) == 0) {
      var $_1 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN8JSObject21getDenseArrayCapacityEv($2);
    if (($16 | 0) == 0) {
      var $_1 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($2, $cx, $13, 0);
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($19 | 0) == 1) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    __ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj($2, $cx, $13, 0);
    var $21 = $origlo | 0;
    var $22 = $orighi | 0;
    var $23 = $cx;
    var $24 = $2;
    var $hi_0_in = $13;
    var $lo_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $lo_0;
    var $hi_0_in;
    var $hi_0 = $hi_0_in - 1 | 0;
    if ($lo_0 >>> 0 < $hi_0 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 1;
      __label__ = 26;
      break;
    }
   case 10:
    var $28 = __ZN8JSObject20getDenseArrayElementEj($2, $lo_0);
    var $29 = $28 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    HEAP32[$21 >> 2] = $30$0;
    HEAP32[$21 + 4 >> 2] = $30$1;
    var $31 = __ZN8JSObject20getDenseArrayElementEj($2, $hi_0);
    var $32 = $31 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    HEAP32[$22 >> 2] = $33$0;
    HEAP32[$22 + 4 >> 2] = $33$1;
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($2, $lo_0, $orighi);
    var $34 = __ZNK2JS5Value7isMagicE10JSWhyMagic($orighi, undef);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $36 = _INT_TO_JSID398($lo_0);
    var $37 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($23, $24, $36);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 12:
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($2, $hi_0, $origlo);
    var $39 = __ZNK2JS5Value7isMagicE10JSWhyMagic($origlo, undef);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $41 = _INT_TO_JSID398($hi_0);
    var $42 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($23, $24, $41);
    if ($42) {
      __label__ = 14;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 14:
    var $hi_0_in = $hi_0;
    var $lo_0 = $lo_0 + 1 | 0;
    __label__ = 9;
    break;
   case 15:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $45 = HEAPU32[$len >> 2];
    var $46 = $45 >>> 1;
    var $47 = $cx + 52 | 0;
    var $i_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if ($i_0 >>> 0 < $46 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 17:
    if ((HEAP32[HEAP32[$47 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $56 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = $i_0 >>> 0;
    var $59 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $60 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $58, $hole, $59);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $65 = ($45 + ($i_0 ^ -1) | 0) >>> 0;
    var $66 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $65, $hole2, $vp);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $69 = HEAP32[$hole >> 2];
    var $70 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $71 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $65, $69, $70);
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $74 = HEAP32[$hole2 >> 2];
    var $75 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $58, $74, $vp);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 16;
    break;
   case 24:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13array_reverseP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11array_shiftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $hole = __stackBase__ + 12;
    var $tvr = __stackBase__ + 16;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $76 = $9;
    __label__ = 26;
    break;
   case 5:
    var $13 = $9 - 1 | 0;
    HEAP32[$length >> 2] = $13;
    var $14 = __ZNK8JSObject12isDenseArrayEv($3);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 6:
    var $16 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $3);
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject21getDenseArrayCapacityEv($3);
    if ($13 >>> 0 < $19 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    var $22 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    if (($22 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZN8JSObject20getDenseArrayElementEj($3, 0);
    var $26 = $25 | 0;
    var $27$0 = HEAP32[$26 >> 2];
    var $27$1 = HEAP32[$26 + 4 >> 2];
    var $28 = $vp | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $29 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp, undef);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 11;
    break;
   case 11:
    __ZN8JSObject22moveDenseArrayElementsEjjj($3, 0, 1, $13);
    var $32 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($32) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $34 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    var $35 = $34 - 1 | 0;
    __ZN8JSObject30setDenseArrayInitializedLengthEj($3, $35);
    __label__ = 14;
    break;
   case 13:
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($3, $13, $1);
    __label__ = 14;
    break;
   case 14:
    __ZN8JSObject14setArrayLengthEP9JSContextj($3, $cx, $13);
    var $38 = _INT_TO_JSID398($13);
    var $39 = $cx;
    var $40 = $3;
    var $41 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($39, $40, $38);
    var $_1 = $41 & 1;
    __label__ = 27;
    break;
   case 15:
    var $43 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, 0, $hole, $vp);
    if (($43 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $46 = $cx + 52 | 0;
    var $i_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 18:
    if ((HEAP32[HEAP32[$46 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($55 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $57 = $i_0 + 1 | 0;
    var $58 = $57 >>> 0;
    var $59 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $60 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $58, $hole, $59);
    if (($60 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $63 = $i_0 >>> 0;
    var $64 = HEAP32[$hole >> 2];
    var $65 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $66 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $3, $63, $64, $65);
    if (($66 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $i_0 = $57;
      __label__ = 17;
      break;
    }
   case 22:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $72 = $13 >>> 0;
    var $73 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $3, $72, 1);
    if (($73 | 0) < 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 27;
    break;
   case 25:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $76 = HEAP32[$length >> 2];
    __label__ = 26;
    break;
   case 26:
    var $76;
    var $78 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $3, $76 >>> 0);
    var $_1 = $78;
    __label__ = 27;
    break;
   case 27:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_shiftP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13array_unshiftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $length = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    var $10 = $9 >>> 0;
    if (($argc | 0) == 0) {
      var $newlen_0 = $10;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $vp + 16 | 0;
    if (($9 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK8JSObject12isDenseArrayEv($3);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $18 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $3);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $21 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($3, $cx, $9, $argc);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($21 | 0) == 1) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    __ZN8JSObject22moveDenseArrayElementsEjjj($3, $argc, 0, $9);
    var $i_08 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_08;
    __ZN2JSL10MagicValueE10JSWhyMagic($1);
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($3, $i_08, $1);
    var $22 = $i_08 + 1 | 0;
    if (($22 | 0) == ($argc | 0)) {
      __label__ = 17;
      break;
    } else {
      var $i_08 = $22;
      __label__ = 9;
      break;
    }
   case 10:
    var $24 = $10 + ($argc >>> 0);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $25 = $cx + 52 | 0;
    var $upperIndex_0 = $24;
    var $last_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $last_0;
    var $upperIndex_0;
    var $27 = $last_0 - 1;
    var $28 = $upperIndex_0 - 1;
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $37 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $27, $hole, $36);
    if (($37 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = HEAP32[$hole >> 2];
    var $41 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $42 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $3, $28, $40, $41);
    if (($42 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($27 != 0) {
      var $upperIndex_0 = $28;
      var $last_0 = $27;
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    __label__ = 17;
    break;
   case 17:
    var $47 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $3, 0, $argc, $13, 1);
    if (($47 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $newlen_0 = $10 + ($argc >>> 0);
    __label__ = 19;
    break;
   case 19:
    var $newlen_0;
    var $53 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $3, $newlen_0);
    if (($53 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $56 = __ZN2JS5Value9setNumberEd($vp, $newlen_0);
    var $_1 = 1;
    __label__ = 24;
    break;
   case 21:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 22:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 23:
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13array_unshiftP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12array_spliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($2, $5);
    __ZN2JS5Value9setObjectER8JSObject($vp, $5);
    if (($argc | 0) == 0) {
      var $_1 = 1;
      __label__ = 69;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $2, $length);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = HEAPU32[$length >> 2];
    var $15 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $13, $d);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 6:
    var $17 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $19 = $14 >>> 0;
    if ($17 < 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $17 + $19;
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($21 < 0) {
      __label__ = 8;
      break;
    } else {
      var $28 = $21;
      __label__ = 11;
      break;
    }
   case 8:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 11;
    break;
   case 9:
    if ($17 > $19) {
      __label__ = 10;
      break;
    } else {
      var $28 = $17;
      __label__ = 11;
      break;
    }
   case 10:
    tempDoubleF64[0] = $19, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $19;
    __label__ = 11;
    break;
   case 11:
    var $28;
    var $29 = $28 >= 0 ? Math.floor($28) : Math.ceil($28);
    var $30 = $vp + 24 | 0;
    var $31 = $14 - $29 | 0;
    if (($argc | 0) == 1) {
      var $_03 = 0;
      var $argv_0 = $30;
      var $end_0 = $14;
      var $count_0 = $31;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $30, $d);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 69;
      break;
    }
   case 13:
    var $36 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($36 < 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = 0;
    __label__ = 17;
    break;
   case 15:
    var $40 = $31 >>> 0;
    if ($36 > $40) {
      __label__ = 16;
      break;
    } else {
      var $44 = $36;
      __label__ = 17;
      break;
    }
   case 16:
    tempDoubleF64[0] = $40, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = $40;
    __label__ = 17;
    break;
   case 17:
    var $44;
    var $45 = $44 >= 0 ? Math.floor($44) : Math.ceil($44);
    var $_03 = $argc - 2 | 0;
    var $argv_0 = $vp + 32 | 0;
    var $end_0 = $45 + $29 | 0;
    var $count_0 = $45;
    __label__ = 18;
    break;
   case 18:
    var $count_0;
    var $end_0;
    var $argv_0;
    var $_03;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    if (($count_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($52) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $cx + 52 | 0;
    var $last_0 = $29;
    __label__ = 24;
    break;
   case 21:
    var $55 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $2);
    if (($55 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 22:
    var $58 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($end_0 >>> 0 > $58 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $61 = __ZN8JSObject21getDenseArrayElementsEv($2);
    var $62 = $61 + ($29 << 3) | 0;
    var $63 = __ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE($cx, $5, $count_0, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 24:
    var $last_0;
    if ($last_0 >>> 0 < $end_0 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 25:
    if ((HEAP32[HEAP32[$53 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $73 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $75 = $last_0 >>> 0;
    var $76 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $77 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $75, $hole, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $84 = ($last_0 - $29 | 0) >>> 0;
    var $85 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $86 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $5, $84, $85);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $last_0 = $last_0 + 1 | 0;
    __label__ = 24;
    break;
   case 31:
    var $92 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $5, $count_0 >>> 0);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ($_03 >>> 0 > $count_0 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 33:
    var $97 = $_03 - $count_0 | 0;
    var $98 = HEAPU32[$length >> 2];
    var $99 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($99) {
      __label__ = 34;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 34:
    var $101 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $2);
    if (($101 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $104 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($98 >>> 0 > $104 >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($98 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $109 = $98 - 1 | 0;
    var $110 = __ZN8JSObject20getDenseArrayElementEj($2, $109);
    var $111 = __ZNK2JS5Value7isMagicE10JSWhyMagic($110, undef);
    if ($111) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $112 = $cx + 52 | 0;
    var $last_1 = $98;
    __label__ = 41;
    break;
   case 39:
    var $114 = __ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj($2, $cx, $98, $97);
    if (($114 | 0) == 0) {
      __label__ = 40;
      break;
    } else if (($114 | 0) == 1) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 40:
    var $116 = $98 - $end_0 | 0;
    __ZN8JSObject22moveDenseArrayElementsEjjj($2, $97 + $end_0 | 0, $end_0, $116);
    var $117 = __ZNK8JSObject14getArrayLengthEv($2);
    var $118 = $117 + $97 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $118);
    var $140 = $98;
    __label__ = 47;
    break;
   case 41:
    var $last_1;
    var $119 = $last_1 - 1 | 0;
    if ($last_1 >>> 0 > $end_0 >>> 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 42:
    if ((HEAP32[HEAP32[$112 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $127 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($127 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $129 = $119 >>> 0;
    var $130 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $131 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $129, $hole, $130);
    if (($131 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $135 = ($119 + $97 | 0) >>> 0;
    var $136 = HEAP32[$hole >> 2];
    var $137 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $138 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $135, $136, $137);
    if (($138 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      var $last_1 = $119;
      __label__ = 41;
      break;
    }
   case 46:
    var $140 = HEAP32[$length >> 2];
    __label__ = 47;
    break;
   case 47:
    var $140;
    var $141 = $140 + $97 | 0;
    HEAP32[$length >> 2] = $141;
    var $185 = $141;
    __label__ = 63;
    break;
   case 48:
    if ($_03 >>> 0 < $count_0 >>> 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $185 = HEAP32[$length >> 2];
    __label__ = 63;
    break;
   case 50:
    var $145 = $count_0 - $_03 | 0;
    var $146 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($146) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $147 = HEAPU32[$length >> 2];
    var $148 = $cx + 52 | 0;
    var $last_2 = $end_0;
    __label__ = 55;
    break;
   case 52:
    var $150 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $2);
    if (($150 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 53:
    var $153 = HEAPU32[$length >> 2];
    var $154 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    if ($153 >>> 0 > $154 >>> 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $158 = $153 - $end_0 | 0;
    __ZN8JSObject22moveDenseArrayElementsEjjj($2, $end_0 - $145 | 0, $end_0, $158);
    var $182 = $153;
    __label__ = 62;
    break;
   case 55:
    var $last_2;
    if ($last_2 >>> 0 < $147 >>> 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 56:
    if ((HEAP32[HEAP32[$148 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $167 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($167 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $169 = $last_2 >>> 0;
    var $170 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $171 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $2, $169, $hole, $170);
    if (($171 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $175 = ($last_2 - $145 | 0) >>> 0;
    var $176 = HEAP32[$hole >> 2];
    var $177 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $178 = __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $2, $175, $176, $177);
    if (($178 | 0) == 0) {
      var $_0 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $last_2 = $last_2 + 1 | 0;
    __label__ = 55;
    break;
   case 61:
    var $182 = HEAP32[$length >> 2];
    __label__ = 62;
    break;
   case 62:
    var $182;
    var $183 = $182 - $145 | 0;
    HEAP32[$length >> 2] = $183;
    var $185 = $183;
    __label__ = 63;
    break;
   case 63:
    var $185;
    if ($185 >>> 0 < $14 >>> 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    var $188 = $cx;
    var $189 = $2;
    var $190 = __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($188, $189, $185, $14);
    if ($190) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 68;
      break;
    }
   case 65:
    var $192 = __ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb($cx, $2, $29, $_03, $argv_0, 1);
    if (($192 | 0) == 0) {
      var $199 = 0;
      __label__ = 67;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $196 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $2, $185 >>> 0);
    var $199 = ($196 | 0) != 0;
    __label__ = 67;
    break;
   case 67:
    var $199;
    var $_0 = $199 & 1;
    __label__ = 68;
    break;
   case 68:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 69;
    break;
   case 69:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12array_spliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE382($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject30setDenseArrayInitializedLengthEj($this, $length) {
  HEAP32[$this + 16 >> 2] = $length;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb374($numSlots, $isArray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $isArray ? 0 : 10;
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12array_concatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $alength = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $tmp = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject14getArrayLengthEv($2);
    var $8 = __ZN8JSObject21getDenseArrayElementsEv($2);
    var $9 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    var $10 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $9, $8, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($2, $10);
    __ZN8JSObject14setArrayLengthEP9JSContextj($10, $cx, $7);
    var $13 = __ZN8JSObject18isPackedDenseArrayEv($2);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($10, $cx);
    __label__ = 6;
    break;
   case 6:
    __ZN2JS5Value9setObjectER8JSObject($vp, $10);
    if (($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_02 = $argc - 1 | 0;
    var $p_0 = $vp + 16 | 0;
    var $nobj_0 = $10;
    var $length_0 = $7;
    __label__ = 10;
    break;
   case 8:
    var $21 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $21);
    var $_02 = $argc;
    var $p_0 = $1;
    var $nobj_0 = $21;
    var $length_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $length_0;
    var $nobj_0;
    var $p_0;
    var $_02;
    var $25 = $cx + 52 | 0;
    var $i_0 = 0;
    var $length_1 = $length_0;
    __label__ = 11;
    break;
   case 11:
    var $length_1;
    var $i_0;
    if ($i_0 >>> 0 > $_02 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = $p_0 + ($i_0 << 3) | 0;
    var $37 = __ZNK2JS5Value8isObjectEv($36);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $39 = __ZNK2JS5Value8toObjectEv($36);
    var $40 = __ZNK8JSObject7isArrayEv($39);
    if ($40) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZNK8JSObject9isWrapperEv($39);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 17:
    var $44 = __ZN8JSObject6unwrapEPj($39, 0);
    var $45 = __ZNK8JSObject7isArrayEv($44);
    if ($45) {
      __label__ = 18;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $47 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $39, $alength);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$alength >> 2];
    var $slot_0 = 0;
    __label__ = 20;
    break;
   case 20:
    var $slot_0;
    if ($slot_0 >>> 0 < $49 >>> 0) {
      __label__ = 21;
      break;
    } else {
      var $_pn = $49;
      __label__ = 28;
      break;
    }
   case 21:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $58 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $61 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $39, $slot_0 >>> 0, $hole, $tmp);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $69 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $nobj_0, ($slot_0 + $length_1 | 0) >>> 0, $tmp);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $slot_0 = $slot_0 + 1 | 0;
    __label__ = 20;
    break;
   case 27:
    var $75 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $nobj_0, $length_1 >>> 0, $36);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      var $_pn = 1;
      __label__ = 28;
      break;
    }
   case 28:
    var $_pn;
    var $i_0 = $i_0 + 1 | 0;
    var $length_1 = $_pn + $length_1 | 0;
    __label__ = 11;
    break;
   case 29:
    var $80 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $nobj_0, $length_1 >>> 0);
    var $_0 = $80;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12array_concatP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11array_sliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $1 = $vp + 16 | 0;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($argc | 0) == 0) {
      var $end_0 = $9;
      var $begin_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $1, $d);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $14 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $16 = $9 >>> 0;
    if ($14 < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $18 = $14 + $16;
    tempDoubleF64[0] = $18, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($18 < 0) {
      __label__ = 7;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 7:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $25 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($14 > $16) {
      __label__ = 9;
      break;
    } else {
      var $25 = $14;
      __label__ = 10;
      break;
    }
   case 9:
    tempDoubleF64[0] = $16, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $25 = $16;
    __label__ = 10;
    break;
   case 10:
    var $25;
    var $26 = $25 >= 0 ? Math.floor($25) : Math.ceil($25);
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      var $end_0 = $9;
      var $begin_0 = $26;
      __label__ = 19;
      break;
    }
   case 11:
    var $29 = $vp + 24 | 0;
    var $30 = __ZNK2JS5Value11isUndefinedEv($29);
    if ($30) {
      var $end_0 = $9;
      var $begin_0 = $26;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $29, $d);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 13:
    var $34 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($34 < 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $37 = $34 + $16;
    tempDoubleF64[0] = $37, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($37 < 0) {
      __label__ = 15;
      break;
    } else {
      var $44 = $37;
      __label__ = 18;
      break;
    }
   case 15:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = 0;
    __label__ = 18;
    break;
   case 16:
    if ($34 > $16) {
      __label__ = 17;
      break;
    } else {
      var $44 = $34;
      __label__ = 18;
      break;
    }
   case 17:
    tempDoubleF64[0] = $16, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $44 = $16;
    __label__ = 18;
    break;
   case 18:
    var $44;
    var $45 = $44 >= 0 ? Math.floor($44) : Math.ceil($44);
    var $end_0 = $45;
    var $begin_0 = $26;
    __label__ = 19;
    break;
   case 19:
    var $begin_0;
    var $end_0;
    var $begin_1 = $begin_0 >>> 0 > $end_0 >>> 0 ? $end_0 : $begin_0;
    var $48 = __ZNK8JSObject12isDenseArrayEv($3);
    if ($48) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    var $50 = __ZN8JSObject30getDenseArrayInitializedLengthEv($3);
    if ($end_0 >>> 0 > $50 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $53 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $3);
    if (($53 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    var $56 = $end_0 - $begin_1 | 0;
    var $57 = __ZN8JSObject21getDenseArrayElementsEv($3);
    var $58 = $57 + ($begin_1 << 3) | 0;
    var $59 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $56, $58, 0);
    if (($59 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($3, $59);
    var $62 = __ZN8JSObject18isPackedDenseArrayEv($3);
    if ($62) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($59, $cx);
    __label__ = 25;
    break;
   case 25:
    __ZN2JS5Value9setObjectER8JSObject($vp, $59);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 26:
    var $67 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $end_0 - $begin_1 | 0, 0);
    if (($67 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZL17TryReuseArrayTypeP8JSObjectS0_($3, $67);
    __ZN2JS5Value9setObjectER8JSObject($vp, $67);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $70 = $cx + 52 | 0;
    var $slot_0 = $begin_1;
    __label__ = 28;
    break;
   case 28:
    var $slot_0;
    if ($slot_0 >>> 0 < $end_0 >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 35;
      break;
    }
   case 29:
    if ((HEAP32[HEAP32[$70 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $79 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $81 = $slot_0 >>> 0;
    var $82 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $83 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $81, $hole, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $90 = ($slot_0 - $begin_1 | 0) >>> 0;
    var $91 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $92 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $67, $90, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $slot_0 = $slot_0 + 1 | 0;
    __label__ = 28;
    break;
   case 35:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 36;
    break;
   case 36:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_sliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13array_indexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, 1, $argc, $vp);
  return $1;
}

function __ZL13array_forEachP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL9array_mapP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 3, $argc, $vp);
  return $1;
}

function __ZL12array_reduceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 1, $argc, $vp);
  return $1;
}

function __ZL17array_reduceRightP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 2, $argc, $vp);
  return $1;
}

function __ZL12array_filterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 4, $argc, $vp);
  return $1;
}

function __ZL10array_someP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 5, $argc, $vp);
  return $1;
}

function __ZL11array_everyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, 6, $argc, $vp);
  return $1;
}

function __ZL13array_isArrayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      var $14 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZNK2JS5Value8isObjectEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $14 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($3);
    var $7 = __ZNK8JSObject7isArrayEv($6);
    if ($7) {
      var $14 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK8JSObject9isWrapperEv($6);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $14 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = __ZN8JSObject6unwrapEPj($6, 0);
    var $12 = __ZNK8JSObject7isArrayEv($11);
    var $14 = $12;
    __label__ = 6;
    break;
   case 6:
    var $14;
    __ZN2JS5Value10setBooleanEb($vp, $14);
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z8js_ArrayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, 3);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    if (($argc | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8isNumberEv($5);
    if ($7) {
      __label__ = 10;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $1, $_pre_phi, $argc);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    var $16 = $12;
    __label__ = 8;
    break;
   case 7:
    var $14 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $argc, $_pre_phi, 0);
    var $16 = $14;
    __label__ = 8;
    break;
   case 8:
    var $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($16, $1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $16);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $20 = __ZNK2JS5Value7isInt32Ev($5);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $22 = __ZNK2JS5Value7toInt32Ev($5);
    if (($22 | 0) < 0) {
      __label__ = 12;
      break;
    } else {
      var $length_0 = $22;
      __label__ = 15;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 13:
    var $26 = __ZNK2JS5Value8toDoubleEv($5);
    var $27 = __Z21js_DoubleToECMAUint32d($26);
    if ($26 != $27 >>> 0) {
      __label__ = 14;
      break;
    } else {
      var $length_0 = $27;
      __label__ = 15;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($cx, 2, 0, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 15:
    var $length_0;
    var $32 = __ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject($cx, $length_0, 0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($32, $1);
    var $35 = __ZNK8JSObject14getArrayLengthEv($32);
    if (($35 | 0) < 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN8JSObject14setArrayLengthEP9JSContextj($32, $cx, $35);
    __label__ = 18;
    break;
   case 18:
    __ZN2JS5Value9setObjectER8JSObject($vp, $32);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z8js_ArrayP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cx + 60 | 0;
    var $4 = __ZNK2js12ContextStack13currentScriptEPPh($3, $pc);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$pc >> 2];
    var $8 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $4, $7, $key);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $10 = __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $key);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $type, $vector, $count) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = __ZN2js5types10TypeObject17unknownPropertiesEv($type);
    if ($4) {
      var $_1 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $6 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($type, $cx, 2, 1);
    if (($6 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($count | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $i_02 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $i_02;
    var $9 = $vector + ($i_02 << 3) | 0;
    var $10 = __ZNK2JS5Value7isMagicE10JSWhyMagic($9, undef);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $9);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($6, $cx, $1);
    __label__ = 7;
    break;
   case 7:
    var $13 = $i_02 + 1 | 0;
    if (($13 | 0) == ($count | 0)) {
      __label__ = 8;
      break;
    } else {
      var $i_02 = $13;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 1;
    __label__ = 10;
    break;
   case 9:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, $proto) {
  var $1 = __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, 0, $proto);
  return $1;
}

function __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $length, $vp, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = ($vp | 0) != 0 ? $length : 0;
    __ZN8JSObject30setDenseArrayInitializedLengthEj($1, $7);
    __label__ = 4;
    break;
   case 4:
    if (($vp | 0) == 0) {
      var $_0 = $1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($1, 0, $vp, $length);
    var $_0 = $1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject($cx, $length, $proto) {
  var $1 = __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto);
  return $1;
}

function __ZN8JSObject14setArrayLengthEP9JSContextj($this, $cx, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($length | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $this, 196608);
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom354($8);
    __ZN2js5types4Type10DoubleTypeEv($1);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $9, $1);
    __label__ = 3;
    break;
   case 3:
    var $11 = $length;
    __ZN8JSObject10setPrivateEPv($this, $11);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_InitArrayClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js14SlowArrayClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $6);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    __ZN8JSObject14setArrayLengthEP9JSContextj($6, $cx, 0);
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 210032 >> 2];
    var $16 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 66, __ZN2js10ArrayClassE, $15, 1);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 1);
    var $20 = $16;
    var $21 = $16 | 0;
    var $22 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $21, $5);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $24 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL13array_methods);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $21, 0, __ZL20array_static_methods);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 3, $20, $6);
    var $_ = $28 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, $key, $ctor, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($key << 2) >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom354($11);
    var $13 = $global | 0;
    __ZN2JSL11ObjectValueER8JSObject383($1, $ctor);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $key, $1);
    var $14 = $key + 37 | 0;
    __ZN2JSL11ObjectValueER8JSObject383($2, $proto);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $14, $2);
    __ZN2JSL11ObjectValueER8JSObject383($3, $ctor);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $13, $12, $3);
    var $15 = $key + 74 | 0;
    var $16 = $global;
    var $17 = $cx;
    var $18 = __ZN8JSObject15addDataPropertyEP9JSContextijj($16, $17, $12, $15, 0);
    if (($18 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv351($4);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $key, $4);
    __ZN2JSL14UndefinedValueEv351($5);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $14, $5);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject383($6, $ctor);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($13, $15, $6);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17GuessObjectGCKindEjb($length);
    var $2 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js10ArrayClassE, $proto, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $length);
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($5) {
      var $_0 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($2, $cx);
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($2, $cx);
    var $_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $length, $proto) {
  var $1 = __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto);
  return $1;
}

function __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17GuessObjectGCKindEjb($length);
    var $2 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js10ArrayClassE, $proto, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject14setArrayLengthEP9JSContextj($2, $cx, $length);
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($2, $cx);
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($2, $cx);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN8JSObject11ensureSlotsEP9JSContextj($2, $cx, $length);
    var $_ = $8 ? $2 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js27NewDenseAllocatedEmptyArrayEP9JSContextjP8JSObject($cx, $length, $proto) {
  var $1 = __ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_($cx, $length, $proto);
  return $1;
}

function __ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj($this, $dstStart, $src, $count) {
  var $1 = $this;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, $dstStart, $src, $count);
  return;
}

function __ZN2js17NewSlowEmptyArrayEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17AddLengthPropertyP9JSContextP8JSObject($cx, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject14setArrayLengthEP9JSContextj($1, $cx, 0);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373($cx) {
  var $3 = HEAPU32[__ZN2js14SlowArrayClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb374($3, 0);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, __ZN2js14SlowArrayClassE, 0, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375($cx, $clasp, $proto, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376($cx, $clasp, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $11 = __ZN2js5types15emptyTypeObjectE;
      var $10 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $cx, 0, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $11 = $8;
      var $10 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $10;
    var $11;
    var $12 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($10 | 0) == 0) {
      var $19 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZNK8JSObject9getParentEv($10);
    var $19 = $17;
    __label__ = 8;
    break;
   case 8:
    var $19;
    var $20 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($12, undef, $clasp, $11, $19, 0, $20);
    var $21 = __ZNK2js5Class8isNativeEv($clasp);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $23 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359($cx, $12, $clasp, $11, $kind);
    if ($23) {
      var $_0 = $12;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($12);
    var $_0 = $12;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376($cx, $clasp, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE382($clasp_idx_val);
    var $2 = $cx;
    var $3 = $proto;
    var $4 = $clasp;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, $1, $3, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, 1, $3, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL17GuessObjectGCKindEjb($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($numSlots | 0) == 0) {
      var $_0 = 6;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gcL15GetGCObjectKindEjb374($numSlots, 1);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11ensureSlotsEP9JSContextj($this, $cx, $nslots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($this);
    if ($1 >>> 0 < $nslots >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = $cx;
    var $6 = __ZN8JSObject9growSlotsEP9JSContextj($4, $5, $nslots);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject383($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $obj, $id, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $id;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $5 = __ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti($cx, $obj, $_0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject4typeEv($obj);
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE($7, $cx, $_0, $value);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13TypeObjectKey6getKeyEPS1_($obj) {
  return $obj;
}

function _JSID_IS_INT387($iden) {
  return $iden & 1;
}

function _JSID_IS_STRING388($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js5types17PrimitiveTypeFlagE11JSValueType($type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type & 255;
    if (($1 | 0) == 6) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 4) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 2) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 9;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 16;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 32;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 64;
    __label__ = 9;
    break;
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13TypeObjectKey7keyBitsEPS1_($obj) {
  return $obj;
}

function _JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 & 255 & 15;
}

function __ZNK2js5types7TypeSet7unknownEv($this) {
  return (HEAP32[$this >> 2] & 65536 | 0) != 0;
}

function __ZNK2js5types4Type9isUnknownEv($this) {
  return (HEAP32[$this >> 2] | 0) == 32;
}

function __ZNK2js5types7TypeSet9baseFlagsEv($this) {
  return HEAP32[$this >> 2] & 65791;
}

function __ZNK2js5types4Type11isPrimitiveEv($this) {
  return HEAPU32[$this >> 2] >>> 0 < 7;
}

function __ZNK2js5types4Type9primitiveEv($this) {
  return HEAP32[$this >> 2] & 255;
}

function __ZNK2js5types4Type11isAnyObjectEv($this) {
  return (HEAP32[$this >> 2] | 0) == 7;
}

function __ZNK2js5types7TypeSet15baseObjectCountEv($this) {
  return HEAPU32[$this >> 2] >>> 8 & 255;
}

function __ZNK2js5types4Type9objectKeyEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $count) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2] & -65281 | $count << 8;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZNK2js5types4Type10typeObjectEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js5types4Type8isObjectEv($this) {
  return HEAPU32[$this >> 2] >>> 0 > 32;
}

function __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $count) {
  var $1 = $this + 12 | 0;
  var $5 = HEAP32[$1 >> 2] & -65521 | $count << 4;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js5typesL15HashSetCapacityEj385($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types4Type10DoubleTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 0);
  return;
}

function __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($this, $cx, $compiling) {
  __ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb($this, $cx, undef);
  return;
}

function __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $id, $assign) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propertyCount = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
    HEAP32[$propertyCount >> 2] = $2;
    var $3 = $cx + 56 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $this + 24 | 0;
    var $6 = __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($4, $5, $propertyCount, $id);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$3 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($10, $cx);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $12 = HEAP32[$6 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $22 = $12;
      __label__ = 8;
      break;
    }
   case 4:
    var $15 = HEAP32[$propertyCount >> 2];
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $15);
    var $16 = __ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE($this, $cx, $id, $6);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    if (($15 | 0) == 4095) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = HEAP32[$6 >> 2];
    __label__ = 8;
    break;
   case 7:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($this, $cx);
    var $20 = __ZN2js5types7TypeSet4makeEP9JSContextPKc($cx, undef);
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($20, $cx, $1);
    var $_0 = $20;
    __label__ = 10;
    break;
   case 8:
    var $22;
    var $23 = $22 + 4 | 0;
    if ($assign) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $23;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($23, $cx, 0);
    var $_0 = $23;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($agg_result, $cx, $val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isDoubleEv($val);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10DoubleTypeEv($agg_result);
    __label__ = 6;
    break;
   case 3:
    var $4 = __ZNK2JS5Value8isObjectEv($val);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $6 = __ZNK2JS5Value8toObjectEv($val);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($agg_result, $6);
    __label__ = 6;
    break;
   case 5:
    var $8 = __ZNK2JS5Value20extractNonDoubleTypeEv($val);
    __ZN2js5types4Type13PrimitiveTypeE11JSValueType($agg_result, $8);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($this, $cx, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectCount = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __ZNK2js5types7TypeSet7unknownEv($this);
    if ($3) {
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $this | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
    var $12 = ($9 ^ -65537) & $8 | 65536;
    HEAP32[$7 >> 2] = $12;
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    __label__ = 18;
    break;
   case 4:
    var $14 = __ZNK2js5types4Type11isPrimitiveEv($type);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $16 = __ZNK2js5types4Type9primitiveEv($type);
    var $17 = __ZN2js5types17PrimitiveTypeFlagE11JSValueType($16);
    var $18 = $this | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 & $17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 6:
    var $_ = ($17 | 0) == 16 ? $17 | 8 : $17;
    var $25 = $_ | $19;
    HEAP32[$18 >> 2] = $25;
    __label__ = 18;
    break;
   case 7:
    var $27 = $this | 0;
    if ((HEAP32[$27 >> 2] & 128 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 8:
    var $32 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($32) {
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    HEAP32[$objectCount >> 2] = $34;
    var $35 = __ZNK2js5types4Type9objectKeyEv($type);
    var $36 = $cx + 56 | 0;
    var $37 = HEAP32[$36 >> 2];
    var $38 = $this + 4 | 0;
    var $39 = __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($37, $38, $objectCount, $35);
    if (($39 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = HEAP32[$36 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($43, $cx);
    __label__ = 22;
    break;
   case 11:
    if ((HEAP32[$39 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 12:
    HEAP32[$39 >> 2] = $35;
    var $48 = HEAPU32[$objectCount >> 2];
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $48);
    if (($48 | 0) == 255) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZNK2js5types4Type12isTypeObjectEv($type);
    if ($51) {
      __label__ = 14;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 14:
    var $53 = __ZNK2js5types4Type10typeObjectEv($type);
    var $54 = __ZN2js5types10TypeObject17unknownPropertiesEv($53);
    if ($54) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($48 >>> 0 > 1) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $58 = $48 - 1 | 0;
    var $60 = $53 + 20 | 0;
    var $62 = HEAP32[$60 >> 2] + $58 * $58 | 0;
    HEAP32[$60 >> 2] = $62;
    if ($62 >>> 0 > 1999) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js5types4Type13AnyObjectTypeEv($1);
    var $66 = HEAP32[$1 >> 2];
    HEAP32[$type >> 2] = $66;
    var $69 = HEAP32[$27 >> 2] | 128;
    HEAP32[$27 >> 2] = $69;
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    __label__ = 18;
    break;
   case 18:
    var $constraint_01 = HEAP32[$this + 8 >> 2];
    var $73 = $cx + 56 | 0;
    var $75 = HEAP32[$73 >> 2] + 376 | 0;
    if (($constraint_01 | 0) == 0) {
      var $_lcssa = $75;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $77 = HEAP32[$type >> 2];
    var $78 = $2 | 0;
    var $constraint_02 = $constraint_01;
    var $80 = $75;
    __label__ = 20;
    break;
   case 20:
    var $80;
    var $constraint_02;
    HEAP32[$78 >> 2] = $77;
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($80, $cx, $constraint_02, $this, $2);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    var $84 = HEAP32[$73 >> 2] + 376 | 0;
    if (($constraint_0 | 0) == 0) {
      var $_lcssa = $84;
      __label__ = 21;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      var $80 = $84;
      __label__ = 20;
      break;
    }
   case 21:
    var $_lcssa;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($_lcssa, $cx);
    __label__ = 22;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE["X"] = 1;

function __ZN2js5types22AutoEnterTypeInferenceD1Ev($this) {
  __ZN2js5types22AutoEnterTypeInferenceD2Ev($this);
  return;
}

function __ZN2js5types22AutoEnterTypeInferenceD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP8[$this + 4 | 0] & 1;
    var $4 = $this | 0;
    HEAP8[HEAP32[HEAP32[$4 >> 2] + 56 >> 2] + 372 | 0] = $3;
    var $11 = HEAP8[$this + 5 | 0] & 1;
    HEAP8[HEAP32[HEAP32[$4 >> 2] + 56 >> 2] + 373 | 0] = $11;
    var $16 = HEAP32[$4 >> 2];
    var $18 = HEAP32[$16 + 56 >> 2];
    if ((HEAP8[$18 + 373 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $24 = $18 + 376 | 0;
    if ((HEAP8[$18 + 384 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types15TypeCompartment9nukeTypesEP9JSContext($24, $16);
    __label__ = 6;
    break;
   case 4:
    if ((HEAP32[$18 + 388 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext($24, $16);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet12clearObjectsEv($this) {
  __ZN2js5types7TypeSet18setBaseObjectCountEj($this, 0);
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_["X"] = 1;

function __ZNK2js5types4Type12isTypeObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type8isObjectEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = (HEAP32[$this >> 2] & 1 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13AnyObjectTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 7);
  return;
}

function __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($this, $cx, $constraint, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type | 0;
    var $2 = $this + 44 | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == (HEAP32[$this + 48 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $9 = $3;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext($this, $cx);
    var $9 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    HEAP32[$2 >> 2] = $9 + 1 | 0;
    var $12 = HEAP32[$this + 40 >> 2];
    var $13 = $12 + $9 * 12 | 0;
    HEAP32[$13 >> 2] = $constraint;
    var $14 = $12 + $9 * 12 + 4 | 0;
    HEAP32[$14 >> 2] = $source;
    var $15 = HEAP32[$1 >> 2];
    var $16 = $12 + $9 * 12 + 8 | 0;
    HEAP32[$16 >> 2] = $15;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 52 | 0;
    if ((HEAP8[$2] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    HEAP8[$2] = 1;
    var $7 = $this + 44 | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $this + 40 | 0;
    var $11 = $1 | 0;
    var $13 = $8;
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $14 = $13 - 1 | 0;
    HEAP32[$7 >> 2] = $14;
    var $15 = HEAP32[$10 >> 2];
    var $18 = HEAP32[$15 + $14 * 12 >> 2];
    var $21 = HEAP32[HEAP32[$18 >> 2] >> 2];
    var $23 = HEAP32[$15 + $14 * 12 + 4 >> 2];
    var $24 = HEAP32[$15 + $14 * 12 + 8 >> 2];
    HEAP32[$11 >> 2] = $24;
    FUNCTION_TABLE[$21]($18, $cx, $23, $1);
    var $25 = HEAP32[$7 >> 2];
    if (($25 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $13 = $25;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP8[$2] = 0;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj385($1);
    var $3 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj385($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_["X"] = 1;

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types4Type10ObjectTypeEP8JSObject($agg_result, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject16hasSingletonTypeEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $obj | 1;
    __ZN2js5types4TypeC1Ej($agg_result, $4);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK8JSObject4typeEv($obj);
    var $7 = $6;
    __ZN2js5types4TypeC1Ej($agg_result, $7);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type13PrimitiveTypeE11JSValueType($agg_result, $type) {
  var $1 = $type & 255;
  __ZN2js5types4TypeC1Ej($agg_result, $1);
  return;
}

function __ZNK2JS5Value20extractNonDoubleTypeEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL($2$0, $2$1);
  return $3;
}

function __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types8Property6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types8Property6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_["X"] = 1;

function __ZN2js5types4Type11UnknownTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 32);
  return;
}

function __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($this, $cx, $configured) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $configured ? 786432 : 262144;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 & $1 | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $3 | $1;
    HEAP32[$2 >> 2] = $7;
    var $constraint_01 = HEAP32[$this + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 3;
      break;
    }
   case 3:
    var $constraint_02;
    var $13 = HEAP32[HEAP32[$constraint_02 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$13]($constraint_02, $cx, $this);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb($this, $cx, $compiling) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 56 | 0;
  var $7 = HEAP8[HEAP32[$3 >> 2] + 372 | 0] & 1;
  HEAP8[$this + 4 | 0] = $7;
  var $12 = HEAP8[HEAP32[$3 >> 2] + 373 | 0] & 1;
  HEAP8[$this + 5 | 0] = $12;
  HEAP8[HEAP32[$3 >> 2] + 372 | 0] = 1;
  HEAP8[HEAP32[$3 >> 2] + 373 | 0] = 1;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5types17AllocationSiteKey5matchERKS1_S3_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$a >> 2] | 0) == (HEAP32[$b >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $21 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAPU32[$a + 4 >> 2];
    var $12 = HEAPU32[$b + 4 >> 2];
    if ((($12 ^ $9) & 16777215 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $21 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = ($9 >>> 24 | 0) == ($12 >>> 24 | 0);
    __label__ = 4;
    break;
   case 4:
    var $21;
    return $21;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js5types17AllocationSiteKey4hashES1_($key) {
  var __stackBase__ = STACKTOP;
  var tempParam = $key;
  $key = STACKTOP;
  STACKTOP += 8;
  HEAP32[$key >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$key + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $7 = HEAPU32[$key + 4 >> 2];
  var $12 = HEAP32[HEAP32[$key >> 2] >> 2] + ($7 & 16777215) ^ $7 >>> 24;
  STACKTOP = __stackBase__;
  return $12;
}

function __ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_($t) {
  var $1 = $t;
  var $st$3$0 = $1 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$0] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$0 + 3] = tempBigInt & 255;
  var $st$3$1 = $1 + 4 | 0;
  tempBigInt = 0;
  HEAP8[$st$3$1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 1] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 2] = tempBigInt & 255;
  tempBigInt >>= 8;
  HEAP8[$st$3$1 + 3] = tempBigInt & 255;
  return;
}

function __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj385($1);
    var $3 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types8Property6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj385($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types8Property6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_["X"] = 1;

function __ZNK2js12ContextStack13currentScriptEPPh($this, $ppc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($ppc | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$ppc >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $4 = $this;
    var $5 = __ZNK2js12ContextStack9maybeRegsEv($4);
    if (($5 | 0) == 0) {
      var $fp_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $5;
    var $9 = __ZNK2js9FrameRegs2fpEv($8);
    var $fp_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $fp_0;
    if (($fp_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = __ZNK2js10StackFrame12isDummyFrameEv($fp_0);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $14 = __ZNK2js10StackFrame4prevEv($fp_0);
    var $fp_0 = $14;
    __label__ = 5;
    break;
   case 8:
    var $15 = __ZNK2js10StackFrame6scriptEv($fp_0);
    var $16 = $15;
    var $17 = __ZNK2js2gc4Cell11compartmentEv($16);
    var $_not = ($17 | 0) != (HEAP32[HEAP32[$this + 8 >> 2] + 56 >> 2] | 0);
    var $_mux = $_not ? 0 : $15;
    if ($_not | $1 ^ 1) {
      var $_0 = $_mux;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($fp_0, $4, 0, 0);
    HEAP32[$ppc >> 2] = $24;
    var $_0 = $15;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script, $pc, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $p = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $6 = $pc - HEAP32[$script >> 2] | 0;
    var $7 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK8JSScript9hasGlobalEv($script);
    if ($6 >>> 0 > 8388607 | $9 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $kind);
    var $_0 = $12;
    __label__ = 9;
    break;
   case 4:
    __ZN2js5types17AllocationSiteKeyC1Ev($key);
    HEAP32[$key >> 2] = $script;
    var $19 = $6 & 16777215 | $kind << 24;
    HEAP32[$key + 4 >> 2] = $19;
    var $20 = $cx + 56 | 0;
    var $21 = HEAP32[$20 >> 2];
    var $23 = HEAP32[$21 + 404 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = $21 + 376 | 0;
    var $27 = __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($26, $cx, $key);
    var $_0 = $27;
    __label__ = 9;
    break;
   case 6:
    __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_($p, $23, $key);
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
    var $_0 = HEAP32[$33 + 8 >> 2];
    __label__ = 9;
    break;
   case 8:
    var $38 = HEAP32[$20 >> 2] + 376 | 0;
    var $39 = __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($38, $cx, $key);
    var $_0 = $39;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey["X"] = 1;

function __ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey($cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $cx;
    var $2 = $proto;
    var $3 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, 0, $key, $2, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$proto >> 2];
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $cx, 0, 0);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSScript9hasGlobalEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$this + 100 >> 2] + 8 >> 2];
    if (($4 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js12GlobalObject9isClearedEv($4);
    var $10 = $7 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17AllocationSiteKeyC1Ev($this) {
  __ZN2js5types17AllocationSiteKeyC2Ev($this);
  return;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 68,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $l;
  var $3 = $1;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  var $5 = __ZN2js5types17AllocationSiteKey4hashES1_($1);
  var $6 = $5 * -1640531527 | 0;
  var $7 = $6 - 2 | 0;
  var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($6);
  var $_ = $8 ? $6 : $7;
  var $9 = $_ & -2;
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js5types17AllocationSiteKey5matchERKS1_S3_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js5types17AllocationSiteKeyC2Ev($this) {
  __ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_($this);
  return;
}

function __ZNK2js12GlobalObject9isClearedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 117);
  var $3 = __ZNK2JS5Value7toInt32Ev($2);
  return ($3 & 1 | 0) != 0;
}

function __ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE($cx, $mode, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $hole = __stackBase__ + 4;
    var $thisv = __stackBase__ + 8;
    var $objv = __stackBase__ + 16;
    var $tvr = __stackBase__ + 24;
    var $args = __stackBase__ + 48;
    var $hole1 = __stackBase__ + 72;
    var $1 = __stackBase__ + 76;
    var $2 = __stackBase__ + 84;
    var $3 = $vp + 8 | 0;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $4, $length);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $vp, 0);
    var $_1 = 0;
    __label__ = 55;
    break;
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $13, 65536);
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAPU32[$length >> 2];
    if (($mode | 0) == 2) {
      __label__ = 7;
      break;
    } else if (($mode | 0) == 1) {
      var $step_0 = 1;
      var $start_0 = 0;
      var $end_0 = $17;
      __label__ = 8;
      break;
    } else if (($mode | 0) == 3 || ($mode | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($mode | 0) == 5) {
      __label__ = 19;
      break;
    } else if (($mode | 0) == 6) {
      __label__ = 20;
      break;
    } else if (($mode | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $step_1 = 1;
      var $newlen_0 = 0;
      var $newarr_0 = 0;
      var $start_2 = 0;
      var $end_1 = $17;
      __label__ = 22;
      break;
    }
   case 7:
    var $step_0 = -1;
    var $start_0 = $17 - 1 | 0;
    var $end_0 = -1;
    __label__ = 8;
    break;
   case 8:
    var $end_0;
    var $start_0;
    var $step_0;
    if (($17 | 0) == 0 & ($argc | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 218, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 55;
    break;
   case 10:
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      var $start_1 = $start_0;
      __label__ = 12;
      break;
    }
   case 11:
    var $27 = $vp + 24 | 0;
    var $st$1$0 = $27 | 0;
    var $28$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$1$1 >> 2];
    var $29 = $vp | 0;
    var $st$6$0 = $29 | 0;
    HEAP32[$st$6$0 >> 2] = $28$0;
    var $st$6$1 = $29 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $28$1;
    var $step_1 = $step_0;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = $start_0;
    var $end_1 = $end_0;
    __label__ = 22;
    break;
   case 12:
    var $start_1;
    var $31 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $4, $start_1 >>> 0, $hole, $vp);
    if (($31 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = $start_1 + $step_0 | 0;
    var $35 = HEAPU32[$hole >> 2];
    var $37 = ($34 | 0) == ($end_0 | 0);
    if (($35 | 0) == 0 | $37) {
      __label__ = 14;
      break;
    } else {
      var $start_1 = $34;
      __label__ = 12;
      break;
    }
   case 14:
    if (($35 | 0) != 0 & $37) {
      __label__ = 15;
      break;
    } else {
      var $step_1 = $step_0;
      var $newlen_0 = 0;
      var $newarr_0 = 0;
      var $start_2 = $34;
      var $end_1 = $end_0;
      __label__ = 22;
      break;
    }
   case 15:
    _JS_ReportErrorNumber($cx, 2, 0, 218, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 55;
    break;
   case 16:
    var $42 = ($mode | 0) == 3 ? $17 : 0;
    var $43 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $42, 0);
    if (($43 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $46 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, 3);
    if (($46 | 0) == 0) {
      var $_1 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($43, $46);
    __ZN2JS5Value9setObjectER8JSObject($vp, $43);
    var $step_1 = 1;
    var $newlen_0 = $42;
    var $newarr_0 = $43;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 19:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 20:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 21:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $step_1 = 1;
    var $newlen_0 = 0;
    var $newarr_0 = 0;
    var $start_2 = 0;
    var $end_1 = $17;
    __label__ = 22;
    break;
   case 22:
    var $end_1;
    var $start_2;
    var $newarr_0;
    var $newlen_0;
    var $step_1;
    if (($17 | 0) == 0) {
      var $_1 = 1;
      __label__ = 55;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ($argc >>> 0 > 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    if (($mode - 1 | 0) >>> 0 < 2) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $58 = $vp + 24 | 0;
    var $st$1$0 = $58 | 0;
    var $59$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $58 + 4 | 0;
    var $59$1 = HEAP32[$st$1$1 >> 2];
    var $60 = $thisv | 0;
    var $st$6$0 = $60 | 0;
    HEAP32[$st$6$0 >> 2] = $59$0;
    var $st$6$1 = $60 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $59$1;
    __label__ = 27;
    break;
   case 26:
    __ZN2JSL14UndefinedValueEv351($thisv);
    __label__ = 27;
    break;
   case 27:
    if (($mode | 0) == 1) {
      var $66 = 4;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $phitmp = ($mode | 0) == 2 ? 4 : 3;
    var $66 = $phitmp;
    __label__ = 29;
    break;
   case 29:
    var $66;
    __ZN2JSL11ObjectValueER8JSObject383($objv, $4);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $67 = $cx + 52 | 0;
    var $68 = $args | 0;
    var $69 = $1 | 0;
    var $70 = $thisv | 0;
    var $71$0 = HEAP32[$70 >> 2];
    var $71$1 = HEAP32[$70 + 4 >> 2];
    var $72 = ($mode - 1 | 0) >>> 0 < 2;
    var $73 = $args | 0;
    var $74 = $vp | 0;
    var $75 = $2 | 0;
    var $76 = $objv | 0;
    var $77$0 = HEAP32[$76 >> 2];
    var $77$1 = HEAP32[$76 + 4 >> 2];
    var $78 = ($mode | 0) > 3;
    var $80 = $cx + 60 | 0;
    var $81 = $cx;
    var $82 = $args;
    var $i_0 = $start_2;
    var $ok_0 = 1;
    var $newlen_1 = $newlen_0;
    __label__ = 30;
    break;
   case 30:
    var $newlen_1;
    var $ok_0;
    var $i_0;
    if (($i_0 | 0) == ($end_1 | 0)) {
      var $ok_2 = $ok_0;
      __label__ = 52;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[HEAP32[$67 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $91 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $94 = $i_0 >>> 0;
    var $95 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $96 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $4, $94, $hole1, $95);
    var $97 = ($96 | 0) != 0;
    var $98 = $97 & 1;
    if ($97) {
      __label__ = 34;
      break;
    } else {
      var $ok_2 = $98;
      __label__ = 52;
      break;
    }
   case 34:
    if ((HEAP32[$hole1 >> 2] | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      var $ok_1 = $98;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 35:
    var $103 = __ZNK2js15InvokeArgsGuard6pushedEv($args);
    if ($103) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $105 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($80, $81, $66, $82);
    if ($105) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 54;
      break;
    }
   case 37:
    var $107 = __ZNK2js12CallReceiver7calleevEv($68);
    __ZN2JSL11ObjectValueER8JSObject383($1, $14);
    var $108$0 = HEAP32[$69 >> 2];
    var $108$1 = HEAP32[$69 + 4 >> 2];
    var $109 = $107 | 0;
    HEAP32[$109 >> 2] = $108$0;
    HEAP32[$109 + 4 >> 2] = $108$1;
    var $110 = __ZNK2js12CallReceiver5thisvEv($68);
    var $111 = $110 | 0;
    HEAP32[$111 >> 2] = $71$0;
    HEAP32[$111 + 4 >> 2] = $71$1;
    if ($72) {
      __label__ = 38;
      break;
    } else {
      var $argi_0 = 0;
      __label__ = 39;
      break;
    }
   case 38:
    var $113 = __ZNK2js8CallArgsixEj($73, 0);
    var $st$1$0 = $74 | 0;
    var $114$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $74 + 4 | 0;
    var $114$1 = HEAP32[$st$1$1 >> 2];
    var $115 = $113 | 0;
    var $st$6$0 = $115 | 0;
    HEAP32[$st$6$0 >> 2] = $114$0;
    var $st$6$1 = $115 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $114$1;
    var $argi_0 = 1;
    __label__ = 39;
    break;
   case 39:
    var $argi_0;
    var $117 = $argi_0 + 1 | 0;
    var $118 = __ZNK2js8CallArgsixEj($73, $argi_0);
    var $119 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $120 = $119 | 0;
    var $st$5$0 = $120 | 0;
    var $121$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $120 + 4 | 0;
    var $121$1 = HEAP32[$st$5$1 >> 2];
    var $122 = $118 | 0;
    HEAP32[$122 >> 2] = $121$0;
    HEAP32[$122 + 4 >> 2] = $121$1;
    var $123 = $argi_0 | 2;
    var $124 = __ZNK2js8CallArgsixEj($73, $117);
    __ZN2JSL10Int32ValueEi360($2, $i_0);
    var $125$0 = HEAP32[$75 >> 2];
    var $125$1 = HEAP32[$75 + 4 >> 2];
    var $126 = $124 | 0;
    HEAP32[$126 >> 2] = $125$0;
    HEAP32[$126 + 4 >> 2] = $125$1;
    var $127 = __ZNK2js8CallArgsixEj($73, $123);
    var $128 = $127 | 0;
    HEAP32[$128 >> 2] = $77$0;
    HEAP32[$128 + 4 >> 2] = $77$1;
    var $129 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $130 = $129 & 1;
    if ($129) {
      __label__ = 40;
      break;
    } else {
      var $ok_2 = $130;
      __label__ = 52;
      break;
    }
   case 40:
    var $132 = __ZNK2js12CallReceiver4rvalEv($68);
    if ($78) {
      __label__ = 41;
      break;
    } else {
      var $cond_0 = 0;
      __label__ = 42;
      break;
    }
   case 41:
    var $134 = __Z17js_ValueToBooleanRKN2JS5ValueE($132);
    var $cond_0 = $134;
    __label__ = 42;
    break;
   case 42:
    var $cond_0;
    if (($mode | 0) == 1 || ($mode | 0) == 2) {
      __label__ = 43;
      break;
    } else if (($mode | 0) == 3) {
      __label__ = 44;
      break;
    } else if (($mode | 0) == 4) {
      __label__ = 45;
      break;
    } else if (($mode | 0) == 5) {
      __label__ = 47;
      break;
    } else if (($mode | 0) == 6) {
      __label__ = 49;
      break;
    } else {
      var $ok_1 = $130;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 43:
    var $137 = $132 | 0;
    var $st$1$0 = $137 | 0;
    var $138$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $137 + 4 | 0;
    var $138$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $74 | 0;
    HEAP32[$st$5$0 >> 2] = $138$0;
    var $st$5$1 = $74 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $138$1;
    var $ok_1 = $130;
    var $newlen_2 = $newlen_1;
    __label__ = 51;
    break;
   case 44:
    var $140 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $newarr_0, $94, $132);
    if (($140 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      var $ok_1 = $140;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 45:
    if (($cond_0 | 0) == 0) {
      var $ok_1 = $130;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $145 = $newlen_1 + 1 | 0;
    var $147 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $newarr_0, $newlen_1 >>> 0, $119);
    if (($147 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      var $ok_1 = $147;
      var $newlen_2 = $145;
      __label__ = 51;
      break;
    }
   case 47:
    if (($cond_0 | 0) == 0) {
      var $ok_1 = $130;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = $130;
    __label__ = 54;
    break;
   case 49:
    if (($cond_0 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      var $ok_1 = $130;
      var $newlen_2 = $newlen_1;
      __label__ = 51;
      break;
    }
   case 50:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = $130;
    __label__ = 54;
    break;
   case 51:
    var $newlen_2;
    var $ok_1;
    var $i_0 = $i_0 + $step_1 | 0;
    var $ok_0 = $ok_1;
    var $newlen_1 = $newlen_2;
    __label__ = 30;
    break;
   case 52:
    var $ok_2;
    if (($ok_2 | 0) != 0 & ($mode | 0) == 4) {
      __label__ = 53;
      break;
    } else {
      var $_0 = $ok_2;
      __label__ = 54;
      break;
    }
   case 53:
    var $162 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $newarr_0, $newlen_1 >>> 0);
    var $_0 = $162;
    __label__ = 54;
    break;
   case 54:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 55;
    break;
   case 55:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE["X"] = 1;

function __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, $construct) {
  var $1 = $args | 0;
  __ZN2js12CallArgsList9setActiveEv($1);
  var $2 = $args | 0;
  var $3 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $2, $construct);
  __ZN2js12CallArgsList11setInactiveEv($1);
  return $3;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function _INT_TO_JSID398($i) {
  return $i << 1 | 1;
}

function __ZN2jsL3MinIjEET_S1_S1_($t1, $t2) {
  var $2 = $t1 >>> 0 < $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZL18JSDOUBLE_IS_FINITEd396($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd397($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN8JSObject18isPackedDenseArrayEv($this) {
  return (HEAP32[$this + 8 >> 2] & 16384 | 0) != 0;
}

function __ZN22AutoArrayCycleDetector10foundCycleEv($this) {
  return (HEAP8[$this + 20 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE($cx, $isLast, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $tosearch = __stackBase__ + 4;
    var $hole = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $start = __stackBase__ + 24;
    var $equal = __stackBase__ + 32;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $3, $length);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$length >> 2];
    if (($9 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $_ = ($isLast | 0) == 0 ? 0 : $9 - 1 | 0;
    if (($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $vp + 16 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAPU32[$st$1$1 >> 2];
    var $20 = $1 | 0;
    var $st$6$0 = $20 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $20 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    var $23$1 = $19$1;
    var $23$0 = $19$0;
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv351($1);
    var $_phi_trans_insert = $1 | 0;
    var $23$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $23$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 8:
    var $23$0;
    var $23$1;
    var $24 = $tosearch | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $i_0 = $_;
    __label__ = 18;
    break;
   case 9:
    var $26 = $vp + 16 | 0;
    var $st$1$0 = $26 | 0;
    var $27$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$1$1 >> 2];
    var $28 = $tosearch | 0;
    var $st$6$0 = $28 | 0;
    HEAP32[$st$6$0 >> 2] = $27$0;
    var $st$6$1 = $28 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $27$1;
    var $29 = $vp + 24 | 0;
    var $30 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $29, $start);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 10:
    var $32 = (tempDoubleI32[0] = HEAP32[$start >> 2], tempDoubleI32[1] = HEAP32[$start + 4 >> 2], tempDoubleF64[0]);
    var $34 = $9 >>> 0;
    if ($32 < 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $36 = $32 + $34;
    tempDoubleF64[0] = $36, HEAP32[$start >> 2] = tempDoubleI32[0], HEAP32[$start + 4 >> 2] = tempDoubleI32[1];
    if ($36 < 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    if (($isLast | 0) == 0) {
      var $i_01 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 13:
    var $41 = $36 >= 0 ? Math.floor($36) : Math.ceil($36);
    var $i_0 = $41;
    __label__ = 18;
    break;
   case 14:
    if ($32 < $34) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($isLast | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $direction_0_ph = -1;
    var $stop_0_ph = 0;
    var $i_1_ph = $9 - 1 | 0;
    __label__ = 20;
    break;
   case 17:
    var $48 = $32 >= 0 ? Math.floor($32) : Math.ceil($32);
    var $i_0 = $48;
    __label__ = 18;
    break;
   case 18:
    var $i_0;
    if (($isLast | 0) == 0) {
      var $i_01 = $i_0;
      __label__ = 19;
      break;
    } else {
      var $direction_0_ph = -1;
      var $stop_0_ph = 0;
      var $i_1_ph = $i_0;
      __label__ = 20;
      break;
    }
   case 19:
    var $i_01;
    var $direction_0_ph = 1;
    var $stop_0_ph = $9 - 1 | 0;
    var $i_1_ph = $i_01;
    __label__ = 20;
    break;
   case 20:
    var $i_1_ph;
    var $stop_0_ph;
    var $direction_0_ph;
    var $52 = $cx + 52 | 0;
    var $i_1 = $i_1_ph;
    __label__ = 21;
    break;
   case 21:
    var $i_1;
    if ((HEAP32[HEAP32[$52 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $59 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $62 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $3, $i_1 >>> 0, $hole, $vp);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 25:
    var $68 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $vp, $tosearch, $equal);
    if ($68) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 26:
    if ((HEAP32[$equal >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $73 = __ZN2JS5Value9setNumberEj($vp, $i_1);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 28:
    if (($i_1 | 0) == ($stop_0_ph | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $i_1 = $direction_0_ph + $i_1 | 0;
    __label__ = 21;
    break;
   case 30:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE["X"] = 1;

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd($cx, $v, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value7isInt32Ev($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value7toInt32Ev($v);
    tempDoubleF64[0] = $4 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $16 = $9;
    __label__ = 7;
    break;
   case 5:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $dp);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $16 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $16;
    var $17 = __ZL18js_DoubleToIntegerd395($16);
    tempDoubleF64[0] = $17, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd395($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd396($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd397($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17TryReuseArrayTypeP8JSObjectS0_($obj, $nobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7isArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject16hasSingletonTypeEv($obj);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject8getProtoEv($obj);
    var $6 = __ZNK8JSObject8getProtoEv($nobj);
    if (($5 | 0) == ($6 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK8JSObject4typeEv($obj);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($nobj, $9);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE($cx, $obj, $length, $vector) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $length);
    if (($vector | 0) == 0 | ($length | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = $cx;
    var $6 = __ZN8JSObject7getTypeEP9JSContext($4, $5);
    var $7 = $6;
    var $8 = __ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj($cx, $7, $vector, $length);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $10 = __ZN8JSObject11ensureSlotsEP9JSContextj($obj, $cx, $length);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $12 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $length);
    var $hole_01 = 0;
    var $i_02 = 0;
    __label__ = 7;
    break;
   case 6:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($obj, $cx);
    var $hole_01 = 0;
    var $i_02 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_02;
    var $hole_01;
    var $15 = $vector + ($i_02 << 3) | 0;
    __ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE($obj, $i_02, $15);
    var $16 = __ZNK2JS5Value7isMagicE10JSWhyMagic($15, undef);
    var $17 = $hole_01 | $16;
    var $18 = $i_02 + 1 | 0;
    if (($18 | 0) == ($length | 0)) {
      __label__ = 8;
      break;
    } else {
      var $hole_01 = $17;
      var $i_02 = $18;
      __label__ = 7;
      break;
    }
   case 8:
    if ($17) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN8JSObject23markDenseArrayNotPackedEP9JSContext($obj, $cx);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject22moveDenseArrayElementsEjjj($this, $dstStart, $srcStart, $count) {
  var $2 = HEAP32[$this + 32 >> 2];
  var $4 = $2 + ($dstStart << 3) | 0;
  var $6 = $2 + ($srcStart << 3) | 0;
  var $7 = $count << 3;
  _llvm_memmove_p0i8_p0i8_i32($4, $6, $7, 1, 0);
  return;
}

function __ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE($cx, $obj, $index, $hole, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($hole | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $index, 1);
    var $_0 = $3 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE($cx, $obj, $index, $v);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE($cx, $obj, $locale, $sepstr, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detector = __stackBase__;
    var $length = __stackBase__ + 24;
    var $sb = __stackBase__ + 28;
    var $hole = __stackBase__ + 108;
    if (($sepstr | 0) == 0) {
      var $seplen_0 = 1;
      var $sep_0 = __ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSString6lengthEv($sepstr);
    var $4 = __ZN8JSString8getCharsEP9JSContext($sepstr, $cx);
    if (($4 | 0) == 0) {
      var $_2 = 0;
      __label__ = 35;
      break;
    } else {
      var $seplen_0 = $3;
      var $sep_0 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $sep_0;
    var $seplen_0;
    __ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject($detector, $cx, $obj);
    var $7 = __ZN22AutoArrayCycleDetector4initEv($detector);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 4:
    var $9 = __ZN22AutoArrayCycleDetector10foundCycleEv($detector);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $15);
    var $_1 = 1;
    __label__ = 34;
    break;
   case 6:
    var $17 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $obj, $length);
    if (($17 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js12StringBufferC1EP9JSContext($sb, $cx);
    var $20 = ($locale | 0) != 0;
    if (($seplen_0 | 0) == 0 & ($20 ^ 1)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = HEAPU32[$length >> 2];
    var $25 = $cx + 52 | 0;
    var $26 = $cx;
    var $index_0 = 0;
    __label__ = 19;
    break;
   case 10:
    var $28 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $obj);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 11:
    var $31 = __ZN8JSObject21getDenseArrayElementsEv($obj);
    var $32 = HEAP32[$length >> 2];
    var $33 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    var $34 = __ZN2jsL3MinIjEET_S1_S1_($32, $33);
    var $35 = $31 + ($34 << 3) | 0;
    var $36 = $cx + 52 | 0;
    var $vp_0 = $31;
    __label__ = 12;
    break;
   case 12:
    var $vp_0;
    if (($vp_0 | 0) == ($35 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[HEAP32[$36 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp_0, undef);
    if ($47) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = __ZNK2JS5Value17isNullOrUndefinedEv($vp_0);
    if ($49) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $vp_0, $sb);
    if ($51) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 18:
    var $vp_0 = $vp_0 + 8 | 0;
    __label__ = 12;
    break;
   case 19:
    var $index_0;
    if ($index_0 >>> 0 < $24 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 20:
    if ((HEAP32[HEAP32[$25 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $64 = __ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE($cx, $obj, $index_0 >>> 0, $hole, $rval);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 24:
    var $70 = __ZNK2JS5Value17isNullOrUndefinedEv($rval);
    if ($70) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($20) {
      __label__ = 26;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $73 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $rval);
    if (($73 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $79 = HEAP32[HEAP32[$25 >> 2] + 210316 >> 2] | 0;
    var $80 = __ZL12ATOM_TO_JSIDP6JSAtom354($79);
    var $81 = $73;
    var $82 = __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($81, $26, $80, 0, 0, $rval);
    if ($82) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 28:
    var $84 = __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $rval, $sb);
    if ($84) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 29:
    var $86 = $index_0 + 1 | 0;
    if (($86 | 0) == ($24 | 0)) {
      var $index_0 = $86;
      __label__ = 19;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $89 = __ZN2js12StringBuffer6appendEPKtj($sb, $sep_0, $seplen_0);
    if ($89) {
      var $index_0 = $86;
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 31:
    var $90 = $sb;
    var $91 = __ZN2js12StringBuffer12finishStringEv($90);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $94 = $91 | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $94);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    __ZN22AutoArrayCycleDetectorD1Ev($detector);
    var $_2 = $_1;
    __label__ = 35;
    break;
   case 35:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE["X"] = 1;

function __ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZN22AutoArrayCycleDetector4initEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $5 = HEAP32[$this >> 2] + 148 | 0;
    var $6 = $this + 12 | 0;
    var $7 = $this + 4 | 0;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($1, $5, $7);
    var $8 = $1;
    var $9 = $6;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    HEAP32[$9 >> 2] = $10$0;
    HEAP32[$9 + 4 >> 2] = $10$1;
    var $11 = $6 | 0;
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $11);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $16 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($5, $6, $7);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$this + 20 | 0] = 0;
    var $19 = __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($5);
    HEAP32[$this + 8 >> 2] = $19;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $v, $sb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v);
    var $4 = __ZN2js12StringBuffer6appendEP8JSString($sb, $3);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = $cx;
    var $7 = $sb;
    var $8 = __ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE($6, $v, $7);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendEPKtj($this, $chars, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($1);
    var $3 = $2 + $len | 0;
    var $4 = __ZN2js12StringBuffer11checkLengthEj($this, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($1, $chars, $len);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22AutoArrayCycleDetectorD1Ev($this) {
  __ZN22AutoArrayCycleDetectorD2Ev($this);
  return;
}

function __ZN22AutoArrayCycleDetectorD2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP8[$this + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$this + 8 >> 2];
    var $11 = HEAP32[$this >> 2] + 148 | 0;
    var $12 = __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($11);
    if (($8 | 0) == ($12 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = HEAP32[$this + 12 >> 2];
    HEAP32[$1 >> 2] = $16;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($11, $1);
    __label__ = 5;
    break;
   case 4:
    var $19 = $this + 4 | 0;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($11, $19);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv($1);
  return $2;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $this, $l);
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 70,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $2);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_VOID($iden) {
  return ($iden | 0) == 2 & 1;
}

function _JSVAL_IS_SPECIFIC_BOOLEAN407($l_0$0, $l_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value12getDoubleRefEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject($this, $cx, $obj) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  HEAP8[$this + 20 | 0] = 1;
  return;
}

function __ZNK18ArraySharpDetector14initiallySharpEv($this) {
  return (HEAP8[$this + 12 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN18ArraySharpDetector14takeSharpCharsEv($this) {
  var $1 = $this + 4 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  return $2;
}

function __ZNK18ArraySharpDetector13hasSharpCharsEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) != 0;
}

function __ZN18ArraySharpDetector9makeSharpEv($this) {
  var $3 = HEAP32[$this + 8 >> 2] + 12 | 0;
  var $7 = HEAP32[$3 >> 2] | 1;
  HEAP32[$3 >> 2] = $7;
  return;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    HEAP16[$_02 >> 1] = HEAP8[$p_01] << 24 >> 24;
    var $4 = $p_01 + 1 | 0;
    if (($4 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $4;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18ArraySharpDetectorC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN2js12AutoIdRooter4addrEv($this) {
  return $this + 12 | 0;
}

function __ZN2js12AutoIdRooter2idEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_($this, $cx, $vec) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $vec;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_($1, $7);
  var $8 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($this, $insBegin, $length) {
  var $1 = $insBegin + ($length << 1) | 0;
  var $2 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($this, $insBegin, $1);
  return $2;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($this, $insBegin, $insEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = ($insEnd - $insBegin | 0) >>> 1;
    if ((HEAP32[$this + 8 >> 2] + $4 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $4);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendEP8JSString($this, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js12StringBuffer7contextEv($this);
    var $2 = __ZN8JSString12ensureLinearEP9JSContext($str, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    var $6 = __ZNK8JSString6lengthEv($5);
    var $7 = $this | 0;
    var $8 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($7);
    var $9 = $8 + $6 | 0;
    var $10 = __ZN2js12StringBuffer11checkLengthEj($this, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZNK14JSLinearString5charsEv($2);
    var $13 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($7, $12, $6);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZL13js_IsCallableRKN2JS5ValueE405($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18ArraySharpDetectorC1EP9JSContext($this, $cx) {
  __ZN18ArraySharpDetectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN18ArraySharpDetector4initEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAP32[$this >> 2];
    var $5 = $obj;
    var $6 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($4, $5, 0, $3);
    var $7 = $6;
    HEAP32[$this + 8 >> 2] = $7;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$this + 12 | 0] = HEAP32[$6 + 12 >> 2] & 255 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16replaceRawBufferEPtj($this, $chars, $len) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj($1, $chars, $len);
  return;
}

function __ZN2js12StringBuffer6appendEt($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($1);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js12StringBuffer11checkLengthEj($this, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_($1, $c);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($this, $array) {
  var $1 = $this | 0;
  var $2 = $array | 0;
  var $3 = $array + 2 | 0;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($1, $2, $3);
  return $4;
}

function __ZN2JSL11StringValueEP8JSString406($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN18ArraySharpDetectorD1Ev($this) {
  __ZN18ArraySharpDetectorD2Ev($this);
  return;
}

function __ZN18ArraySharpDetectorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[$this + 8 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAP32[$this >> 2];
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($18, 0);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($this, $insBegin, $insEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $insEnd - $insBegin | 0;
    if ((HEAP32[$this + 8 >> 2] + $3 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $3);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $length) {
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this);
  var $2 = $insBegin + $length | 0;
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($1, $insBegin, $2);
  var $3 = $this + 8 | 0;
  var $5 = HEAP32[$3 >> 2] + $length | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj($this, $p, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($this);
    var $5 = $4;
    __ZN2js18ContextAllocPolicy5free_EPv($3, $5);
    __label__ = 3;
    break;
   case 3:
    if ($length >>> 0 < 33) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $this + 16 | 0;
    var $10 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($9);
    var $11 = $10;
    HEAP32[$this + 4 >> 2] = $11;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = 32;
    var $15 = $p + ($length << 1) | 0;
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($11, $p, $15);
    var $16 = $this | 0;
    var $17 = $p;
    __ZN2js18ContextAllocPolicy5free_EPv($16, $17);
    __label__ = 6;
    break;
   case 5:
    HEAP32[$this + 4 >> 2] = $p;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = $length;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoIdRooterC1EP9JSContexti($this, $cx, $id) {
  __ZN2js12AutoIdRooterC2EP9JSContexti($this, $cx, $id);
  return;
}

function __ZNK2JS5Value6isTrueEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_SPECIFIC_BOOLEAN407($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js12AutoIdRooterD1Ev($this) {
  __ZN2js12AutoIdRooterD2Ev($this);
  return;
}

function __ZN2js12AutoIdRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js12AutoIdRooterC2EP9JSContexti($this, $cx, $id) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -11);
  HEAP32[$this + 12 >> 2] = $id;
  return;
}

function __ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev($this_0_1_val_val) {
  var $1 = $this_0_1_val_val;
  __ZN9JSContext5free_EPv(undef, $1);
  return;
}

function __ZN2js15AutoArrayRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2JSL11DoubleValueEd408($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $v, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $1 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $v, $atom);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$atom >> 2];
    var $4 = __ZL12ATOM_TO_JSIDP6JSAtom354($3);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $v, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $1 = __ZNK2JS5Value8isStringEv($v);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($3, $v);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $4);
    var $7 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $4, 0);
    HEAP32[$atomp >> 2] = $7;
    var $_0 = ($7 | 0) != 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = __ZNK2JS5Value8toStringEv($v);
    var $11 = __ZNK8JSString6isAtomEv($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZNK8JSString6asAtomEv($10);
    HEAP32[$atomp >> 2] = $13;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $15 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $10, 0);
    HEAP32[$atomp >> 2] = $15;
    var $_0 = ($15 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompareArgsD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js15InvokeArgsGuardD1Ev($1);
  return;
}

function __ZN11CompareArgsC2EP9JSContextN2JS5ValueE($this, $cx, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $_02 = $0 | 0;
  var $tmp$0 = HEAP32[$_02 >> 2];
  var $tmp$1 = HEAP32[$_02 + 4 >> 2];
  HEAP32[$this >> 2] = $cx;
  var $3 = $this + 4 | 0;
  __ZN2js15InvokeArgsGuardC1Ev($3);
  var $_03 = $this + 32 | 0;
  HEAP32[$_03 >> 2] = $tmp$0;
  HEAP32[$_03 + 4 >> 2] = $tmp$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 3;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE($this, $i, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js15ArgumentsObject13initialLengthEv($this);
    if ($1 >>> 0 > $i >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = __ZNK2js15ArgumentsObject7elementEj($this, $i);
    var $5 = $4 | 0;
    var $st$2$0 = $5 | 0;
    var $6$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$2$1 >> 2];
    var $7 = $vp | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp, undef);
    if ($8) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7onTraceEv($this);
    if ($10) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($this);
    if (($12 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2js10StackFrame18canonicalActualArgEj($12, $i);
    var $16 = $15 | 0;
    var $st$2$0 = $16 | 0;
    var $17$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$7 >> 2] = $17$0;
    HEAP32[$7 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject7elementEj($this, $i) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  return $1 + 8 + ($i << 3) | 0;
}

function __ZNK2js15ArgumentsObject7onTraceEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  return ($2 | 0) == 41254;
}

function __ZNK2js15ArgumentsObject15maybeStackFrameEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  return $2;
}

function __ZNK2js15ArgumentsObject4dataEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 1);
  var $3 = __ZNK2JS5Value9toPrivateEv($2);
  return $3;
}

function __ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE($this, $cx, $len, $vec) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, $len);
  HEAP32[$this + 12 >> 2] = $vec;
  return;
}

function __ZN2js14AutoValueArrayD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $2 = __ZNK8JSObject7isArrayEv($_01);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = __ZNK8JSObject14getArrayLengthEv($_01);
    var $5 = __ZN2JS5Value9setNumberEj($vp, $4);
    __label__ = 5;
    break;
   case 4:
    var $7 = __ZNK8JSObject8getProtoEv($_01);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj423($bits) {
  return $bits;
}

function __ZN11JSAtomState21checkStaticInvariantsEv($this) {
  return;
}

function _JSID_TO_INT420($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING422($iden) {
  return $iden;
}

function _JSVAL_IS_MAGIC_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -124) & 1;
}

function __ZNK2js10StackFrame13formalArgsEndEv($this) {
  return $this;
}

function __ZN6JSAtom14asPropertyNameEv($this) {
  return $this;
}

function __ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst) {
  HEAP32[$this >> 2] = $argsobj;
  HEAP32[$this + 4 >> 2] = $dst;
  return;
}

function __ZNK8JSObject17isStrictArgumentsEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js26StrictArgumentsObjectClassE | 0);
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($this) {
  return HEAP32[$this >> 2] & -2;
}

function __ZN11JSAtomState16commonAtomsStartEv($this) {
  return $this + 24 | 0;
}

function __Z20js_FinishCommonAtomsP9JSContext($cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144136 | 0;
  HEAP32[$3 >> 2] = 0;
  return;
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb($this, $enabled) {
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | $enabled & 1;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $newlen = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $tvr = __stackBase__ + 16;
    var $index = __stackBase__ + 32;
    var $junk = __stackBase__ + 36;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZNK8JSObject7isArrayEv($obj);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom354($8);
    var $10 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $9, $vp, 0, 0, 1);
    var $_1 = $10;
    __label__ = 36;
    break;
   case 3:
    var $12 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $vp, $newlen);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 4:
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $16 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $17 = HEAPU32[$newlen >> 2];
    if ($16 != $17 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 36;
    break;
   case 7:
    var $22 = __ZNK8JSObject14getArrayLengthEv($obj);
    if (($22 | 0) == ($17 | 0)) {
      var $_1 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN2JS5Value9setNumberEj($vp, $17);
    if ($22 >>> 0 < $17 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $17);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 10:
    var $29 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $31 = __ZN8JSObject21getDenseArrayCapacityEv($obj);
    if ($31 >>> 0 > $17 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj($obj, $cx, $17);
    __label__ = 13;
    break;
   case 13:
    var $35 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($35 >>> 0 > $17 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 14:
    __ZN8JSObject30setDenseArrayInitializedLengthEj($obj, $17);
    var $38 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($38) {
      __label__ = 33;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($obj, $cx);
    __label__ = 33;
    break;
   case 16:
    var $41 = $22 - $17 | 0;
    if ($41 >>> 0 < 16777216) {
      __label__ = 17;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 17:
    var $43 = $cx + 52 | 0;
    var $44 = ($strict | 0) != 0;
    var $oldlen_0 = $22;
    __label__ = 18;
    break;
   case 18:
    var $oldlen_0;
    var $46 = $oldlen_0 - 1 | 0;
    if ((HEAP32[HEAP32[$43 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($52 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $oldlen_0);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 21:
    var $56 = __ZL18DeleteArrayElementP9JSContextP8JSObjectdb($cx, $obj, $46 >>> 0, $44);
    if (($56 | 0) < 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $oldlen_0);
    var $_1 = $56 >>> 31 ^ 1;
    __label__ = 36;
    break;
   case 23:
    if (($46 | 0) == ($17 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $oldlen_0 = $46;
      __label__ = 18;
      break;
    }
   case 24:
    var $62 = _JS_NewPropertyIterator($cx, $obj);
    if (($62 | 0) == 0) {
      var $_1 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $62);
    var $65 = $cx + 52 | 0;
    __label__ = 26;
    break;
   case 26:
    if ((HEAP32[HEAP32[$65 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $71 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($71 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $73 = _JS_NextProperty(undef, $62, $1);
    var $74 = HEAPU32[$1 >> 2];
    var $75 = _JSID_IS_VOID($74);
    if (($75 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $78 = __Z12js_IdIsIndexiPj($74, $index);
    if (($78 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ((HEAP32[$index >> 2] - $17 | 0) >>> 0 < $41 >>> 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 31:
    var $85 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj, $cx, $74, $junk, 0);
    if (($85 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 32:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    __label__ = 33;
    break;
   case 33:
    var $88 = HEAP32[$newlen >> 2];
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj, $cx, $88);
    var $_1 = 1;
    __label__ = 36;
    break;
   case 34:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 35:
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj($this, $cx, $cap) {
  var $1 = $this;
  var $2 = $cx;
  __ZN8JSObject11shrinkSlotsEP9JSContextj($1, $2, $cap);
  return;
}

function __ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj($this, $cx, $start, $length) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -2);
  HEAP32[$this + 12 >> 2] = $start;
  HEAP32[$this + 16 >> 2] = $length;
  return;
}

function __Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $index, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($1, $2, $2, $index, $vp);
  return $3;
}

function __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = $obj;
  var $3 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($1, $2, $2, $id, $vp);
  return $3;
}

function __ZL17IsDenseArrayIndexP8JSObjectj($obj, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($1 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject20getDenseArrayElementEj($obj, $index);
    var $5 = __ZNK2JS5Value7isMagicE10JSWhyMagic($4, undef);
    var $8 = $5 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($this, $cx, $index, $objp, $propp) {
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 8 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 72;
  var $6 = FUNCTION_TABLE[$5]($cx, $this, $index, $objp, $propp);
  return $6;
}

function __ZL14IsDenseArrayIdP9JSContextP8JSObjecti($cx_0_11_val_0_70_28_val, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = $cx_0_11_val_0_70_28_val | 0;
    var $2 = __ZL12JSID_IS_ATOMiP6JSAtom($id, $1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      var $11 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$i >> 2];
    var $9 = __ZL17IsDenseArrayIndexP8JSObjectj($obj, $8);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_TO_ATOMi421($id) {
  var $1 = _JSID_TO_STRING422($id);
  return $1;
}

function __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($this, $cx, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($this, $cx, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15ArgumentsObject8elementsEv($this) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  return $1 + 8 | 0;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj($this, $op, $start, $count) {
  var __stackBase__ = STACKTOP;
  var tempParam = $op;
  $op = STACKTOP;
  STACKTOP += 8;
  HEAP32[$op >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$op + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $4 = HEAPU16[$1 + 56 >> 1] & 65535;
    var $5 = __ZNK2js10StackFrame13formalArgsEndEv($this);
    var $6 = __ZNK2js10StackFrame13numActualArgsEv($this);
    var $_02 = ($count | 0) == -1 ? $6 - $start | 0 : $count;
    var $9 = $_02 + $start | 0;
    var $11 = $5 + ($start - $4 << 3) | 0;
    if ($9 >>> 0 > $4 >>> 0) {
      var $_1 = $start;
      var $p1_0 = $11;
      __label__ = 5;
      break;
    } else {
      var $_01 = $start;
      var $p_0 = $11;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_0;
    var $_01;
    if ($_01 >>> 0 < $9 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    var $14 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_01, $p_0);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $_01 = $_01 + 1 | 0;
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $p1_0;
    var $_1;
    if ($_1 >>> 0 < $4 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $20 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_1, $p1_0);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $_1 = $_1 + 1 | 0;
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    var $p2_0 = $5 + (-2 - $4 - $6 + $_1 << 3) | 0;
    var $_2 = $_1;
    __label__ = 9;
    break;
   case 9:
    var $_2;
    var $p2_0;
    if ($_2 >>> 0 < $9 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 10:
    var $30 = __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($op, $_2, $p2_0);
    if ($30) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $p2_0 = $p2_0 + 8 | 0;
    var $_2 = $_2 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst) {
  __ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE($this, $argsobj, $dst);
  return;
}

function __ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE($this, $argi, $src) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZNK2js15ArgumentsObject7elementEj($2, $argi);
    var $4 = __ZNK2JS5Value7isMagicE10JSWhyMagic($3, undef);
    if ($4) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this + 4 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = $7 + 8 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $src | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $7 | 0;
    var $st$10$0 = $11 | 0;
    HEAP32[$st$10$0 >> 2] = $10$0;
    var $st$10$1 = $11 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12BigIndexToIdP9JSContextP8JSObjectjiPi($cx, $obj, $index, $createAtom, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ + 20 | 0;
    var $start_0 = $1;
    var $_01 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $start_0;
    var $3 = $start_0 - 2 | 0;
    HEAP16[$3 >> 1] = (($_01 >>> 0) % 10 | 48) & 65535;
    var $7 = Math.floor(($_01 >>> 0) / 10);
    if ($_01 >>> 0 > 9) {
      var $start_0 = $3;
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($createAtom | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject11isSlowArrayEv($obj);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZNK8JSObject11isArgumentsEv($obj);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK8JSObject8isObjectEv($obj);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $1 - $3 >> 1;
    var $22 = __Z24js_GetExistingStringAtomP9JSContextPKtj($cx, $3, $21);
    if (($22 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $atom_0 = $22;
      __label__ = 10;
      break;
    }
   case 8:
    HEAP32[$idp >> 2] = 2;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $29 = $1 - $3 >> 1;
    var $30 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $3, $29, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $atom_0 = $30;
      __label__ = 10;
      break;
    }
   case 10:
    var $atom_0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom354($atom_0);
    HEAP32[$idp >> 2] = $33;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18ReallyBigIndexToIdP9JSContextdPi($cx, $index, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11DoubleValueEd408($1, $index);
  var $2 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $1, $idp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js15AutoValueRooterC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -1);
  var $2 = $this + 16 | 0;
  __ZN2JSL9NullValueEv429($2);
  return;
}

function __ZN2JSL9NullValueEv429($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $atom | 0;
  __ZN2JSL11StringValueEP8JSString478($1, $2);
  var $3 = $cx;
  var $4 = $bytes;
  var $5 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($3, $1, $4, 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2JSL11StringValueEP8JSString478($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __Z16js_InitAtomStateP9JSRuntime($rt) {
  var $1 = $rt + 209948 | 0;
  var $2 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj($1, 1024);
  return $2 & 1;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1, $len);
  return $2;
}

function __Z18js_FinishAtomStateP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $rt + 209948 | 0;
    var $2 = __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r, $1);
    var $4 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $6 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($5);
    __ZN6JSAtom8finalizeEP9JSRuntime($6, undef);
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $7 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv($1);
  return $2;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $1);
  return;
}

function __ZN6JSAtom8finalizeEP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
    if (($2 | 0) == 18) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZN8JSString6asFlatEv($5);
    __ZN12JSFlatString8finalizeEP9JSRuntime($6, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_InitCommonAtomsP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $2 + 209948 | 0;
    var $4 = __ZN11JSAtomState16commonAtomsStartEv($3);
    var $i_0 = 0;
    var $atoms_0 = $4;
    __label__ = 2;
    break;
   case 2:
    var $atoms_0;
    var $i_0;
    if ($i_0 >>> 0 < 131) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[_js_common_atom_names + ($i_0 << 2) >> 2];
    var $10 = _strlen($9);
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $9, $10, 1, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN6JSAtom14asPropertyNameEv($11);
    var $15 = $14 | 0;
    HEAP32[$atoms_0 >> 2] = $15;
    var $i_0 = $i_0 + 1 | 0;
    var $atoms_0 = $atoms_0 + 4 | 0;
    __label__ = 2;
    break;
   case 5:
    __ZN11JSAtomState14clearLazyAtomsEv($3);
    var $21 = HEAP32[$2 + 209972 >> 2] | 0;
    var $23 = HEAP32[$1 >> 2] + 144136 | 0;
    HEAP32[$23 >> 2] = $21;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $bytes, $length, $ib, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inflated = __stackBase__;
    var $inflatedLength = __stackBase__ + 64;
    var $chars = __stackBase__ + 68;
    var $1 = __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    HEAP32[$inflatedLength >> 2] = 31;
    if ($length >>> 0 < 32) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = $inflated | 0;
    var $7 = $cx;
    if (($fc | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($7, $bytes, $length, $6, $inflatedLength, 1);
    __label__ = 7;
    break;
   case 5:
    var $11 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($7, $bytes, $length, $6, $inflatedLength);
    __label__ = 7;
    break;
   case 6:
    HEAP32[$inflatedLength >> 2] = $length;
    var $13 = $cx;
    var $14 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($13, $bytes, $inflatedLength, $fc);
    HEAP32[$chars >> 2] = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $17 = HEAP32[$inflatedLength >> 2];
    HEAP16[$inflated + ($17 << 1) >> 1] = 0;
    HEAP32[$chars >> 2] = $6;
    var $19 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $17, $ib, 0);
    var $_0 = $19;
    __label__ = 10;
    break;
   case 8:
    var $21 = HEAP32[$inflatedLength >> 2];
    var $22 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $21, $ib, 1);
    var $23 = HEAP32[$chars >> 2];
    if (($23 | 0) == 0) {
      var $_0 = $22;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $23;
    __ZN9JSContext5free_EPv(undef, $26);
    var $_0 = $22;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSAtomState14clearLazyAtomsEv($this) {
  var $2 = $this + 548 | 0;
  _memset($2, 0, 88, 1);
  return;
}

function __Z17js_TraceAtomStateP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $entry = __stackBase__ + 16;
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    var $8 = $4 + 209948 | 0;
    if ((HEAP32[$4 + 136 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r, $8);
    var $10 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $12 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($11);
    var $13 = $12 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $13);
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $14 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($r1, $8);
    var $16 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r1);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r1);
    __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($entry, $17);
    var $18 = __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($entry);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry);
    var $21 = $20 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $21);
    __label__ = 7;
    break;
   case 7:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r1);
    var $23 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r1);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($this, $other) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_($this, $other);
  return;
}

function __Z17js_SweepAtomStateP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $entry = __stackBase__ + 16;
    var $3 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($e, $3);
    var $4 = $e | 0;
    var $5 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $6 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($4);
    __ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_($entry, $6);
    var $7 = __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($entry);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry);
    var $10 = $9;
    var $11 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 6:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($4);
    var $14 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($4);
    if ($14) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this);
  return;
}

function __Z14AtomIsInternedP9JSContextP6JSAtom($cx, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 20;
    var $3 = __ZN2js13StaticStrings8isStaticEP6JSAtom($atom);
    if ($3) {
      var $_1 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $7 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPK6JSAtom($1, $atom);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($p, $7, $1);
    __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_1 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($p);
    var $13 = __ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv($12);
    var $_1 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($this, $cx) {
  __ZN2js24AutoLockAtomsCompartmentC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE($agg_result, $1, $l);
  return;
}

function __ZN2js10AtomHasher6LookupC1EPK6JSAtom($this, $atom) {
  __ZN2js10AtomHasher6LookupC2EPK6JSAtom($this, $atom);
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 74,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $str, $ib) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $chars = __stackBase__ + 20;
    var $2 = __ZNK8JSString6isAtomEv($str);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6asAtomEv($str);
    if (($ib | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $4;
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = __ZN2js13StaticStrings8isStaticEP6JSAtom($4);
    if ($7) {
      var $_0 = $4;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $11 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPK6JSAtom($1, $4);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($p, $11, $1);
    var $12 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($p);
    __ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb($12, 1);
    var $_0 = $4;
    __label__ = 7;
    break;
   case 5:
    var $14 = __ZNK8JSString6lengthEv($str);
    var $15 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    HEAP32[$chars >> 2] = $15;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $chars, $14, $ib, 0);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb) {
  var $1 = __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb);
  return $1;
}

function __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $chars, $length, $ib) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $chars;
    var $2 = __ZN2jsL17CheckStringLengthEP9JSContextj489($cx, $length);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $1, $length, $ib, 0);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($t) {
  return $t;
}

function _INT_TO_JSID501($i) {
  return $i << 1 | 1;
}

function _OBJECT_TO_JSID502($obj) {
  return $obj | 4;
}

function _JSID_TO_STRING504($iden) {
  return $iden;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv($this) {
  return $this + 200 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv($this) {
  return $this + 8 | 0;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv($this) {
  return $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
}

function __ZNK7mozilla9RangedPtrItE3getEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK7mozilla9RangedPtrItEmiERKS1_($this, $other) {
  return (HEAP32[$this >> 2] - HEAP32[$other >> 2] | 0) >>> 1;
}

function __ZNK8JSObject5isXMLEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js8XMLClassE | 0);
}

function __ZNK7mozilla9RangedPtrItEdeEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE($this, $p) {
  var $2 = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $2;
  return $this;
}

function __ZN7mozilla9RangedPtrItEC2EPtS2_j($this, $p, $start, $length) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN7mozilla9RangedPtrItEC2EPtS2_S2_($this, $p, $start, $end) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($this) {
  return HEAPU32[$this >> 2] >>> 0 > 24;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js9HashCharsEPKtj($chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 0) {
      var $h_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $h_02 = 0;
      var $_013 = $length;
      var $_04 = $chars;
      __label__ = 2;
      break;
    }
   case 2:
    var $_04;
    var $_013;
    var $h_02;
    var $7 = HEAPU16[$_04 >> 1] & 65535 ^ ($h_02 << 4 | $h_02 >>> 28);
    var $9 = $_013 - 1 | 0;
    if (($9 | 0) == 0) {
      var $h_0_lcssa = $7;
      __label__ = 3;
      break;
    } else {
      var $h_02 = $7;
      var $_013 = $9;
      var $_04 = $_04 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    var $h_0_lcssa;
    return $h_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior($cx, $pchars, $length, $ib, $ocb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 24;
    var $sc = __stackBase__ + 32;
    var $lookup = __stackBase__ + 44;
    var $3 = __stackBase__ + 56;
    var $4 = HEAP32[$pchars >> 2];
    var $5 = $cx + 52 | 0;
    var $7 = HEAP32[$5 >> 2] + 210584 | 0;
    var $8 = __ZN2js13StaticStrings6lookupEPKtj($7, $4, $length);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_2 = $8;
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $12 = HEAP32[$5 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPKtj($1, $4, $length);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE($p, $12, $1);
    var $13 = $p | 0;
    __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $13);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($13);
    var $19 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($18);
    var $20 = ($ib | 0) != 0;
    __ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb($18, $20);
    var $_2 = $19;
    __label__ = 12;
    break;
   case 4:
    var $24 = HEAP32[HEAP32[$5 >> 2] >> 2];
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, $24);
    var $26 = $cx;
    if (($ocb | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $28 = __Z12js_NewStringP9JSContextPtj($26, $4, $length);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$pchars >> 2] = 0;
    var $key_0 = $28;
    __label__ = 8;
    break;
   case 7:
    var $32 = __Z17js_NewStringCopyNP9JSContextPKtj($26, $4, $length);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $key_0 = $32;
      __label__ = 8;
      break;
    }
   case 8:
    var $key_0;
    __ZN2js10AtomHasher6LookupC1EPKtj($lookup, $4, $length);
    var $36 = ($ib | 0) != 0;
    __ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b($3, $key_0, $36);
    var $37 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_($12, $p, $lookup, $3);
    if ($37) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $40 = __ZN13JSFixedString27morphAtomizedStringIntoAtomEv($key_0);
    var $_0 = $40;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    var $_2 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior["X"] = 1;

function __Z24js_GetExistingStringAtomP9JSContextPKtj($cx, $chars, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 20;
    var $3 = $cx + 52 | 0;
    var $5 = HEAP32[$3 >> 2] + 210584 | 0;
    var $6 = __ZN2js13StaticStrings6lookupEPKtj($5, $chars, $length);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    __ZN2js24AutoLockAtomsCompartmentC1EP9JSContext($lock, $cx);
    var $10 = HEAP32[$3 >> 2] + 209948 | 0;
    __ZN2js10AtomHasher6LookupC1EPKtj($1, $chars, $length);
    __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE($p, $10, $1);
    __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv($p);
    var $16 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($15);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StaticStrings6lookupEPKtj($this, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($length | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($length | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $2 = HEAPU16[$chars >> 1];
    if (($2 & 65535) < 256) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $5 = __ZN2js13StaticStrings7getUnitEt($this, $2);
    var $_0 = $5;
    __label__ = 12;
    break;
   case 4:
    var $7 = HEAPU16[$chars >> 1];
    var $8 = __ZN2js13StaticStrings15fitsInSmallCharEt($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $11 = HEAP16[$chars + 2 >> 1];
    var $12 = __ZN2js13StaticStrings15fitsInSmallCharEt($11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 6:
    var $14 = __ZN2js13StaticStrings10getLength2Ett($this, $7, $11);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 7:
    var $16 = HEAPU16[$chars >> 1];
    var $17 = $16 & 65535;
    if (($16 - 49 & 65535 & 65535) < 9) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $21 = HEAPU16[$chars + 2 >> 1];
    var $22 = $21 & 65535;
    if (($21 - 48 & 65535 & 65535) < 10) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $26 = HEAPU16[$chars + 4 >> 1];
    if (($26 - 48 & 65535 & 65535) < 10) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $34 = $17 * 100 - 5328 + $22 * 10 + ($26 & 65535) | 0;
    if ($34 >>> 0 < 256) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = __ZN2js13StaticStrings6getIntEi($this, $34);
    var $_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10AtomHasher6LookupC1EPKtj($this, $chars, $length) {
  __ZN2js10AtomHasher6LookupC2EPKtj($this, $chars, $length);
  return;
}

function __Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_($cx, $indices, $atoms) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv($indices);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv($indices);
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($r, $3);
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($4) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $7 = HEAP32[$5 >> 2];
    var $10 = $atoms + (HEAP32[$5 + 4 >> 2] << 2) | 0;
    HEAP32[$10 >> 2] = $7;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $13 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv($indices);
    var $14 = __ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv($indices);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $it_01 = $13;
      __label__ = 5;
      break;
    }
   case 5:
    var $it_01;
    var $17 = HEAP32[$it_01 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $atoms + (HEAP32[$it_01 + 4 >> 2] << 2) | 0;
    HEAP32[$22 >> 2] = $17;
    __label__ = 7;
    break;
   case 7:
    var $24 = $it_01 + 8 | 0;
    if (($24 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $it_01 = $24;
      __label__ = 5;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($this);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13IndexToIdSlowEP9JSContextjPi($cx, $index, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__ + 20;
    var $start = __stackBase__ + 24;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 20 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_S2_($end, $2, undef, undef);
    var $4 = HEAP32[$end >> 2];
    HEAP32[$1 >> 2] = $4;
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $index, $1);
    var $6 = __ZNK7mozilla9RangedPtrItE3getEv($start);
    var $7 = __ZNK7mozilla9RangedPtrItEmiERKS1_($end, $start);
    var $8 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $6, $7, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZL12ATOM_TO_JSIDP6JSAtom496($8);
    HEAP32[$idp >> 2] = $11;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrItEC1EPtS2_S2_($this, $p, $start, $end) {
  __ZN7mozilla9RangedPtrItEC2EPtS2_S2_($this, $p, undef, undef);
  return;
}

function __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($agg_result, $index, $end) {
  var __stackBase__ = STACKTOP;
  var tempParam = $end;
  $end = STACKTOP;
  STACKTOP += 4;
  HEAP32[$end >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = Math.floor(($_0 >>> 0) / 10);
    var $5 = (($_0 >>> 0) % 10 | 48) & 65535;
    var $6 = __ZN7mozilla9RangedPtrItEmmEv($end);
    var $7 = __ZNK7mozilla9RangedPtrItEdeEv($6);
    HEAP16[$7 >> 1] = $5;
    if ($_0 >>> 0 > 9) {
      var $_0 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$end >> 2];
    HEAP32[$agg_result >> 2] = $11;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom496($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj522($1);
  return $2;
}

function __Z22js_CheckForStringIndexi($id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12JSID_IS_ATOMi499($id);
    if (($1 | 0) == 0) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12JSID_TO_ATOMi500($id);
    var $5 = $4 | 0;
    var $6 = __ZNK14JSLinearString5charsEv($5);
    var $7 = HEAPU16[$6 >> 1];
    var $8 = $7 << 16 >> 16 == 45;
    var $9 = $8 & 1;
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $s_0 = $6;
      var $14 = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $6 + 2 | 0;
    var $s_0 = $11;
    var $14 = HEAP16[$11 >> 1];
    __label__ = 4;
    break;
   case 4:
    var $14;
    var $s_0;
    var $16 = ($14 & 65535) - 48 | 0;
    if ($16 >>> 0 < 10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 5:
    var $19 = $4 | 0;
    var $20 = __ZNK8JSString6lengthEv($19);
    var $21 = $20 - $9 | 0;
    if ($21 >>> 0 > 10) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $s_0 + ($21 << 1) | 0;
    var $25 = $s_0 + 2 | 0;
    if (($16 | 0) == 0) {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = 0;
      var $cp_1 = $25;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = HEAPU16[$25 >> 1] & 65535;
    if (($28 - 48 | 0) >>> 0 < 10) {
      var $cp_04 = $25;
      var $index_05 = $16;
      var $31 = $28;
      __label__ = 8;
      break;
    } else {
      var $c_1 = 0;
      var $oldIndex_1 = 0;
      var $index_1 = $16;
      var $cp_1 = $25;
      __label__ = 9;
      break;
    }
   case 8:
    var $31;
    var $index_05;
    var $cp_04;
    var $32 = $31 - 48 | 0;
    var $34 = $32 + $index_05 * 10 | 0;
    var $35 = $cp_04 + 2 | 0;
    var $37 = HEAPU16[$35 >> 1] & 65535;
    if (($37 - 48 | 0) >>> 0 < 10) {
      var $cp_04 = $35;
      var $index_05 = $34;
      var $31 = $37;
      __label__ = 8;
      break;
    } else {
      var $c_1 = $32;
      var $oldIndex_1 = $index_05;
      var $index_1 = $34;
      var $cp_1 = $35;
      __label__ = 9;
      break;
    }
   case 9:
    var $cp_1;
    var $index_1;
    var $oldIndex_1;
    var $c_1;
    if (($cp_1 | 0) == ($24 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 10:
    if ($8 & ($index_1 | 0) == 0) {
      var $_0 = $id;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $oldIndex_1 >>> 0 < 107374182;
    if ($8) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    if ($44) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($oldIndex_1 | 0) == 107374182 & $c_1 >>> 0 < 5) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 14:
    var $51 = _INT_TO_JSID501(-$index_1 | 0);
    var $_0 = $51;
    __label__ = 18;
    break;
   case 15:
    if ($44) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($oldIndex_1 | 0) == 107374182 & $c_1 >>> 0 < 4) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $id;
      __label__ = 18;
      break;
    }
   case 17:
    var $57 = _INT_TO_JSID501($index_1);
    var $_0 = $57;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_CheckForStringIndexi["X"] = 1;

function __ZL12JSID_IS_ATOMi499($id) {
  var $1 = _JSID_IS_STRING508($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi500($id) {
  var $1 = _JSID_TO_STRING504($id);
  return $1;
}

function __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj, $idval, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject5isXMLEv($obj);
    var $2 = __ZNK2JS5Value8toObjectEv($idval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _OBJECT_TO_JSID502($2);
    HEAP32[$idp >> 2] = $4;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $6 = $2;
    var $7 = $cx;
    var $8 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($6, $idp, $7);
    if ($8) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval, $idp);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj, $idval, $idp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject5isXMLEv($obj);
    var $3 = __ZNK2JS5Value8toObjectEv($idval);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _OBJECT_TO_JSID502($3);
    HEAP32[$idp >> 2] = $5;
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $7 = $3;
    var $8 = $cx;
    var $9 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($7, $idp, $8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$idp >> 2];
    __ZN2jsL9IdToValueEi503($1, $11);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 5:
    var $16 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval, $idp);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = HEAP32[$idp >> 2];
    var $19 = _JSID_TO_STRING504($18);
    __ZN2JS5Value9setStringEP8JSString($vp, $19);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi503($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING508($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING504($id);
    __ZN2JSL11StringValueEP8JSString478($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT509($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT511($id);
    __ZN2JSL10Int32ValueEi510($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT512($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT514($id);
    __ZN2JSL11ObjectValueER8JSObject513($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv515($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrItEmmEv($this) {
  var $1 = __ZN7mozilla9RangedPtrItEmIEj($this, 1);
  return $1;
}

function __ZN7mozilla9RangedPtrItEmIEj($this, $dec) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN7mozilla9RangedPtrItEmiEj($1, $this, $dec);
  var $2 = __ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE($this, $1);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrItEmiEj($agg_result, $this, $dec) {
  var $4 = HEAP32[$this >> 2] + (-$dec << 1) | 0;
  __ZNK7mozilla9RangedPtrItE6createEPt($agg_result, undef, $4);
  return;
}

function __ZNK7mozilla9RangedPtrItE6createEPt($agg_result, $this, $ptr) {
  __ZN7mozilla9RangedPtrItEC1EPtS2_j($agg_result, $ptr, undef, undef);
  return;
}

function __ZN7mozilla9RangedPtrItEC1EPtS2_j($this, $p, $start, $length) {
  __ZN7mozilla9RangedPtrItEC2EPtS2_j($this, $p, undef, undef);
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l);
  var $2 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l) {
  var $1 = __ZN2js10AtomHasher4hashERKNS0_6LookupE($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($1);
  var $3 = __ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE($2, $l);
  return $3;
}

function __ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE($entry, $lookup) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv($entry);
    var $3 = HEAP32[$lookup + 8 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = ($3 | 0) == ($1 | 0);
    __label__ = 5;
    break;
   case 3:
    var $8 = $1 | 0;
    var $9 = __ZNK8JSString6lengthEv($8);
    var $11 = HEAP32[$lookup + 4 >> 2];
    if (($9 | 0) == ($11 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $1 | 0;
    var $15 = __ZNK14JSLinearString5charsEv($14);
    var $17 = HEAP32[$lookup >> 2];
    var $18 = __ZN2jsL8PodEqualIKtEEbPT_S3_j($15, $17, $11);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL8PodEqualIKtEEbPT_S3_j($one, $two, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($len >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = $one + ($len << 1) | 0;
    var $p2_0 = $two;
    var $p1_0 = $one;
    __label__ = 3;
    break;
   case 3:
    var $p1_0;
    var $p2_0;
    if (($p1_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAP16[$p1_0 >> 1] << 16 >> 16 == HEAP16[$p2_0 >> 1] << 16 >> 16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $p2_0 = $p2_0 + 2 | 0;
    var $p1_0 = $p1_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = $one;
    var $15 = $two;
    var $16 = $len << 1;
    var $17 = _memcmp($14, $15, $16);
    var $_0 = ($17 | 0) == 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10AtomHasher4hashERKNS0_6LookupE($l) {
  var $2 = HEAP32[$l >> 2];
  var $4 = HEAP32[$l + 4 >> 2];
  var $5 = __ZN2js9HashCharsEPKtj($2, $4);
  return $5;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj($hash);
  return $1;
}

function __ZL14JSID_FROM_BITSj522($bits) {
  return $bits;
}

function _JSVAL_TO_BOOLEAN_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSID_IS_STRING508($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT509($iden) {
  return $iden & 1;
}

function _JSID_TO_INT511($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT512($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT514($iden) {
  return $iden & -8;
}

function __ZL15JSDOUBLE_IS_NaNd535($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_($this, $other) {
  var $3 = HEAP32[$other >> 2];
  HEAP32[$this >> 2] = $3;
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv($this) {
  return (HEAP32[$this + 20 >> 2] | 0) != 0;
}

function __ZN2js10AtomHasher6LookupC2EPKtj($this, $chars, $length) {
  HEAP32[$this >> 2] = $chars;
  HEAP32[$this + 4 >> 2] = $length;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js13StaticStrings7getUnitEt($this, $c) {
  return HEAP32[$this + 17412 + (($c & 65535) << 2) >> 2];
}

function __ZN2js13StaticStrings10getLength2Ett($this, $c1, $c2) {
  var $2 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c1 & 65535) | 0;
  var $7 = STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE + ($c2 & 65535) | 0;
  return HEAP32[$this + 4 + (((HEAPU8[$2] & 255) << 6) + (HEAPU8[$7] & 255) << 2) >> 2];
}

function __ZN2js13StaticStrings7getUintEj($this, $u) {
  return HEAP32[$this + 16388 + ($u << 2) >> 2];
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b($this, $ptr, $tagged) {
  HEAP32[$this >> 2] = $tagged & 1 | $ptr;
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js24AutoLockAtomsCompartmentC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __Z18js_BooleanToStringP9JSContexti($cx, $b) {
  return HEAP32[HEAP32[$cx + 52 >> 2] + 209976 + ((($b | 0) != 0 & 1) << 2) >> 2] | 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb560($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($1);
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($1);
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($this) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_($1, $7);
  var $8 = __ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev($1);
  var $10 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $10;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js18TaggedPointerEntryI6JSAtomEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 3) | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi510($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject513($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL14UndefinedValueEv515($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js13StaticStrings6getIntEi($this, $i) {
  var $1 = __ZN2js13StaticStrings7getUintEj($this, $i);
  return $1;
}

function __ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_($this, $p, $l, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_($1, $p, $l, $t);
  return $2;
}

function __ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b($this, $ptr, $tagged) {
  __ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b($this, $ptr, $tagged);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $2, 1);
    var $4 = $p | 0;
    HEAP32[$p >> 2] = $3;
    var $6 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($4);
    if ($6) {
      var $10 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$t >> 2];
    var $7 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$7 >> 2] = $6;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE($l);
  var $2 = __ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js10AtomHasher6LookupC2EPK6JSAtom($this, $atom) {
  var $1 = $this | 0;
  var $2 = $atom | 0;
  var $3 = __ZNK14JSLinearString5charsEv($2);
  HEAP32[$1 >> 2] = $3;
  var $4 = $this + 4 | 0;
  var $5 = $atom | 0;
  var $6 = __ZNK8JSString6lengthEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = $atom;
  return;
}

function __ZN12JSFlatString8finalizeEP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK14JSLinearString5charsEv($1);
    if (($2 | 0) == ($this + 8 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2;
    __ZN9JSRuntime5free_EPv(undef, $7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13bool_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $buf = __stackBase__ + 4;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $buf | 0;
    var $9 = HEAP32[_js_common_atom_names + ((HEAP8[$b] & 1 & 255) + 1 << 2) >> 2];
    var $10 = _JS_snprintf($3, 32, STRING_TABLE.__str3529 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $9, tempInt));
    var $11 = $cx;
    var $12 = _JS_NewStringCopyZ($11, $3);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $12);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13bool_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 209976 + ((HEAP8[$b] & 1 & 255) << 2) >> 2];
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $12);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12bool_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (HEAP8[$b] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_InitBooleanClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js12BooleanClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb532($1, 0);
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($6, $1);
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 210036 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 76, __ZN2js12BooleanClassE, $13, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14 | 0;
    var $18 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $17, $5);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $20 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL15boolean_methods);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $22 = $cx;
    var $23 = $3;
    var $24 = $14;
    var $25 = $5;
    var $26 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($22, $23, 4, $24, $25);
    var $_ = $26 ? $6 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($this, $pthis) {
  var $1 = $this;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 0, $pthis);
  return;
}

function __ZN2JSL12BooleanValueEb532($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZL7BooleanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5 = __Z17js_ValueToBooleanRKN2JS5ValueE($4);
    var $7 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = __ZN2jsL14IsConstructingEPKN2JS5ValueE($vp);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558($cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL12BooleanValueEb532($1, $7);
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($10, $1);
    var $13 = $10;
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value10setBooleanEb($vp, $7);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE($cx, $b, $sb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($b | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($sb, STRING_TABLE._js_true_str);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($sb, STRING_TABLE._js_false_str);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 4 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 5 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __Z17js_ValueToBooleanRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = ($3 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isStringEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toStringEv($v);
    var $10 = __ZNK8JSString6lengthEv($9);
    var $_0 = ($10 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 5:
    var $14 = __ZNK2JS5Value8isObjectEv($v);
    if ($14) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2JS5Value17isNullOrUndefinedEv($v);
    if ($16) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZNK2JS5Value8isDoubleEv($v);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $20 = __ZNK2JS5Value8toDoubleEv($v);
    var $21 = __ZL15JSDOUBLE_IS_NaNd535($20);
    if (($21 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $26 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = $20 != 0;
    __label__ = 10;
    break;
   case 10:
    var $26;
    var $_0 = $26 & 1;
    __label__ = 12;
    break;
   case 11:
    var $29 = __ZNK2JS5Value9toBooleanEv($v);
    var $_0 = $29 & 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value9toBooleanEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_BOOLEAN_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558($cx) {
  var $3 = HEAPU32[__ZN2js12BooleanClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb560($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561($cx, $4);
  return $5;
}

function __ZL9SwapBytesy($u$0, $u$1) {
  return [ $u$0, $u$1 ];
}

function _JSVAL_IS_MAGIC_IMPL571($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -124) & 1;
}

function _JSVAL_IS_BOOLEAN_IMPL($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function __ZL12PairToUInt64jj($tag, $data) {
  return [ $data | 0, 0 | $tag ];
}

function _JSID_IS_INT594($iden) {
  return $iden & 1;
}

function _JSID_TO_INT595($iden) {
  return $iden >> 1;
}

function _JSID_TO_STRING596($iden) {
  return $iden;
}

function __ZL14ArrayTypeToTagj($type) {
  return $type - 65280 | 0;
}

function __ZL25ReinterpretDoubleAsUInt64d($d) {
  tempDoubleF64[0] = $d;
  return [ tempDoubleI32[0], tempDoubleI32[1] ];
}

function __ZN2js7SCInputC2EP9JSContextPKyj($this, $cx, $data, $nbytes) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $data;
  HEAP32[$this + 8 >> 2] = $data + ($nbytes >>> 3 << 3) | 0;
  return;
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js12BooleanClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $22 = __ZNK2JS5Value8isObjectEv($1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js12BooleanClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js12BooleanClassE, $3, $10, 0, (__ZN2js12BooleanClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js12BooleanClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isMagicEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_MAGIC_IMPL571($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($1);
    HEAP8[$v] = $4 & 1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isObjectEv($1);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toObjectEv($1);
    var $10 = __ZNK8JSObject8getClassEv($9);
    if (($10 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $9;
    var $14 = __ZNK8JSObject16getPrimitiveThisEv($13);
    var $15 = __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($14);
    HEAP8[$v] = $15 & 1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $18 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($18, $vp, __ZN2js12BooleanClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value9isBooleanEv($v);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value9toBooleanEv($v);
  return $1;
}

function __ZNK8JSObject16getPrimitiveThisEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  return $2;
}

function __ZNK2JS5Value9isBooleanEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_BOOLEAN_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __Z14js_GetSCOffsetP23JSStructuredCloneWriter($writer) {
  var $1 = __ZN23JSStructuredCloneWriter6outputEv($writer);
  var $2 = __ZN2js8SCOutput5countEv($1);
  var $2$0 = $2[0];
  return [ $2$0 << 3 | 0 >>> 29, $2[1] << 3 | $2$0 >>> 29 ];
}

function __ZN2js8SCOutput5countEv($this) {
  var $1 = $this + 4 | 0;
  var $2 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($1);
  return [ $2, 0 ];
}

function __ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv($cx, $v, $bufp, $nbytesp, $cb, $cbClosure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 244;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $out = __stackBase__;
    var $w = __stackBase__ + 28;
    __ZN2js8SCOutputC2EP9JSContext($out, $cx);
    __ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($w, $out, $cb, $cbClosure);
    var $1 = __ZN23JSStructuredCloneWriter4initEv($w);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE($w, $v);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZN2js8SCOutput13extractBufferEPPyPj($out, $bufp, $nbytesp);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    __ZN23JSStructuredCloneWriterD1Ev($w);
    __ZN2js8SCOutputD1Ev($out);
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb, $cbClosure) {
  __ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb, $cbClosure);
  return;
}

function __ZN23JSStructuredCloneWriter4initEv($this) {
  var $1 = $this + 180 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, 0);
  return $2;
}

function __ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE($this, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $val = __stackBase__ + 8;
    var $1 = __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $2 = $this + 96 | 0;
    var $3 = $this + 4 | 0;
    var $4 = $2;
    var $5 = $this | 0;
    var $6 = $this + 120 | 0;
    var $7 = $prop;
    __label__ = 3;
    break;
   case 3:
    var $8 = __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv($2);
    if ($8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($3);
    var $11 = __ZNK2JS5Value8toObjectEv($10);
    var $12 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv($4);
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $13 - 1 | 0;
    HEAP32[$12 >> 2] = $16;
    var $17 = __ZNK2js16AutoVectorRooterIiE4backEv($6);
    var $18 = HEAP32[$17 >> 2];
    __ZN2js16AutoVectorRooterIiE7popBackEv($6);
    var $19 = _JSID_IS_STRING598($18);
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = _JSID_IS_INT594($18);
    if (($22 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $26 = __ZNK8JSObject6getOpsEv($11);
    var $29 = $25;
    var $30 = HEAP32[$26 + 4 >> 2];
    var $31 = $11;
    var $32 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($29, $30, $31, $18, $obj2, $7);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = __ZN23JSStructuredCloneWriter7writeIdEi($this, $18);
    if ($38) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $40 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $41 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($11, $40, $18, $val);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $val);
    if ($44) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $46 = HEAP32[$5 >> 2];
    var $47 = __ZN2js8SCOutput9writePairEjj($46, -65536, 0);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($3);
    __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv($4);
    __label__ = 3;
    break;
   case 13:
    var $49 = $this + 180 | 0;
    __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($49);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE["X"] = 1;

function __ZN2js8SCOutput13extractBufferEPPyPj($this, $datap, $sizep) {
  var $1 = $this + 4 | 0;
  var $2 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($1);
  HEAP32[$sizep >> 2] = $2 << 3;
  var $4 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv($1);
  HEAP32[$datap >> 2] = $4;
  return ($4 | 0) != 0;
}

function __ZN23JSStructuredCloneWriterD1Ev($this) {
  __ZN23JSStructuredCloneWriterD2Ev($this);
  return;
}

function __ZN2js8SCOutputD1Ev($this) {
  __ZN2js8SCOutputD2Ev($this);
  return;
}

function __ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv($cx, $data, $nbytes, $vp, $cb, $cbClosure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 208;
  var $in = __stackBase__;
  var $r = __stackBase__ + 12;
  __ZN2js7SCInputC2EP9JSContextPKyj($in, $cx, $data, $nbytes);
  __ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($r, $in, $cb, $cbClosure);
  var $1 = __ZN23JSStructuredCloneReader4readEPN2JS5ValueE($r, $vp);
  __ZN23JSStructuredCloneReaderD1Ev($r);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb, $cbClosure) {
  __ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb, $cbClosure);
  return;
}

function __ZN23JSStructuredCloneReader4readEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $v = __stackBase__ + 4;
    var $1 = __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $2 = $this + 4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $3 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($2);
    if (($3 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($2);
    var $7 = __ZNK2JS5Value8toObjectEv($6);
    var $8 = __ZN23JSStructuredCloneReader6readIdEPi($this, $id);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $10 = HEAP32[$id >> 2];
    var $11 = _JSID_IS_VOID605($10);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($2);
    __label__ = 3;
    break;
   case 7:
    var $15 = __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $v);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $17 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $18 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $17, $10, $v, 10, 12, 1);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 9:
    var $21 = $this + 96 | 0;
    __ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv($21);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReaderD1Ev($this) {
  __ZN23JSStructuredCloneReaderD2Ev($this);
  return;
}

function __ZN2js7SCInput3eofEv($this) {
  var __stackBase__ = STACKTOP;
  var $2 = HEAP32[$this >> 2];
  _JS_ReportErrorNumber($2, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str573 | 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js7SCInput4readEPy($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js7SCInput3eofEv($this);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = $2 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $10$0 = HEAP32[$2 >> 2];
    var $10$1 = HEAP32[$2 + 4 >> 2];
    var $11 = __ZL9SwapBytesy($10$0, $10$1);
    var $11$0 = $11[0];
    var $11$1 = $11[1];
    HEAP32[$p >> 2] = $11$0;
    HEAP32[$p + 4 >> 2] = $11$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput8readPairEPjS1_($this, $tagp, $datap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    HEAP32[$u >> 2] = 0;
    HEAP32[$u + 4 >> 2] = 0;
    var $1 = __ZN2js7SCInput4readEPy($this, $u);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3$0 = HEAP32[$u >> 2];
    var $5 = HEAP32[$u + 4 >> 2];
    HEAP32[$tagp >> 2] = $5;
    var $6 = $3$0;
    HEAP32[$datap >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput10readDoubleEPd($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pun = __stackBase__;
    var $1 = $pun | 0;
    var $2 = __ZN2js7SCInput4readEPy($this, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $pun;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZL15CanonicalizeNand($5);
    tempDoubleF64[0] = $6, HEAP32[$p >> 2] = tempDoubleI32[0], HEAP32[$p + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15CanonicalizeNand($d) {
  var $1 = _JS_CANONICALIZE_NAN644($d);
  return $1;
}

function __ZN2js7SCInput9readBytesEPvj($this, $p, $nbytes) {
  var $1 = __ZN2js7SCInput9readArrayIhEEbPT_j($this, $p, $nbytes);
  return $1;
}

function __ZN2js7SCInput9readArrayIhEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 7);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 3;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZN2js7SCInput3eofEv($this);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $17 = $8;
    _memcpy($p, $17, $nelems, 1);
    var $19 = HEAP32[$7 >> 2] + ($2 << 3) | 0;
    HEAP32[$7 >> 2] = $19;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readCharsEPtj($this, $p, $nchars) {
  var $1 = __ZN2js7SCInput9readArrayItEEbPT_j($this, $p, $nchars);
  return $1;
}

function __ZN2js7SCInput9readArrayItEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 3);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 2;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZN2js7SCInput3eofEv($this);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $17 = $8;
    var $18 = $17 + ($nelems << 1) | 0;
    if (($17 | 0) == ($18 | 0)) {
      var $25 = $8;
      __label__ = 7;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $17;
      __label__ = 5;
      break;
    }
   case 5:
    var $q_03;
    var $_012;
    var $20 = $q_03 + 2 | 0;
    var $21 = HEAP16[$q_03 >> 1];
    var $22 = __ZL9SwapBytest($21);
    HEAP16[$_012 >> 1] = $22;
    if (($20 | 0) == ($18 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_012 = $_012 + 2 | 0;
      var $q_03 = $20;
      __label__ = 5;
      break;
    }
   case 6:
    var $25 = HEAP32[$7 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $25;
    HEAP32[$7 >> 2] = $25 + ($2 << 3) | 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutputC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $cx;
  var $3 = $this + 4 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8SCOutput5writeEy($this, $u$0, $u$1) {
  var $1 = $this + 4 | 0;
  var $2 = __ZL9SwapBytesy($u$0, $u$1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_($1, $2$0, $2$1);
  return $3;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_($this, $t$0, $t$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_($this, $t$0, $t$1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutput9writePairEjj($this, $tag, $data) {
  var $1 = __ZL12PairToUInt64jj($tag, $data);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZN2js8SCOutput5writeEy($this, $1$0, $1$1);
  return $2;
}

function __ZN2js8SCOutput11writeDoubleEd($this, $d) {
  var $1 = __ZL15CanonicalizeNand($d);
  var $2 = __ZL25ReinterpretDoubleAsUInt64d($1);
  var $2$0 = $2[0];
  var $2$1 = $2[1];
  var $3 = __ZN2js8SCOutput5writeEy($this, $2$0, $2$1);
  return $3;
}

function __ZN2js8SCOutput10writeBytesEPKvj($this, $p, $nbytes) {
  var $1 = __ZN2js8SCOutput10writeArrayIhEEbPKT_j($this, $p, $nbytes);
  return $1;
}

function __ZN2js8SCOutput10writeArrayIhEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 7);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2js8SCOutput7contextEv($this);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 3;
    var $9 = $this + 4 | 0;
    var $10 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($9);
    var $11 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($9);
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($9, $10);
    var $15 = $14;
    _memcpy($15, $p, $nelems, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutput10writeCharsEPKtj($this, $p, $nchars) {
  var $1 = __ZN2js8SCOutput10writeArrayItEEbPKT_j($this, $p, $nchars);
  return $1;
}

function __ZN2js8SCOutput10writeArrayItEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 3);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2js8SCOutput7contextEv($this);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 2;
    var $9 = $this + 4 | 0;
    var $10 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($9);
    var $11 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($9);
    HEAP32[$12 >> 2] = 0;
    HEAP32[$12 + 4 >> 2] = 0;
    var $13 = $p + ($nelems << 1) | 0;
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($9, $10);
    var $_012 = $p;
    var $q_03 = $14;
    __label__ = 6;
    break;
   case 6:
    var $q_03;
    var $_012;
    var $17 = $_012 + 2 | 0;
    var $18 = HEAP16[$_012 >> 1];
    var $19 = __ZL9SwapBytest($18);
    HEAP16[$q_03 >> 1] = $19;
    if (($17 | 0) == ($13 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      var $_012 = $17;
      var $q_03 = $q_03 + 2 | 0;
      __label__ = 6;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] << 3;
    var $7 = __ZN2js15TempAllocPolicy7malloc_Ej($3, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($8, $11, $12);
    HEAP32[$4 >> 2] = 0;
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $14 = $this + 4 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $this + 16 | 0;
    var $17 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($16);
    HEAP32[$14 >> 2] = $17;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 0;
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, $tag, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN2js8SCOutput9writePairEjj($7, $tag, $1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    var $11 = __ZN2js8SCOutput10writeCharsEPKtj($10, $3, $1);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter7contextEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js8SCOutput7contextEv($2);
  return $3;
}

function __ZN23JSStructuredCloneWriter7writeIdEi($this, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT594($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this >> 2];
    var $6 = _JSID_TO_INT595($id);
    var $7 = __ZN2js8SCOutput9writePairEjj($5, -65533, $6);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    var $9 = _JSID_TO_STRING596($id);
    var $10 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $9);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    var $5 = __ZL14ArrayTypeToTagj($4);
    var $6 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $7 = __ZN2js8SCOutput9writePairEjj($3, $5, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $9 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($9 | 0) == 0 || ($9 | 0) == 1 || ($9 | 0) == 8) {
      __label__ = 3;
      break;
    } else if (($9 | 0) == 2 || ($9 | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 4 || ($9 | 0) == 5 || ($9 | 0) == 6) {
      __label__ = 5;
      break;
    } else if (($9 | 0) == 7) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $11 = HEAP32[$2 >> 2];
    var $12 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $13 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $14 = __ZN2js8SCOutput10writeArrayIhEEbPKT_j($11, $12, $13);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 4:
    var $16 = HEAP32[$2 >> 2];
    var $17 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $18 = $17;
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $20 = __ZN2js8SCOutput10writeArrayItEEbPKT_j($16, $18, $19);
    var $_0 = $20;
    __label__ = 7;
    break;
   case 5:
    var $22 = HEAP32[$2 >> 2];
    var $23 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $24 = $23;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $26 = __ZN2js8SCOutput10writeArrayIjEEbPKT_j($22, $24, $25);
    var $_0 = $26;
    __label__ = 7;
    break;
   case 6:
    var $28 = HEAP32[$2 >> 2];
    var $29 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $30 = $29;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $32 = __ZN2js8SCOutput10writeArrayIyEEbPKT_j($28, $30, $31);
    var $_0 = $32;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray7getTypeEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 3);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __ZN2js10TypedArray9getLengthEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 0);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function __ZN2js8SCOutput10writeArrayIjEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 1);
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2js8SCOutput7contextEv($this);
    __Z27js_ReportAllocationOverflowP9JSContext($5);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $7 = $uadd.f0;
    var $8 = $7 >>> 1;
    var $9 = $this + 4 | 0;
    var $10 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($9);
    var $11 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($9, $8);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($9);
    HEAP32[$12 >> 2] = 0;
    HEAP32[$12 + 4 >> 2] = 0;
    var $13 = $p + ($nelems << 2) | 0;
    var $14 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($9, $10);
    var $_012 = $p;
    var $q_03 = $14;
    __label__ = 6;
    break;
   case 6:
    var $q_03;
    var $_012;
    var $17 = $_012 + 4 | 0;
    var $18 = HEAP32[$_012 >> 2];
    var $19 = __ZL9SwapBytesj($18);
    HEAP32[$q_03 >> 2] = $19;
    if (($17 | 0) == ($13 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      var $_012 = $17;
      var $q_03 = $q_03 + 4 | 0;
      __label__ = 6;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SCOutput10writeArrayIyEEbPKT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nelems | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 4 | 0;
    var $4 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv($3);
    var $5 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($3, $nelems);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($3);
    var $st$3$0 = $6 | 0;
    HEAP32[$st$3$0 >> 2] = 0;
    var $st$3$1 = $6 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = 0;
    var $7 = $p + ($nelems << 3) | 0;
    var $8 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($3, $4);
    var $_012 = $p;
    var $q_03 = $8;
    __label__ = 4;
    break;
   case 4:
    var $q_03;
    var $_012;
    var $10 = $_012 + 8 | 0;
    var $st$3$0 = $_012 | 0;
    var $11$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_012 + 4 | 0;
    var $11$1 = HEAP32[$st$3$1 >> 2];
    var $12 = __ZL9SwapBytesy($11$0, $11$1);
    var $12$0 = $12[0];
    var $12$1 = $12[1];
    HEAP32[$q_03 >> 2] = $12$0;
    HEAP32[$q_03 + 4 >> 2] = $12$1;
    if (($10 | 0) == ($7 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_012 = $10;
      var $q_03 = $q_03 + 8 | 0;
      __label__ = 4;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN8JSObject21arrayBufferByteLengthEv($1);
    var $5 = __ZN2js8SCOutput9writePairEjj($3, -65527, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    var $8 = __ZN8JSObject21arrayBufferDataOffsetEv($1);
    var $9 = __ZN8JSObject21arrayBufferByteLengthEv($1);
    var $10 = __ZN2js8SCOutput10writeBytesEPKvj($7, $8, $9);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_STRING598($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSVAL_IS_DOUBLE_IMPL599($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function __ZL14TagToArrayTypej($tag) {
  return $tag + 65280 | 0;
}

function __ZN8JSObject21arrayBufferByteLengthEv($this) {
  return HEAP32[HEAP32[$this + 32 >> 2] >> 2];
}

function __ZN8JSObject21arrayBufferDataOffsetEv($this) {
  return HEAP32[$this + 32 >> 2] + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2jsL7ReverseIiEEvPT_S2_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $beg;
    var $_01 = $end;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_0;
    if (($_0 | 0) == ($_01 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $_01 - 4 | 0;
    if (($4 | 0) == ($_0 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = HEAP32[$_0 >> 2];
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$_0 >> 2] = $8;
    HEAP32[$4 >> 2] = $7;
    var $_0 = $_0 + 4 | 0;
    var $_01 = $4;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject9isBooleanEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js12BooleanClassE | 0);
}

function __ZNK8JSObject8isNumberEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js11NumberClassE | 0);
}

function __ZNK8JSObject8isStringEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js11StringClassE | 0);
}

function __ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN5Chars3getEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN5Chars6forgetEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN23JSStructuredCloneWriter11startObjectEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $4 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $obj;
    var $5 = $this + 180 | 0;
    __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $5, $1);
    var $6 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $6);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$this >> 2];
    var $13 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($6);
    var $15 = HEAP32[$13 + 4 >> 2];
    var $16 = __ZN2js8SCOutput9writePairEjj($12, -65523, $15);
    var $_0 = $16;
    __label__ = 10;
    break;
   case 3:
    var $18 = __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($5);
    HEAP32[$3 >> 2] = $18;
    var $19 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($5, $p, $1, $3);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $21 = __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($5);
    if (($21 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = __ZN23JSStructuredCloneWriter7contextEv($this);
    _JS_ReportErrorNumber($24, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str1574 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 6:
    var $26 = $this + 120 | 0;
    var $27 = $26 | 0;
    var $28 = __ZNK2js16AutoVectorRooterIiE6lengthEv($27);
    var $29 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $30 = HEAP32[$1 >> 2];
    var $31 = $29;
    var $32 = $30;
    var $33 = $26;
    var $34 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($31, $32, 8, $33);
    if ($34) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $36 = __ZN2js16AutoVectorRooterIiE5beginEv($27);
    var $37 = $36 + ($28 << 2) | 0;
    var $38 = __ZN2js16AutoVectorRooterIiE3endEv($27);
    __ZN2jsL7ReverseIiEEvPT_S2_($37, $38);
    var $39 = $this + 4 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($4, $30);
    var $40 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($39, $4);
    if ($40) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $45 = $38 - $37 >> 2;
    var $47 = $this + 96 | 0;
    var $48 = __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_($47, $45);
    if ($48) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $51 = HEAP32[$this >> 2];
    var $52 = __ZNK8JSObject7isArrayEv($30);
    var $53 = $52 ? -65529 : -65528;
    var $54 = __ZN2js8SCOutput9writePairEjj($51, $53, 0);
    var $_0 = $54;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter11startObjectEP8JSObject["X"] = 1;

function __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 78,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIiE5beginEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIiE3endEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($1);
  return $2;
}

function __ZN2JSL11ObjectValueER8JSObject597($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v);
    var $4 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $3);
    var $_0 = $4;
    __label__ = 36;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isNumberEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZNK2JS5Value8toNumberEv($v);
    var $11 = __ZN2js8SCOutput11writeDoubleEd($9, $10);
    var $_0 = $11;
    __label__ = 36;
    break;
   case 5:
    var $13 = __ZNK2JS5Value9isBooleanEv($v);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAP32[$this >> 2];
    var $17 = __ZNK2JS5Value9toBooleanEv($v);
    var $18 = $17 & 1;
    var $19 = __ZN2js8SCOutput9writePairEjj($16, -65534, $18);
    var $_0 = $19;
    __label__ = 36;
    break;
   case 7:
    var $21 = __ZNK2JS5Value6isNullEv($v);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZN2js8SCOutput9writePairEjj($24, -65536, 0);
    var $_0 = $25;
    __label__ = 36;
    break;
   case 9:
    var $27 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = HEAP32[$this >> 2];
    var $31 = __ZN2js8SCOutput9writePairEjj($30, -65535, 0);
    var $_0 = $31;
    __label__ = 36;
    break;
   case 11:
    var $33 = __ZNK2JS5Value8isObjectEv($v);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 12:
    var $35 = __ZNK2JS5Value8toObjectEv($v);
    var $36 = __ZNK8JSObject8isRegExpEv($35);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $38 = __ZN2js6RegExp11extractFromEP8JSObject($35);
    var $40 = HEAP32[$this >> 2];
    var $41 = __ZNK2js6RegExp8getFlagsEv($38);
    var $42 = HEAP32[$41 >> 2];
    var $43 = __ZN2js8SCOutput9writePairEjj($40, -65530, $42);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 14:
    var $45 = __ZNK2js6RegExp9getSourceEv($38);
    var $46 = $45 | 0;
    var $47 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65532, $46);
    var $_0 = $47;
    __label__ = 36;
    break;
   case 15:
    var $49 = __ZNK8JSObject6isDateEv($35);
    if ($49) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $51 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $52 = $51;
    var $53 = $35;
    var $54 = __Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject($52, $53);
    var $55 = $this | 0;
    var $56 = HEAP32[$55 >> 2];
    var $57 = __ZN2js8SCOutput9writePairEjj($56, -65531, 0);
    if ($57) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 17:
    var $59 = HEAP32[$55 >> 2];
    var $60 = __ZN2js8SCOutput11writeDoubleEd($59, $54);
    var $_0 = $60;
    __label__ = 36;
    break;
   case 18:
    var $62 = __ZNK8JSObject8isObjectEv($35);
    if ($62) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = __ZNK8JSObject7isArrayEv($35);
    if ($64) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $66 = __ZN23JSStructuredCloneWriter11startObjectEP8JSObject($this, $35);
    var $_0 = $66;
    __label__ = 36;
    break;
   case 21:
    var $68 = __Z15js_IsTypedArrayP8JSObject($35);
    if (($68 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $71 = __ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject($this, $35);
    var $_0 = $71;
    __label__ = 36;
    break;
   case 23:
    var $73 = __Z16js_IsArrayBufferP8JSObject($35);
    if (($73 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = __ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject($this, $35);
    var $_0 = $76;
    __label__ = 36;
    break;
   case 25:
    var $78 = __ZNK8JSObject9isBooleanEv($35);
    if ($78) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $81 = HEAP32[$this >> 2];
    var $82 = $35;
    var $83 = __ZNK8JSObject16getPrimitiveThisEv($82);
    var $84 = __ZNK2JS5Value9toBooleanEv($83);
    var $85 = $84 & 1;
    var $86 = __ZN2js8SCOutput9writePairEjj($81, -65526, $85);
    var $_0 = $86;
    __label__ = 36;
    break;
   case 27:
    var $88 = __ZNK8JSObject8isNumberEv($35);
    if ($88) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $90 = $this | 0;
    var $91 = HEAP32[$90 >> 2];
    var $92 = __ZN2js8SCOutput9writePairEjj($91, -65524, 0);
    if ($92) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 29:
    var $94 = HEAP32[$90 >> 2];
    var $95 = $35;
    var $96 = __ZNK8JSObject16getPrimitiveThisEv($95);
    var $97 = __ZNK2JS5Value8toNumberEv($96);
    var $98 = __ZN2js8SCOutput11writeDoubleEd($94, $97);
    var $_0 = $98;
    __label__ = 36;
    break;
   case 30:
    var $100 = __ZNK8JSObject8isStringEv($35);
    if ($100) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $102 = $35;
    var $103 = __ZNK8JSObject16getPrimitiveThisEv($102);
    var $104 = __ZNK2JS5Value8toStringEv($103);
    var $105 = __ZN23JSStructuredCloneWriter11writeStringEjP8JSString($this, -65525, $104);
    var $_0 = $105;
    __label__ = 36;
    break;
   case 32:
    var $108 = HEAP32[$this + 208 >> 2];
    if (($108 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $112 = HEAP32[$108 + 4 >> 2];
    if (($112 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $115 = __ZN23JSStructuredCloneWriter7contextEv($this);
    var $117 = HEAP32[$this + 212 >> 2];
    var $118 = FUNCTION_TABLE[$112]($115, $this, $35, $117);
    var $_0 = ($118 | 0) != 0;
    __label__ = 36;
    break;
   case 35:
    var $121 = __ZN23JSStructuredCloneWriter7contextEv($this);
    _JS_ReportErrorNumber($121, 2, 0, 261, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE["X"] = 1;

function __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($1);
  return $2;
}

function __ZNK2js16AutoVectorRooterIiE4backEv($this) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIiE7popBackEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN23JSStructuredCloneReader11checkDoubleEd($this, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $2 = _JSVAL_IS_DOUBLE_IMPL599($1$0, $1$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($5, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2575 | 0, tempInt));
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReader7contextEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js7SCInput7contextEv($2);
  return $3;
}

function __ZN23JSStructuredCloneReader10readStringEj($this, $nchars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chars = __stackBase__;
    if ($nchars >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($3, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str3576 | 0, tempInt));
    var $_1 = 0;
    __label__ = 8;
    break;
   case 3:
    __ZN5CharsC1Ev($chars);
    var $5 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $6 = __ZN5Chars8allocateEP9JSContextj($chars, $5, $nchars);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZN5Chars3getEv($chars);
    var $11 = __ZN2js7SCInput9readCharsEPtj($9, $10, $nchars);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $14 = __ZN5Chars3getEv($chars);
    var $15 = $13;
    var $16 = __Z12js_NewStringP9JSContextPtj($15, $14, $nchars);
    var $17 = $16 | 0;
    if (($16 | 0) == 0) {
      var $_0 = $17;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN5Chars6forgetEv($chars);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN5CharsD1Ev($chars);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsC1Ev($this) {
  __ZN5CharsC2Ev($this);
  return;
}

function __ZN5Chars8allocateEP9JSContextj($this, $cx, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($len << 1) + 2 | 0;
    var $3 = __ZN9JSContext7malloc_Ej($cx, $2);
    var $4 = $3;
    HEAP32[$this + 4 >> 2] = $4;
    HEAP32[$this >> 2] = $cx;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$4 + ($len << 1) >> 1] = 0;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsD1Ev($this) {
  __ZN5CharsD2Ev($this);
  return;
}

function __ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE($this, $tag, $nelems, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14TagToArrayTypej($tag);
    var $2 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $3 = __Z19js_CreateTypedArrayP9JSContextij($2, $1, $nelems);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($3);
    if (($1 | 0) == 0 || ($1 | 0) == 1 || ($1 | 0) == 8) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 2 || ($1 | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 4 || ($1 | 0) == 5 || ($1 | 0) == 6) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 7) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($6);
    var $11 = __ZN2js7SCInput9readArrayIhEEbPT_j($9, $10, $nelems);
    var $_0 = $11;
    __label__ = 7;
    break;
   case 4:
    var $14 = HEAP32[$this >> 2];
    var $15 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($6);
    var $16 = $15;
    var $17 = __ZN2js7SCInput9readArrayItEEbPT_j($14, $16, $nelems);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 5:
    var $20 = HEAP32[$this >> 2];
    var $21 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($6);
    var $22 = $21;
    var $23 = __ZN2js7SCInput9readArrayIjEEbPT_j($20, $22, $nelems);
    var $_0 = $23;
    __label__ = 7;
    break;
   case 6:
    var $26 = HEAP32[$this >> 2];
    var $27 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($6);
    var $28 = $27;
    var $29 = __ZN2js7SCInput9readArrayIyEEbPT_j($26, $28, $nelems);
    var $_0 = $29;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readArrayIjEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($nelems, 1);
    var $1 = $uadd.f0;
    var $2 = $1 >>> 1;
    var $3 = $uadd.f1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAPU32[$7 >> 2];
    if ($2 >>> 0 > HEAP32[$this + 8 >> 2] - $8 >> 3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZN2js7SCInput3eofEv($this);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $17 = $8;
    var $18 = $17 + ($nelems << 2) | 0;
    if (($17 | 0) == ($18 | 0)) {
      var $25 = $8;
      __label__ = 7;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $17;
      __label__ = 5;
      break;
    }
   case 5:
    var $q_03;
    var $_012;
    var $20 = $q_03 + 4 | 0;
    var $21 = HEAP32[$q_03 >> 2];
    var $22 = __ZL9SwapBytesj($21);
    HEAP32[$_012 >> 2] = $22;
    if (($20 | 0) == ($18 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_012 = $_012 + 4 | 0;
      var $q_03 = $20;
      __label__ = 5;
      break;
    }
   case 6:
    var $25 = HEAP32[$7 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $25;
    HEAP32[$7 >> 2] = $25 + ($2 << 3) | 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7SCInput9readArrayIyEEbPT_j($this, $p, $nelems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (HEAP32[$this + 8 >> 2] - $4 >> 3 >>> 0 < $nelems >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN2js7SCInput3eofEv($this);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $13 = $4 + ($nelems << 3) | 0;
    if (($nelems | 0) == 0) {
      var $20 = $4;
      __label__ = 6;
      break;
    } else {
      var $_012 = $p;
      var $q_03 = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $q_03;
    var $_012;
    var $15 = $q_03 + 8 | 0;
    var $16$0 = HEAP32[$q_03 >> 2];
    var $16$1 = HEAP32[$q_03 + 4 >> 2];
    var $17 = __ZL9SwapBytesy($16$0, $16$1);
    var $17$0 = $17[0];
    var $17$1 = $17[1];
    HEAP32[$_012 >> 2] = $17$0;
    HEAP32[$_012 + 4 >> 2] = $17$1;
    if (($15 | 0) == ($13 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $_012 + 8 | 0;
      var $q_03 = $15;
      __label__ = 4;
      break;
    }
   case 5:
    var $20 = HEAP32[$3 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $20;
    HEAP32[$3 >> 2] = $20 + ($nelems << 3) | 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE($this, $nbytes, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $2 = __Z20js_CreateArrayBufferP9JSContextj($1, $nbytes);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $6 = HEAP32[$this >> 2];
    var $7 = __ZN8JSObject21arrayBufferDataOffsetEv($2);
    var $8 = __ZN2js7SCInput9readArrayIhEEbPT_j($6, $7, $nbytes);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9SwapBytesj($u) {
  return $u;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function _INT_TO_JSID603($i) {
  return $i << 1 | 1;
}

function _JSID_IS_VOID605($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZL18JSDOUBLE_IS_FINITEd600($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIjEcvRjEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIjEC2ERj($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tag = __stackBase__;
    var $data = __stackBase__ + 4;
    var $d = __stackBase__ + 8;
    var $d1 = __stackBase__ + 16;
    var $tag2 = __stackBase__ + 24;
    var $nchars = __stackBase__ + 28;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = $this | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZN2js7SCInput8readPairEPjS1_($4, $tag, $data);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 2:
    var $7 = HEAPU32[$tag >> 2];
    if (($7 | 0) == -65536) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == -65535) {
      __label__ = 4;
      break;
    } else if (($7 | 0) == -65534 || ($7 | 0) == -65526) {
      __label__ = 5;
      break;
    } else if (($7 | 0) == -65532 || ($7 | 0) == -65525) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == -65524) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == -65531) {
      __label__ = 13;
      break;
    } else if (($7 | 0) == -65530) {
      __label__ = 26;
      break;
    } else if (($7 | 0) == -65529 || ($7 | 0) == -65528) {
      __label__ = 33;
      break;
    } else if (($7 | 0) == -65523) {
      __label__ = 40;
      break;
    } else if (($7 | 0) == -65527) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 3:
    __ZN2JS5Value7setNullEv($vp);
    __label__ = 54;
    break;
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 54;
    break;
   case 5:
    var $12 = (HEAP32[$data >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $12);
    if (($7 | 0) == -65526) {
      __label__ = 6;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 6:
    var $15 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $16 = $15;
    var $17 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($16, $vp);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 7:
    var $20 = HEAP32[$data >> 2];
    var $21 = __ZN23JSStructuredCloneReader10readStringEj($this, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value9setStringEP8JSString($vp, $21);
    if (($7 | 0) == -65525) {
      __label__ = 9;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 9:
    var $26 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $27 = $26;
    var $28 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($27, $vp);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 10:
    var $31 = HEAP32[$3 >> 2];
    var $32 = __ZN2js7SCInput10readDoubleEPd($31, $d);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 11:
    var $34 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $35 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $34);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 12:
    __ZN2JS5Value9setDoubleEd($vp, $34);
    var $37 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $38 = $37;
    var $39 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($38, $vp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 13:
    var $42 = HEAP32[$3 >> 2];
    var $43 = __ZN2js7SCInput10readDoubleEPd($42, $d1);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 14:
    var $45 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $46 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $45);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 15:
    var $48 = !isNaN($45) && !isNaN(0);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 16:
    var $50 = __ZL18JSDOUBLE_IS_FINITEd600($45);
    if (($50 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ($45 < 0) {
      __label__ = 18;
      break;
    } else {
      var $57 = $45;
      __label__ = 19;
      break;
    }
   case 18:
    var $57 = -$45;
    __label__ = 19;
    break;
   case 19:
    var $57;
    if ($57 > 864e13) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $60 = $45;
    var $61 = __ZL18js_DoubleToIntegerd601($60);
    var $65 = $61;
    __label__ = 22;
    break;
   case 21:
    var $63 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $65 = $63;
    __label__ = 22;
    break;
   case 22:
    var $65;
    if ($45 != $65) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $68 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($68, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str4577 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 24:
    var $70 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $71 = $70;
    var $72 = __Z20js_NewDateObjectMsecP9JSContextd($71, $45);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $75 = $72;
    __ZN2JS5Value9setObjectER8JSObject($vp, $75);
    __label__ = 54;
    break;
   case 26:
    var $77 = HEAP32[$3 >> 2];
    var $78 = __ZN2js7SCInput8readPairEPjS1_($77, $tag2, $nchars);
    if ($78) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 27:
    if ((HEAP32[$tag2 >> 2] | 0) == -65532) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $83 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($83, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str5578 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 29:
    var $85 = HEAP32[$nchars >> 2];
    var $86 = __ZN23JSStructuredCloneReader10readStringEj($this, $85);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $89 = __ZNK8JSString6lengthEv($86);
    var $90 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $91 = __ZN8JSString8getCharsEP9JSContext($86, $90);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $94 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $95 = HEAP32[$data >> 2];
    var $96 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($94, $91, $89, $95, 0);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JS5Value9setObjectER8JSObject($vp, $96);
    __label__ = 54;
    break;
   case 33:
    var $100 = ($7 | 0) == -65529;
    var $101 = __ZN23JSStructuredCloneReader7contextEv($this);
    if ($100) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $103 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($101, 0);
    var $107 = $103;
    __label__ = 36;
    break;
   case 35:
    var $105 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602($101);
    var $107 = $105;
    __label__ = 36;
    break;
   case 36:
    var $107;
    if (($107 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $110 = $this + 4 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($1, $107);
    var $111 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($110, $1);
    if ($111) {
      __label__ = 38;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 38:
    var $113 = $this + 96 | 0;
    __ZN2JSL11ObjectValueER8JSObject597($2, $107);
    var $114 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($113, $2);
    if ($114) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 39:
    __ZN2JS5Value9setObjectER8JSObject($vp, $107);
    __label__ = 54;
    break;
   case 40:
    var $117 = HEAPU32[$data >> 2];
    var $118 = $this + 96 | 0;
    var $119 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($118);
    if ($117 >>> 0 < $119 >>> 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $122 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($122, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str6579 | 0, tempInt));
    __label__ = 42;
    break;
   case 42:
    var $124 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($118, $117);
    var $125 = $124 | 0;
    var $126$0 = HEAP32[$125 >> 2];
    var $126$1 = HEAP32[$125 + 4 >> 2];
    var $127 = $vp | 0;
    HEAP32[$127 >> 2] = $126$0;
    HEAP32[$127 + 4 >> 2] = $126$1;
    __label__ = 54;
    break;
   case 43:
    var $129 = HEAP32[$data >> 2];
    var $130 = __ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE($this, $129, $vp);
    var $_0 = $130;
    __label__ = 55;
    break;
   case 44:
    if ($7 >>> 0 < 4293918721) {
      __label__ = 45;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 45:
    var $134 = HEAP32[$data >> 2];
    var $135 = __ZL23ReinterpretPairAsDoublejj($7, $134);
    var $136 = __ZN23JSStructuredCloneReader11checkDoubleEd($this, $135);
    if ($136) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 0;
      __label__ = 55;
      break;
    }
   case 46:
    var $138 = __ZN2JS5Value9setNumberEd($vp, $135);
    __label__ = 54;
    break;
   case 47:
    if (($7 + 65280 | 0) >>> 0 < 9) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $142 = HEAP32[$data >> 2];
    var $143 = __ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE($this, $7, $142, $vp);
    var $_0 = $143;
    __label__ = 55;
    break;
   case 49:
    var $146 = HEAP32[$this + 188 >> 2];
    if (($146 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $150 = HEAPU32[$146 >> 2];
    if (($150 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $153 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($153, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str7580 | 0, tempInt));
    var $_0 = 0;
    __label__ = 55;
    break;
   case 52:
    var $155 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $156 = HEAP32[$data >> 2];
    var $158 = HEAP32[$this + 192 >> 2];
    var $159 = FUNCTION_TABLE[$150]($155, $this, $7, $156, $158);
    if (($159 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    __ZN2JS5Value9setObjectER8JSObject($vp, $159);
    __label__ = 54;
    break;
   case 54:
    var $_0 = 1;
    __label__ = 55;
    break;
   case 55:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE["X"] = 1;

function __ZL18js_DoubleToIntegerd601($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd600($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd628($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb613($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614($cx, $4);
  return $5;
}

function __ZL23ReinterpretPairAsDoublejj($tag, $data) {
  var $1 = __ZL12PairToUInt64jj($tag, $data);
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2 = __ZL25ReinterpretUInt64AsDoubley($1$0, $1$1);
  return $2;
}

function __ZN23JSStructuredCloneReader6readIdEPi($this, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tag = __stackBase__;
    var $data = __stackBase__ + 4;
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js7SCInput8readPairEPjS1_($2, $tag, $data);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $5 = HEAP32[$tag >> 2];
    if (($5 | 0) == -65533) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == -65532) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == -65536) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = HEAP32[$data >> 2];
    var $8 = _INT_TO_JSID603($7);
    HEAP32[$idp >> 2] = $8;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $10 = HEAP32[$data >> 2];
    var $11 = __ZN23JSStructuredCloneReader10readStringEj($this, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN23JSStructuredCloneReader7contextEv($this);
    var $15 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($14, $11, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZL12ATOM_TO_JSIDP6JSAtom604($15);
    HEAP32[$idp >> 2] = $18;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    HEAP32[$idp >> 2] = 2;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $21 = __ZN23JSStructuredCloneReader7contextEv($this);
    _JS_ReportErrorNumber($21, 2, 0, 260, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2273379 | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom604($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj609($1);
  return $2;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 8 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE($27, $1);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $9);
  var $10 = __ZNK2js7MoveRefIjEcvRjEv($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIjEC1ERj($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIjEC1ERj($this, $t) {
  __ZN2js7MoveRefIjEC2ERj($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP8JSObjectjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectjEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectjEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZL9SwapBytest($u) {
  return $u;
}

function __ZL14JSID_FROM_BITSj609($bits) {
  return $bits;
}

function __Z16js_FinishThreadsP9JSRuntime($rt) {
  return;
}

function _JS_CANONICALIZE_NAN644($d) {
  var $1 = isNaN($d) || isNaN(0);
  var $_d = $1 ? NaN : $d;
  return $_d;
}

function __ZL25ReinterpretUInt64AsDoubley($u$0, $u$1) {
  var $1 = (tempDoubleI32[0] = $u$0, tempDoubleI32[1] = $u$1, tempDoubleF64[0]);
  return $1;
}

function __ZL15JSDOUBLE_IS_NaNd628($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($e) {
  return $e | 0;
}

function __ZNK2js8SCOutput7contextEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2$0 = HEAP32[$p_01 >> 2];
    var $2$1 = HEAP32[$p_01 + 4 >> 2];
    HEAP32[$_02 >> 2] = $2$0;
    HEAP32[$_02 + 4 >> 2] = $2$1;
    var $3 = $p_01 + 8 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb613($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsC2Ev($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js7SCInput7contextEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_CurrentThreadDataP9JSRuntime($rt) {
  return $rt + 144280 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($1);
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 8 | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 3;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_($this, $t$0, $t$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t$0;
    HEAP32[$1 + 4 >> 2] = $t$1;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN5CharsD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneReaderD2Ev($this) {
  var $1 = $this + 96 | 0;
  __ZN2js15AutoValueVectorD1Ev($1);
  var $2 = $this + 4 | 0;
  __ZN2js15AutoValueVectorD1Ev($2);
  return;
}

function __ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv($this, $in, $cb, $cbClosure) {
  HEAP32[$this >> 2] = $in;
  var $2 = $this + 4 | 0;
  var $3 = __ZNK2js7SCInput7contextEv($in);
  __ZN2js15AutoValueVectorC1EP9JSContext($2, $3);
  var $4 = $this + 96 | 0;
  var $5 = __ZNK2js7SCInput7contextEv($in);
  __ZN2js15AutoValueVectorC1EP9JSContext($4, $5);
  HEAP32[$this + 188 >> 2] = $cb;
  HEAP32[$this + 192 >> 2] = $cbClosure;
  return;
}

function __ZN2js8SCOutputD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterD2Ev($this) {
  var $1 = $this + 180 | 0;
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this + 120 | 0;
  __ZN2js12AutoIdVectorD1Ev($2);
  var $4 = $this + 96 | 0;
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev($4);
  var $5 = $this + 4 | 0;
  __ZN2js15AutoValueVectorD1Ev($5);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv($this, $out, $cb, $cbClosure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$this >> 2] = $out;
  var $4 = $this + 4 | 0;
  var $5 = __ZNK2js8SCOutput7contextEv($out);
  __ZN2js15AutoValueVectorC1EP9JSContext($4, $5);
  var $6 = $this + 96 | 0;
  var $7 = __ZNK2js8SCOutput7contextEv($out);
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $7);
  var $8 = $6;
  __ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_($8, $1);
  var $9 = $this + 120 | 0;
  var $10 = __ZNK2js8SCOutput7contextEv($out);
  __ZN2js12AutoIdVectorC1EP9JSContext($9, $10);
  var $11 = $this + 180 | 0;
  var $12 = __ZNK2js8SCOutput7contextEv($out);
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $12);
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($11, $2);
  HEAP32[$this + 208 >> 2] = $cb;
  HEAP32[$this + 212 >> 2] = $cbClosure;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10ThreadDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js10StackSpaceC2Ev($3);
  HEAP8[$this + 24 | 0] = 0;
  var $5 = $this + 28 | 0;
  __ZN2js8GSNCacheC1Ev($5);
  var $6 = $this + 56 | 0;
  __ZN2js13PropertyCacheC1Ev($6);
  HEAP32[$this + 65596 >> 2] = 0;
  var $8 = $this + 65600 | 0;
  var $9 = __ZN2js18GetNativeStackBaseEv();
  HEAP32[$8 >> 2] = $9;
  HEAP32[$this + 65604 >> 2] = 0;
  var $11 = $this + 65608 | 0;
  __ZN2js24ConservativeGCThreadDataC1Ev($11);
  HEAP32[$this + 65656 >> 2] = 0;
  return;
}

function __ZN2js8GSNCacheC1Ev($this) {
  __ZN2js8GSNCacheC2Ev($this);
  return;
}

function __ZN2js13PropertyCacheC1Ev($this) {
  __ZN2js13PropertyCacheC2Ev($this);
  return;
}

function __ZN2js18GetNativeStackBaseEv() {
  var $1 = __ZN2js22GetNativeStackBaseImplEv();
  return $1;
}

function __ZN2js24ConservativeGCThreadDataC1Ev($this) {
  __ZN2js24ConservativeGCThreadDataC2Ev($this);
  return;
}

function __ZN2js10ThreadDataD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 65596 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _js_DestroyDtoaState($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 28 | 0;
    __ZN2js8GSNCacheD1Ev($6);
    var $8 = $this + 4 | 0;
    __ZN2js10StackSpaceD2Ev($8);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GSNCacheD1Ev($this) {
  __ZN2js8GSNCacheD2Ev($this);
  return;
}

function __ZN2js10ThreadData4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this + 4 | 0;
    var $3 = __ZN2js10StackSpace4initEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = _js_NewDtoaState();
    HEAP32[$this + 65596 >> 2] = $5;
    var $9 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_GetCurrentScriptP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($cx);
    var $4 = __ZNK2js10StackFrame11maybeScriptEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_InitThreadsP9JSRuntime($rt) {
  var $1 = $rt + 144280 | 0;
  var $2 = __ZN2js10ThreadData4initEv($1);
  return $2 & 1;
}

function __Z15js_PurgeThreadsP9JSContext($cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144280 | 0;
  __ZN2js10ThreadData5purgeEP9JSContext($3, undef);
  return;
}

function __ZN2js10ThreadData5purgeEP9JSContext($this, $cx) {
  var $2 = $this + 28 | 0;
  __ZN2js8GSNCache5purgeEv($2);
  var $3 = $this + 56 | 0;
  __ZN2js13PropertyCache5purgeEP9JSContext($3, undef);
  return;
}

function __Z13js_NewContextP9JSRuntimej($rt, $stackChunkSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $1 = __ZN2js11OffTheBooks7calloc_Ej(312);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN9JSContextC2EP9JSRuntime($4, $rt);
    HEAP32[$1 + 200 >> 2] = $rt + 144148 | 0;
    HEAP32[$1 + 48 >> 2] = -1;
    var $11 = $1 + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($11, 3);
    var $13 = $1 + 72 | 0;
    _JS_InitArenaPool($13, undef, 4056, 8);
    var $15 = $1 + 104 | 0;
    _JS_InitArenaPool($15, undef, 4056, 4);
    var $17 = $1 + 148 | 0;
    var $18 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($17, 0);
    if ($18) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $19 = $rt + 24 | 0;
    var $20 = HEAP32[$19 >> 2];
    __label__ = 5;
    break;
   case 4:
    __ZN2js10Foreground7delete_I9JSContextEEvPT_($4);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 5:
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($20 | 0) == 2) {
      var $first_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 6:
    HEAP32[$19 >> 2] = 1;
    var $first_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $first_0;
    var $25 = $1;
    HEAP32[$1 >> 2] = $rt + 144140 | 0;
    var $27 = $rt + 144144 | 0;
    var $28 = HEAP32[$27 >> 2];
    HEAP32[$1 + 4 >> 2] = $28;
    var $32 = HEAP32[$27 >> 2] | 0;
    HEAP32[$32 >> 2] = $25;
    HEAP32[$27 >> 2] = $25;
    var $33 = $1;
    __Z13js_InitRandomP9JSContext($33);
    if ($first_0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $35 = $rt + 210584 | 0;
    var $36 = __ZN2js13StaticStrings4initEP9JSContext($35, $4);
    var $37 = $36 & 1;
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $ok_0 = $37;
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = __Z18js_InitCommonAtomsP9JSContext($4);
    var $ok_0 = $39 & 1;
    __label__ = 10;
    break;
   case 10:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($4, 3);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 12:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    HEAP32[$19 >> 2] = 2;
    __label__ = 13;
    break;
   case 13:
    var $47 = HEAP32[$rt + 28 >> 2];
    if (($47 | 0) == 0) {
      var $_0 = $4;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = FUNCTION_TABLE[$47]($4, 0);
    if (($50 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = $4;
      __label__ = 16;
      break;
    }
   case 15:
    __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($4, 3);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_NewContextP9JSRuntimej["X"] = 1;

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js10Foreground7delete_I9JSContextEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContextD2Ev($p);
    var $3 = $p;
    _js_free816($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext13fromLinkFieldEP10JSCListStr($link) {
  return $link;
}

function __ZNK2js13AutoResolving18alreadyStartedSlowEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 12 | 0;
    var $5 = HEAP32[$this + 4 >> 2];
    var $6 = $this + 8 | 0;
    var $cursor_0 = HEAP32[$this + 16 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $cursor_0;
    if (($5 | 0) == (HEAP32[$cursor_0 + 4 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$6 >> 2] | 0) == (HEAP32[$cursor_0 + 8 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if ((HEAP32[$3 >> 2] | 0) == (HEAP32[$cursor_0 + 12 >> 2] | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[$cursor_0 + 16 >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $cursor_0 = $23;
      __label__ = 2;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_GetErrorMessagePvPKcj($userRef, $locale, $errorNumber) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($errorNumber | 0) != 0 & $errorNumber >>> 0 < 287) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = _js_ErrorFormatString + ($errorNumber << 3) | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DestroyContextP9JSContext20JSDestroyContextMode($cx, $mode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $2 = HEAPU32[$cx + 52 >> 2];
    if (($mode | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 28 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = FUNCTION_TABLE[$6]($cx, 1);
    __label__ = 4;
    break;
   case 4:
    var $11 = $cx | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $cx + 4 | 0;
    var $15 = HEAP32[$13 >> 2] | 0;
    HEAP32[$15 >> 2] = $12;
    var $16 = HEAP32[$13 >> 2];
    var $18 = HEAP32[$11 >> 2] + 4 | 0;
    HEAP32[$18 >> 2] = $16;
    var $19 = $2 + 144140 | 0;
    if ((HEAP32[$19 >> 2] | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($mode - 1 | 0) >>> 0 < 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 6:
    var $25 = $2 + 24 | 0;
    HEAP32[$25 >> 2] = 3;
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    var $26 = $2 + 4 | 0;
    var $27 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($26);
    var $28 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($26);
    if ($27 >>> 0 < $28 >>> 0) {
      var $compartment_05 = $27;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $compartment_05;
    var $31 = HEAP32[$compartment_05 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment5printEP9JSContextb($31, $cx, 0);
    var $32 = $compartment_05 + 4 | 0;
    if ($32 >>> 0 < $28 >>> 0) {
      var $compartment_05 = $32;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __Z20js_FinishCommonAtomsP9JSContext($cx);
    var $34 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($26);
    var $35 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($26);
    if (($34 | 0) == ($35 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $c_04 = $34;
      __label__ = 9;
      break;
    }
   case 9:
    var $c_04;
    var $37 = HEAP32[$c_04 >> 2];
    __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($37, $cx, 0);
    var $38 = $c_04 + 4 | 0;
    var $39 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($26);
    if (($38 | 0) == ($39 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $c_04 = $38;
      __label__ = 9;
      break;
    }
   case 10:
    var $42 = $cx;
    var $43 = _JS_ClearAllWatchPoints($42);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[__ZN2js8gcReasonE >> 2] = 2;
    __label__ = 13;
    break;
   case 12:
    var $48 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $48;
    __label__ = 13;
    break;
   case 13:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 1);
    HEAP32[$25 >> 2] = 0;
    __label__ = 23;
    break;
   case 14:
    if (($mode | 0) == 2) {
      __label__ = 15;
      break;
    } else if (($mode | 0) == 1) {
      __label__ = 19;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[__ZN2js8gcReasonE >> 2] = 3;
    __label__ = 18;
    break;
   case 17:
    var $55 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $55;
    __label__ = 18;
    break;
   case 18:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 0);
    __label__ = 23;
    break;
   case 19:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[__ZN2js8gcReasonE >> 2] = 3;
    __label__ = 22;
    break;
   case 21:
    var $62 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $62;
    __label__ = 22;
    break;
   case 22:
    _JS_MaybeGC($cx);
    __label__ = 23;
    break;
   case 23:
    __ZN2js10Foreground7delete_I9JSContextEEvPT_($cx);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_DestroyContextP9JSContext20JSDestroyContextMode["X"] = 1;

function __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($rt, $unlocked, $iterp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lockIf = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $rt;
    var $2 = HEAP32[$iterp >> 2];
    __ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev($lockIf);
    if (($unlocked | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_($lockIf, $1);
    __label__ = 3;
    break;
   case 3:
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_in = $2 | 0;
    var $13 = HEAP32[$1 >> 2];
    __label__ = 6;
    break;
   case 5:
    var $10 = HEAP32[$1 >> 2];
    var $_in = $10 + 144140 | 0;
    var $13 = $10;
    __label__ = 6;
    break;
   case 6:
    var $13;
    var $_in;
    var $14 = HEAP32[$_in >> 2];
    var $15 = __ZN9JSContext13fromLinkFieldEP10JSCListStr($14);
    var $cx_0 = ($15 | 0) == ($13 + 144140 | 0) ? 0 : $15;
    HEAP32[$iterp >> 2] = $cx_0;
    STACKTOP = __stackBase__;
    return $cx_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_($this, $t1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$t1 >> 2];
    __ZN2js10AutoLockGCC1EP9JSRuntime($2, $5);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 8 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_NextActiveContextP9JSRuntimeP9JSContext($rt, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $iter = __stackBase__;
  HEAP32[$iter >> 2] = $cx;
  var $1 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($rt, 0, $iter);
  STACKTOP = __stackBase__;
  return $1;
}

function __Z20js_ReportOutOfMemoryP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $report = __stackBase__;
    var $incr = __stackBase__ + 40;
    var $1 = $cx + 52 | 0;
    var $3 = HEAP32[$1 >> 2] + 144224 | 0;
    HEAP32[$3 >> 2] = 1;
    var $5 = HEAP32[$cx + 180 >> 2];
    var $6 = $cx;
    var $7 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($6, 0, 0, 137);
    if (($7 | 0) == 0) {
      var $13 = STRING_TABLE.__str2647 | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$7 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $13;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    HEAP32[$report + 24 >> 2] = 0;
    HEAP32[$report + 28 >> 2] = 137;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[$cx + 200 >> 2];
    var $21 = HEAP32[$19 + 64 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$19 + 68 >> 2];
    var $26 = FUNCTION_TABLE[$21]($cx, $13, $report, $25);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP32[$1 >> 2] + 229028 | 0;
    __ZN2js19AutoAtomicIncrementC1EPi($incr, $29);
    FUNCTION_TABLE[$5]($cx, $13, $report);
    __ZN2js19AutoAtomicIncrementD1Ev($incr);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx, 0);
    __label__ = 2;
    break;
   case 2:
    var $2 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $5 = __ZNK2js10StackFrame13isScriptFrameEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js10StackFrame6scriptEv($4);
    var $9 = HEAP32[$7 + 52 >> 2];
    HEAP32[$report >> 2] = $9;
    var $11 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $12 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $13 = $cx;
    var $14 = $11;
    var $15 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($13, $14, $12);
    HEAP32[$report + 4 >> 2] = $15;
    __label__ = 6;
    break;
   case 5:
    var $18 = __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 2;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19AutoAtomicIncrementC1EPi($this, $p) {
  __ZN2js19AutoAtomicIncrementC2EPi($this, $p);
  return;
}

function __ZN2js19AutoAtomicIncrementD1Ev($this) {
  __ZN2js19AutoAtomicIncrementD2Ev($this);
  return;
}

function __Z21js_ReportOverRecursedP9JSContext($maybecx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($maybecx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($maybecx, 2, 0, 26, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_ReportAllocationOverflowP9JSContext($maybecx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($maybecx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($maybecx, 2, 0, 6, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ReportErrorVAP9JSContextjPKcPc($cx, $flags, $format, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $messagelen = __stackBase__ + 4;
    var $report = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZL16checkReportFlagsP9JSContextPj($cx, $1);
    if ($2) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_vsmprintf($format, $ap);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _strlen($4);
    HEAP32[$messagelen >> 2] = $7;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    var $8 = HEAP32[$1 >> 2];
    var $9 = $report + 24 | 0;
    HEAP32[$9 >> 2] = $8;
    HEAP32[$report + 28 >> 2] = 206;
    var $11 = $cx;
    var $12 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($11, $4, $messagelen, 0);
    HEAP32[$report + 32 >> 2] = $12;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    var $15 = HEAP32[$9 >> 2] & 1;
    __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $4, $report, 0, 0);
    __ZN2js10Foreground5free_EPv($4);
    var $16 = $12;
    __ZN2js10Foreground5free_EPv($16);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16checkReportFlagsP9JSContextPj($cx, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$flags >> 2];
    if (($1 & 8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx + 60 | 0;
    var $6 = __ZNK2js12ContextStack13currentScriptEPPh($5, 0);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$6 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$flags >> 2] & -2;
    HEAP32[$flags >> 2] = $15;
    var $27 = $15;
    __label__ = 9;
    break;
   case 5:
    var $17 = __ZNK9JSContext15hasStrictOptionEv($cx);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 6:
    var $20 = HEAP32[$flags >> 2] | 1;
    HEAP32[$flags >> 2] = $20;
    var $27 = $20;
    __label__ = 9;
    break;
   case 7:
    if (($1 & 4 | 0) == 0) {
      var $27 = $1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZNK9JSContext15hasStrictOptionEv($cx);
    if ($25) {
      var $27 = $1;
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 9:
    var $27;
    if (($27 & 1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZNK9JSContext15hasWErrorOptionEv($cx);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$flags >> 2] = $27 & -2;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $message, $reportp, $callback, $userRef) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($callback | 0) == 0 | ($callback | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$reportp + 28 >> 2] | 0) == 147) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $reportp + 24 | 0;
    var $10 = HEAP32[$8 >> 2] | 2;
    HEAP32[$8 >> 2] = $10;
    __label__ = 4;
    break;
   case 4:
    var $12 = _JS_IsRunning($cx);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $cx;
    var $16 = $reportp;
    var $17 = __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($15, $message, $16, $callback, $userRef);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($cx, $message, $reportp);
    __label__ = 10;
    break;
   case 7:
    var $22 = HEAP32[$cx + 200 >> 2];
    var $24 = HEAP32[$22 + 64 >> 2];
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$cx + 180 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAP32[$22 + 68 >> 2];
    var $33 = FUNCTION_TABLE[$24]($cx, $message, $reportp, $32);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($cx, $callback, $userRef, $errorNumber, $messagep, $reportp, $charArgs, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argLengths = __stackBase__;
    var $charArgLength = __stackBase__ + 40;
    var $len = __stackBase__ + 44;
    var $len1 = __stackBase__ + 48;
    HEAP32[$messagep >> 2] = 0;
    if (($callback | 0) == 0 | ($callback | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($4, $userRef, 0, $errorNumber);
    var $efs_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = FUNCTION_TABLE[$callback]($userRef, 0, $errorNumber);
    var $efs_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $efs_0;
    if (($efs_0 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = HEAPU16[$efs_0 + 4 >> 1];
    var $13 = $12 & 65535;
    if ($12 << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAPU32[$efs_0 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 7:
    var $20 = ($13 << 2) + 4 | 0;
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    var $22 = $21;
    var $23 = $reportp + 36 | 0;
    HEAP32[$23 >> 2] = $22;
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$22 + ($13 << 2) >> 2] = 0;
    var $27 = $cx;
    var $totalArgsLength_0 = 0;
    var $i_0 = 0;
    var $_02 = $ap;
    __label__ = 9;
    break;
   case 9:
    var $_02;
    var $i_0;
    var $totalArgsLength_0;
    if (($i_0 | 0) < ($13 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    if ($charArgs) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $33 = HEAP32[$_02 >> 2];
    var $34 = _strlen($33);
    HEAP32[$charArgLength >> 2] = $34;
    var $35 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($27, $33, $charArgLength, 0);
    var $37 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$37 >> 2] = $35;
    var $40 = HEAP32[HEAP32[$23 >> 2] + ($i_0 << 2) >> 2];
    if (($40 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $48 = $40;
      __label__ = 13;
      break;
    }
   case 12:
    var $44 = HEAP32[$_02 >> 2];
    var $46 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$46 >> 2] = $44;
    var $48 = HEAP32[HEAP32[$23 >> 2] + ($i_0 << 2) >> 2];
    __label__ = 13;
    break;
   case 13:
    var $48;
    var $_1 = $_02 + 4 | 0;
    var $49 = __Z9js_strlenPKt($48);
    HEAP32[$argLengths + ($i_0 << 2) >> 2] = $49;
    var $totalArgsLength_0 = $49 + $totalArgsLength_0 | 0;
    var $i_0 = $i_0 + 1 | 0;
    var $_02 = $_1;
    __label__ = 9;
    break;
   case 14:
    var $55 = HEAP32[$23 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$55 >> 2] = 0;
    var $57 = HEAP32[$efs_0 >> 2];
    if (($57 | 0) != 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 15:
    var $60 = _strlen($57);
    HEAP32[$len >> 2] = $60;
    var $61 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($27, $57, $len, 0);
    if (($61 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $69 = ($totalArgsLength_0 + $13 * -3 + HEAP32[$len >> 2] << 1) + 2 | 0;
    var $70 = __ZN9JSContext7malloc_Ej($cx, $69);
    var $71 = $70;
    var $72 = $reportp + 32 | 0;
    HEAP32[$72 >> 2] = $71;
    if (($70 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $out_0 = $71;
      var $fmt_0 = $61;
      __label__ = 18;
      break;
    }
   case 17:
    var $75 = $61;
    __ZN9JSContext5free_EPv(undef, $75);
    __label__ = 29;
    break;
   case 18:
    var $fmt_0;
    var $out_0;
    var $76 = HEAPU16[$fmt_0 >> 1];
    if ($76 << 16 >> 16 == 123) {
      __label__ = 20;
      break;
    } else if ($76 << 16 >> 16 == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_pre_phi = $fmt_0 + 2 | 0;
    __label__ = 22;
    break;
   case 20:
    var $78 = $fmt_0 + 2 | 0;
    var $isdigittmp = (HEAPU16[$78 >> 1] & 65535) - 48 | 0;
    if ($isdigittmp >>> 0 < 10) {
      __label__ = 21;
      break;
    } else {
      var $_pre_phi = $78;
      __label__ = 22;
      break;
    }
   case 21:
    var $86 = HEAP32[HEAP32[$23 >> 2] + ($isdigittmp << 2) >> 2];
    var $87 = $argLengths + ($isdigittmp << 2) | 0;
    var $89 = HEAP32[$87 >> 2] << 1;
    _memcpy($out_0, $86, $89, 1);
    var $out_0 = $out_0 + (HEAP32[$87 >> 2] << 1) | 0;
    var $fmt_0 = $fmt_0 + 6 | 0;
    __label__ = 18;
    break;
   case 22:
    var $_pre_phi;
    HEAP16[$out_0 >> 1] = $76;
    var $out_0 = $out_0 + 2 | 0;
    var $fmt_0 = $_pre_phi;
    __label__ = 18;
    break;
   case 23:
    HEAP16[$out_0 >> 1] = 0;
    var $96 = $61;
    __ZN9JSContext5free_EPv(undef, $96);
    var $97 = HEAP32[$72 >> 2];
    var $101 = $out_0 - $97 >> 1;
    var $102 = __ZN2js13DeflateStringEP9JSContextPKtj($27, $97, $101);
    HEAP32[$messagep >> 2] = $102;
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 24:
    var $105 = _JS_strdup($cx, $16);
    HEAP32[$messagep >> 2] = $105;
    if (($105 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $108 = _strlen($105);
    HEAP32[$len1 >> 2] = $108;
    var $109 = $cx;
    var $110 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($109, $105, $len1, 0);
    HEAP32[$reportp + 32 >> 2] = $110;
    if (($110 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    if ((HEAP32[$messagep >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 27:
    var $116 = __ZN9JSContext7malloc_Ej($cx, 62);
    HEAP32[$messagep >> 2] = $116;
    if (($116 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $119 = _JS_snprintf($116, 62, STRING_TABLE.__str3648 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $errorNumber, tempInt));
    var $_0 = 1;
    __label__ = 38;
    break;
   case 29:
    var $120 = $reportp + 36 | 0;
    var $121 = HEAP32[$120 >> 2];
    if (($121 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($charArgs) {
      __label__ = 31;
      break;
    } else {
      var $133 = $121;
      __label__ = 33;
      break;
    }
   case 31:
    var $124 = HEAP32[$121 >> 2];
    if (($124 | 0) == 0) {
      var $133 = $121;
      __label__ = 33;
      break;
    } else {
      var $i_110 = 0;
      var $126 = $124;
      __label__ = 32;
      break;
    }
   case 32:
    var $126;
    var $i_110;
    var $127 = $i_110 + 1 | 0;
    __ZN9JSContext5free_EPv(undef, $126);
    var $129 = HEAP32[$120 >> 2];
    var $131 = HEAP32[$129 + ($127 << 2) >> 2];
    if (($131 | 0) == 0) {
      var $133 = $129;
      __label__ = 33;
      break;
    } else {
      var $i_110 = $127;
      var $126 = $131;
      __label__ = 32;
      break;
    }
   case 33:
    var $133;
    __ZN9JSContext5free_EPv(undef, $133);
    HEAP32[$120 >> 2] = 0;
    __label__ = 34;
    break;
   case 34:
    var $135 = $reportp + 32 | 0;
    var $136 = HEAP32[$135 >> 2];
    if (($136 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $139 = $136;
    __ZN9JSContext5free_EPv(undef, $139);
    HEAP32[$135 >> 2] = 0;
    __label__ = 36;
    break;
   case 36:
    var $140 = HEAP32[$messagep >> 2];
    if (($140 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN9JSContext5free_EPv(undef, $140);
    HEAP32[$messagep >> 2] = 0;
    var $_0 = 0;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_["X"] = 1;

function __Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc($cx, $flags, $callback, $userRef, $errorNumber, $charArgs, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $report = __stackBase__ + 4;
    var $message = __stackBase__ + 44;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZL16checkReportFlagsP9JSContextPj($cx, $1);
    if ($2) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = $4 & 1;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_($report);
    HEAP32[$report + 24 >> 2] = $4;
    HEAP32[$report + 28 >> 2] = $errorNumber;
    __ZL19PopulateReportBlameP9JSContextP13JSErrorReport($cx, $report);
    var $8 = ($charArgs | 0) != 0;
    var $9 = __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($cx, $callback, $userRef, $errorNumber, $message, $report, $8, $ap);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$message >> 2];
    __ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $12, $report, $callback, $userRef);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv(undef, $12);
    __label__ = 5;
    break;
   case 5:
    var $16 = $report + 36 | 0;
    var $17 = HEAP32[$16 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($8) {
      __label__ = 7;
      break;
    } else {
      var $29 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = HEAP32[$17 >> 2];
    if (($20 | 0) == 0) {
      var $29 = $17;
      __label__ = 9;
      break;
    } else {
      var $i_01 = 0;
      var $22 = $20;
      __label__ = 8;
      break;
    }
   case 8:
    var $22;
    var $i_01;
    var $23 = $i_01 + 1 | 0;
    __ZN9JSContext5free_EPv(undef, $22);
    var $25 = HEAP32[$16 >> 2];
    var $27 = HEAP32[$25 + ($23 << 2) >> 2];
    if (($27 | 0) == 0) {
      var $29 = $25;
      __label__ = 9;
      break;
    } else {
      var $i_01 = $23;
      var $22 = $27;
      __label__ = 8;
      break;
    }
   case 9:
    var $29;
    __ZN9JSContext5free_EPv(undef, $29);
    __label__ = 10;
    break;
   case 10:
    var $33 = HEAP32[$report + 32 >> 2];
    if (($33 | 0) == 0) {
      var $_0 = $5;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $33;
    __ZN9JSContext5free_EPv(undef, $36);
    var $_0 = $5;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc["X"] = 1;

function __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($cx, $message, $reportp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($message | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx + 176 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($4);
    __label__ = 4;
    break;
   case 4:
    var $8 = _JS_strdup($cx, $message);
    HEAP32[$3 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = HEAP32[$cx + 180 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAP32[$cx + 200 >> 2];
    var $18 = HEAP32[$16 + 64 >> 2];
    if (($18 | 0) == 0) {
      var $25 = $8;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$16 + 68 >> 2];
    var $23 = FUNCTION_TABLE[$18]($cx, $8, $reportp, $22);
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAP32[$3 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $25;
    FUNCTION_TABLE[$12]($cx, $25, $reportp);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_ReportIsNotDefinedP9JSContextPKc($cx, $name) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 1, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $name, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __Z22js_CurrentPCIsInImacroP9JSContext($cx) {
  return 0;
}

function __ZN9JSContext22thisDuringConstructionEv($this) {
  return $this;
}

function __ZN9JSContext16updateJITEnabledEv($this) {
  return;
}

function __ZN2js10LeaveTraceEP9JSContext($cx) {
  return;
}

function __ZN2js13CanLeaveTraceEP9JSContext($cx) {
  return 0;
}

function __ZNK7mozilla14AlignedStorageILj8EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj8EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv($this) {
  return $this;
}

function __ZNK2js14ThreadDataIter5emptyEv($this) {
  return (HEAP8[$this + 4 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js14ThreadDataIter10threadDataEv($this) {
  return HEAP32[$this >> 2] + 144280 | 0;
}

function __ZN2js14ThreadDataIter8popFrontEv($this) {
  HEAP8[$this + 4 | 0] = 1;
  return;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev($this) {
  HEAP8[$this + 8 | 0] = 0;
  return;
}

function __ZN14DSTOffsetCache5purgeEv($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  var $2 = $this + 16 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = -2147483648;
  var $3 = $this + 8 | 0;
  HEAP32[$3 >> 2] = 0;
  HEAP32[$3 + 4 >> 2] = -2147483648;
  var $4 = $this + 24 | 0;
  HEAP32[$4 >> 2] = 0;
  HEAP32[$4 + 4 >> 2] = 0;
  var $5 = $this + 40 | 0;
  HEAP32[$5 >> 2] = 0;
  HEAP32[$5 + 4 >> 2] = -2147483648;
  var $6 = $this + 32 | 0;
  HEAP32[$6 >> 2] = 0;
  HEAP32[$6 + 4 >> 2] = -2147483648;
  return;
}

function __ZNK2js10StackFrame11hasImacropcEv($this) {
  return (HEAP32[$this >> 2] & 8192 | 0) != 0;
}

function __ZNK2js10StackFrame8imacropcEv($this) {
  return HEAP32[$this + 40 >> 2];
}

function __ZN2js14ThreadDataIterC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js19AutoAtomicIncrementD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  var $4 = HEAP32[$2 >> 2] - 1 | 0;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js19AutoAtomicIncrementC2EPi($this, $p) {
  HEAP32[$this >> 2] = $p;
  var $3 = HEAP32[$p >> 2] + 1 | 0;
  HEAP32[$p >> 2] = $3;
  return;
}

function __ZNK2js9StackIter2pcEv($this) {
  return HEAP32[$this + 28 >> 2];
}

function __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v, $fallback) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_idx_val$0, $v_idx_val$1, $fallback);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strcmp($1, STRING_TABLE._js_undefined_str | 0);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _strcmp($1, STRING_TABLE._js_null_str | 0);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = _JS_ReportErrorFlagsAndNumber($cx, 0, 2, 0, 39, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    var $ok_0 = $10;
    __label__ = 8;
    break;
   case 5:
    var $12 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = _JS_ReportErrorFlagsAndNumber($cx, 0, 2, 0, 222, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_undefined_str | 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    var $ok_0 = $14;
    __label__ = 8;
    break;
   case 7:
    var $16 = _JS_ReportErrorFlagsAndNumber($cx, 0, 2, 0, 222, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_null_str | 0, HEAP32[tempInt + 8 >> 2] = 0, tempInt));
    var $ok_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    __ZN9JSContext5free_EPv(undef, $1);
    var $_0 = $ok_0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_0_0_0_val$0, $v_0_0_0_val$1, $fallback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $1 | 0;
  HEAP32[$2 >> 2] = $v_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $v_0_0_0_val$1;
  var $3 = _js_DecompileValueGenerator($cx, $spindex, $1, $fallback);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($cx, $v, $arg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ | 0;
    var $2 = _JS_snprintf($1, 11, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $arg, tempInt));
    var $3 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE($v);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $bytes_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toObjectEv($v);
    var $6 = __ZNK8JSObject18getFunctionPrivateEv($5);
    var $9 = HEAP32[$6 + 72 >> 2] | 0;
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $10 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, 1, $v_idx_val$0, $v_idx_val$1, $9);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $bytes_0 = $10;
      __label__ = 3;
      break;
    }
   case 3:
    var $bytes_0;
    var $14 = ($bytes_0 | 0) != 0 ? $bytes_0 : __str93064 | 0;
    _JS_ReportErrorNumber($cx, 2, 0, 227, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $14, tempInt));
    __ZN9JSContext5free_EPv(undef, $bytes_0);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, $flags, $errorNumber, $spindex, $v, $fallback, $arg1, $arg2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v_idx = $v | 0;
    var $v_idx_val$0 = HEAP32[$v_idx >> 2];
    var $v_idx_val$1 = HEAP32[$v_idx + 4 >> 2];
    var $1 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v_idx_val$0, $v_idx_val$1, $fallback);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_ReportErrorFlagsAndNumber($cx, $flags, 2, 0, $errorNumber, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $arg1, HEAP32[tempInt + 8 >> 2] = $arg2, tempInt));
    __ZN9JSContext5free_EPv(undef, $1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16checkOutOfMemoryP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $lock = __stackBase__;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $5 = HEAPU32[$rt + 140 >> 2] >>> 0 > HEAPU32[$rt + 152 >> 2] >>> 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __Z26js_InvokeOperationCallbackP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 144280 | 0;
    HEAP32[$3 >> 2] = 0;
    if ((HEAP32[$2 + 196 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$2 + 144076 >> 2];
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $9, 0);
    var $10 = __Z16checkOutOfMemoryP9JSRuntime($2);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $14 = HEAP32[$cx + 184 >> 2];
    if (($14 | 0) == 0) {
      var $20 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = FUNCTION_TABLE[$14]($cx);
    var $20 = ($17 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $20;
    var $_0 = $20 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_HandleExecutionInterruptP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[$cx + 52 >> 2] + 144280 >> 2] | 0) == 0) {
      var $result_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    var $result_0 = ($7 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $result_0;
    return $result_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24TriggerOperationCallbackEP9JSContext($cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144280 | 0;
  __ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime($3, undef);
  return;
}

function __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    __ZN2js14ThreadDataIterC1EP9JSRuntime($i, $rt);
    var $1 = __ZNK2js14ThreadDataIter5emptyEv($i);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZNK2js14ThreadDataIter10threadDataEv($i);
    __ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime($2, undef);
    __ZN2js14ThreadDataIter8popFrontEv($i);
    var $3 = __ZNK2js14ThreadDataIter5emptyEv($i);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14ThreadDataIterC1EP9JSRuntime($this, $rt) {
  __ZN2js14ThreadDataIterC2EP9JSRuntime($this, $rt);
  return;
}

function __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($fp | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind($cx);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    if (($_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = __ZNK2js10StackFrame12isDummyFrameEv($_0);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $8 = __ZNK2js10StackFrame4prevEv($_0);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 6:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __Z23js_GetCurrentBytecodePCP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext4regsEv($cx);
    var $5 = HEAP32[$3 + 4 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK9JSContext2fpEv($cx);
    var $9 = __ZNK2js10StackFrame13maybeImacropcEv($8);
    if (HEAP8[$5] << 24 >> 24 == 58) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $5;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = ($9 | 0) != 0 ? $9 : $5;
    var $_0 = $phitmp;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13maybeImacropcEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11hasImacropcEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame8imacropcEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContextC2EP9JSRuntime($this, $rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP8[$this + 16 | 0] = 0;
  HEAP32[$this + 52 >> 2] = $rt;
  HEAP32[$this + 56 >> 2] = 0;
  var $6 = $this + 60 | 0;
  var $7 = __ZN9JSContext22thisDuringConstructionEv($this);
  var $8 = $6;
  var $9 = $7;
  __ZN2js12ContextStackC2EP9JSContext($8, $9);
  var $10 = $this + 148 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($10, $1);
  var $11 = $this + 236 | 0;
  __ZN14DSTOffsetCacheC1Ev($11);
  var $12 = $this + 288 | 0;
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_($12, $2);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN14DSTOffsetCacheC1Ev($this) {
  __ZN14DSTOffsetCacheC2Ev($this);
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN9JSContextD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 100 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($2);
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 104 | 0;
    _JS_FinishArenaPool($6);
    var $7 = $this + 72 | 0;
    _JS_FinishArenaPool($7);
    var $9 = HEAP32[$this + 176 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground5free_EPv($9);
    __label__ = 5;
    break;
   case 5:
    var $14 = HEAP32[$this + 172 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $map_01 = $14;
      __label__ = 6;
      break;
    }
   case 6:
    var $map_01;
    var $17 = HEAP32[$map_01 + 12 >> 2];
    __ZN2js10Foreground5free_EPv($map_01);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $map_01 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    var $20 = $this + 288 | 0;
    __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev($20);
    var $21 = $this + 148 | 0;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($21);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js12ParseMapPoolD1Ev($p);
    var $3 = $p;
    _js_free816($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN9JSContext16resetCompartmentEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scopeobj = __stackBase__;
    var $1 = $this + 60 | 0;
    var $2 = __ZNK2js12ContextStack5hasfpEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($this);
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    HEAP32[$scopeobj >> 2] = $5;
    var $14 = $5;
    __label__ = 5;
    break;
   case 3:
    var $8 = HEAP32[$this + 132 >> 2];
    HEAP32[$scopeobj >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($this, $scopeobj);
    var $11 = HEAP32[$scopeobj >> 2];
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $14 = $11;
      __label__ = 5;
      break;
    }
   case 5:
    var $14;
    var $16 = __ZNK2js2gc4Cell11compartmentEv($14);
    HEAP32[$this + 56 >> 2] = $16;
    var $20 = HEAP8[$16 + 376 | 0] & 1;
    HEAP8[$this + 232 | 0] = $20;
    var $22 = __ZN9JSContext18isExceptionPendingEv($this);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    __ZN9JSContext20wrapPendingExceptionEv($this);
    __label__ = 8;
    break;
   case 7:
    HEAP32[$this + 56 >> 2] = 0;
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj >> 2];
    var $2 = __ZNK8JSObject8getClassEv($1);
    var $4 = HEAP32[$2 + 76 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = FUNCTION_TABLE[$4]($cx, $1);
    HEAP32[$obj >> 2] = $7;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext20wrapPendingExceptionEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN9JSContext19getPendingExceptionEv($v, $this);
    __ZN9JSContext21clearPendingExceptionEv($this);
    var $3 = HEAP32[$this + 56 >> 2];
    var $4 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($3, $this, $v);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($this, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9JSContext12generatorForEPN2js10StackFrameE($this, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 288 | 0;
    var $2 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv($1);
    var $3 = HEAPU32[$2 >> 2];
    var $4 = __ZN11JSGenerator9liveFrameEv($3);
    if (($4 | 0) == ($fp | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($1);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj($1, $i_0);
    var $11 = HEAPU32[$10 >> 2];
    var $12 = __ZN11JSGenerator9liveFrameEv($11);
    if (($12 | 0) == ($fp | 0)) {
      var $_0 = $11;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv($this) {
  var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN11JSGenerator9liveFrameEv($this) {
  var $1 = $this + 8 | 0;
  var $2 = __ZNK2js9FrameRegs2fpEv($1);
  return $2;
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZNK9JSContext28runningWithTrustedPrincipalsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 56 >> 2];
    if (($2 | 0) == 0) {
      var $14 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 4 >> 2];
    var $9 = HEAP32[$this + 52 >> 2];
    var $10 = __ZNK9JSRuntime17trustedPrincipalsEv($9);
    var $14 = ($6 | 0) == ($10 | 0);
    __label__ = 3;
    break;
   case 3:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime15onTooMuchMallocEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 6;
    __label__ = 4;
    break;
   case 3:
    var $5 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $5;
    __label__ = 4;
    break;
   case 4:
    __ZN2js9TriggerGCEP9JSRuntime($this);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext($this, $p, $nbytes, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cx | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 3;
    break;
   case 3:
    return 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 52 >> 2];
    var $3 = $this + 104 | 0;
    __ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool($2, $3);
    if ((HEAP32[$this + 308 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this + 100 | 0;
    var $9 = HEAP32[$8 >> 2];
    __ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_($9);
    HEAP32[$8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool($rt, $pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    if (($2 | 0) == (HEAP32[$pool >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $2 + 4 | 0;
    if ((HEAP32[$2 + 12 >> 2] | 0) == (HEAP32[$9 >> 2] + 8 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $14 = _JS_Now();
    var $14$0 = $14[0];
    var $14$1 = $14[1];
    var $16 = HEAP32[$9 >> 2];
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18$0 = (i64Math.subtract($14$0, $14$1, $17$0, $17$1), i64Math.result[0]);
    var $18$1 = i64Math.result[1];
    var $21$0 = HEAP32[$rt + 160 >> 2];
    var $22$0 = (i64Math.multiply($21$0, 0, 1e3, 0), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    if (($18$1 | 0) > ($22$1 | 0) || ($18$1 | 0) == ($22$1 | 0) && $18$0 >>> 0 > $22$0 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_FreeArenaPool($pool);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPoolD1Ev($this) {
  __ZN2js12ParseMapPoolD2Ev($this);
  return;
}

function _js_free816($p) {
  _free($p);
  return;
}

function __ZN2js12ParseMapPoolD2Ev($this) {
  __ZN2js12ParseMapPool8purgeAllEv($this);
  var $1 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($1);
  var $2 = $this | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($2);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj8EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj8EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 2;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14DSTOffsetCacheC2Ev($this) {
  __ZN14DSTOffsetCache5purgeEv($this);
  return;
}

function __ZNK9JSContext15hasStrictOptionEv($this) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this, 1);
  return $1;
}

function __ZNK9JSContext15hasWErrorOptionEv($this) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this, 2);
  return $1;
}

function __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($this, $cx, $opt) {
  __ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE($this, $cx, $opt);
  return;
}

function __ZNK2js13FrameRegsIter4doneEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js9StackIter4doneEv($1);
  return $2;
}

function __ZNK2js13FrameRegsIter2fpEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js9StackIter2fpEv($1);
  return $2;
}

function __ZNK2js13FrameRegsIter2pcEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js9StackIter2pcEv($1);
  return $2;
}

function __ZN2js13FrameRegsIterppEv($this) {
  var $1 = $this;
  var $2 = __ZN2js9StackIterppEv($1);
  __ZN2js13FrameRegsIter6settleEv($this);
  return $this;
}

function __ZN2js13FrameRegsIter6settleEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    __label__ = 2;
    break;
   case 2:
    var $3 = __ZNK2js9StackIter4doneEv($1);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js9StackIter8isScriptEv($1);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js9StackIterppEv($1);
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE($this, $cx, $opt) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE($1, $2, $opt);
  __ZN2js13FrameRegsIter6settleEv($this);
  return;
}

function __ZN2js8GSNCacheD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment11thisForCtorEv($this) {
  return $this;
}

function _JSID_IS_INT844($iden) {
  return $iden & 1;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject846($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject847($object) {
  return $object;
}

function __ZN2js24ConservativeGCThreadDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK8JSObject15isStopIterationEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js18StopIterationClassE | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js13PropertyCacheC2Ev($this) {
  __ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 65540, 1);
  return;
}

function __ZN2js8GSNCacheC2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN13JSCompartmentC2EP9JSRuntime($this, $rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  var $6 = __stackBase__ + 20;
  HEAP32[$this >> 2] = $rt;
  HEAP32[$this + 4 >> 2] = 0;
  var $9 = $this + 8 | 0;
  __ZN2js2gc10ArenaListsC1Ev($9);
  HEAP32[$this + 328 >> 2] = 0;
  HEAP32[$this + 332 >> 2] = 0;
  HEAP32[$this + 336 >> 2] = 0;
  HEAP8[$this + 340 | 0] = 0;
  HEAP32[$this + 708 >> 2] = 0;
  HEAP8[$this + 712 | 0] = 0;
  HEAP8[$this + 713 | 0] = 0;
  var $17 = $this + 716 | 0;
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_($17, $1);
  var $18 = $this + 744 | 0;
  var $19 = __ZN13JSCompartment11thisForCtorEv($this);
  __ZN2js12PropertyTreeC1EP13JSCompartment($18, $19);
  HEAP32[$this + 748 >> 2] = 0;
  HEAP32[$this + 752 >> 2] = 0;
  HEAP32[$this + 756 >> 2] = 0;
  HEAP32[$this + 760 >> 2] = 0;
  HEAP32[$this + 764 >> 2] = 0;
  HEAP32[$this + 768 >> 2] = 0;
  var $26 = $this + 772 | 0;
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($26, $2);
  HEAP32[$this + 796 >> 2] = 0;
  HEAP32[$this + 800 >> 2] = 0;
  HEAP32[$this + 804 >> 2] = HEAP8[$rt + 144220 | 0] & 1 & 255;
  var $34 = $this + 808 | 0;
  __ZN2js15NativeIterCacheC1Ev($34);
  var $35 = $this + 1836 | 0;
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev($35);
  var $36 = $this + 1864 | 0;
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_($36, $3);
  var $37 = $this + 1888 | 0;
  __ZN2js9DtoaCacheC1Ev($37);
  HEAP32[$this + 1904 >> 2] = 0;
  var $39 = $this + 1908 | 0;
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_($39, $4);
  var $40 = $this + 1932 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($40, $5);
  var $41 = $this + 1956 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSRuntime($6, $rt);
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_($41, $6);
  HEAP32[$this + 1984 >> 2] = 0;
  var $43 = $this + 452 | 0;
  __ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_($43);
  STACKTOP = __stackBase__;
  return;
}

__ZN13JSCompartmentC2EP9JSRuntime["X"] = 1;

function __ZN2js2gc10ArenaListsC1Ev($this) {
  __ZN2js2gc10ArenaListsC2Ev($this);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12PropertyTreeC1EP13JSCompartment($this, $comp) {
  __ZN2js12PropertyTreeC2EP13JSCompartment($this, $comp);
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15NativeIterCacheC1Ev($this) {
  __ZN2js15NativeIterCacheC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js9DtoaCacheC1Ev($this) {
  __ZN2js9DtoaCacheC2Ev($this);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18RuntimeAllocPolicyC1EP9JSRuntime($this, $rt) {
  __ZN2js18RuntimeAllocPolicyC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 256, 1);
  return;
}

function __ZN13JSCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 1904 >> 2];
  __ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_($2);
  var $4 = HEAP32[$this + 1984 >> 2];
  __ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_($4);
  var $5 = $this + 1956 | 0;
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev($5);
  var $6 = $this + 1932 | 0;
  __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($6);
  var $7 = $this + 1908 | 0;
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($7);
  var $8 = $this + 1864 | 0;
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev($8);
  var $9 = $this + 1836 | 0;
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev($9);
  var $10 = $this + 772 | 0;
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($10);
  var $11 = $this + 716 | 0;
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev($11);
  var $12 = $this + 376 | 0;
  __ZN2js5types15TypeCompartmentD2Ev($12);
  var $13 = $this + 8 | 0;
  __ZN2js2gc10ArenaListsD1Ev($13);
  return;
}

function __ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free864($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13WatchpointMapD1Ev($p);
    var $3 = $p;
    _js_free864($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev($this);
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js2gc10ArenaListsD1Ev($this) {
  __ZN2js2gc10ArenaListsD2Ev($this);
  return;
}

function __ZN13JSCompartment4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP8[$this + 373 | 0] = 0;
    HEAP8[$this + 372 | 0] = 0;
    var $3 = $this + 376 | 0;
    __ZN2js5types15TypeCompartment4initEP9JSContext($3, $cx);
    var $4 = $this + 344 | 0;
    _JS_InitArenaPool($4, undef, 4056, 8);
    var $5 = $this + 716 | 0;
    var $6 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj($5, 0);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $8 = $this + 1864 | 0;
    var $9 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj($8, 0);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $12 = HEAP32[$this >> 2];
    var $13 = __ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v($12);
    HEAP32[$this + 740 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $this + 1908 | 0;
    var $18 = __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($17, 0);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $20 = $this + 1932 | 0;
    var $21 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($20, 0);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = $this + 1956 | 0;
    var $24 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj($23, 0);
    var $_0 = $24;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($1, $len);
  return $2;
}

function __ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 4, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN3WTF20BumpPointerAllocatorC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj($1, $len);
  return $2;
}

function __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $stackDummy_ = __stackBase__ + 4;
    var $global = __stackBase__ + 8;
    var $p = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $orig = __stackBase__ + 24;
    var $proto = __stackBase__ + 32;
    HEAP32[$flags >> 2] = 0;
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 38;
    break;
   case 3:
    var $8 = __ZNK2JS5Value10isMarkableEv($vp);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8isStringEv($vp);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value8toStringEv($vp);
    var $13 = $12;
    var $14 = __ZNK2js2gc4Cell11compartmentEv($13);
    if (($14 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK8JSString6isAtomEv($12);
    if ($17) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK9JSContext5hasfpEv($cx);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = __ZNK9JSContext2fpEv($cx);
    var $22 = __ZNK2js10StackFrame10scopeChainEv($21);
    var $23 = $22;
    var $24 = __ZNK8JSObject9getGlobalEv($23);
    HEAP32[$global >> 2] = $24;
    __label__ = 10;
    break;
   case 9:
    var $28 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $28;
    var $29 = $cx;
    var $30 = $global;
    var $31 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($29, $30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 10:
    var $33 = __ZNK2JS5Value8isObjectEv($vp);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 11:
    var $35 = __ZNK2JS5Value8toObjectEv($vp);
    var $36 = $35;
    var $37 = __ZNK2js2gc4Cell11compartmentEv($36);
    if (($37 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZNK8JSObject15isStopIterationEv($35);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = $cx;
    var $43 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($42, 0, 23, $vp, 0);
    var $_0 = ($43 | 0) != 0;
    __label__ = 38;
    break;
   case 14:
    var $46 = __ZNK8JSObject8getClassEv($35);
    if ((HEAP32[$46 + 76 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $51 = __ZN8JSObject6unwrapEPj($35, $flags);
    __ZN2JS5Value9setObjectER8JSObject($vp, $51);
    var $52 = __ZNK8JSObject14getCompartmentEv($51);
    if (($52 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $58 = HEAP32[HEAP32[$cx + 52 >> 2] + 229024 >> 2];
    if (($58 | 0) == 0) {
      var $obj_0 = $51;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = HEAP32[$global >> 2];
    var $62 = HEAP32[$flags >> 2];
    var $63 = FUNCTION_TABLE[$58]($cx, $61, $51, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      var $obj_0 = $63;
      __label__ = 18;
      break;
    }
   case 18:
    var $obj_0;
    __ZN2JS5Value9setObjectER8JSObject($vp, $obj_0);
    var $66 = __ZNK8JSObject14getCompartmentEv($obj_0);
    if (($66 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $72 = HEAP32[HEAP32[$cx + 52 >> 2] + 229024 >> 2];
    if (($72 | 0) == 0) {
      var $obj_1 = $35;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $75 = HEAP32[$global >> 2];
    var $76 = HEAP32[$flags >> 2];
    var $77 = FUNCTION_TABLE[$72]($cx, $75, $35, $76);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      var $obj_1 = $77;
      __label__ = 21;
      break;
    }
   case 21:
    var $obj_1;
    __ZN2JS5Value9setObjectER8JSObject($vp, $obj_1);
    __label__ = 22;
    break;
   case 22:
    var $81 = $this + 716 | 0;
    __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_($p, $81, $vp);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $86 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $87 = $86 + 8 | 0;
    var $88$0 = HEAP32[$87 >> 2];
    var $88$1 = HEAP32[$87 + 4 >> 2];
    var $89 = $vp | 0;
    HEAP32[$89 >> 2] = $88$0;
    HEAP32[$89 + 4 >> 2] = $88$1;
    var $90 = __ZNK2JS5Value8isObjectEv($vp);
    if ($90) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 24:
    var $92 = __ZNK2JS5Value8toObjectEv($vp);
    var $93 = HEAP32[$global >> 2];
    var $94 = __ZNK8JSObject10getJSClassEv($93);
    if (($94 | 0) == (_js_dummy_class | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $97 = __ZNK8JSObject9getParentEv($92);
    if (($97 | 0) == ($93 | 0)) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      var $obj1_0 = $92;
      __label__ = 26;
      break;
    }
   case 26:
    var $obj1_0;
    __ZN8JSObject9setParentEPS_($obj1_0, $93);
    var $99 = __ZNK8JSObject8getProtoEv($obj1_0);
    if (($99 | 0) == 0) {
      var $_0 = 1;
      __label__ = 38;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $102 = __ZL25IsCrossCompartmentWrapperP8JSObject($99);
    if ($102) {
      var $obj1_0 = $99;
      __label__ = 26;
      break;
    } else {
      var $_0 = 1;
      __label__ = 38;
      break;
    }
   case 28:
    var $104 = __ZNK2JS5Value8isStringEv($vp);
    if ($104) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $106 = $vp | 0;
    var $107$0 = HEAP32[$106 >> 2];
    var $107$1 = HEAP32[$106 + 4 >> 2];
    var $108 = $orig | 0;
    HEAP32[$108 >> 2] = $107$0;
    HEAP32[$108 + 4 >> 2] = $107$1;
    var $109 = __ZNK2JS5Value8toStringEv($vp);
    var $110 = __ZN8JSString8getCharsEP9JSContext($109, $cx);
    if (($110 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $113 = __ZNK8JSString6lengthEv($109);
    var $114 = $cx;
    var $115 = __Z17js_NewStringCopyNP9JSContextPKtj($114, $110, $113);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $118 = $115 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $118);
    var $119 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($81, $orig, $vp);
    var $_0 = ($119 | 0) != 0;
    __label__ = 38;
    break;
   case 32:
    var $122 = __ZNK2JS5Value8toObjectEv($vp);
    var $123 = __ZNK8JSObject8getProtoEv($122);
    HEAP32[$proto >> 2] = $123;
    var $124 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $proto);
    if ($124) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 33:
    var $129 = HEAP32[HEAP32[$cx + 52 >> 2] + 229020 >> 2];
    var $130 = HEAP32[$proto >> 2];
    var $131 = HEAP32[$global >> 2];
    var $132 = HEAP32[$flags >> 2];
    var $133 = FUNCTION_TABLE[$129]($cx, $122, $130, $131, $132);
    if (($133 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN2JS5Value9setObjectER8JSObject($vp, $133);
    var $136 = __ZNK8JSObject8getProtoEv($133);
    if (($136 | 0) == ($130 | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $139 = $cx;
    var $140 = $133;
    var $141 = $130;
    var $142 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($139, $140, $141, 0);
    if ($142) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 38;
      break;
    }
   case 36:
    var $144 = __ZNK8JSObject15getProxyPrivateEv($133);
    var $145 = __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_($81, $144, $vp);
    if (($145 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN8JSObject9setParentEPS_($133, $131);
    var $_0 = 1;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2JS5Value10isMarkableEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_TRACEABLE_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZL25IsCrossCompartmentWrapperP8JSObject($wrapper) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isWrapperEv($wrapper);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN9JSWrapper14wrapperHandlerEPK8JSObject($wrapper);
    var $4 = $3;
    var $5 = __ZNK9JSWrapper5flagsEv($4);
    var $9 = ($5 & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$objp >> 2];
    if (($2 | 0) == 0) {
      var $_1 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject841($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $5 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $6 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $9 = __ZNK2JS5Value8toObjectEv($8);
    HEAP32[$objp >> 2] = $9;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPP8JSString($this, $cx, $strp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$strp >> 2];
    __ZN2JSL11StringValueEP8JSString840($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $3 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $4 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $7 = __ZNK2JS5Value8toStringEv($6);
    HEAP32[$strp >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString840($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject841($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN13JSCompartment6wrapIdEP9JSContextPi($this, $cx, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = HEAP32[$idp >> 2];
    var $3 = _JSID_IS_INT844($2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    __ZN2jsL9IdToValueEi845($1, $2);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $1);
    var $6 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $7 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $9, $idp);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi845($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING869($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING870($id);
    __ZN2JSL11StringValueEP8JSString840($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT844($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT872($id);
    __ZN2JSL10Int32ValueEi871($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT873($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT874($id);
    __ZN2JSL11ObjectValueER8JSObject841($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv875($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($this, $cx, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = HEAP32[$propp >> 2];
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($v, $1);
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value14toObjectOrNullEv($v);
    var $5 = __ZN2jsL16CastAsPropertyOpEP8JSObject846($4);
    HEAP32[$propp >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($agg_result, $op) {
  var $1 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($op);
  __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $1);
  return;
}

function __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($this, $cx, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = HEAP32[$propp >> 2];
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($v, $1);
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value14toObjectOrNullEv($v);
    var $5 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject847($4);
    HEAP32[$propp >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($agg_result, $op) {
  var $1 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($op);
  __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $1);
  return;
}

function __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $desc | 0;
    var $2 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($this, $cx, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $desc + 4 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 & 16 | 0) == 0) {
      var $12 = $5;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $desc + 8 | 0;
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($this, $cx, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $12 = HEAP32[$4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $12;
    if (($12 & 32 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $desc + 12 | 0;
    var $17 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($this, $cx, $16);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $22 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $desc + 16 | 0;
    var $20 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($this, $cx, $19);
    var $22 = $20;
    __label__ = 8;
    break;
   case 8:
    var $22;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($this, $cx, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props | 0;
    var $2 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $3 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $n_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $n_0;
    if ($n_0 >>> 0 < $3 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $2 + ($n_0 << 2) | 0;
    var $8 = __ZN13JSCompartment6wrapIdEP9JSContextPi($this, $cx, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 716 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($2);
    var $5 = $4 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $5, undef);
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($2);
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($2);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this);
  return;
}

function __ZNK2js2gc12CellIterImpl4doneEv($this) {
  return (HEAP32[$this + 28 >> 2] | 0) == 0;
}

function __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZN8JSScript13clearAnalysisEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 100 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    HEAP32[$5 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9DtoaCache5purgeEv($this) {
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js18ThreadContextRange5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZN2js18ThreadContextRange8popFrontEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN13JSCompartment9markTypesEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $i1 = __stackBase__ + 32;
    var $i2 = __stackBase__ + 64;
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $this, 13);
    var $1 = $i | 0;
    var $2 = __ZNK2js2gc12CellIterImpl4doneEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $i1 | 0;
    var $thingKind_04 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($1);
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $4, undef);
    __ZN2js2gc12CellIterImpl4nextEv($1);
    var $5 = __ZNK2js2gc12CellIterImpl4doneEv($1);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $thingKind_04;
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $this, $thingKind_04);
    var $7 = __ZNK2js2gc12CellIterImpl4doneEv($3);
    if ($7) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $8 = __ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v($3);
    var $9 = __ZNK8JSObject9isNewbornEv($8);
    if ($9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZNK8JSObject16hasSingletonTypeEv($8);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $8, undef);
    __label__ = 8;
    break;
   case 8:
    __ZN2js2gc12CellIterImpl4nextEv($3);
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($3);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 9:
    var $15 = $thingKind_04 + 1 | 0;
    if (($15 | 0) == 13) {
      __label__ = 10;
      break;
    } else {
      var $thingKind_04 = $15;
      __label__ = 4;
      break;
    }
   case 10:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i2, $this, 15);
    var $17 = $i2 | 0;
    var $18 = __ZNK2js2gc12CellIterImpl4doneEv($17);
    if ($18) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $19 = __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($17);
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $19, undef);
    __ZN2js2gc12CellIterImpl4nextEv($17);
    var $20 = __ZNK2js2gc12CellIterImpl4doneEv($17);
    if ($20) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  __ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind);
  return;
}

function __ZN2js2gc12CellIterImpl4nextEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = $this + 20 | 0;
    var $4 = $this + 8 | 0;
    var $5 = $this + 12 | 0;
    var $6 = $1;
    var $7 = $5;
    var $8 = $this | 0;
    var $11 = HEAP32[$2 >> 2];
    var $10 = HEAP32[$3 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $10;
    var $11;
    if (($11 | 0) == (HEAP32[$10 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $16 = __ZNK2js2gc8FreeSpan7hasNextEv($10);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $21 = HEAP32[$this + 4 >> 2];
    var $22 = $21 + HEAP32[$10 + 4 >> 2] | 0;
    HEAP32[$2 >> 2] = $22;
    var $23 = __ZNK2js2gc8FreeSpan8nextSpanEv($10);
    HEAP32[$3 >> 2] = $23;
    var $38 = $22;
    var $37 = $21;
    __label__ = 9;
    break;
   case 5:
    var $25 = HEAP32[$4 >> 2];
    if (($25 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$this + 28 >> 2] = 0;
    __label__ = 10;
    break;
   case 7:
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($1, $25);
    var $30$0 = HEAP32[$6 >> 2];
    var $30$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $30$0;
    HEAP32[$7 + 4 >> 2] = $30$1;
    HEAP32[$3 >> 2] = $5;
    var $31 = HEAP32[$4 >> 2];
    var $32 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($31);
    var $34 = HEAP32[$8 >> 2] | $32;
    HEAP32[$2 >> 2] = $34;
    var $36 = HEAP32[$31 + 4 >> 2];
    HEAP32[$4 >> 2] = $36;
    var $11 = $34;
    var $10 = $5;
    __label__ = 2;
    break;
   case 8:
    var $38 = $11;
    var $37 = HEAP32[$this + 4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $37;
    var $38;
    HEAP32[$this + 28 >> 2] = $38;
    HEAP32[$2 >> 2] = $38 + $37 | 0;
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12CellIterImpl4nextEv["X"] = 1;

function __ZN13JSCompartment5sweepEP9JSContextj($this, $cx, $releaseInterval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $oldPool = __stackBase__ + 16;
    var $i = __stackBase__ + 44;
    var $i1 = __stackBase__ + 76;
    var $1 = $this + 716 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e);
    var $4 = $this + 748 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($2);
    var $8 = $7 | 0;
    var $9 = __ZNK2JS5Value9toGCThingEv($8);
    var $10 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $9);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($2);
    var $13 = $12 + 8 | 0;
    var $14 = __ZNK2JS5Value9toGCThingEv($13);
    var $15 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($e);
    __label__ = 6;
    break;
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($2);
    var $18 = __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($2);
    if ($18) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 7:
    var $20 = $5;
    var $21 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $20);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$4 >> 2] = 0;
    __label__ = 9;
    break;
   case 9:
    var $24 = $this + 752 | 0;
    var $25 = HEAP32[$24 >> 2];
    if (($25 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = $25;
    var $29 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $28);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$24 >> 2] = 0;
    __label__ = 12;
    break;
   case 12:
    var $32 = $this + 756 | 0;
    var $33 = HEAP32[$32 >> 2];
    if (($33 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = $33;
    var $37 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $36);
    if ($37) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$32 >> 2] = 0;
    __label__ = 15;
    break;
   case 15:
    var $40 = $this + 760 | 0;
    var $41 = HEAP32[$40 >> 2];
    if (($41 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $44 = $41;
    var $45 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $44);
    if ($45) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$40 >> 2] = 0;
    __label__ = 18;
    break;
   case 18:
    var $48 = $this + 764 | 0;
    var $49 = HEAP32[$48 >> 2];
    if (($49 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = $49;
    var $53 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $52);
    if ($53) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$48 >> 2] = 0;
    __label__ = 21;
    break;
   case 21:
    var $56 = $this + 768 | 0;
    var $57 = HEAP32[$56 >> 2];
    if (($57 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $60 = $57;
    var $61 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $60);
    if ($61) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP32[$56 >> 2] = 0;
    __label__ = 24;
    break;
   case 24:
    var $64 = $this + 796 | 0;
    var $65 = HEAP32[$64 >> 2];
    if (($65 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $68 = $65;
    var $69 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $68);
    if ($69) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    HEAP32[$64 >> 2] = 0;
    __label__ = 27;
    break;
   case 27:
    var $72 = $this + 800 | 0;
    var $73 = HEAP32[$72 >> 2];
    if (($73 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $76 = $73;
    var $77 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $76);
    if ($77) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    HEAP32[$72 >> 2] = 0;
    __label__ = 30;
    break;
   case 30:
    __ZN13JSCompartment16sweepBreakpointsEP9JSContext($this, $cx);
    var $80 = $this + 712 | 0;
    if ((HEAP8[$80] & 1) << 24 >> 24 == 0) {
      __label__ = 31;
      break;
    } else {
      var $92 = 0;
      __label__ = 33;
      break;
    }
   case 31:
    if (($releaseInterval | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $92 = 1;
      __label__ = 33;
      break;
    }
   case 32:
    var $92 = (HEAP8[$this + 713 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 33;
    break;
   case 33:
    var $92;
    if ((HEAP8[$this + 372 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 34:
    var $98 = $this + 344 | 0;
    __ZN2js13MoveArenaPoolEP11JSArenaPoolS1_($98, $oldPool);
    var $99 = $this + 376 | 0;
    if ((HEAP8[$99 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $this, 13);
    var $105 = $i | 0;
    var $106 = __ZNK2js2gc12CellIterImpl4doneEv($105);
    if ($106) {
      __label__ = 40;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $107 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($105);
    var $108 = $107 + 100 | 0;
    if ((HEAP32[$108 >> 2] | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript($cx, $107);
    if ($92) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $113 = HEAP32[$108 >> 2];
    __ZN2js5types10TypeScript7destroyEv($113);
    HEAP32[$108 >> 2] = 0;
    var $114 = $107 + 38 | 0;
    var $116 = HEAP8[$114] | 16;
    HEAP8[$114] = $116;
    __label__ = 39;
    break;
   case 39:
    __ZN2js2gc12CellIterImpl4nextEv($105);
    var $118 = __ZNK2js2gc12CellIterImpl4doneEv($105);
    if ($118) {
      __label__ = 40;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 40:
    __ZN2js5types15TypeCompartment5sweepEP9JSContext($99, $cx);
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $this, 13);
    var $119 = $i1 | 0;
    var $120 = __ZNK2js2gc12CellIterImpl4doneEv($119);
    if ($120) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $121 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($119);
    __ZN8JSScript13clearAnalysisEv($121);
    __ZN2js2gc12CellIterImpl4nextEv($119);
    var $122 = __ZNK2js2gc12CellIterImpl4doneEv($119);
    if ($122) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 42:
    _JS_FinishArenaPool($oldPool);
    __label__ = 43;
    break;
   case 43:
    HEAP8[$80] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN13JSCompartment5sweepEP9JSContextj["X"] = 1;

function __ZNK2JS5Value9toGCThingEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_GCTHING_IMPL($2$0, $2$1);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN13JSCompartment16sweepBreakpointsEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($2);
    var $6 = HEAP32[$4 + 4 >> 2];
    var $8 = HEAP32[$6 + 12 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    var $12 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $16 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZNK2js14BreakpointSite7hasTrapEv($6);
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    var $17 = __ZNK2js14BreakpointSite15firstBreakpointEv($6);
    if (($17 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $bp_01 = $17;
      __label__ = 7;
      break;
    }
   case 7:
    var $bp_01;
    var $19 = __ZN2js10Breakpoint10nextInSiteEv($bp_01);
    if ($12) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = HEAP32[$bp_01 >> 2];
    var $23 = __ZNK2js8Debugger10toJSObjectEv($22);
    var $24 = $23;
    var $25 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $24);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $bp_01 = $19;
      __label__ = 7;
      break;
    }
   case 10:
    __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($bp_01, $cx, $e);
    __label__ = 9;
    break;
   case 11:
    if ($16) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($6, $cx, $e, 0, 0);
    __label__ = 13;
    break;
   case 13:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $30 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($30) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13MoveArenaPoolEP11JSArenaPoolS1_($oldPool, $newPool) {
  var $1 = $newPool;
  var $2 = $oldPool;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  HEAP32[$1 + 12 >> 2] = HEAP32[$2 + 12 >> 2];
  HEAP32[$1 + 16 >> 2] = HEAP32[$2 + 16 >> 2];
  HEAP32[$1 + 20 >> 2] = HEAP32[$2 + 20 >> 2];
  HEAP32[$1 + 24 >> 2] = HEAP32[$2 + 24 >> 2];
  var $4 = HEAP32[$newPool + 20 >> 2];
  var $7 = HEAP32[$newPool + 24 >> 2] + 1 | 0;
  _JS_InitArenaPool($oldPool, undef, $4, $7);
  return;
}

function __ZN13JSCompartment5purgeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    __ZN2js2gc10ArenaLists5purgeEv($1);
    var $2 = $this + 1888 | 0;
    __ZN2js9DtoaCache5purgeEv($2);
    var $i_02 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_02;
    var $4 = $this + 452 + ($i_02 << 2) | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $listHeadp_01 = $4;
      var $7 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $7;
    var $listHeadp_01;
    HEAP32[$listHeadp_01 >> 2] = 0;
    var $9 = $7 + 84 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $listHeadp_01 = $9;
      var $7 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $i_02 + 1 | 0;
    if (($12 | 0) == 64) {
      __label__ = 5;
      break;
    } else {
      var $i_02 = $12;
      __label__ = 2;
      break;
    }
   case 5:
    var $15 = $this + 808 | 0;
    __ZN2js15NativeIterCache5purgeEv($15);
    var $16 = $this + 1836 | 0;
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv($16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $2 = $this + ($i_01 << 3) | 0;
    var $3 = __ZNK2js2gc8FreeSpan7isEmptyEv($2);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($2);
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($5, $2);
    __ZN2js2gc8FreeSpan11initAsEmptyEj($2, 0);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == 20) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15NativeIterCache5purgeEv($this) {
  var $1 = $this | 0;
  __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($1);
  HEAP32[$this + 1024 >> 2] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv($this);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment14allocMathCacheEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext4new_IN2js9MathCacheEEEPT_v($cx);
    var $2 = $this + 1904 | 0;
    HEAP32[$2 >> 2] = $1;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $6 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $6 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js9MathCacheEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 81920);
    if (($1 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $1;
    __ZN2js9MathCacheC2Ev($5);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSCompartment13backEdgeCountEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $this + 1908 | 0;
    __ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $3, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $_0 = HEAP32[$8 + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 80,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN13JSCompartment16incBackEdgeCountEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $pc;
    var $4 = $this + 1908 | 0;
    HEAP32[$2 >> 2] = 0;
    __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj($p, $4, $1, $2);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($3, $p);
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $10 = $9 + 4 | 0;
    var $12 = HEAP32[$10 >> 2] + 1 | 0;
    HEAP32[$10 >> 2] = $12;
    var $_0 = $12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj($agg_result, $this, $k, $defaultValue) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$agg_result >> 2] = $8;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS5_13MapHashPolicyES4_E6AddPtrERKS1_RKj($this, $p, $k, $defaultValue);
    var $13 = HEAP32[$p >> 2];
    HEAP32[$agg_result >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = $cx + 60 | 0;
    var $2 = __ZNK2js12ContextStack5spaceEv($1);
    var $3 = $i;
    var $4 = $2;
    __ZN2js13AllFramesIterC2ERNS_10StackSpaceE($3, $4);
    __label__ = 2;
    break;
   case 2:
    var $6 = __ZNK2js13AllFramesIter4doneEv($i);
    if ($6) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js13AllFramesIter2fpEv($i);
    var $9 = __ZNK2js10StackFrame11maybeScriptEv($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = __ZNK2js2gc4Cell11compartmentEv($12);
    if (($13 | 0) == ($this | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZN2js13AllFramesIterppEv($3);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17setDebugModeFromCEP9JSContextb($this, $cx, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK13JSCompartment9debugModeEv($this);
    var $2 = $this + 804 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if ($1 ^ ($3 >>> 0 > 1 | $b)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = __ZN13JSCompartment17hasScriptsOnStackEP9JSContext($this, $cx);
    if ($8 & $b) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 281, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $14 = HEAP32[$2 >> 2] & -2 | $b & 1;
    HEAP32[$2 >> 2] = $14;
    __ZN13JSCompartment18updateForDebugModeEP9JSContext(undef, $cx);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$2 >> 2] = $3 & -2 | $b & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment18updateForDebugModeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    __ZN2js18ThreadContextRangeC1EP9JSContext($r, $cx);
    var $1 = __ZNK2js18ThreadContextRange5emptyEv($r);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18ThreadContextRange8popFrontEv($r);
    var $2 = __ZNK2js18ThreadContextRange5emptyEv($r);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18ThreadContextRangeC1EP9JSContext($this, $cx) {
  __ZN2js18ThreadContextRangeC2EP9JSContext($this, $cx);
  return;
}

function __ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE($this, $cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $global;
    var $2 = __ZNK13JSCompartment9debugModeEv($this);
    var $3 = $this + 1932 | 0;
    var $4 = __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_($3, $1);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $8 = $this + 804 | 0;
    var $10 = HEAP32[$8 >> 2] | 2;
    HEAP32[$8 >> 2] = $10;
    if ($2) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN13JSCompartment18updateForDebugModeEP9JSContext(undef, $cx);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE($this, $cx, $global, $debuggeesEnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $global;
    var $2 = __ZNK13JSCompartment9debugModeEv($this);
    if (($debuggeesEnum | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv($debuggeesEnum);
    var $_pre_phi = $this + 1932 | 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $this + 1932 | 0;
    __ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_($6, $1);
    var $_pre_phi = $6;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    var $8 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($_pre_phi);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $10 = $this + 804 | 0;
    var $12 = HEAP32[$10 >> 2] & -3;
    HEAP32[$10 >> 2] = $12;
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $14 = __ZNK13JSCompartment9debugModeEv($this);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN13JSCompartment18updateForDebugModeEP9JSContext(undef, $cx);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment17getBreakpointSiteEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_($p, $3, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($p);
    var $12 = HEAP32[$8 + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    STACKTOP = __stackBase__;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($this, $cx, $script, $pc, $scriptObject) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $site = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_($p, $3, $1);
    var $4 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv($2, $4);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 52 >> 2];
    var $11 = HEAP32[$1 >> 2];
    var $12 = __ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_($10, $script, $11);
    HEAP32[$site >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_($3, $p, $1, $site);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $18 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($4);
    var $20 = HEAP32[$18 + 4 >> 2];
    var $21 = $20 + 12 | 0;
    if ((HEAP32[$21 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $20;
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$21 >> 2] = $scriptObject;
    var $_0 = $20;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($this) {
  return $this;
}

function __ZNK2js14BreakpointSite7hasTrapEv($this) {
  return (HEAP32[$this + 28 >> 2] | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPhjEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIPhjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE($e) {
  return $e | 0;
}

function __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($this) {
  return (HEAP8[$this + 24 | 0] & 1) << 24 >> 24 == 0;
}

function __ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 40, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js14BreakpointSiteC2EP8JSScriptPh($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject($this, $cx, $dbg, $script, $handler) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($script | 0) == 0;
    var $5 = ($dbg | 0) == 0;
    var $6 = ($handler | 0) == 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($2);
    var $10 = HEAP32[$8 + 4 >> 2];
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$10 >> 2] | 0) == ($script | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $16 = __ZNK2js14BreakpointSite15firstBreakpointEv($10);
    if (($16 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_01 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $bp_01;
    var $18 = __ZN2js10Breakpoint10nextInSiteEv($bp_01);
    if ($5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$bp_01 >> 2] | 0) == ($dbg | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($18 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_01 = $18;
      __label__ = 7;
      break;
    }
   case 10:
    if ($6) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZNK2js10Breakpoint10getHandlerEv($bp_01);
    if (($26 | 0) == ($handler | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 12:
    __ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE($bp_01, $cx, $e);
    __label__ = 9;
    break;
   case 13:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $29 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($29) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev($this);
  return;
}

function __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($this, $cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $this + 1956 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($script | 0) == 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($2);
    var $8 = HEAP32[$6 + 4 >> 2];
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$8 >> 2] | 0) == ($script | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($8, $cx, $e, 0, 0);
    __label__ = 7;
    break;
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($2);
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($2);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$trc >> 2];
    var $3 = $this + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $3);
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r);
    if ($4) {
      var $markedAny_0_lcssa = 0;
      __label__ = 10;
      break;
    } else {
      var $markedAny_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $markedAny_01;
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r);
    var $7 = HEAP32[$5 + 4 >> 2];
    if ((HEAP32[$7 + 28 >> 2] | 0) == 0) {
      var $markedAny_2 = $markedAny_01;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$7 + 12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $13;
    var $17 = __Z20IsAboutToBeFinalizedP9JSContextPKv($2, $16);
    if ($17) {
      var $markedAny_2 = $markedAny_01;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $7 + 32 | 0;
    var $20 = __ZNK2JS5Value10isMarkableEv($19);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $markedAny_1 = $markedAny_01;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value9toGCThingEv($19);
    var $23 = __Z20IsAboutToBeFinalizedP9JSContextPKv($2, $22);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $markedAny_1 = $markedAny_01;
      __label__ = 8;
      break;
    }
   case 7:
    var $markedAny_1 = 1;
    __label__ = 8;
    break;
   case 8:
    var $markedAny_1;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $19, undef);
    var $markedAny_2 = $markedAny_1;
    __label__ = 9;
    break;
   case 9:
    var $markedAny_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    var $27 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r);
    if ($27) {
      var $markedAny_0_lcssa = $markedAny_2;
      __label__ = 10;
      break;
    } else {
      var $markedAny_01 = $markedAny_2;
      __label__ = 2;
      break;
    }
   case 10:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return ($markedAny_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free864($p) {
  _free($p);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS5_13MapHashPolicyES4_E6AddPtrERKS1_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPhjEEEENS_7MoveRefIT_EERS5_($1, $8);
  __ZN2js12HashMapEntryIPhjEaSENS_7MoveRefIS2_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPhjEaSENS_7MoveRefIS2_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPhjEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefIPhEcvRS1_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIPhjEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $9);
  var $10 = __ZNK2js7MoveRefIjEcvRjEv($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPhjEEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC2ERS3_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhjEC1Ev($this) {
  __ZN2js12HashMapEntryIPhjEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l) {
  var $1 = __ZN2js13PointerHasherIPhLj2EE4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE($1);
  var $3 = __ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($this);
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($1);
  HEAP8[$this + 24 | 0] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this);
  return $1;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($1);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $1);
  return;
}

function __ZN2js2gc8FreeSpan13encodeOffsetsEjj($firstOffset, $lastOffset) {
  return $lastOffset << 16 | $firstOffset;
}

function _JSVAL_TO_GCTHING_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZNK2js2gc11ArenaHeader7addressEv($this) {
  return $this;
}

function _JSID_IS_STRING869($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING870($iden) {
  return $iden;
}

function _JSID_TO_INT872($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT873($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT874($iden) {
  return $iden & -8;
}

function _JSVAL_IS_TRACEABLE_IMPL($l_0$0, $l_0$1) {
  var $2 = $l_0$1;
  return (($2 | 0) == -123 | ($2 | 0) == -121) & 1;
}

function __ZN2js2gc5Chunk11fromAddressEj($addr) {
  return $addr & -1048576;
}

function __ZN3WTF20BumpPointerAllocatorC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev($this) {
  HEAP8[$this + 24 | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js18ThreadContextRangeC2EP9JSContext($this, $cx) {
  var $3 = HEAP32[$cx + 52 >> 2] + 144140 | 0;
  HEAP32[$this + 4 >> 2] = $3;
  var $6 = HEAP32[$3 >> 2];
  HEAP32[$this >> 2] = $6;
  return;
}

function __ZNK2js2gc8FreeSpan7isEmptyEv($this) {
  return HEAPU32[$this >> 2] >>> 0 > HEAPU32[$this + 4 >> 2] >>> 0;
}

function __ZN2js2gc8FreeSpan11initAsEmptyEj($this, $arenaAddr) {
  HEAP32[$this >> 2] = $arenaAddr + 4096 | 0;
  HEAP32[$this + 4 >> 2] = $arenaAddr | 4095;
  return;
}

function __ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv($this) {
  return HEAP32[$this + 4 >> 2] & -4096;
}

function __ZNK2js2gc8FreeSpan7hasNextEv($this) {
  return (HEAP32[$this + 4 >> 2] & 1 | 0) == 0;
}

function __ZNK2js2gc8FreeSpan8nextSpanEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js2gc8FreeSpanC2Ejj($this, $first, $last) {
  HEAP32[$this >> 2] = $first;
  HEAP32[$this + 4 >> 2] = $last;
  return;
}

function __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($kind) {
  return HEAP32[__ZN2js2gc5Arena17FirstThingOffsetsE + ($kind << 2) >> 2];
}

function __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($this, $thingKind) {
  return HEAP32[$this + 160 + ($thingKind << 3) >> 2];
}

function __ZNK9JSWrapper5flagsEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js18RuntimeAllocPolicyC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js9DtoaCacheC2Ev($this) {
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZN2js12PropertyTreeC2EP13JSCompartment($this, $comp) {
  HEAP32[$this >> 2] = $comp;
  return;
}

function __ZN2js2gc10ArenaLists9ArenaList5clearEv($this) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $1;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + HEAP32[$this + 4 >> 2] * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = $this | 0;
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j($10, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF20BumpPointerAllocatorC1Ev($this) {
  __ZN3WTF20BumpPointerAllocatorC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13WatchpointMapD1Ev($this) {
  __ZN2js13WatchpointMapD2Ev($this);
  return;
}

function __ZN2js13WatchpointMapD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv($this);
    __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 1024, 1);
  return;
}

function __ZNK2js2gc8FreeSpan11arenaHeaderEv($this) {
  var $1 = __ZNK2js2gc8FreeSpan12arenaAddressEv($this);
  return $1;
}

function __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($this, $span) {
  var $1 = __ZNK2js2gc8FreeSpan15encodeAsOffsetsEv($span);
  HEAP32[$this + 8 >> 2] = $1;
  return;
}

function __ZNK2js2gc8FreeSpan15encodeAsOffsetsEv($this) {
  var $1 = __ZNK2js2gc8FreeSpan12arenaAddressEv($this);
  var $4 = HEAP32[$this >> 2] - $1 | 0;
  var $7 = HEAP32[$this + 4 >> 2] & 4095;
  var $8 = __ZN2js2gc8FreeSpan13encodeOffsetsEjj($4, $7);
  return $8;
}

function __ZNK2js2gc8FreeSpan12arenaAddressEv($this) {
  var $1 = __ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv($this);
  return $1;
}

function __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($agg_result, $this) {
  var $1 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($this);
  var $3 = HEAP32[$this + 8 >> 2];
  __ZN2js2gc8FreeSpan13decodeOffsetsEjj($agg_result, $1, $3);
  return;
}

function __ZNK2js2gc11ArenaHeader12arenaAddressEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader7addressEv($this);
  return $1;
}

function __ZN2js2gc8FreeSpan13decodeOffsetsEjj($agg_result, $arenaAddr, $offsets) {
  var $3 = ($offsets & 65535) + $arenaAddr | 0;
  var $4 = $offsets >>> 16 | $arenaAddr;
  __ZN2js2gc8FreeSpanC1Ejj($agg_result, $3, $4);
  return;
}

function __ZN2js2gc8FreeSpanC1Ejj($this, $first, $last) {
  __ZN2js2gc8FreeSpanC2Ejj($this, $first, $last);
  return;
}

function __ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  var $1 = $this | 0;
  __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($1, $comp, $kind);
  return;
}

function __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  var $1 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($kind);
  HEAP32[$this >> 2] = $1;
  var $3 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($kind);
  HEAP32[$this + 4 >> 2] = $3;
  var $5 = $comp + 8 | 0;
  var $6 = __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($5, $kind);
  HEAP32[$this + 8 >> 2] = $6;
  var $8 = $this + 12 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($8, 0);
  HEAP32[$this + 20 >> 2] = $8;
  var $11 = HEAP32[$8 >> 2];
  HEAP32[$this + 24 >> 2] = $11;
  __ZN2js2gc12CellIterImpl4nextEv($this);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject866($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL10Int32ValueEi871($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL14UndefinedValueEv875($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js2gc10ArenaListsD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $2 = $this + 160 + ($i_01 << 3) | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $7 = HEAP32[$5 + 4 >> 2];
    HEAP32[$2 >> 2] = $7;
    var $8 = __ZNK2js2gc11ArenaHeader5chunkEv($5);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($8, $5);
    var $9 = HEAP32[$2 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $5 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    var $11 = $i_01 + 1 | 0;
    if (($11 | 0) == 20) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc11ArenaHeader5chunkEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader7addressEv($this);
  var $2 = __ZN2js2gc5Chunk11fromAddressEj($1);
  return $2;
}

function __ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15NativeIterCacheC2Ev($this) {
  HEAP32[$this + 1024 >> 2] = 0;
  var $2 = $this | 0;
  __ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_($2);
  return;
}

function __ZN2js2gc10ArenaListsC2Ev($this) {
  var $1 = $this + 160 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($1);
  var $2 = $this + 168 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($2);
  var $3 = $this + 176 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($3);
  var $4 = $this + 184 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($4);
  var $5 = $this + 192 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($5);
  var $6 = $this + 200 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($6);
  var $7 = $this + 208 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($7);
  var $8 = $this + 216 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($8);
  var $9 = $this + 224 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($9);
  var $10 = $this + 232 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($10);
  var $11 = $this + 240 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($11);
  var $12 = $this + 248 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($12);
  var $13 = $this + 256 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($13);
  var $14 = $this + 264 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($14);
  var $15 = $this + 272 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($15);
  var $16 = $this + 280 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($16);
  var $17 = $this + 288 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($17);
  var $18 = $this + 296 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($18);
  var $19 = $this + 304 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($19);
  var $20 = $this + 312 | 0;
  __ZN2js2gc10ArenaLists9ArenaListC1Ev($20);
  var $21 = $this | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($21, 0);
  var $22 = $this + 8 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($22, 0);
  var $23 = $this + 16 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($23, 0);
  var $24 = $this + 24 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($24, 0);
  var $25 = $this + 32 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($25, 0);
  var $26 = $this + 40 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($26, 0);
  var $27 = $this + 48 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($27, 0);
  var $28 = $this + 56 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($28, 0);
  var $29 = $this + 64 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($29, 0);
  var $30 = $this + 72 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($30, 0);
  var $31 = $this + 80 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($31, 0);
  var $32 = $this + 88 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($32, 0);
  var $33 = $this + 96 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($33, 0);
  var $34 = $this + 104 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($34, 0);
  var $35 = $this + 112 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($35, 0);
  var $36 = $this + 120 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($36, 0);
  var $37 = $this + 128 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($37, 0);
  var $38 = $this + 136 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($38, 0);
  var $39 = $this + 144 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($39, 0);
  var $40 = $this + 152 | 0;
  __ZN2js2gc8FreeSpan11initAsEmptyEj($40, 0);
  return;
}

__ZN2js2gc10ArenaListsC2Ev["X"] = 1;

function __ZN2js2gc10ArenaLists9ArenaListC1Ev($this) {
  __ZN2js2gc10ArenaLists9ArenaListC2Ev($this);
  return;
}

function __ZN2js2gc10ArenaLists9ArenaListC2Ev($this) {
  __ZN2js2gc10ArenaLists9ArenaList5clearEv($this);
  return;
}

function __ZN2js5crash5StackC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash10CrashStackC2Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash10CrashStackC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash11CrashHeaderC1Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash5Stack8snapshotEv($this) {
  var $1 = _time(0);
  var $2$1 = ($1 | 0) < 0 ? -1 : 0;
  var $3 = $this + 24 | 0;
  HEAP32[$3 >> 2] = $1;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return 0;
}

function __ZN2js5crash4RingC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash9CrashRingC2Ey($1, $id$0, $id$1);
  return;
}

function __ZN2js5crash9CrashRingC2Ey($this, $id$0, $id$1) {
  var $1 = $this | 0;
  __ZN2js5crash11CrashHeaderC1Ey($1, $id$0, $id$1);
  var $3 = $this + 24 | 0;
  for (var $$dest = $3 >> 2, $$stop = $$dest + 8194; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  return;
}

function __ZN2js5crash4Ring4pushEyPvj($this, $tag$0, $tag$1, $data, $size) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  var $t = __stackBase__ + 8;
  var $mysize = __stackBase__ + 16;
  HEAP32[$1 >> 2] = $tag$0;
  HEAP32[$1 + 4 >> 2] = $tag$1;
  var $2 = _time(0);
  var $3$1 = ($2 | 0) < 0 ? -1 : 0;
  HEAP32[$t >> 2] = $2;
  HEAP32[$t + 4 >> 2] = $3$1;
  var $4 = $1;
  __ZN2js5crash4Ring9copyBytesEPvj($this, $4, 8);
  var $5 = $t;
  __ZN2js5crash4Ring9copyBytesEPvj($this, $5, 8);
  __ZN2js5crash4Ring9copyBytesEPvj($this, $data, $size);
  HEAP32[$mysize >> 2] = $size;
  HEAP32[$mysize + 4 >> 2] = 0;
  var $7 = $mysize;
  __ZN2js5crash4Ring9copyBytesEPvj($this, $7, 8);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5crash15SnapshotGCStackEv() {
  return;
}

function __ZN2js5crash18SnapshotErrorStackEv() {
  return;
}

function __ZN2js5crash13SaveCrashDataEyPvj($tag$0, $tag$1, $ptr, $size) {
  return;
}

function _JS_EnumerateDiagnosticMemoryRegions($callback) {
  return;
}

function __ZN2js5crash4Ring9copyBytesEPvj($this, $data, $size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $size >>> 0 < 32768 ? $size : 32768;
    var $2 = $this + 24 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4$0 = $_0;
    var $4$1 = 0;
    var $5$0 = (i64Math.add($3$0, $3$1, $4$0, $4$1), i64Math.result[0]);
    var $5$1 = i64Math.result[1];
    var $$emscripten$temp$0$1 = 0;
    if ($5$1 >>> 0 > $$emscripten$temp$0$1 >>> 0 || $5$1 >>> 0 == $$emscripten$temp$0$1 >>> 0 && $5$0 >>> 0 > 32768 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8$0 = (i64Math.subtract(32768, 0, $3$0, $3$1), i64Math.result[0]);
    var $8$1 = i64Math.result[1];
    var $9 = $8$0;
    var $10 = $_0 - $9 | 0;
    var $12 = $this + ($3$0 + 32) | 0;
    _memcpy($12, $data, $9, 1);
    var $13 = $this + 32 | 0;
    var $14 = $data + $9 | 0;
    _memcpy($13, $14, $10, 1);
    var $storemerge$1 = 0;
    var $storemerge$0 = $10;
    __label__ = 4;
    break;
   case 3:
    var $18 = $this + ($3$0 + 32) | 0;
    _memcpy($18, $data, $_0, 1);
    var $19$0 = HEAP32[$2 >> 2];
    var $19$1 = HEAP32[$2 + 4 >> 2];
    var $20$0 = (i64Math.add($19$0, $19$1, $4$0, $4$1), i64Math.result[0]);
    var $20$1 = i64Math.result[1];
    var $storemerge$1 = $20$1;
    var $storemerge$0 = $20$0;
    __label__ = 4;
    break;
   case 4:
    var $storemerge$0;
    var $storemerge$1;
    HEAP32[$2 >> 2] = $storemerge$0;
    HEAP32[$2 + 4 >> 2] = $storemerge$1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function ___cxx_global_var_init888() {
  __ZN2js5crash5StackC2Ey(__ZN2js5crashL8gGCStackE, 1024, 0);
  return;
}

function ___cxx_global_var_init1889() {
  __ZN2js5crash5StackC2Ey(__ZN2js5crashL11gErrorStackE, 1025, 0);
  return;
}

function ___cxx_global_var_init2890() {
  __ZN2js5crash4RingC2Ey(__ZN2js5crashL11gRingBufferE, 2048, 0);
  return;
}

function __ZN2js5crash11CrashHeaderC1Ey($this, $id$0, $id$1) {
  __ZN2js5crash11CrashHeaderC2Ey($this, $id$0, $id$1);
  return;
}

function __ZN2js5crash11CrashHeaderC2Ey($this, $id$0, $id$1) {
  var $1 = $this + 16 | 0;
  HEAP32[$1 >> 2] = $id$0;
  HEAP32[$1 + 4 >> 2] = $id$1;
  var $2 = $this | 0;
  for (var $$src = STRING_TABLE.__ZN2js5crashL12crash_cookieE | 0, $$dest = $2, $$stop = $$src + 16; $$src < $$stop; $$src++, $$dest++) {
    HEAP8[$$dest] = HEAP8[$$src];
  }
  return;
}

function __GLOBAL__I_a891() {
  ___cxx_global_var_init888();
  ___cxx_global_var_init1889();
  ___cxx_global_var_init2890();
  return;
}

function __ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $vp) {
  var $2 = ($hint | 0) == 0 ? 3 : $hint;
  var $3 = $cx;
  var $4 = $obj;
  var $5 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($3, $4, $2, $vp);
  return $5;
}

function __ZL8date_UTCP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $msec_time = __stackBase__;
    var $1 = $vp + 16 | 0;
    var $2 = __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $1, $msec_time);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$msec_time >> 2], tempDoubleI32[1] = HEAP32[$msec_time + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZL18JSDOUBLE_IS_FINITEd1004($5);
    if (($6 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($5 < 0) {
      __label__ = 4;
      break;
    } else {
      var $13 = $5;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = -$5;
    __label__ = 5;
    break;
   case 5:
    var $13;
    if ($13 > 864e13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $5;
    var $17 = __ZL18js_DoubleToIntegerd1005($16);
    var $21 = $17;
    __label__ = 8;
    break;
   case 7:
    var $19 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $21 = $19;
    __label__ = 8;
    break;
   case 8:
    var $21;
    tempDoubleF64[0] = $21, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $22 = __ZN2JS5Value9setNumberEd($vp, $21);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10date_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($6, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setStringEP8JSString($5, $7);
    var $10 = $cx;
    var $11 = __ZN8JSString12ensureLinearEP9JSContext($7, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL16date_parseStringP14JSLinearStringPdP9JSContext($11, $result, $cx);
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $17);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 7:
    var $19 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $20 = __ZL18JSDOUBLE_IS_FINITEd1004($19);
    if (($20 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($19 < 0) {
      __label__ = 9;
      break;
    } else {
      var $27 = $19;
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = -$19;
    __label__ = 10;
    break;
   case 10:
    var $27;
    if ($27 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $30 = $19;
    var $31 = __ZL18js_DoubleToIntegerd1005($30);
    var $35 = $31;
    __label__ = 13;
    break;
   case 12:
    var $33 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $35 = $33;
    __label__ = 13;
    break;
   case 13:
    var $35;
    tempDoubleF64[0] = $35, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $36 = __ZN2JS5Value9setNumberEd($vp, $35);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8date_nowP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL11NowAsMillisv();
  __ZN2JS5Value9setDoubleEd($vp, $1);
  return 1;
}

function __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2JS5Value9setNumberEd($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $localtime = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $utctime);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, 0, $localtime);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $14 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $16 = ($13 - $14) / 6e4;
    var $17 = __ZN2JS5Value9setNumberEd($vp, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_getYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $yearVal = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 2);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $yearVal | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZNK2JS5Value7isInt32Ev($yearVal);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZNK2JS5Value7toInt32Ev($yearVal);
    var $17 = $16 - 1900 | 0;
    __ZN2JS5Value8setInt32Ei($vp, $17);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $12$0;
    HEAP32[$19 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 2);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12YearFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_getMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 3);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL13MonthFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_getDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 4);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15date_getUTCDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12DateFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11date_getDayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 5);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14date_getUTCDayP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL7WeekDayd($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_getHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 6);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL12HourFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15date_getMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 7);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL11MinFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject7getSlotEj($3, 8);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $result);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      var $10 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL10msFromTimed($3);
    var $8 = $7 | 0;
    tempDoubleF64[0] = $8, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_setTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject6isDateEv($3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 6:
    var $13 = $vp + 16 | 0;
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $13, $result);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $16 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $17 = __ZL18JSDOUBLE_IS_FINITEd1004($16);
    if (($17 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($16 < 0) {
      __label__ = 9;
      break;
    } else {
      var $24 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $24 = -$16;
    __label__ = 10;
    break;
   case 10:
    var $24;
    if ($24 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = $16;
    var $28 = __ZL18js_DoubleToIntegerd1005($27);
    var $32 = $28;
    __label__ = 13;
    break;
   case 12:
    var $30 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $32 = $30;
    __label__ = 13;
    break;
   case 13:
    var $32;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $32, $vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_setYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $year = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $13 = $vp + 16 | 0;
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $13, $year);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 6:
    var $16 = (tempDoubleI32[0] = HEAP32[$year >> 2], tempDoubleI32[1] = HEAP32[$year + 4 >> 2], tempDoubleF64[0]);
    var $17 = __ZL18JSDOUBLE_IS_FINITEd1004($16);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    var $21 = __ZL18js_DoubleToIntegerd1005($16);
    if ($21 >= 0 & $21 <= 99) {
      __label__ = 9;
      break;
    } else {
      var $27 = $21;
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = $21 + 1900;
    __label__ = 10;
    break;
   case 10:
    var $27;
    tempDoubleF64[0] = $27, HEAP32[$year >> 2] = tempDoubleI32[0], HEAP32[$year + 4 >> 2] = tempDoubleI32[1];
    var $28 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $29 = __ZL18JSDOUBLE_IS_FINITEd1004($28);
    if (($29 | 0) == 0) {
      var $34 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = __ZL9LocalTimedP9JSContext($28, $cx);
    var $34 = $32;
    __label__ = 12;
    break;
   case 12:
    var $34;
    var $35 = __ZL13MonthFromTimed($34);
    var $36 = $35 | 0;
    var $37 = __ZL12DateFromTimed($34);
    var $38 = $37 | 0;
    var $39 = __ZL7MakeDayddd($27, $36, $38);
    var $40 = $39 * 864e5;
    var $41 = __ZL13TimeWithinDayd($34);
    var $42 = $40 + $41;
    var $43 = __ZL3UTCdP9JSContext($42, $cx);
    tempDoubleF64[0] = $43, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $44 = __ZL18JSDOUBLE_IS_FINITEd1004($43);
    if (($44 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($43 < 0) {
      __label__ = 14;
      break;
    } else {
      var $51 = $43;
      __label__ = 15;
      break;
    }
   case 14:
    var $51 = -$43;
    __label__ = 15;
    break;
   case 15:
    var $51;
    if ($51 > 864e13) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $54 = $43;
    var $55 = __ZL18js_DoubleToIntegerd1005($54);
    var $59 = $55;
    __label__ = 18;
    break;
   case 17:
    var $57 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $59 = $57;
    __label__ = 18;
    break;
   case 18:
    var $59;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $59, $vp);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12date_setYearP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16date_setFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 3, 1, $argc, $vp);
  return $1;
}

function __ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 3, 0, $argc, $vp);
  return $1;
}

function __ZL13date_setMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 2, 1, $argc, $vp);
  return $1;
}

function __ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 2, 0, $argc, $vp);
  return $1;
}

function __ZL12date_setDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 1, 1, $argc, $vp);
  return $1;
}

function __ZL15date_setUTCDateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, 1, 0, $argc, $vp);
  return $1;
}

function __ZL13date_setHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 4, 1, $argc, $vp);
  return $1;
}

function __ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 4, 0, $argc, $vp);
  return $1;
}

function __ZL15date_setMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 3, 1, $argc, $vp);
  return $1;
}

function __ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 3, 0, $argc, $vp);
  return $1;
}

function __ZL15date_setSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 2, 1, $argc, $vp);
  return $1;
}

function __ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 2, 0, $argc, $vp);
  return $1;
}

function __ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 1, 1, $argc, $vp);
  return $1;
}

function __ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, 1, 0, $argc, $vp);
  return $1;
}

function __ZL16date_toGMTStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, 82);
  return $1;
}

function __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str1462819 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str104998 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $6, STRING_TABLE.__str1061000 | 0, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fmtbytes = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_1 = $3;
    __label__ = 8;
    break;
   case 3:
    var $5 = $vp + 8 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $vp + 16 | 0;
    var $12 = $cx;
    var $13 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($12, $11);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($11, $13);
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($fmtbytes, $cx, $13);
    var $16 = __ZNK16JSAutoByteStringntEv($fmtbytes);
    if ($16) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK16JSAutoByteString3ptrEv($fmtbytes);
    var $19 = __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $8, $18, $vp);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($fmtbytes);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17date_toDateStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 1, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18JSDOUBLE_IS_FINITEd1004($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL17date_toTimeStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 2, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16date_toISOStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, 84);
  return $1;
}

function __ZL11date_toJSONP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2JSL11ObjectValueER8JSObject1038($tv, $6);
    var $7 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE($cx, $tv);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $9 = __ZNK2JS5Value8isDoubleEv($tv);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value8toDoubleEv($tv);
    var $12 = __ZL18JSDOUBLE_IS_FINITEd1004($11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($vp);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 6:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210240 >> 2];
    var $21 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($3, $2, $20, $vp);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZL13js_IsCallableRKN2JS5ValueE1052($vp);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = _JS_ReportErrorFlagsAndNumber($2, 0, 2, 0, 253, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 13;
    break;
   case 9:
    var $28 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($28);
    var $30 = $cx + 60 | 0;
    var $31 = $cx;
    var $32 = $args;
    var $33 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($30, $31, 0, $32);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $35 = $args | 0;
    var $36 = __ZNK2js12CallReceiver7calleevEv($35);
    var $37 = $vp | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $36 | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = __ZNK2js12CallReceiver5thisvEv($35);
    __ZN2JS5Value9setObjectER8JSObject($40, $3);
    var $41 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($2, $28, 0);
    if ($41) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $43 = __ZNK2js12CallReceiver4rvalEv($35);
    var $44 = $43 | 0;
    var $45$0 = HEAP32[$44 >> 2];
    var $45$1 = HEAP32[$44 + 4 >> 2];
    HEAP32[$37 >> 2] = $45$0;
    HEAP32[$37 + 4 >> 2] = $45$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($28);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11date_toJSONP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13date_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $cbuf = __stackBase__ + 8;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = $cx;
    var $5 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($4, $cbuf, $3, 10);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $9 = _JS_smprintf(STRING_TABLE.__str122090 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_Date_str | 0, HEAP32[tempInt + 4 >> 2] = $5, tempInt));
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $13 = _JS_NewStringCopyZ($4, $9);
    __ZN9JSContext5free_EPv(undef, $9);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $13);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js12ToCStringBufD2Ev($cbuf);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 0, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12date_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = $vp + 8 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $vp + 16 | 0;
    var $11 = $cx;
    var $12 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($11, $10);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN8JSString12ensureLinearEP9JSContext($12, $6);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = HEAP32[HEAP32[$cx + 52 >> 2] + 21e4 >> 2] | 0;
    var $23 = __ZN2js12EqualStringsEP14JSLinearStringS1_($15, $22);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = __ZL12date_getTimeP9JSContextjPN2JS5ValueE($cx, $argc, $vp);
    var $_0 = $25;
    __label__ = 9;
    break;
   case 8:
    var $27 = __ZL13date_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp);
    var $_0 = $27;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z7js_DateP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $msec_time = __stackBase__ + 8;
    var $1 = __ZN2jsL14IsConstructingEPKN2JS5ValueE1003($vp);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL11NowAsMillisv();
    var $4 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $3, 0, $vp);
    var $_0 = $4;
    __label__ = 37;
    break;
   case 3:
    var $6 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($argc | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 4:
    var $8 = __ZL11NowAsMillisv();
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $8;
    __label__ = 35;
    break;
   case 5:
    var $10 = __ZNK2JS5Value8isStringEv($6);
    if ($10) {
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = $cx;
    var $13 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($12, $6, $d);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 37;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $16 = __ZL18JSDOUBLE_IS_FINITEd1004($15);
    if (($16 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($15 < 0) {
      __label__ = 9;
      break;
    } else {
      var $23 = $15;
      __label__ = 10;
      break;
    }
   case 9:
    var $23 = -$15;
    __label__ = 10;
    break;
   case 10:
    var $23;
    if ($23 > 864e13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = $15;
    var $27 = __ZL18js_DoubleToIntegerd1005($26);
    var $31 = $27;
    __label__ = 13;
    break;
   case 12:
    var $29 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $31 = $29;
    __label__ = 13;
    break;
   case 13:
    var $31;
    tempDoubleF64[0] = $31, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $31;
    __label__ = 35;
    break;
   case 14:
    var $33 = $cx;
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($33, $6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2JS5Value9setStringEP8JSString($6, $34);
    var $37 = $cx;
    var $38 = __ZN8JSString12ensureLinearEP9JSContext($34, $37);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = __ZL16date_parseStringP14JSLinearStringPdP9JSContext($38, $d, $cx);
    if (($41 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $44 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $44, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $44;
    __label__ = 35;
    break;
   case 18:
    var $46 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $47 = __ZL18JSDOUBLE_IS_FINITEd1004($46);
    if (($47 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($46 < 0) {
      __label__ = 20;
      break;
    } else {
      var $54 = $46;
      __label__ = 21;
      break;
    }
   case 20:
    var $54 = -$46;
    __label__ = 21;
    break;
   case 21:
    var $54;
    if ($54 > 864e13) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $57 = $46;
    var $58 = __ZL18js_DoubleToIntegerd1005($57);
    var $62 = $58;
    __label__ = 24;
    break;
   case 23:
    var $60 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $62 = $60;
    __label__ = 24;
    break;
   case 24:
    var $62;
    tempDoubleF64[0] = $62, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $62;
    __label__ = 35;
    break;
   case 25:
    var $64 = __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $6, $msec_time);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $67 = (tempDoubleI32[0] = HEAP32[$msec_time >> 2], tempDoubleI32[1] = HEAP32[$msec_time + 4 >> 2], tempDoubleF64[0]);
    var $68 = __ZL18JSDOUBLE_IS_FINITEd1004($67);
    if (($68 | 0) == 0) {
      var $89 = $67;
      __label__ = 34;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $71 = __ZL3UTCdP9JSContext($67, $cx);
    tempDoubleF64[0] = $71, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $72 = __ZL18JSDOUBLE_IS_FINITEd1004($71);
    if (($72 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($71 < 0) {
      __label__ = 29;
      break;
    } else {
      var $79 = $71;
      __label__ = 30;
      break;
    }
   case 29:
    var $79 = -$71;
    __label__ = 30;
    break;
   case 30:
    var $79;
    if ($79 > 864e13) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $82 = $71;
    var $83 = __ZL18js_DoubleToIntegerd1005($82);
    var $87 = $83;
    __label__ = 33;
    break;
   case 32:
    var $85 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $87 = $85;
    __label__ = 33;
    break;
   case 33:
    var $87;
    tempDoubleF64[0] = $87, HEAP32[$msec_time >> 2] = tempDoubleI32[0], HEAP32[$msec_time + 4 >> 2] = tempDoubleI32[1];
    var $89 = $87;
    __label__ = 34;
    break;
   case 34:
    var $89;
    tempDoubleF64[0] = $89, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $91 = $89;
    __label__ = 35;
    break;
   case 35:
    var $91;
    var $92 = __Z20js_NewDateObjectMsecP9JSContextd($cx, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $95 = $92;
    __ZN2JS5Value9setObjectER8JSObject($vp, $95);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z7js_DateP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE1003($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $date, $format, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 220;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $tzbuf = __stackBase__ + 100;
    var $split = __stackBase__ + 200;
    var $1 = __ZL18JSDOUBLE_IS_FINITEd1004($date);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $buf | 0;
    var $5 = _JS_snprintf($4, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_pre_phi = $4;
    __label__ = 19;
    break;
   case 3:
    var $7 = __ZL9LocalTimedP9JSContext($date, $cx);
    var $8 = __ZL10AdjustTimedP9JSContext($date, $cx);
    var $9 = $8 / 6e4;
    var $10 = _floor($9);
    var $11 = $10 & -1;
    var $15 = (($11 | 0) / 60 & -1) * 100 + $11 % 60 | 0;
    __ZL11new_explodedP8PRMJTimeP9JSContext($date, $split, $cx);
    var $16 = $tzbuf | 0;
    var $17 = _PRMJ_FormatTime($16, 100, STRING_TABLE.__str77971 | 0, $split);
    if (($17 | 0) == 0) {
      var $usetz_3 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = _strlen($16);
    if ($20 >>> 0 > 100) {
      var $usetz_2 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($20 | 0) == 0) {
      var $usetz_2 = 1;
      __label__ = 11;
      break;
    } else {
      var $usetz_03 = 1;
      var $i_04 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_04;
    var $usetz_03;
    var $26 = HEAP8[$tzbuf + $i_04 | 0] << 24 >> 24 & 65535;
    if ($26 >>> 0 > 127) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = _isalpha($26);
    if (($29 | 0) != 0 | ($26 - 48 | 0) >>> 0 < 10) {
      var $usetz_1 = $usetz_03;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($26 | 0) == 41 || ($26 | 0) == 40 || ($26 | 0) == 32) {
      var $usetz_1 = $usetz_03;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $usetz_1 = 0;
    __label__ = 10;
    break;
   case 10:
    var $usetz_1;
    var $33 = $i_04 + 1 | 0;
    if (($33 | 0) == ($20 | 0)) {
      var $usetz_2 = $usetz_1;
      __label__ = 11;
      break;
    } else {
      var $usetz_03 = $usetz_1;
      var $i_04 = $33;
      __label__ = 6;
      break;
    }
   case 11:
    var $usetz_2;
    if (HEAP8[$16] << 24 >> 24 == 40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    if (HEAP8[$tzbuf + 1 | 0] << 24 >> 24 == 41) {
      __label__ = 13;
      break;
    } else {
      var $usetz_3 = $usetz_2;
      __label__ = 14;
      break;
    }
   case 13:
    var $usetz_3 = 0;
    __label__ = 14;
    break;
   case 14:
    var $usetz_3;
    if (($format | 0) == 0) {
      __label__ = 16;
      break;
    } else if (($format | 0) == 1) {
      __label__ = 17;
      break;
    } else if (($format | 0) == 2) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_pre_phi = $buf | 0;
    __label__ = 19;
    break;
   case 16:
    var $43 = $buf | 0;
    var $44 = __ZL7WeekDayd($7);
    var $46 = HEAP32[__ZL4days + ($44 << 2) >> 2];
    var $47 = __ZL13MonthFromTimed($7);
    var $49 = HEAP32[__ZL6months + ($47 << 2) >> 2];
    var $50 = __ZL12DateFromTimed($7);
    var $51 = __ZL12YearFromTimed($7);
    var $52 = __ZL12HourFromTimed($7);
    var $53 = __ZL11MinFromTimed($7);
    var $54 = __ZL11SecFromTimed($7);
    var $55 = ($usetz_3 | 0) != 0;
    var $56 = $55 ? STRING_TABLE._js_space_str | 0 : __str93064 | 0;
    var $57 = $55 ? $16 : __str93064 | 0;
    var $58 = _JS_snprintf($43, 100, STRING_TABLE.__str78972 | 0, (tempInt = STACKTOP, STACKTOP += 40, HEAP32[tempInt >> 2] = $46, HEAP32[tempInt + 4 >> 2] = $49, HEAP32[tempInt + 8 >> 2] = $50, HEAP32[tempInt + 12 >> 2] = $51, HEAP32[tempInt + 16 >> 2] = $52, HEAP32[tempInt + 20 >> 2] = $53, HEAP32[tempInt + 24 >> 2] = $54, HEAP32[tempInt + 28 >> 2] = $15, HEAP32[tempInt + 32 >> 2] = $56, HEAP32[tempInt + 36 >> 2] = $57, tempInt));
    var $_pre_phi = $43;
    __label__ = 19;
    break;
   case 17:
    var $60 = $buf | 0;
    var $61 = __ZL7WeekDayd($7);
    var $63 = HEAP32[__ZL4days + ($61 << 2) >> 2];
    var $64 = __ZL13MonthFromTimed($7);
    var $66 = HEAP32[__ZL6months + ($64 << 2) >> 2];
    var $67 = __ZL12DateFromTimed($7);
    var $68 = __ZL12YearFromTimed($7);
    var $69 = _JS_snprintf($60, 100, STRING_TABLE.__str81975 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $63, HEAP32[tempInt + 4 >> 2] = $66, HEAP32[tempInt + 8 >> 2] = $67, HEAP32[tempInt + 12 >> 2] = $68, tempInt));
    var $_pre_phi = $60;
    __label__ = 19;
    break;
   case 18:
    var $71 = $buf | 0;
    var $72 = __ZL12HourFromTimed($7);
    var $73 = __ZL11MinFromTimed($7);
    var $74 = __ZL11SecFromTimed($7);
    var $75 = ($usetz_3 | 0) != 0;
    var $76 = $75 ? STRING_TABLE._js_space_str | 0 : __str93064 | 0;
    var $77 = $75 ? $16 : __str93064 | 0;
    var $78 = _JS_snprintf($71, 100, STRING_TABLE.__str82976 | 0, (tempInt = STACKTOP, STACKTOP += 24, HEAP32[tempInt >> 2] = $72, HEAP32[tempInt + 4 >> 2] = $73, HEAP32[tempInt + 8 >> 2] = $74, HEAP32[tempInt + 12 >> 2] = $15, HEAP32[tempInt + 16 >> 2] = $76, HEAP32[tempInt + 20 >> 2] = $77, tempInt));
    var $_pre_phi = $71;
    __label__ = 19;
    break;
   case 19:
    var $_pre_phi;
    var $80 = $cx;
    var $81 = _JS_NewStringCopyZ($80, $_pre_phi);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JS5Value9setStringEP8JSString($rval, $81);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE["X"] = 1;

function __ZL11NowAsMillisv() {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  return $2$0 + $2$1 * 4294967296;
}

function __ZL18js_DoubleToIntegerd1005($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd1004($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd1014($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd1014($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL16date_parseStringP14JSLinearStringPdP9JSContext($str, $result, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL19date_parseISOStringP14JSLinearStringPdP9JSContext($str, $result, $cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 79;
      break;
    }
   case 2:
    var $4 = __ZNK14JSLinearString5charsEv($str);
    var $5 = $str | 0;
    var $6 = __ZNK8JSString6lengthEv($5);
    if (($6 | 0) == 0) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = 0;
      var $seenplusminus_0 = 0;
      var $i_0 = 0;
      var $year_0 = -1;
      var $mon_0 = -1;
      var $mday_0 = -1;
      var $hour_0 = -1;
      var $min_0 = -1;
      var $sec_0 = -1;
      var $tzoffset_0 = -1;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $prevc_0;
    var $tzoffset_0;
    var $sec_0;
    var $min_0;
    var $hour_0;
    var $mday_0;
    var $mon_0;
    var $year_0;
    var $i_0;
    var $seenplusminus_0;
    var $seenmonthname_0;
    if ($i_0 >>> 0 < $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 4:
    var $11 = HEAPU16[$4 + ($i_0 << 1) >> 1];
    var $12 = $11 & 65535;
    var $13 = $i_0 + 1 | 0;
    if (($11 & 65535) < 33) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $13;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($11 << 16 >> 16 == 44) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $13;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else if ($11 << 16 >> 16 == 45) {
      __label__ = 6;
      break;
    } else if ($11 << 16 >> 16 == 40) {
      var $depth_0_ph = 1;
      var $i_1_ph = $13;
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    if ((HEAP16[$4 + ($13 << 1) >> 1] - 48 & 65535 & 65535) < 10) {
      __label__ = 7;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $13;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    }
   case 7:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $13;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0;
    var $prevc_0 = $12;
    __label__ = 3;
    break;
   case 8:
    var $i_1;
    if ($i_1 >>> 0 < $6 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_1;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    }
   case 9:
    var $24 = HEAP16[$4 + ($i_1 << 1) >> 1];
    var $25 = $i_1 + 1 | 0;
    if ($24 << 16 >> 16 == 40) {
      __label__ = 10;
      break;
    } else if ($24 << 16 >> 16 == 41) {
      __label__ = 12;
      break;
    } else {
      var $i_1 = $25;
      __label__ = 8;
      break;
    }
   case 10:
    var $depth_0_ph = $depth_0_ph + 1 | 0;
    var $i_1_ph = $25;
    __label__ = 11;
    break;
   case 11:
    var $i_1_ph;
    var $depth_0_ph;
    var $i_1 = $i_1_ph;
    __label__ = 8;
    break;
   case 12:
    var $29 = $depth_0_ph - 1 | 0;
    if (($29 | 0) < 1) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $25;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $prevc_0;
      __label__ = 3;
      break;
    } else {
      var $depth_0_ph = $29;
      var $i_1_ph = $25;
      __label__ = 11;
      break;
    }
   case 13:
    if (($11 - 48 & 65535 & 65535) < 10) {
      var $i_2 = $13;
      var $c_0 = $12;
      var $n_0_in = $12;
      __label__ = 14;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 14:
    var $n_0_in;
    var $c_0;
    var $i_2;
    var $n_0 = $n_0_in - 48 | 0;
    var $33 = $i_2 >>> 0 < $6 >>> 0;
    if ($33) {
      __label__ = 15;
      break;
    } else {
      var $c_1 = $c_0;
      __label__ = 17;
      break;
    }
   case 15:
    var $36 = HEAPU16[$4 + ($i_2 << 1) >> 1];
    var $37 = $36 & 65535;
    if (($36 - 48 & 65535 & 65535) < 10) {
      __label__ = 16;
      break;
    } else {
      var $c_1 = $37;
      __label__ = 17;
      break;
    }
   case 16:
    var $41 = $37 + $n_0 * 10 | 0;
    var $i_2 = $i_2 + 1 | 0;
    var $c_0 = $37;
    var $n_0_in = $41;
    __label__ = 14;
    break;
   case 17:
    var $c_1;
    var $43 = ($prevc_0 | 0) == 43;
    if (($prevc_0 | 0) == 45 || ($prevc_0 | 0) == 43) {
      __label__ = 18;
      break;
    } else if (($prevc_0 | 0) == 47) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 18:
    if (($n_0 | 0) < 24) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $n_1 = $n_0 * 60 | 0;
    __label__ = 21;
    break;
   case 20:
    var $n_1 = (($n_0 | 0) / 100 & -1) * 60 + $n_0 % 100 | 0;
    __label__ = 21;
    break;
   case 21:
    var $n_1;
    var $n_2 = $43 ? -$n_1 | 0 : $n_1;
    if (($tzoffset_0 | 0) == -1 || ($tzoffset_0 | 0) == 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = 1;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $n_2;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 22:
    if (($mon_0 | $mday_0 | 0) > -1 & ($year_0 | 0) < 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 23:
    if (($c_1 | 0) < 33) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if (($c_1 | 0) == 47 || ($c_1 | 0) == 44) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($33) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 26:
    if (($c_1 | 0) == 58) {
      __label__ = 27;
      break;
    } else if (($c_1 | 0) == 47) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 27:
    if (($hour_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $n_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if (($min_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $n_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 29:
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $n_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $n_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 31:
    if ($33 & ($c_1 | 0) > 32) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    if (($c_1 | 0) == 45 || ($c_1 | 0) == 44 || ($c_1 | 0) == 40) {
      __label__ = 33;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 33:
    if (($seenplusminus_0 | 0) != 0 & ($n_0 | 0) < 60) {
      __label__ = 34;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 34:
    if (($tzoffset_0 | 0) < 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_2;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0 - $n_0 | 0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 36:
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_2;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $n_0 + $tzoffset_0 | 0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 37:
    if (($hour_0 | 0) > -1 & ($min_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $n_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if (($prevc_0 | 0) == 58 & ($min_0 | 0) > -1 & ($sec_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $n_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $n_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $n_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    if (($year_0 | 0) < 0) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_2;
      var $year_0 = $n_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 42:
    if ($11 << 16 >> 16 == 58 || $11 << 16 >> 16 == 47 || $11 << 16 >> 16 == 45 || $11 << 16 >> 16 == 43) {
      var $seenmonthname_0 = $seenmonthname_0;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $13;
      var $year_0 = $year_0;
      var $mon_0 = $mon_0;
      var $mday_0 = $mday_0;
      var $hour_0 = $hour_0;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_0;
      var $prevc_0 = $12;
      __label__ = 3;
      break;
    } else {
      var $i_3 = $13;
      __label__ = 43;
      break;
    }
   case 43:
    var $i_3;
    if ($i_3 >>> 0 < $6 >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 44:
    var $99 = HEAPU16[$4 + ($i_3 << 1) >> 1];
    if (($99 - 65 & 65535 & 65535) < 26 | ($99 - 97 & 65535 & 65535) < 26) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $i_3 = $i_3 + 1 | 0;
    __label__ = 43;
    break;
   case 46:
    if ($i_3 >>> 0 > $13 >>> 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 47:
    var $106 = $i_3 - $i_0 | 0;
    var $k_0 = 32;
    __label__ = 48;
    break;
   case 48:
    var $k_0;
    var $108 = $k_0 - 1 | 0;
    if (($k_0 | 0) > 0) {
      __label__ = 49;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 49:
    var $112 = HEAP32[__ZL3wtb + ($108 << 2) >> 2];
    var $113 = __ZL18date_regionMatchesPKciPKtiii($112, $4, $i_0, $106);
    if (($113 | 0) == 0) {
      var $k_0 = $108;
      __label__ = 48;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $117 = HEAPU32[__ZL3ttb + ($108 << 2) >> 2];
    if (($k_0 - 3 | 0) >>> 0 > 6) {
      __label__ = 51;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 51:
    if ($108 >>> 0 < 2) {
      __label__ = 52;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 52:
    if ($hour_0 >>> 0 > 12) {
      __label__ = 78;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $126 = ($hour_0 | 0) == 12;
    if (($108 | 0) == 0 & $126) {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = 0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    if (($108 | 0) == 1) {
      __label__ = 55;
      break;
    } else {
      var $seenmonthname_1 = $seenmonthname_0;
      var $year_2 = $year_0;
      var $mon_2 = $mon_0;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    }
   case 55:
    var $hour_0_ = $126 ? 12 : $hour_0 + 12 | 0;
    var $seenmonthname_0 = $seenmonthname_0;
    var $seenplusminus_0 = $seenplusminus_0;
    var $i_0 = $i_3;
    var $year_0 = $year_0;
    var $mon_0 = $mon_0;
    var $mday_0 = $mday_0;
    var $hour_0 = $hour_0_;
    var $min_0 = $min_0;
    var $sec_0 = $sec_0;
    var $tzoffset_0 = $tzoffset_0;
    var $prevc_0 = 0;
    __label__ = 3;
    break;
   case 56:
    if ($108 >>> 0 < 21) {
      __label__ = 57;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 57:
    if (($seenmonthname_0 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 58:
    var $135 = $117 - 1 | 0;
    if (($mon_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $year_0;
      var $mon_2 = $135;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    if (($mday_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $year_0;
      var $mon_2 = $135;
      var $mday_2 = $mon_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    if (($year_0 | 0) < 0) {
      var $seenmonthname_1 = 1;
      var $year_2 = $mon_0;
      var $mon_2 = $135;
      var $mday_2 = $mday_0;
      var $hour_2 = $hour_0;
      var $tzoffset_2 = $tzoffset_0;
      __label__ = 62;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 61:
    var $seenmonthname_1 = $seenmonthname_0;
    var $year_2 = $year_0;
    var $mon_2 = $mon_0;
    var $mday_2 = $mday_0;
    var $hour_2 = $hour_0;
    var $tzoffset_2 = $117 - 1e4 | 0;
    __label__ = 62;
    break;
   case 62:
    var $tzoffset_2;
    var $hour_2;
    var $mday_2;
    var $mon_2;
    var $year_2;
    var $seenmonthname_1;
    if (($108 | 0) < 0) {
      __label__ = 78;
      break;
    } else {
      var $seenmonthname_0 = $seenmonthname_1;
      var $seenplusminus_0 = $seenplusminus_0;
      var $i_0 = $i_3;
      var $year_0 = $year_2;
      var $mon_0 = $mon_2;
      var $mday_0 = $mday_2;
      var $hour_0 = $hour_2;
      var $min_0 = $min_0;
      var $sec_0 = $sec_0;
      var $tzoffset_0 = $tzoffset_2;
      var $prevc_0 = 0;
      __label__ = 3;
      break;
    }
   case 63:
    if (($mon_0 | $mday_0 | $year_0 | 0) < 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if (($seenmonthname_0 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    if (($mday_0 | 0) > 69 & ($year_0 | 0) > 69) {
      __label__ = 78;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    if (($mday_0 | 0) < 70 & ($year_0 | 0) < 70) {
      __label__ = 78;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $157 = ($mday_0 | 0) > ($year_0 | 0);
    var $mday_3 = $157 ? $year_0 : $mday_0;
    var $year_3 = $157 ? $mday_0 : $year_0;
    var $_year_3 = ($year_3 - 70 | 0) >>> 0 < 30 ? $year_3 + 1900 | 0 : $year_3;
    var $year_4 = $_year_3;
    var $mon_3 = $mon_0;
    var $mday_4 = $mday_3;
    __label__ = 74;
    break;
   case 68:
    if (($mon_0 | 0) < 70) {
      __label__ = 69;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 69:
    var $_year_0 = ($year_0 | 0) < 100 ? $year_0 + 1900 | 0 : $year_0;
    var $year_4 = $_year_0;
    var $mon_3 = $mon_0;
    var $mday_4 = $mday_0;
    __label__ = 74;
    break;
   case 70:
    var $167 = ($mday_0 | 0) < 70;
    if (($mon_0 | 0) < 100) {
      __label__ = 71;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 71:
    if ($167) {
      __label__ = 72;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 72:
    var $year_4 = $mon_0 + 1900 | 0;
    var $mon_3 = $mday_0;
    var $mday_4 = $year_0;
    __label__ = 74;
    break;
   case 73:
    if ($167) {
      var $year_4 = $mon_0;
      var $mon_3 = $mday_0;
      var $mday_4 = $year_0;
      __label__ = 74;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 74:
    var $mday_4;
    var $mon_3;
    var $year_4;
    var $181 = ($hour_0 | 0) < 0 ? 0 : $hour_0 | 0;
    var $183 = ($min_0 | 0) < 0 ? 0 : $min_0 | 0;
    var $185 = ($sec_0 | 0) < 0 ? 0 : $sec_0 | 0;
    var $186 = __ZL17date_msecFromDateddddddd($year_4 | 0, $mon_3 - 1 | 0, $mday_4 | 0, $181, $183, $185, 0);
    if (($tzoffset_0 | 0) == -1) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    var $189 = __ZL3UTCdP9JSContext($186, $cx);
    var $msec_0 = $189;
    __label__ = 77;
    break;
   case 76:
    var $msec_0 = $186 + ($tzoffset_0 | 0) * 6e4;
    __label__ = 77;
    break;
   case 77:
    var $msec_0;
    tempDoubleF64[0] = $msec_0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 79;
    break;
   case 78:
    tempDoubleF64[0] = 0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 0;
    __label__ = 79;
    break;
   case 79:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16date_parseStringP14JSLinearStringPdP9JSContext["X"] = 1;

function __ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd($cx, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $d = __stackBase__ + 56;
    var $1 = $cx;
    var $loop_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $loop_0;
    if ($loop_0 >>> 0 < 7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 3:
    if ($loop_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $7 = $argv + ($loop_0 << 3) | 0;
    var $8 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($1, $7, $d);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $10 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = __ZL18JSDOUBLE_IS_FINITEd1004($10);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $14, HEAP32[$rval >> 2] = tempDoubleI32[0], HEAP32[$rval + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 15;
    break;
   case 7:
    var $16 = __ZL18js_DoubleToIntegerd1005($10);
    var $17 = $array + ($loop_0 << 3) | 0;
    tempDoubleF64[0] = $16, HEAP32[$17 >> 2] = tempDoubleI32[0], HEAP32[$17 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 8:
    var $20 = $array + ($loop_0 << 3) | 0;
    if (($loop_0 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    tempDoubleF64[0] = 1, HEAP32[$20 >> 2] = tempDoubleI32[0], HEAP32[$20 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 10:
    tempDoubleF64[0] = 0, HEAP32[$20 >> 2] = tempDoubleI32[0], HEAP32[$20 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 11;
    break;
   case 11:
    var $loop_0 = $loop_0 + 1 | 0;
    __label__ = 2;
    break;
   case 12:
    var $26 = $array | 0;
    var $27 = (tempDoubleI32[0] = HEAP32[$26 >> 2], tempDoubleI32[1] = HEAP32[$26 + 4 >> 2], tempDoubleF64[0]);
    if ($27 < 0 | $27 > 99) {
      var $32 = $27;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $31 = $27 + 1900;
    tempDoubleF64[0] = $31, HEAP32[$26 >> 2] = tempDoubleI32[0], HEAP32[$26 + 4 >> 2] = tempDoubleI32[1];
    var $32 = $31;
    __label__ = 14;
    break;
   case 14:
    var $32;
    var $33 = $array + 8 | 0;
    var $34 = (tempDoubleI32[0] = HEAP32[$33 >> 2], tempDoubleI32[1] = HEAP32[$33 + 4 >> 2], tempDoubleF64[0]);
    var $35 = $array + 16 | 0;
    var $36 = (tempDoubleI32[0] = HEAP32[$35 >> 2], tempDoubleI32[1] = HEAP32[$35 + 4 >> 2], tempDoubleF64[0]);
    var $37 = $array + 24 | 0;
    var $38 = (tempDoubleI32[0] = HEAP32[$37 >> 2], tempDoubleI32[1] = HEAP32[$37 + 4 >> 2], tempDoubleF64[0]);
    var $39 = $array + 32 | 0;
    var $40 = (tempDoubleI32[0] = HEAP32[$39 >> 2], tempDoubleI32[1] = HEAP32[$39 + 4 >> 2], tempDoubleF64[0]);
    var $41 = $array + 40 | 0;
    var $42 = (tempDoubleI32[0] = HEAP32[$41 >> 2], tempDoubleI32[1] = HEAP32[$41 + 4 >> 2], tempDoubleF64[0]);
    var $43 = $array + 48 | 0;
    var $44 = (tempDoubleI32[0] = HEAP32[$43 >> 2], tempDoubleI32[1] = HEAP32[$43 + 4 >> 2], tempDoubleF64[0]);
    var $45 = __ZL17date_msecFromDateddddddd($32, $34, $36, $38, $40, $42, $44);
    tempDoubleF64[0] = $45, HEAP32[$rval >> 2] = tempDoubleI32[0], HEAP32[$rval + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd["X"] = 1;

function __ZL3UTCdP9JSContext($t, $cx) {
  var $1 = (tempDoubleI32[0] = HEAP32[__ZL8LocalTZA >> 2], tempDoubleI32[1] = HEAP32[__ZL8LocalTZA + 4 >> 2], tempDoubleF64[0]);
  var $2 = $t - $1;
  var $3 = __ZL10AdjustTimedP9JSContext($2, $cx);
  return $t - $3;
}

function __Z20js_NewDateObjectMsecP9JSContextd($cx, $msec_time) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $cx;
    var $6 = __ZN8JSObject11ensureSlotsEP9JSContextj($4, $5, 9);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($1, $msec_time, 0);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_InitDateClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toUTCStringFun = __stackBase__;
    var $1 = _PRMJ_LocalGMTDifference();
    tempDoubleF64[0] = -(($1 | 0) * 1e3), HEAP32[__ZL8LocalTZA >> 2] = tempDoubleI32[0], HEAP32[__ZL8LocalTZA + 4 >> 2] = tempDoubleI32[1];
    var $5 = $obj;
    var $6 = __ZN8JSObject8asGlobalEv($5);
    var $7 = $cx;
    var $8 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($6, $7, __ZN2js9DateClassE);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $cx_idx = $cx + 52 | 0;
    var $cx_idx_val = HEAP32[$cx_idx >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $9, 0);
    var $15 = HEAP32[HEAP32[$cx_idx >> 2] + 210044 >> 2];
    var $16 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($6, $7, 86, __ZN2js9DateClassE, $15, 7);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $16 | 0;
    var $20 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($7, $19, $8);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $22 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($7, $19, 0, __ZL19date_static_methods);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $24 = $cx;
    var $25 = $8;
    var $26 = _JS_DefineFunctions($24, $25, __ZL12date_methods);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP32[$cx_idx >> 2];
    var $32 = HEAP32[$29 + 210328 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom1010($32);
    var $35 = HEAP32[$29 + 210312 >> 2];
    var $36 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($24, $25, $33, $toUTCStringFun);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $39 = $35 | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom1010($39);
    var $41 = $cx;
    var $42 = $8;
    var $43 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($41, $42, $40, $toUTCStringFun, 10, 12, 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $46 = __ZN9JSContext20typeInferenceEnabledEv($24);
    if ($46) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $48 = __ZN8JSObject5brandEP9JSContext($8, $7);
    __label__ = 10;
    break;
   case 10:
    var $50 = $6;
    var $51 = $16;
    var $52 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($24, $50, 6, $51, $25);
    var $_ = $52 ? $9 : 0;
    var $_0 = $_;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_InitDateClassP9JSContextP8JSObject["X"] = 1;

function __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_0_11_val, $obj, $vp) {
  var $1 = $cx_0_11_val + 144112 | 0;
  var $2 = __ZN2JS5Value12getDoubleRefEv($1);
  var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
  __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($obj, $3, $vp);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom1010($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1046($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011($cx) {
  var $3 = HEAPU32[__ZN2js9DateClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1026($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027($cx, $4);
  return $5;
}

function __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($obj, $t, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $4 = __ZNK8JSObject8numSlotsEv($3);
    if ($4 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = $4 >>> 0 < 9 ? $4 : 9;
    var $ind_01 = 1;
    __label__ = 3;
    break;
   case 3:
    var $ind_01;
    __ZN2JSL14UndefinedValueEv1024($1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $ind_01, $1);
    var $9 = $ind_01 + 1 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $ind_01 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    __ZN2JSL11DoubleValueEd1017($2, $t);
    __ZN8JSObject14setDateUTCTimeERKN2JS5ValueE($obj, $2);
    if (($vp | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setDoubleEd($vp, $t);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_NewDateObjectP9JSContextiiiiii($cx, $year, $mon, $mday, $hour, $min, $sec) {
  var $1 = $year | 0;
  var $2 = $mon | 0;
  var $3 = $mday | 0;
  var $4 = $hour | 0;
  var $5 = $min | 0;
  var $6 = $sec | 0;
  var $7 = __ZL17date_msecFromDateddddddd($1, $2, $3, $4, $5, $6, 0);
  var $8 = __ZL3UTCdP9JSContext($7, $cx);
  var $9 = __Z20js_NewDateObjectMsecP9JSContextd($cx, $8);
  return $9;
}

function __ZL17date_msecFromDateddddddd($year, $mon, $mday, $hour, $min, $sec, $msec) {
  var $1 = __ZL7MakeDayddd($year, $mon, $mday);
  return $1 * 864e5 + ((($hour * 60 + $min) * 60 + $sec) * 1e3 + $msec);
}

function __Z14js_DateIsValidP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $utctime);
    if (($1 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    var $8 = ($5 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject6isDateEv($1);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($vp | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($6, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $8 = __ZNK8JSObject14getDateUTCTimeEv($obj);
    var $9 = __ZNK2JS5Value8toNumberEv($8);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_DateGetYearP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL12YearFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $time) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj;
    var $4 = __ZNK8JSObject6isDateEv($3);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($vp | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($8, $vp, __ZN2js9DateClassE);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $10 = __ZNK8JSObject7getSlotEj($3, 1);
    var $11 = __ZNK2JS5Value11isUndefinedEv($10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $13 = __ZL14FillLocalTimesP9JSContextP8JSObject($cx, $obj);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    if (($time | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZNK8JSObject7getSlotEj($3, 1);
    var $18 = __ZNK2JS5Value8toDoubleEv($17);
    tempDoubleF64[0] = $18, HEAP32[$time >> 2] = tempDoubleI32[0], HEAP32[$time + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12YearFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $t / 31556952e3;
    var $2 = _floor($1);
    var $3 = $2 & -1;
    var $4 = $3 + 1970 | 0;
    var $6 = $3 * 365 | 0;
    var $9 = ($3 + 1 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($3 + 69 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($3 + 369 | 0) / 400;
    var $20 = _floor($19);
    var $22 = ($16 + $20) * 864e5;
    if ($22 > $t) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $y_0 = $3 + 1969 | 0;
    __label__ = 5;
    break;
   case 3:
    var $27 = __ZL10DaysInYeari($4);
    if ($22 + ($27 | 0) * 864e5 > $t) {
      var $y_0 = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $y_0 = $3 + 1971 | 0;
    __label__ = 5;
    break;
   case 5:
    var $y_0;
    return $y_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_DateGetMonthP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL13MonthFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MonthFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12YearFromTimed($t);
    var $2 = $t / 864e5;
    var $3 = _floor($2);
    var $6 = $1 * 365 - 719050 | 0;
    var $9 = ($1 - 1969 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($1 - 1901 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($1 - 1601 | 0) / 400;
    var $20 = _floor($19);
    var $23 = $3 - ($16 + $20) & -1;
    if (($23 | 0) < 31) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $26 = __ZL14DaysInFebruaryi($1);
    if (($23 | 0) < ($26 + 31 | 0)) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($23 | 0) < ($26 + 62 | 0)) {
      var $_0 = 2;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($23 | 0) < ($26 + 92 | 0)) {
      var $_0 = 3;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 | 0) < ($26 + 123 | 0)) {
      var $_0 = 4;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($23 | 0) < ($26 + 153 | 0)) {
      var $_0 = 5;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($23 | 0) < ($26 + 184 | 0)) {
      var $_0 = 6;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($23 | 0) < ($26 + 215 | 0)) {
      var $_0 = 7;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($23 | 0) < ($26 + 245 | 0)) {
      var $_0 = 8;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($23 | 0) < ($26 + 276 | 0)) {
      var $_0 = 9;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_ = ($23 | 0) < ($26 + 306 | 0) ? 10 : 11;
    var $_0 = $_;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13MonthFromTimed["X"] = 1;

function __ZL14JSID_FROM_BITSj1046($bits) {
  return $bits;
}

function __ZL10IsLeapYeari($year) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($year & 3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if (($year % 100 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $10 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = ($year % 400 | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb1026($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_DateGetDateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL12DateFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12DateFromTimed($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12YearFromTimed($t);
    var $2 = $t / 864e5;
    var $3 = _floor($2);
    var $6 = $1 * 365 - 719050 | 0;
    var $9 = ($1 - 1969 | 0) * .25;
    var $10 = _floor($9);
    var $11 = $6 + $10;
    var $14 = ($1 - 1901 | 0) / 100;
    var $15 = _floor($14);
    var $16 = $11 - $15;
    var $19 = ($1 - 1601 | 0) / 400;
    var $20 = _floor($19);
    var $23 = $3 - ($16 + $20) & -1;
    if (($23 | 0) < 31) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $23 + 1 | 0;
    __label__ = 24;
    break;
   case 3:
    var $28 = __ZL14DaysInFebruaryi($1);
    var $29 = $28 + 30 | 0;
    if (($23 | 0) > ($29 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $23 - 30 | 0;
    __label__ = 24;
    break;
   case 5:
    var $34 = $28 + 61 | 0;
    if (($23 | 0) > ($34 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $23 - $29 | 0;
    __label__ = 24;
    break;
   case 7:
    var $39 = $28 + 91 | 0;
    if (($23 | 0) > ($39 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = $23 - $34 | 0;
    __label__ = 24;
    break;
   case 9:
    var $44 = $28 + 122 | 0;
    if (($23 | 0) > ($44 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = $23 - $39 | 0;
    __label__ = 24;
    break;
   case 11:
    var $49 = $28 + 152 | 0;
    if (($23 | 0) > ($49 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = $23 - $44 | 0;
    __label__ = 24;
    break;
   case 13:
    var $54 = $28 + 183 | 0;
    if (($23 | 0) > ($54 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_0 = $23 - $49 | 0;
    __label__ = 24;
    break;
   case 15:
    var $59 = $28 + 214 | 0;
    if (($23 | 0) > ($59 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_0 = $23 - $54 | 0;
    __label__ = 24;
    break;
   case 17:
    var $64 = $28 + 244 | 0;
    if (($23 | 0) > ($64 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_0 = $23 - $59 | 0;
    __label__ = 24;
    break;
   case 19:
    var $69 = $28 + 275 | 0;
    if (($23 | 0) > ($69 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = $23 - $64 | 0;
    __label__ = 24;
    break;
   case 21:
    var $74 = $28 + 305 | 0;
    if (($23 | 0) > ($74 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_0 = $23 - $69 | 0;
    __label__ = 24;
    break;
   case 23:
    var $_0 = $23 - $74 | 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12DateFromTimed["X"] = 1;

function __Z15js_DateGetHoursP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL12HourFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12HourFromTimed($t) {
  var $1 = $t / 36e5;
  var $2 = _floor($1);
  var $3 = _fmod($2, 24);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 24 | 0 : $4;
  return $_;
}

function __Z17js_DateGetMinutesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localtime = __stackBase__;
    var $1 = __ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $localtime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$localtime >> 2], tempDoubleI32[1] = HEAP32[$localtime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL11MinFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11MinFromTimed($t) {
  var $1 = $t / 6e4;
  var $2 = _floor($1);
  var $3 = _fmod($2, 60);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 60 | 0 : $4;
  return $_;
}

function __Z17js_DateGetSecondsP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $utctime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL15JSDOUBLE_IS_NaNd1014($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL11SecFromTimed($4);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11SecFromTimed($t) {
  var $1 = $t / 1e3;
  var $2 = _floor($1);
  var $3 = _fmod($2, 60);
  var $4 = $3 & -1;
  var $_ = ($4 | 0) < 0 ? $4 + 60 | 0 : $4;
  return $_;
}

function __Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $utctime = __stackBase__;
  var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, 0, $utctime);
  var $2 = ($1 | 0) == 0;
  var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
  var $_0 = $2 ? 0 : $3;
  STACKTOP = __stackBase__;
  return $_0;
}

function __Z14js_IntervalNowv() {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  return $2$0;
}

function __ZL14DaysInFebruaryi($year) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 ? 29 : 28;
  return $2;
}

function __ZL10DaysInYeari($year) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 ? 366 : 365;
  return $2;
}

function __ZL14FillLocalTimesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __ZNK8JSObject14getDateUTCTimeEv($obj);
    var $11 = __ZNK2JS5Value8toNumberEv($10);
    var $12 = $obj;
    var $13 = __ZNK8JSObject8numSlotsEv($12);
    if ($13 >>> 0 < 9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = $obj;
    var $17 = $cx;
    var $18 = __ZN8JSObject9growSlotsEP9JSContextj($16, $17, 9);
    if ($18) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 3:
    var $20 = __ZL18JSDOUBLE_IS_FINITEd1004($11);
    if (($20 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 1, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 2, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 3, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 4, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 5, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 6, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 7, $1);
    __ZN2JSL11DoubleValueEd1017($1, $11);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 8, $1);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 5:
    var $23 = __ZL9LocalTimedP9JSContext($11, $cx);
    __ZN2JSL11DoubleValueEd1017($2, $23);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 1, $2);
    var $24 = $23 / 31556952e3;
    var $25 = _floor($24);
    var $26 = $25 & -1;
    var $27 = $26 + 1970 | 0;
    var $29 = $26 * 365 | 0;
    var $32 = ($26 + 1 | 0) * .25;
    var $33 = _floor($32);
    var $34 = $29 + $33;
    var $37 = ($26 + 69 | 0) / 100;
    var $38 = _floor($37);
    var $39 = $34 - $38;
    var $42 = ($26 + 369 | 0) / 400;
    var $43 = _floor($42);
    var $45 = ($39 + $43) * 864e5;
    if ($45 > $23) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $48 = $26 + 1969 | 0;
    var $49 = __ZL10DaysInYeari($48);
    var $yearDays_0 = $49;
    var $year_0 = $48;
    var $yearStartTime_0 = $45 - ($49 | 0) * 864e5;
    __label__ = 9;
    break;
   case 7:
    var $54 = __ZL10DaysInYeari($27);
    var $57 = $45 + ($54 | 0) * 864e5;
    if ($57 > $23) {
      var $yearDays_0 = $54;
      var $year_0 = $27;
      var $yearStartTime_0 = $45;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $60 = $26 + 1971 | 0;
    var $61 = __ZL10DaysInYeari($60);
    var $yearDays_0 = $61;
    var $year_0 = $60;
    var $yearStartTime_0 = $57;
    __label__ = 9;
    break;
   case 9:
    var $yearStartTime_0;
    var $year_0;
    var $yearDays_0;
    __ZN2JSL10Int32ValueEi1018($3, $year_0);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 2, $3);
    var $63 = $23 - $yearStartTime_0;
    var $64$0 = $63 >>> 0;
    var $64$1 = Math.min(Math.floor($63 / 4294967296), 4294967295);
    var $65$0 = (i64Math.divide($64$0, $64$1, 1e3, 0, true), i64Math.result[0]);
    var $65$1 = i64Math.result[1];
    var $66 = $65$0;
    var $67 = ($66 | 0) / 86400 & -1;
    if (($66 | 0) < 2678400) {
      var $month_0 = 0;
      var $step_0 = -1;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $71 = ($yearDays_0 | 0) == 366 ? 59 : 58;
    if (($67 | 0) > ($71 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $month_0 = 1;
      var $step_0 = 30;
      __label__ = 20;
      break;
    }
   case 11:
    var $74 = $71 + 31 | 0;
    if (($67 | 0) > ($74 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $month_0 = 2;
      var $step_0 = $71;
      __label__ = 20;
      break;
    }
   case 12:
    var $77 = $71 + 61 | 0;
    if (($67 | 0) > ($77 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $month_0 = 3;
      var $step_0 = $74;
      __label__ = 20;
      break;
    }
   case 13:
    var $80 = $71 + 92 | 0;
    if (($67 | 0) > ($80 | 0)) {
      __label__ = 14;
      break;
    } else {
      var $month_0 = 4;
      var $step_0 = $77;
      __label__ = 20;
      break;
    }
   case 14:
    var $83 = $71 + 122 | 0;
    if (($67 | 0) > ($83 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $month_0 = 5;
      var $step_0 = $80;
      __label__ = 20;
      break;
    }
   case 15:
    var $86 = $71 + 153 | 0;
    if (($67 | 0) > ($86 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $month_0 = 6;
      var $step_0 = $83;
      __label__ = 20;
      break;
    }
   case 16:
    var $89 = $71 + 184 | 0;
    if (($67 | 0) > ($89 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $month_0 = 7;
      var $step_0 = $86;
      __label__ = 20;
      break;
    }
   case 17:
    var $92 = $71 + 214 | 0;
    if (($67 | 0) > ($92 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $month_0 = 8;
      var $step_0 = $89;
      __label__ = 20;
      break;
    }
   case 18:
    var $95 = $71 + 245 | 0;
    if (($67 | 0) > ($95 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $month_0 = 9;
      var $step_0 = $92;
      __label__ = 20;
      break;
    }
   case 19:
    var $98 = $71 + 275 | 0;
    var $99 = ($67 | 0) > ($98 | 0);
    var $_ = $99 ? $98 : $95;
    var $_1 = $99 ? 11 : 10;
    var $month_0 = $_1;
    var $step_0 = $_;
    __label__ = 20;
    break;
   case 20:
    var $step_0;
    var $month_0;
    __ZN2JSL10Int32ValueEi1018($4, $month_0);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 3, $4);
    var $101 = $67 - $step_0 | 0;
    __ZN2JSL10Int32ValueEi1018($5, $101);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 4, $5);
    var $102 = __ZL7WeekDayd($23);
    __ZN2JSL10Int32ValueEi1018($6, $102);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 5, $6);
    var $103 = ($66 | 0) % 60;
    __ZN2JSL10Int32ValueEi1018($7, $103);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 8, $7);
    var $105 = (($66 | 0) / 60 & -1 | 0) % 60;
    __ZN2JSL10Int32ValueEi1018($8, $105);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 7, $8);
    var $107 = (($66 | 0) / 3600 & -1 | 0) % 24;
    __ZN2JSL10Int32ValueEi1018($9, $107);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($12, 6, $9);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14FillLocalTimesP9JSContextP8JSObject["X"] = 1;

function __ZNK8JSObject14getDateUTCTimeEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  return $2;
}

function __ZN2JSL11DoubleValueEd1017($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZL9LocalTimedP9JSContext($t, $cx) {
  var $1 = __ZL10AdjustTimedP9JSContext($t, $cx);
  return $1 + $t;
}

function __ZN2JSL10Int32ValueEi1018($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL7WeekDayd($t) {
  var $1 = $t / 864e5;
  var $2 = _floor($1);
  var $5 = (($2 & -1) + 4 | 0) % 7;
  var $_ = ($5 | 0) < 0 ? $5 + 7 | 0 : $5;
  return $_;
}

function __ZL10AdjustTimedP9JSContext($date, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL16DaylightSavingTAdP9JSContext($date, $cx);
    var $2 = (tempDoubleI32[0] = HEAP32[__ZL8LocalTZA >> 2], tempDoubleI32[1] = HEAP32[__ZL8LocalTZA + 4 >> 2], tempDoubleF64[0]);
    var $3 = $1 + $2;
    if ($2 < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _fmod($3, 864e5);
    var $12 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = 864e5 - $3;
    var $9 = _fmod($8, 864e5);
    var $12 = -$9;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16DaylightSavingTAdP9JSContext($t, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL15JSDOUBLE_IS_NaNd1014($t);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $t;
      __label__ = 5;
      break;
    }
   case 2:
    if ($t < 0 | $t > 21459168e5) {
      __label__ = 3;
      break;
    } else {
      var $_02 = $t;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL12YearFromTimed($t);
    var $8 = __ZL20EquivalentYearForDSTi($7);
    var $9 = $8 | 0;
    var $10 = __ZL13MonthFromTimed($t);
    var $11 = $10 | 0;
    var $12 = __ZL12DateFromTimed($t);
    var $13 = $12 | 0;
    var $14 = __ZL7MakeDayddd($9, $11, $13);
    var $15 = $14 * 864e5;
    var $16 = __ZL13TimeWithinDayd($t);
    var $_02 = $15 + $16;
    __label__ = 4;
    break;
   case 4:
    var $_02;
    var $19$0 = $_02 >>> 0;
    var $19$1 = Math.min(Math.floor($_02 / 4294967296), 4294967295);
    var $20 = $cx + 236 | 0;
    var $21 = __ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext($20, $19$0, $19$1, undef);
    var $_0 = $21[0] + $21[1] * 4294967296;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20EquivalentYearForDSTi($year) {
  var $3 = $year * 365 - 719050 | 0;
  var $6 = ($year - 1969 | 0) * .25;
  var $7 = _floor($6);
  var $8 = $3 + $7;
  var $11 = ($year - 1901 | 0) / 100;
  var $12 = _floor($11);
  var $13 = $8 - $12;
  var $16 = ($year - 1601 | 0) / 400;
  var $17 = _floor($16);
  var $21 = (($13 + $17 & -1) + 4 | 0) % 7;
  var $_ = ($21 | 0) < 0 ? $21 + 7 | 0 : $21;
  var $24 = __ZL10IsLeapYeari($year);
  return HEAP32[__ZL16yearStartingWith + ($24 & 1) * 28 + ($_ << 2) >> 2];
}

function __ZL7MakeDayddd($year, $month, $date) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $month / 12;
    var $2 = _floor($1);
    var $3 = $2 + $year;
    var $4 = _fmod($month, 12);
    if ($4 < 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $4 + 12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $9 = $3 & -1;
    var $10 = __ZL10IsLeapYeari($9);
    var $11 = $10 & 1;
    var $13 = ($3 - 1970) * 365;
    var $15 = ($3 - 1969) * .25;
    var $16 = _floor($15);
    var $17 = $13 + $16;
    var $19 = ($3 - 1901) / 100;
    var $20 = _floor($19);
    var $21 = $17 - $20;
    var $23 = ($3 - 1601) / 400;
    var $24 = _floor($23);
    var $27 = ($21 + $24) * 864e5 / 864e5;
    var $28 = _floor($27);
    var $30 = __ZL15firstDayOfMonth + $11 * 104 + (($_0 & -1) << 3) | 0;
    var $31 = (tempDoubleI32[0] = HEAP32[$30 >> 2], tempDoubleI32[1] = HEAP32[$30 + 4 >> 2], tempDoubleF64[0]);
    return $28 + $31 + $date - 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13TimeWithinDayd($t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _fmod($t, 864e5);
    if ($1 < 0) {
      __label__ = 2;
      break;
    } else {
      var $result_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $result_0 = $1 + 864e5;
    __label__ = 3;
    break;
   case 3:
    var $result_0;
    return $result_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1024($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject14setDateUTCTimeERKN2JS5ValueE($this, $time) {
  var $1 = $this;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 0, $time);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js9DateClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $22 = __ZNK2JS5Value8isObjectEv($1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js9DateClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js9DateClassE, $3, $10, 0, (__ZN2js9DateClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js9DateClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject1038($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2js7unicode8CharInfoEt($code) {
  var $1 = $code & 65535;
  return __ZN2js7unicode11js_charinfoE + (HEAPU16[__ZN2js7unicode6index2E + (((HEAPU16[__ZN2js7unicode6index1E + ($1 >>> 6 << 1) >> 1] & 65535) << 6 | $1 & 63) << 1) >> 1] & 65535) * 6 | 0;
}

function __ZL10fractionalPdPKtPjj($result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$i >> 2];
    tempDoubleF64[0] = 0, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $factor_0 = .1;
    var $3 = HEAP32[$i >> 2];
    __label__ = 2;
    break;
   case 2:
    var $3;
    var $factor_0;
    if ($3 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAPU16[$s + ($3 << 1) >> 1];
    if (($7 & 65535) > 47 & ($7 & 65535) < 58) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = (($7 & 65535) - 48 | 0) * $factor_0;
    var $15 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $16 = $15 + $14;
    tempDoubleF64[0] = $16, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $19 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $19;
    var $factor_0 = $factor_0 * .1;
    var $3 = $19;
    __label__ = 2;
    break;
   case 5:
    return ($3 | 0) != ($1 | 0) & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6digitsPjPKtS_j($result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$i >> 2];
    HEAP32[$result >> 2] = 0;
    var $3 = HEAP32[$i >> 2];
    __label__ = 2;
    break;
   case 2:
    var $3;
    if ($3 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP16[$s + ($3 << 1) >> 1] - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$result >> 2] * 10 | 0;
    HEAP32[$result >> 2] = $11;
    var $17 = $11 - 48 + (HEAPU16[$s + (HEAP32[$i >> 2] << 1) >> 1] & 65535) | 0;
    HEAP32[$result >> 2] = $17;
    var $19 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $19;
    var $3 = $19;
    __label__ = 2;
    break;
   case 5:
    return ($3 | 0) != ($1 | 0) & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK16JSAutoByteStringntEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZL19date_parseISOStringP14JSLinearStringPdP9JSContext($str, $result, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $year = __stackBase__ + 4;
    var $month = __stackBase__ + 8;
    var $day = __stackBase__ + 12;
    var $hour = __stackBase__ + 16;
    var $min = __stackBase__ + 20;
    var $sec = __stackBase__ + 24;
    var $frac = __stackBase__ + 28;
    var $tzHour = __stackBase__ + 36;
    var $tzMin = __stackBase__ + 40;
    HEAP32[$i >> 2] = 0;
    HEAP32[$year >> 2] = 1970;
    HEAP32[$month >> 2] = 1;
    HEAP32[$day >> 2] = 1;
    HEAP32[$hour >> 2] = 0;
    HEAP32[$min >> 2] = 0;
    HEAP32[$sec >> 2] = 0;
    tempDoubleF64[0] = 0, HEAP32[$frac >> 2] = tempDoubleI32[0], HEAP32[$frac + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tzHour >> 2] = 0;
    HEAP32[$tzMin >> 2] = 0;
    var $1 = __ZNK14JSLinearString5charsEv($str);
    var $2 = $str | 0;
    var $3 = __ZNK8JSString6lengthEv($2);
    if (($3 | 0) != 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 43) {
      var $dateMul_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 45) {
      var $dateMul_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $dateMul_0;
    HEAP32[$i >> 2] = 1;
    var $11 = __ZL7ndigitsjPjPKtS_j(6, $year, $1, $i, $3);
    if (($11 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $dateMul_1 = $dateMul_0;
      __label__ = 7;
      break;
    }
   case 5:
    if (HEAP16[$1 >> 1] << 16 >> 16 == 84) {
      var $dateMul_1 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZL7ndigitsjPjPKtS_j(4, $year, $1, $i, $3);
    if (($17 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $dateMul_1 = 1;
      __label__ = 7;
      break;
    }
   case 7:
    var $dateMul_1;
    var $19 = HEAPU32[$i >> 2];
    if ($19 >>> 0 < $3 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $41 = $19;
      __label__ = 14;
      break;
    }
   case 8:
    if (HEAP16[$1 + ($19 << 1) >> 1] << 16 >> 16 == 45) {
      __label__ = 9;
      break;
    } else {
      var $41 = $19;
      __label__ = 14;
      break;
    }
   case 9:
    HEAP32[$i >> 2] = $19 + 1 | 0;
    var $27 = __ZL7ndigitsjPjPKtS_j(2, $month, $1, $i, $3);
    if (($27 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAPU32[$i >> 2];
    if ($30 >>> 0 < $3 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $41 = $30;
      __label__ = 14;
      break;
    }
   case 11:
    if (HEAP16[$1 + ($30 << 1) >> 1] << 16 >> 16 == 45) {
      __label__ = 12;
      break;
    } else {
      var $41 = $30;
      __label__ = 14;
      break;
    }
   case 12:
    HEAP32[$i >> 2] = $30 + 1 | 0;
    var $38 = __ZL7ndigitsjPjPKtS_j(2, $day, $1, $i, $3);
    if (($38 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = HEAP32[$i >> 2];
    __label__ = 14;
    break;
   case 14:
    var $41;
    if ($41 >>> 0 < $3 >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 15:
    if (HEAP16[$1 + ($41 << 1) >> 1] << 16 >> 16 == 84) {
      __label__ = 16;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 16:
    HEAP32[$i >> 2] = $41 + 1 | 0;
    var $49 = __ZL7ndigitsjPjPKtS_j(2, $hour, $1, $i, $3);
    if (($49 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = HEAPU32[$i >> 2];
    if ($52 >>> 0 < $3 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 18:
    if (HEAP16[$1 + ($52 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 19;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 19:
    HEAP32[$i >> 2] = $52 + 1 | 0;
    var $60 = __ZL7ndigitsjPjPKtS_j(2, $min, $1, $i, $3);
    if (($60 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $63 = HEAPU32[$i >> 2];
    if ($63 >>> 0 < $3 >>> 0) {
      __label__ = 21;
      break;
    } else {
      var $85 = $63;
      __label__ = 27;
      break;
    }
   case 21:
    if (HEAP16[$1 + ($63 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 22;
      break;
    } else {
      var $85 = $63;
      __label__ = 27;
      break;
    }
   case 22:
    HEAP32[$i >> 2] = $63 + 1 | 0;
    var $71 = __ZL7ndigitsjPjPKtS_j(2, $sec, $1, $i, $3);
    if (($71 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $74 = HEAPU32[$i >> 2];
    if ($74 >>> 0 < $3 >>> 0) {
      __label__ = 24;
      break;
    } else {
      var $85 = $74;
      __label__ = 27;
      break;
    }
   case 24:
    if (HEAP16[$1 + ($74 << 1) >> 1] << 16 >> 16 == 46) {
      __label__ = 25;
      break;
    } else {
      var $85 = $74;
      __label__ = 27;
      break;
    }
   case 25:
    HEAP32[$i >> 2] = $74 + 1 | 0;
    var $82 = __ZL10fractionalPdPKtPjj($frac, $1, $i, $3);
    if (($82 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $85 = HEAP32[$i >> 2];
    __label__ = 27;
    break;
   case 27:
    var $85;
    if ($85 >>> 0 < $3 >>> 0) {
      __label__ = 28;
      break;
    } else {
      var $isLocalTime_0 = 1;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 28:
    if (HEAP16[$1 + ($85 << 1) >> 1] << 16 >> 16 == 90) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    HEAP32[$i >> 2] = $85 + 1 | 0;
    var $isLocalTime_0 = 0;
    var $tzMul_1 = 1;
    __label__ = 36;
    break;
   case 30:
    if (HEAP16[$1 + ($85 << 1) >> 1] << 16 >> 16 == 43) {
      var $tzMul_0 = 1;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (HEAP16[$1 + ($85 << 1) >> 1] << 16 >> 16 == 45) {
      var $tzMul_0 = -1;
      __label__ = 32;
      break;
    } else {
      var $isLocalTime_0 = 1;
      var $tzMul_1 = 1;
      __label__ = 36;
      break;
    }
   case 32:
    var $tzMul_0;
    HEAP32[$i >> 2] = $85 + 1 | 0;
    var $102 = __ZL7ndigitsjPjPKtS_j(2, $tzHour, $1, $i, $3);
    if (($102 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $105 = HEAPU32[$i >> 2];
    if ($105 >>> 0 < $3 >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 34:
    if (HEAP16[$1 + ($105 << 1) >> 1] << 16 >> 16 == 58) {
      __label__ = 35;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 35:
    HEAP32[$i >> 2] = $105 + 1 | 0;
    var $113 = __ZL7ndigitsjPjPKtS_j(2, $tzMin, $1, $i, $3);
    if (($113 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $isLocalTime_0 = 0;
      var $tzMul_1 = $tzMul_0;
      __label__ = 36;
      break;
    }
   case 36:
    var $tzMul_1;
    var $isLocalTime_0;
    var $115 = HEAPU32[$year >> 2];
    if ($115 >>> 0 > 275943) {
      __label__ = 53;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $118 = HEAPU32[$month >> 2];
    if (($118 | 0) == 0 | $118 >>> 0 > 12) {
      __label__ = 53;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $122 = HEAPU32[$day >> 2];
    if (($122 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $125 = __ZL11DaysInMonthii($115, $118);
    if ($122 >>> 0 > $125 >>> 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $128 = HEAPU32[$hour >> 2];
    if ($128 >>> 0 > 24) {
      __label__ = 53;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $132 = HEAPU32[$min >> 2];
    if (($128 | 0) == 24) {
      __label__ = 42;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 42:
    if (($132 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 43:
    var $136 = HEAPU32[$sec >> 2];
    if (($136 | 0) == 0) {
      var $142 = $136;
      var $141 = $132;
      __label__ = 46;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 44:
    if ($132 >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_pr = HEAPU32[$sec >> 2];
    if ($_pr >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      var $142 = $_pr;
      var $141 = $132;
      __label__ = 46;
      break;
    }
   case 46:
    var $141;
    var $142;
    var $143 = HEAPU32[$tzHour >> 2];
    if ($143 >>> 0 > 23) {
      __label__ = 53;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $146 = HEAPU32[$tzMin >> 2];
    if ($146 >>> 0 > 59) {
      __label__ = 53;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    if ((HEAP32[$i >> 2] | 0) == ($3 | 0)) {
      __label__ = 49;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 49:
    var $152 = $118 - 1 | 0;
    HEAP32[$month >> 2] = $152;
    var $155 = ($dateMul_1 | 0) * ($115 >>> 0);
    var $156 = $152 >>> 0;
    var $157 = $122 >>> 0;
    var $158 = $128 >>> 0;
    var $161 = (tempDoubleI32[0] = HEAP32[$frac >> 2], tempDoubleI32[1] = HEAP32[$frac + 4 >> 2], tempDoubleF64[0]);
    var $162 = $161 * 1e3;
    var $163 = __ZL17date_msecFromDateddddddd($155, $156, $157, $158, $141 >>> 0, $142 >>> 0, $162);
    if ($isLocalTime_0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $165 = __ZL3UTCdP9JSContext($163, $cx);
    var $msec_0 = $165;
    __label__ = 52;
    break;
   case 51:
    var $msec_0 = $163 - ($tzMul_1 | 0) * (($143 >>> 0) * 36e5 + ($146 >>> 0) * 6e4);
    __label__ = 52;
    break;
   case 52:
    var $msec_0;
    if ($msec_0 < -864e13 | $msec_0 > 864e13) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 1;
      var $storemerge = $msec_0;
      __label__ = 54;
      break;
    }
   case 53:
    var $_0 = 0;
    var $storemerge = 0;
    __label__ = 54;
    break;
   case 54:
    var $storemerge;
    var $_0;
    tempDoubleF64[0] = $storemerge, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19date_parseISOStringP14JSLinearStringPdP9JSContext["X"] = 1;

function __ZL18date_regionMatchesPKciPKtiii($s1, $s2, $s2off, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = 0;
    var $_02 = $count;
    var $_03 = $s2off;
    __label__ = 2;
    break;
   case 2:
    var $_03;
    var $_02;
    var $_0;
    if (($_02 | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $5 = HEAP8[$s1 + $_0 | 0];
    if ($5 << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = HEAP16[$s2 + ($_03 << 1) >> 1];
    if ($9 << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $5 << 24 >> 24;
    var $13 = __ZN2js7unicode11ToLowerCaseEt($12);
    var $14 = __ZN2js7unicode11ToLowerCaseEt($9);
    if ($13 << 16 >> 16 == $14 << 16 >> 16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_0 = $_0 + 1 | 0;
    var $_02 = $_02 - 1 | 0;
    var $_03 = $_03 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    return ($_02 | 0) == 0 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode11ToLowerCaseEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $8 = (HEAP8[$1 + 4 | 0] & 8) << 24 >> 24 == 0 ? $ch : 0;
  return $8 + HEAP16[$1 + 2 >> 1] & 65535;
}

function __ZL7ndigitsjPjPKtS_j($n, $result, $s, $i, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$i >> 2];
    var $2 = $1 + $n | 0;
    var $limit_ = $2 >>> 0 > $limit >>> 0 ? $limit : $2;
    var $4 = __ZL6digitsPjPKtS_j($result, $s, $i, $limit_);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP32[$i >> 2] - $1 | 0) == ($n | 0) & 1;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$i >> 2] = $1;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11DaysInMonthii($year, $month) {
  var $1 = __ZL10IsLeapYeari($year);
  var $2 = $1 & 1;
  var $3 = __ZL15firstDayOfMonth + $2 * 104 + ($month << 3) | 0;
  var $4 = (tempDoubleI32[0] = HEAP32[$3 >> 2], tempDoubleI32[1] = HEAP32[$3 + 4 >> 2], tempDoubleF64[0]);
  var $6 = __ZL15firstDayOfMonth + $2 * 104 + ($month - 1 << 3) | 0;
  var $7 = (tempDoubleI32[0] = HEAP32[$6 >> 2], tempDoubleI32[1] = HEAP32[$6 + 4 >> 2], tempDoubleF64[0]);
  return $4 - $7 & -1;
}

function __ZL11new_explodedP8PRMJTimeP9JSContext($timeval, $split, $cx) {
  var $1 = __ZL12YearFromTimed($timeval);
  var $2 = __ZL10msFromTimed($timeval);
  HEAP32[$split >> 2] = $2 * 1e3 | 0;
  var $5 = __ZL11SecFromTimed($timeval);
  HEAP8[$split + 4 | 0] = $5 & 255;
  var $8 = __ZL11MinFromTimed($timeval);
  HEAP8[$split + 5 | 0] = $8 & 255;
  var $11 = __ZL12HourFromTimed($timeval);
  HEAP8[$split + 6 | 0] = $11 & 255;
  var $14 = __ZL12DateFromTimed($timeval);
  HEAP8[$split + 7 | 0] = $14 & 255;
  var $17 = __ZL13MonthFromTimed($timeval);
  HEAP8[$split + 8 | 0] = $17 & 255;
  var $20 = __ZL7WeekDayd($timeval);
  HEAP8[$split + 9 | 0] = $20 & 255;
  HEAP32[$split + 12 >> 2] = $1;
  var $24 = $timeval / 864e5;
  var $25 = _floor($24);
  var $28 = $1 * 365 - 719050 | 0;
  var $31 = ($1 - 1969 | 0) * .25;
  var $32 = _floor($31);
  var $33 = $28 + $32;
  var $36 = ($1 - 1901 | 0) / 100;
  var $37 = _floor($36);
  var $38 = $33 - $37;
  var $41 = ($1 - 1601 | 0) / 400;
  var $42 = _floor($41);
  HEAP16[$split + 16 >> 1] = $25 - ($38 + $42) & -1 & 65535;
  var $48 = __ZL16DaylightSavingTAdP9JSContext($timeval, $cx);
  HEAP8[$split + 18 | 0] = $48 != 0 & 1;
  return;
}

__ZL11new_explodedP8PRMJTimeP9JSContext["X"] = 1;

function __ZL10msFromTimed($t) {
  var $1 = _fmod($t, 1e3);
  var $2 = $1 & -1;
  var $_ = ($2 | 0) < 0 ? $2 + 1e3 | 0 : $2;
  return $_;
}

function __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $6, $vp, $dp);
    var $_0 = ($7 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $cx, 4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE1052($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($this, $cx, $hint, $vp) {
  var $1 = $this;
  var $2 = __ZNK8JSObject8getClassEv($1);
  var $4 = HEAP32[$2 + 32 >> 2];
  var $7 = ($4 | 0) == 88 ? 90 : $4;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $hint, $vp);
  return ($8 | 0) != 0;
}

function __ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE($cx, $vp, $printFunc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utctime = __stackBase__;
    var $buf = __stackBase__ + 8;
    var $1 = __ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd($cx, $vp, $utctime);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZL18JSDOUBLE_IS_FINITEd1004($3);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if (($printFunc | 0) == 84) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    _JS_ReportErrorNumber($9, 2, 0, 24, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $11 = $buf | 0;
    var $12 = _JS_snprintf($11, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 6:
    var $14 = $buf | 0;
    FUNCTION_TABLE[$printFunc]($14, 100, $3);
    __label__ = 7;
    break;
   case 7:
    var $16 = $buf | 0;
    var $17 = $cx;
    var $18 = _JS_NewStringCopyZ($17, $16);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16print_iso_stringPcjd($buf, $size, $utctime) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL12YearFromTimed($utctime);
  var $2 = __ZL13MonthFromTimed($utctime);
  var $3 = $2 + 1 | 0;
  var $4 = __ZL12DateFromTimed($utctime);
  var $5 = __ZL12HourFromTimed($utctime);
  var $6 = __ZL11MinFromTimed($utctime);
  var $7 = __ZL11SecFromTimed($utctime);
  var $8 = __ZL10msFromTimed($utctime);
  var $9 = _JS_snprintf($buf, $size, STRING_TABLE.__str103997 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $1, HEAP32[tempInt + 4 >> 2] = $3, HEAP32[tempInt + 8 >> 2] = $4, HEAP32[tempInt + 12 >> 2] = $5, HEAP32[tempInt + 16 >> 2] = $6, HEAP32[tempInt + 20 >> 2] = $7, HEAP32[tempInt + 24 >> 2] = $8, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN16JSAutoByteStringC1EP9JSContextP8JSString($this, $cx, $str) {
  __ZN16JSAutoByteStringC2EP9JSContextP8JSString($this, $cx, $str);
  return;
}

function __ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE($cx, $obj, $format, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 128;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $split = __stackBase__ + 100;
    var $utctime = __stackBase__ + 120;
    var $1 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $obj, $vp, $utctime);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = (tempDoubleI32[0] = HEAP32[$utctime >> 2], tempDoubleI32[1] = HEAP32[$utctime + 4 >> 2], tempDoubleF64[0]);
    var $5 = __ZL18JSDOUBLE_IS_FINITEd1004($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $buf | 0;
    var $9 = _JS_snprintf($8, 100, STRING_TABLE.__ZL15js_NaN_date_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 15;
    break;
   case 4:
    var $11 = __ZL9LocalTimedP9JSContext($4, $cx);
    __ZL11new_explodedP8PRMJTimeP9JSContext($11, $split, $cx);
    var $12 = $buf | 0;
    var $13 = _PRMJ_FormatTime($12, 100, $format, $split);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE($cx, $4, 0, $vp);
    var $_0 = $16;
    __label__ = 20;
    break;
   case 6:
    var $18 = _strcmp($format, STRING_TABLE.__str104998 | 0);
    if (($18 | 0) == 0 & ($13 | 0) > 5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    if (((HEAP8[$buf + ($13 - 3) | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $buf + ($13 - 2) | 0;
    if (((HEAP8[$28] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if (((HEAP8[$buf + ($13 - 1) | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    if (((HEAP8[$12] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if (((HEAP8[$buf + 1 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (((HEAP8[$buf + 2 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if (((HEAP8[$buf + 3 | 0] << 24 >> 24) - 48 | 0) >>> 0 < 10) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = 102 - $13 | 0;
    var $53 = __Z14js_DateGetYearP9JSContextP8JSObject($cx, $obj);
    var $54 = _JS_snprintf($28, $52, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $53, tempInt));
    __label__ = 15;
    break;
   case 15:
    var $57 = HEAP32[$cx + 36 >> 2];
    if (($57 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $61 = HEAP32[$57 + 12 >> 2];
    if (($61 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = $buf | 0;
    var $65 = FUNCTION_TABLE[$61]($cx, $64, $vp);
    var $_0 = $65;
    __label__ = 20;
    break;
   case 18:
    var $67 = $buf | 0;
    var $68 = $cx;
    var $69 = _JS_NewStringCopyZ($68, $67);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value9setStringEP8JSString($vp, $69);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE["X"] = 1;

function __ZN16JSAutoByteStringC2EP9JSContextP8JSString($this, $cx, $str) {
  var $1 = $this | 0;
  var $2 = $cx;
  var $3 = _JS_EncodeString($2, $str);
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL16print_gmt_stringPcjd($buf, $size, $utctime) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL7WeekDayd($utctime);
  var $3 = HEAP32[__ZL4days + ($1 << 2) >> 2];
  var $4 = __ZL12DateFromTimed($utctime);
  var $5 = __ZL13MonthFromTimed($utctime);
  var $7 = HEAP32[__ZL6months + ($5 << 2) >> 2];
  var $8 = __ZL12YearFromTimed($utctime);
  var $9 = __ZL12HourFromTimed($utctime);
  var $10 = __ZL11MinFromTimed($utctime);
  var $11 = __ZL11SecFromTimed($utctime);
  var $12 = _JS_snprintf($buf, $size, STRING_TABLE.__str1081002 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $3, HEAP32[tempInt + 4 >> 2] = $4, HEAP32[tempInt + 8 >> 2] = $7, HEAP32[tempInt + 12 >> 2] = $8, HEAP32[tempInt + 16 >> 2] = $9, HEAP32[tempInt + 20 >> 2] = $10, HEAP32[tempInt + 24 >> 2] = $11, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function _JSID_IS_INT1059($iden) {
  return $iden & 1;
}

function __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp) {
  return $fp;
}

function _JS_SetRuntimeDebugMode($rt, $debug) {
  HEAP8[$rt + 144220 | 0] = ($debug | 0) != 0 & 1;
  return;
}

function __ZN2js10StackFrame11setHookDataEPv($this, $v) {
  HEAP32[$this + 44 >> 2] = $v;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 65536;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js11GetGSNCacheEP9JSContext($cx) {
  return HEAP32[$cx + 52 >> 2] + 144308 | 0;
}

function _JS_SetInterrupt($rt, $hook, $closure) {
  HEAP32[$rt + 144148 >> 2] = $hook;
  HEAP32[$rt + 144152 >> 2] = $closure;
  return 1;
}

function _JS_ClearInterrupt($rt, $hoop, $closurep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($hoop | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$rt + 144148 >> 2];
    HEAP32[$hoop >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    var $_pre = $rt + 144152 | 0;
    if (($closurep | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAP32[$_pre >> 2];
    HEAP32[$closurep >> 2] = $8;
    __label__ = 5;
    break;
   case 5:
    HEAP32[$rt + 144148 >> 2] = 0;
    HEAP32[$_pre >> 2] = 0;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13date_makeTimeP9JSContextjijPN2JS5ValueE($cx, $maxargs, $local, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $result = __stackBase__ + 32;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $11 = __ZL18JSDOUBLE_IS_FINITEd1004($10);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 7:
    var $_01 = $argc >>> 0 > $maxargs >>> 0 ? $maxargs : $argc;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $_01 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $23 = $vp + ($i_0 + 2 << 3) | 0;
    var $24 = $args + ($i_0 << 3) | 0;
    var $25 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $23, $24);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 10:
    var $27 = (tempDoubleI32[0] = HEAP32[$24 >> 2], tempDoubleI32[1] = HEAP32[$24 + 4 >> 2], tempDoubleF64[0]);
    var $28 = __ZL18JSDOUBLE_IS_FINITEd1004($27);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 12:
    var $32 = __ZL18js_DoubleToIntegerd1005($27);
    tempDoubleF64[0] = $32, HEAP32[$24 >> 2] = tempDoubleI32[0], HEAP32[$24 + 4 >> 2] = tempDoubleI32[1];
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 13:
    var $35 = ($local | 0) != 0;
    if ($35) {
      __label__ = 14;
      break;
    } else {
      var $lorutime_0 = $10;
      __label__ = 15;
      break;
    }
   case 14:
    var $37 = __ZL9LocalTimedP9JSContext($10, $cx);
    var $lorutime_0 = $37;
    __label__ = 15;
    break;
   case 15:
    var $lorutime_0;
    var $39 = $args | 0;
    var $40 = $args + ($_01 << 3) | 0;
    if ($maxargs >>> 0 > 3 & ($_01 | 0) > 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $44 = $args + 8 | 0;
    var $45 = (tempDoubleI32[0] = HEAP32[$39 >> 2], tempDoubleI32[1] = HEAP32[$39 + 4 >> 2], tempDoubleF64[0]);
    var $hour_0 = $45;
    var $argp_0 = $44;
    __label__ = 18;
    break;
   case 17:
    var $47 = __ZL12HourFromTimed($lorutime_0);
    var $hour_0 = $47 | 0;
    var $argp_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $argp_0;
    var $hour_0;
    if ($maxargs >>> 0 > 2 & $argp_0 >>> 0 < $40 >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = (tempDoubleI32[0] = HEAP32[$argp_0 >> 2], tempDoubleI32[1] = HEAP32[$argp_0 + 4 >> 2], tempDoubleF64[0]);
    var $min_0 = $54;
    var $argp_1 = $argp_0 + 8 | 0;
    __label__ = 21;
    break;
   case 20:
    var $56 = __ZL11MinFromTimed($lorutime_0);
    var $min_0 = $56 | 0;
    var $argp_1 = $argp_0;
    __label__ = 21;
    break;
   case 21:
    var $argp_1;
    var $min_0;
    if ($maxargs >>> 0 > 1 & $argp_1 >>> 0 < $40 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $63 = (tempDoubleI32[0] = HEAP32[$argp_1 >> 2], tempDoubleI32[1] = HEAP32[$argp_1 + 4 >> 2], tempDoubleF64[0]);
    var $sec_0 = $63;
    var $argp_2 = $argp_1 + 8 | 0;
    __label__ = 24;
    break;
   case 23:
    var $65 = __ZL11SecFromTimed($lorutime_0);
    var $sec_0 = $65 | 0;
    var $argp_2 = $argp_1;
    __label__ = 24;
    break;
   case 24:
    var $argp_2;
    var $sec_0;
    if (($maxargs | 0) != 0 & $argp_2 >>> 0 < $40 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $71 = (tempDoubleI32[0] = HEAP32[$argp_2 >> 2], tempDoubleI32[1] = HEAP32[$argp_2 + 4 >> 2], tempDoubleF64[0]);
    var $msec_0 = $71;
    __label__ = 27;
    break;
   case 26:
    var $73 = __ZL10msFromTimed($lorutime_0);
    var $msec_0 = $73 | 0;
    __label__ = 27;
    break;
   case 27:
    var $msec_0;
    var $81 = (($hour_0 * 60 + $min_0) * 60 + $sec_0) * 1e3 + $msec_0;
    var $83 = _floor($lorutime_0 / 864e5);
    var $85 = $83 * 864e5 + $81;
    tempDoubleF64[0] = $85, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    if ($35) {
      __label__ = 28;
      break;
    } else {
      var $89 = $85;
      __label__ = 29;
      break;
    }
   case 28:
    var $87 = __ZL3UTCdP9JSContext($85, $cx);
    tempDoubleF64[0] = $87, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $89 = $87;
    __label__ = 29;
    break;
   case 29:
    var $89;
    var $90 = __ZL18JSDOUBLE_IS_FINITEd1004($89);
    if (($90 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if ($89 < 0) {
      __label__ = 31;
      break;
    } else {
      var $97 = $89;
      __label__ = 32;
      break;
    }
   case 31:
    var $97 = -$89;
    __label__ = 32;
    break;
   case 32:
    var $97;
    if ($97 > 864e13) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $101 = __ZL18js_DoubleToIntegerd1005($89);
    var $105 = $101;
    __label__ = 35;
    break;
   case 34:
    var $103 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $105 = $103;
    __label__ = 35;
    break;
   case 35:
    var $105;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $105, $vp);
    var $_0 = 1;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13date_makeTimeP9JSContextjijPN2JS5ValueE["X"] = 1;

function __ZL13date_makeDateP9JSContextjijPN2JS5ValueE($cx, $maxargs, $local, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $result = __stackBase__ + 24;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd($cx, $4, $vp, $result);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cx_idx1_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx1_val, $4, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 5:
    var $_01 = $argc >>> 0 > $maxargs >>> 0 ? $maxargs : $argc;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $_01 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $17 = $vp + ($i_0 + 2 << 3) | 0;
    var $18 = $args + ($i_0 << 3) | 0;
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($2, $17, $18);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 8:
    var $21 = (tempDoubleI32[0] = HEAP32[$18 >> 2], tempDoubleI32[1] = HEAP32[$18 + 4 >> 2], tempDoubleF64[0]);
    var $22 = __ZL18JSDOUBLE_IS_FINITEd1004($21);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE($cx_idx_val, $4, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 10:
    var $26 = __ZL18js_DoubleToIntegerd1005($21);
    tempDoubleF64[0] = $26, HEAP32[$18 >> 2] = tempDoubleI32[0], HEAP32[$18 + 4 >> 2] = tempDoubleI32[1];
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 11:
    var $29 = (tempDoubleI32[0] = HEAP32[$result >> 2], tempDoubleI32[1] = HEAP32[$result + 4 >> 2], tempDoubleF64[0]);
    var $30 = __ZL18JSDOUBLE_IS_FINITEd1004($29);
    if (($30 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if ($maxargs >>> 0 < 3) {
      __label__ = 13;
      break;
    } else {
      var $lorutime_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    __ZN2JS5Value9setDoubleEd($vp, $29);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 14:
    if (($local | 0) == 0) {
      var $lorutime_0 = $29;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZL9LocalTimedP9JSContext($29, $cx);
    var $lorutime_0 = $38;
    __label__ = 16;
    break;
   case 16:
    var $lorutime_0;
    var $40 = $args | 0;
    var $41 = $args + ($_01 << 3) | 0;
    if ($maxargs >>> 0 > 2 & ($_01 | 0) > 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $45 = $args + 8 | 0;
    var $46 = (tempDoubleI32[0] = HEAP32[$40 >> 2], tempDoubleI32[1] = HEAP32[$40 + 4 >> 2], tempDoubleF64[0]);
    var $year_0 = $46;
    var $argp_0 = $45;
    __label__ = 19;
    break;
   case 18:
    var $48 = __ZL12YearFromTimed($lorutime_0);
    var $year_0 = $48 | 0;
    var $argp_0 = $40;
    __label__ = 19;
    break;
   case 19:
    var $argp_0;
    var $year_0;
    if ($maxargs >>> 0 > 1 & $argp_0 >>> 0 < $41 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $55 = (tempDoubleI32[0] = HEAP32[$argp_0 >> 2], tempDoubleI32[1] = HEAP32[$argp_0 + 4 >> 2], tempDoubleF64[0]);
    var $month_0 = $55;
    var $argp_1 = $argp_0 + 8 | 0;
    __label__ = 22;
    break;
   case 21:
    var $57 = __ZL13MonthFromTimed($lorutime_0);
    var $month_0 = $57 | 0;
    var $argp_1 = $argp_0;
    __label__ = 22;
    break;
   case 22:
    var $argp_1;
    var $month_0;
    if (($maxargs | 0) != 0 & $argp_1 >>> 0 < $41 >>> 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $63 = (tempDoubleI32[0] = HEAP32[$argp_1 >> 2], tempDoubleI32[1] = HEAP32[$argp_1 + 4 >> 2], tempDoubleF64[0]);
    var $day_0 = $63;
    __label__ = 25;
    break;
   case 24:
    var $65 = __ZL12DateFromTimed($lorutime_0);
    var $day_0 = $65 | 0;
    __label__ = 25;
    break;
   case 25:
    var $day_0;
    var $68 = __ZL7MakeDayddd($year_0, $month_0, $day_0);
    var $69 = $68 * 864e5;
    var $70 = __ZL13TimeWithinDayd($lorutime_0);
    var $71 = $69 + $70;
    tempDoubleF64[0] = $71, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    if (($local | 0) == 0) {
      var $76 = $71;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $74 = __ZL3UTCdP9JSContext($71, $cx);
    tempDoubleF64[0] = $74, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $76 = $74;
    __label__ = 27;
    break;
   case 27:
    var $76;
    var $77 = __ZL18JSDOUBLE_IS_FINITEd1004($76);
    if (($77 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($76 < 0) {
      __label__ = 29;
      break;
    } else {
      var $84 = $76;
      __label__ = 30;
      break;
    }
   case 29:
    var $84 = -$76;
    __label__ = 30;
    break;
   case 30:
    var $84;
    if ($84 > 864e13) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $88 = __ZL18js_DoubleToIntegerd1005($76);
    var $92 = $88;
    __label__ = 33;
    break;
   case 32:
    var $90 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $92 = $90;
    __label__ = 33;
    break;
   case 33:
    var $92;
    __ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE($4, $92, $vp);
    var $_0 = 1;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13date_makeDateP9JSContextjijPN2JS5ValueE["X"] = 1;

function _JS_GetDebugMode($cx) {
  var $3 = HEAP32[$cx + 56 >> 2];
  var $4 = __ZNK13JSCompartment9debugModeEv($3);
  return $4 & 1;
}

function _JS_SetDebugMode($cx, $debug) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = _JS_SetDebugModeForCompartment($cx, $2, $debug);
  return $3;
}

function _JS_SetDebugModeForCompartment($cx, $comp, $debug) {
  var $1 = ($debug | 0) != 0;
  var $2 = $comp;
  var $3 = $cx;
  var $4 = __ZN13JSCompartment17setDebugModeFromCEP9JSContextb($2, $3, $1);
  return $4 & 1;
}

function __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($1);
    var $4 = HEAP32[$cx + 200 >> 2];
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = HEAP32[$4 + 40 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $12 = HEAP32[$4 + 44 >> 2];
    var $13 = FUNCTION_TABLE[$7]($cx, $10, 1, 0, $12);
    __ZN2js10StackFrame11setHookDataEPv($fp, $13);
    __label__ = 6;
    break;
   case 4:
    var $16 = HEAP32[$4 + 48 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $21 = HEAP32[$4 + 52 >> 2];
    var $22 = FUNCTION_TABLE[$16]($cx, $19, 1, 0, $21);
    __ZN2js10StackFrame11setHookDataEPv($fp, $22);
    __label__ = 6;
    break;
   case 6:
    __ZN2js8Debugger12onEnterFrameEP9JSContext($cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12onEnterFrameEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2];
    var $4 = __ZN13JSCompartment12getDebuggeesEv($3);
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    __ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $okArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ok = __stackBase__;
    HEAP32[$ok >> 2] = $okArg & 1;
    var $2 = __ZNK2js10StackFrame13maybeHookDataEv($fp);
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $fp;
    var $6 = __ZNK2js10StackFrame22isFramePushedByExecuteEv($5);
    var $8 = HEAPU32[$cx + 200 >> 2];
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$8 + 40 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $15 = FUNCTION_TABLE[$11]($cx, $14, 0, $ok, $2);
    __label__ = 7;
    break;
   case 5:
    var $18 = HEAP32[$8 + 48 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($fp);
    var $22 = FUNCTION_TABLE[$18]($cx, $21, 0, $ok, $2);
    __label__ = 7;
    break;
   case 7:
    __ZN2js8Debugger12onLeaveFrameEP9JSContext($cx);
    var $25 = (HEAP32[$ok >> 2] | 0) != 0;
    STACKTOP = __stackBase__;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame13maybeHookDataEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11hasHookDataEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 44 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger12onLeaveFrameEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = $2;
    var $4 = __ZN13JSCompartment12getDebuggeesEv($3);
    var $5 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $2 + 1956 | 0;
    var $8 = __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    __ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext($10);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetSingleStepMode($cx, $script, $singleStep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($singleStep | 0) != 0;
    var $5 = $script;
    var $6 = $cx;
    var $7 = __ZN8JSScript15setStepModeFlagEP9JSContextb($5, $6, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14CheckDebugModeP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_GetDebugMode($cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _JS_ReportErrorFlagsAndNumber($4, 0, 2, 0, 257, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_UntrapScriptCode($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $script | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $script;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    var $5 = $4 + 1956 | 0;
    __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv($r, $5);
    var $6 = $script + 8 | 0;
    var $7 = $script;
    var $8 = $cx;
    var $code_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $code_0;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($r);
    if ($10) {
      var $code_3 = $code_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($r);
    var $14 = HEAPU32[$12 + 4 >> 2];
    if ((HEAP32[$14 >> 2] | 0) == ($script | 0)) {
      __label__ = 4;
      break;
    } else {
      var $code_2 = $code_0;
      __label__ = 15;
      break;
    }
   case 4:
    var $19 = $14 + 4 | 0;
    var $20 = HEAPU32[$19 >> 2];
    var $21 = HEAPU32[$1 >> 2];
    var $25 = HEAPU32[$6 >> 2];
    if (($20 - $21 | 0) >>> 0 < $25 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $code_2 = $code_0;
      __label__ = 15;
      break;
    }
   case 5:
    if (($code_0 | 0) == ($21 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $code_1 = $code_0;
      var $63 = $20;
      var $62 = $21;
      __label__ = 14;
      break;
    }
   case 6:
    var $30 = __ZN8JSScript5notesEv($7);
    var $31 = HEAP8[$30];
    if ($31 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $30;
      __label__ = 12;
      break;
    } else {
      var $sn_01 = $30;
      var $33 = $31;
      __label__ = 7;
      break;
    }
   case 7:
    var $33;
    var $sn_01;
    if (($33 & 255) > 191) {
      var $39 = 24;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $39 = ($33 & 255) >>> 3;
    __label__ = 9;
    break;
   case 9:
    var $39;
    if (HEAP8[_js_SrcNoteSpec + ($39 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $46 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $44 = _js_SrcNoteLength($sn_01);
    var $46 = $44;
    __label__ = 11;
    break;
   case 11:
    var $46;
    var $47 = $sn_01 + $46 | 0;
    var $48 = HEAPU8[$47];
    if ($48 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $47;
      __label__ = 12;
      break;
    } else {
      var $sn_01 = $47;
      var $33 = $48;
      __label__ = 7;
      break;
    }
   case 12:
    var $sn_0_lcssa;
    var $54 = $25 + 1 - $30 + $sn_0_lcssa | 0;
    var $55 = __ZN9JSContext7malloc_Ej($8, $54);
    if (($55 | 0) == 0) {
      var $code_3 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $58 = HEAP32[$1 >> 2];
    _memcpy($55, $58, $54, 1);
    var $59 = __ZN2js11GetGSNCacheEP9JSContext($cx);
    var $60 = $59;
    __ZN2js8GSNCache5purgeEv($60);
    var $code_1 = $55;
    var $63 = HEAP32[$19 >> 2];
    var $62 = HEAP32[$1 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $62;
    var $63;
    var $code_1;
    HEAP8[$code_1 + ($63 - $62) | 0] = HEAP32[$14 + 8 >> 2] & 255;
    var $code_2 = $code_1;
    __label__ = 15;
    break;
   case 15:
    var $code_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($r);
    var $code_0 = $code_2;
    __label__ = 2;
    break;
   case 16:
    var $code_3;
    STACKTOP = __stackBase__;
    return $code_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_UntrapScriptCode["X"] = 1;

function _JS_SetTrap($cx, $script, $pc, $handler, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $closure = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $closure | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $script;
    var $9 = __ZNK2js2gc4Cell11compartmentEv($8);
    var $10 = $cx;
    var $11 = $script;
    var $12 = __ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject($9, $10, $11, $pc, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $handler;
    var $16 = __ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_($12, undef, $15, $closure);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetTrapOpcode($cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment17getBreakpointSiteEPh($2, $pc);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$3 + 8 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $12 = HEAPU8[$pc] & 255;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearTrap($cx, $script, $pc, $handlerp, $closurep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment17getBreakpointSiteEPh($2, $pc);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    var $7 = $handlerp;
    __ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_($3, $6, 0, $7, $closurep);
    __label__ = 7;
    break;
   case 3:
    if (($handlerp | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$handlerp >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    if (($closurep | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $14$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $14$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $15 = $closurep | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearScriptTraps($cx, $script) {
  var $1 = $script;
  var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
  var $3 = $cx;
  var $4 = $script;
  __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($2, $3, $4);
  return;
}

function _JS_ClearAllTrapsForCompartment($cx) {
  var $3 = HEAP32[$cx + 56 >> 2];
  var $4 = $cx;
  __ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript($3, $4, 0);
  return;
}

function _JS_SetWatchPoint($cx, $obj, $id, $handler, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $v = __stackBase__ + 4;
    var $attrs = __stackBase__ + 12;
    var $propid = __stackBase__ + 16;
    var $idroot = __stackBase__ + 20;
    var $2 = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    HEAP32[$1 >> 2] = $obj;
    var $4 = $cx;
    var $5 = __Z22js_CheckForStringIndexi($id);
    var $6 = $1;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($4, $6);
    var $7 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $idroot;
    __ZN2js15AutoValueRooterC1EP9JSContext($10, $4);
    var $11 = _JSID_IS_INT1059($5);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$propid >> 2] = $5;
    var $20 = $5;
    __label__ = 6;
    break;
   case 4:
    __ZN2jsL9IdToValueEi1060($2, $5);
    var $15 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($4, $2, $propid);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    var $17 = HEAP32[$propid >> 2];
    var $18 = __Z22js_CheckForStringIndexi($17);
    HEAP32[$propid >> 2] = $18;
    __ZN2jsL9IdToValueEi1060($3, $18);
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($idroot, $3);
    var $20 = $18;
    __label__ = 6;
    break;
   case 6:
    var $20;
    if (($7 | 0) == ($obj | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $cx;
    var $24 = $7;
    var $25 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($23, $24, $20, 3, $v, $attrs);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $7;
    var $29 = __ZNK8JSObject8isNativeEv($28);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZNK8JSObject8getClassEv($28);
    var $33 = HEAP32[$31 >> 2];
    _JS_ReportErrorNumber($4, 2, 0, 15, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 10:
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($4, $28, $20);
    var $35 = $cx + 56 | 0;
    var $38 = HEAP32[HEAP32[$35 >> 2] + 1984 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $wpmap_0 = $38;
      __label__ = 15;
      break;
    }
   case 11:
    var $42 = HEAP32[$cx + 52 >> 2];
    var $43 = __ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v($42);
    if (($43 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = $43;
    var $47 = __ZN2js13WatchpointMap4initEv($46);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($4);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 14:
    var $51 = HEAP32[$35 >> 2] + 1984 | 0;
    HEAP32[$51 >> 2] = $43;
    var $wpmap_0 = $43;
    __label__ = 15;
    break;
   case 15:
    var $wpmap_0;
    var $54 = $handler;
    var $55 = $closure;
    var $56 = __ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_($wpmap_0, $4, $28, $5, $54, $55);
    var $_0 = $56 & 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($10);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_SetWatchPoint["X"] = 1;

function _JS_LocalNameToAtom($w) {
  return $w & -2;
}

function __ZN2jsL13VersionNumberE9JSVersion1066($version) {
  return $version & 4095;
}

function __ZN2js15AutoValueRooter3setEN2JS5ValueE($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $_02 = $0 | 0;
  var $tmp$0 = HEAP32[$_02 >> 2];
  var $tmp$1 = HEAP32[$_02 + 4 >> 2];
  var $_03 = $this + 16 | 0;
  HEAP32[$_03 >> 2] = $tmp$0;
  HEAP32[$_03 + 4 >> 2] = $tmp$1;
  STACKTOP = __stackBase__;
  return;
}

function _JS_EndPC($cx, $script) {
  return HEAP32[$script >> 2] + HEAP32[$script + 8 >> 2] | 0;
}

function _JS_GetFunctionArgumentCount($cx, $fun) {
  return HEAPU16[$fun + 56 >> 1] & 65535;
}

function __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function _JS_AtomKey($atom) {
  return $atom | 0;
}

function _JS_GetScriptPrincipals($cx, $script) {
  return HEAP32[$script + 76 >> 2];
}

function __ZNK2js10StackFrame15isDebuggerFrameEv($this) {
  return (HEAP32[$this >> 2] & 16 | 0) != 0;
}

function _JS_GetScriptFilename($cx, $script) {
  return HEAP32[$script + 52 >> 2];
}

function _JS_GetScriptSourceMap($cx, $script) {
  return HEAP32[$script + 80 >> 2];
}

function _JS_GetScriptBaseLineNumber($cx, $script) {
  return HEAP32[$script + 28 >> 2];
}

function _JS_SetNewScriptHookProc($rt, $hook, $callerdata) {
  HEAP32[$rt + 144156 >> 2] = $hook;
  HEAP32[$rt + 144160 >> 2] = $callerdata;
  return;
}

function _JS_SetDestroyScriptHookProc($rt, $hook, $callerdata) {
  HEAP32[$rt + 144164 >> 2] = $hook;
  HEAP32[$rt + 144168 >> 2] = $callerdata;
  return;
}

function __ZN2jsL9IdToValueEi1060($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1077($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1080($id);
    __ZN2JSL11StringValueEP8JSString1079($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1059($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1082($id);
    __ZN2JSL10Int32ValueEi1081($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1083($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1085($id);
    __ZN2JSL11ObjectValueER8JSObject1084($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1068($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSRuntime7malloc_EjP9JSContext($1, 24, 0);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$2 + 4 >> 2] = 0;
    HEAP32[$2 + 8 >> 2] = 0;
    HEAP32[$2 + 12 >> 2] = 0;
    HEAP32[$2 + 16 >> 2] = 0;
    HEAP32[$2 + 20 >> 2] = 0;
    __ZN2js13WatchpointMapC1Ev($5);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearWatchPoint($cx, $obj, $id, $handlerp, $closurep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z22js_CheckForStringIndexi($id);
    var $8 = $obj;
    var $9 = $4;
    var $10 = $handlerp;
    var $11 = $closurep;
    __ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_($9, $8, $7, $10, $11);
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearWatchPointsForObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $4;
    __ZN2js13WatchpointMap13unwatchObjectEP8JSObject($8, $7);
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ClearAllWatchPoints($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 1984 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    __ZN2js13WatchpointMap5clearEv($9);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_PCToLineNumber($cx, $script, $pc) {
  var $1 = $cx;
  var $2 = $script;
  var $3 = __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($1, $2, $pc);
  return $3;
}

function _JS_LineNumberToPC($cx, $script, $lineno) {
  var $1 = $script;
  var $2 = __Z17js_LineNumberToPCP8JSScriptj($1, $lineno);
  return $2;
}

function _JS_GetLinePCs($cx, $script, $startLine, $maxLines, $count, $retLines, $retPCs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script + 8 >> 2];
    var $maxLines_ = $2 >>> 0 > $maxLines >>> 0 ? $maxLines : $2;
    var $4 = $maxLines_ << 2;
    var $5 = $cx;
    var $6 = __ZN9JSContext7malloc_Ej($5, $4);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN9JSContext7malloc_Ej($5, $4);
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN9JSContext5free_EPv(undef, $6);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 4:
    var $16 = HEAP32[$script + 28 >> 2];
    var $17 = $script;
    var $18 = __ZN8JSScript5notesEv($17);
    var $19 = $script | 0;
    var $sn_0 = $18;
    var $i_0 = 0;
    var $offset_0 = 0;
    var $lineno_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $lineno_0;
    var $offset_0;
    var $i_0;
    var $sn_0;
    var $21 = HEAPU8[$sn_0];
    var $22 = $21 & 255;
    if ($21 << 24 >> 24 == 0) {
      var $i_2 = $i_0;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = ($21 & 255) > 191;
    var $_v = $25 ? 63 : 7;
    var $27 = ($_v & $22) + $offset_0 | 0;
    var $_ = $25 ? 24 : $22 >>> 3;
    if (($_ - 22 | 0) >>> 0 < 2) {
      __label__ = 7;
      break;
    } else {
      var $i_1 = $i_0;
      var $lineno_2 = $lineno_0;
      var $46 = $21;
      __label__ = 13;
      break;
    }
   case 7:
    if (($_ | 0) == 23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $33 = _js_GetSrcNoteOffset($sn_0, 0);
    var $lineno_1 = $33;
    __label__ = 10;
    break;
   case 9:
    var $lineno_1 = $lineno_0 + 1 | 0;
    __label__ = 10;
    break;
   case 10:
    var $lineno_1;
    if ($lineno_1 >>> 0 < $startLine >>> 0) {
      var $i_1 = $i_0;
      var $lineno_2 = $lineno_1;
      var $46 = $21;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$7 + ($i_0 << 2) >> 2] = $lineno_1;
    var $41 = HEAP32[$19 >> 2] + $27 | 0;
    HEAP32[$11 + ($i_0 << 2) >> 2] = $41;
    var $43 = $i_0 + 1 | 0;
    if ($43 >>> 0 < $maxLines >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $i_2 = $43;
      __label__ = 18;
      break;
    }
   case 12:
    var $i_1 = $43;
    var $lineno_2 = $lineno_1;
    var $46 = HEAP8[$sn_0];
    __label__ = 13;
    break;
   case 13:
    var $46;
    var $lineno_2;
    var $i_1;
    if (($46 & 255) > 191) {
      var $52 = 24;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = ($46 & 255) >>> 3;
    __label__ = 15;
    break;
   case 15:
    var $52;
    if (HEAP8[_js_SrcNoteSpec + ($52 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $59 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = _js_SrcNoteLength($sn_0);
    var $59 = $57;
    __label__ = 17;
    break;
   case 17:
    var $59;
    var $sn_0 = $sn_0 + $59 | 0;
    var $i_0 = $i_1;
    var $offset_0 = $27;
    var $lineno_0 = $lineno_2;
    __label__ = 5;
    break;
   case 18:
    var $i_2;
    HEAP32[$count >> 2] = $i_2;
    if (($retLines | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP32[$retLines >> 2] = $7;
    __label__ = 21;
    break;
   case 20:
    __ZN9JSContext5free_EPv(undef, $6);
    __label__ = 21;
    break;
   case 21:
    if (($retPCs | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP32[$retPCs >> 2] = $11;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 23:
    __ZN9JSContext5free_EPv(undef, $10);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetLinePCs["X"] = 1;

function _JS_FunctionHasLocalNames($cx, $fun) {
  var $1 = $fun;
  var $2 = __ZNK10JSFunction6scriptEv($1);
  var $4 = $2 + 64 | 0;
  var $5 = __ZNK2js8Bindings13hasLocalNamesEv($4);
  return $5 & 1;
}

function __ZNK2js8Bindings13hasLocalNamesEv($this) {
  var $1 = __ZNK2js8Bindings15countLocalNamesEv($this);
  return ($1 | 0) != 0;
}

function _JS_GetFunctionLocalNameArray($cx, $fun, $markp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localNames = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $2 = $cx;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $2);
    var $3 = $localNames;
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($3, $1);
    var $4 = $fun;
    var $5 = __ZNK10JSFunction6scriptEv($4);
    var $7 = $5 + 64 | 0;
    var $8 = $localNames;
    var $9 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($7, undef, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $11 = $cx + 88 | 0;
    var $15 = HEAP32[HEAP32[$11 >> 2] + 12 >> 2];
    HEAP32[$markp >> 2] = $15;
    var $16 = HEAP32[$11 >> 2];
    var $17 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE6lengthEv($localNames);
    var $20 = HEAP32[$cx + 96 >> 2];
    var $23 = ($17 << 2) + $20 & ($20 ^ -1);
    var $24 = $16 + 12 | 0;
    var $25 = HEAPU32[$24 >> 2];
    var $27 = HEAPU32[$16 + 8 >> 2];
    if ($23 >>> 0 > $27 >>> 0 | $25 >>> 0 > ($27 - $23 | 0) >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $32 = $cx + 72 | 0;
    var $33 = _JS_ArenaAllocate($32, $23);
    var $_p_0 = $33;
    __label__ = 5;
    break;
   case 4:
    var $36 = $23 + $25 | 0;
    HEAP32[$24 >> 2] = $36;
    var $_p_0 = $25;
    __label__ = 5;
    break;
   case 5:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($2);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $41 = $_p_0;
    var $42 = $_p_0;
    var $43 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv($3);
    var $44 = $43;
    var $45 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE6lengthEv($localNames);
    var $46 = $45 << 2;
    _memcpy($42, $44, $46, 1);
    var $_0 = $41;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($3);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetFunctionLocalNameArray["X"] = 1;

function _JS_ReleaseFunctionLocalNameArray($cx, $mark) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 72 | 0;
    var $3 = HEAP32[$cx + 88 >> 2];
    if (($3 | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $mark;
    var $9 = HEAP32[$3 + 4 >> 2];
    var $11 = $3 + 12 | 0;
    if (($7 - $9 | 0) >>> 0 > (HEAP32[$11 >> 2] - $9 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = HEAP32[$cx + 96 >> 2];
    var $20 = $17 + $7 & ($17 ^ -1);
    HEAP32[$11 >> 2] = $20;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($1, $mark);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFunctionScript($cx, $fun) {
  var $1 = __ZNK10JSFunction11maybeScriptEv($fun);
  return $1;
}

function __ZNK10JSFunction11maybeScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK10JSFunction13isInterpretedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK10JSFunction6scriptEv($1);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFunctionNative($cx, $fun) {
  var $1 = __ZNK10JSFunction11maybeNativeEv($fun);
  return $1;
}

function __ZNK10JSFunction11maybeNativeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK10JSFunction13isInterpretedEv($1);
    if ($2) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK10JSFunction6nativeEv($this);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FrameIterator($cx, $iteratorp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$iteratorp >> 2];
    var $3 = __ZN2js8ValueifyEP12JSStackFrame($2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1065($cx);
    var $11 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK2js10StackFrame4prevEv($3);
    var $11 = $8;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $12 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($11);
    HEAP32[$iteratorp >> 2] = $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1065($cx) {
  var $1 = $cx;
  var $2 = __ZNK9JSContext7maybefpEv($1);
  return $2;
}

function _JS_GetFrameScript($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame11maybeScriptEv($2);
  return $3;
}

function _JS_GetFramePC($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $4 = $2;
  var $5 = $cx + 60 | 0;
  var $6 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($4, $5, 0, 0);
  return $6;
}

function _JS_GetScriptedCaller($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $cx;
  var $4 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($3, $2);
  var $5 = $4;
  var $6 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($5);
  return $6;
}

function _JS_GetFrameAnnotation($cx, $fpArg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = $2;
    var $4 = __ZNK2js10StackFrame10annotationEv($3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js10StackFrame13isScriptFrameEv($2);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $10 = $cx;
    var $11 = __ZN8JSObject10principalsEP9JSContext($9, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    var $17 = HEAP32[$11 + 8 >> 2];
    var $18 = FUNCTION_TABLE[$17]($cx, $14);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = __ZNK2js10StackFrame10annotationEv($3);
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetFrameAnnotation($cx, $fp, $annotation) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $2;
  __ZN2js10StackFrame13setAnnotationEPv($3, $annotation);
  return;
}

function _JS_GetFramePrincipalArray($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $cx;
    var $5 = __ZN8JSObject10principalsEP9JSContext($3, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $11 = HEAP32[$5 + 4 >> 2];
    var $12 = FUNCTION_TABLE[$11]($cx, $8);
    var $_0 = $12;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_IsScriptFrame($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame12isDummyFrameEv($2);
  return $3 & 1 ^ 1;
}

function _JS_GetFrameObject($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
  return $3;
}

function _JS_GetFrameScopeChain($cx, $fpArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $4, $3);
    var $5 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $2;
    var $8 = __ZN2jsL8JsvalifyEPNS_10StackFrameE($7);
    var $9 = _JS_GetFrameCallObject($cx, $8);
    var $10 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($4, $2);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameCallObject($cx, $fpArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame15isFunctionFrameEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $5 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $6 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $6, $5);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $9 = __ZNK2js10StackFrame10hasCallObjEv($2);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($2);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($6, $2);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 6:
    var $16 = $2;
    var $17 = __ZNK2js10StackFrame7callObjEv($16);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameThis($cx, $fpArg, $thisv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame12isDummyFrameEv($2);
    if ($3) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $6 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $6, $5);
    var $7 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($6, $2);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2js10StackFrame9thisValueEv($2);
    var $12 = $11 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $thisv | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameFunction($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $2;
  var $4 = __ZNK2js10StackFrame8maybeFunEv($3);
  return $4;
}

function __ZNK2js10StackFrame8maybeFunEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame15isFunctionFrameEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame3funEv($1);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFrameFunctionObject($cx, $fpArg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fpArg;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = __ZNK2js10StackFrame15isFunctionFrameEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js10StackFrame6calleeEv($2);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_IsConstructorFrame($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame14isConstructingEv($2);
  return $3 & 1;
}

function _JS_GetFrameCalleeObject($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $2;
  var $4 = __ZNK2js10StackFrame12maybeCalleevEv($3);
  var $5 = __ZNK2JS5Value14toObjectOrNullEv($4);
  return $5;
}

function __ZNK2js10StackFrame12maybeCalleevEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $8 = $this;
    var $9 = __ZNK2js10StackFrame10formalArgsEv($8);
    var $_pn = $9;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 16 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetValidFrameCalleeObject($cx, $fp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $fp;
    var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
    var $3 = $cx;
    var $4 = __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($2, $3, $v);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $v | 0;
    var $7 = $vp | 0;
    var $8$0 = HEAP32[$6 >> 2];
    var $8$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $8$0;
    HEAP32[$7 + 4 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_IsDebuggerFrame($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $2;
  var $4 = __ZNK2js10StackFrame15isDebuggerFrameEv($3);
  return $4 & 1;
}

function _JS_IsGlobalFrame($cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = __ZNK2js10StackFrame13isGlobalFrameEv($2);
  return $3 & 1;
}

function _JS_GetFrameReturnValue($agg_result, $cx, $fp) {
  var $1 = $fp;
  var $2 = __ZN2js8ValueifyEP12JSStackFrame($1);
  var $3 = $2;
  var $4 = __ZN2js10StackFrame11returnValueEv($3);
  var $5 = $4 | 0;
  var $6$0 = HEAP32[$5 >> 2];
  var $6$1 = HEAP32[$5 + 4 >> 2];
  var $7 = $agg_result | 0;
  HEAP32[$7 >> 2] = $6$0;
  HEAP32[$7 + 4 >> 2] = $6$1;
  return;
}

function __ZN2js10StackFrame11returnValueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = $this + 24 | 0;
    if ((HEAP32[$this >> 2] & 262144 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($5);
    __label__ = 3;
    break;
   case 3:
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_SetFrameReturnValue($cx, $fpArg, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $rval = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $rval | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $fpArg;
  var $6 = __ZN2js8ValueifyEP12JSStackFrame($5);
  var $7 = $6;
  __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($7, $rval);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($this, $v) {
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this + 24 | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  __ZN2js10StackFrame15markReturnValueEv($this);
  return;
}

function _JS_GetScriptLineExtent($cx, $script) {
  var $1 = $script;
  var $2 = __Z22js_GetScriptLineExtentP8JSScript($1);
  return $2;
}

function _JS_GetScriptVersion($cx, $script) {
  var $1 = $script;
  var $2 = __ZNK8JSScript10getVersionEv($1);
  var $3 = __ZN2jsL13VersionNumberE9JSVersion1066($2);
  return $3;
}

function _JS_EvaluateUCInStackFrame($cx, $fpArg, $chars, $length, $filename, $lineno, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ac = __stackBase__;
    var $1 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JS_GetFrameScopeChain($cx, $fpArg);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = $4;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $7, $8);
    var $9 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $fpArg;
    var $12 = __ZN2js8ValueifyEP12JSStackFrame($11);
    var $13 = __ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE($7, $8, $12, $chars, $length, $filename, $lineno, $rval);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 6;
    break;
   case 6:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_EvaluateInStackFrame($cx, $fp, $bytes, $length, $filename, $lineno, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    HEAP32[$len >> 2] = $length;
    var $1 = __ZL14CheckDebugModeP9JSContext($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($4, $bytes, $len, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$len >> 2];
    var $9 = _JS_EvaluateUCInStackFrame($cx, $fp, $5, $8, $filename, $lineno, $rval);
    var $10 = $5;
    __ZN9JSContext5free_EPv(undef, $10);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_PropertyIterator($obj, $iteratorp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$iteratorp >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = __ZNK8JSObject12lastPropertyEv($4);
    var $shape_0 = $5;
    __label__ = 5;
    break;
   case 3:
    var $8 = $1;
    var $9 = __ZNK2js5Shape8previousEv($8);
    var $10 = $9;
    var $11 = __ZNK2js5Shape8previousEv($9);
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $shape_0 = $10;
      __label__ = 5;
      break;
    }
   case 4:
    var $shape_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $shape_0;
    var $15 = $shape_0;
    HEAP32[$iteratorp >> 2] = $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_UnsafeGetLastProfilingError() {
  return __ZL10gLastError | 0;
}

function _JS_StartProfiling($profileName) {
  return 1;
}

function _JS_StopProfiling($profileName) {
  return 1;
}

function _JS_DumpProfile($outfile, $profileName) {
  return 1;
}

function _JS_DefineProfilingFunctions($cx, $obj) {
  return 1;
}

function _JS_DumpBytecode($cx, $script) {
  return;
}

function __ZL26DumpBytecodeScriptCallbackP9JSContextPvS1_13JSGCTraceKindj($cx, $data, $thing, $traceKind, $thingSize) {
  return;
}

function __ZL16ControlProfilersb($toState) {
  HEAP8[__ZN2js6Probes15ProfilingActiveE] = $toState & 1;
  return;
}

function _JSID_IS_STRING1077($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1080($iden) {
  return $iden;
}

function _JSID_TO_INT1082($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT1083($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1085($iden) {
  return $iden & -8;
}

function _JS_DHashVoidPtrKeyStub($table, $key) {
  return $key >>> 2;
}

function __ZNK2js5Shape8writableEv($this) {
  return (HEAP8[$this + 28 | 0] & 2) << 24 >> 24 == 0;
}

function __ZNK2js5Shape12configurableEv($this) {
  return (HEAP8[$this + 28 | 0] & 4) << 24 >> 24 == 0;
}

function __ZNK2js5Shape5Range5emptyEv($this) {
  return (HEAP32[HEAP32[$this >> 2] + 32 >> 2] | 0) == 0;
}

function _JS_SetDebuggerHandler($rt, $handler, $closure) {
  HEAP32[$rt + 144172 >> 2] = $handler;
  HEAP32[$rt + 144176 >> 2] = $closure;
  return 1;
}

function _JS_SetSourceHandler($rt, $handler, $closure) {
  HEAP32[$rt + 144180 >> 2] = $handler;
  HEAP32[$rt + 144184 >> 2] = $closure;
  return 1;
}

function _JS_SetExecuteHook($rt, $hook, $closure) {
  HEAP32[$rt + 144188 >> 2] = $hook;
  HEAP32[$rt + 144192 >> 2] = $closure;
  return 1;
}

function _JS_SetCallHook($rt, $hook, $closure) {
  HEAP32[$rt + 144196 >> 2] = $hook;
  HEAP32[$rt + 144200 >> 2] = $closure;
  return 1;
}

function _JS_SetThrowHook($rt, $hook, $closure) {
  HEAP32[$rt + 144204 >> 2] = $hook;
  HEAP32[$rt + 144208 >> 2] = $closure;
  return 1;
}

function _JS_SetDebugErrorHook($rt, $hook, $closure) {
  HEAP32[$rt + 144212 >> 2] = $hook;
  HEAP32[$rt + 144216 >> 2] = $closure;
  return 1;
}

function __ZN8JSScript7regexpsEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 18 | 0] & 255) | 0;
}

function __ZNK8JSObject8isSystemEv($this) {
  return (HEAP32[$this + 8 >> 2] & 2 | 0) != 0;
}

function __ZN8JSObject9setSystemEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function _JS_GetGlobalDebugHooks($rt) {
  return $rt + 144148 | 0;
}

function _JS_SetContextDebugHooks($cx, $hooks) {
  var $1 = $cx + 200 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = $hooks;
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10StackFrame15markReturnValueEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 262144;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK10JSFunction6nativeEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZNK2js8Bindings15countLocalNamesEv($this) {
  return (HEAPU16[$this + 6 >> 1] & 65535) + (HEAPU16[$this + 4 >> 1] & 65535) + (HEAPU16[$this + 8 >> 1] & 65535) | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv($this) {
  return (HEAP32[$this + 12 >> 2] | 0) == 0;
}

function __ZNK2js10StackFrame11hasHookDataEv($this) {
  return (HEAP32[$this >> 2] & 65536 | 0) != 0;
}

function _JS_DHashStringKey($table, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$key];
    if ($1 << 24 >> 24 == 0) {
      var $h_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $h_01 = 0;
      var $s_02 = $key;
      var $3 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $3;
    var $s_02;
    var $h_01;
    var $8 = $3 & 255 ^ ($h_01 << 4 | $h_01 >>> 28);
    var $9 = $s_02 + 1 | 0;
    var $10 = HEAPU8[$9];
    if ($10 << 24 >> 24 == 0) {
      var $h_0_lcssa = $8;
      __label__ = 3;
      break;
    } else {
      var $h_01 = $8;
      var $s_02 = $9;
      var $3 = $10;
      __label__ = 2;
      break;
    }
   case 3:
    var $h_0_lcssa;
    return $h_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetPropertyDesc($cx, $obj, $sprop, $pd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lastException = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $r = __stackBase__ + 32;
    var $4 = __stackBase__ + 40;
    var $5 = $cx;
    var $6 = $obj;
    var $7 = $sprop;
    var $8 = $7 + 12 | 0;
    var $9 = HEAP32[$8 >> 2];
    __ZN2jsL9IdToJsvalEi1067($1, $9);
    var $10 = $1 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $pd | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = __ZN9JSContext18isExceptionPendingEv($5);
    __ZN2JSL14UndefinedValueEv1068($lastException);
    if ($13) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN9JSContext19getPendingExceptionEv($lastException, $5);
    __label__ = 3;
    break;
   case 3:
    __ZN9JSContext21clearPendingExceptionEv($5);
    var $16 = HEAP32[$8 >> 2];
    var $17 = $pd + 8 | 0;
    var $18 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($5, $6, $16, $17);
    if (($18 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $21 = __ZN9JSContext18isExceptionPendingEv($5);
    var $22 = $pd + 16 | 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$22] = -128;
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $24$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $24$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $25 = $17 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    __label__ = 8;
    break;
   case 6:
    HEAP8[$22] = 64;
    __ZN9JSContext19getPendingExceptionEv($2, $5);
    var $27 = $2 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $17 | 0;
    var $st$8$0 = $29 | 0;
    HEAP32[$st$8$0 >> 2] = $28$0;
    var $st$8$1 = $29 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $28$1;
    __label__ = 8;
    break;
   case 7:
    HEAP8[$pd + 16 | 0] = 0;
    __label__ = 8;
    break;
   case 8:
    if ($13) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $lastException | 0;
    var $st$1$0 = $34 | 0;
    var $35$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $34 + 4 | 0;
    var $35$1 = HEAP32[$st$1$1 >> 2];
    var $36 = $3 | 0;
    var $st$6$0 = $36 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    var $st$6$1 = $36 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $35$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($5, $3);
    __label__ = 10;
    break;
   case 10:
    var $37 = $sprop;
    var $38 = __ZNK2js5Shape10enumerableEv($37);
    var $39 = $38 & 1;
    var $40 = __ZNK2js5Shape8writableEv($7);
    var $41 = $40 ? 0 : 2;
    var $42 = __ZNK2js5Shape12configurableEv($7);
    var $43 = $42 ? 0 : 4;
    var $44 = $pd + 16 | 0;
    var $48 = $41 | $39 | HEAP8[$44] | $43;
    HEAP8[$44] = $48;
    HEAP8[$pd + 17 | 0] = 0;
    var $50 = __ZNK2js5Shape6getterEv($37);
    if (($50 | 0) == 92) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP16[$7 + 30 >> 1];
    HEAP16[$pd + 18 >> 1] = $54;
    var $56 = $48 | 16;
    HEAP8[$44] = $56;
    __label__ = 15;
    break;
   case 12:
    if (($50 | 0) == 94) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $61 = HEAP16[$7 + 30 >> 1];
    HEAP16[$pd + 18 >> 1] = $61;
    var $63 = $48 | 32;
    HEAP8[$44] = $63;
    __label__ = 15;
    break;
   case 14:
    HEAP16[$pd + 18 >> 1] = 0;
    __label__ = 15;
    break;
   case 15:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $67$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $67$1 = HEAP32[$st$1$1 >> 2];
    var $68 = $pd + 24 | 0;
    var $st$6$0 = $68 | 0;
    HEAP32[$st$6$0 >> 2] = $67$0;
    var $st$6$1 = $68 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $67$1;
    var $69 = $7 + 24 | 0;
    var $70 = HEAP32[$69 >> 2];
    var $71 = __ZNK8JSObject12containsSlotEj($6, $70);
    if ($71) {
      __label__ = 16;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $73 = __ZNK8JSObject12lastPropertyEv($6);
    var $74 = $73;
    __ZNK2js5Shape3allEv($r, $74);
    var $75 = $r;
    __label__ = 17;
    break;
   case 17:
    var $77 = __ZNK2js5Shape5Range5emptyEv($r);
    if ($77) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $79 = __ZNK2js5Shape5Range5frontEv($75);
    if (($79 | 0) == ($37 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$79 + 24 >> 2] | 0) == (HEAP32[$69 >> 2] | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $88 = HEAP32[$79 + 12 >> 2];
    __ZN2jsL9IdToJsvalEi1067($4, $88);
    var $89 = $4 | 0;
    var $90$0 = HEAP32[$89 >> 2];
    var $90$1 = HEAP32[$89 + 4 >> 2];
    var $st$8$0 = $68 | 0;
    HEAP32[$st$8$0 >> 2] = $90$0;
    var $st$8$1 = $68 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $90$1;
    __label__ = 22;
    break;
   case 21:
    __ZN2js5Shape5Range8popFrontEv($75);
    __label__ = 17;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetPropertyDesc["X"] = 1;

function __ZN2jsL9IdToJsvalEi1067($agg_result, $id) {
  __ZN2jsL9IdToValueEi1060($agg_result, $id);
  return;
}

function __ZN2JSL14UndefinedValueEv1068($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZNK2js5Shape3allEv($agg_result, $this) {
  var $1 = $agg_result;
  var $2 = $this;
  __ZN2js5Shape5RangeC1EPKS0_($1, $2);
  return;
}

function _JS_GetPropertyDescArray($cx, $obj, $pda) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $cx;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8getClassEv($2);
    var $4 = __ZNK8JSObject8isNativeEv($2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$3 >> 2];
    _JS_ReportErrorNumber($1, 2, 0, 153, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    var $16 = HEAP32[$3 + 24 >> 2];
    var $17 = FUNCTION_TABLE[$16]($cx, $obj);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = __ZNK8JSObject11nativeEmptyEv($2);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$pda >> 2] = 0;
    HEAP32[$pda + 4 >> 2] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 7:
    var $25 = __ZNK8JSObject13propertyCountEv($obj);
    var $26 = $25 << 5;
    var $27 = __ZN9JSContext7malloc_Ej($1, $26);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = __ZNK8JSObject12lastPropertyEv($2);
    var $32 = $31;
    __ZNK2js5Shape3allEv($r, $32);
    var $33 = $r;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $35 = __ZNK2js5Shape5Range5emptyEv($r);
    if ($35) {
      var $i_1 = $i_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $28 + ($i_0 << 5) | 0;
    var $38 = $37 | 0;
    var $39 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $38, 0);
    if (($39 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $28 + ($i_0 << 5) + 8 | 0;
    var $43 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $42, 0);
    if (($43 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = __ZNK2js5Shape5Range5frontEv($33);
    var $47 = $46;
    var $48 = _JS_GetPropertyDesc($cx, $obj, $47, $37);
    if ((HEAP8[$28 + ($i_0 << 5) + 16 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $54 = $28 + ($i_0 << 5) + 24 | 0;
    var $55 = __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($1, $54, 0);
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $58 = $i_0 + 1 | 0;
    if (($58 | 0) == ($25 | 0)) {
      var $i_1 = $58;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2js5Shape5Range8popFrontEv($33);
    var $i_0 = $58;
    __label__ = 9;
    break;
   case 16:
    var $i_1;
    HEAP32[$pda >> 2] = $i_1;
    HEAP32[$pda + 4 >> 2] = $28;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 17:
    HEAP32[$pda >> 2] = $i_0 + 1 | 0;
    HEAP32[$pda + 4 >> 2] = $28;
    _JS_PutPropertyDescArray($cx, $pda);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetPropertyDescArray["X"] = 1;

function __ZNK8JSObject13propertyCountEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12lastPropertyEv($1);
  var $3 = $2;
  var $4 = __ZNK2js5Shape10entryCountEv($3);
  return $4;
}

function _JS_PutPropertyDescArray($cx, $pda) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$pda + 4 >> 2];
    var $3 = $pda | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 52 | 0;
    var $i_01 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_01;
    var $10 = $2 + ($i_01 << 5) | 0;
    var $11 = HEAP32[$6 >> 2];
    var $12 = _js_RemoveRoot($11, $10);
    var $15 = $2 + ($i_01 << 5) + 8 | 0;
    var $16 = HEAP32[$6 >> 2];
    var $17 = _js_RemoveRoot($16, $15);
    if ((HEAP8[$2 + ($i_01 << 5) + 16 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $25 = $2 + ($i_01 << 5) + 24 | 0;
    var $26 = HEAP32[$6 >> 2];
    var $27 = _js_RemoveRoot($26, $25);
    __label__ = 5;
    break;
   case 5:
    var $29 = $i_01 + 1 | 0;
    if ($29 >>> 0 < HEAPU32[$3 >> 2] >>> 0) {
      var $i_01 = $29;
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = $2;
    __ZN9JSContext5free_EPv(undef, $32);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetObjectTotalSize($cx, $obj) {
  var $1 = __ZNK8JSObject18slotsAndStructSizeEv($obj);
  return $1;
}

function __ZNK8JSObject18slotsAndStructSizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject24denseArrayHasInlineSlotsEv($1);
    if ($4) {
      var $ndslots_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSObject8numSlotsEv($1);
    var $ndslots_0 = $6;
    __label__ = 6;
    break;
   case 4:
    if ((HEAP32[$this + 32 >> 2] | 0) == 0) {
      var $ndslots_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZNK8JSObject8numSlotsEv($1);
    var $13 = __ZNK8JSObject13numFixedSlotsEv($1);
    var $ndslots_0 = $12 - $13 | 0;
    __label__ = 6;
    break;
   case 6:
    var $ndslots_0;
    var $16 = __ZNK8JSObject10structSizeEv($this);
    return $16 + ($ndslots_0 << 3) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetFunctionTotalSize($cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fun | 0;
    var $2 = _JS_GetObjectTotalSize(undef, $1);
    var $3 = $2 + 80 | 0;
    var $4 = $fun;
    var $5 = __ZNK10JSFunction13isInterpretedEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $nbytes_0 = $3;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK10JSFunction6scriptEv($4);
    var $8 = $7;
    var $9 = _JS_GetScriptTotalSize(undef, $8);
    var $nbytes_0 = $9 + $3 | 0;
    __label__ = 3;
    break;
   case 3:
    var $nbytes_0;
    var $13 = HEAP32[$fun + 72 >> 2];
    if (($13 | 0) == 0) {
      var $nbytes_1 = $nbytes_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL16GetAtomTotalSizeP9JSContextP6JSAtom($13);
    var $nbytes_1 = $16 + $nbytes_0 | 0;
    __label__ = 5;
    break;
   case 5:
    var $nbytes_1;
    return $nbytes_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetScriptTotalSize($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$script + 84 >> 2];
    if (($2 | 0) == 0) {
      var $nbytes_0 = 104;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JS_GetObjectTotalSize(undef, $2);
    var $nbytes_0 = $5 + 104 | 0;
    __label__ = 3;
    break;
   case 3:
    var $nbytes_0;
    var $11 = HEAPU32[$script + 40 >> 2];
    var $14 = HEAP32[$script + 8 >> 2] + $nbytes_0 + ($11 << 2) | 0;
    if (($11 | 0) == 0) {
      var $nbytes_1_lcssa = $14;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$script + 56 >> 2];
    var $i_04 = 0;
    var $nbytes_15 = $14;
    __label__ = 5;
    break;
   case 5:
    var $nbytes_15;
    var $i_04;
    var $20 = HEAP32[$17 + ($i_04 << 2) >> 2];
    var $21 = __ZL16GetAtomTotalSizeP9JSContextP6JSAtom($20);
    var $22 = $21 + $nbytes_15 | 0;
    var $23 = $i_04 + 1 | 0;
    if ($23 >>> 0 < $11 >>> 0) {
      var $i_04 = $23;
      var $nbytes_15 = $22;
      __label__ = 5;
      break;
    } else {
      var $nbytes_1_lcssa = $22;
      __label__ = 6;
      break;
    }
   case 6:
    var $nbytes_1_lcssa;
    var $26 = HEAP32[$script + 52 >> 2];
    if (($26 | 0) == 0) {
      var $nbytes_2 = $nbytes_1_lcssa;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = _strlen($26);
    var $nbytes_2 = $29 + ($nbytes_1_lcssa + 1) | 0;
    __label__ = 8;
    break;
   case 8:
    var $nbytes_2;
    var $33 = $script;
    var $34 = __ZN8JSScript5notesEv($33);
    var $35 = HEAP8[$34];
    if ($35 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $34;
      __label__ = 14;
      break;
    } else {
      var $sn_03 = $34;
      var $37 = $35;
      __label__ = 9;
      break;
    }
   case 9:
    var $37;
    var $sn_03;
    if (($37 & 255) > 191) {
      var $43 = 24;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $43 = ($37 & 255) >>> 3;
    __label__ = 11;
    break;
   case 11:
    var $43;
    if (HEAP8[_js_SrcNoteSpec + ($43 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $50 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = _js_SrcNoteLength($sn_03);
    var $50 = $48;
    __label__ = 13;
    break;
   case 13:
    var $50;
    var $51 = $sn_03 + $50 | 0;
    var $52 = HEAPU8[$51];
    if ($52 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $51;
      __label__ = 14;
      break;
    } else {
      var $sn_03 = $51;
      var $37 = $52;
      __label__ = 9;
      break;
    }
   case 14:
    var $sn_0_lcssa;
    var $58 = $nbytes_2 + 1 - $34 + $sn_0_lcssa | 0;
    var $60 = HEAP8[$script + 16 | 0];
    var $61 = __ZN8JSScript13isValidOffsetEh($60);
    if ($61) {
      __label__ = 15;
      break;
    } else {
      var $nbytes_4 = $58;
      __label__ = 17;
      break;
    }
   case 15:
    var $63 = __ZN8JSScript7objectsEv($33);
    var $65 = HEAP32[$63 + 4 >> 2];
    var $70 = HEAP32[$63 >> 2];
    var $i1_0 = $65;
    var $nbytes_3 = $58 + 8 + ($65 << 2) | 0;
    __label__ = 16;
    break;
   case 16:
    var $nbytes_3;
    var $i1_0;
    var $72 = $i1_0 - 1 | 0;
    var $74 = HEAP32[$70 + ($72 << 2) >> 2];
    var $75 = _JS_GetObjectTotalSize(undef, $74);
    var $76 = $75 + $nbytes_3 | 0;
    if (($72 | 0) == 0) {
      var $nbytes_4 = $76;
      __label__ = 17;
      break;
    } else {
      var $i1_0 = $72;
      var $nbytes_3 = $76;
      __label__ = 16;
      break;
    }
   case 17:
    var $nbytes_4;
    var $79 = HEAP8[$script + 18 | 0];
    var $80 = __ZN8JSScript13isValidOffsetEh($79);
    if ($80) {
      __label__ = 18;
      break;
    } else {
      var $nbytes_6 = $nbytes_4;
      __label__ = 20;
      break;
    }
   case 18:
    var $82 = __ZN8JSScript7regexpsEv($script);
    var $84 = HEAP32[$82 + 4 >> 2];
    var $89 = HEAP32[$82 >> 2];
    var $i2_0 = $84;
    var $nbytes_5 = $nbytes_4 + 8 + ($84 << 2) | 0;
    __label__ = 19;
    break;
   case 19:
    var $nbytes_5;
    var $i2_0;
    var $91 = $i2_0 - 1 | 0;
    var $93 = HEAP32[$89 + ($91 << 2) >> 2];
    var $94 = _JS_GetObjectTotalSize(undef, $93);
    var $95 = $94 + $nbytes_5 | 0;
    if (($91 | 0) == 0) {
      var $nbytes_6 = $95;
      __label__ = 20;
      break;
    } else {
      var $i2_0 = $91;
      var $nbytes_5 = $95;
      __label__ = 19;
      break;
    }
   case 20:
    var $nbytes_6;
    var $98 = HEAP8[$script + 19 | 0];
    var $99 = __ZN8JSScript13isValidOffsetEh($98);
    if ($99) {
      __label__ = 21;
      break;
    } else {
      var $nbytes_7 = $nbytes_6;
      __label__ = 22;
      break;
    }
   case 21:
    var $101 = __ZN8JSScript8trynotesEv($33);
    var $nbytes_7 = $nbytes_6 + 8 + HEAP32[$101 + 4 >> 2] * 12 | 0;
    __label__ = 22;
    break;
   case 22:
    var $nbytes_7;
    var $109 = HEAP32[$script + 76 >> 2];
    if (($109 | 0) == 0) {
      var $nbytes_8 = $nbytes_7;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $113 = HEAPU32[$109 + 12 >> 2];
    if (($113 | 0) > 1) {
      __label__ = 24;
      break;
    } else {
      var $pbytes_0 = 24;
      __label__ = 25;
      break;
    }
   case 24:
    var $116 = $113 + 23 | 0;
    var $117 = Math.floor(($116 >>> 0) / ($113 >>> 0));
    var $pbytes_0 = $117;
    __label__ = 25;
    break;
   case 25:
    var $pbytes_0;
    var $nbytes_8 = $pbytes_0 + $nbytes_7 | 0;
    __label__ = 26;
    break;
   case 26:
    var $nbytes_8;
    return $nbytes_8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetScriptTotalSize["X"] = 1;

function __ZL16GetAtomTotalSizeP9JSContextP6JSAtom($atom) {
  var $1 = $atom | 0;
  var $2 = __ZNK8JSString6lengthEv($1);
  return ($2 << 1) + 30 | 0;
}

function _JS_IsSystemObject($cx, $obj) {
  var $1 = __ZNK8JSObject8isSystemEv($obj);
  return $1 & 1;
}

function _JS_MakeSystemObject($cx, $obj) {
  __ZN8JSObject9setSystemEv($obj);
  return 1;
}

function _js_RevertVersion($cx) {
  var $1 = $cx;
  __ZN9JSContext20clearVersionOverrideEv($1);
  return;
}

function _JS_ClearContextDebugHooks($cx) {
  var $1 = _JS_SetContextDebugHooks($cx, _js_NullDebugHooks);
  return $1;
}

function _JS_PauseProfilers($profileName) {
  __ZL16ControlProfilersb(0);
  return 1;
}

function _JS_ResumeProfilers($profileName) {
  __ZL16ControlProfilersb(1);
  return 1;
}

function _JS_DumpCompartmentBytecode($cx) {
  var $3 = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  __ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE($3, $4, 13, 0, 96);
  return;
}

function __ZN2js13WatchpointMapC1Ev($this) {
  __ZN2js13WatchpointMapC2Ev($this);
  return;
}

function __ZN2js13WatchpointMapC2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK8JSObject10structSizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject10isFunctionEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject10getPrivateEv($1);
    if (($4 | 0) == 0) {
      var $11 = 80;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject13numFixedSlotsEv($1);
    var $11 = ($7 << 3) + 40 | 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape10entryCountEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this;
    var $2 = __ZNK2js5Shape8hasTableEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape8getTableEv($1);
    var $_0 = HEAP32[$4 + 4 >> 2];
    __label__ = 6;
    break;
   case 3:
    __ZNK2js5Shape3allEv($r, $this);
    var $8 = __ZNK2js5Shape5Range5emptyEv($r);
    if ($8) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $r;
    var $count_01 = 0;
    __label__ = 5;
    break;
   case 5:
    var $count_01;
    var $11 = $count_01 + 1 | 0;
    __ZN2js5Shape5Range8popFrontEv($9);
    var $12 = __ZNK2js5Shape5Range5emptyEv($r);
    if ($12) {
      var $_0 = $11;
      __label__ = 6;
      break;
    } else {
      var $count_01 = $11;
      __label__ = 5;
      break;
    }
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1079($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1081($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject1084($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv($1);
  return $2;
}

function _JS_DHashAllocTable($table, $nbytes) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($nbytes);
  return $1;
}

function _JS_DHashFreeTable($table, $ptr) {
  __ZN2js10Foreground5free_EPv($ptr);
  return;
}

function _JS_DHashFinalizeStub($table) {
  return;
}

function _JS_DHashGetStubOps() {
  return __ZL8stub_ops;
}

function _JS_DHashMatchEntryStub($table, $entry, $key) {
  return (HEAP32[$entry + 4 >> 2] | 0) == ($key | 0) & 1;
}

function _JS_DHashTableSetAlphaBounds($table, $maxAlpha, $minAlpha) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($maxAlpha < .5 | $maxAlpha >= 1 | $minAlpha < 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_02 = 16 - $maxAlpha * 16 < 1 ? .9375 : $maxAlpha;
    if ($_02 * .5 > $minAlpha) {
      var $_0 = $minAlpha;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = 1 << 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16);
    var $17 = ($15 >>> 0) * $_02;
    if ($15 >>> 0 > 511) {
      __label__ = 4;
      break;
    } else {
      var $22 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $22 = $15 >>> 8 >>> 0;
    __label__ = 5;
    break;
   case 5:
    var $22;
    var $_0 = ($17 - $22) / ($15 << 1 >>> 0);
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $28 = $_02 * 256;
    var $29 = $28 >= 0 ? Math.floor($28) : Math.ceil($28);
    HEAP8[$table + 10 | 0] = $29;
    var $31 = $_0 * 256;
    var $32 = $31 >= 0 ? Math.floor($31) : Math.ceil($31);
    HEAP8[$table + 11 | 0] = $32;
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13FindFreeEntryP12JSDHashTablej($table, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP16[$table + 8 >> 1] << 16 >> 16;
    var $4 = $keyHash >>> ($3 >>> 0);
    var $5 = $table + 28 | 0;
    var $7 = $table + 12 | 0;
    var $10 = HEAP32[$5 >> 2] + $4 * HEAP32[$7 >> 2] | 0;
    var $11 = $10;
    if ((HEAP32[$10 >> 2] | 0) == 0) {
      var $_0 = $11;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = 32 - $3 | 0;
    var $19 = $keyHash << $16 >>> ($3 >>> 0) | 1;
    var $21 = (1 << $16) - 1 | 0;
    var $entry_0 = $11;
    var $hash1_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $hash1_0;
    var $entry_0;
    var $23 = $entry_0 | 0;
    var $25 = HEAP32[$23 >> 2] | 1;
    HEAP32[$23 >> 2] = $25;
    var $27 = $hash1_0 - $19 & $21;
    var $31 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] * $27 | 0;
    var $32 = $31;
    if ((HEAP32[$31 >> 2] | 0) == 0) {
      var $_0 = $32;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $32;
      var $hash1_0 = $27;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashMatchStringKey($table, $entry, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$entry + 4 >> 2];
    if (($3 | 0) == ($key | 0)) {
      var $12 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($3 | 0) == 0 | ($key | 0) == 0) {
      var $12 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = _strcmp($3, $key);
    var $12 = ($9 | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashMoveEntryStub($table, $from, $to) {
  var $1 = $to;
  var $2 = $from;
  var $4 = HEAP32[$table + 12 >> 2];
  _memcpy($1, $2, $4, 1);
  return;
}

function _JS_DHashClearEntryStub($table, $entry) {
  var $1 = $entry;
  var $3 = HEAP32[$table + 12 >> 2];
  _memset($1, 0, $3, 1);
  return;
}

function _JS_DHashFreeStringKey($table, $entry) {
  var $3 = HEAP32[$entry + 4 >> 2];
  __ZN2js10Foreground5free_EPv($3);
  var $4 = $entry;
  var $6 = HEAP32[$table + 12 >> 2];
  _memset($4, 0, $6, 1);
  return;
}

function _JS_NewDHashTable($ops, $data, $entrySize, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11OffTheBooks7malloc_Ej(32);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JS_DHashTableInit($2, $ops, $data, $entrySize, $capacity);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $2;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableInit($table, $ops, $data, $entrySize, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$table >> 2] = $ops;
    HEAP32[$table + 4 >> 2] = $data;
    var $_01 = $capacity >>> 0 < 16 ? 16 : $capacity;
    if ($_01 >>> 0 < 2) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $_01 - 1 | 0;
    var $7 = _llvm_ctlz_i32($6);
    var $10 = 32 - $7 | 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    if (1 << $10 >>> 0 > 16777215) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP16[$table + 8 >> 1] = 32 - $10 & 65535;
    HEAP8[$table + 10 | 0] = -64;
    HEAP8[$table + 11 | 0] = 64;
    HEAP32[$table + 12 >> 2] = $entrySize;
    HEAP32[$table + 20 >> 2] = 0;
    HEAP32[$table + 16 >> 2] = 0;
    HEAP32[$table + 24 >> 2] = 0;
    var $23 = $entrySize << $10;
    var $25 = HEAP32[$ops >> 2];
    var $26 = FUNCTION_TABLE[$25]($table, $23);
    HEAP32[$table + 28 >> 2] = $26;
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _memset($26, 0, $23, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableDestroy($table) {
  _JS_DHashTableFinish($table);
  var $1 = $table;
  __ZN2js10Foreground5free_EPv($1);
  return;
}

function _JS_DHashTableFinish($table) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 24 >> 2];
    FUNCTION_TABLE[$4]($table);
    var $5 = $table + 28 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $8 = HEAPU32[$table + 12 >> 2];
    var $13 = $8 << 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16);
    var $14 = $6 + $13 | 0;
    if (($13 | 0) > 0) {
      var $entryAddr_01 = $6;
      __label__ = 2;
      break;
    } else {
      var $27 = $6;
      __label__ = 6;
      break;
    }
   case 2:
    var $entryAddr_01;
    if (HEAPU32[$entryAddr_01 >> 2] >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $23 = HEAP32[HEAP32[$1 >> 2] + 20 >> 2];
    FUNCTION_TABLE[$23]($table, $entryAddr_01);
    __label__ = 4;
    break;
   case 4:
    var $25 = $entryAddr_01 + $8 | 0;
    if ($25 >>> 0 < $14 >>> 0) {
      var $entryAddr_01 = $25;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$5 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $27;
    var $30 = HEAP32[HEAP32[$1 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$30]($table, $27);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableOperate($table, $key, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    var $5 = FUNCTION_TABLE[$4]($table, $key);
    var $6 = $5 * -1640531527 | 0;
    var $_ = $6 >>> 0 < 2 ? $6 - 2 | 0 : $6;
    var $9 = $_ & -2;
    if (($op | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 13;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 2:
    var $11 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 0);
    var $entry_0 = $11;
    __label__ = 17;
    break;
   case 3:
    var $16 = 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16) | 0;
    var $17 = 1 << $16;
    var $18 = $table + 16 | 0;
    var $20 = $table + 20 | 0;
    var $21 = HEAPU32[$20 >> 2];
    if (($21 + HEAP32[$18 >> 2] | 0) >>> 0 < (HEAPU8[$table + 10 | 0] & 255) << $16 >>> 8 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_1 = $21 >>> 0 < $17 >>> 2 >>> 0 & 1;
    var $32 = __ZL11ChangeTableP12JSDHashTablei($table, $_1);
    if (($32 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if ((HEAP32[$20 >> 2] + HEAP32[$18 >> 2] | 0) == ($17 - 1 | 0)) {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $41 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 1);
    var $42 = $41 | 0;
    var $43 = HEAPU32[$42 >> 2];
    if ($43 >>> 0 > 1) {
      var $entry_0 = $41;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($43 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $keyHash_1 = $9;
      __label__ = 9;
      break;
    }
   case 8:
    var $49 = HEAP32[$20 >> 2] - 1 | 0;
    HEAP32[$20 >> 2] = $49;
    var $keyHash_1 = $_ | 1;
    __label__ = 9;
    break;
   case 9:
    var $keyHash_1;
    var $54 = HEAP32[HEAP32[$1 >> 2] + 28 >> 2];
    if (($54 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $57 = FUNCTION_TABLE[$54]($table, $41, $key);
    if (($57 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $61 = $41 + 4 | 0;
    var $64 = HEAP32[$table + 12 >> 2] - 4 | 0;
    _memset($61, 0, $64, 1);
    var $entry_0 = 0;
    __label__ = 17;
    break;
   case 12:
    HEAP32[$42 >> 2] = $keyHash_1;
    var $67 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $67;
    var $entry_0 = $41;
    __label__ = 17;
    break;
   case 13:
    var $69 = __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $9, 2);
    if (HEAPU32[$69 >> 2] >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 14:
    _JS_DHashTableRawRemove($table, $69);
    var $77 = 32 - (HEAP16[$table + 8 >> 1] << 16 >> 16) | 0;
    if (1 << $77 >>> 0 > 16) {
      __label__ = 15;
      break;
    } else {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    if (HEAPU32[$table + 16 >> 2] >>> 0 > (HEAPU8[$table + 11 | 0] & 255) << $77 >>> 8 >>> 0) {
      var $entry_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $90 = __ZL11ChangeTableP12JSDHashTablei($table, -1);
    var $entry_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $entry_0;
    return $entry_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DHashTableOperate["X"] = 1;

function __ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator($table, $key, $keyHash, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table + 8 | 0;
    var $2 = HEAPU16[$1 >> 1];
    var $3 = $2 << 16 >> 16;
    var $4 = $keyHash >>> ($3 >>> 0);
    var $5 = $table + 28 | 0;
    var $7 = $table + 12 | 0;
    var $10 = HEAP32[$5 >> 2] + $4 * HEAP32[$7 >> 2] | 0;
    var $11 = $10;
    var $13 = HEAP32[$10 >> 2];
    if (($13 | 0) == 0) {
      var $_0 = $11;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = HEAPU32[HEAP32[$table >> 2] + 12 >> 2];
    if (($13 & -2 | 0) == ($keyHash | 0)) {
      __label__ = 3;
      break;
    } else {
      var $26 = $2;
      __label__ = 5;
      break;
    }
   case 3:
    var $23 = FUNCTION_TABLE[$19]($table, $11, $key);
    if (($23 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $11;
      __label__ = 16;
      break;
    }
   case 4:
    var $26 = HEAP16[$1 >> 1];
    __label__ = 5;
    break;
   case 5:
    var $26;
    var $28 = 32 - ($26 << 16 >> 16) | 0;
    var $31 = $keyHash << $28 >>> ($3 >>> 0) | 1;
    var $33 = (1 << $28) - 1 | 0;
    var $34 = ($op | 0) == 1;
    var $firstRemoved_0 = 0;
    var $entry_0 = $11;
    var $hash1_0 = $4;
    __label__ = 6;
    break;
   case 6:
    var $hash1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $35 = $entry_0 | 0;
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      __label__ = 11;
      break;
    }
   case 8:
    var $firstRemoved_1 = $entry_0;
    __label__ = 11;
    break;
   case 9:
    if ($34) {
      __label__ = 10;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = $36 | 1;
    HEAP32[$35 >> 2] = $43;
    var $firstRemoved_1 = $firstRemoved_0;
    __label__ = 11;
    break;
   case 11:
    var $firstRemoved_1;
    var $45 = $hash1_0 - $31 & $33;
    var $49 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] * $45 | 0;
    var $50 = $49;
    var $52 = HEAP32[$49 >> 2];
    if (($52 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (($firstRemoved_1 | 0) == 0) {
      var $_0 = $50;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $phitmp = $34 ? $firstRemoved_1 : $50;
    var $_0 = $phitmp;
    __label__ = 16;
    break;
   case 14:
    if (($52 & -2 | 0) == ($keyHash | 0)) {
      __label__ = 15;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $50;
      var $hash1_0 = $45;
      __label__ = 6;
      break;
    }
   case 15:
    var $61 = FUNCTION_TABLE[$19]($table, $50, $key);
    if (($61 | 0) == 0) {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $50;
      var $hash1_0 = $45;
      __label__ = 6;
      break;
    } else {
      var $_0 = $50;
      __label__ = 16;
      break;
    }
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator["X"] = 1;

function __ZL11ChangeTableP12JSDHashTablei($table, $deltaLog2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $table + 8 | 0;
    var $4 = 32 - (HEAP16[$1 >> 1] << 16 >> 16) | 0;
    var $5 = $4 + $deltaLog2 | 0;
    var $6 = 1 << $4;
    if (1 << $5 >>> 0 > 16777215) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAPU32[$table + 12 >> 2];
    var $12 = $11 << $5;
    var $13 = $table | 0;
    var $16 = HEAP32[HEAP32[$13 >> 2] >> 2];
    var $17 = FUNCTION_TABLE[$16]($table, $12);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = 32 - $5 & 65535;
    HEAP16[$1 >> 1] = $21;
    HEAP32[$table + 20 >> 2] = 0;
    var $23 = $table + 24 | 0;
    var $25 = HEAP32[$23 >> 2] + 1 | 0;
    HEAP32[$23 >> 2] = $25;
    _memset($17, 0, $12, 1);
    var $26 = $table + 28 | 0;
    var $27 = HEAPU32[$26 >> 2];
    HEAP32[$26 >> 2] = $17;
    var $30 = HEAP32[HEAP32[$13 >> 2] + 16 >> 2];
    var $oldEntryAddr_01 = $27;
    var $i_02 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_02;
    var $oldEntryAddr_01;
    var $32 = $oldEntryAddr_01;
    var $33 = HEAPU32[$32 >> 2];
    if ($33 >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $36 = $oldEntryAddr_01;
    var $37 = $33 & -2;
    HEAP32[$32 >> 2] = $37;
    var $38 = __ZL13FindFreeEntryP12JSDHashTablej($table, $37);
    FUNCTION_TABLE[$30]($table, $36, $38);
    var $39 = HEAP32[$32 >> 2];
    HEAP32[$38 >> 2] = $39;
    __label__ = 6;
    break;
   case 6:
    var $43 = $i_02 + 1 | 0;
    if ($43 >>> 0 < $6 >>> 0) {
      var $oldEntryAddr_01 = $oldEntryAddr_01 + $11 | 0;
      var $i_02 = $43;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $48 = HEAP32[HEAP32[$13 >> 2] + 4 >> 2];
    FUNCTION_TABLE[$48]($table, $27);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ChangeTableP12JSDHashTablei["X"] = 1;

function _JS_DHashTableRawRemove($table, $entry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $entry | 0;
    var $2 = HEAP32[$1 >> 2];
    var $6 = HEAP32[HEAP32[$table >> 2] + 20 >> 2];
    FUNCTION_TABLE[$6]($table, $entry);
    if (($2 & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    var $10 = $table + 20 | 0;
    var $12 = HEAP32[$10 >> 2] + 1 | 0;
    HEAP32[$10 >> 2] = $12;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$1 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $15 = $table + 16 | 0;
    var $17 = HEAP32[$15 >> 2] - 1 | 0;
    HEAP32[$15 >> 2] = $17;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_DHashTableEnumerate($table, $etor, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$table + 28 >> 2];
    var $4 = HEAPU32[$table + 12 >> 2];
    var $5 = $table + 8 | 0;
    var $8 = 32 - (HEAP16[$5 >> 1] << 16 >> 16) | 0;
    var $9 = 1 << $8;
    var $11 = $2 + ($4 << $8) | 0;
    var $didRemove_0 = 0;
    var $i_0 = 0;
    var $entryAddr_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $entryAddr_0;
    var $i_0;
    var $didRemove_0;
    if ($entryAddr_0 >>> 0 < $11 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $didRemove_3 = $didRemove_0;
      var $i_2 = $i_0;
      __label__ = 8;
      break;
    }
   case 3:
    var $15 = $entryAddr_0;
    if (HEAPU32[$entryAddr_0 >> 2] >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $didRemove_2 = $didRemove_0;
      var $i_1 = $i_0;
      __label__ = 7;
      break;
    }
   case 4:
    var $20 = $i_0 + 1 | 0;
    var $21 = FUNCTION_TABLE[$etor]($table, $15, $i_0, $arg);
    if (($21 & 2 | 0) == 0) {
      var $didRemove_1 = $didRemove_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_DHashTableRawRemove($table, $15);
    var $didRemove_1 = 1;
    __label__ = 6;
    break;
   case 6:
    var $didRemove_1;
    if (($21 & 1 | 0) == 0) {
      var $didRemove_2 = $didRemove_1;
      var $i_1 = $20;
      __label__ = 7;
      break;
    } else {
      var $didRemove_3 = $didRemove_1;
      var $i_2 = $20;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_1;
    var $didRemove_2;
    var $didRemove_0 = $didRemove_2;
    var $i_0 = $i_1;
    var $entryAddr_0 = $entryAddr_0 + $4 | 0;
    __label__ = 2;
    break;
   case 8:
    var $i_2;
    var $didRemove_3;
    if (($didRemove_3 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (HEAPU32[$table + 20 >> 2] >>> 0 < $9 >>> 2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = HEAP32[$table + 16 >> 2];
    __label__ = 13;
    break;
   case 11:
    if ($9 >>> 0 > 16) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $41 = HEAPU32[$table + 16 >> 2];
    if ($41 >>> 0 > (HEAPU8[$table + 11 | 0] & 255) << $8 >>> 8 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $49 = $41;
      __label__ = 13;
      break;
    }
   case 13:
    var $49;
    var $51 = ($49 >>> 1) + $49 | 0;
    var $capacity_0 = $51 >>> 0 < 16 ? 16 : $51;
    if ($capacity_0 >>> 0 < 2) {
      var $58 = -32;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = _llvm_ctlz_i32($capacity_0 - 1 | 0);
    var $58 = 32 - $56 - 32 | 0;
    __label__ = 15;
    break;
   case 15:
    var $58;
    var $61 = $58 + (HEAP16[$5 >> 1] << 16 >> 16) | 0;
    var $62 = __ZL11ChangeTableP12JSDHashTablei($table, $61);
    __label__ = 16;
    break;
   case 16:
    return $i_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_DHashTableEnumerate["X"] = 1;

function _js_strtod_harder($state, $s00, $se, $err) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($err | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$err >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $4 = __strtod($state, $s00, $se);
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __strtod($state, $s00, $se) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bbe = __stackBase__;
    var $bbbits = __stackBase__ + 4;
    var $s_0 = $s00;
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    var $2 = HEAP8[$s_0];
    var $3 = $2 << 24 >> 24;
    if (($3 | 0) == 45) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 43) {
      var $sign_0 = 0;
      __label__ = 4;
      break;
    } else if (($3 | 0) == 9 || ($3 | 0) == 10 || ($3 | 0) == 11 || ($3 | 0) == 12 || ($3 | 0) == 13 || ($3 | 0) == 32) {
      __label__ = 5;
      break;
    } else if (($3 | 0) == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      var $sign_1 = 0;
      var $s_1 = $s_0;
      var $9 = $2;
      __label__ = 6;
      break;
    }
   case 3:
    var $sign_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $sign_0;
    var $4 = $s_0 + 1 | 0;
    var $5 = HEAP8[$4];
    if ($5 << 24 >> 24 == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      var $sign_1 = $sign_0;
      var $s_1 = $4;
      var $9 = $5;
      __label__ = 6;
      break;
    }
   case 5:
    var $s_0 = $s_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $9;
    var $s_1;
    var $sign_1;
    if ($9 << 24 >> 24 == 48) {
      var $s_2 = $s_1;
      __label__ = 7;
      break;
    } else {
      var $nz0_0 = 0;
      var $s_3 = $s_1;
      var $13 = $9;
      __label__ = 8;
      break;
    }
   case 7:
    var $s_2;
    var $11 = $s_2 + 1 | 0;
    var $12 = HEAP8[$11];
    if ($12 << 24 >> 24 == 48) {
      var $s_2 = $11;
      __label__ = 7;
      break;
    } else if ($12 << 24 >> 24 == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $11;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $nz0_0 = 1;
      var $s_3 = $11;
      var $13 = $12;
      __label__ = 8;
      break;
    }
   case 8:
    var $13;
    var $s_3;
    var $nz0_0;
    var $14 = $13 << 24 >> 24;
    if (($13 - 48 & 255 & 255) < 10) {
      var $z_0202 = 0;
      var $y_0203 = 0;
      var $s_4204 = $s_3;
      var $nd_0205 = 0;
      var $16 = $14;
      __label__ = 9;
      break;
    } else {
      var $z_0_lcssa = 0;
      var $y_0_lcssa = 0;
      var $s_4_lcssa = $s_3;
      var $nd_0_lcssa = 0;
      var $_lcssa199 = $13;
      var $_lcssa200 = $14;
      __label__ = 14;
      break;
    }
   case 9:
    var $16;
    var $nd_0205;
    var $s_4204;
    var $y_0203;
    var $z_0202;
    if (($nd_0205 | 0) < 9) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $y_1 = $y_0203 * 10 - 48 + $16 | 0;
    var $z_1 = $z_0202;
    __label__ = 13;
    break;
   case 11:
    if (($nd_0205 | 0) < 16) {
      __label__ = 12;
      break;
    } else {
      var $y_1 = $y_0203;
      var $z_1 = $z_0202;
      __label__ = 13;
      break;
    }
   case 12:
    var $y_1 = $y_0203;
    var $z_1 = $z_0202 * 10 - 48 + $16 | 0;
    __label__ = 13;
    break;
   case 13:
    var $z_1;
    var $y_1;
    var $29 = $nd_0205 + 1 | 0;
    var $30 = $s_4204 + 1 | 0;
    var $31 = HEAPU8[$30];
    var $32 = $31 << 24 >> 24;
    if (($31 - 48 & 255 & 255) < 10) {
      var $z_0202 = $z_1;
      var $y_0203 = $y_1;
      var $s_4204 = $30;
      var $nd_0205 = $29;
      var $16 = $32;
      __label__ = 9;
      break;
    } else {
      var $z_0_lcssa = $z_1;
      var $y_0_lcssa = $y_1;
      var $s_4_lcssa = $30;
      var $nd_0_lcssa = $29;
      var $_lcssa199 = $31;
      var $_lcssa200 = $32;
      __label__ = 14;
      break;
    }
   case 14:
    var $_lcssa200;
    var $_lcssa199;
    var $nd_0_lcssa;
    var $s_4_lcssa;
    var $y_0_lcssa;
    var $z_0_lcssa;
    if ($_lcssa199 << 24 >> 24 == 46) {
      __label__ = 15;
      break;
    } else {
      var $c_3 = $_lcssa200;
      var $nd_5 = $nd_0_lcssa;
      var $nf_3 = 0;
      var $nz_4 = 0;
      var $s_8 = $s_4_lcssa;
      var $s0_2 = $s_3;
      var $y_8 = $y_0_lcssa;
      var $z_8 = $z_0_lcssa;
      __label__ = 35;
      break;
    }
   case 15:
    var $36 = $s_4_lcssa + 1 | 0;
    var $37 = HEAP8[$36];
    var $38 = $37 << 24 >> 24;
    if (($nd_0_lcssa | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $c_1 = $38;
      var $nd_1 = $nd_0_lcssa;
      var $nf_0 = 0;
      var $nz_1 = 0;
      var $s_6 = $36;
      var $s0_0 = $s_3;
      var $y_2 = $y_0_lcssa;
      var $z_2 = $z_0_lcssa;
      __label__ = 20;
      break;
    }
   case 16:
    if ($37 << 24 >> 24 == 48) {
      var $s_5192 = $36;
      var $nz_0193 = 0;
      __label__ = 17;
      break;
    } else {
      var $s_5_lcssa = $36;
      var $nz_0_lcssa = 0;
      var $c_0_lcssa = $38;
      __label__ = 19;
      break;
    }
   case 17:
    var $nz_0193;
    var $s_5192;
    var $41 = $nz_0193 + 1 | 0;
    var $42 = $s_5192 + 1 | 0;
    var $43 = HEAP8[$42];
    if ($43 << 24 >> 24 == 48) {
      var $s_5192 = $42;
      var $nz_0193 = $41;
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $s_5_lcssa = $42;
    var $nz_0_lcssa = $41;
    var $c_0_lcssa = $43 << 24 >> 24;
    __label__ = 19;
    break;
   case 19:
    var $c_0_lcssa;
    var $nz_0_lcssa;
    var $s_5_lcssa;
    if (($c_0_lcssa - 49 | 0) >>> 0 < 9) {
      var $c_2 = $c_0_lcssa;
      var $nd_2 = $nd_0_lcssa;
      var $nf_1 = $nz_0_lcssa;
      var $nz_2 = 0;
      var $s_7 = $s_5_lcssa;
      var $s0_1 = $s_5_lcssa;
      var $y_3 = $y_0_lcssa;
      var $z_3 = $z_0_lcssa;
      __label__ = 21;
      break;
    } else {
      var $c_3 = $c_0_lcssa;
      var $nd_5 = $nd_0_lcssa;
      var $nf_3 = 0;
      var $nz_4 = $nz_0_lcssa;
      var $s_8 = $s_5_lcssa;
      var $s0_2 = $s_3;
      var $y_8 = $y_0_lcssa;
      var $z_8 = $z_0_lcssa;
      __label__ = 35;
      break;
    }
   case 20:
    var $z_2;
    var $y_2;
    var $s0_0;
    var $s_6;
    var $nz_1;
    var $nf_0;
    var $nd_1;
    var $c_1;
    if (($c_1 - 48 | 0) >>> 0 < 10) {
      var $c_2 = $c_1;
      var $nd_2 = $nd_1;
      var $nf_1 = $nf_0;
      var $nz_2 = $nz_1;
      var $s_7 = $s_6;
      var $s0_1 = $s0_0;
      var $y_3 = $y_2;
      var $z_3 = $z_2;
      __label__ = 21;
      break;
    } else {
      var $c_3 = $c_1;
      var $nd_5 = $nd_1;
      var $nf_3 = $nf_0;
      var $nz_4 = $nz_1;
      var $s_8 = $s_6;
      var $s0_2 = $s0_0;
      var $y_8 = $y_2;
      var $z_8 = $z_2;
      __label__ = 35;
      break;
    }
   case 21:
    var $z_3;
    var $y_3;
    var $s0_1;
    var $s_7;
    var $nz_2;
    var $nf_1;
    var $nd_2;
    var $c_2;
    var $51 = $nz_2 + 1 | 0;
    var $52 = $c_2 - 48 | 0;
    if (($52 | 0) == 0) {
      var $nd_4 = $nd_2;
      var $nf_2 = $nf_1;
      var $nz_3 = $51;
      var $y_7 = $y_3;
      var $z_7 = $z_3;
      __label__ = 34;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $55 = $nf_1 + $51 | 0;
    var $57 = $nd_2 + 1 | 0;
    var $58 = ($nd_2 | 0) < 9;
    if (($nz_2 | 0) > 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 23:
    var $smax = ($51 | 0) > 2 ? $51 : 2;
    var $z_4117 = $z_3;
    var $y_4118 = $y_3;
    var $i_0119 = 1;
    var $62 = $57;
    var $61 = $58;
    __label__ = 24;
    break;
   case 24:
    var $61;
    var $62;
    var $i_0119;
    var $y_4118;
    var $z_4117;
    if ($61) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $y_5 = $y_4118 * 10 | 0;
    var $z_5 = $z_4117;
    __label__ = 28;
    break;
   case 26:
    if (($62 | 0) < 17) {
      __label__ = 27;
      break;
    } else {
      var $y_5 = $y_4118;
      var $z_5 = $z_4117;
      __label__ = 28;
      break;
    }
   case 27:
    var $y_5 = $y_4118;
    var $z_5 = $z_4117 * 10 | 0;
    __label__ = 28;
    break;
   case 28:
    var $z_5;
    var $y_5;
    var $70 = $i_0119 + 1 | 0;
    var $73 = ($62 | 0) < 9;
    if (($70 | 0) < ($51 | 0)) {
      var $z_4117 = $z_5;
      var $y_4118 = $y_5;
      var $i_0119 = $70;
      var $62 = $62 + 1 | 0;
      var $61 = $73;
      __label__ = 24;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $74 = $nd_2 + $smax | 0;
    if ($73) {
      var $_lcssa287 = $74;
      var $y_4_lcssa288 = $y_5;
      var $z_4_lcssa291 = $z_5;
      __label__ = 31;
      break;
    } else {
      var $_lcssa286 = $74;
      var $y_4_lcssa289 = $y_5;
      var $z_4_lcssa290 = $z_5;
      __label__ = 32;
      break;
    }
   case 30:
    if ($58) {
      var $_lcssa287 = $57;
      var $y_4_lcssa288 = $y_3;
      var $z_4_lcssa291 = $z_3;
      __label__ = 31;
      break;
    } else {
      var $_lcssa286 = $57;
      var $y_4_lcssa289 = $y_3;
      var $z_4_lcssa290 = $z_3;
      __label__ = 32;
      break;
    }
   case 31:
    var $z_4_lcssa291;
    var $y_4_lcssa288;
    var $_lcssa287;
    var $nd_4 = $_lcssa287;
    var $nf_2 = $55;
    var $nz_3 = 0;
    var $y_7 = $y_4_lcssa288 * 10 + $52 | 0;
    var $z_7 = $z_4_lcssa291;
    __label__ = 34;
    break;
   case 32:
    var $z_4_lcssa290;
    var $y_4_lcssa289;
    var $_lcssa286;
    if (($_lcssa286 | 0) < 17) {
      __label__ = 33;
      break;
    } else {
      var $nd_4 = $_lcssa286;
      var $nf_2 = $55;
      var $nz_3 = 0;
      var $y_7 = $y_4_lcssa289;
      var $z_7 = $z_4_lcssa290;
      __label__ = 34;
      break;
    }
   case 33:
    var $nd_4 = $_lcssa286;
    var $nf_2 = $55;
    var $nz_3 = 0;
    var $y_7 = $y_4_lcssa289;
    var $z_7 = $z_4_lcssa290 * 10 + $52 | 0;
    __label__ = 34;
    break;
   case 34:
    var $z_7;
    var $y_7;
    var $nz_3;
    var $nf_2;
    var $nd_4;
    var $85 = $s_7 + 1 | 0;
    var $c_1 = HEAP8[$85] << 24 >> 24;
    var $nd_1 = $nd_4;
    var $nf_0 = $nf_2;
    var $nz_1 = $nz_3;
    var $s_6 = $85;
    var $s0_0 = $s0_1;
    var $y_2 = $y_7;
    var $z_2 = $z_7;
    __label__ = 20;
    break;
   case 35:
    var $z_8;
    var $y_8;
    var $s0_2;
    var $s_8;
    var $nz_4;
    var $nf_3;
    var $nd_5;
    var $c_3;
    if (($c_3 | 0) == 101 || ($c_3 | 0) == 69) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $s00;
      var $e_1 = 0;
      var $s_12 = $s_8;
      __label__ = 48;
      break;
    }
   case 36:
    if (($nz_4 | $nz0_0 | $nd_5 | 0) == 0) {
      var $_1 = $s00;
      __label__ = 50;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $93 = $s_8 + 1 | 0;
    var $95 = HEAP8[$93] << 24 >> 24;
    if (($95 | 0) == 45) {
      __label__ = 38;
      break;
    } else if (($95 | 0) == 43) {
      var $esign_0 = 0;
      __label__ = 39;
      break;
    } else {
      var $c_4 = $95;
      var $esign_1 = 0;
      var $s_9 = $93;
      __label__ = 40;
      break;
    }
   case 38:
    var $esign_0 = 1;
    __label__ = 39;
    break;
   case 39:
    var $esign_0;
    var $98 = $s_8 + 2 | 0;
    var $c_4 = HEAP8[$98] << 24 >> 24;
    var $esign_1 = $esign_0;
    var $s_9 = $98;
    __label__ = 40;
    break;
   case 40:
    var $s_9;
    var $esign_1;
    var $c_4;
    if (($c_4 - 48 | 0) >>> 0 < 10) {
      __label__ = 41;
      break;
    } else {
      var $_0 = $s_8;
      var $e_1 = 0;
      var $s_12 = $s_8;
      __label__ = 48;
      break;
    }
   case 41:
    if (($c_4 | 0) == 48) {
      var $s_10131 = $s_9;
      __label__ = 42;
      break;
    } else {
      var $s_10_lcssa = $s_9;
      var $c_5_lcssa = $c_4;
      __label__ = 44;
      break;
    }
   case 42:
    var $s_10131;
    var $104 = $s_10131 + 1 | 0;
    var $105 = HEAP8[$104];
    if ($105 << 24 >> 24 == 48) {
      var $s_10131 = $104;
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $s_10_lcssa = $104;
    var $c_5_lcssa = $105 << 24 >> 24;
    __label__ = 44;
    break;
   case 44:
    var $c_5_lcssa;
    var $s_10_lcssa;
    if (($c_5_lcssa - 49 | 0) >>> 0 < 9) {
      __label__ = 45;
      break;
    } else {
      var $_0 = $s_8;
      var $e_1 = 0;
      var $s_12 = $s_10_lcssa;
      __label__ = 48;
      break;
    }
   case 45:
    var $L_0124 = $c_5_lcssa - 48 | 0;
    var $110 = $s_10_lcssa + 1 | 0;
    var $111 = HEAPU8[$110];
    if (($111 - 48 & 255 & 255) < 10) {
      var $L_0126 = $L_0124;
      var $114 = $110;
      var $113 = $111;
      __label__ = 46;
      break;
    } else {
      var $L_0_lcssa = $L_0124;
      var $_lcssa123 = $110;
      __label__ = 47;
      break;
    }
   case 46:
    var $113;
    var $114;
    var $L_0126;
    var $L_0 = ($113 << 24 >> 24) + $L_0126 * 10 - 48 | 0;
    var $118 = $114 + 1 | 0;
    var $119 = HEAPU8[$118];
    if (($119 - 48 & 255 & 255) < 10) {
      var $L_0126 = $L_0;
      var $114 = $118;
      var $113 = $119;
      __label__ = 46;
      break;
    } else {
      var $L_0_lcssa = $L_0;
      var $_lcssa123 = $118;
      __label__ = 47;
      break;
    }
   case 47:
    var $_lcssa123;
    var $L_0_lcssa;
    var $e_0 = ($_lcssa123 - $s_10_lcssa | 0) > 8 | ($L_0_lcssa | 0) > 19999 ? 19999 : $L_0_lcssa;
    var $e_0_ = ($esign_1 | 0) == 0 ? $e_0 : -$e_0 | 0;
    var $_0 = $s_8;
    var $e_1 = $e_0_;
    var $s_12 = $_lcssa123;
    __label__ = 48;
    break;
   case 48:
    var $s_12;
    var $e_1;
    var $_0;
    if (($nd_5 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 49:
    if (($nz_4 | $nz0_0 | 0) == 0) {
      var $_1 = $_0;
      __label__ = 50;
      break;
    } else {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    }
   case 50:
    var $_1;
    var $sign_2 = 0;
    var $s_13 = $_1;
    var $rv_16$1 = 0;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 51:
    var $134 = $e_1 - $nf_3 | 0;
    var $nd0_0 = ($nd_0_lcssa | 0) == 0 ? $nd_5 : $nd_0_lcssa;
    var $136 = ($nd_5 | 0) < 16;
    var $137 = $136 ? $nd_5 : 16;
    var $138 = $y_8 >>> 0;
    if (($137 | 0) > 9) {
      __label__ = 52;
      break;
    } else {
      var $rv_0_in = $138;
      __label__ = 53;
      break;
    }
   case 52:
    var $142 = _tens + ($137 - 9 << 3) | 0;
    var $143 = (tempDoubleI32[0] = HEAP32[$142 >> 2], tempDoubleI32[1] = HEAP32[$142 + 4 >> 2], tempDoubleF64[0]);
    var $rv_0_in = $143 * $138 + ($z_8 >>> 0);
    __label__ = 53;
    break;
   case 53:
    var $rv_0_in;
    tempDoubleF64[0] = $rv_0_in;
    var $rv_0$0 = tempDoubleI32[0];
    var $rv_0$1 = tempDoubleI32[1];
    if ($136) {
      __label__ = 54;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 54:
    if (($e_1 | 0) == ($nf_3 | 0)) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = $rv_0$1;
      var $rv_16$0 = $rv_0$0;
      __label__ = 165;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    if (($134 | 0) > 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 56:
    if (($134 | 0) < 23) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $155 = _tens + ($134 << 3) | 0;
    var $156 = (tempDoubleI32[0] = HEAP32[$155 >> 2], tempDoubleI32[1] = HEAP32[$155 + 4 >> 2], tempDoubleF64[0]);
    var $157 = $rv_0_in * $156;
    tempDoubleF64[0] = $157;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 58:
    var $160 = 15 - $nd_5 | 0;
    if (($134 | 0) > ($160 + 22 | 0)) {
      __label__ = 62;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $165 = _tens + ($160 << 3) | 0;
    var $166 = (tempDoubleI32[0] = HEAP32[$165 >> 2], tempDoubleI32[1] = HEAP32[$165 + 4 >> 2], tempDoubleF64[0]);
    var $167 = $rv_0_in * $166;
    var $168 = _tens + ($134 - $160 << 3) | 0;
    var $169 = (tempDoubleI32[0] = HEAP32[$168 >> 2], tempDoubleI32[1] = HEAP32[$168 + 4 >> 2], tempDoubleF64[0]);
    var $170 = $167 * $169;
    tempDoubleF64[0] = $170;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 60:
    if (($134 | 0) > -23) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $176 = _tens + (-$134 << 3) | 0;
    var $177 = (tempDoubleI32[0] = HEAP32[$176 >> 2], tempDoubleI32[1] = HEAP32[$176 + 4 >> 2], tempDoubleF64[0]);
    var $178 = $rv_0_in / $177;
    tempDoubleF64[0] = $178;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = tempDoubleI32[1];
    var $rv_16$0 = tempDoubleI32[0];
    __label__ = 165;
    break;
   case 62:
    var $182 = $134 + ($nd_5 - $137) | 0;
    if (($182 | 0) > 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 63:
    var $185 = $182 & 15;
    if (($185 | 0) == 0) {
      var $rv_1$1 = $rv_0$1;
      var $rv_1$0 = $rv_0$0;
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $188 = _tens + ($185 << 3) | 0;
    var $189 = (tempDoubleI32[0] = HEAP32[$188 >> 2], tempDoubleI32[1] = HEAP32[$188 + 4 >> 2], tempDoubleF64[0]);
    var $190 = $rv_0_in * $189;
    tempDoubleF64[0] = $190;
    var $rv_1$1 = tempDoubleI32[1];
    var $rv_1$0 = tempDoubleI32[0];
    __label__ = 65;
    break;
   case 65:
    var $rv_1$0;
    var $rv_1$1;
    var $193 = $182 & -16;
    if (($193 | 0) == 0) {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_1$1;
      var $rv_9$0 = $rv_1$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    if (($193 | 0) > 308) {
      __label__ = 67;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 67:
    var $197 = ___errno();
    HEAP32[$197 >> 2] = 34;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = 2146435072;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 68:
    var $199 = ___errno();
    HEAP32[$199 >> 2] = 34;
    if (($298 | 0) == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 2146435072;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $delta_4 = $361;
      var $rv_15$1 = 2146435072;
      var $rv_15$0 = 0;
      __label__ = 164;
      break;
    }
   case 69:
    var $202 = $182 >> 4;
    if (($202 | 0) > 1) {
      var $rv_3143$1 = $rv_1$1;
      var $rv_3143$0 = $rv_1$0;
      var $j_0144 = 0;
      var $e1_0145 = $202;
      __label__ = 70;
      break;
    } else {
      var $rv_3_lcssa$1 = $rv_1$1;
      var $rv_3_lcssa$0 = $rv_1$0;
      var $j_0_lcssa = 0;
      __label__ = 73;
      break;
    }
   case 70:
    var $e1_0145;
    var $j_0144;
    var $rv_3143$0;
    var $rv_3143$1;
    if (($e1_0145 & 1 | 0) == 0) {
      var $rv_4$1 = $rv_3143$1;
      var $rv_4$0 = $rv_3143$0;
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $207 = _bigtens + ($j_0144 << 3) | 0;
    var $208 = (tempDoubleI32[0] = HEAP32[$207 >> 2], tempDoubleI32[1] = HEAP32[$207 + 4 >> 2], tempDoubleF64[0]);
    var $209 = (tempDoubleI32[0] = $rv_3143$0, tempDoubleI32[1] = $rv_3143$1, tempDoubleF64[0]);
    var $210 = $209 * $208;
    tempDoubleF64[0] = $210;
    var $rv_4$1 = tempDoubleI32[1];
    var $rv_4$0 = tempDoubleI32[0];
    __label__ = 72;
    break;
   case 72:
    var $rv_4$0;
    var $rv_4$1;
    var $213 = $j_0144 + 1 | 0;
    var $214 = $e1_0145 >> 1;
    if (($214 | 0) > 1) {
      var $rv_3143$1 = $rv_4$1;
      var $rv_3143$0 = $rv_4$0;
      var $j_0144 = $213;
      var $e1_0145 = $214;
      __label__ = 70;
      break;
    } else {
      var $rv_3_lcssa$1 = $rv_4$1;
      var $rv_3_lcssa$0 = $rv_4$0;
      var $j_0_lcssa = $213;
      __label__ = 73;
      break;
    }
   case 73:
    var $j_0_lcssa;
    var $rv_3_lcssa$0;
    var $rv_3_lcssa$1;
    var $221 = _bigtens + ($j_0_lcssa << 3) | 0;
    var $222 = (tempDoubleI32[0] = HEAP32[$221 >> 2], tempDoubleI32[1] = HEAP32[$221 + 4 >> 2], tempDoubleF64[0]);
    var $223 = (tempDoubleI32[0] = 0 | $rv_3_lcssa$0 & -1, tempDoubleI32[1] = $rv_3_lcssa$1 - 55574528 | $rv_3_lcssa$1 & 0, tempDoubleF64[0]);
    var $224 = $223 * $222;
    tempDoubleF64[0] = $224;
    var $225$0 = tempDoubleI32[0];
    var $225$1 = tempDoubleI32[1];
    var $227 = $225$1;
    var $228 = $227 & 2146435072;
    if ($228 >>> 0 > 2090860544) {
      __label__ = 67;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    if ($228 >>> 0 > 2089811968) {
      var $scale_1 = 0;
      var $rv_9$1 = 2146435071;
      var $rv_9$0 = -1;
      __label__ = 94;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $scale_1 = 0;
    var $rv_9$1 = $227 + 55574528 | $225$1 & 0;
    var $rv_9$0 = 0 | $225$0 & -1;
    __label__ = 94;
    break;
   case 76:
    if (($182 | 0) < 0) {
      __label__ = 77;
      break;
    } else {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_0$1;
      var $rv_9$0 = $rv_0$0;
      __label__ = 94;
      break;
    }
   case 77:
    var $239 = -$182 | 0;
    var $240 = $239 & 15;
    if (($240 | 0) == 0) {
      var $rv_5$1 = $rv_0$1;
      var $rv_5$0 = $rv_0$0;
      __label__ = 79;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $243 = _tens + ($240 << 3) | 0;
    var $244 = (tempDoubleI32[0] = HEAP32[$243 >> 2], tempDoubleI32[1] = HEAP32[$243 + 4 >> 2], tempDoubleF64[0]);
    var $245 = $rv_0_in / $244;
    tempDoubleF64[0] = $245;
    var $rv_5$1 = tempDoubleI32[1];
    var $rv_5$0 = tempDoubleI32[0];
    __label__ = 79;
    break;
   case 79:
    var $rv_5$0;
    var $rv_5$1;
    var $248 = $239 >> 4;
    if (($248 | 0) == 0) {
      var $scale_1 = 0;
      var $rv_9$1 = $rv_5$1;
      var $rv_9$0 = $rv_5$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    if (($248 | 0) > 31) {
      __label__ = 92;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $254 = ($248 & 16 | 0) == 0;
    var $scale_0 = $254 ? 0 : 106;
    if (($248 | 0) > 0) {
      var $rv_6136$1 = $rv_5$1;
      var $rv_6136$0 = $rv_5$0;
      var $j_1137 = 0;
      var $e1_1138 = $248;
      __label__ = 82;
      break;
    } else {
      var $rv_6_lcssa$1 = $rv_5$1;
      var $rv_6_lcssa$0 = $rv_5$0;
      __label__ = 85;
      break;
    }
   case 82:
    var $e1_1138;
    var $j_1137;
    var $rv_6136$0;
    var $rv_6136$1;
    if (($e1_1138 & 1 | 0) == 0) {
      var $rv_7$1 = $rv_6136$1;
      var $rv_7$0 = $rv_6136$0;
      __label__ = 84;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $259 = _tinytens + ($j_1137 << 3) | 0;
    var $260 = (tempDoubleI32[0] = HEAP32[$259 >> 2], tempDoubleI32[1] = HEAP32[$259 + 4 >> 2], tempDoubleF64[0]);
    var $261 = (tempDoubleI32[0] = $rv_6136$0, tempDoubleI32[1] = $rv_6136$1, tempDoubleF64[0]);
    var $262 = $261 * $260;
    tempDoubleF64[0] = $262;
    var $rv_7$1 = tempDoubleI32[1];
    var $rv_7$0 = tempDoubleI32[0];
    __label__ = 84;
    break;
   case 84:
    var $rv_7$0;
    var $rv_7$1;
    var $266 = $e1_1138 >> 1;
    if (($266 | 0) > 0) {
      var $rv_6136$1 = $rv_7$1;
      var $rv_6136$0 = $rv_7$0;
      var $j_1137 = $j_1137 + 1 | 0;
      var $e1_1138 = $266;
      __label__ = 82;
      break;
    } else {
      var $rv_6_lcssa$1 = $rv_7$1;
      var $rv_6_lcssa$0 = $rv_7$0;
      __label__ = 85;
      break;
    }
   case 85:
    var $rv_6_lcssa$0;
    var $rv_6_lcssa$1;
    if ($254) {
      var $rv_8$1 = $rv_6_lcssa$1;
      var $rv_8$0 = $rv_6_lcssa$0;
      __label__ = 91;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $272 = 107 - (($rv_6_lcssa$1 >>> 20 | 0 << 12) & 2047) | 0;
    if (($272 | 0) > 0) {
      __label__ = 87;
      break;
    } else {
      var $rv_8$1 = $rv_6_lcssa$1;
      var $rv_8$0 = $rv_6_lcssa$0;
      __label__ = 91;
      break;
    }
   case 87:
    if (($272 | 0) > 31) {
      __label__ = 88;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 88:
    if (($272 | 0) > 52) {
      var $rv_8$1 = 57671680;
      var $rv_8$0 = 0;
      __label__ = 91;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $rv_8$1 = -1 << $272 - 32 & $rv_6_lcssa$1;
    var $rv_8$0 = 0;
    __label__ = 91;
    break;
   case 90:
    var $rv_8$1 = 0 | $rv_6_lcssa$1 & -1;
    var $rv_8$0 = -1 << $272 & $rv_6_lcssa$0 | $rv_6_lcssa$0 & 0;
    __label__ = 91;
    break;
   case 91:
    var $rv_8$0;
    var $rv_8$1;
    var $292 = (tempDoubleI32[0] = $rv_8$0, tempDoubleI32[1] = $rv_8$1, tempDoubleF64[0]);
    if ($292 != 0) {
      var $scale_1 = $scale_0;
      var $rv_9$1 = $rv_8$1;
      var $rv_9$0 = $rv_8$0;
      __label__ = 94;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $294 = ___errno();
    HEAP32[$294 >> 2] = 34;
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = 0;
    var $rv_16$0 = 0;
    __label__ = 165;
    break;
   case 93:
    var $delta_1;
    var $295 = ___errno();
    HEAP32[$295 >> 2] = 34;
    if (($298 | 0) == 0) {
      var $sign_2 = $sign_1;
      var $s_13 = $s_12;
      var $rv_16$1 = 0;
      var $rv_16$0 = 0;
      __label__ = 165;
      break;
    } else {
      var $delta_4 = $delta_1;
      var $rv_15$1 = 0;
      var $rv_15$0 = 0;
      __label__ = 164;
      break;
    }
   case 94:
    var $rv_9$0;
    var $rv_9$1;
    var $scale_1;
    var $298 = _s2b($state, $s0_2, $nd0_0, $nd_5, $y_8);
    var $299 = $298 + 4 | 0;
    var $301 = $298 + 12 | 0;
    var $302 = $298 + 16 | 0;
    var $303 = ($134 | 0) > -1;
    var $bd5_0 = $303 ? $134 : 0;
    var $bb5_0 = $303 ? 0 : -$134 | 0;
    var $bd2_1 = $scale_1 + $bd5_0 | 0;
    var $305 = ($bb5_0 | 0) > 0;
    var $306 = ($bd5_0 | 0) > 0;
    var $307 = ($scale_1 | 0) == 0;
    var $308 = ($scale_1 | 0) != 0;
    var $rv_10$1 = $rv_9$1;
    var $rv_10$0 = $rv_9$0;
    __label__ = 95;
    break;
   case 95:
    var $rv_10$0;
    var $rv_10$1;
    var $310 = HEAP32[$299 >> 2];
    var $311 = _Balloc($state, $310);
    var $313 = $311 + 12 | 0;
    var $316 = (HEAP32[$302 >> 2] << 2) + 8 | 0;
    _memcpy($313, $301, $316, 1);
    var $317 = (tempDoubleI32[0] = $rv_10$0, tempDoubleI32[1] = $rv_10$1, tempDoubleF64[0]);
    var $318 = _d2b($state, $317, $bbe, $bbbits);
    var $319 = _i2b($state, 1);
    var $320 = HEAP32[$bbe >> 2];
    var $321 = ($320 | 0) > -1;
    var $_neg = $321 ? 0 : -$320 | 0;
    var $322 = $321 ? $320 : 0;
    var $bb2_1 = $322 + $bb5_0 | 0;
    var $323 = $320 - $scale_1 | 0;
    var $324 = HEAP32[$bbbits >> 2];
    var $j_2 = ($324 - 1 + $323 | 0) < -1022 ? $323 + 1075 | 0 : 54 - $324 | 0;
    var $330 = $j_2 + $bb2_1 | 0;
    var $332 = $bd2_1 + $_neg + $j_2 | 0;
    var $334 = ($330 | 0) < ($332 | 0) ? $330 : $332;
    var $i_1 = ($334 | 0) > ($bb2_1 | 0) ? $bb2_1 : $334;
    if (($i_1 | 0) > 0) {
      __label__ = 96;
      break;
    } else {
      var $bb2_2 = $330;
      var $bd2_2 = $332;
      var $bs2_0 = $bb2_1;
      __label__ = 97;
      break;
    }
   case 96:
    var $bb2_2 = $330 - $i_1 | 0;
    var $bd2_2 = $332 - $i_1 | 0;
    var $bs2_0 = $bb2_1 - $i_1 | 0;
    __label__ = 97;
    break;
   case 97:
    var $bs2_0;
    var $bd2_2;
    var $bb2_2;
    if ($305) {
      __label__ = 98;
      break;
    } else {
      var $bs_2 = $319;
      var $bb_2 = $318;
      __label__ = 99;
      break;
    }
   case 98:
    var $343 = _pow5mult($state, $319, $bb5_0);
    var $344 = _mult($state, $343, $318);
    _Bfree($state, $318);
    var $bs_2 = $343;
    var $bb_2 = $344;
    __label__ = 99;
    break;
   case 99:
    var $bb_2;
    var $bs_2;
    if (($bb2_2 | 0) > 0) {
      __label__ = 100;
      break;
    } else {
      var $bb_3 = $bb_2;
      __label__ = 101;
      break;
    }
   case 100:
    var $348 = _lshift($state, $bb_2, $bb2_2);
    var $bb_3 = $348;
    __label__ = 101;
    break;
   case 101:
    var $bb_3;
    if ($306) {
      __label__ = 102;
      break;
    } else {
      var $bd_2 = $311;
      __label__ = 103;
      break;
    }
   case 102:
    var $351 = _pow5mult($state, $311, $bd5_0);
    var $bd_2 = $351;
    __label__ = 103;
    break;
   case 103:
    var $bd_2;
    if (($bd2_2 | 0) > 0) {
      __label__ = 104;
      break;
    } else {
      var $bd_3 = $bd_2;
      __label__ = 105;
      break;
    }
   case 104:
    var $355 = _lshift($state, $bd_2, $bd2_2);
    var $bd_3 = $355;
    __label__ = 105;
    break;
   case 105:
    var $bd_3;
    if (($bs2_0 | 0) > 0) {
      __label__ = 106;
      break;
    } else {
      var $bs_3 = $bs_2;
      __label__ = 107;
      break;
    }
   case 106:
    var $359 = _lshift($state, $bs_2, $bs2_0);
    var $bs_3 = $359;
    __label__ = 107;
    break;
   case 107:
    var $bs_3;
    var $361 = _diff($state, $bb_3, $bd_3);
    var $362 = $361 + 12 | 0;
    var $363 = HEAPU32[$362 >> 2];
    HEAP32[$362 >> 2] = 0;
    var $364 = _cmp($361, $bs_3);
    if (($364 | 0) < 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 108:
    if (($363 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 109:
    if (($rv_10$0 | 0) == 0) {
      __label__ = 110;
      break;
    } else {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 110:
    var $373 = $rv_10$1;
    if (($373 & 1048575 | 0) != 0 | ($373 & 2146435072) >>> 0 < 112197633) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    if ((HEAP32[$361 + 20 >> 2] | 0) == 0) {
      __label__ = 112;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 112:
    if ((HEAP32[$361 + 16 >> 2] | 0) < 2) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $387 = _lshift($state, $361, 1);
    var $388 = _cmp($387, $bs_3);
    if (($388 | 0) > 0) {
      var $delta_2 = $387;
      __label__ = 124;
      break;
    } else {
      var $delta_3 = $387;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    }
   case 114:
    if (($364 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 115:
    var $393 = ($363 | 0) != 0;
    var $395 = $rv_10$1;
    var $396 = $395 & 1048575;
    if ($393) {
      __label__ = 116;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 116:
    if (($396 | 0) == 1048575) {
      __label__ = 117;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 117:
    var $400 = $rv_10$0;
    if ($307) {
      var $409 = -1;
      __label__ = 120;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    var $402 = $395 & 2146435072;
    if ($402 >>> 0 < 111149057) {
      __label__ = 119;
      break;
    } else {
      var $409 = -1;
      __label__ = 120;
      break;
    }
   case 119:
    var $409 = -1 << 107 - ($402 >>> 20);
    __label__ = 120;
    break;
   case 120:
    var $409;
    if (($400 | 0) == ($409 | 0)) {
      __label__ = 121;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 121:
    var $delta_3 = $361;
    var $rv_14$1 = ($395 & 2146435072) + 1048576 | 0;
    var $rv_14$0 = 0;
    __label__ = 161;
    break;
   case 122:
    if (($396 | 0) == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 123:
    if (($rv_10$0 | 0) == 0) {
      var $delta_2 = $361;
      __label__ = 124;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 124:
    var $delta_2;
    var $_pre18 = $rv_10$1 & 2146435072;
    if (($307 ^ 1) & $_pre18 >>> 0 < 112197633) {
      __label__ = 125;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 125:
    if ($_pre18 >>> 0 > 57671680) {
      var $rv_147$1 = $rv_10$1;
      var $rv_147$0 = $rv_10$0;
      var $delta_38 = $delta_2;
      __label__ = 162;
      break;
    } else {
      var $delta_1 = $delta_2;
      __label__ = 93;
      break;
    }
   case 126:
    var $delta_3 = $delta_2;
    var $rv_14$1 = $_pre18 - 1048576 | 1048575 | 0;
    var $rv_14$0 = 0 | -1;
    __label__ = 161;
    break;
   case 127:
    if (($rv_10$0 & 1) == 0 && ($rv_10$1 & 0) == 0) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_10$1;
      var $rv_14$0 = $rv_10$0;
      __label__ = 161;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $433 = _ulp($317);
    if ($393) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    var $rv_11_in = $317 + $433;
    __label__ = 131;
    break;
   case 130:
    var $437 = $317 - $433;
    if ($437 != 0) {
      var $rv_11_in = $437;
      __label__ = 131;
      break;
    } else {
      var $delta_1 = $361;
      __label__ = 93;
      break;
    }
   case 131:
    var $rv_11_in;
    tempDoubleF64[0] = $rv_11_in;
    var $delta_3 = $361;
    var $rv_14$1 = tempDoubleI32[1];
    var $rv_14$0 = tempDoubleI32[0];
    __label__ = 161;
    break;
   case 132:
    var $441 = _ratio($361, $bs_3);
    if ($441 > 2) {
      __label__ = 139;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    if (($363 | 0) == 0) {
      __label__ = 134;
      break;
    } else {
      var $aadj_1 = 1;
      var $aadj1_0$1 = 1072693248;
      var $aadj1_0$0 = 0;
      __label__ = 142;
      break;
    }
   case 134:
    if (($rv_10$0 & -1) == 0 && ($rv_10$1 & 1048575) == 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $$emscripten$temp$8$1 = 0;
    if (($rv_10$0 | 0) != 1 | ($rv_10$1 >>> 0 > $$emscripten$temp$8$1 >>> 0 || $rv_10$1 >>> 0 == $$emscripten$temp$8$1 >>> 0 && $rv_10$0 >>> 0 > -1 >>> 0)) {
      var $aadj_1 = 1;
      var $aadj1_0$1 = -1074790400;
      var $aadj1_0$0 = 0;
      __label__ = 142;
      break;
    } else {
      var $delta_1 = $361;
      __label__ = 93;
      break;
    }
   case 136:
    if ($441 < 1) {
      var $aadj_0 = .5;
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $aadj_0 = $441 * .5;
    __label__ = 138;
    break;
   case 138:
    var $aadj_0;
    tempDoubleF64[0] = -$aadj_0;
    var $aadj_1 = $aadj_0;
    var $aadj1_0$1 = tempDoubleI32[1];
    var $aadj1_0$0 = tempDoubleI32[0];
    __label__ = 142;
    break;
   case 139:
    var $460 = $441 * .5;
    if (($363 | 0) == 0) {
      __label__ = 140;
      break;
    } else {
      var $465 = $460;
      __label__ = 141;
      break;
    }
   case 140:
    var $465 = -$460;
    __label__ = 141;
    break;
   case 141:
    var $465;
    tempDoubleF64[0] = $465;
    var $aadj_1 = $460;
    var $aadj1_0$1 = tempDoubleI32[1];
    var $aadj1_0$0 = tempDoubleI32[0];
    __label__ = 142;
    break;
   case 142:
    var $aadj1_0$0;
    var $aadj1_0$1;
    var $aadj_1;
    var $469 = $rv_10$1;
    var $470 = $469 & 2146435072;
    if (($470 | 0) == 2145386496) {
      __label__ = 143;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 143:
    var $476 = (tempDoubleI32[0] = $aadj1_0$0, tempDoubleI32[1] = $aadj1_0$1, tempDoubleF64[0]);
    var $477 = (tempDoubleI32[0] = 0 | $rv_10$0 & -1, tempDoubleI32[1] = $469 - 55574528 | $rv_10$1 & 0, tempDoubleF64[0]);
    var $478 = _ulp($477);
    var $480 = $477 + $476 * $478;
    tempDoubleF64[0] = $480;
    var $481$0 = tempDoubleI32[0];
    var $481$1 = tempDoubleI32[1];
    var $483 = $481$1;
    if (($483 & 2145386496) >>> 0 > 2090860543) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    if ($rv_10$0 == -1 && $rv_10$1 == 2146435071) {
      __label__ = 68;
      break;
    } else {
      var $rv_13$1 = 2146435071;
      var $rv_13$0 = -1;
      __label__ = 160;
      break;
    }
   case 145:
    var $aadj_4 = $aadj_1;
    var $rv_12$1 = $483 + 55574528 | $481$1 & 0;
    var $rv_12$0 = 0 | $481$0 & -1;
    __label__ = 153;
    break;
   case 146:
    if ($308 & $470 >>> 0 < 111149057) {
      __label__ = 147;
      break;
    } else {
      var $aadj_3 = $aadj_1;
      var $aadj1_2$1 = $aadj1_0$1;
      var $aadj1_2$0 = $aadj1_0$0;
      __label__ = 152;
      break;
    }
   case 147:
    if ($aadj_1 > 2147483647) {
      var $aadj_2 = $aadj_1;
      var $aadj1_1$1 = $aadj1_0$1;
      var $aadj1_1$0 = $aadj1_0$0;
      __label__ = 151;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    var $497 = $aadj_1 >= 0 ? Math.floor($aadj_1) : Math.ceil($aadj_1);
    var $500 = ($497 | 0) == 0 ? 1 : $497 >>> 0;
    if (($363 | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      var $505 = $500;
      __label__ = 150;
      break;
    }
   case 149:
    var $505 = -$500;
    __label__ = 150;
    break;
   case 150:
    var $505;
    tempDoubleF64[0] = $505;
    var $aadj_2 = $500;
    var $aadj1_1$1 = tempDoubleI32[1];
    var $aadj1_1$0 = tempDoubleI32[0];
    __label__ = 151;
    break;
   case 151:
    var $aadj1_1$0;
    var $aadj1_1$1;
    var $aadj_2;
    var $aadj_3 = $aadj_2;
    var $aadj1_2$1 = 112197632 - $470 + $aadj1_1$1 | $aadj1_1$1 & 0;
    var $aadj1_2$0 = 0 | $aadj1_1$0 & -1;
    __label__ = 152;
    break;
   case 152:
    var $aadj1_2$0;
    var $aadj1_2$1;
    var $aadj_3;
    var $515 = (tempDoubleI32[0] = $aadj1_2$0, tempDoubleI32[1] = $aadj1_2$1, tempDoubleF64[0]);
    var $516 = _ulp($317);
    var $518 = $317 + $515 * $516;
    tempDoubleF64[0] = $518;
    var $aadj_4 = $aadj_3;
    var $rv_12$1 = tempDoubleI32[1];
    var $rv_12$0 = tempDoubleI32[0];
    __label__ = 153;
    break;
   case 153:
    var $rv_12$0;
    var $rv_12$1;
    var $aadj_4;
    var $522 = $rv_12$1;
    if ($307) {
      __label__ = 154;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 154:
    if (($470 | 0) == ($522 & 2146435072 | 0)) {
      __label__ = 155;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 155:
    var $529 = $aadj_4 - ($aadj_4 & -1 | 0);
    if (($363 | 0) == 0) {
      __label__ = 156;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 156:
    if (($rv_12$0 | 0) == 0) {
      __label__ = 157;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 157:
    if (($522 & 1048575 | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 158:
    if ($529 < .4999999 | $529 > .5000001) {
      var $delta_3 = $361;
      var $rv_14$1 = $rv_12$1;
      var $rv_14$0 = $rv_12$0;
      __label__ = 161;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 159:
    if ($529 < .24999995) {
      var $delta_4 = $361;
      var $rv_15$1 = $rv_12$1;
      var $rv_15$0 = $rv_12$0;
      __label__ = 164;
      break;
    } else {
      var $rv_13$1 = $rv_12$1;
      var $rv_13$0 = $rv_12$0;
      __label__ = 160;
      break;
    }
   case 160:
    var $rv_13$0;
    var $rv_13$1;
    _Bfree($state, $bb_3);
    _Bfree($state, $bd_3);
    _Bfree($state, $bs_3);
    _Bfree($state, $361);
    var $rv_10$1 = $rv_13$1;
    var $rv_10$0 = $rv_13$0;
    __label__ = 95;
    break;
   case 161:
    var $rv_14$0;
    var $rv_14$1;
    var $delta_3;
    if ($307) {
      var $delta_4 = $delta_3;
      var $rv_15$1 = $rv_14$1;
      var $rv_15$0 = $rv_14$0;
      __label__ = 164;
      break;
    } else {
      var $rv_147$1 = $rv_14$1;
      var $rv_147$0 = $rv_14$0;
      var $delta_38 = $delta_3;
      __label__ = 162;
      break;
    }
   case 162:
    var $delta_38;
    var $rv_147$0;
    var $rv_147$1;
    var $543 = (tempDoubleI32[0] = $rv_147$0, tempDoubleI32[1] = $rv_147$1, tempDoubleF64[0]);
    var $544 = $543 * 1.232595164407831e-32;
    tempDoubleF64[0] = $544;
    var $545$0 = tempDoubleI32[0];
    var $545$1 = tempDoubleI32[1];
    var $$emscripten$temp$13$1 = 1;
    if (($545$1 >>> 0 < $$emscripten$temp$13$1 >>> 0 || $545$1 >>> 0 == $$emscripten$temp$13$1 >>> 0 && $545$0 >>> 0 < 0 >>> 0) & ($545$0 | 0) == 0) {
      __label__ = 163;
      break;
    } else {
      var $delta_4 = $delta_38;
      var $rv_15$1 = $545$1;
      var $rv_15$0 = $545$0;
      __label__ = 164;
      break;
    }
   case 163:
    var $550 = ___errno();
    HEAP32[$550 >> 2] = 34;
    var $delta_4 = $delta_38;
    var $rv_15$1 = $545$1;
    var $rv_15$0 = $545$0;
    __label__ = 164;
    break;
   case 164:
    var $rv_15$0;
    var $rv_15$1;
    var $delta_4;
    _Bfree($state, $bb_3);
    _Bfree($state, $bd_3);
    _Bfree($state, $bs_3);
    _Bfree($state, $298);
    _Bfree($state, $delta_4);
    var $sign_2 = $sign_1;
    var $s_13 = $s_12;
    var $rv_16$1 = $rv_15$1;
    var $rv_16$0 = $rv_15$0;
    __label__ = 165;
    break;
   case 165:
    var $rv_16$0;
    var $rv_16$1;
    var $s_13;
    var $sign_2;
    if (($se | 0) == 0) {
      __label__ = 167;
      break;
    } else {
      __label__ = 166;
      break;
    }
   case 166:
    HEAP32[$se >> 2] = $s_13;
    __label__ = 167;
    break;
   case 167:
    var $555 = (tempDoubleI32[0] = $rv_16$0, tempDoubleI32[1] = $rv_16$1, tempDoubleF64[0]);
    if (($sign_2 | 0) == 0) {
      var $559 = $555;
      __label__ = 169;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $559 = -$555;
    __label__ = 169;
    break;
   case 169:
    var $559;
    STACKTOP = __stackBase__;
    return $559;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__strtod["X"] = 1;

function _js_dtostr($state, $buffer, $bufferSize, $mode, $precision, $dinput) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $buffer;
    var $decPt = STACKTOP;
    STACKTOP += 4;
    var $sign = STACKTOP;
    STACKTOP += 4;
    var $numEnd = STACKTOP;
    STACKTOP += 4;
    HEAP32[$numEnd >> 2] = 0;
    if (($mode | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $_04 = $mode;
      __label__ = 4;
      break;
    }
   case 2:
    if ($dinput >= 1e+21 | $dinput <= -1e+21) {
      __label__ = 3;
      break;
    } else {
      var $_04 = 2;
      __label__ = 4;
      break;
    }
   case 3:
    var $_04 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_04;
    tempDoubleF64[0] = $dinput;
    var $8$0 = tempDoubleI32[0];
    var $8$1 = tempDoubleI32[1];
    var $9 = STRING_TABLE.__ZL9dtoaModes + $_04 | 0;
    var $11 = HEAPU8[$9] & 255;
    var $12 = _dtoa($state, $dinput, $11, $precision, $decPt, $sign, $numEnd);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$numEnd >> 2] - $12 | 0;
    if ($18 >>> 0 > ($bufferSize - 2 | 0) >>> 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $buffer + 2 | 0;
    _memcpy($22, $12, $18, 1);
    _freedtoa($state, $12);
    var $23 = $18 + ($buffer + 2) | 0;
    HEAP32[$numEnd >> 2] = $23;
    HEAP8[$23] = 0;
    var $24 = HEAPU32[$decPt >> 2];
    if (($24 | 0) == 9999) {
      var $numBegin_1 = $22;
      __label__ = 32;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($_04 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($_04 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($_04 | 0) == 3) {
      __label__ = 10;
      break;
    } else if (($_04 | 0) == 1) {
      var $minNDigits_0 = 0;
      __label__ = 11;
      break;
    } else if (($_04 | 0) == 4) {
      __label__ = 12;
      break;
    } else {
      var $minNDigits_1 = 0;
      var $exponentialNotation_0 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $28 = ($24 + 5 | 0) >>> 0 > 26;
    var $_6 = $28 ? 0 : $24;
    var $minNDigits_1 = $_6;
    var $exponentialNotation_0 = $28 & 1;
    __label__ = 14;
    break;
   case 9:
    var $31 = ($precision | 0) < 0 ? 0 : $precision;
    var $minNDigits_1 = $24 + $31 | 0;
    var $exponentialNotation_0 = 0;
    __label__ = 14;
    break;
   case 10:
    var $minNDigits_0 = $precision;
    __label__ = 11;
    break;
   case 11:
    var $minNDigits_0;
    var $minNDigits_1 = $minNDigits_0;
    var $exponentialNotation_0 = 1;
    __label__ = 14;
    break;
   case 12:
    if (($24 | 0) < -5 | ($24 | 0) > ($precision | 0)) {
      __label__ = 13;
      break;
    } else {
      var $minNDigits_1 = $precision;
      var $exponentialNotation_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $minNDigits_1 = $precision;
    var $exponentialNotation_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $exponentialNotation_0;
    var $minNDigits_1;
    if (($18 | 0) < ($minNDigits_1 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $nDigits_0 = $18;
      __label__ = 18;
      break;
    }
   case 15:
    var $41 = $minNDigits_1 + ($buffer + 2) | 0;
    var $43 = $23;
    __label__ = 16;
    break;
   case 16:
    var $43;
    HEAP32[$numEnd >> 2] = $43 + 1 | 0;
    HEAP8[$43] = 48;
    var $45 = HEAP32[$numEnd >> 2];
    if (($45 | 0) == ($41 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $43 = $45;
      __label__ = 16;
      break;
    }
   case 17:
    HEAP8[$45] = 0;
    var $nDigits_0 = $minNDigits_1;
    __label__ = 18;
    break;
   case 18:
    var $nDigits_0;
    if (($exponentialNotation_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($nDigits_0 | 0) == 1) {
      var $numBegin_0 = $22;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $buffer + 1 | 0;
    var $54 = HEAP8[$22];
    HEAP8[$53] = $54;
    HEAP8[$22] = 46;
    var $numBegin_0 = $53;
    __label__ = 21;
    break;
   case 21:
    var $numBegin_0;
    var $55 = HEAP32[$numEnd >> 2];
    var $58 = $1 + $bufferSize - $55 | 0;
    var $59 = $24 - 1 | 0;
    var $60 = _JS_snprintf($55, $58, STRING_TABLE.__str1096 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $59, tempInt));
    var $numBegin_1 = $numBegin_0;
    __label__ = 32;
    break;
   case 22:
    if (($24 | 0) == ($nDigits_0 | 0)) {
      var $numBegin_1 = $22;
      __label__ = 32;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if (($24 | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $66 = $buffer + 1 | 0;
    var $p_0 = $66;
    __label__ = 25;
    break;
   case 25:
    var $p_0;
    var $68 = $p_0 + 1 | 0;
    var $69 = HEAP8[$68];
    HEAP8[$p_0] = $69;
    var $71 = HEAP32[$decPt >> 2] - 1 | 0;
    HEAP32[$decPt >> 2] = $71;
    if (($71 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $p_0 = $68;
      __label__ = 25;
      break;
    }
   case 26:
    HEAP8[$68] = 46;
    var $numBegin_1 = $66;
    __label__ = 32;
    break;
   case 27:
    var $75 = HEAP32[$numEnd >> 2];
    var $77 = $75 + (1 - $24) | 0;
    HEAP32[$numEnd >> 2] = $77;
    HEAP8[$77] = 0;
    if (($75 | 0) == ($22 | 0)) {
      var $q_0_lcssa = $77;
      __label__ = 29;
      break;
    } else {
      var $p_112 = $75;
      var $q_013 = $77;
      __label__ = 28;
      break;
    }
   case 28:
    var $q_013;
    var $p_112;
    var $79 = $p_112 - 1 | 0;
    var $80 = HEAP8[$79];
    var $81 = $q_013 - 1 | 0;
    HEAP8[$81] = $80;
    if (($79 | 0) == ($22 | 0)) {
      var $q_0_lcssa = $81;
      __label__ = 29;
      break;
    } else {
      var $p_112 = $79;
      var $q_013 = $81;
      __label__ = 28;
      break;
    }
   case 29:
    var $q_0_lcssa;
    var $83 = $buffer + 3 | 0;
    if (($83 | 0) == ($q_0_lcssa | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $scevgep1819 = $q_0_lcssa + (-3 - $1) | 0;
    _memset($83, 48, $scevgep1819, 1);
    __label__ = 31;
    break;
   case 31:
    HEAP8[$22] = 46;
    var $87 = $buffer + 1 | 0;
    HEAP8[$87] = 48;
    var $numBegin_1 = $87;
    __label__ = 32;
    break;
   case 32:
    var $numBegin_1;
    if ((HEAP32[$sign >> 2] | 0) == 0) {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $93 = $8$1;
    var $96 = ($8$0 | 0) == 0;
    if (($93 | 0) == -2147483648 & $96) {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if (($93 & 2146435072 | 0) == 2146435072) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    if ($96) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    }
   case 36:
    if (($93 & 1048575 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $_0 = $numBegin_1;
      __label__ = 38;
      break;
    }
   case 37:
    var $105 = $numBegin_1 - 1 | 0;
    HEAP8[$105] = 45;
    var $_0 = $105;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_dtostr["X"] = 1;

function _dtoa($state, $d_0, $mode, $ndigits, $decpt, $sign, $rve) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d_0;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $bbits = STACKTOP;
    STACKTOP += 4;
    var $be = STACKTOP;
    STACKTOP += 4;
    if (($1$1 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$sign >> 2] = 1;
    var $d_020$1 = $1$1 & 2147483647;
    var $d_020$0 = $1$0 & -1;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$sign >> 2] = 0;
    var $d_020$1 = $1$1;
    var $d_020$0 = $1$0;
    __label__ = 4;
    break;
   case 4:
    var $d_020$0;
    var $d_020$1;
    var $9 = $d_020$1;
    if (($9 & 2146435072 | 0) == 2146435072) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$decpt >> 2] = 9999;
    if (($d_020$0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($9 & 1048575 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = _nrv_alloc($state, STRING_TABLE._js_Infinity_str | 0, $rve, 8);
    var $_0 = $19;
    __label__ = 164;
    break;
   case 8:
    var $21 = _nrv_alloc($state, STRING_TABLE._js_NaN_str | 0, $rve, 3);
    var $_0 = $21;
    __label__ = 164;
    break;
   case 9:
    var $23 = (tempDoubleI32[0] = $d_020$0, tempDoubleI32[1] = $d_020$1, tempDoubleF64[0]);
    if ($23 != 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$decpt >> 2] = 1;
    var $26 = _nrv_alloc($state, STRING_TABLE.__str64083 | 0, $rve, 1);
    var $_0 = $26;
    __label__ = 164;
    break;
   case 11:
    var $28 = _d2b($state, $23, $be, $bbits);
    var $31 = ($d_020$1 >>> 20 | 0 << 12) & 2047;
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $31 - 1023 | 0;
    var $denorm_0 = 0;
    var $d2_0$1 = $d_020$1 & 1048575 | 1072693248 | $d_020$1 & 0;
    var $d2_0$0 = 0 | $d_020$0 & -1;
    __label__ = 17;
    break;
   case 13:
    var $42 = HEAP32[$be >> 2] + HEAP32[$bbits >> 2] | 0;
    if (($42 + 1074 | 0) > 32) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $57 = $d_020$0 >>> (($42 + 1042 | 0) >>> 0) | $9 << -1010 - $42;
    __label__ = 16;
    break;
   case 15:
    var $57 = $d_020$0 << -1042 - $42;
    __label__ = 16;
    break;
   case 16:
    var $57;
    tempDoubleF64[0] = $57 >>> 0;
    var $59$1 = tempDoubleI32[1];
    var $i_0 = $42 - 1 | 0;
    var $denorm_0 = 1;
    var $d2_0$1 = $59$1 - 32505856 | $59$1 & 0;
    var $d2_0$0 = 0 | tempDoubleI32[0] & -1;
    __label__ = 17;
    break;
   case 17:
    var $d2_0$0;
    var $d2_0$1;
    var $denorm_0;
    var $i_0;
    var $67 = (tempDoubleI32[0] = $d2_0$0, tempDoubleI32[1] = $d2_0$1, tempDoubleF64[0]);
    var $73 = ($67 - 1.5) * .289529654602168 + .1760912590558 + ($i_0 | 0) * .301029995663981;
    var $74 = $73 & -1;
    if ($73 < 0) {
      __label__ = 18;
      break;
    } else {
      var $k_0 = $74;
      __label__ = 20;
      break;
    }
   case 18:
    if ($73 != ($74 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $k_0 = $74;
      __label__ = 20;
      break;
    }
   case 19:
    var $k_0 = $74 - 1 | 0;
    __label__ = 20;
    break;
   case 20:
    var $k_0;
    if ($k_0 >>> 0 < 23) {
      __label__ = 21;
      break;
    } else {
      var $k_2 = $k_0;
      var $k_check_0 = 1;
      __label__ = 22;
      break;
    }
   case 21:
    var $84 = _tens + ($k_0 << 3) | 0;
    var $85 = (tempDoubleI32[0] = HEAP32[$84 >> 2], tempDoubleI32[1] = HEAP32[$84 + 4 >> 2], tempDoubleF64[0]);
    var $k_2 = (($23 < $85) << 31 >> 31) + $k_0 | 0;
    var $k_check_0 = 0;
    __label__ = 22;
    break;
   case 22:
    var $k_check_0;
    var $k_2;
    var $89 = HEAP32[$bbits >> 2] - $i_0 | 0;
    var $90 = ($89 | 0) > 0;
    var $s2_0 = $90 ? $89 - 1 | 0 : 0;
    var $b2_0 = $90 ? 0 : 1 - $89 | 0;
    if (($k_2 | 0) > -1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $b2_1 = $b2_0;
    var $b5_0 = 0;
    var $s2_1 = $s2_0 + $k_2 | 0;
    var $s5_0 = $k_2;
    __label__ = 25;
    break;
   case 24:
    var $b2_1 = $b2_0 - $k_2 | 0;
    var $b5_0 = -$k_2 | 0;
    var $s2_1 = $s2_0;
    var $s5_0 = 0;
    __label__ = 25;
    break;
   case 25:
    var $s5_0;
    var $s2_1;
    var $b5_0;
    var $b2_1;
    var $_08 = $mode >>> 0 > 9 ? 0 : $mode;
    var $102 = ($_08 | 0) > 5;
    var $__08 = $102 ? $_08 - 4 | 0 : $_08;
    if (($__08 | 0) == 0 || ($__08 | 0) == 1) {
      __label__ = 26;
      break;
    } else if (($__08 | 0) == 2) {
      __label__ = 27;
      break;
    } else if (($__08 | 0) == 4) {
      var $leftright_0 = 1;
      __label__ = 28;
      break;
    } else if (($__08 | 0) == 3) {
      __label__ = 29;
      break;
    } else if (($__08 | 0) == 5) {
      var $leftright_1 = 1;
      __label__ = 30;
      break;
    } else {
      var $_110 = $ndigits;
      var $i_1 = $i_0;
      var $ilim_0 = 0;
      var $ilim1_0 = 0;
      var $leftright_2 = 1;
      __label__ = 32;
      break;
    }
   case 26:
    var $103 = _rv_alloc($state, 18);
    var $leftright_237 = 1;
    var $ilim1_038 = -1;
    var $ilim_039 = -1;
    var $_11040 = 0;
    var $260 = $103;
    __label__ = 64;
    break;
   case 27:
    var $leftright_0 = 0;
    __label__ = 28;
    break;
   case 28:
    var $leftright_0;
    var $_09 = ($ndigits | 0) < 1 ? 1 : $ndigits;
    var $_110 = $_09;
    var $i_1 = $_09;
    var $ilim_0 = $_09;
    var $ilim1_0 = $_09;
    var $leftright_2 = $leftright_0;
    __label__ = 32;
    break;
   case 29:
    var $leftright_1 = 0;
    __label__ = 30;
    break;
   case 30:
    var $leftright_1;
    var $109 = $k_2 + $ndigits | 0;
    var $110 = $109 + 1 | 0;
    if (($109 | 0) < 0) {
      __label__ = 31;
      break;
    } else {
      var $_110 = $ndigits;
      var $i_1 = $110;
      var $ilim_0 = $110;
      var $ilim1_0 = $109;
      var $leftright_2 = $leftright_1;
      __label__ = 32;
      break;
    }
   case 31:
    var $_110 = $ndigits;
    var $i_1 = 1;
    var $ilim_0 = $110;
    var $ilim1_0 = $109;
    var $leftright_2 = $leftright_1;
    __label__ = 32;
    break;
   case 32:
    var $leftright_2;
    var $ilim1_0;
    var $ilim_0;
    var $i_1;
    var $_110;
    var $114 = _rv_alloc($state, $i_1);
    if ($ilim_0 >>> 0 > 14 | $102) {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if (($k_2 | 0) > 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 34:
    var $120 = _tens + (($k_2 & 15) << 3) | 0;
    var $121 = (tempDoubleI32[0] = HEAP32[$120 >> 2], tempDoubleI32[1] = HEAP32[$120 + 4 >> 2], tempDoubleF64[0]);
    var $122 = $k_2 >> 4;
    if (($122 & 16 | 0) == 0) {
      var $ieps_0_ph = 2;
      var $j_0_ph = $122;
      var $d_1$1 = $d_020$1;
      var $d_1$0 = $d_020$0;
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $127 = $23 / 1e+256;
    tempDoubleF64[0] = $127;
    var $ieps_0_ph = 3;
    var $j_0_ph = $122 & 15;
    var $d_1$1 = tempDoubleI32[1];
    var $d_1$0 = tempDoubleI32[0];
    __label__ = 36;
    break;
   case 36:
    var $d_1$0;
    var $d_1$1;
    var $j_0_ph;
    var $ieps_0_ph;
    if (($j_0_ph | 0) == 0) {
      var $ieps_0_lcssa = $ieps_0_ph;
      var $ds_0_lcssa = $121;
      __label__ = 40;
      break;
    } else {
      var $j_058 = $j_0_ph;
      var $ieps_059 = $ieps_0_ph;
      var $i_260 = 0;
      var $ds_061 = $121;
      __label__ = 37;
      break;
    }
   case 37:
    var $ds_061;
    var $i_260;
    var $ieps_059;
    var $j_058;
    if (($j_058 & 1 | 0) == 0) {
      var $ds_1 = $ds_061;
      var $ieps_1 = $ieps_059;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $134 = _bigtens + ($i_260 << 3) | 0;
    var $135 = (tempDoubleI32[0] = HEAP32[$134 >> 2], tempDoubleI32[1] = HEAP32[$134 + 4 >> 2], tempDoubleF64[0]);
    var $ds_1 = $ds_061 * $135;
    var $ieps_1 = $ieps_059 + 1 | 0;
    __label__ = 39;
    break;
   case 39:
    var $ieps_1;
    var $ds_1;
    var $138 = $j_058 >> 1;
    if (($138 | 0) == 0) {
      var $ieps_0_lcssa = $ieps_1;
      var $ds_0_lcssa = $ds_1;
      __label__ = 40;
      break;
    } else {
      var $j_058 = $138;
      var $ieps_059 = $ieps_1;
      var $i_260 = $i_260 + 1 | 0;
      var $ds_061 = $ds_1;
      __label__ = 37;
      break;
    }
   case 40:
    var $ds_0_lcssa;
    var $ieps_0_lcssa;
    var $141 = (tempDoubleI32[0] = $d_1$0, tempDoubleI32[1] = $d_1$1, tempDoubleF64[0]);
    var $142 = $141 / $ds_0_lcssa;
    tempDoubleF64[0] = $142;
    var $ieps_4 = $ieps_0_lcssa;
    var $d_4$1 = tempDoubleI32[1];
    var $d_4$0 = tempDoubleI32[0];
    __label__ = 46;
    break;
   case 41:
    var $145 = -$k_2 | 0;
    if (($k_2 | 0) == 0) {
      var $ieps_4 = 2;
      var $d_4$1 = $d_020$1;
      var $d_4$0 = $d_020$0;
      __label__ = 46;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $149 = _tens + (($145 & 15) << 3) | 0;
    var $150 = (tempDoubleI32[0] = HEAP32[$149 >> 2], tempDoubleI32[1] = HEAP32[$149 + 4 >> 2], tempDoubleF64[0]);
    var $151 = $23 * $150;
    tempDoubleF64[0] = $151;
    var $152$0 = tempDoubleI32[0];
    var $152$1 = tempDoubleI32[1];
    var $153 = $145 >> 4;
    if (($153 | 0) == 0) {
      var $ieps_4 = 2;
      var $d_4$1 = $152$1;
      var $d_4$0 = $152$0;
      __label__ = 46;
      break;
    } else {
      var $j_142 = $153;
      var $ieps_243 = 2;
      var $i_344 = 0;
      var $d_2$1 = $152$1;
      var $d_2$0 = $152$0;
      __label__ = 43;
      break;
    }
   case 43:
    var $d_2$0;
    var $d_2$1;
    var $i_344;
    var $ieps_243;
    var $j_142;
    if (($j_142 & 1 | 0) == 0) {
      var $ieps_3 = $ieps_243;
      var $d_3$1 = $d_2$1;
      var $d_3$0 = $d_2$0;
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $159 = _bigtens + ($i_344 << 3) | 0;
    var $160 = (tempDoubleI32[0] = HEAP32[$159 >> 2], tempDoubleI32[1] = HEAP32[$159 + 4 >> 2], tempDoubleF64[0]);
    var $161 = (tempDoubleI32[0] = $d_2$0, tempDoubleI32[1] = $d_2$1, tempDoubleF64[0]);
    var $162 = $161 * $160;
    tempDoubleF64[0] = $162;
    var $ieps_3 = $ieps_243 + 1 | 0;
    var $d_3$1 = tempDoubleI32[1];
    var $d_3$0 = tempDoubleI32[0];
    __label__ = 45;
    break;
   case 45:
    var $d_3$0;
    var $d_3$1;
    var $ieps_3;
    var $165 = $j_142 >> 1;
    if (($165 | 0) == 0) {
      var $ieps_4 = $ieps_3;
      var $d_4$1 = $d_3$1;
      var $d_4$0 = $d_3$0;
      __label__ = 46;
      break;
    } else {
      var $j_142 = $165;
      var $ieps_243 = $ieps_3;
      var $i_344 = $i_344 + 1 | 0;
      var $d_2$1 = $d_3$1;
      var $d_2$0 = $d_3$0;
      __label__ = 43;
      break;
    }
   case 46:
    var $d_4$0;
    var $d_4$1;
    var $ieps_4;
    if (($k_check_0 | 0) == 0) {
      var $ieps_5 = $ieps_4;
      var $ilim_1 = $ilim_0;
      var $k_3 = $k_2;
      var $d_5$1 = $d_4$1;
      var $d_5$0 = $d_4$0;
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $170 = (tempDoubleI32[0] = $d_4$0, tempDoubleI32[1] = $d_4$1, tempDoubleF64[0]);
    if ($170 < 1 & ($ilim_0 | 0) > 0) {
      __label__ = 48;
      break;
    } else {
      var $ieps_5 = $ieps_4;
      var $ilim_1 = $ilim_0;
      var $k_3 = $k_2;
      var $d_5$1 = $d_4$1;
      var $d_5$0 = $d_4$0;
      __label__ = 50;
      break;
    }
   case 48:
    if (($ilim1_0 | 0) < 1) {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $177 = $170 * 10;
    tempDoubleF64[0] = $177;
    var $ieps_5 = $ieps_4 + 1 | 0;
    var $ilim_1 = $ilim1_0;
    var $k_3 = $k_2 - 1 | 0;
    var $d_5$1 = tempDoubleI32[1];
    var $d_5$0 = tempDoubleI32[0];
    __label__ = 50;
    break;
   case 50:
    var $d_5$0;
    var $d_5$1;
    var $k_3;
    var $ilim_1;
    var $ieps_5;
    var $182 = (tempDoubleI32[0] = $d_5$0, tempDoubleI32[1] = $d_5$1, tempDoubleF64[0]);
    var $184 = ($ieps_5 | 0) * $182 + 7;
    tempDoubleF64[0] = $184;
    var $185$1 = tempDoubleI32[1];
    var $ins$0 = 0 | tempDoubleI32[0] & -1;
    var $ins$1 = $185$1 - 54525952 | $185$1 & 0;
    if (($ilim_1 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 51:
    var $193 = $182 - 5;
    var $194 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    if ($193 > $194) {
      var $S_3 = 0;
      var $mhi_6 = 0;
      var $k_8 = $k_3;
      var $b_5 = $28;
      var $419 = $114;
      __label__ = 116;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    if ($193 < -$194) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $114;
      __label__ = 115;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 53:
    var $202 = _tens + ($ilim_1 - 1 << 3) | 0;
    var $203 = (tempDoubleI32[0] = HEAP32[$202 >> 2], tempDoubleI32[1] = HEAP32[$202 + 4 >> 2], tempDoubleF64[0]);
    if (($leftright_2 | 0) == 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $205 = .5 / $203;
    var $206 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    var $s_0 = $114;
    var $i_4 = 1;
    var $eps_0_in = $205 - $206;
    var $d_6$1 = $d_5$1;
    var $d_6$0 = $d_5$0;
    __label__ = 55;
    break;
   case 55:
    var $d_6$0;
    var $d_6$1;
    var $eps_0_in;
    var $i_4;
    var $s_0;
    var $209 = (tempDoubleI32[0] = $d_6$0, tempDoubleI32[1] = $d_6$1, tempDoubleF64[0]);
    var $210 = $209 >= 0 ? Math.floor($209) : Math.ceil($209);
    var $212 = $209 - ($210 | 0);
    var $215 = $s_0 + 1 | 0;
    HEAP8[$s_0] = $210 + 48 & 255;
    if ($212 < $eps_0_in) {
      var $s_14 = $215;
      var $k_10 = $k_3;
      var $b_13 = $28;
      var $556 = $114;
      __label__ = 162;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (1 - $212 < $eps_0_in) {
      var $s_5_ph = $215;
      var $k_5_ph = $k_3;
      var $_ph = $114;
      __label__ = 73;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if (($i_4 | 0) < ($ilim_1 | 0)) {
      __label__ = 58;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 58:
    var $224 = $212 * 10;
    tempDoubleF64[0] = $224;
    var $s_0 = $215;
    var $i_4 = $i_4 + 1 | 0;
    var $eps_0_in = $eps_0_in * 10;
    var $d_6$1 = tempDoubleI32[1];
    var $d_6$0 = tempDoubleI32[0];
    __label__ = 55;
    break;
   case 59:
    var $227 = (tempDoubleI32[0] = $ins$0, tempDoubleI32[1] = $ins$1, tempDoubleF64[0]);
    var $228 = $227 * $203;
    var $229 = $182 & -1;
    var $231 = $182 - ($229 | 0);
    tempDoubleF64[0] = $231;
    var $232$0 = tempDoubleI32[0];
    var $232$1 = tempDoubleI32[1];
    var $ilim_352 = $231 != 0 ? $ilim_1 : 1;
    var $236 = $114 + 1 | 0;
    HEAP8[$114] = $229 + 48 & 255;
    if (($ilim_352 | 0) == 1) {
      var $_lcssa51 = $236;
      var $d_7$1 = $232$1;
      var $d_7$0 = $232$0;
      __label__ = 60;
      break;
    } else {
      var $i_553 = 1;
      var $ilim_354 = $ilim_352;
      var $247 = $236;
      var $d_8$1 = $232$1;
      var $d_8$0 = $232$0;
      __label__ = 63;
      break;
    }
   case 60:
    var $d_7$0;
    var $d_7$1;
    var $_lcssa51;
    var $238 = (tempDoubleI32[0] = $d_7$0, tempDoubleI32[1] = $d_7$1, tempDoubleF64[0]);
    if ($238 > $228 + .5) {
      var $s_5_ph = $_lcssa51;
      var $k_5_ph = $k_3;
      var $_ph = $114;
      __label__ = 73;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    if ($238 < .5 - $228) {
      var $s_2 = $_lcssa51;
      __label__ = 62;
      break;
    } else {
      var $leftright_237 = $leftright_2;
      var $ilim1_038 = $ilim1_0;
      var $ilim_039 = $ilim_0;
      var $_11040 = $_110;
      var $260 = $114;
      __label__ = 64;
      break;
    }
   case 62:
    var $s_2;
    var $244 = $s_2 - 1 | 0;
    if (HEAP8[$244] << 24 >> 24 == 48) {
      var $s_2 = $244;
      __label__ = 62;
      break;
    } else {
      var $s_14 = $s_2;
      var $k_10 = $k_3;
      var $b_13 = $28;
      var $556 = $114;
      __label__ = 162;
      break;
    }
   case 63:
    var $d_8$0;
    var $d_8$1;
    var $247;
    var $ilim_354;
    var $i_553;
    var $248 = $i_553 + 1 | 0;
    var $249 = (tempDoubleI32[0] = $d_8$0, tempDoubleI32[1] = $d_8$1, tempDoubleF64[0]);
    var $250 = $249 * 10;
    var $251 = $250 & -1;
    var $253 = $250 - ($251 | 0);
    tempDoubleF64[0] = $253;
    var $254$0 = tempDoubleI32[0];
    var $254$1 = tempDoubleI32[1];
    var $ilim_3 = $253 != 0 ? $ilim_354 : $248;
    var $258 = $247 + 1 | 0;
    HEAP8[$247] = $251 + 48 & 255;
    if (($248 | 0) == ($ilim_3 | 0)) {
      var $_lcssa51 = $258;
      var $d_7$1 = $254$1;
      var $d_7$0 = $254$0;
      __label__ = 60;
      break;
    } else {
      var $i_553 = $248;
      var $ilim_354 = $ilim_3;
      var $247 = $258;
      var $d_8$1 = $254$1;
      var $d_8$0 = $254$0;
      __label__ = 63;
      break;
    }
   case 64:
    var $260;
    var $_11040;
    var $ilim_039;
    var $ilim1_038;
    var $leftright_237;
    var $261 = HEAPU32[$be >> 2];
    if (($261 | 0) > -1 & ($k_2 | 0) < 15) {
      __label__ = 65;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 65:
    var $265 = _tens + ($k_2 << 3) | 0;
    var $266 = (tempDoubleI32[0] = HEAP32[$265 >> 2], tempDoubleI32[1] = HEAP32[$265 + 4 >> 2], tempDoubleF64[0]);
    if (($_11040 | 0) < 0 & ($ilim_039 | 0) < 1) {
      __label__ = 66;
      break;
    } else {
      var $s_4 = $260;
      var $i_6 = 1;
      var $d_10$1 = $d_020$1;
      var $d_10$0 = $d_020$0;
      __label__ = 68;
      break;
    }
   case 66:
    if (($ilim_039 | 0) < 0) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $272 = (tempDoubleI32[0] = $d_020$0, tempDoubleI32[1] = $d_020$1, tempDoubleF64[0]);
    if ($272 < $266 * 5) {
      var $S_2 = 0;
      var $mhi_5 = 0;
      var $b_4 = $28;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      var $S_3 = 0;
      var $mhi_6 = 0;
      var $k_8 = $k_2;
      var $b_5 = $28;
      var $419 = $260;
      __label__ = 116;
      break;
    }
   case 68:
    var $d_10$0;
    var $d_10$1;
    var $i_6;
    var $s_4;
    var $275 = (tempDoubleI32[0] = $d_10$0, tempDoubleI32[1] = $d_10$1, tempDoubleF64[0]);
    var $277 = $275 / $266 & -1;
    var $280 = $275 - ($277 | 0) * $266;
    var $283 = $s_4 + 1 | 0;
    HEAP8[$s_4] = $277 + 48 & 255;
    if ($280 != 0) {
      __label__ = 69;
      break;
    } else {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    }
   case 69:
    if (($i_6 | 0) == ($ilim_039 | 0)) {
      __label__ = 70;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 70:
    var $288 = $280 + $280;
    if ($288 > $266) {
      var $s_5_ph = $283;
      var $k_5_ph = $k_2;
      var $_ph = $260;
      __label__ = 73;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    if ($288 == $266) {
      __label__ = 72;
      break;
    } else {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    }
   case 72:
    if (($277 & 1 | 0) == 0) {
      var $s_14 = $283;
      var $k_10 = $k_2;
      var $b_13 = $28;
      var $556 = $260;
      __label__ = 162;
      break;
    } else {
      var $s_5_ph = $283;
      var $k_5_ph = $k_2;
      var $_ph = $260;
      __label__ = 73;
      break;
    }
   case 73:
    var $_ph;
    var $k_5_ph;
    var $s_5_ph;
    var $s_5 = $s_5_ph;
    __label__ = 74;
    break;
   case 74:
    var $s_5;
    var $296 = $s_5 - 1 | 0;
    var $297 = HEAP8[$296];
    if ($297 << 24 >> 24 == 57) {
      __label__ = 75;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 75:
    if (($296 | 0) == ($_ph | 0)) {
      __label__ = 76;
      break;
    } else {
      var $s_5 = $296;
      __label__ = 74;
      break;
    }
   case 76:
    HEAP8[$296] = 48;
    var $k_6 = $k_5_ph + 1 | 0;
    var $303 = 49;
    __label__ = 78;
    break;
   case 77:
    var $k_6 = $k_5_ph;
    var $303 = $297 + 1 & 255;
    __label__ = 78;
    break;
   case 78:
    var $303;
    var $k_6;
    HEAP8[$296] = $303;
    var $s_14 = $s_5;
    var $k_10 = $k_6;
    var $b_13 = $28;
    var $556 = $_ph;
    __label__ = 162;
    break;
   case 79:
    var $306 = $280 * 10;
    tempDoubleF64[0] = $306;
    var $s_4 = $283;
    var $i_6 = $i_6 + 1 | 0;
    var $d_10$1 = tempDoubleI32[1];
    var $d_10$0 = tempDoubleI32[0];
    __label__ = 68;
    break;
   case 80:
    var $309 = ($leftright_237 | 0) != 0;
    if ($309) {
      __label__ = 81;
      break;
    } else {
      var $mhi_0 = 0;
      var $b2_2 = $b2_1;
      var $s2_2 = $s2_1;
      __label__ = 85;
      break;
    }
   case 81:
    if (($denorm_0 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $318 = $261 + 1075 | 0;
    __label__ = 84;
    break;
   case 83:
    var $318 = 54 - HEAP32[$bbits >> 2] | 0;
    __label__ = 84;
    break;
   case 84:
    var $318;
    var $319 = $318 + $b2_1 | 0;
    var $320 = $318 + $s2_1 | 0;
    var $321 = _i2b($state, 1);
    var $mhi_0 = $321;
    var $b2_2 = $319;
    var $s2_2 = $320;
    __label__ = 85;
    break;
   case 85:
    var $s2_2;
    var $b2_2;
    var $mhi_0;
    if (($b2_1 | 0) > 0 & ($s2_2 | 0) > 0) {
      __label__ = 86;
      break;
    } else {
      var $b2_3 = $b2_2;
      var $m2_0 = $b2_1;
      var $s2_3 = $s2_2;
      __label__ = 87;
      break;
    }
   case 86:
    var $327 = ($b2_1 | 0) < ($s2_2 | 0) ? $b2_1 : $s2_2;
    var $b2_3 = $b2_2 - $327 | 0;
    var $m2_0 = $b2_1 - $327 | 0;
    var $s2_3 = $s2_2 - $327 | 0;
    __label__ = 87;
    break;
   case 87:
    var $s2_3;
    var $m2_0;
    var $b2_3;
    if (($b5_0 | 0) > 0) {
      __label__ = 88;
      break;
    } else {
      var $mhi_2 = $mhi_0;
      var $b_1 = $28;
      __label__ = 91;
      break;
    }
   case 88:
    if ($309) {
      __label__ = 89;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 89:
    var $335 = _pow5mult($state, $mhi_0, $b5_0);
    var $336 = _mult($state, $335, $28);
    _Bfree($state, $28);
    var $mhi_2 = $335;
    var $b_1 = $336;
    __label__ = 91;
    break;
   case 90:
    var $338 = _pow5mult($state, $28, $b5_0);
    var $mhi_2 = $mhi_0;
    var $b_1 = $338;
    __label__ = 91;
    break;
   case 91:
    var $b_1;
    var $mhi_2;
    var $340 = _i2b($state, 1);
    if (($s5_0 | 0) > 0) {
      __label__ = 92;
      break;
    } else {
      var $S_0 = $340;
      __label__ = 93;
      break;
    }
   case 92:
    var $343 = _pow5mult($state, $340, $s5_0);
    var $S_0 = $343;
    __label__ = 93;
    break;
   case 93:
    var $S_0;
    if (($__08 | 0) < 2 | $309) {
      __label__ = 94;
      break;
    } else {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    }
   case 94:
    if (($d_020$0 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    }
   case 95:
    var $351 = $d_020$1;
    if (($351 & 1048575 | 0) != 0 | ($351 & 2145386496 | 0) == 0) {
      var $b2_4 = $b2_3;
      var $s2_4 = $s2_3;
      var $spec_case_0 = 0;
      __label__ = 97;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $b2_4 = $b2_3 + 1 | 0;
    var $s2_4 = $s2_3 + 1 | 0;
    var $spec_case_0 = 1;
    __label__ = 97;
    break;
   case 97:
    var $spec_case_0;
    var $s2_4;
    var $b2_4;
    if (($s5_0 | 0) == 0) {
      var $370 = 1;
      __label__ = 99;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $366 = HEAP32[$S_0 + 20 + (HEAP32[$S_0 + 16 >> 2] - 1 << 2) >> 2];
    var $367 = _hi0bits($366);
    var $370 = 32 - $367 | 0;
    __label__ = 99;
    break;
   case 99:
    var $370;
    var $372 = $370 + $s2_4 & 31;
    var $_ = ($372 | 0) == 0 ? 0 : 32 - $372 | 0;
    if ($_ >>> 0 > 4) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    var $377 = $_ - 4 | 0;
    var $b2_5 = $377 + $b2_4 | 0;
    var $m2_1 = $377 + $m2_0 | 0;
    var $s2_5 = $377 + $s2_4 | 0;
    __label__ = 103;
    break;
   case 101:
    if ($_ >>> 0 < 4) {
      __label__ = 102;
      break;
    } else {
      var $b2_5 = $b2_4;
      var $m2_1 = $m2_0;
      var $s2_5 = $s2_4;
      __label__ = 103;
      break;
    }
   case 102:
    var $384 = $_ + 28 | 0;
    var $b2_5 = $384 + $b2_4 | 0;
    var $m2_1 = $384 + $m2_0 | 0;
    var $s2_5 = $384 + $s2_4 | 0;
    __label__ = 103;
    break;
   case 103:
    var $s2_5;
    var $m2_1;
    var $b2_5;
    if (($b2_5 | 0) > 0) {
      __label__ = 104;
      break;
    } else {
      var $b_2 = $b_1;
      __label__ = 105;
      break;
    }
   case 104:
    var $391 = _lshift($state, $b_1, $b2_5);
    var $b_2 = $391;
    __label__ = 105;
    break;
   case 105:
    var $b_2;
    if (($s2_5 | 0) > 0) {
      __label__ = 106;
      break;
    } else {
      var $S_1 = $S_0;
      __label__ = 107;
      break;
    }
   case 106:
    var $395 = _lshift($state, $S_0, $s2_5);
    var $S_1 = $395;
    __label__ = 107;
    break;
   case 107:
    var $S_1;
    if (($k_check_0 | 0) == 0) {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim_039;
      var $k_7 = $k_2;
      var $b_3 = $b_2;
      __label__ = 111;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $399 = _cmp($b_2, $S_1);
    if (($399 | 0) < 0) {
      __label__ = 109;
      break;
    } else {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim_039;
      var $k_7 = $k_2;
      var $b_3 = $b_2;
      __label__ = 111;
      break;
    }
   case 109:
    var $402 = $k_2 - 1 | 0;
    var $403 = _multadd($state, $b_2, 10, 0);
    if ($309) {
      __label__ = 110;
      break;
    } else {
      var $mhi_4 = $mhi_2;
      var $ilim_5 = $ilim1_038;
      var $k_7 = $402;
      var $b_3 = $403;
      __label__ = 111;
      break;
    }
   case 110:
    var $405 = _multadd($state, $mhi_2, 10, 0);
    var $mhi_4 = $405;
    var $ilim_5 = $ilim1_038;
    var $k_7 = $402;
    var $b_3 = $403;
    __label__ = 111;
    break;
   case 111:
    var $b_3;
    var $k_7;
    var $ilim_5;
    var $mhi_4;
    if (($ilim_5 | 0) < 1) {
      __label__ = 112;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 112:
    if (($__08 | 0) == 5 || ($__08 | 0) == 3) {
      __label__ = 113;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 113:
    if (($ilim_5 | 0) < 0) {
      var $S_2 = $S_1;
      var $mhi_5 = $mhi_4;
      var $b_4 = $b_3;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $412 = _multadd($state, $S_1, 5, 0);
    var $413 = _cmp($b_3, $412);
    if (($413 | 0) < 0) {
      var $S_2 = $412;
      var $mhi_5 = $mhi_4;
      var $b_4 = $b_3;
      var $416 = $260;
      __label__ = 115;
      break;
    } else {
      var $S_3 = $412;
      var $mhi_6 = $mhi_4;
      var $k_8 = $k_7;
      var $b_5 = $b_3;
      var $419 = $260;
      __label__ = 116;
      break;
    }
   case 115:
    var $416;
    var $b_4;
    var $mhi_5;
    var $S_2;
    HEAP8[$416] = 48;
    var $s_13 = $416 + 1 | 0;
    var $S_4 = $S_2;
    var $mhi_13 = $mhi_5;
    var $mlo_6 = 0;
    var $k_9 = 0;
    var $b_12 = $b_4;
    var $549 = $416;
    __label__ = 158;
    break;
   case 116:
    var $419;
    var $b_5;
    var $k_8;
    var $mhi_6;
    var $S_3;
    HEAP8[$419] = 49;
    var $s_13 = $419 + 1 | 0;
    var $S_4 = $S_3;
    var $mhi_13 = $mhi_6;
    var $mlo_6 = 0;
    var $k_9 = $k_8 + 1 | 0;
    var $b_12 = $b_5;
    var $549 = $419;
    __label__ = 158;
    break;
   case 117:
    if ($309) {
      __label__ = 118;
      break;
    } else {
      var $s_9 = $260;
      var $i_9 = 1;
      var $b_9 = $b_3;
      __label__ = 148;
      break;
    }
   case 118:
    if (($m2_1 | 0) > 0) {
      __label__ = 119;
      break;
    } else {
      var $mhi_7 = $mhi_4;
      __label__ = 120;
      break;
    }
   case 119:
    var $426 = _lshift($state, $mhi_4, $m2_1);
    var $mhi_7 = $426;
    __label__ = 120;
    break;
   case 120:
    var $mhi_7;
    if (($spec_case_0 | 0) == 0) {
      var $mhi_9_ph = $mhi_7;
      __label__ = 122;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $431 = HEAP32[$mhi_7 + 4 >> 2];
    var $432 = _Balloc($state, $431);
    var $434 = $432 + 12 | 0;
    var $440 = (HEAP32[$mhi_7 + 16 >> 2] << 2) + 8 | 0;
    _memcpy($434, $mhi_7 + 12 | 0, $440, 1);
    var $441 = _lshift($state, $432, 1);
    var $mhi_9_ph = $441;
    __label__ = 122;
    break;
   case 122:
    var $mhi_9_ph;
    var $442 = ($__08 | 0) == 1;
    var $444 = ($d_020$0 & 1) == 0 && ($d_020$1 & 0) == 0;
    var $s_8 = $260;
    var $mhi_9 = $mhi_9_ph;
    var $i_8 = 1;
    var $mlo_2 = $mhi_7;
    var $b_6 = $b_3;
    __label__ = 123;
    break;
   case 123:
    var $b_6;
    var $mlo_2;
    var $i_8;
    var $mhi_9;
    var $s_8;
    var $446 = _quorem($b_6, $S_1);
    var $447 = $446 + 48 | 0;
    var $448 = _cmp($b_6, $mlo_2);
    var $449 = _diff($state, $S_1, $mhi_9);
    if ((HEAP32[$449 + 12 >> 2] | 0) == 0) {
      __label__ = 125;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    _Bfree($state, $449);
    var $464 = 1;
    __label__ = 128;
    break;
   case 125:
    var $454 = _cmp($b_6, $449);
    _Bfree($state, $449);
    if (($454 | 0) != 0 | $442 | $444 ^ 1) {
      var $464 = $454;
      __label__ = 128;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    if (($447 | 0) == 57) {
      var $b_8 = $b_6;
      __label__ = 140;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $_31 = ($448 | 0) > 0 ? $446 + 49 | 0 : $447;
    HEAP8[$s_8] = $_31 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_6;
    var $549 = $260;
    __label__ = 158;
    break;
   case 128:
    var $464;
    if (($448 | 0) < 0) {
      __label__ = 130;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    if (($448 | 0) != 0 | $442 | $444 ^ 1) {
      __label__ = 138;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP32[$b_6 + 20 >> 2] | 0) == 0) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    if ((HEAP32[$b_6 + 16 >> 2] | 0) > 1 & ($464 | 0) > 0) {
      __label__ = 133;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $b_6;
      __label__ = 137;
      break;
    }
   case 132:
    if (($464 | 0) > 0) {
      __label__ = 133;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $b_6;
      __label__ = 137;
      break;
    }
   case 133:
    var $479 = _lshift($state, $b_6, 1);
    var $480 = _cmp($479, $S_1);
    if (($480 | 0) > 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    if (($480 | 0) == 0) {
      __label__ = 135;
      break;
    } else {
      var $dig_1 = $447;
      var $b_7 = $479;
      __label__ = 137;
      break;
    }
   case 135:
    if (($447 & 1 | 0) == 0) {
      var $dig_1 = $447;
      var $b_7 = $479;
      __label__ = 137;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $488 = $446 + 49 | 0;
    if (($447 | 0) == 57) {
      var $b_8 = $479;
      __label__ = 140;
      break;
    } else {
      var $dig_1 = $488;
      var $b_7 = $479;
      __label__ = 137;
      break;
    }
   case 137:
    var $b_7;
    var $dig_1;
    HEAP8[$s_8] = $dig_1 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_7;
    var $549 = $260;
    __label__ = 158;
    break;
   case 138:
    if (($464 | 0) > 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 139:
    if (($447 | 0) == 57) {
      var $b_8 = $b_6;
      __label__ = 140;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 140:
    var $b_8;
    HEAP8[$s_8] = 57;
    var $s_11_ph = $s_8 + 1 | 0;
    var $mhi_12_ph = $mhi_9;
    var $mlo_5_ph = $mlo_2;
    var $b_11_ph = $b_8;
    __label__ = 141;
    break;
   case 141:
    var $b_11_ph;
    var $mlo_5_ph;
    var $mhi_12_ph;
    var $s_11_ph;
    var $s_11 = $s_11_ph;
    __label__ = 153;
    break;
   case 142:
    HEAP8[$s_8] = $446 + 49 & 255;
    var $s_13 = $s_8 + 1 | 0;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_9;
    var $mlo_6 = $mlo_2;
    var $k_9 = $k_7;
    var $b_12 = $b_6;
    var $549 = $260;
    __label__ = 158;
    break;
   case 143:
    var $505 = $s_8 + 1 | 0;
    HEAP8[$s_8] = $447 & 255;
    if (($i_8 | 0) == ($ilim_5 | 0)) {
      var $s_10 = $505;
      var $mhi_11 = $mhi_9;
      var $mlo_4 = $mlo_2;
      var $b_10 = $b_6;
      __label__ = 152;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $508 = _multadd($state, $b_6, 10, 0);
    if (($mlo_2 | 0) == ($mhi_9 | 0)) {
      __label__ = 145;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 145:
    var $511 = _multadd($state, $mhi_9, 10, 0);
    var $mhi_10 = $511;
    var $mlo_3 = $511;
    __label__ = 147;
    break;
   case 146:
    var $513 = _multadd($state, $mlo_2, 10, 0);
    var $514 = _multadd($state, $mhi_9, 10, 0);
    var $mhi_10 = $514;
    var $mlo_3 = $513;
    __label__ = 147;
    break;
   case 147:
    var $mlo_3;
    var $mhi_10;
    var $s_8 = $505;
    var $mhi_9 = $mhi_10;
    var $i_8 = $i_8 + 1 | 0;
    var $mlo_2 = $mlo_3;
    var $b_6 = $508;
    __label__ = 123;
    break;
   case 148:
    var $b_9;
    var $i_9;
    var $s_9;
    var $517 = _quorem($b_9, $S_1);
    var $520 = $s_9 + 1 | 0;
    HEAP8[$s_9] = $517 + 48 & 255;
    if ((HEAP32[$b_9 + 20 >> 2] | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 149:
    if ((HEAP32[$b_9 + 16 >> 2] | 0) < 2) {
      var $s_13 = $520;
      var $S_4 = $S_1;
      var $mhi_13 = $mhi_4;
      var $mlo_6 = 0;
      var $k_9 = $k_7;
      var $b_12 = $b_9;
      var $549 = $260;
      __label__ = 158;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    if (($i_9 | 0) < ($ilim_5 | 0)) {
      __label__ = 151;
      break;
    } else {
      var $s_10 = $520;
      var $mhi_11 = $mhi_4;
      var $mlo_4 = 0;
      var $b_10 = $b_9;
      __label__ = 152;
      break;
    }
   case 151:
    var $531 = _multadd($state, $b_9, 10, 0);
    var $s_9 = $520;
    var $i_9 = $i_9 + 1 | 0;
    var $b_9 = $531;
    __label__ = 148;
    break;
   case 152:
    var $b_10;
    var $mlo_4;
    var $mhi_11;
    var $s_10;
    var $533 = _lshift($state, $b_10, 1);
    var $534 = _cmp($533, $S_1);
    if (($534 | 0) > -1) {
      var $s_11_ph = $s_10;
      var $mhi_12_ph = $mhi_11;
      var $mlo_5_ph = $mlo_4;
      var $b_11_ph = $533;
      __label__ = 141;
      break;
    } else {
      var $s_12 = $s_10;
      __label__ = 157;
      break;
    }
   case 153:
    var $s_11;
    var $537 = $s_11 - 1 | 0;
    var $538 = HEAP8[$537];
    if ($538 << 24 >> 24 == 57) {
      __label__ = 154;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 154:
    if (($537 | 0) == ($260 | 0)) {
      __label__ = 155;
      break;
    } else {
      var $s_11 = $537;
      __label__ = 153;
      break;
    }
   case 155:
    HEAP8[$537] = 49;
    var $s_13 = $s_11;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_12_ph;
    var $mlo_6 = $mlo_5_ph;
    var $k_9 = $k_7 + 1 | 0;
    var $b_12 = $b_11_ph;
    var $549 = $260;
    __label__ = 158;
    break;
   case 156:
    var $545 = $538 + 1 & 255;
    HEAP8[$537] = $545;
    var $s_13 = $s_11;
    var $S_4 = $S_1;
    var $mhi_13 = $mhi_12_ph;
    var $mlo_6 = $mlo_5_ph;
    var $k_9 = $k_7;
    var $b_12 = $b_11_ph;
    var $549 = $260;
    __label__ = 158;
    break;
   case 157:
    var $s_12;
    var $546 = $s_12 - 1 | 0;
    if (HEAP8[$546] << 24 >> 24 == 48) {
      var $s_12 = $546;
      __label__ = 157;
      break;
    } else {
      var $s_13 = $s_12;
      var $S_4 = $S_1;
      var $mhi_13 = $mhi_11;
      var $mlo_6 = $mlo_4;
      var $k_9 = $k_7;
      var $b_12 = $533;
      var $549 = $260;
      __label__ = 158;
      break;
    }
   case 158:
    var $549;
    var $b_12;
    var $k_9;
    var $mlo_6;
    var $mhi_13;
    var $S_4;
    var $s_13;
    _Bfree($state, $S_4);
    if (($mhi_13 | 0) == 0) {
      var $s_14 = $s_13;
      var $k_10 = $k_9;
      var $b_13 = $b_12;
      var $556 = $549;
      __label__ = 162;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    if (($mlo_6 | 0) == 0 | ($mlo_6 | 0) == ($mhi_13 | 0)) {
      __label__ = 161;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 160:
    _Bfree($state, $mlo_6);
    __label__ = 161;
    break;
   case 161:
    _Bfree($state, $mhi_13);
    var $s_14 = $s_13;
    var $k_10 = $k_9;
    var $b_13 = $b_12;
    var $556 = $549;
    __label__ = 162;
    break;
   case 162:
    var $556;
    var $b_13;
    var $k_10;
    var $s_14;
    _Bfree($state, $b_13);
    HEAP8[$s_14] = 0;
    HEAP32[$decpt >> 2] = $k_10 + 1 | 0;
    if (($rve | 0) == 0) {
      var $_0 = $556;
      __label__ = 164;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    HEAP32[$rve >> 2] = $s_14;
    var $_0 = $556;
    __label__ = 164;
    break;
   case 164:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_dtoa["X"] = 1;

function __ZL6divremP6Bigintj($b, $divisor) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $b + 16 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $b + 20 | 0;
    var $bp_0 = $b + 20 + ($2 << 2) | 0;
    var $remainder_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $remainder_0;
    var $bp_0;
    var $8 = $bp_0 - 4 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = $9 >>> 16;
    var $12 = $11 | $remainder_0 << 16;
    var $13 = Math.floor(($12 >>> 0) / ($divisor >>> 0));
    var $18 = $11 - $13 * $divisor << 16 | $9 & 65535;
    var $19 = Math.floor(($18 >>> 0) / ($divisor >>> 0));
    var $21 = $18 - $19 * $divisor | 0;
    HEAP32[$8 >> 2] = $13 << 16 | $19;
    if (($8 | 0) == ($5 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $bp_0 = $8;
      var $remainder_0 = $21;
      __label__ = 3;
      break;
    }
   case 4:
    if ((HEAP32[$b + 20 + ($2 - 1 << 2) >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $21;
      __label__ = 6;
      break;
    }
   case 5:
    var $32 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $32;
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7quorem2P6Biginti($b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k >> 5;
    var $2 = $k & 31;
    var $3 = $b + 16 | 0;
    var $5 = HEAP32[$3 >> 2] - $1 | 0;
    if (($5 | 0) < 1) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $b + 20 | 0;
    var $11 = $b + 20 + ($1 << 2) | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $13 = $12 >>> ($2 >>> 0);
    var $14 = $12 & (1 << $2) - 1;
    HEAP32[$11 >> 2] = $14;
    var $_pre = $1 + 1 | 0;
    if (($5 | 0) != 2 | ($2 | 0) == 0) {
      var $result_0 = $13;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $result_0 = HEAP32[$b + 20 + ($_pre << 2) >> 2] << 32 - $2 | $13;
    __label__ = 4;
    break;
   case 4:
    var $result_0;
    if (($14 | 0) == 0 & ($1 | 0) != 0) {
      var $bxe_01 = $11;
      var $n_02 = $_pre;
      __label__ = 5;
      break;
    } else {
      var $n_0_lcssa = $_pre;
      __label__ = 6;
      break;
    }
   case 5:
    var $n_02;
    var $bxe_01;
    var $26 = $n_02 - 1 | 0;
    var $27 = $bxe_01 - 4 | 0;
    if ((HEAP32[$27 >> 2] | 0) == 0 & ($27 | 0) != ($10 | 0)) {
      var $bxe_01 = $27;
      var $n_02 = $26;
      __label__ = 5;
      break;
    } else {
      var $n_0_lcssa = $26;
      __label__ = 6;
      break;
    }
   case 6:
    var $n_0_lcssa;
    HEAP32[$3 >> 2] = $n_0_lcssa;
    var $_0 = $result_0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _cmp($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$a + 16 >> 2];
    var $4 = HEAP32[$b + 16 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $2 - $4 | 0;
    __label__ = 7;
    break;
   case 3:
    var $9 = $a + 20 | 0;
    var $xb_0 = $b + 20 + ($4 << 2) | 0;
    var $xa_0 = $a + 20 + ($4 << 2) | 0;
    __label__ = 4;
    break;
   case 4:
    var $xa_0;
    var $xb_0;
    var $13 = $xa_0 - 4 | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $15 = $xb_0 - 4 | 0;
    var $16 = HEAPU32[$15 >> 2];
    if (($14 | 0) == ($16 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $14 >>> 0 < $16 >>> 0 ? -1 : 1;
    var $_0 = $20;
    __label__ = 7;
    break;
   case 6:
    if ($13 >>> 0 > $9 >>> 0) {
      var $xb_0 = $15;
      var $xa_0 = $13;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _freedtoa($state, $s) {
  var $1 = $s - 4 | 0;
  var $2 = $1;
  var $4 = HEAP32[$1 >> 2];
  HEAP32[$s >> 2] = $4;
  var $6 = 1 << $4;
  HEAP32[$s + 4 >> 2] = $6;
  _Bfree($state, $2);
  return;
}

function _js_dtobasestr($state, $base, $dinput) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $bits = __stackBase__ + 4;
    var $e1 = __stackBase__ + 8;
    var $bbits = __stackBase__ + 12;
    var $1 = __ZN2js11OffTheBooks7malloc_Ej(1078);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($dinput < 0) {
      __label__ = 3;
      break;
    } else {
      var $p_0 = $1;
      var $d_0_in = $dinput;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $1 + 1 | 0;
    HEAP8[$1] = 45;
    var $p_0 = $6;
    var $d_0_in = -$dinput;
    __label__ = 4;
    break;
   case 4:
    var $d_0_in;
    var $p_0;
    tempDoubleF64[0] = $d_0_in;
    var $d_0$0 = tempDoubleI32[0];
    var $d_0$1 = tempDoubleI32[1];
    var $10 = $d_0$1;
    if (($10 & 2146435072 | 0) == 2146435072) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if (($d_0$0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $20 = STRING_TABLE._js_NaN_str | 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $phitmp = ($10 & 1048575 | 0) == 0 ? STRING_TABLE._js_Infinity_str | 0 : STRING_TABLE._js_NaN_str | 0;
    var $20 = $phitmp;
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = _strcpy($p_0, $20);
    var $_0 = $1;
    __label__ = 54;
    break;
   case 8:
    var $23 = _floor($d_0_in);
    if ($23 > 4294967295) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $23 >= 0 ? Math.floor($23) : Math.ceil($23);
    if (($26 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $p_1 = $p_0;
      var $n_0 = $26;
      __label__ = 10;
      break;
    }
   case 10:
    var $n_0;
    var $p_1;
    var $28 = Math.floor(($n_0 >>> 0) / ($base >>> 0));
    var $30 = $n_0 - $28 * $base | 0;
    var $_v5 = $30 >>> 0 > 9 ? 87 : 48;
    var $34 = $p_1 + 1 | 0;
    HEAP8[$p_1] = $_v5 + $30 & 255;
    if (($28 | 0) == 0) {
      var $p_3 = $34;
      __label__ = 18;
      break;
    } else {
      var $p_1 = $34;
      var $n_0 = $28;
      __label__ = 10;
      break;
    }
   case 11:
    HEAP8[$p_0] = 48;
    var $p_3 = $p_0 + 1 | 0;
    __label__ = 18;
    break;
   case 12:
    var $39 = _d2b($state, $23, $e, $bits);
    if (($39 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $42 = HEAP32[$e >> 2];
    var $43 = _lshift($state, $39, $42);
    if (($43 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = $43 + 16 | 0;
    var $p_2 = $p_0;
    __label__ = 16;
    break;
   case 15:
    _Bfree($state, 0);
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 54;
    break;
   case 16:
    var $p_2;
    var $48 = __ZL6divremP6Bigintj($43, $base);
    var $_v = $48 >>> 0 > 9 ? 87 : 48;
    var $52 = $p_2 + 1 | 0;
    HEAP8[$p_2] = $_v + $48 & 255;
    if ((HEAP32[$45 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $p_2 = $52;
      __label__ = 16;
      break;
    }
   case 17:
    _Bfree($state, $43);
    var $p_3 = $52;
    __label__ = 18;
    break;
   case 18:
    var $p_3;
    var $q_013 = $p_3 - 1 | 0;
    if ($q_013 >>> 0 > $p_0 >>> 0) {
      var $pInt_014 = $p_0;
      var $q_015 = $q_013;
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $q_015;
    var $pInt_014;
    var $57 = HEAP8[$pInt_014];
    var $58 = HEAP8[$q_015];
    var $59 = $pInt_014 + 1 | 0;
    HEAP8[$pInt_014] = $58;
    HEAP8[$q_015] = $57;
    var $q_0 = $q_015 - 1 | 0;
    if ($q_0 >>> 0 > $59 >>> 0) {
      var $pInt_014 = $59;
      var $q_015 = $q_0;
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $61 = $d_0_in - $23;
    if ($61 != 0) {
      __label__ = 21;
      break;
    } else {
      var $p_5 = $p_3;
      __label__ = 53;
      break;
    }
   case 21:
    HEAP8[$p_3] = 46;
    var $64 = _d2b($state, $61, $e1, $bbits);
    if (($64 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = 0;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 22:
    var $b2_0;
    var $s_0;
    var $mlo_0;
    var $mhi_0;
    _Bfree($state, $b2_0);
    _Bfree($state, $s_0);
    if (($mlo_0 | 0) == ($mhi_0 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    _Bfree($state, $mlo_0);
    __label__ = 24;
    break;
   case 24:
    _Bfree($state, $mhi_0);
    __ZN2js10Foreground5free_EPv($1);
    var $_0 = 0;
    __label__ = 54;
    break;
   case 25:
    var $72 = ($d_0$1 >>> 20 | 0 << 12) & 2047;
    var $s2_0 = ($72 | 0) == 0 ? -1 : -$72 | 0;
    var $75 = $s2_0 + 1076 | 0;
    var $76 = _i2b($state, 1);
    if (($76 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = 0;
      var $b2_0 = $64;
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $79 = $d_0$0;
    if (($79 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $mhi_1 = $76;
      var $s2_1 = $75;
      __label__ = 29;
      break;
    }
   case 27:
    if (($10 & 1048575 | 0) != 0 | ($10 & 2145386496 | 0) == 0) {
      var $mhi_1 = $76;
      var $s2_1 = $75;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $87 = $s2_0 + 1077 | 0;
    var $88 = _i2b($state, 2);
    if (($88 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $64;
      __label__ = 22;
      break;
    } else {
      var $mhi_1 = $88;
      var $s2_1 = $87;
      __label__ = 29;
      break;
    }
   case 29:
    var $s2_1;
    var $mhi_1;
    var $92 = HEAP32[$e1 >> 2] + $s2_1 | 0;
    var $93 = _lshift($state, $64, $92);
    if (($93 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $96 = _i2b($state, 1);
    if (($96 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $93;
      __label__ = 22;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $99 = _lshift($state, $96, $s2_1);
    if (($99 | 0) == 0) {
      var $mhi_0 = $mhi_1;
      var $mlo_0 = $76;
      var $s_0 = 0;
      var $b2_0 = $93;
      __label__ = 22;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $101 = $79 & 1;
    var $mhi_2 = $mhi_1;
    var $mlo_1 = $76;
    var $p_4_pn = $p_3;
    var $b2_1 = $93;
    __label__ = 33;
    break;
   case 33:
    var $b2_1;
    var $p_4_pn;
    var $mlo_1;
    var $mhi_2;
    var $p_4 = $p_4_pn + 1 | 0;
    var $103 = _multadd($state, $b2_1, $base, 0);
    if (($103 | 0) == 0) {
      var $mhi_0 = $mhi_2;
      var $mlo_0 = $mlo_1;
      var $s_0 = $99;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $106 = __ZL7quorem2P6Biginti($103, $s2_1);
    var $107 = ($mlo_1 | 0) == ($mhi_2 | 0);
    var $108 = _multadd($state, $mlo_1, $base, 0);
    var $109 = ($108 | 0) == 0;
    if ($107) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    if ($109) {
      var $mhi_0 = 0;
      var $mlo_0 = 0;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      var $mhi_3 = $108;
      __label__ = 38;
      break;
    }
   case 36:
    if ($109) {
      var $mhi_0 = $mhi_2;
      var $mlo_0 = 0;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $113 = _multadd($state, $mhi_2, $base, 0);
    if (($113 | 0) == 0) {
      var $mhi_0 = 0;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      var $mhi_3 = $113;
      __label__ = 38;
      break;
    }
   case 38:
    var $mhi_3;
    var $116 = _cmp($103, $108);
    var $117 = _diff($state, $99, $mhi_3);
    if (($117 | 0) == 0) {
      var $mhi_0 = $mhi_3;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = $103;
      __label__ = 22;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ((HEAP32[$117 + 12 >> 2] | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    _Bfree($state, $117);
    var $131 = 1;
    __label__ = 43;
    break;
   case 41:
    var $124 = _cmp($103, $117);
    _Bfree($state, $117);
    if (($124 | $101 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      var $131 = $124;
      __label__ = 43;
      break;
    }
   case 42:
    var $digit_2_ph = (($116 | 0) > 0 & 1) + $106 | 0;
    var $b2_3_ph = $103;
    __label__ = 50;
    break;
   case 43:
    var $131;
    if (($116 | 0) < 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if (($116 | $101 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 45:
    if (($131 | 0) > 0) {
      __label__ = 46;
      break;
    } else {
      var $digit_2_ph = $106;
      var $b2_3_ph = $103;
      __label__ = 50;
      break;
    }
   case 46:
    var $139 = _lshift($state, $103, 1);
    if (($139 | 0) == 0) {
      var $mhi_0 = $mhi_3;
      var $mlo_0 = $108;
      var $s_0 = $99;
      var $b2_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $142 = _cmp($139, $99);
    var $digit_2_ph = (($142 | 0) > 0 & 1) + $106 | 0;
    var $b2_3_ph = $139;
    __label__ = 50;
    break;
   case 48:
    var $146 = ($131 | 0) > 0;
    var $_8 = ($146 & 1) + $106 | 0;
    if ($146) {
      var $digit_2_ph = $_8;
      var $b2_3_ph = $103;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $_v4 = $_8 >>> 0 > 9 ? 87 : 48;
    HEAP8[$p_4] = $_v4 + $_8 & 255;
    var $mhi_2 = $mhi_3;
    var $mlo_1 = $108;
    var $p_4_pn = $p_4;
    var $b2_1 = $103;
    __label__ = 33;
    break;
   case 50:
    var $b2_3_ph;
    var $digit_2_ph;
    var $_v422 = $digit_2_ph >>> 0 > 9 ? 87 : 48;
    var $155 = $p_4_pn + 2 | 0;
    HEAP8[$p_4] = $_v422 + $digit_2_ph & 255;
    _Bfree($state, $b2_3_ph);
    _Bfree($state, $99);
    if (($108 | 0) == ($mhi_3 | 0)) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    _Bfree($state, $108);
    __label__ = 52;
    break;
   case 52:
    _Bfree($state, $mhi_3);
    var $p_5 = $155;
    __label__ = 53;
    break;
   case 53:
    var $p_5;
    HEAP8[$p_5] = 0;
    var $_0 = $1;
    __label__ = 54;
    break;
   case 54:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_dtobasestr["X"] = 1;

function _d2b($state, $d_0, $e, $bits) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = $d_0;
    var $1$0 = tempDoubleI32[0];
    var $1$1 = tempDoubleI32[1];
    var $y = STACKTOP;
    STACKTOP += 4;
    var $z = STACKTOP;
    STACKTOP += 4;
    var $2 = _Balloc($state, 1);
    var $3 = $2 + 20 | 0;
    var $6 = $1$1 & 1048575;
    var $9 = ($1$1 >>> 20 | 0 << 12) & 2047;
    var $10 = ($9 | 0) != 0;
    var $storemerge2 = $10 ? $6 | 1048576 : $6;
    HEAP32[$z >> 2] = $storemerge2;
    var $12 = $1$0;
    HEAP32[$y >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = _lo0bits($y);
    var $17 = HEAPU32[$y >> 2];
    if (($15 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$3 >> 2] = $storemerge2 << 32 - $15 | $17;
    var $22 = $storemerge2 >>> ($15 >>> 0);
    HEAP32[$z >> 2] = $22;
    var $25 = $22;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$3 >> 2] = $17;
    var $25 = $storemerge2;
    __label__ = 5;
    break;
   case 5:
    var $25;
    HEAP32[$2 + 24 >> 2] = $25;
    var $28 = ($25 | 0) != 0 ? 2 : 1;
    HEAP32[$2 + 16 >> 2] = $28;
    var $i_0 = $28;
    var $k_0 = $15;
    __label__ = 7;
    break;
   case 6:
    var $31 = _lo0bits($z);
    var $32 = HEAP32[$z >> 2];
    HEAP32[$3 >> 2] = $32;
    HEAP32[$2 + 16 >> 2] = 1;
    var $i_0 = 1;
    var $k_0 = $31 + 32 | 0;
    __label__ = 7;
    break;
   case 7:
    var $k_0;
    var $i_0;
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$e >> 2] = $9 - 1075 + $k_0 | 0;
    var $storemerge = 53 - $k_0 | 0;
    __label__ = 10;
    break;
   case 9:
    HEAP32[$e >> 2] = $k_0 - 1074 | 0;
    var $42 = $i_0 << 5;
    var $45 = HEAP32[$2 + 20 + ($i_0 - 1 << 2) >> 2];
    var $46 = _hi0bits($45);
    var $storemerge = $42 - $46 | 0;
    __label__ = 10;
    break;
   case 10:
    var $storemerge;
    HEAP32[$bits >> 2] = $storemerge;
    STACKTOP = __stackBase__;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_d2b["X"] = 1;

function _lshift($state, $b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k >> 5;
    var $3 = HEAP32[$b + 4 >> 2];
    var $4 = $b + 16 | 0;
    var $6 = HEAP32[$4 >> 2] + $1 | 0;
    var $7 = $6 + 1 | 0;
    var $9 = HEAP32[$b + 8 >> 2];
    if (($7 | 0) > ($9 | 0)) {
      var $k1_04 = $3;
      var $i_05 = $9;
      __label__ = 2;
      break;
    } else {
      var $k1_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 2:
    var $i_05;
    var $k1_04;
    var $11 = $k1_04 + 1 | 0;
    var $12 = $i_05 << 1;
    if (($7 | 0) > ($12 | 0)) {
      var $k1_04 = $11;
      var $i_05 = $12;
      __label__ = 2;
      break;
    } else {
      var $k1_0_lcssa = $11;
      __label__ = 3;
      break;
    }
   case 3:
    var $k1_0_lcssa;
    var $14 = _Balloc($state, $k1_0_lcssa);
    var $15 = $14 + 20 | 0;
    if (($1 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $x1_0_lcssa = $15;
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = $k >> 3 & -4;
    var $scevgep13 = $15;
    _memset($scevgep13, 0, $18, 4);
    var $x1_0_lcssa = $18 + ($14 + 20) | 0;
    __label__ = 5;
    break;
   case 5:
    var $x1_0_lcssa;
    var $22 = $b + 20 | 0;
    var $24 = $b + 20 + (HEAP32[$4 >> 2] << 2) | 0;
    var $25 = $k & 31;
    if (($25 | 0) == 0) {
      var $x1_2 = $x1_0_lcssa;
      var $x_1 = $22;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = 32 - $25 | 0;
    var $z_0 = 0;
    var $x1_1 = $x1_0_lcssa;
    var $x_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $x_0;
    var $x1_1;
    var $z_0;
    var $32 = HEAP32[$x_0 >> 2] << $25 | $z_0;
    var $33 = $x1_1 + 4 | 0;
    HEAP32[$x1_1 >> 2] = $32;
    var $34 = $x_0 + 4 | 0;
    var $36 = HEAPU32[$x_0 >> 2] >>> ($28 >>> 0);
    if ($34 >>> 0 < $24 >>> 0) {
      var $z_0 = $36;
      var $x1_1 = $33;
      var $x_0 = $34;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$33 >> 2] = $36;
    var $_ = ($36 | 0) == 0 ? $7 : $6 + 2 | 0;
    var $n1_0 = $_;
    __label__ = 10;
    break;
   case 9:
    var $x_1;
    var $x1_2;
    var $41 = $x_1 + 4 | 0;
    var $42 = HEAP32[$x_1 >> 2];
    HEAP32[$x1_2 >> 2] = $42;
    if ($41 >>> 0 < $24 >>> 0) {
      var $x1_2 = $x1_2 + 4 | 0;
      var $x_1 = $41;
      __label__ = 9;
      break;
    } else {
      var $n1_0 = $7;
      __label__ = 10;
      break;
    }
   case 10:
    var $n1_0;
    HEAP32[$14 + 16 >> 2] = $n1_0 - 1 | 0;
    _Bfree($state, $b);
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_lshift["X"] = 1;

function _Bfree($state, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($v | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$v + 4 >> 2];
    if (($4 | 0) > 7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $v;
    __Z9dtoa_freePv($7);
    __label__ = 5;
    break;
   case 4:
    var $9 = $state + ($4 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    HEAP32[$v >> 2] = $10;
    HEAP32[$9 >> 2] = $v;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _i2b($state, $i) {
  var $1 = _Balloc($state, 1);
  HEAP32[$1 + 20 >> 2] = $i;
  HEAP32[$1 + 16 >> 2] = 1;
  return $1;
}

function _multadd($state, $b, $m, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $b + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4$1 = ($a | 0) < 0 ? -1 : 0;
    var $5$0 = $m;
    var $5$1 = ($m | 0) < 0 ? -1 : 0;
    var $carry_0$1 = $4$1;
    var $carry_0$0 = $a;
    var $x_0 = $b + 20 | 0;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $x_0;
    var $carry_0$0;
    var $carry_0$1;
    var $8$0 = HEAP32[$x_0 >> 2];
    var $9$0 = (i64Math.multiply($8$0, 0, $5$0, $5$1), i64Math.result[0]);
    var $9$1 = i64Math.result[1];
    var $10$0 = (i64Math.add($9$0, $9$1, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $10$1 = i64Math.result[1];
    var $11$0 = $10$1;
    var $11$1 = 0;
    var $12 = $10$0;
    HEAP32[$x_0 >> 2] = $12;
    var $14 = $i_0 + 1 | 0;
    if (($14 | 0) < ($2 | 0)) {
      var $carry_0$1 = $11$1;
      var $carry_0$0 = $11$0;
      var $x_0 = $x_0 + 4 | 0;
      var $i_0 = $14;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($11$0 == 0 && $11$1 == 0) {
      var $_1 = $b;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($2 | 0) < (HEAP32[$b + 8 >> 2] | 0)) {
      var $_0 = $b;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$b + 4 >> 2] + 1 | 0;
    var $26 = _Balloc($state, $25);
    var $28 = $26 + 12 | 0;
    var $30 = $b + 12 | 0;
    var $33 = (HEAP32[$1 >> 2] << 2) + 8 | 0;
    _memcpy($28, $30, $33, 1);
    _Bfree($state, $b);
    var $_0 = $26;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    var $36 = $2 + 1 | 0;
    var $37 = $_0 + 20 + ($2 << 2) | 0;
    HEAP32[$37 >> 2] = $11$0;
    HEAP32[$_0 + 16 >> 2] = $36;
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_multadd["X"] = 1;

function _diff($state, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _cmp($a, $b);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _Balloc($state, 0);
    HEAP32[$4 + 16 >> 2] = 1;
    HEAP32[$4 + 20 >> 2] = 0;
    var $_0 = $4;
    __label__ = 10;
    break;
   case 3:
    var $8 = ($1 | 0) < 0;
    var $_lobit = $1 >>> 31;
    var $a_b = $8 ? $a : $b;
    var $b_a = $8 ? $b : $a;
    var $10 = HEAP32[$b_a + 4 >> 2];
    var $11 = _Balloc($state, $10);
    var $12 = $11 + 12 | 0;
    HEAP32[$12 >> 2] = $_lobit;
    var $14 = HEAPU32[$b_a + 16 >> 2];
    var $19 = $a_b + 20 + (HEAP32[$a_b + 16 >> 2] << 2) | 0;
    var $borrow_0$1 = 0;
    var $borrow_0$0 = 0;
    var $xa_0 = $b_a + 20 | 0;
    var $xc_0 = $11 + 20 | 0;
    var $xb_0 = $a_b + 20 | 0;
    __label__ = 4;
    break;
   case 4:
    var $xb_0;
    var $xc_0;
    var $xa_0;
    var $borrow_0$0;
    var $borrow_0$1;
    var $22 = $xa_0 + 4 | 0;
    var $24$0 = HEAP32[$xa_0 >> 2];
    var $25 = $xb_0 + 4 | 0;
    var $27$0 = HEAP32[$xb_0 >> 2];
    var $28$0 = (i64Math.subtract($24$0, 0, $27$0, 0), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29$0 = (i64Math.subtract($28$0, $28$1, $borrow_0$0, $borrow_0$1), i64Math.result[0]);
    var $29$1 = i64Math.result[1];
    var $31$0 = $29$1 & 1;
    var $31$1 = 0 & 0;
    var $32 = $29$0;
    var $33 = $xc_0 + 4 | 0;
    HEAP32[$xc_0 >> 2] = $32;
    if ($25 >>> 0 < $19 >>> 0) {
      var $borrow_0$1 = $31$1;
      var $borrow_0$0 = $31$0;
      var $xa_0 = $22;
      var $xc_0 = $33;
      var $xb_0 = $25;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $35 = $b_a + 20 + ($14 << 2) | 0;
    if ($22 >>> 0 < $35 >>> 0) {
      var $xc_15 = $33;
      var $xa_16 = $22;
      var $borrow_17$1 = $31$1;
      var $borrow_17$0 = $31$0;
      __label__ = 7;
      break;
    } else {
      var $xc_1_lcssa = $33;
      __label__ = 6;
      break;
    }
   case 6:
    var $xc_1_lcssa;
    var $37 = $xc_1_lcssa - 4 | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $wa_03 = $14;
      var $49 = $37;
      __label__ = 8;
      break;
    } else {
      var $wa_0_lcssa = $14;
      __label__ = 9;
      break;
    }
   case 7:
    var $borrow_17$0;
    var $borrow_17$1;
    var $xa_16;
    var $xc_15;
    var $40 = $xa_16 + 4 | 0;
    var $42$0 = HEAP32[$xa_16 >> 2];
    var $43$0 = (i64Math.subtract($42$0, 0, $borrow_17$0, $borrow_17$1), i64Math.result[0]);
    var $43$1 = i64Math.result[1];
    var $45$0 = $43$1 & 1;
    var $46 = $43$0;
    var $47 = $xc_15 + 4 | 0;
    HEAP32[$xc_15 >> 2] = $46;
    if ($40 >>> 0 < $35 >>> 0) {
      var $xc_15 = $47;
      var $xa_16 = $40;
      var $borrow_17$1 = 0 & 0;
      var $borrow_17$0 = $45$0;
      __label__ = 7;
      break;
    } else {
      var $xc_1_lcssa = $47;
      __label__ = 6;
      break;
    }
   case 8:
    var $49;
    var $wa_03;
    var $50 = $wa_03 - 1 | 0;
    var $51 = $49 - 4 | 0;
    if ((HEAP32[$51 >> 2] | 0) == 0) {
      var $wa_03 = $50;
      var $49 = $51;
      __label__ = 8;
      break;
    } else {
      var $wa_0_lcssa = $50;
      __label__ = 9;
      break;
    }
   case 9:
    var $wa_0_lcssa;
    var $54 = $11 + 16 | 0;
    HEAP32[$54 >> 2] = $wa_0_lcssa;
    var $_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_diff["X"] = 1;

function _js_NewDtoaState() {
  var $1 = _newdtoa();
  return $1;
}

function _newdtoa() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z11dtoa_mallocj(2344);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memset($1, 0, 2344, 1);
    HEAP32[$1 + 2340 >> 2] = $1 + 36 | 0;
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DestroyDtoaState($state) {
  _destroydtoa($state);
  return;
}

function _destroydtoa($state) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $state + 36 | 0;
    var $2 = $state + 2340 | 0;
    var $i_03 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_03;
    var $5 = HEAP32[$state + ($i_03 << 2) >> 2];
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $v_02 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $v_02;
    var $8 = HEAPU32[$v_02 >> 2];
    var $9 = $v_02;
    if ($9 >>> 0 >= $1 >>> 0 & $9 >>> 0 < $2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if (($8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $v_02 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    __Z9dtoa_freePv($v_02);
    __label__ = 4;
    break;
   case 6:
    var $15 = $i_03 + 1 | 0;
    if (($15 | 0) == 8) {
      __label__ = 7;
      break;
    } else {
      var $i_03 = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = $state;
    __Z9dtoa_freePv($17);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9dtoa_freePv($p) {
  __ZN2js10Foreground5free_EPv($p);
  return;
}

function __Z11dtoa_mallocj($size) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($size);
  return $1;
}

function _lo0bits($y) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$y >> 2];
    if (($1 & 7 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    if (($1 & 2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$y >> 2] = $1 >>> 1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 5:
    HEAP32[$y >> 2] = $1 >>> 2;
    var $_0 = 2;
    __label__ = 15;
    break;
   case 6:
    var $17 = ($1 & 65535 | 0) == 0;
    var $_ = $17 ? $1 >>> 16 : $1;
    var $k_0 = $17 ? 16 : 0;
    if (($_ & 255 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $x_1 = $_;
      var $k_1 = $k_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $x_1 = $_ >>> 8;
    var $k_1 = $k_0 | 8;
    __label__ = 8;
    break;
   case 8:
    var $k_1;
    var $x_1;
    if (($x_1 & 15 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $x_2 = $x_1;
      var $k_2 = $k_1;
      __label__ = 10;
      break;
    }
   case 9:
    var $x_2 = $x_1 >>> 4;
    var $k_2 = $k_1 + 4 | 0;
    __label__ = 10;
    break;
   case 10:
    var $k_2;
    var $x_2;
    if (($x_2 & 3 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $x_3 = $x_2;
      var $k_3 = $k_2;
      __label__ = 12;
      break;
    }
   case 11:
    var $x_3 = $x_2 >>> 2;
    var $k_3 = $k_2 + 2 | 0;
    __label__ = 12;
    break;
   case 12:
    var $k_3;
    var $x_3;
    if (($x_3 & 1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $x_4 = $x_3;
      var $k_4 = $k_3;
      __label__ = 14;
      break;
    }
   case 13:
    var $40 = $x_3 >>> 1;
    if (($40 | 0) == 0) {
      var $_0 = 32;
      __label__ = 15;
      break;
    } else {
      var $x_4 = $40;
      var $k_4 = $k_3 + 1 | 0;
      __label__ = 14;
      break;
    }
   case 14:
    var $k_4;
    var $x_4;
    HEAP32[$y >> 2] = $x_4;
    var $_0 = $k_4;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_lo0bits["X"] = 1;

function _hi0bits($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $x >>> 0 > 65535;
    var $x_ = $2 ? $x : $x << 16;
    var $k_0 = $2 ? 0 : 16;
    if ($x_ >>> 0 > 16777215) {
      var $_1 = $x_;
      var $k_1 = $k_0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_1 = $x_ << 8;
    var $k_1 = $k_0 | 8;
    __label__ = 3;
    break;
   case 3:
    var $k_1;
    var $_1;
    if ($_1 >>> 0 > 268435455) {
      var $_2 = $_1;
      var $k_2 = $k_1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_2 = $_1 << 4;
    var $k_2 = $k_1 + 4 | 0;
    __label__ = 5;
    break;
   case 5:
    var $k_2;
    var $_2;
    if ($_2 >>> 0 > 1073741823) {
      var $_3 = $_2;
      var $k_3 = $k_2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_3 = $_2 << 2;
    var $k_3 = $k_2 + 2 | 0;
    __label__ = 7;
    break;
   case 7:
    var $k_3;
    var $_3;
    if (($_3 | 0) < 0) {
      var $k_4 = $k_3;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($_3 & 1073741824 | 0) == 0) {
      var $_0 = 32;
      __label__ = 10;
      break;
    } else {
      var $k_4 = $k_3 + 1 | 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $k_4;
    var $_0 = $k_4;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _ulp($x_0) {
  tempDoubleF64[0] = $x_0;
  var $7$1 = (tempDoubleI32[1] & 2146435072) - 54525952 | 0;
  var $8 = (tempDoubleI32[0] = 0, tempDoubleI32[1] = $7$1, tempDoubleF64[0]);
  return $8;
}

function _Balloc($state, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($k | 0) < 8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $state + ($k << 2) | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$3 >> 2] = $8;
    var $rv_1 = $4;
    __label__ = 9;
    break;
   case 4:
    var $10 = 1 << $k;
    var $32 = $10;
    var $31 = ($10 << 2) + 27 | 0;
    __label__ = 7;
    break;
   case 5:
    var $14 = 1 << $k;
    var $16 = ($14 << 2) + 27 | 0;
    var $17 = $16 >>> 3;
    var $18 = $state + 2340 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ((($19 - ($state + 36) >> 3) + $17 | 0) >>> 0 < 289) {
      __label__ = 6;
      break;
    } else {
      var $32 = $14;
      var $31 = $16;
      __label__ = 7;
      break;
    }
   case 6:
    var $28 = $19;
    HEAP32[$18 >> 2] = $19 + ($17 << 3) | 0;
    var $rv_0 = $28;
    var $37 = $14;
    __label__ = 8;
    break;
   case 7:
    var $31;
    var $32;
    var $34 = __Z11dtoa_mallocj($31 & -8);
    var $rv_0 = $34;
    var $37 = $32;
    __label__ = 8;
    break;
   case 8:
    var $37;
    var $rv_0;
    HEAP32[$rv_0 + 4 >> 2] = $k;
    HEAP32[$rv_0 + 8 >> 2] = $37;
    var $rv_1 = $rv_0;
    __label__ = 9;
    break;
   case 9:
    var $rv_1;
    HEAP32[$rv_1 + 16 >> 2] = 0;
    HEAP32[$rv_1 + 12 >> 2] = 0;
    return $rv_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_Balloc["X"] = 1;

function _nrv_alloc($state, $s, $rve, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _rv_alloc($state, $n);
    var $2 = HEAP8[$s];
    HEAP8[$1] = $2;
    if ($2 << 24 >> 24 == 0) {
      var $t_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $_01 = $s;
      var $t_02 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $t_02;
    var $_01;
    var $4 = $_01 + 1 | 0;
    var $5 = $t_02 + 1 | 0;
    var $6 = HEAP8[$4];
    HEAP8[$5] = $6;
    if ($6 << 24 >> 24 == 0) {
      var $t_0_lcssa = $5;
      __label__ = 3;
      break;
    } else {
      var $_01 = $4;
      var $t_02 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $t_0_lcssa;
    if (($rve | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$rve >> 2] = $t_0_lcssa;
    __label__ = 5;
    break;
   case 5:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _rv_alloc($state, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($i >>> 0 < 20) {
      var $k_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $j_01 = 4;
      var $k_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $k_02;
    var $j_01;
    var $2 = $k_02 + 1 | 0;
    var $3 = $j_01 << 1;
    if (($3 + 16 | 0) >>> 0 > $i >>> 0) {
      var $k_0_lcssa = $2;
      __label__ = 3;
      break;
    } else {
      var $j_01 = $3;
      var $k_02 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    var $k_0_lcssa;
    var $6 = _Balloc($state, $k_0_lcssa);
    HEAP32[$6 >> 2] = $k_0_lcssa;
    return $6 + 4 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _pow5mult($state, $b, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $k & 3;
    if (($1 | 0) == 0) {
      var $_01 = $b;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[_p05 + ($1 - 1 << 2) >> 2];
    var $7 = _multadd($state, $b, $6, 0);
    var $_01 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_01;
    var $9 = $k >> 2;
    if (($9 | 0) == 0) {
      var $_0 = $_01;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $state + 32 | 0;
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $_01;
      var $_02 = $9;
      var $p5_0 = $13;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = _i2b($state, 625);
    HEAP32[$12 >> 2] = $16;
    HEAP32[$16 >> 2] = 0;
    var $_1 = $_01;
    var $_02 = $9;
    var $p5_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $p5_0;
    var $_02;
    var $_1;
    if (($_02 & 1 | 0) == 0) {
      var $_2 = $_1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = _mult($state, $_1, $p5_0);
    _Bfree($state, $_1);
    var $_2 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_2;
    var $23 = $_02 >> 1;
    if (($23 | 0) == 0) {
      var $_0 = $_2;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $p5_0 | 0;
    var $27 = HEAP32[$26 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_1 = $_2;
      var $_02 = $23;
      var $p5_0 = $27;
      __label__ = 6;
      break;
    }
   case 10:
    var $30 = _mult($state, $p5_0, $p5_0);
    HEAP32[$26 >> 2] = $30;
    HEAP32[$30 >> 2] = 0;
    var $_1 = $_2;
    var $_02 = $23;
    var $p5_0 = $30;
    __label__ = 6;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _mult($state, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = (HEAP32[$a + 16 >> 2] | 0) < (HEAP32[$b + 16 >> 2] | 0);
    var $_01 = $5 ? $a : $b;
    var $_0 = $5 ? $b : $a;
    var $9 = HEAPU32[$_0 + 16 >> 2];
    var $11 = HEAPU32[$_01 + 16 >> 2];
    var $12 = $11 + $9 | 0;
    var $k_0 = (($12 | 0) > (HEAP32[$_0 + 8 >> 2] | 0) & 1) + HEAP32[$_0 + 4 >> 2] | 0;
    var $17 = _Balloc($state, $k_0);
    var $18 = $17 + 20 | 0;
    var $19 = $17 + 20 + ($12 << 2) | 0;
    if (($12 | 0) > 0) {
      var $x_06 = $18;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $x_06;
    HEAP32[$x_06 >> 2] = 0;
    var $21 = $x_06 + 4 | 0;
    if ($21 >>> 0 < $19 >>> 0) {
      var $x_06 = $21;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = $_0 + 20 | 0;
    var $24 = $_0 + 20 + ($9 << 2) | 0;
    var $25 = $_01 + 20 + ($11 << 2) | 0;
    if (($11 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $xc_1 = $19;
      var $wc_0 = $12;
      __label__ = 10;
      break;
    }
   case 4:
    var $xb_04 = $_01 + 20 | 0;
    var $xc0_05 = $18;
    __label__ = 5;
    break;
   case 5:
    var $xc0_05;
    var $xb_04;
    var $29 = $xb_04 + 4 | 0;
    var $30 = HEAP32[$xb_04 >> 2];
    if (($30 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32$0 = $30;
    var $32$1 = 0;
    var $carry_0$1 = 0;
    var $carry_0$0 = 0;
    var $xc_0 = $xc0_05;
    var $x_1 = $23;
    __label__ = 7;
    break;
   case 7:
    var $x_1;
    var $xc_0;
    var $carry_0$0;
    var $carry_0$1;
    var $34 = $x_1 + 4 | 0;
    var $36$0 = HEAP32[$x_1 >> 2];
    var $37$0 = (i64Math.multiply($36$0, 0, $32$0, $32$1), i64Math.result[0]);
    var $37$1 = i64Math.result[1];
    var $39$0 = HEAP32[$xc_0 >> 2];
    var $40$0 = (i64Math.add($39$0, 0, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $40$1 = i64Math.result[1];
    var $41$0 = (i64Math.add($40$0, $40$1, $37$0, $37$1), i64Math.result[0]);
    var $41$1 = i64Math.result[1];
    var $42$0 = $41$1;
    var $43 = $41$0;
    var $44 = $xc_0 + 4 | 0;
    HEAP32[$xc_0 >> 2] = $43;
    if ($34 >>> 0 < $24 >>> 0) {
      var $carry_0$1 = 0;
      var $carry_0$0 = $42$0;
      var $xc_0 = $44;
      var $x_1 = $34;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$44 >> 2] = $42$0;
    __label__ = 9;
    break;
   case 9:
    if ($29 >>> 0 < $25 >>> 0) {
      var $xb_04 = $29;
      var $xc0_05 = $xc0_05 + 4 | 0;
      __label__ = 5;
      break;
    } else {
      var $xc_1 = $19;
      var $wc_0 = $12;
      __label__ = 10;
      break;
    }
   case 10:
    var $wc_0;
    var $xc_1;
    if (($wc_0 | 0) > 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $53 = $xc_1 - 4 | 0;
    if ((HEAP32[$53 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $xc_1 = $53;
    var $wc_0 = $wc_0 - 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $58 = $17 + 16 | 0;
    HEAP32[$58 >> 2] = $wc_0;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_mult["X"] = 1;

function _quorem($b, $S) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$S + 16 >> 2];
    var $3 = $b + 16 | 0;
    if ((HEAP32[$3 >> 2] | 0) < ($2 | 0)) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $S + 20 | 0;
    var $8 = $2 - 1 | 0;
    var $9 = $S + 20 + ($8 << 2) | 0;
    var $10 = $b + 20 | 0;
    var $11 = $b + 20 + ($8 << 2) | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $14 = HEAP32[$9 >> 2] + 1 | 0;
    var $15 = Math.floor(($12 >>> 0) / ($14 >>> 0));
    if (($15 | 0) == 0) {
      var $n_1 = $8;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17$0 = $15;
    var $17$1 = 0;
    var $bx_0 = $10;
    var $sx_0 = $7;
    var $carry_0$1 = 0;
    var $carry_0$0 = 0;
    var $borrow_0$1 = 0;
    var $borrow_0$0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $borrow_0$0;
    var $borrow_0$1;
    var $carry_0$0;
    var $carry_0$1;
    var $sx_0;
    var $bx_0;
    var $19 = $sx_0 + 4 | 0;
    var $21$0 = HEAP32[$sx_0 >> 2];
    var $22$0 = (i64Math.multiply($21$0, 0, $17$0, $17$1), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    var $23$0 = (i64Math.add($22$0, $22$1, $carry_0$0, $carry_0$1), i64Math.result[0]);
    var $23$1 = i64Math.result[1];
    var $24$0 = $23$1;
    var $24$1 = 0;
    var $26$0 = HEAP32[$bx_0 >> 2];
    var $27$0 = $23$0 & -1;
    var $27$1 = $23$1 & 0;
    var $28$0 = (i64Math.subtract($26$0, 0, $27$0, $27$1), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29$0 = (i64Math.subtract($28$0, $28$1, $borrow_0$0, $borrow_0$1), i64Math.result[0]);
    var $29$1 = i64Math.result[1];
    var $31$0 = $29$1 & 1;
    var $32 = $29$0;
    HEAP32[$bx_0 >> 2] = $32;
    if ($19 >>> 0 > $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $bx_0 = $bx_0 + 4 | 0;
      var $sx_0 = $19;
      var $carry_0$1 = $24$1;
      var $carry_0$0 = $24$0;
      var $borrow_0$1 = 0 & 0;
      var $borrow_0$0 = $31$0;
      __label__ = 4;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      var $n_0 = $8;
      var $bxe_0 = $11;
      __label__ = 6;
      break;
    } else {
      var $n_1 = $8;
      __label__ = 10;
      break;
    }
   case 6:
    var $bxe_0;
    var $n_0;
    var $38 = $bxe_0 - 4 | 0;
    if ($38 >>> 0 > $10 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ((HEAP32[$38 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $n_0 = $n_0 - 1 | 0;
    var $bxe_0 = $38;
    __label__ = 6;
    break;
   case 9:
    HEAP32[$3 >> 2] = $n_0;
    var $n_1 = $n_0;
    __label__ = 10;
    break;
   case 10:
    var $n_1;
    var $46 = _cmp($b, $S);
    if (($46 | 0) > -1) {
      var $bx_1 = $10;
      var $sx_1 = $7;
      var $carry_1$1 = 0;
      var $carry_1$0 = 0;
      var $borrow_1$1 = 0;
      var $borrow_1$0 = 0;
      __label__ = 11;
      break;
    } else {
      var $_0 = $15;
      __label__ = 17;
      break;
    }
   case 11:
    var $borrow_1$0;
    var $borrow_1$1;
    var $carry_1$0;
    var $carry_1$1;
    var $sx_1;
    var $bx_1;
    var $48 = $sx_1 + 4 | 0;
    var $50$0 = HEAP32[$sx_1 >> 2];
    var $51$0 = (i64Math.add($50$0, 0, $carry_1$0, $carry_1$1), i64Math.result[0]);
    var $51$1 = i64Math.result[1];
    var $52$0 = $51$1;
    var $52$1 = 0;
    var $54$0 = HEAP32[$bx_1 >> 2];
    var $55$0 = $51$0 & -1;
    var $55$1 = $51$1 & 0;
    var $56$0 = (i64Math.subtract($54$0, 0, $55$0, $55$1), i64Math.result[0]);
    var $56$1 = i64Math.result[1];
    var $57$0 = (i64Math.subtract($56$0, $56$1, $borrow_1$0, $borrow_1$1), i64Math.result[0]);
    var $57$1 = i64Math.result[1];
    var $59$0 = $57$1 & 1;
    var $60 = $57$0;
    HEAP32[$bx_1 >> 2] = $60;
    if ($48 >>> 0 > $9 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $bx_1 = $bx_1 + 4 | 0;
      var $sx_1 = $48;
      var $carry_1$1 = $52$1;
      var $carry_1$0 = $52$0;
      var $borrow_1$1 = 0 & 0;
      var $borrow_1$0 = $59$0;
      __label__ = 11;
      break;
    }
   case 12:
    var $64 = $15 + 1 | 0;
    var $65 = $b + 20 + ($n_1 << 2) | 0;
    if ((HEAP32[$65 >> 2] | 0) == 0) {
      var $n_2 = $n_1;
      var $bxe_1 = $65;
      __label__ = 13;
      break;
    } else {
      var $_0 = $64;
      __label__ = 17;
      break;
    }
   case 13:
    var $bxe_1;
    var $n_2;
    var $68 = $bxe_1 - 4 | 0;
    if ($68 >>> 0 > $10 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    if ((HEAP32[$68 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $n_2 = $n_2 - 1 | 0;
    var $bxe_1 = $68;
    __label__ = 13;
    break;
   case 16:
    HEAP32[$3 >> 2] = $n_2;
    var $_0 = $64;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_quorem["X"] = 1;

function _s2b($state, $s, $nd0, $nd, $y9) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nd + 8 | 0;
    var $2 = ($1 | 0) / 9 & -1;
    if (($1 | 0) > 17) {
      var $k_05 = 0;
      var $y_06 = 1;
      __label__ = 2;
      break;
    } else {
      var $k_0_lcssa = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $y_06;
    var $k_05;
    var $4 = $y_06 << 1;
    var $5 = $k_05 + 1 | 0;
    if (($2 | 0) > ($4 | 0)) {
      var $k_05 = $5;
      var $y_06 = $4;
      __label__ = 2;
      break;
    } else {
      var $k_0_lcssa = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $k_0_lcssa;
    var $7 = _Balloc($state, $k_0_lcssa);
    HEAP32[$7 + 20 >> 2] = $y9;
    HEAP32[$7 + 16 >> 2] = 1;
    if (($nd0 | 0) > 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $lftr_limit13 = $s + $nd0 | 0;
    var $_0 = $s + 9 | 0;
    var $b_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $b_0;
    var $_0;
    var $14 = $_0 + 1 | 0;
    var $17 = (HEAP8[$_0] << 24 >> 24) - 48 | 0;
    var $18 = _multadd($state, $b_0, 10, $17);
    if (($14 | 0) == ($lftr_limit13 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $14;
      var $b_0 = $18;
      __label__ = 5;
      break;
    }
   case 6:
    var $_1_ph = $nd0 + ($s + 1) | 0;
    var $i_1_ph = $nd0;
    var $b_1_ph = $18;
    __label__ = 8;
    break;
   case 7:
    var $_1_ph = $s + 10 | 0;
    var $i_1_ph = 9;
    var $b_1_ph = $7;
    __label__ = 8;
    break;
   case 8:
    var $b_1_ph;
    var $i_1_ph;
    var $_1_ph;
    if (($i_1_ph | 0) < ($nd | 0)) {
      __label__ = 9;
      break;
    } else {
      var $b_1_lcssa = $b_1_ph;
      __label__ = 11;
      break;
    }
   case 9:
    var $lftr_limit = $_1_ph + ($nd - $i_1_ph) | 0;
    var $b_11 = $b_1_ph;
    var $_13 = $_1_ph;
    __label__ = 10;
    break;
   case 10:
    var $_13;
    var $b_11;
    var $26 = $_13 + 1 | 0;
    var $29 = (HEAP8[$_13] << 24 >> 24) - 48 | 0;
    var $30 = _multadd($state, $b_11, 10, $29);
    if (($26 | 0) == ($lftr_limit | 0)) {
      var $b_1_lcssa = $30;
      __label__ = 11;
      break;
    } else {
      var $b_11 = $30;
      var $_13 = $26;
      __label__ = 10;
      break;
    }
   case 11:
    var $b_1_lcssa;
    return $b_1_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_s2b["X"] = 1;

function _ratio($a, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ka = __stackBase__;
    var $kb = __stackBase__ + 4;
    var $1 = _b2d($a, $ka);
    tempDoubleF64[0] = $1;
    var $2$0 = tempDoubleI32[0];
    var $2$1 = tempDoubleI32[1];
    var $3 = _b2d($b, $kb);
    tempDoubleF64[0] = $3;
    var $4$0 = tempDoubleI32[0];
    var $4$1 = tempDoubleI32[1];
    var $14 = (HEAP32[$a + 16 >> 2] - HEAP32[$b + 16 >> 2] << 5) + (HEAP32[$ka >> 2] - HEAP32[$kb >> 2]) | 0;
    if (($14 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $da_0$1 = ($14 << 20) + $2$1 | $2$1 & 0;
    var $da_0$0 = 0 | $2$0 & -1;
    var $db_0$1 = $4$1;
    var $db_0$0 = $4$0;
    __label__ = 4;
    break;
   case 3:
    var $da_0$1 = $2$1;
    var $da_0$0 = $2$0;
    var $db_0$1 = $14 * -1048576 + $4$1 | $4$1 & 0;
    var $db_0$0 = 0 | $4$0 & -1;
    __label__ = 4;
    break;
   case 4:
    var $db_0$0;
    var $db_0$1;
    var $da_0$0;
    var $da_0$1;
    var $31 = (tempDoubleI32[0] = $da_0$0, tempDoubleI32[1] = $da_0$1, tempDoubleF64[0]);
    var $32 = (tempDoubleI32[0] = $db_0$0, tempDoubleI32[1] = $db_0$1, tempDoubleF64[0]);
    var $33 = $31 / $32;
    STACKTOP = __stackBase__;
    return $33;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_ratio["X"] = 1;

function _b2d($a, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a + 20 | 0;
    var $3 = HEAPU32[$a + 16 >> 2];
    var $_sum = $3 - 1 | 0;
    var $4 = $a + 20 + ($_sum << 2) | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $6 = _hi0bits($5);
    HEAP32[$e >> 2] = 32 - $6 | 0;
    if (($6 | 0) < 11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = 11 - $6 | 0;
    var $14$0 = 0;
    var $14$1 = $5 >>> ($10 >>> 0) | 1072693248;
    if (($_sum | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      var $20 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $20 = HEAP32[$a + 20 + ($3 - 2 << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $20;
    var $d_0$1 = 0 | $14$1;
    var $d_0$0 = $20 >>> ($10 >>> 0) | $5 << $6 + 21 | $14$0;
    __label__ = 12;
    break;
   case 5:
    if (($_sum | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $32 = 0;
      var $xa_0 = $4;
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = $a + 20 + ($3 - 2 << 2) | 0;
    var $32 = HEAP32[$29 >> 2];
    var $xa_0 = $29;
    __label__ = 7;
    break;
   case 7:
    var $xa_0;
    var $32;
    var $33 = $6 - 11 | 0;
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = 43 - $6 | 0;
    var $42$0 = 0;
    var $42$1 = $5 << $33 | $32 >>> ($37 >>> 0) | 1072693248;
    if ($xa_0 >>> 0 > $1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $48 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $48 = HEAP32[$xa_0 - 4 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $48;
    var $d_0$1 = 0 | $42$1;
    var $d_0$0 = $48 >>> ($37 >>> 0) | $32 << $33 | $42$0;
    __label__ = 12;
    break;
   case 11:
    var $d_0$1 = 0 | ($5 | 1072693248);
    var $d_0$0 = $32 | 0;
    __label__ = 12;
    break;
   case 12:
    var $d_0$0;
    var $d_0$1;
    var $59 = (tempDoubleI32[0] = $d_0$0, tempDoubleI32[1] = $d_0$1, tempDoubleF64[0]);
    return $59;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_b2d["X"] = 1;

function __ZN13JSTreeContext5traceEP8JSTracer($this, $trc) {
  var $2 = $this + 92 | 0;
  var $3 = $trc;
  __ZN2js8Bindings5traceEP8JSTracer($2, $3);
  return;
}

function __ZN15JSCodeGeneratorC2EPN2js6ParserEj($this, $parser, $lineno) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  var $6 = $this | 0;
  __ZN13JSTreeContextC2EPN2js6ParserE($6, $parser);
  var $7 = $this + 176 | 0;
  var $8 = $parser + 12 | 0;
  var $9 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($7, $9);
  var $11 = $this + 240 | 0;
  var $12 = $this + 192 | 0;
  for (var $$dest = $12 >> 2, $$stop = $$dest + 12; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  var $13 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $13);
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_($11, $1);
  var $14 = $this + 268 | 0;
  var $15 = HEAP32[$8 >> 2];
  __ZN13JSGCConstListC1EP9JSContext($14, $15);
  var $16 = $this + 292 | 0;
  __ZN14JSCGObjectListC1Ev($16);
  var $17 = $this + 300 | 0;
  __ZN14JSCGObjectListC1Ev($17);
  var $18 = $this + 308 | 0;
  var $19 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($18, $19);
  var $20 = $this + 316 | 0;
  var $21 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $21);
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_($20, $2);
  var $22 = $this + 364 | 0;
  var $23 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($3, $23);
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_($22, $3);
  var $24 = $this + 508 | 0;
  var $25 = HEAP32[$8 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($24, $25);
  var $26 = $this + 516 | 0;
  var $27 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($4, $27);
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($26, $4);
  var $28 = $this + 564 | 0;
  var $29 = HEAP32[$8 >> 2];
  __ZN2js15TempAllocPolicyC1EP9JSContext($5, $29);
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($28, $5);
  HEAP16[$this + 612 >> 1] = 0;
  HEAP16[$this + 614 >> 1] = 0;
  HEAP32[$this >> 2] = 1;
  var $34 = $this + 140 | 0;
  var $35 = $this + 172 | 0;
  var $36 = $this + 108 | 0;
  _memset($36, 0, 64, 1);
  HEAP32[$35 >> 2] = $34;
  HEAP32[$this + 168 >> 2] = $lineno;
  HEAP32[$this + 136 >> 2] = $lineno;
  HEAP32[$this + 188 >> 2] = $lineno;
  STACKTOP = __stackBase__;
  return;
}

__ZN15JSCodeGeneratorC2EPN2js6ParserEj["X"] = 1;

function __ZN13JSTreeContextC2EPN2js6ParserE($this, $prs) {
  var $1 = $this + 40 | 0;
  var $2 = $prs + 12 | 0;
  var $3 = $this;
  for (var $$dest = $3 >> 2, $$stop = $$dest + 10; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  var $4 = HEAP32[$2 >> 2];
  __ZN2js9AtomDeclsC1EP9JSContext($1, $4);
  HEAP32[$this + 48 >> 2] = $prs;
  HEAP32[$this + 52 >> 2] = 0;
  HEAP32[$this + 56 >> 2] = 0;
  HEAP32[$this + 60 >> 2] = 0;
  var $9 = $this + 64 | 0;
  var $10 = HEAP32[$2 >> 2];
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext($9, $10);
  var $12 = $prs + 980 | 0;
  var $13 = HEAP32[$12 >> 2];
  HEAP32[$this + 72 >> 2] = $13;
  HEAP32[$this + 76 >> 2] = 0;
  HEAP32[$this + 80 >> 2] = 0;
  HEAP32[$this + 84 >> 2] = 0;
  HEAP32[$this + 88 >> 2] = 0;
  var $18 = $this + 92 | 0;
  __ZN2js8BindingsC1EP9JSContext($18, undef);
  HEAP32[$this + 104 >> 2] = -1;
  HEAP32[$12 >> 2] = $this;
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext($this, $cx) {
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN13JSGCConstListC1EP9JSContext($this, $cx) {
  __ZN13JSGCConstListC2EP9JSContext($this, $cx);
  return;
}

function __ZN14JSCGObjectListC1Ev($this) {
  __ZN14JSCGObjectListC2Ev($this);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($this, $cx, $ib) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 184 | 0;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($1);
    var $2 = $this | 0;
    var $3 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($2, $cx, $ib);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this + 240 | 0;
    var $6 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($5, 0);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $this + 176 | 0;
    var $9 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($8, $cx);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($this) {
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($this);
  return;
}

function __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($this, $cx, $ib) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ib | 0) == 1) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 40 | 0;
    var $4 = __ZN2js9AtomDecls4initEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $this + 64 | 0;
    var $7 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext($6, $cx);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $8 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    if (($8 | 0) == 65535) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$cg + 208 >> 2] + ($8 << 4) | 0;
    __label__ = 11;
    break;
   case 3:
    var $21 = $pc - HEAP32[HEAP32[$cg + 172 >> 2] >> 2] | 0;
    var $25 = $cg + 208 | 0;
    var $hi_0_ph = HEAP32[$cg + 220 >> 2] - 1 | 0;
    var $lo_0_ph = 0;
    __label__ = 4;
    break;
   case 4:
    var $lo_0_ph;
    var $hi_0_ph;
    var $hi_0 = $hi_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $hi_0;
    if (($lo_0_ph | 0) > ($hi_0 | 0)) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = ($hi_0 + $lo_0_ph | 0) / 2 & -1;
    var $31 = HEAP32[$25 >> 2];
    var $33 = HEAP32[$31 + ($30 << 4) + 8 >> 2];
    if (($33 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = $31 + ($30 << 4) | 0;
    __label__ = 11;
    break;
   case 8:
    if (($33 | 0) < ($21 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $hi_0_ph = $hi_0;
    var $lo_0_ph = $30 + 1 | 0;
    __label__ = 4;
    break;
   case 10:
    var $hi_0 = $30 - 1 | 0;
    __label__ = 5;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext11inStatementE10JSStmtType($this, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmt_0_in = $this + 24 | 0;
    __label__ = 2;
    break;
   case 2:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAPU16[$stmt_0 >> 1] & 65535 | 0) == ($type | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSTreeContext10inFunctionEv($this) {
  return (HEAP32[$this >> 2] & 2 | 0) != 0;
}

function __ZNK2js8Bindings9countVarsEv($this) {
  return HEAP16[$this + 6 >> 1];
}

function __ZN13JSTreeContext18skipSpansGeneratorEj($this, $skip) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    var $tc_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $tc_0;
    var $i_0;
    if ($i_0 >>> 0 >= $skip >>> 0 | ($tc_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$tc_0 >> 2] & 512 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    var $tc_0 = HEAP32[$tc_0 + 72 >> 2];
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext7blockidEv($this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $_in = ($2 | 0) == 0 ? $this + 4 | 0 : $2 + 4 | 0;
  return HEAP32[$_in >> 2];
}

function __ZN13JSTreeContext10blockChainEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 32 >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$2 + 8 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_PopStatement($tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 24 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 24 >> 2];
    HEAP32[$1 >> 2] = $4;
    var $_pre = $2 + 2 | 0;
    if (((HEAPU16[$2 >> 1] & 65535) - 6 | 0) >>> 0 < 2) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP16[$_pre >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 5;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    }
   case 3:
    var $_pre_phi;
    var $15 = HEAP32[$2 + 28 >> 2];
    HEAP32[$tc + 28 >> 2] = $15;
    if ((HEAP16[$_pre_phi >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $25 = HEAP32[HEAP32[$2 + 20 >> 2] + 12 >> 2];
    HEAP32[$tc + 32 >> 2] = $25;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext12parseMapPoolEv($cx);
    var $6 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v($5);
    HEAP32[$1 >> 2] = $6;
    var $_0 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15JSCodeGeneratorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = HEAP32[$this + 108 >> 2];
    __ZN9JSContext5free_EPv(undef, $3);
    var $5 = HEAP32[$this + 120 >> 2];
    __ZN9JSContext5free_EPv(undef, $5);
    var $7 = HEAP32[$this + 140 >> 2];
    __ZN9JSContext5free_EPv(undef, $7);
    var $9 = HEAP32[$this + 152 >> 2];
    __ZN9JSContext5free_EPv(undef, $9);
    var $11 = HEAP32[$this + 208 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $11;
    __ZN9JSContext5free_EPv(undef, $14);
    __label__ = 3;
    break;
   case 3:
    var $16 = $this + 564 | 0;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($16);
    var $17 = $this + 516 | 0;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($17);
    var $18 = $this + 508 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($18);
    var $19 = $this + 364 | 0;
    __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev($19);
    var $20 = $this + 316 | 0;
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev($20);
    var $21 = $this + 308 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($21);
    var $22 = $this + 268 | 0;
    __ZN13JSGCConstListD1Ev($22);
    var $23 = $this + 240 | 0;
    __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($23);
    var $24 = $this + 176 | 0;
    __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($24);
    __ZN13JSTreeContextD2Ev($1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev($this) {
  __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN13JSGCConstListD1Ev($this) {
  __ZN13JSGCConstListD2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN13JSTreeContextD2Ev($this) {
  var $2 = HEAP32[$this + 72 >> 2];
  var $5 = HEAP32[$this + 48 >> 2] + 980 | 0;
  HEAP32[$5 >> 2] = $2;
  var $6 = $this + 64 | 0;
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev($6);
  var $7 = $this + 40 | 0;
  __ZN2js9AtomDeclsD1Ev($7);
  return;
}

function _js_Emit1($cx, $cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 1);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $op & 255;
    var $7 = HEAP32[$cg + 172 >> 2] + 8 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    HEAP8[$8] = $4;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $6 = HEAP32[$2 + 8 >> 2];
    var $8 = HEAPU32[$2 + 4 >> 2];
    var $10 = $4;
    var $11 = $6 - $10 | 0;
    var $12 = $11 + $delta | 0;
    if (($6 + $delta | 0) >>> 0 > $8 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $11;
      __label__ = 12;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if ($12 >>> 0 > 1024) {
      __label__ = 4;
      break;
    } else {
      var $newlength_0 = 1024;
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZN2js11RoundUpPow2Ej($12);
    var $newlength_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $newlength_0;
    var $22 = __ZN9JSContext7malloc_Ej($cx, $newlength_0);
    var $newlength_2 = $newlength_0;
    var $newbase_0 = $22;
    __label__ = 9;
    break;
   case 6:
    var $26 = $8 - $10 << 1;
    if ($26 >>> 0 < $12 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $newlength_1 = $26;
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = __ZN2js11RoundUpPow2Ej($12);
    var $newlength_1 = $29;
    __label__ = 8;
    break;
   case 8:
    var $newlength_1;
    var $31 = __ZN9JSContext8realloc_EPvj($cx, $4, $newlength_1);
    var $newlength_2 = $newlength_1;
    var $newbase_0 = $31;
    __label__ = 9;
    break;
   case 9:
    var $newbase_0;
    var $newlength_2;
    if (($newbase_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = -1;
    __label__ = 12;
    break;
   case 11:
    var $37 = HEAP32[$1 >> 2] | 0;
    HEAP32[$37 >> 2] = $newbase_0;
    var $40 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$40 >> 2] = $newbase_0 + $newlength_2 | 0;
    var $41 = $newbase_0 + $11 | 0;
    var $43 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$43 >> 2] = $41;
    var $_0 = $11;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9EmitCheckP9JSContextP15JSCodeGeneratori["X"] = 1;

function __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    var $1 = __stackBase__ + 12;
    var $6 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2] + $target | 0;
    var $8 = HEAPU8[$6] & 255;
    var $10 = HEAPU32[_js_CodeSpec + ($8 << 3) + 4 >> 2];
    var $_pre = HEAPU32[$cg + 192 >> 2];
    if (($10 & 12582912 | 0) == 0) {
      var $21 = $_pre;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = $_pre + ($10 >>> 22 & 3) | 0;
    var $17 = $cg + 196 | 0;
    if ($16 >>> 0 > HEAPU32[$17 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $21 = $_pre;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$17 >> 2] = $16;
    var $21 = $_pre;
    __label__ = 4;
    break;
   case 4:
    var $21;
    var $_idx_val = HEAP8[_js_CodeSpec + ($8 << 3) + 1 | 0];
    var $22 = _js_GetStackUses($_idx_val, $8, $6);
    var $23 = $cg + 192 | 0;
    var $24 = $21 - $22 | 0;
    HEAP32[$23 >> 2] = $24;
    if (($24 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $27 = $numBuf | 0;
    var $28 = _JS_snprintf($27, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $target, tempInt));
    var $31 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $32 = __ZNK2js11TokenStream11getFilenameEv($31);
    var $34 = ($32 | 0) == 0 ? STRING_TABLE.__str401148 | 0 : $32;
    var $35 = _JS_ReportErrorFlagsAndNumber($cx, 1, 2, 0, 16, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $34, HEAP32[tempInt + 4 >> 2] = $27, tempInt));
    __label__ = 6;
    break;
   case 6:
    var $38 = HEAP8[_js_CodeSpec + ($8 << 3) + 2 | 0];
    if ($38 << 24 >> 24 < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $ndefs_0 = $38 << 24 >> 24;
    __label__ = 9;
    break;
   case 8:
    var $45 = HEAP32[HEAP32[$cg + 296 >> 2] + 8 >> 2];
    var $46 = HEAP32[$23 >> 2];
    __ZN2JSL10Int32ValueEi1190($1, $46);
    __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($45, 0, $1);
    var $47 = $45;
    var $48 = __ZNK8JSObject13propertyCountEv($47);
    var $ndefs_0 = $48;
    __label__ = 9;
    break;
   case 9:
    var $ndefs_0;
    var $51 = HEAP32[$23 >> 2] + $ndefs_0 | 0;
    HEAP32[$23 >> 2] = $51;
    var $52 = $cg + 196 | 0;
    if ($51 >>> 0 > HEAPU32[$52 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$52 >> 2] = $51;
    __label__ = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11UpdateDepthP9JSContextP15JSCodeGeneratori["X"] = 1;

function _js_Emit2($cx, $cg, $op, $op1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 2);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = $op1;
    var $10 = $7 + 2 | 0;
    var $12 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$12 >> 2] = $10;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_Emit3($cx, $cg, $op, $op1, $op2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 3);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = $op1;
    HEAP8[$7 + 2 | 0] = $op2;
    var $11 = $7 + 3 | 0;
    var $13 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$13 >> 2] = $11;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_Emit5($cx, $cg, $op, $op1, $op2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, 5);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $7 = HEAPU32[HEAP32[$4 >> 2] + 8 >> 2];
    HEAP8[$7] = $op & 255;
    HEAP8[$7 + 1 | 0] = ($op1 & 65535) >>> 8 & 255;
    HEAP8[$7 + 2 | 0] = $op1 & 255;
    HEAP8[$7 + 3 | 0] = ($op2 & 65535) >>> 8 & 255;
    HEAP8[$7 + 4 | 0] = $op2 & 255;
    var $19 = $7 + 5 | 0;
    var $21 = HEAP32[$4 >> 2] + 8 | 0;
    HEAP32[$21 >> 2] = $19;
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitN($cx, $cg, $op, $extra) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $extra + 1 | 0;
    var $2 = __ZL9EmitCheckP9JSContextP15JSCodeGeneratori($cx, $cg, $1);
    if (($2 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $cg + 172 | 0;
    var $8 = HEAP32[HEAP32[$5 >> 2] + 8 >> 2];
    HEAP8[$8] = $op & 255;
    var $10 = $8 + 1 | 0;
    _memset($10, 0, $extra, 1);
    var $11 = $8 + $1 | 0;
    var $13 = HEAP32[$5 >> 2] + 8 | 0;
    HEAP32[$13 >> 2] = $11;
    if (HEAP8[_js_CodeSpec + ($op << 3) + 1 | 0] << 24 >> 24 > -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZL11UpdateDepthP9JSContextP15JSCodeGeneratori($cx, $cg, $2);
    __label__ = 4;
    break;
   case 4:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_SetJumpOffset($cx, $cg, $pc, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if (($off + 32768 | 0) >>> 0 < 65536) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$pc + 1 | 0] = $off >>> 8 & 255;
    HEAP8[$pc + 2 | 0] = $off & 255;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    var $17 = __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $16, $off);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cg + 172 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2];
    var $pc_0 = HEAP32[$2 >> 2] + HEAP32[$cg + 228 >> 2] | 0;
    __label__ = 2;
    break;
   case 2:
    var $pc_0;
    if (($pc_0 | 0) == ($9 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAPU8[$pc_0] & 255;
    var $16 = HEAP32[_js_CodeSpec + ($13 << 3) + 4 >> 2] & 31;
    if (($16 | 0) == 4 || ($16 | 0) == 5) {
      __label__ = 4;
      break;
    } else if (($16 | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $18 = __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $pc_0);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $pc_0 = $18;
      __label__ = 2;
      break;
    }
   case 5:
    var $29 = ((HEAPU8[$pc_0 + 1 | 0] & 255) << 8 | HEAPU8[$pc_0 + 2 | 0] & 255) << 16 >> 16;
    var $30 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc_0, $pc_0, $29);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $pc_0 = $pc_0 + (HEAP8[_js_CodeSpec + ($13 << 3) | 0] << 24 >> 24) | 0;
    __label__ = 2;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $sd, $off) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    HEAP32[$args >> 2] = $cx;
    HEAP32[$args + 4 >> 2] = $cg;
    var $5 = HEAP32[$sd >> 2] + $off | 0;
    HEAP32[$args + 8 >> 2] = $5;
    var $7 = $args + 12 | 0;
    HEAP32[$7 >> 2] = 0;
    var $8 = $cg + 212 | 0;
    var $9 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $8);
    var $10 = HEAP32[$7 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $10 | 1;
    HEAP32[$sd + 12 >> 2] = $15;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16ensureSharpSlotsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    if ((HEAP32[$1 >> 2] | 0) > -1) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK13JSTreeContext10inFunctionEv($this);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAPU32[HEAP32[$this + 48 >> 2] + 12 >> 2];
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($10, STRING_TABLE.__str3667 | 0, 6, 0, 0);
    var $12 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($10, STRING_TABLE.__str11107 | 0, 6, 0, 0);
    if (($11 | 0) == 0 | ($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $this + 92 | 0;
    var $17 = __ZNK2js8Bindings9countVarsEv($16);
    HEAP32[$1 >> 2] = $17 & 65535;
    var $19 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($16, $10, $11);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $21 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($16, $10, $12);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    HEAP32[$1 >> 2] = 0;
    __label__ = 7;
    break;
   case 7:
    var $24 = $this | 0;
    var $26 = HEAP32[$24 >> 2] | 32768;
    HEAP32[$24 >> 2] = $26;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($1, $2, $name, 2);
  return $3;
}

function _js_PushStatement($tc, $stmt, $type, $top) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $stmt | 0;
    HEAP16[$2 >> 1] = $type & 65535;
    var $3 = $stmt + 2 | 0;
    HEAP16[$3 >> 1] = 0;
    var $4 = __ZN13JSTreeContext7blockidEv($tc);
    HEAP32[$stmt + 4 >> 2] = $4;
    HEAP32[$stmt + 8 >> 2] = $top;
    HEAP32[$stmt + 16 >> 2] = -1;
    HEAP32[$stmt + 12 >> 2] = -1;
    HEAP32[$stmt + 20 >> 2] = 0;
    var $10 = $tc + 24 | 0;
    var $11 = HEAP32[$10 >> 2];
    HEAP32[$stmt + 24 >> 2] = $11;
    HEAP32[$10 >> 2] = $stmt;
    if (((HEAPU16[$2 >> 1] & 65535) - 6 | 0) >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP16[$3 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $22 = $tc + 28 | 0;
    var $23 = HEAP32[$22 >> 2];
    HEAP32[$stmt + 28 >> 2] = $23;
    HEAP32[$22 >> 2] = $stmt;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$stmt + 28 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_PushBlockScope($tc, $stmt, $blockBox, $top) {
  _js_PushStatement($tc, $stmt, 4, $top);
  var $1 = $stmt + 2 | 0;
  var $3 = HEAP16[$1 >> 1] | 1;
  HEAP16[$1 >> 1] = $3;
  var $4 = $tc + 32 | 0;
  var $5 = HEAP32[$4 >> 2];
  HEAP32[$blockBox + 12 >> 2] = $5;
  var $8 = HEAP32[$blockBox + 8 >> 2];
  var $9 = __ZN13JSTreeContext10blockChainEv($tc);
  __ZN8JSObject9setParentEPS_($8, $9);
  var $10 = $tc + 28 | 0;
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$stmt + 28 >> 2] = $11;
  HEAP32[$10 >> 2] = $stmt;
  HEAP32[$4 >> 2] = $blockBox;
  HEAP32[$stmt + 20 >> 2] = $blockBox;
  return;
}

function _js_PopStatementCG($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $3 = HEAPU32[$cg + 24 >> 2];
    if (((HEAPU16[$3 >> 1] & 65535) - 8 | 0) >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$3 + 12 >> 2];
    var $12 = $cg + 172 | 0;
    var $15 = HEAP32[HEAP32[$12 >> 2] + 8 >> 2];
    var $16 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $11, $15, 6);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$3 + 16 >> 2];
    var $26 = HEAP32[HEAP32[$12 >> 2] >> 2] + HEAP32[$3 + 8 >> 2] | 0;
    var $27 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $20, $26, 6);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _js_PopStatement($1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $last, $target, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2];
    var $6 = $4 - 1 | 0;
    var $7 = $target;
    var $pc_0 = $4 + $last | 0;
    __label__ = 2;
    break;
   case 2:
    var $pc_0;
    if (($pc_0 | 0) == ($6 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $pc_0);
    var $13 = $7 - $pc_0 | 0;
    var $14 = _js_SetJumpOffset($cx, $cg, $pc_0, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$pc_0] = $op;
    var $pc_0 = $pc_0 + -$11 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DefineCompileTimeConstant($cx, $cg, $atom, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cg + 240 | 0;
    var $7 = $pn + 32 | 0;
    var $8 = (tempDoubleI32[0] = HEAP32[$7 >> 2], tempDoubleI32[1] = HEAP32[$7 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd1149($2, $8);
    var $9 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_($5, $1, $2);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode6isKindEN2js9TokenKindE($this, $kind) {
  var $1 = __ZNK11JSParseNode7getKindEv($this);
  return ($1 | 0) == ($kind | 0);
}

function __ZNK11JSParseNode6isDefnEv($this) {
  return (HEAP32[$this >> 2] | 0) < 0;
}

function __ZNK13JSTreeContext9callsEvalEv($this) {
  return (HEAP32[$this >> 2] & 8388608 | 0) != 0;
}

function __ZN15JSCodeGenerator7contextEv($this) {
  return HEAP32[HEAP32[$this + 48 >> 2] + 12 >> 2];
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js11UpvarCookie3setEtt($this, $newLevel, $newSlot) {
  HEAP32[$this >> 2] = ($newLevel & 65535) << 16 | $newSlot & 65535;
  return;
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($2);
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $7 + 8 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd1149($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function _js_LexicalLookup($tc, $atom, $slotp, $stmt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($stmt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_01_ph = $stmt;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01_ph = HEAP32[$tc + 28 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_01_ph;
    var $5 = $tc + 48 | 0;
    var $_01 = $_01_ph;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if (($_01 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == 6) {
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP16[$_01 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[HEAP32[$_01 + 20 >> 2] + 8 >> 2];
    var $25 = HEAP32[HEAP32[$5 >> 2] + 12 >> 2];
    var $26 = __ZL12ATOM_TO_JSIDP6JSAtom1150($atom);
    var $27 = __ZN8JSObject12nativeLookupEP9JSContexti($22, $25, $26);
    if (($27 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($slotp | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZNK8JSObject7getSlotEj($22, 0);
    var $33 = __ZNK2JS5Value7toInt32Ev($32);
    var $37 = (HEAP16[$27 + 30 >> 1] << 16 >> 16) + $33 | 0;
    HEAP32[$slotp >> 2] = $37;
    __label__ = 13;
    break;
   case 10:
    var $_01 = HEAP32[$_01 + 28 >> 2];
    __label__ = 4;
    break;
   case 11:
    if (($slotp | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$slotp >> 2] = -1;
    __label__ = 13;
    break;
   case 13:
    return $_01;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_LexicalLookup["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom1150($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1189($1);
  return $2;
}

function __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK13JSTreeContext9callsEvalEv($1);
    if ($2) {
      var $8 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK11JSParseNode8isClosedEv($pn);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode8isClosedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 2048);
  return $1;
}

function __ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE($this, $atom, $slot, $cookie) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $allAtomIndex = __stackBase__ + 20;
    var $globalUseIndex = __stackBase__ + 24;
    var $2 = __stackBase__ + 28;
    HEAP32[$1 >> 2] = $atom;
    var $3 = $this + 508 | 0;
    var $4 = __ZN15JSCodeGenerator7contextEv($this);
    var $5 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($3, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($3);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $7, $1);
    var $8 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $13 = HEAP32[$11 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($cookie, 0, $13);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $15 = $this + 364 | 0;
    var $16 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($15);
    if ($16 >>> 0 > 65535) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js11UpvarCookie8makeFreeEv($cookie);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    var $20 = HEAP32[$1 >> 2];
    var $21 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($this, $20, $allAtomIndex);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $23 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($15);
    HEAP32[$globalUseIndex >> 2] = $23;
    var $24 = $23 & 65535;
    __ZN2js11UpvarCookie3setEtt($cookie, 0, $24);
    var $25 = HEAP32[$allAtomIndex >> 2];
    HEAP32[$2 >> 2] = $25;
    HEAP32[$2 + 4 >> 2] = $slot;
    var $26 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($15, $2);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $28 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($3);
    var $29 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($28, $p, $1, $globalUseIndex);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $5, $key);
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $10 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($10 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($agg_result, $10, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($10);
    var $_0 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11UpvarCookie8makeFreeEv($this) {
  __ZN2js11UpvarCookie3setEtt($this, -1, -1);
  return;
}

function __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($this, $atom, $indexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $index = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $2 = $this + 176 | 0;
    var $3 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($2);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $3, $1);
    var $4 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $8 = HEAP32[$7 >> 2];
    HEAP32[$indexp >> 2] = $8;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($2);
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($10);
    HEAP32[$index >> 2] = $11;
    var $12 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($10, $p, $1, $index);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = HEAP32[$index >> 2];
    HEAP32[$indexp >> 2] = $14;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $t;
    var $11 = $1;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $15 = HEAP32[$value >> 2];
    var $17 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$17 >> 2] = $15;
    var $18 = $this + 4 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    var $21 = $this | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $25 = $this + 200 | 0;
    var $26 = $p | 0;
    var $27 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($25, $26, $key, $value);
    var $_0 = $27;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitFunctionScript($cx, $cg, $body) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = $cg | 0;
    if ((HEAP32[$2 >> 2] & 512 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cg + 172 | 0;
    HEAP32[$8 >> 2] = $cg + 108 | 0;
    var $9 = _js_Emit1($cx, $cg, 205);
    if (($9 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$8 >> 2] = $cg + 140 | 0;
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZNK13JSTreeContext19needsEagerArgumentsEv($1);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $17 = $cg + 172 | 0;
    HEAP32[$17 >> 2] = $cg + 108 | 0;
    var $18 = _js_Emit1($cx, $cg, 9);
    if (($18 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = _js_Emit1($cx, $cg, 81);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$17 >> 2] = $cg + 140 | 0;
    __label__ = 8;
    break;
   case 8:
    if ((HEAP32[$2 >> 2] & 1048576 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $cg + 172 | 0;
    HEAP32[$30 >> 2] = $cg + 108 | 0;
    var $31 = _js_Emit1($cx, $cg, 229);
    if (($31 | 0) < 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$30 >> 2] = $cg + 140 | 0;
    __label__ = 11;
    break;
   case 11:
    var $36 = _js_EmitTree($cx, $cg, $body);
    if (($36 | 0) == 0) {
      var $47 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = _js_Emit1($cx, $cg, 197);
    if (($39 | 0) > -1) {
      __label__ = 13;
      break;
    } else {
      var $47 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = $cx;
    var $43 = $cg;
    var $44 = __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($42, $43);
    var $47 = ($44 | 0) != 0;
    __label__ = 14;
    break;
   case 14:
    var $47;
    var $_0 = $47 & 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_EmitFunctionScript["X"] = 1;

function __ZNK13JSTreeContext19needsEagerArgumentsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK13JSTreeContext12inStrictModeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK13JSTreeContext13usesArgumentsEv($this);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK13JSTreeContext16mutatesParameterEv($this);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK13JSTreeContext9callsEvalEv($this);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_EmitTree($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $useful = __stackBase__;
    var $stmtInfo = __stackBase__ + 4;
    var $noteIndex = __stackBase__ + 36;
    var $op = __stackBase__ + 40;
    var $elm = __stackBase__ + 44;
    var $stackDummy_ = __stackBase__ + 48;
    var $slot = __stackBase__ + 52;
    var $tps = __stackBase__ + 56;
    var $labelIndex = __stackBase__ + 68;
    var $labelIndex2 = __stackBase__ + 72;
    var $catchJump = __stackBase__ + 76;
    var $index4 = __stackBase__ + 80;
    var $tps7 = __stackBase__ + 84;
    var $index11 = __stackBase__ + 96;
    var $1 = __stackBase__ + 100;
    var $index16 = __stackBase__ + 108;
    var $index17 = __stackBase__ + 112;
    var $index19 = __stackBase__ + 116;
    var $index21 = __stackBase__ + 120;
    __ZN16EmitLevelManagerC1EP15JSCodeGenerator($elm, $cg);
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_1 = 0;
    __label__ = 613;
    break;
   case 3:
    var $8 = $cg + 172 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $16 = HEAP32[$9 + 8 >> 2] - HEAP32[$9 >> 2] | 0;
    HEAP32[$pn + 20 >> 2] = $16;
    var $18 = $pn + 8 | 0;
    var $19 = HEAPU32[$18 >> 2];
    var $21 = HEAP32[$8 >> 2] + 28 | 0;
    var $22 = HEAP32[$21 >> 2];
    var $23 = $19 - $22 | 0;
    if (($19 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$21 >> 2] = $19;
    if ($23 >>> 0 < ((($19 >>> 0 > 127 & 1) << 1) + 2 | 0) >>> 0) {
      var $delta__0 = $23;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = _js_NewSrcNote2($cx, $cg, 23, $19);
    if (($32 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $delta__0;
    var $34 = _js_NewSrcNote($cx, $cg, 22);
    if (($34 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = $delta__0 - 1 | 0;
    if (($37 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $delta__0 = $37;
      __label__ = 6;
      break;
    }
   case 8:
    var $39 = __ZNK11JSParseNode7getKindEv($pn);
    if (($39 | 0) == 34) {
      __label__ = 9;
      break;
    } else if (($39 | 0) == 84) {
      __label__ = 38;
      break;
    } else if (($39 | 0) == 85) {
      __label__ = 47;
      break;
    } else if (($39 | 0) == 35) {
      __label__ = 48;
      break;
    } else if (($39 | 0) == 37) {
      __label__ = 65;
      break;
    } else if (($39 | 0) == 40) {
      __label__ = 66;
      break;
    } else if (($39 | 0) == 41) {
      __label__ = 77;
      break;
    } else if (($39 | 0) == 42) {
      __label__ = 90;
      break;
    } else if (($39 | 0) == 43) {
      __label__ = 164;
      break;
    } else if (($39 | 0) == 44) {
      __label__ = 174;
      break;
    } else if (($39 | 0) == 47) {
      __label__ = 183;
      break;
    } else if (($39 | 0) == 53) {
      __label__ = 189;
      break;
    } else if (($39 | 0) == 54) {
      __label__ = 234;
      break;
    } else if (($39 | 0) == 46) {
      __label__ = 249;
      break;
    } else if (($39 | 0) == 48) {
      __label__ = 250;
      break;
    } else if (($39 | 0) == 77) {
      __label__ = 258;
      break;
    } else if (($39 | 0) == 25) {
      __label__ = 264;
      break;
    } else if (($39 | 0) == 82) {
      __label__ = 286;
      break;
    } else if (($39 | 0) == 2) {
      __label__ = 291;
      break;
    } else if (($39 | 0) == 6) {
      __label__ = 315;
      break;
    } else if (($39 | 0) == 3) {
      __label__ = 326;
      break;
    } else if (($39 | 0) == 4) {
      __label__ = 333;
      break;
    } else if (($39 | 0) == 5) {
      __label__ = 334;
      break;
    } else if (($39 | 0) == 7 || ($39 | 0) == 8) {
      __label__ = 343;
      break;
    } else if (($39 | 0) == 15 || ($39 | 0) == 9 || ($39 | 0) == 10 || ($39 | 0) == 11 || ($39 | 0) == 12 || ($39 | 0) == 13 || ($39 | 0) == 45 || ($39 | 0) == 57 || ($39 | 0) == 14 || ($39 | 0) == 16 || ($39 | 0) == 17 || ($39 | 0) == 18) {
      __label__ = 360;
      break;
    } else if (($39 | 0) == 71) {
      __label__ = 366;
      break;
    } else if (($39 | 0) == 56 || ($39 | 0) == 70 || ($39 | 0) == 39 || ($39 | 0) == 19) {
      __label__ = 372;
      break;
    } else if (($39 | 0) == 20 || ($39 | 0) == 21) {
      __label__ = 378;
      break;
    } else if (($39 | 0) == 50) {
      __label__ = 403;
      break;
    } else if (($39 | 0) == 74) {
      __label__ = 420;
      break;
    } else if (($39 | 0) == 22) {
      __label__ = 427;
      break;
    } else if (($39 | 0) == 23 || ($39 | 0) == 73) {
      __label__ = 428;
      break;
    } else if (($39 | 0) == 49 || ($39 | 0) == 27) {
      __label__ = 429;
      break;
    } else if (($39 | 0) == 80) {
      __label__ = 448;
      break;
    } else if (($39 | 0) == 81) {
      __label__ = 461;
      break;
    } else if (($39 | 0) == 79) {
      __label__ = 473;
      break;
    } else if (($39 | 0) == 24 || ($39 | 0) == 78) {
      var $_3 = $pn;
      var $sharpnum_0 = -1;
      __label__ = 477;
      break;
    } else if (($39 | 0) == 26) {
      var $_4 = $pn;
      var $sharpnum_1 = -1;
      __label__ = 502;
      break;
    } else if (($39 | 0) == 51) {
      __label__ = 541;
      break;
    } else if (($39 | 0) == 52) {
      __label__ = 547;
      break;
    } else if (($39 | 0) == 29) {
      __label__ = 549;
      break;
    } else if (($39 | 0) == 64 || ($39 | 0) == 65 || ($39 | 0) == 66 || ($39 | 0) == 68 || ($39 | 0) == 67 || ($39 | 0) == 31) {
      __label__ = 551;
      break;
    } else if (($39 | 0) == 30) {
      __label__ = 552;
      break;
    } else if (($39 | 0) == 32) {
      __label__ = 553;
      break;
    } else if (($39 | 0) == 72 || ($39 | 0) == 33) {
      __label__ = 554;
      break;
    } else if (($39 | 0) == 58) {
      __label__ = 555;
      break;
    } else if (($39 | 0) == 75 || ($39 | 0) == 76) {
      __label__ = 556;
      break;
    } else if (($39 | 0) == 61 || ($39 | 0) == 59 || ($39 | 0) == 60) {
      __label__ = 571;
      break;
    } else if (($39 | 0) == 63) {
      __label__ = 592;
      break;
    } else if (($39 | 0) == 69) {
      __label__ = 604;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 9:
    var $41 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = _js_Emit1($cx, $cg, 208);
    if (($43 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 11:
    var $47 = $pn + 32 | 0;
    var $48 = HEAP32[$47 >> 2];
    var $49 = __ZNK13JSFunctionBox8functionEv($48);
    var $50 = __ZNK10JSFunction6scriptEv($49);
    if (($50 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $56 = HEAPU32[$pn + 44 >> 2] >>> 12;
    var $57 = __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $56);
    if (($57 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 13:
    var $60 = $cg | 0;
    var $62 = HEAP32[$cg + 48 >> 2];
    var $63 = HEAP32[$18 >> 2];
    var $64 = __ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_($cx, $62, $63);
    if (($64 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_1 = 0;
    __label__ = 613;
    break;
   case 15:
    var $68 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($64, $cx, 1);
    if ($68) {
      __label__ = 16;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 16:
    var $77 = HEAP32[HEAP32[$47 >> 2] + 60 >> 2] | HEAP32[$cg >> 2] & 67108864 | 3;
    var $78 = $64 | 0;
    var $79 = $64 | 0;
    HEAP32[$79 >> 2] = $77;
    var $80 = $64 + 92 | 0;
    var $82 = HEAP32[$47 >> 2] + 44 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($80, undef, $82);
    if ((HEAP32[$79 >> 2] & 32768 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $87 = $80;
    var $88 = $cx;
    var $89 = __ZN2js8Bindings13sharpSlotBaseEP9JSContext($87, $88);
    var $90 = $64 + 104 | 0;
    HEAP32[$90 >> 2] = $89;
    if (($89 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN13JSTreeContext11setFunctionEP10JSFunction($78, $49);
    var $93 = HEAP32[$47 >> 2];
    var $94 = $64 + 80 | 0;
    HEAP32[$94 >> 2] = $93;
    var $95 = $64 + 72 | 0;
    HEAP32[$95 >> 2] = $60;
    var $98 = HEAP32[$cg + 76 >> 2] + 1 | 0;
    var $99 = $64 + 76 | 0;
    HEAP32[$99 >> 2] = $98;
    var $102 = HEAP32[$pn + 36 >> 2];
    var $103 = _js_EmitFunctionScript($cx, $64, $102);
    var $_010 = ($103 | 0) == 0 ? 0 : $pn;
    __ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_(undef, $64);
    if (($_010 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $107 = $cg + 292 | 0;
    var $109 = $_010 + 32 | 0;
    var $111 = HEAP32[$109 >> 2] | 0;
    var $112 = __ZN14JSCGObjectList5indexEP11JSObjectBox($107, $111);
    var $113 = __ZNK11JSParseNode5getOpEv($_010);
    HEAP32[$op >> 2] = $113;
    if (($113 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[HEAP32[$109 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      var $125 = $113;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $122 = _js_NewSrcNote($cx, $cg, 1);
    if (($122 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $125 = HEAP32[$op >> 2];
    __label__ = 23;
    break;
   case 23:
    var $125;
    var $126 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $125, $112, $cg, 0);
    if ($126) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 24:
    var $128 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($128 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 608;
      break;
    }
   case 25:
    var $131 = __ZNK13JSTreeContext10inFunctionEv($60);
    if ($131) {
      __label__ = 32;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $134 = HEAP32[$49 + 72 >> 2];
    var $135 = __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $_010, $134);
    if ($135) {
      __label__ = 27;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 27:
    var $138 = $_010 + 40 | 0;
    var $139 = __ZNK2js11UpvarCookie6isFreeEv($138);
    if ($139) {
      __label__ = 28;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 28:
    HEAP32[$8 >> 2] = $cg + 108 | 0;
    var $142 = __ZNK10JSFunction13isFlatClosureEv($49);
    var $143 = $142 ? 222 : 127;
    HEAP32[$op >> 2] = $143;
    var $144 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $143, $112, $cg, 0);
    if ($144) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 29:
    var $146 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($146 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    HEAP32[$8 >> 2] = $cg + 140 | 0;
    __label__ = 31;
    break;
   case 31:
    var $151 = __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $112);
    if (($151 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 608;
      break;
    }
   case 32:
    var $156 = HEAP32[$49 + 72 >> 2];
    var $157 = $cg + 92 | 0;
    var $158 = $cx;
    var $159 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($157, $158, $156, $slot);
    var $161 = $_010 + 44 | 0;
    var $165 = HEAP32[$161 >> 2] & 4095 | $112 << 12;
    HEAP32[$161 >> 2] = $165;
    var $166 = __ZNK10JSFunction13isFlatClosureEv($49);
    var $167 = $166 ? 223 : 140;
    HEAP32[$op >> 2] = $167;
    var $168 = __ZNK11JSParseNode8isClosedEv($_010);
    if ($168) {
      __label__ = 33;
      break;
    } else {
      var $178 = $167;
      __label__ = 36;
      break;
    }
   case 33:
    var $170 = __ZNK13JSTreeContext9callsEvalEv($60);
    if ($170) {
      var $178 = $167;
      __label__ = 36;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $172 = $cg + 564 | 0;
    var $174 = $_010 + 40 | 0;
    var $175 = __ZNK2js11UpvarCookie4slotEv($174);
    var $176 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($172, $175);
    if ($176) {
      __label__ = 35;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 35:
    var $178 = HEAP32[$op >> 2];
    __label__ = 36;
    break;
   case 36:
    var $178;
    var $179 = HEAP32[$slot >> 2];
    var $180 = __ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator($cx, $178, $179, $112, $cg);
    if (($180 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $183 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($183 | 0) > -1) {
      var $ok_059 = 1;
      var $_560 = $_010;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 38:
    var $185 = __ZNK11JSParseNode4lastEv($pn);
    var $187 = $cg + 516 | 0;
    var $pn21_0_in = $pn + 32 | 0;
    __label__ = 39;
    break;
   case 39:
    var $pn21_0_in;
    var $pn21_0 = HEAP32[$pn21_0_in >> 2];
    if (($pn21_0 | 0) == ($185 | 0)) {
      __label__ = 46;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $191 = __ZNK11JSParseNode6isDefnEv($pn21_0);
    if ($191) {
      __label__ = 41;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 41:
    var $193 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn21_0);
    if (($193 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $196 = __ZNK11JSParseNode5getOpEv($pn21_0);
    if ((HEAP32[_js_CodeSpec + ($196 << 3) + 4 >> 2] & 31 | 0) == 6) {
      __label__ = 43;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 43:
    var $202 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $pn21_0);
    if ($202) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $205 = $pn21_0 + 40 | 0;
    var $206 = __ZNK2js11UpvarCookie4slotEv($205);
    var $207 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($187, $206);
    if ($207) {
      __label__ = 45;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 45:
    var $pn21_0_in = $pn21_0 + 24 | 0;
    __label__ = 39;
    break;
   case 46:
    var $211 = _js_EmitTree($cx, $cg, $185);
    var $_5 = $pn;
    var $ok_0 = $211;
    __label__ = 607;
    break;
   case 47:
    var $213 = $cg + 184 | 0;
    var $214 = $pn + 32 | 0;
    var $216 = HEAP32[$214 >> 2];
    HEAP32[$213 >> 2] = $216;
    var $220 = HEAP32[$pn + 36 >> 2];
    var $221 = _js_EmitTree($cx, $cg, $220);
    var $222 = $213 | 0;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($222);
    var $223 = $214;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($223, $cx);
    var $_5 = $pn;
    var $ok_0 = $221;
    __label__ = 607;
    break;
   case 48:
    var $225 = $stmtInfo | 0;
    HEAP16[$225 >> 1] = 1;
    HEAP32[$noteIndex >> 2] = -1;
    var $226 = $cg | 0;
    var $227 = $stmtInfo + 12 | 0;
    var $228 = $stmtInfo + 8 | 0;
    var $_111 = $pn;
    var $beq_0 = -1;
    var $jmp_0 = -1;
    __label__ = 49;
    break;
   case 49:
    var $jmp_0;
    var $beq_0;
    var $_111;
    var $231 = HEAP32[$_111 + 32 >> 2];
    var $232 = _js_EmitTree($cx, $cg, $231);
    if (($232 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $235 = HEAP32[$8 >> 2];
    var $242 = HEAP32[$235 + 8 >> 2] - HEAP32[$235 >> 2] | 0;
    if (HEAP16[$225 >> 1] << 16 >> 16 == 1) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    _js_PushStatement($226, $stmtInfo, 1, $242);
    __label__ = 54;
    break;
   case 52:
    HEAP16[$225 >> 1] = 1;
    HEAP32[$228 >> 2] = $242;
    var $247 = HEAP32[$noteIndex >> 2];
    var $249 = _js_SetSrcNoteOffset($cx, $cg, $247, 0, $jmp_0 - $beq_0 | 0);
    if (($249 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $252 = HEAP32[$noteIndex >> 2];
    var $253 = $242 - $beq_0 | 0;
    var $254 = _js_SetSrcNoteOffset($cx, $cg, $252, 1, $253);
    if (($254 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $259 = HEAP32[$_111 + 40 >> 2];
    var $260 = ($259 | 0) != 0;
    var $261 = $260 ? 2 : 1;
    var $262 = _js_NewSrcNote($cx, $cg, $261);
    HEAP32[$noteIndex >> 2] = $262;
    if (($262 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $265 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($265 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $270 = HEAP32[$_111 + 36 >> 2];
    var $271 = _js_EmitTree($cx, $cg, $270);
    if (($271 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ($260) {
      __label__ = 58;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 58:
    HEAP16[$225 >> 1] = 2;
    var $275 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmtInfo, $227, -1, 0);
    if (($275 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $278 = HEAP32[$8 >> 2];
    var $280 = HEAP32[$278 >> 2];
    var $281 = $280 + $265 | 0;
    var $286 = HEAP32[$278 + 8 >> 2] - ($280 + $265) | 0;
    var $287 = _js_SetJumpOffset($cx, $cg, $281, $286);
    if (($287 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $290 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($259, 35);
    if ($290) {
      var $_111 = $259;
      var $beq_0 = $265;
      var $jmp_0 = $275;
      __label__ = 49;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $292 = _js_EmitTree($cx, $cg, $259);
    if (($292 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $295 = HEAP32[$noteIndex >> 2];
    var $296 = $275 - $265 | 0;
    var $297 = _js_SetSrcNoteOffset($cx, $cg, $295, 0, $296);
    if (($297 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $300 = HEAP32[$8 >> 2];
    var $302 = HEAP32[$300 >> 2];
    var $303 = $302 + $265 | 0;
    var $308 = HEAP32[$300 + 8 >> 2] - ($302 + $265) | 0;
    var $309 = _js_SetJumpOffset($cx, $cg, $303, $308);
    if (($309 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $312 = _js_PopStatementCG($cx, $cg);
    var $_5 = $_111;
    var $ok_0 = $312;
    __label__ = 607;
    break;
   case 65:
    var $314 = __ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo($cx, $cg, $pn, $stmtInfo);
    var $_5 = $pn;
    var $ok_0 = $314;
    __label__ = 607;
    break;
   case 66:
    var $316 = $cg | 0;
    _js_PushStatement($316, $stmtInfo, 14, $16);
    var $317 = _js_NewSrcNote($cx, $cg, 4);
    HEAP32[$noteIndex >> 2] = $317;
    if (($317 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $320 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($320 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $323 = _js_NewSrcNote($cx, $cg, 4);
    if (($323 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $326 = $pn + 36 | 0;
    var $328 = HEAP32[$326 >> 2];
    var $329 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $328);
    if (($329 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $333 = HEAP32[$326 >> 2];
    var $334 = _js_EmitTree($cx, $cg, $333);
    if (($334 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $337 = HEAP32[$8 >> 2];
    var $339 = HEAP32[$337 >> 2];
    var $340 = $339 + $320 | 0;
    var $345 = HEAP32[$337 + 8 >> 2] - ($339 + $320) | 0;
    var $346 = _js_SetJumpOffset($cx, $cg, $340, $345);
    if (($346 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $350 = HEAP32[$pn + 32 >> 2];
    var $351 = _js_EmitTree($cx, $cg, $350);
    if (($351 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $354 = HEAP32[$8 >> 2];
    var $362 = $329 - HEAP32[$354 + 8 >> 2] + HEAP32[$354 >> 2] | 0;
    var $363 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $362);
    if (($363 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $366 = $363 - $329 | 0;
    var $367 = _js_SetSrcNoteOffset($cx, $cg, $323, 0, $366);
    if (($367 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $370 = HEAP32[$noteIndex >> 2];
    var $371 = $363 - $320 | 0;
    var $372 = _js_SetSrcNoteOffset($cx, $cg, $370, 0, $371);
    if (($372 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $375 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $375;
    __label__ = 607;
    break;
   case 77:
    var $377 = _js_NewSrcNote($cx, $cg, 4);
    HEAP32[$noteIndex >> 2] = $377;
    if (($377 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $380 = _js_Emit1($cx, $cg, 0);
    if (($380 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $383 = _js_NewSrcNote($cx, $cg, 4);
    if (($383 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $386 = $pn + 32 | 0;
    var $387 = HEAP32[$386 >> 2];
    var $388 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $387);
    if (($388 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $391 = $cg | 0;
    _js_PushStatement($391, $stmtInfo, 11, $388);
    var $392 = HEAP32[$386 >> 2];
    var $393 = _js_EmitTree($cx, $cg, $392);
    if (($393 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $396 = HEAP32[$8 >> 2];
    var $403 = HEAP32[$396 + 8 >> 2] - HEAP32[$396 >> 2] | 0;
    var $stmt_0 = $stmtInfo;
    __label__ = 83;
    break;
   case 83:
    var $stmt_0;
    HEAP32[$stmt_0 + 8 >> 2] = $403;
    var $407 = HEAP32[$stmt_0 + 24 >> 2];
    if (($407 | 0) == 0) {
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    if (HEAP16[$407 >> 1] << 16 >> 16 == 0) {
      var $stmt_0 = $407;
      __label__ = 83;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $415 = HEAP32[$pn + 36 >> 2];
    var $416 = _js_EmitTree($cx, $cg, $415);
    if (($416 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $419 = HEAP32[$8 >> 2];
    var $427 = $388 - HEAP32[$419 + 8 >> 2] + HEAP32[$419 >> 2] | 0;
    var $428 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $427);
    if (($428 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $431 = $428 - $388 | 0;
    var $432 = _js_SetSrcNoteOffset($cx, $cg, $383, 0, $431);
    if (($432 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $435 = HEAP32[$noteIndex >> 2];
    var $437 = 1 - $388 + $403 | 0;
    var $438 = _js_SetSrcNoteOffset($cx, $cg, $435, 0, $437);
    if (($438 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $441 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $441;
    __label__ = 607;
    break;
   case 90:
    var $444 = HEAP32[$pn + 32 >> 2];
    var $445 = $cg | 0;
    _js_PushStatement($445, $stmtInfo, 12, $16);
    var $446 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($444, 45);
    if ($446) {
      __label__ = 91;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 91:
    HEAP16[$stmtInfo >> 1] = 13;
    var $449 = $444 + 32 | 0;
    var $450 = HEAP32[$449 >> 2];
    if (($450 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    __ZN12TempPopScopeC1Ev($tps);
    var $forLet_033 = 0;
    __label__ = 96;
    break;
   case 93:
    var $453 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($450, 81);
    var $454 = $cg | 0;
    var $456 = HEAP32[$454 >> 2] | 16;
    HEAP32[$454 >> 2] = $456;
    var $457 = _js_EmitTree($cx, $cg, $450);
    if (($457 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    var $461 = HEAP32[$454 >> 2] & -17;
    HEAP32[$454 >> 2] = $461;
    __ZN12TempPopScopeC1Ev($tps);
    if ($453) {
      __label__ = 95;
      break;
    } else {
      var $forLet_033 = 0;
      __label__ = 96;
      break;
    }
   case 95:
    var $463 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($463) {
      var $forLet_033 = 1;
      __label__ = 96;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 96:
    var $forLet_033;
    var $467 = HEAP32[$444 + 40 >> 2];
    var $468 = _js_EmitTree($cx, $cg, $467);
    if (($468 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    if ($forLet_033) {
      __label__ = 98;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 98:
    var $472 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($472) {
      __label__ = 99;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 99:
    var $477 = HEAP32[$pn + 44 >> 2] & 255;
    var $478 = _js_Emit2($cx, $cg, 75, $477);
    if (($478 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $481 = _js_NewSrcNote($cx, $cg, 2);
    HEAP32[$noteIndex >> 2] = $481;
    if (($481 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $484 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($484 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $487 = _js_NewSrcNote($cx, $cg, 4);
    if (($487 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    var $490 = HEAP32[$8 >> 2];
    var $497 = HEAP32[$490 + 8 >> 2] - HEAP32[$490 >> 2] | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $497;
    HEAP32[$stmtInfo + 16 >> 2] = -1;
    HEAP32[$stmtInfo + 12 >> 2] = -1;
    var $501 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, 0);
    if (($501 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    var $506 = HEAP32[$444 + 36 >> 2];
    var $507 = __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $506, 0, 0);
    if ($507) {
      __label__ = 105;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 105:
    var $509 = HEAP32[$8 >> 2];
    var $514 = HEAP32[$509 + 8 >> 2];
    var $515 = HEAP32[$509 >> 2];
    var $516 = HEAP32[$449 >> 2];
    if (($516 | 0) == 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $519 = __ZNK11JSParseNode4isOpE4JSOp($516, 129);
    var $520 = $519 ? 0 : 2;
    var $521 = _js_NewSrcNote2($cx, $cg, 6, $520);
    if (($521 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $524 = _js_Emit1($cx, $cg, 81);
    if (($524 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $529 = HEAP32[$pn + 36 >> 2];
    var $530 = _js_EmitTree($cx, $cg, $529);
    if (($530 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $stmt_1 = $stmtInfo;
      __label__ = 109;
      break;
    }
   case 109:
    var $stmt_1;
    var $532 = HEAP32[$8 >> 2];
    var $539 = HEAP32[$532 + 8 >> 2] - HEAP32[$532 >> 2] | 0;
    HEAP32[$stmt_1 + 8 >> 2] = $539;
    var $542 = HEAP32[$stmt_1 + 24 >> 2];
    if (($542 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    if (HEAP16[$542 >> 1] << 16 >> 16 == 0) {
      var $stmt_1 = $542;
      __label__ = 109;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    var $548 = HEAP32[$8 >> 2];
    var $550 = HEAP32[$548 >> 2];
    var $551 = $550 + $484 | 0;
    var $556 = HEAP32[$548 + 8 >> 2] - ($550 + $484) | 0;
    var $557 = _js_SetJumpOffset($cx, $cg, $551, $556);
    if (($557 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $560 = _js_Emit1($cx, $cg, 76);
    if (($560 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $563 = HEAP32[$8 >> 2];
    var $571 = $497 - HEAP32[$563 + 8 >> 2] + HEAP32[$563 >> 2] | 0;
    var $572 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $571);
    if (($572 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $575 = $572 - $497 | 0;
    var $576 = _js_SetSrcNoteOffset($cx, $cg, $487, 0, $575);
    if (($576 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $579 = HEAP32[$noteIndex >> 2];
    var $581 = $514 - $484 - $515 | 0;
    var $582 = _js_SetSrcNoteOffset($cx, $cg, $579, 0, $581);
    if (($582 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    var $585 = HEAP32[$noteIndex >> 2];
    var $586 = $572 - $484 | 0;
    var $587 = _js_SetSrcNoteOffset($cx, $cg, $585, 1, $586);
    if (($587 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $top_0 = $497;
      __label__ = 160;
      break;
    }
   case 117:
    HEAP32[$op >> 2] = 81;
    var $591 = HEAP32[$444 + 32 >> 2];
    if (($591 | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 118:
    HEAP32[$op >> 2] = 0;
    __label__ = 127;
    break;
   case 119:
    var $595 = $cg | 0;
    var $597 = HEAP32[$595 >> 2] | 16;
    HEAP32[$595 >> 2] = $597;
    var $598 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($591, 4);
    if ($598) {
      __label__ = 120;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 120:
    var $_idx5_val = HEAP32[$591 + 32 >> 2];
    var $_idx6_val = HEAP32[$591 + 36 >> 2];
    var $600 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, 81, $_idx5_val, $_idx6_val, $op);
    if (($600 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    if ((HEAP32[$op >> 2] | 0) == 81) {
      __label__ = 122;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 122:
    var $603 = _js_EmitTree($cx, $cg, $591);
    if (($603 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $606 = __ZNK11JSParseNode7getKindEv($591);
    var $607 = __ZN2jsL15TokenKindIsDeclENS_9TokenKindE($606);
    if ($607) {
      __label__ = 124;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 124:
    if ((HEAP32[$591 + 44 >> 2] & 64 | 0) == 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    HEAP32[$op >> 2] = 0;
    __label__ = 126;
    break;
   case 126:
    var $616 = HEAP32[$595 >> 2] & -17;
    HEAP32[$595 >> 2] = $616;
    __label__ = 127;
    break;
   case 127:
    var $618 = _js_NewSrcNote($cx, $cg, 3);
    HEAP32[$noteIndex >> 2] = $618;
    if (($618 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $621 = HEAP32[$op >> 2];
    var $622 = _js_Emit1($cx, $cg, $621);
    if (($622 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $625 = HEAP32[$8 >> 2];
    var $627 = HEAP32[$625 + 8 >> 2];
    var $629 = HEAP32[$625 >> 2];
    var $632 = $627 - $629 | 0;
    var $633 = $444 + 36 | 0;
    if ((HEAP32[$633 >> 2] | 0) == 0) {
      var $jmp_1 = -1;
      var $641 = $627;
      var $640 = $629;
      __label__ = 132;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    var $637 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($637 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    var $_pre50 = HEAP32[$8 >> 2];
    var $jmp_1 = $637;
    var $641 = HEAP32[$_pre50 + 8 >> 2];
    var $640 = HEAP32[$_pre50 >> 2];
    __label__ = 132;
    break;
   case 132:
    var $640;
    var $641;
    var $jmp_1;
    var $644 = $641 - $640 | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $644;
    HEAP32[$stmtInfo + 16 >> 2] = -1;
    HEAP32[$stmtInfo + 12 >> 2] = -1;
    var $648 = _js_NewSrcNote($cx, $cg, 4);
    if (($648 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    var $651 = $pn + 36 | 0;
    var $653 = HEAP32[$651 >> 2];
    var $654 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $653);
    if (($654 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $658 = HEAP32[$651 >> 2];
    var $659 = _js_EmitTree($cx, $cg, $658);
    if (($659 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $662 = HEAP32[$8 >> 2];
    var $664 = HEAP32[$662 + 8 >> 2];
    var $666 = HEAP32[$662 >> 2];
    var $667 = $664;
    var $668 = $666;
    var $stmt_2 = $stmtInfo;
    var $671 = $664;
    var $670 = $666;
    __label__ = 136;
    break;
   case 136:
    var $670;
    var $671;
    var $stmt_2;
    HEAP32[$stmt_2 + 8 >> 2] = $671 - $670 | 0;
    var $677 = HEAP32[$stmt_2 + 24 >> 2];
    if (($677 | 0) == 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    if (HEAP16[$677 >> 1] << 16 >> 16 == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $_pre54 = HEAP32[$8 >> 2];
    var $stmt_2 = $677;
    var $671 = HEAP32[$_pre54 + 8 >> 2];
    var $670 = HEAP32[$_pre54 >> 2];
    __label__ = 136;
    break;
   case 139:
    var $685 = HEAP32[$444 + 40 >> 2];
    if (($685 | 0) == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    HEAP32[$op >> 2] = 81;
    var $688 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($685, 4);
    if ($688) {
      __label__ = 141;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 141:
    var $_idx3_val = HEAP32[$685 + 32 >> 2];
    var $_idx4_val = HEAP32[$685 + 36 >> 2];
    var $690 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, 81, $_idx3_val, $_idx4_val, $op);
    if (($690 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 142:
    var $_pr = HEAP32[$op >> 2];
    if (($_pr | 0) == 81) {
      __label__ = 143;
      break;
    } else {
      var $697 = $_pr;
      __label__ = 145;
      break;
    }
   case 143:
    var $694 = _js_EmitTree($cx, $cg, $685);
    if (($694 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $697 = HEAP32[$op >> 2];
    __label__ = 145;
    break;
   case 145:
    var $697;
    var $698 = _js_Emit1($cx, $cg, $697);
    if (($698 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $702 = HEAP32[$pn + 16 >> 2];
    if ((HEAP32[HEAP32[$8 >> 2] + 28 >> 2] | 0) == ($702 | 0)) {
      __label__ = 149;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $708 = _js_NewSrcNote2($cx, $cg, 23, $702);
    if (($708 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    var $712 = HEAP32[$8 >> 2] + 28 | 0;
    HEAP32[$712 >> 2] = $702;
    __label__ = 149;
    break;
   case 149:
    var $713 = HEAP32[$8 >> 2];
    var $715 = HEAP32[$713 + 8 >> 2];
    var $717 = HEAP32[$713 >> 2];
    var $720 = $715 - $717 | 0;
    if ((HEAP32[$633 >> 2] | 0) == 0) {
      var $735 = $715;
      var $734 = $717;
      __label__ = 153;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    var $724 = $717 + $jmp_1 | 0;
    var $725 = $720 - $jmp_1 | 0;
    var $726 = _js_SetJumpOffset($cx, $cg, $724, $725);
    if (($726 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    var $730 = HEAP32[$633 >> 2];
    var $731 = _js_EmitTree($cx, $cg, $730);
    if (($731 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 152:
    var $_pre59 = HEAP32[$8 >> 2];
    var $735 = HEAP32[$_pre59 + 8 >> 2];
    var $734 = HEAP32[$_pre59 >> 2];
    __label__ = 153;
    break;
   case 153:
    var $734;
    var $735;
    var $740 = _js_SetSrcNoteOffset($cx, $cg, $648, 0, $735 - $644 - $734 | 0);
    if (($740 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 154:
    var $743 = HEAP32[$noteIndex >> 2];
    var $744 = $720 - $632 | 0;
    var $745 = _js_SetSrcNoteOffset($cx, $cg, $743, 0, $744);
    if (($745 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $748 = HEAP32[$noteIndex >> 2];
    var $750 = $667 - $632 - $668 | 0;
    var $751 = _js_SetSrcNoteOffset($cx, $cg, $748, 1, $750);
    if (($751 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    var $754 = HEAP32[$noteIndex >> 2];
    var $755 = HEAP32[$8 >> 2];
    var $763 = HEAP32[$755 + 8 >> 2] - $632 - HEAP32[$755 >> 2] | 0;
    var $764 = _js_SetSrcNoteOffset($cx, $cg, $754, 2, $763);
    if (($764 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 157;
      break;
    }
   case 157:
    var $769 = HEAP32[$8 >> 2];
    var $777 = HEAP32[$769 >> 2] - HEAP32[$769 + 8 >> 2] + $644 | 0;
    if ((HEAP32[$633 >> 2] | 0) == 0) {
      __label__ = 159;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 158:
    var $779 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 8, $777);
    if (($779 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $top_0 = $644;
      __label__ = 160;
      break;
    }
   case 159:
    var $782 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, $777);
    if (($782 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $top_0 = $644;
      __label__ = 160;
      break;
    }
   case 160:
    var $top_0;
    var $785 = _js_PopStatementCG($cx, $cg);
    if (($785 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $788 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($444, 45);
    if ($788) {
      __label__ = 162;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 162:
    var $791 = HEAP32[$cg + 192 >> 2];
    var $792 = HEAP32[$8 >> 2];
    var $799 = HEAP32[$792 + 8 >> 2] - HEAP32[$792 >> 2] | 0;
    var $800 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 2, $791, $top_0, $799);
    if (($800 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $803 = _js_Emit1($cx, $cg, 78);
    if (($803 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 164:
    var $807 = HEAPU32[$cg + 24 >> 2];
    var $810 = HEAP32[$pn + 32 >> 2];
    if (($810 | 0) == 0) {
      __label__ = 169;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    var $813 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $810, $labelIndex);
    if ($813) {
      var $stmt_3 = $807;
      __label__ = 166;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 166:
    var $stmt_3;
    if (HEAP16[$stmt_3 >> 1] << 16 >> 16 == 0) {
      __label__ = 167;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 167:
    if ((HEAP32[$stmt_3 + 20 >> 2] | 0) == ($810 | 0)) {
      __label__ = 172;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $stmt_3 = HEAP32[$stmt_3 + 24 >> 2];
    __label__ = 166;
    break;
   case 169:
    HEAP32[$labelIndex >> 2] = -1;
    var $825 = HEAPU16[$807 >> 1];
    if ($825 << 16 >> 16 != 5 & ($825 & 65535) < 11) {
      var $stmt_4141 = $807;
      __label__ = 170;
      break;
    } else {
      var $stmt_4_lcssa = $807;
      var $_lcssa139 = $825;
      __label__ = 171;
      break;
    }
   case 170:
    var $stmt_4141;
    var $829 = HEAPU32[$stmt_4141 + 24 >> 2];
    var $831 = HEAPU16[$829 >> 1];
    if ($831 << 16 >> 16 != 5 & ($831 & 65535) < 11) {
      var $stmt_4141 = $829;
      __label__ = 170;
      break;
    } else {
      var $stmt_4_lcssa = $829;
      var $_lcssa139 = $831;
      __label__ = 171;
      break;
    }
   case 171:
    var $_lcssa139;
    var $stmt_4_lcssa;
    var $835 = $_lcssa139 << 16 >> 16 == 5 ? 18 : 1;
    var $stmt_5 = $stmt_4_lcssa;
    var $noteType_0 = $835;
    var $836 = -1;
    __label__ = 173;
    break;
   case 172:
    var $stmt_5 = $stmt_3;
    var $noteType_0 = 16;
    var $836 = HEAP32[$labelIndex >> 2];
    __label__ = 173;
    break;
   case 173:
    var $836;
    var $noteType_0;
    var $stmt_5;
    var $838 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmt_5, $stmt_5 + 12 | 0, $836, $noteType_0);
    if (($838 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 174:
    var $842 = HEAPU32[$cg + 24 >> 2];
    var $845 = HEAP32[$pn + 32 >> 2];
    if (($845 | 0) == 0) {
      __label__ = 179;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 175:
    var $848 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $845, $labelIndex2);
    if ($848) {
      var $stmt_6 = $842;
      var $loop_0 = 0;
      __label__ = 176;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 176:
    var $loop_0;
    var $stmt_6;
    var $850 = HEAPU16[$stmt_6 >> 1];
    if ($850 << 16 >> 16 == 0) {
      __label__ = 177;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 177:
    if ((HEAP32[$stmt_6 + 20 >> 2] | 0) == ($845 | 0)) {
      __label__ = 181;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 178:
    var $loop_1 = ($850 & 65535) > 10 ? $stmt_6 : $loop_0;
    var $stmt_6 = HEAPU32[$stmt_6 + 24 >> 2];
    var $loop_0 = $loop_1;
    __label__ = 176;
    break;
   case 179:
    HEAP32[$labelIndex2 >> 2] = -1;
    if ((HEAPU16[$842 >> 1] & 65535) < 11) {
      var $stmt_7136 = $842;
      __label__ = 180;
      break;
    } else {
      var $stmt_8 = $842;
      var $noteType_1 = 5;
      var $868 = -1;
      __label__ = 182;
      break;
    }
   case 180:
    var $stmt_7136;
    var $864 = HEAPU32[$stmt_7136 + 24 >> 2];
    if ((HEAPU16[$864 >> 1] & 65535) < 11) {
      var $stmt_7136 = $864;
      __label__ = 180;
      break;
    } else {
      var $stmt_8 = $864;
      var $noteType_1 = 5;
      var $868 = -1;
      __label__ = 182;
      break;
    }
   case 181:
    var $stmt_8 = $loop_0;
    var $noteType_1 = 17;
    var $868 = HEAP32[$labelIndex2 >> 2];
    __label__ = 182;
    break;
   case 182:
    var $868;
    var $noteType_1;
    var $stmt_8;
    var $870 = __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $stmt_8, $stmt_8 + 16 | 0, $868, $noteType_1);
    if (($870 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 183:
    var $874 = HEAP32[$pn + 32 >> 2];
    var $875 = _js_EmitTree($cx, $cg, $874);
    if (($875 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 184;
      break;
    }
   case 184:
    var $878 = $cg | 0;
    var $879 = HEAP32[$8 >> 2];
    var $886 = HEAP32[$879 + 8 >> 2] - HEAP32[$879 >> 2] | 0;
    _js_PushStatement($878, $stmtInfo, 6, $886);
    var $887 = _js_Emit1($cx, $cg, 3);
    if (($887 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 185;
      break;
    }
   case 185:
    var $890 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($890 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 186:
    var $895 = HEAP32[$pn + 36 >> 2];
    var $896 = _js_EmitTree($cx, $cg, $895);
    if (($896 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    var $899 = _js_Emit1($cx, $cg, 4);
    if (($899 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 188:
    var $902 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $902;
    __label__ = 607;
    break;
   case 189:
    HEAP32[$catchJump >> 2] = -1;
    var $904 = $cg | 0;
    var $906 = $pn + 40 | 0;
    var $909 = (HEAP32[$906 >> 2] | 0) != 0 ? 9 : 8;
    var $910 = HEAP32[$8 >> 2];
    var $917 = HEAP32[$910 + 8 >> 2] - HEAP32[$910 >> 2] | 0;
    _js_PushStatement($904, $stmtInfo, $909, $917);
    var $918 = $cg + 192 | 0;
    var $919 = HEAPU32[$918 >> 2];
    var $920 = _js_Emit1($cx, $cg, 134);
    if (($920 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $923 = HEAP32[$8 >> 2];
    var $930 = HEAP32[$923 + 8 >> 2] - HEAP32[$923 >> 2] | 0;
    var $932 = HEAP32[$pn + 32 >> 2];
    var $933 = _js_EmitTree($cx, $cg, $932);
    if (($933 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 191;
      break;
    }
   case 191:
    if ((HEAP32[$906 >> 2] | 0) == 0) {
      __label__ = 194;
      break;
    } else {
      __label__ = 192;
      break;
    }
   case 192:
    var $939 = _js_NewSrcNote($cx, $cg, 11);
    if (($939 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 193:
    var $942 = $stmtInfo + 12 | 0;
    var $943 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $942);
    if (($943 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 194;
      break;
    }
   case 194:
    var $946 = _js_NewSrcNote($cx, $cg, 11);
    if (($946 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 195:
    var $949 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $catchJump);
    if (($949 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 196:
    var $952 = HEAP32[$8 >> 2];
    var $959 = HEAP32[$952 + 8 >> 2] - HEAP32[$952 >> 2] | 0;
    var $960 = $pn + 36 | 0;
    var $961 = HEAP32[$960 >> 2];
    if (($961 | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 197;
      break;
    }
   case 197:
    var $965 = $stmtInfo + 16 | 0;
    var $966 = $stmtInfo + 8 | 0;
    var $967 = $stmtInfo + 12 | 0;
    var $968 = $919 + 1 | 0;
    var $pn3_0_in = $961 + 32 | 0;
    var $count_0 = 0;
    var $prevBox_0 = 0;
    var $lastCatch_0 = 0;
    __label__ = 198;
    break;
   case 198:
    var $lastCatch_0;
    var $prevBox_0;
    var $count_0;
    var $pn3_0_in;
    var $pn3_0 = HEAP32[$pn3_0_in >> 2];
    if (($pn3_0 | 0) == 0) {
      __label__ = 213;
      break;
    } else {
      __label__ = 199;
      break;
    }
   case 199:
    var $972 = HEAP32[$965 >> 2];
    if (($972 | 0) == -1) {
      __label__ = 206;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 200:
    var $975 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $prevBox_0);
    if (($975 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 201:
    var $978 = HEAP32[$8 >> 2];
    var $980 = HEAP32[$978 >> 2];
    var $981 = $980 + $972 | 0;
    var $986 = HEAP32[$978 + 8 >> 2] - ($980 + $972) | 0;
    var $987 = _js_SetJumpOffset($cx, $cg, $981, $986);
    if (($987 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 202:
    HEAP32[$918 >> 2] = $968 + $count_0 | 0;
    var $991 = _js_NewSrcNote($cx, $cg, 11);
    if (($991 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 203;
      break;
    }
   case 203:
    var $994 = _js_Emit1($cx, $cg, 153);
    if (($994 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 204;
      break;
    }
   case 204:
    var $997 = _js_NewSrcNote($cx, $cg, 11);
    if (($997 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 205:
    var $1000 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $prevBox_0);
    if (($1000 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 206;
      break;
    }
   case 206:
    var $1003 = _js_NewSrcNote2($cx, $cg, 20, 0);
    if (($1003 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 207:
    HEAP32[$966 >> 2] = $1003;
    var $1007 = $pn3_0 + 32 | 0;
    var $1011 = HEAP32[HEAP32[$1007 >> 2] + 8 >> 2];
    var $1012 = __ZNK8JSObject13propertyCountEv($1011);
    var $1013 = HEAP32[$1007 >> 2];
    var $1014 = _js_EmitTree($cx, $cg, $pn3_0);
    if (($1014 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 208;
      break;
    }
   case 208:
    if ((HEAP32[$906 >> 2] | 0) == 0) {
      __label__ = 210;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 209:
    var $1020 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $967);
    if (($1020 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 210;
      break;
    }
   case 210:
    var $1023 = _js_NewSrcNote($cx, $cg, 11);
    if (($1023 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 211;
      break;
    }
   case 211:
    var $1026 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $catchJump);
    if (($1026 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 212:
    var $1029 = __ZNK11JSParseNode4exprEv($pn3_0);
    var $pn3_0_in = $pn3_0 + 24 | 0;
    var $count_0 = $1012;
    var $prevBox_0 = $1013;
    var $lastCatch_0 = $1029;
    __label__ = 198;
    break;
   case 213:
    if (($lastCatch_0 | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 214;
      break;
    }
   case 214:
    if ((HEAP32[$lastCatch_0 + 36 >> 2] | 0) == 0) {
      __label__ = 220;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 215:
    var $1038 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $prevBox_0);
    if (($1038 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    var $1041 = HEAP32[$8 >> 2];
    var $1043 = HEAP32[$1041 >> 2];
    var $1044 = HEAP32[$965 >> 2];
    var $1045 = $1043 + $1044 | 0;
    var $1050 = HEAP32[$1041 + 8 >> 2] - ($1043 + $1044) | 0;
    var $1051 = _js_SetJumpOffset($cx, $cg, $1045, $1050);
    if (($1051 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    HEAP32[$918 >> 2] = $968;
    var $1054 = _js_NewSrcNote($cx, $cg, 11);
    if (($1054 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 218:
    var $1057 = _js_Emit1($cx, $cg, 112);
    if (($1057 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 219;
      break;
    }
   case 219:
    var $1060 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1060 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 220;
      break;
    }
   case 220:
    if ((HEAP32[$906 >> 2] | 0) == 0) {
      var $finallyStart_0 = 0;
      __label__ = 226;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 221:
    var $1066 = HEAP32[$stmtInfo + 12 >> 2];
    var $1069 = HEAP32[HEAP32[$8 >> 2] + 8 >> 2];
    var $1070 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $1066, $1069, 116);
    if (($1070 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 222;
      break;
    }
   case 222:
    var $1073 = HEAP32[$8 >> 2];
    var $1080 = HEAP32[$1073 + 8 >> 2] - HEAP32[$1073 >> 2] | 0;
    HEAP16[$stmtInfo >> 1] = 10;
    var $1084 = HEAP32[HEAP32[$906 >> 2] + 8 >> 2];
    var $1085 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $1084);
    if (($1085 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 223;
      break;
    }
   case 223:
    var $1088 = _js_Emit1($cx, $cg, 135);
    if (($1088 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 224;
      break;
    }
   case 224:
    var $1091 = HEAP32[$906 >> 2];
    var $1092 = _js_EmitTree($cx, $cg, $1091);
    if (($1092 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 225;
      break;
    }
   case 225:
    var $1095 = _js_Emit1($cx, $cg, 117);
    if (($1095 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $finallyStart_0 = $1080;
      __label__ = 226;
      break;
    }
   case 226:
    var $finallyStart_0;
    var $1098 = _js_PopStatementCG($cx, $cg);
    if (($1098 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 227;
      break;
    }
   case 227:
    var $1101 = _js_NewSrcNote($cx, $cg, 15);
    if (($1101 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 228;
      break;
    }
   case 228:
    var $1104 = _js_Emit1($cx, $cg, 0);
    if (($1104 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 229;
      break;
    }
   case 229:
    var $1107 = HEAP32[$catchJump >> 2];
    var $1110 = HEAP32[HEAP32[$8 >> 2] + 8 >> 2];
    var $1111 = __ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh($cx, $cg, $1107, $1110, 6);
    if (($1111 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 230;
      break;
    }
   case 230:
    if ((HEAP32[$960 >> 2] | 0) == 0) {
      __label__ = 232;
      break;
    } else {
      __label__ = 231;
      break;
    }
   case 231:
    var $1117 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 0, $919, $930, $959);
    if (($1117 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 232;
      break;
    }
   case 232:
    if ((HEAP32[$906 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    var $1123 = __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, 1, $919, $930, $finallyStart_0);
    if (($1123 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 234:
    var $1127 = HEAP32[$cg + 24 >> 2];
    HEAP16[$1127 >> 1] = 7;
    var $1130 = HEAP32[$1127 + 8 >> 2];
    var $1132 = HEAP32[$1127 + 24 >> 2];
    var $1133 = _js_Emit1($cx, $cg, 118);
    if (($1133 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 235;
      break;
    }
   case 235:
    var $1136 = $pn + 36 | 0;
    if ((HEAP32[$1136 >> 2] | 0) == 0) {
      __label__ = 237;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 236:
    var $1140 = _js_Emit1($cx, $cg, 12);
    if (($1140 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 237;
      break;
    }
   case 237:
    var $1144 = HEAP32[$pn + 32 >> 2];
    var $1145 = __ZNK11JSParseNode7getKindEv($1144);
    if (($1145 | 0) == 24 || ($1145 | 0) == 26) {
      __label__ = 238;
      break;
    } else if (($1145 | 0) == 29) {
      __label__ = 240;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 238:
    var $1147 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, 0, $1144);
    if (($1147 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 239:
    var $1150 = _js_Emit1($cx, $cg, 81);
    if (($1150 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 240:
    var $1154 = $1144 + 40 | 0;
    var $1155 = __ZNK2js11UpvarCookie9asIntegerEv($1154);
    var $1157 = $1155 >>> 8 & 255;
    var $1158 = $1155 & 255;
    var $1159 = _js_Emit3($cx, $cg, 132, $1157, $1158);
    if (($1159 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 241;
      break;
    }
   case 241:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 132);
    __label__ = 242;
    break;
   case 242:
    var $1162 = HEAP32[$1136 >> 2];
    if (($1162 | 0) == 0) {
      __label__ = 247;
      break;
    } else {
      __label__ = 243;
      break;
    }
   case 243:
    var $1165 = $1162;
    var $1166 = _js_EmitTree($cx, $cg, $1165);
    if (($1166 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 244;
      break;
    }
   case 244:
    var $1170 = HEAP32[$1132 + 8 >> 2];
    var $1171 = HEAP32[$8 >> 2];
    var $1179 = HEAP32[$1171 + 8 >> 2] - $1130 - HEAP32[$1171 >> 2] | 0;
    var $1180 = _js_SetSrcNoteOffset($cx, $cg, $1170, 0, $1179);
    if (($1180 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $1183 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($1183 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 246;
      break;
    }
   case 246:
    var $1186 = $1132 + 16 | 0;
    HEAP32[$1186 >> 2] = $1183;
    var $1187 = _js_Emit1($cx, $cg, 81);
    if (($1187 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 247;
      break;
    }
   case 247:
    var $1192 = HEAP32[$pn + 40 >> 2];
    var $1193 = _js_EmitTree($cx, $cg, $1192);
    if (($1193 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $1197 = HEAP32[$cg + 192 >> 2];
    var $1198 = _js_NewSrcNote2($cx, $cg, 20, $1197);
    if (($1198 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 249:
    var $1201 = __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $pn, 0, $noteIndex);
    if (($1201 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 250:
    var $1205 = HEAP32[$pn + 32 >> 2];
    if (($1205 | 0) == 0) {
      __label__ = 252;
      break;
    } else {
      __label__ = 251;
      break;
    }
   case 251:
    var $1208 = _js_EmitTree($cx, $cg, $1205);
    if (($1208 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 252:
    var $1211 = _js_Emit1($cx, $cg, 1);
    if (($1211 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 253:
    var $1214 = HEAP32[$8 >> 2];
    var $1221 = HEAP32[$1214 + 8 >> 2] - HEAP32[$1214 >> 2] | 0;
    var $1222 = _js_Emit1($cx, $cg, 5);
    if (($1222 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 254;
      break;
    }
   case 254:
    var $1225 = __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, 0);
    if (($1225 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 255;
      break;
    }
   case 255:
    var $1229 = HEAP32[$8 >> 2];
    var $1233 = HEAP32[$1229 >> 2];
    if (($1221 + 1 | 0) == (HEAP32[$1229 + 8 >> 2] - $1233 | 0)) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 256;
      break;
    }
   case 256:
    HEAP8[$1233 + $1221 | 0] = -102;
    var $1240 = _js_Emit1($cx, $cg, 155);
    if (($1240 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 257;
      break;
    }
   case 257:
    var $1243 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1243 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 258:
    var $1247 = HEAP32[$pn + 32 >> 2];
    if (($1247 | 0) == 0) {
      __label__ = 260;
      break;
    } else {
      __label__ = 259;
      break;
    }
   case 259:
    var $1250 = _js_EmitTree($cx, $cg, $1247);
    if (($1250 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 260:
    var $1253 = _js_Emit1($cx, $cg, 1);
    if (($1253 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 261:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 263;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 262:
    var $1260 = _js_NewSrcNote($cx, $cg, 11);
    if (($1260 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 263;
      break;
    }
   case 263:
    var $1263 = _js_Emit1($cx, $cg, 206);
    if (($1263 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 264:
    var $1266 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 1);
    if ($1266) {
      __label__ = 265;
      break;
    } else {
      __label__ = 267;
      break;
    }
   case 265:
    var $1269 = HEAP32[$pn + 32 >> 2];
    var $1270 = _js_EmitTree($cx, $cg, $1269);
    if (($1270 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 266;
      break;
    }
   case 266:
    var $1273 = __ZNK11JSParseNode5getOpEv($pn);
    var $1274 = _js_Emit1($cx, $cg, $1273);
    if (($1274 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 267:
    HEAP32[$noteIndex >> 2] = -1;
    var $1277 = HEAP32[$8 >> 2];
    var $1282 = HEAP32[$1277 + 8 >> 2];
    var $1283 = HEAP32[$1277 >> 2];
    var $1285 = $pn + 44 | 0;
    if ((HEAP32[$1285 >> 2] & 128 | 0) == 0) {
      __label__ = 270;
      break;
    } else {
      __label__ = 268;
      break;
    }
   case 268:
    var $1290 = _js_NewSrcNote2($cx, $cg, 10, 0);
    HEAP32[$noteIndex >> 2] = $1290;
    if (($1290 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 269:
    var $1293 = _js_Emit1($cx, $cg, 0);
    if (($1293 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 270;
      break;
    }
   case 270:
    var $1296 = $cg | 0;
    _js_PushStatement($1296, $stmtInfo, 4, $16);
    var $1298 = HEAP32[$pn + 32 >> 2];
    var $1299 = HEAP32[$1285 >> 2];
    if (($1299 & 256 | 0) == 0) {
      var $pn2_1 = $1298;
      __label__ = 280;
      break;
    } else {
      __label__ = 271;
      break;
    }
   case 271:
    if (($1299 & 512 | 0) == 0) {
      var $pnchild_0 = $1298;
      __label__ = 274;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    var $1306 = _js_EmitTree($cx, $cg, $1298);
    if (($1306 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 273:
    var $pnchild_0 = HEAP32[$1298 + 24 >> 2];
    __label__ = 274;
    break;
   case 274:
    var $pnchild_0;
    var $pn2_0 = $pnchild_0;
    __label__ = 275;
    break;
   case 275:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $pn2_1 = $pnchild_0;
      __label__ = 280;
      break;
    } else {
      __label__ = 276;
      break;
    }
   case 276:
    var $1315 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 34);
    if ($1315) {
      __label__ = 277;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 277:
    var $1317 = __ZNK11JSParseNode4isOpE4JSOp($pn2_0, 0);
    if ($1317) {
      __label__ = 278;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 278:
    var $1319 = _js_EmitTree($cx, $cg, $pn2_0);
    if (($1319 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 279:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 275;
    break;
   case 280:
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      __label__ = 283;
      break;
    } else {
      __label__ = 281;
      break;
    }
   case 281:
    var $1326 = _js_EmitTree($cx, $cg, $pn2_1);
    if (($1326 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 282;
      break;
    }
   case 282:
    var $pn2_1 = HEAP32[$pn2_1 + 24 >> 2];
    __label__ = 280;
    break;
   case 283:
    var $1332 = HEAP32[$noteIndex >> 2];
    if (($1332 | 0) > -1) {
      __label__ = 284;
      break;
    } else {
      __label__ = 285;
      break;
    }
   case 284:
    var $1335 = HEAP32[$8 >> 2];
    var $1344 = $1283 - $1282 + HEAP32[$1335 + 8 >> 2] - HEAP32[$1335 >> 2] | 0;
    var $1345 = _js_SetSrcNoteOffset($cx, $cg, $1332, 0, $1344);
    if (($1345 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 285;
      break;
    }
   case 285:
    var $1348 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $1348;
    __label__ = 607;
    break;
   case 286:
    var $1350 = $cg | 0;
    _js_PushStatement($1350, $stmtInfo, 3, $16);
    var $pn2_2_in = $pn + 32 | 0;
    __label__ = 287;
    break;
   case 287:
    var $pn2_2_in;
    var $pn2_2 = HEAP32[$pn2_2_in >> 2];
    if (($pn2_2 | 0) == 0) {
      __label__ = 290;
      break;
    } else {
      __label__ = 288;
      break;
    }
   case 288:
    var $1355 = _js_EmitTree($cx, $cg, $pn2_2);
    if (($1355 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 289;
      break;
    }
   case 289:
    var $pn2_2_in = $pn2_2 + 24 | 0;
    __label__ = 287;
    break;
   case 290:
    var $1360 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $1360;
    __label__ = 607;
    break;
   case 291:
    var $1363 = HEAPU32[$pn + 32 >> 2];
    if (($1363 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 292;
      break;
    }
   case 292:
    var $1369 = (HEAP32[$cg >> 2] & 16386 | 0) == 0;
    var $1370 = $1369 & 1;
    HEAP32[$useful >> 2] = $1370;
    if ($1369) {
      var $_pr38 = $1370;
      __label__ = 295;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1372 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $1363, $useful);
    if (($1372 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $_pr38 = HEAP32[$useful >> 2];
    __label__ = 295;
    break;
   case 295:
    var $_pr38;
    var $1375 = ($_pr38 | 0) == 0;
    if ($1375) {
      __label__ = 296;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 296:
    var $1378 = HEAP32[$cg + 24 >> 2];
    if (($1378 | 0) == 0) {
      __label__ = 301;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    if (HEAP16[$1378 >> 1] << 16 >> 16 == 0) {
      __label__ = 298;
      break;
    } else {
      __label__ = 300;
      break;
    }
   case 298:
    var $1387 = HEAP32[$8 >> 2];
    if ((HEAP32[$1378 + 8 >> 2] | 0) < (HEAP32[$1387 + 8 >> 2] - HEAP32[$1387 >> 2] | 0)) {
      __label__ = 300;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    HEAP32[$useful >> 2] = 1;
    __label__ = 303;
    break;
   case 300:
    if ($1375) {
      __label__ = 301;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 301:
    var $1397 = __ZNK11JSParseNode25isDirectivePrologueMemberEv($pn);
    if ($1397) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $1400 = HEAP32[$1363 + 8 >> 2];
    var $1402 = HEAP32[$8 >> 2] + 28 | 0;
    HEAP32[$1402 >> 2] = $1400;
    var $1405 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $1406 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $1405, $1363, 5, 163, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($1406) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 303:
    var $1407 = $1369 ? 2 : 81;
    HEAP32[$op >> 2] = $1407;
    if ($1369) {
      __label__ = 313;
      break;
    } else {
      __label__ = 304;
      break;
    }
   case 304:
    var $1409 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1363, 4);
    if ($1409) {
      __label__ = 305;
      break;
    } else {
      __label__ = 307;
      break;
    }
   case 305:
    var $_idx1_val = HEAP32[$1363 + 32 >> 2];
    var $_idx2_val = HEAP32[$1363 + 36 >> 2];
    var $1411 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $1407, $_idx1_val, $_idx2_val, $op);
    if (($1411 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 306;
      break;
    }
   case 306:
    if ((HEAP32[$op >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 307;
      break;
    }
   case 307:
    var $1415 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1363, 4);
    if ($1415) {
      __label__ = 308;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 308:
    var $1417 = __ZNK11JSParseNode4isOpE4JSOp($1363, 0);
    if ($1417) {
      __label__ = 309;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 309:
    var $1420 = HEAP32[$1363 + 32 >> 2];
    var $1421 = __ZNK11JSParseNode4isOpE4JSOp($1420, 54);
    if ($1421) {
      __label__ = 310;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 310:
    var $1424 = HEAP32[$1363 + 36 >> 2];
    var $1425 = $1424;
    var $1426 = __ZNK11JSParseNode4isOpE4JSOp($1425, 130);
    if ($1426) {
      __label__ = 311;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 311:
    var $1430 = HEAP32[$1424 + 32 >> 2];
    var $1431 = __ZNK13JSFunctionBox8joinableEv($1430);
    if ($1431) {
      __label__ = 312;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 312:
    __ZN11JSParseNode5setOpE4JSOp($1420, 226);
    __label__ = 313;
    break;
   case 313:
    var $1433 = _js_EmitTree($cx, $cg, $1363);
    if (($1433 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 314;
      break;
    }
   case 314:
    var $1436 = HEAP32[$op >> 2];
    var $1437 = _js_Emit1($cx, $cg, $1436);
    if (($1437 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 315:
    var $1442 = HEAP32[$pn + 32 >> 2];
    var $1443 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $1442, $index4);
    if ($1443) {
      __label__ = 316;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 316:
    var $1445 = __ZNK11JSParseNode4exprEv($pn);
    var $1446 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1445, 25);
    if ($1446) {
      var $1453 = 1;
      __label__ = 319;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1448 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1445, 80);
    if ($1448) {
      __label__ = 318;
      break;
    } else {
      var $1453 = 0;
      __label__ = 319;
      break;
    }
   case 318:
    var $1450 = __ZNK11JSParseNode4exprEv($1445);
    var $1451 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1450, 25);
    var $1453 = $1451;
    __label__ = 319;
    break;
   case 319:
    var $1453;
    var $1454 = $1453 ? 14 : 13;
    var $1455 = HEAP32[$index4 >> 2];
    var $1456 = _js_NewSrcNote2($cx, $cg, $1454, $1455);
    HEAP32[$noteIndex >> 2] = $1456;
    if (($1456 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 320;
      break;
    }
   case 320:
    var $1459 = _js_Emit1($cx, $cg, 0);
    if (($1459 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 321;
      break;
    }
   case 321:
    var $1462 = $cg | 0;
    var $1463 = HEAP32[$8 >> 2];
    var $1470 = HEAP32[$1463 + 8 >> 2] - HEAP32[$1463 >> 2] | 0;
    _js_PushStatement($1462, $stmtInfo, 0, $1470);
    HEAP32[$stmtInfo + 20 >> 2] = $1442;
    var $1472 = _js_EmitTree($cx, $cg, $1445);
    if (($1472 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 322;
      break;
    }
   case 322:
    var $1475 = _js_PopStatementCG($cx, $cg);
    if (($1475 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 323;
      break;
    }
   case 323:
    if ($1453) {
      __label__ = 324;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 324:
    var $1479 = _js_NewSrcNote($cx, $cg, 15);
    if (($1479 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 325;
      break;
    }
   case 325:
    var $1482 = _js_Emit1($cx, $cg, 0);
    if (($1482 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 326:
    HEAP32[$noteIndex >> 2] = -1;
    var $off_0 = -1;
    var $pn2_3_in = $pn + 32 | 0;
    __label__ = 327;
    break;
   case 327:
    var $pn2_3_in;
    var $off_0;
    var $pn2_3 = HEAP32[$pn2_3_in >> 2];
    var $1487 = _js_EmitTree($cx, $cg, $pn2_3);
    if (($1487 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 328;
      break;
    }
   case 328:
    var $1490 = HEAP32[$8 >> 2];
    var $1497 = HEAP32[$1490 + 8 >> 2] - HEAP32[$1490 >> 2] | 0;
    var $1498 = HEAP32[$noteIndex >> 2];
    if (($1498 | 0) > -1) {
      __label__ = 329;
      break;
    } else {
      __label__ = 330;
      break;
    }
   case 329:
    var $1501 = $1497 - $off_0 | 0;
    var $1502 = _js_SetSrcNoteOffset($cx, $cg, $1498, 0, $1501);
    if (($1502 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 330;
      break;
    }
   case 330:
    var $1505 = $pn2_3 + 24 | 0;
    if ((HEAP32[$1505 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 331;
      break;
    }
   case 331:
    var $1509 = _js_NewSrcNote2($cx, $cg, 7, 0);
    HEAP32[$noteIndex >> 2] = $1509;
    if (($1509 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 332;
      break;
    }
   case 332:
    var $1512 = _js_Emit1($cx, $cg, 81);
    if (($1512 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $off_0 = $1497;
      var $pn2_3_in = $1505;
      __label__ = 327;
      break;
    }
   case 333:
    var $1516 = HEAP32[$pn + 32 >> 2];
    var $1517 = __ZNK11JSParseNode5getOpEv($pn);
    var $1520 = HEAP32[$pn + 36 >> 2];
    var $1521 = __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $1516, $1517, $1520);
    if ($1521) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 334:
    var $1524 = HEAP32[$pn + 32 >> 2];
    var $1525 = _js_EmitTree($cx, $cg, $1524);
    if (($1525 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 335:
    var $1528 = _js_NewSrcNote($cx, $cg, 9);
    HEAP32[$noteIndex >> 2] = $1528;
    if (($1528 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 336;
      break;
    }
   case 336:
    var $1531 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 7, 0);
    if (($1531 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 337;
      break;
    }
   case 337:
    var $1536 = HEAP32[$pn + 36 >> 2];
    var $1537 = _js_EmitTree($cx, $cg, $1536);
    if (($1537 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 338;
      break;
    }
   case 338:
    var $1540 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 6, 0);
    if (($1540 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 339;
      break;
    }
   case 339:
    var $1543 = HEAP32[$8 >> 2];
    var $1545 = HEAP32[$1543 >> 2];
    var $1546 = $1545 + $1531 | 0;
    var $1551 = HEAP32[$1543 + 8 >> 2] - ($1545 + $1531) | 0;
    var $1552 = _js_SetJumpOffset($cx, $cg, $1546, $1551);
    if (($1552 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    var $1555 = $cg + 192 | 0;
    var $1557 = HEAP32[$1555 >> 2] - 1 | 0;
    HEAP32[$1555 >> 2] = $1557;
    var $1560 = HEAP32[$pn + 40 >> 2];
    var $1561 = _js_EmitTree($cx, $cg, $1560);
    if (($1561 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 341;
      break;
    }
   case 341:
    var $1564 = HEAP32[$8 >> 2];
    var $1566 = HEAP32[$1564 >> 2];
    var $1567 = $1566 + $1540 | 0;
    var $1572 = HEAP32[$1564 + 8 >> 2] - ($1566 + $1540) | 0;
    var $1573 = _js_SetJumpOffset($cx, $cg, $1567, $1572);
    if (($1573 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 342;
      break;
    }
   case 342:
    var $1576 = HEAP32[$noteIndex >> 2];
    var $1577 = $1540 - $1531 | 0;
    var $1578 = _js_SetSrcNoteOffset($cx, $cg, $1576, 0, $1577);
    if (($1578 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 343:
    var $1581 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    var $1582 = $pn + 32 | 0;
    var $1583 = HEAP32[$1582 >> 2];
    var $1584 = _js_EmitTree($cx, $cg, $1583);
    var $1585 = ($1584 | 0) == 0;
    if ($1581) {
      __label__ = 344;
      break;
    } else {
      __label__ = 349;
      break;
    }
   case 344:
    if ($1585) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 345;
      break;
    }
   case 345:
    var $1588 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1588 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 346:
    var $1593 = HEAP32[$pn + 36 >> 2];
    var $1594 = _js_EmitTree($cx, $cg, $1593);
    if (($1594 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 347;
      break;
    }
   case 347:
    var $1597 = HEAP32[$8 >> 2];
    var $1601 = HEAP32[$1597 >> 2];
    var $1604 = $1601 + $1588 | 0;
    var $1606 = HEAP32[$1597 + 8 >> 2] - $1588 - $1601 | 0;
    var $1607 = _js_SetJumpOffset($cx, $cg, $1604, $1606);
    if (($1607 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1610 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP8[$1604] = $1610 & 255;
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 608;
    break;
   case 349:
    if ($1585) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    var $1614 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1614 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $jmp_2 = $1614;
      var $pn2_4 = $1583;
      __label__ = 351;
      break;
    }
   case 351:
    var $pn2_4;
    var $jmp_2;
    var $1617 = HEAP32[$pn2_4 + 24 >> 2];
    var $1620 = (HEAP32[$1617 + 24 >> 2] | 0) == 0;
    var $1621 = _js_EmitTree($cx, $cg, $1617);
    var $1622 = ($1621 | 0) != 0;
    if ($1620) {
      __label__ = 355;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 352:
    if ($1622) {
      __label__ = 353;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 353:
    var $1625 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 152, 0);
    if (($1625 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 354;
      break;
    }
   case 354:
    var $1631 = HEAP32[HEAP32[$8 >> 2] >> 2] + $jmp_2 | 0;
    var $1632 = $1625 - $jmp_2 | 0;
    var $1633 = __ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi($cx, $cg, $1631, $1632);
    if (($1633 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $jmp_2 = $1625;
      var $pn2_4 = $1617;
      __label__ = 351;
      break;
    }
   case 355:
    if ($1622) {
      __label__ = 356;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 356:
    var $1638 = HEAP32[$8 >> 2];
    var $1642 = HEAP32[$1638 >> 2];
    var $1645 = HEAP32[$1638 + 8 >> 2] - $1642 | 0;
    var $top_1 = $1614;
    var $pn2_5 = HEAP32[$1582 >> 2];
    var $1647 = $1642;
    __label__ = 357;
    break;
   case 357:
    var $1647;
    var $pn2_5;
    var $top_1;
    var $1648 = $1647 + $top_1 | 0;
    var $1649 = __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $1648);
    var $1650 = $1645 - $top_1 | 0;
    var $1651 = _js_SetJumpOffset($cx, $cg, $1648, $1650);
    if (($1651 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 358:
    var $1654 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP8[$1648] = $1654 & 255;
    var $1657 = HEAP32[$pn2_5 + 24 >> 2];
    if ((HEAP32[$1657 + 24 >> 2] | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 359;
      break;
    }
   case 359:
    var $top_1 = $1649 + $top_1 | 0;
    var $pn2_5 = $1657;
    var $1647 = HEAP32[HEAP32[$8 >> 2] >> 2];
    __label__ = 357;
    break;
   case 360:
    var $1663 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($1663) {
      __label__ = 361;
      break;
    } else {
      __label__ = 366;
      break;
    }
   case 361:
    var $1666 = HEAP32[$pn + 32 >> 2];
    var $1667 = _js_EmitTree($cx, $cg, $1666);
    if (($1667 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 362;
      break;
    }
   case 362:
    var $1670 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1670;
    var $pn2_6 = $1666;
    __label__ = 363;
    break;
   case 363:
    var $pn2_6;
    var $1673 = HEAP32[$pn2_6 + 24 >> 2];
    if (($1673 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 364;
      break;
    }
   case 364:
    var $1676 = _js_EmitTree($cx, $cg, $1673);
    if (($1676 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 365;
      break;
    }
   case 365:
    var $1679 = HEAP32[$op >> 2];
    var $1680 = _js_Emit1($cx, $cg, $1679);
    if (($1680 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $pn2_6 = $1673;
      __label__ = 363;
      break;
    }
   case 366:
    var $1683 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($1683) {
      __label__ = 367;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 367:
    var $1685 = __ZNK11JSParseNode4exprEv($pn);
    var $1686 = _js_EmitTree($cx, $cg, $1685);
    if (($1686 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 368;
      break;
    }
   case 368:
    var $1689 = __ZNK11JSParseNode5getOpEv($pn);
    var $1690 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $1689, $cg, 0);
    if ($1690) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 369:
    var $1692 = $cg | 0;
    var $1693 = HEAP32[$1692 >> 2];
    var $1694 = $1693 & -17;
    HEAP32[$1692 >> 2] = $1694;
    var $1696 = HEAP32[$pn + 32 >> 2];
    var $1697 = _js_EmitTree($cx, $cg, $1696);
    if (($1697 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 370;
      break;
    }
   case 370:
    var $1702 = HEAP32[$pn + 36 >> 2];
    var $1703 = _js_EmitTree($cx, $cg, $1702);
    if (($1703 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 371;
      break;
    }
   case 371:
    var $1708 = HEAP32[$1692 >> 2] | $1693 & 16;
    HEAP32[$1692 >> 2] = $1708;
    var $1709 = __ZNK11JSParseNode5getOpEv($pn);
    var $1710 = _js_Emit1($cx, $cg, $1709);
    if (($1710 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 372:
    var $1713 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1713;
    var $pn_idx_val = HEAP32[$pn + 32 >> 2];
    if (($1713 | 0) == 174) {
      __label__ = 373;
      break;
    } else if (($1713 | 0) == 39) {
      __label__ = 374;
      break;
    } else {
      __label__ = 376;
      break;
    }
   case 373:
    var $1715 = __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn_idx_val, 174, $cg);
    if (($1715 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 374:
    var $1718 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_idx_val, 29);
    if ($1718) {
      __label__ = 376;
      break;
    } else {
      __label__ = 375;
      break;
    }
   case 375:
    HEAP32[$op >> 2] = 200;
    __label__ = 376;
    break;
   case 376:
    var $1721 = $cg | 0;
    var $1722 = HEAP32[$1721 >> 2];
    var $1723 = $1722 & -17;
    HEAP32[$1721 >> 2] = $1723;
    var $1724 = _js_EmitTree($cx, $cg, $pn_idx_val);
    if (($1724 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 377;
      break;
    }
   case 377:
    var $1729 = HEAP32[$1721 >> 2] | $1722 & 16;
    HEAP32[$1721 >> 2] = $1729;
    var $1730 = HEAP32[$op >> 2];
    var $1731 = _js_Emit1($cx, $cg, $1730);
    if (($1731 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 378:
    var $1735 = HEAPU32[$pn + 32 >> 2];
    var $1736 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1736;
    var $1737 = __ZNK11JSParseNode7getKindEv($1735);
    if (($1737 | 0) == 22) {
      __label__ = 393;
      break;
    } else if (($1737 | 0) == 23) {
      __label__ = 394;
      break;
    } else if (($1737 | 0) == 27) {
      __label__ = 395;
      break;
    } else if (($1737 | 0) == 19) {
      __label__ = 400;
      break;
    } else {
      __label__ = 379;
      break;
    }
   case 379:
    __ZN11JSParseNode5setOpE4JSOp($1735, $1736);
    var $1739 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1735);
    if (($1739 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 380;
      break;
    }
   case 380:
    var $1742 = __ZNK11JSParseNode5getOpEv($1735);
    HEAP32[$op >> 2] = $1742;
    if (($1742 | 0) == 131) {
      __label__ = 381;
      break;
    } else {
      __label__ = 382;
      break;
    }
   case 381:
    var $1745 = _js_Emit1($cx, $cg, 131);
    if (($1745 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 388;
      break;
    }
   case 382:
    var $1749 = $1735 + 40 | 0;
    var $1750 = __ZNK2js11UpvarCookie6isFreeEv($1749);
    if ($1750) {
      __label__ = 385;
      break;
    } else {
      __label__ = 383;
      break;
    }
   case 383:
    var $1752 = __ZNK2js11UpvarCookie9asIntegerEv($1749);
    var $1754 = $1752 >>> 8 & 255;
    var $1755 = $1752 & 255;
    var $1756 = _js_Emit3($cx, $cg, $1742, $1754, $1755);
    if (($1756 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $1759 = HEAP32[$op >> 2];
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $1759);
    __label__ = 388;
    break;
   case 385:
    if ((HEAP32[_js_CodeSpec + ($1742 << 3) + 4 >> 2] & 3072 | 0) == 0) {
      __label__ = 387;
      break;
    } else {
      __label__ = 386;
      break;
    }
   case 386:
    var $1766 = __ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1735, $1742, $cg);
    if ($1766) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 387:
    var $1768 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $1735, $1742, $cg, 0);
    if ($1768) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 388:
    var $1770 = __ZNK11JSParseNode7isConstEv($1735);
    if ($1770) {
      __label__ = 389;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 389:
    var $1772 = _js_Emit1($cx, $cg, 35);
    if (($1772 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 390;
      break;
    }
   case 390:
    var $1775 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $1775;
    if ((HEAP32[_js_CodeSpec + ($1775 << 3) + 4 >> 2] & 4096 | 0) == 0) {
      __label__ = 391;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 391:
    var $1781 = _js_Emit1($cx, $cg, 63);
    if (($1781 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 392;
      break;
    }
   case 392:
    var $1790 = (HEAPU32[_js_CodeSpec + (HEAP32[$op >> 2] << 3) + 4 >> 2] >>> 11 & 1 ^ 1) + 27 | 0;
    HEAP32[$op >> 2] = $1790;
    var $1791 = _js_Emit1($cx, $cg, $1790);
    if (($1791 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 393:
    var $1794 = __ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1735, $1736, $cg);
    if ($1794) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 394:
    var $1796 = __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1735, $1736, $cg);
    if ($1796) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 395:
    var $1798 = _js_EmitTree($cx, $cg, $1735);
    if (($1798 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 396;
      break;
    }
   case 396:
    var $1801 = HEAP32[$8 >> 2];
    var $1811 = HEAP32[$1801 + 8 >> 2] - HEAP32[$1735 + 20 >> 2] - HEAP32[$1801 >> 2] | 0;
    var $1812 = _js_NewSrcNote2($cx, $cg, 12, $1811);
    if (($1812 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 397;
      break;
    }
   case 397:
    var $1815 = HEAP32[$op >> 2];
    var $1816 = _js_Emit1($cx, $cg, $1815);
    if (($1816 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 398;
      break;
    }
   case 398:
    var $1819 = _js_Emit1($cx, $cg, 1);
    if (($1819 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 399;
      break;
    }
   case 399:
    var $1822 = _js_Emit1($cx, $cg, 81);
    if (($1822 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 400:
    var $1826 = HEAP32[$1735 + 32 >> 2];
    var $1827 = _js_EmitTree($cx, $cg, $1826);
    if (($1827 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 401:
    var $1830 = _js_Emit1($cx, $cg, 172);
    if (($1830 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 402;
      break;
    }
   case 402:
    var $1833 = HEAP32[$op >> 2];
    var $1834 = __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, 0, $1833, $cg);
    if ($1834) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 403:
    var $1837 = HEAP32[$pn + 32 >> 2];
    var $1838 = __ZNK11JSParseNode7getKindEv($1837);
    if (($1838 | 0) == 29) {
      __label__ = 404;
      break;
    } else if (($1838 | 0) == 22) {
      __label__ = 408;
      break;
    } else if (($1838 | 0) == 73) {
      __label__ = 409;
      break;
    } else if (($1838 | 0) == 23) {
      __label__ = 410;
      break;
    } else {
      __label__ = 411;
      break;
    }
   case 404:
    var $1840 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1837);
    if (($1840 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 405;
      break;
    }
   case 405:
    var $1843 = __ZNK11JSParseNode5getOpEv($1837);
    HEAP32[$op >> 2] = $1843;
    if (($1843 | 0) == 66) {
      __label__ = 406;
      break;
    } else {
      __label__ = 407;
      break;
    }
   case 406:
    var $1846 = _js_Emit1($cx, $cg, 66);
    if (($1846 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 407:
    var $1849 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $1837, $1843, $cg, 0);
    if ($1849) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 408:
    var $1851 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $1837, 37, $cg, 0, 0);
    if (($1851 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 409:
    var $1854 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1837, 186, $cg);
    if (($1854 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 410:
    var $1857 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1837, 38, $cg);
    if (($1857 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 411:
    HEAP32[$useful >> 2] = 0;
    var $1860 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $1837, $useful);
    if (($1860 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 412;
      break;
    }
   case 412:
    if ((HEAP32[$useful >> 2] | 0) == 0) {
      __label__ = 413;
      break;
    } else {
      __label__ = 414;
      break;
    }
   case 413:
    HEAP32[$noteIndex >> 2] = -1;
    var $off_1 = -1;
    __label__ = 417;
    break;
   case 414:
    var $1867 = _js_EmitTree($cx, $cg, $1837);
    if (($1867 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 415;
      break;
    }
   case 415:
    var $1870 = HEAP32[$8 >> 2];
    var $1872 = HEAP32[$1870 + 8 >> 2];
    var $1874 = HEAP32[$1870 >> 2];
    var $1875 = _js_NewSrcNote2($cx, $cg, 7, 0);
    HEAP32[$noteIndex >> 2] = $1875;
    if (($1875 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 416;
      break;
    }
   case 416:
    var $1880 = $1872 - $1874 | 0;
    var $1881 = _js_Emit1($cx, $cg, 81);
    if (($1881 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $off_1 = $1880;
      __label__ = 417;
      break;
    }
   case 417:
    var $off_1;
    var $1884 = _js_Emit1($cx, $cg, 67);
    if (($1884 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 418;
      break;
    }
   case 418:
    var $1887 = HEAP32[$noteIndex >> 2];
    if (($1887 | 0) > -1) {
      __label__ = 419;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 419:
    var $1890 = HEAP32[$8 >> 2];
    var $1898 = HEAP32[$1890 + 8 >> 2] - $off_1 - HEAP32[$1890 >> 2] | 0;
    var $1899 = _js_SetSrcNoteOffset($cx, $cg, $1887, 0, $1898);
    if (($1899 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 420:
    var $1903 = HEAP32[$pn + 32 >> 2];
    var $1904 = _js_EmitTree($cx, $cg, $1903);
    if (($1904 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 421;
      break;
    }
   case 421:
    var $1907 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 176, 0);
    if (($1907 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 422;
      break;
    }
   case 422:
    var $1910 = $pn + 36 | 0;
    var $1912 = HEAP32[$1910 >> 2];
    var $1913 = __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1912);
    if (($1913 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 423;
      break;
    }
   case 423:
    var $1917 = HEAP32[$1910 >> 2];
    var $1918 = _js_EmitTree($cx, $cg, $1917);
    if (($1918 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 424;
      break;
    }
   case 424:
    var $1921 = HEAP32[$8 >> 2];
    var $1923 = HEAP32[$1921 >> 2];
    var $1924 = $1923 + $1907 | 0;
    var $1929 = HEAP32[$1921 + 8 >> 2] - ($1923 + $1907) | 0;
    var $1930 = _js_SetJumpOffset($cx, $cg, $1924, $1929);
    if (($1930 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 425;
      break;
    }
   case 425:
    var $1933 = HEAP32[$8 >> 2];
    var $1941 = $1913 - HEAP32[$1933 + 8 >> 2] + HEAP32[$1933 >> 2] | 0;
    var $1942 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 177, $1941);
    if (($1942 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 426;
      break;
    }
   case 426:
    var $1945 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1945 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 427:
    var $1948 = __ZNK11JSParseNode5getOpEv($pn);
    var $1949 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $1948, $cg, 0, 0);
    var $_5 = $pn;
    var $ok_0 = $1949;
    __label__ = 607;
    break;
   case 428:
    var $1951 = __ZNK11JSParseNode5getOpEv($pn);
    var $1952 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $1951, $cg);
    var $_5 = $pn;
    var $ok_0 = $1952;
    __label__ = 607;
    break;
   case 429:
    var $1954 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 27);
    var $1956 = HEAPU32[$pn + 32 >> 2];
    var $1957 = __ZNK11JSParseNode7getKindEv($1956);
    if (($1957 | 0) == 29) {
      __label__ = 430;
      break;
    } else if (($1957 | 0) == 22) {
      __label__ = 431;
      break;
    } else if (($1957 | 0) == 23) {
      __label__ = 432;
      break;
    } else if (($1957 | 0) == 19) {
      __label__ = 433;
      break;
    } else {
      __label__ = 435;
      break;
    }
   case 430:
    var $1959 = $1954 & 1;
    var $1960 = __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $1956, $1959);
    if (($1960 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 431:
    var $1963 = __ZNK11JSParseNode5getOpEv($1956);
    var $1964 = $1954 & 1;
    var $1965 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $1956, $1963, $cg, $1964, 0);
    if (($1965 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 432:
    var $1968 = $1954 ? 196 : 55;
    var $1969 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $1956, $1968, $cg);
    if (($1969 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 436;
      break;
    }
   case 433:
    var $1972 = __ZNK11JSParseNode4isOpE4JSOp($1956, 174);
    if ($1972) {
      __label__ = 434;
      break;
    } else {
      __label__ = 435;
      break;
    }
   case 434:
    var $_idx_val = HEAP32[$1956 + 32 >> 2];
    var $1974 = __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $_idx_val, 199, $cg);
    if (($1974 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 438;
      break;
    }
   case 435:
    var $1977 = _js_EmitTree($cx, $cg, $1956);
    if (($1977 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 437;
      break;
    }
   case 436:
    if ($1954) {
      __label__ = 438;
      break;
    } else {
      __label__ = 437;
      break;
    }
   case 437:
    var $1980 = _js_Emit1($cx, $cg, 1);
    if (($1980 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 438;
      break;
    }
   case 438:
    var $1982 = $cg | 0;
    var $1983 = HEAP32[$1982 >> 2];
    var $1984 = $1983 & -17;
    HEAP32[$1982 >> 2] = $1984;
    var $_pn28 = $1956;
    __label__ = 439;
    break;
   case 439:
    var $_pn28;
    var $pn3_1 = HEAP32[$_pn28 + 24 >> 2];
    if (($pn3_1 | 0) == 0) {
      __label__ = 441;
      break;
    } else {
      __label__ = 440;
      break;
    }
   case 440:
    var $1988 = _js_EmitTree($cx, $cg, $pn3_1);
    if (($1988 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $_pn28 = $pn3_1;
      __label__ = 439;
      break;
    }
   case 441:
    var $1993 = HEAP32[$1982 >> 2] | $1983 & 16;
    HEAP32[$1982 >> 2] = $1993;
    var $1994 = HEAP32[$8 >> 2];
    var $2002 = HEAP32[$1994 + 8 >> 2] - $16 - HEAP32[$1994 >> 2] | 0;
    var $2003 = _js_NewSrcNote2($cx, $cg, 12, $2002);
    if (($2003 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 442;
      break;
    }
   case 442:
    var $2008 = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $2009 = __ZNK11JSParseNode5getOpEv($pn);
    var $2011 = $2008 >>> 8 & 255;
    var $2012 = $2008 & 255;
    var $2013 = _js_Emit3($cx, $cg, $2009, $2011, $2012);
    if (($2013 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 443;
      break;
    }
   case 443:
    var $2016 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $2016);
    var $2017 = __ZNK11JSParseNode4isOpE4JSOp($pn, 123);
    if ($2017) {
      __label__ = 444;
      break;
    } else {
      __label__ = 446;
      break;
    }
   case 444:
    var $2019 = HEAPU32[$18 >> 2];
    var $2021 = $2019 >>> 8 & 255;
    var $2022 = $2019 & 255;
    var $2023 = _js_Emit3($cx, $cg, 119, $2021, $2022);
    if (($2023 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 445;
      break;
    }
   case 445:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 119);
    var $2026 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($2026 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 446;
      break;
    }
   case 446:
    if ((HEAP32[$pn + 44 >> 2] & 256 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 447:
    var $2035 = _js_Emit1($cx, $cg, 74);
    if (($2035 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 448:
    var $2040 = HEAPU32[$pn + 32 >> 2];
    var $2041 = $cg | 0;
    var $2042 = HEAP32[$8 >> 2];
    var $2049 = HEAP32[$2042 + 8 >> 2] - HEAP32[$2042 >> 2] | 0;
    _js_PushBlockScope($2041, $stmtInfo, $2040, $2049);
    HEAP32[$noteIndex >> 2] = -1;
    var $2050 = __ZNK11JSParseNode4exprEv($pn);
    var $2051 = __ZNK11JSParseNode7getKindEv($2050);
    if (($2051 | 0) == 81 || ($2051 | 0) == 54 || ($2051 | 0) == 42) {
      __label__ = 453;
      break;
    } else {
      __label__ = 449;
      break;
    }
   case 449:
    var $2054 = HEAP32[$stmtInfo + 24 >> 2];
    if (($2054 | 0) == 0) {
      __label__ = 450;
      break;
    } else {
      __label__ = 451;
      break;
    }
   case 450:
    var $2057 = __ZNK13JSTreeContext10inFunctionEv($2041);
    if ($2057) {
      __label__ = 453;
      break;
    } else {
      __label__ = 452;
      break;
    }
   case 451:
    if (HEAP16[$2054 >> 1] << 16 >> 16 == 4) {
      __label__ = 452;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 452:
    var $2063 = _js_NewSrcNote2($cx, $cg, 10, 0);
    HEAP32[$noteIndex >> 2] = $2063;
    if (($2063 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 453:
    var $2066 = __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $pn, $cg);
    if ($2066) {
      __label__ = 454;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 454:
    var $2070 = HEAP32[$pn + 36 >> 2];
    var $2071 = _js_EmitTree($cx, $cg, $2070);
    if (($2071 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 455;
      break;
    }
   case 455:
    var $2074 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $2074;
    if (($2074 | 0) == 210) {
      __label__ = 456;
      break;
    } else {
      __label__ = 457;
      break;
    }
   case 456:
    var $2077 = HEAP32[$8 >> 2];
    var $2085 = HEAP32[$2077 + 8 >> 2] - $16 - HEAP32[$2077 >> 2] | 0;
    var $2086 = _js_NewSrcNote2($cx, $cg, 12, $2085);
    if (($2086 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 457:
    var $2089 = HEAP32[$noteIndex >> 2];
    if (($2089 | 0) > -1) {
      __label__ = 458;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 458:
    var $2092 = HEAP32[$8 >> 2];
    var $2100 = HEAP32[$2092 + 8 >> 2] - $16 - HEAP32[$2092 >> 2] | 0;
    var $2101 = _js_SetSrcNoteOffset($cx, $cg, $2089, 0, $2100);
    if (($2101 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 459:
    var $2103 = HEAP32[$op >> 2];
    var $2104 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, $2103, $2040);
    if (($2104 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 460;
      break;
    }
   case 460:
    var $2107 = _js_PopStatementCG($cx, $cg);
    var $_5 = $pn;
    var $ok_0 = $2107;
    __label__ = 607;
    break;
   case 461:
    var $2109 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($2109) {
      __label__ = 463;
      break;
    } else {
      __label__ = 462;
      break;
    }
   case 462:
    __ZN12TempPopScopeC1Ev($tps7);
    var $_249 = $pn;
    __label__ = 464;
    break;
   case 463:
    var $2112 = HEAP32[$pn + 36 >> 2];
    var $2113 = $2112;
    var $2115 = HEAP32[$pn + 32 >> 2];
    __ZN12TempPopScopeC1Ev($tps7);
    if (($2112 | 0) == 0) {
      var $_249 = $2115;
      __label__ = 464;
      break;
    } else {
      var $2122 = 1;
      var $_25053 = $2115;
      var $pn2_74855 = $2113;
      __label__ = 465;
      break;
    }
   case 464:
    var $_249;
    if ((HEAP32[$cg >> 2] & 16 | 0) == 0) {
      var $2126 = 0;
      var $_25052 = $_249;
      var $pn2_74854 = 0;
      var $2125 = 0;
      __label__ = 466;
      break;
    } else {
      var $2122 = 0;
      var $_25053 = $_249;
      var $pn2_74855 = 0;
      __label__ = 465;
      break;
    }
   case 465:
    var $pn2_74855;
    var $_25053;
    var $2122;
    var $2123 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps7, $cx, $cg);
    if ($2123) {
      var $2126 = $2122;
      var $_25052 = $_25053;
      var $pn2_74854 = $pn2_74855;
      var $2125 = 1;
      __label__ = 466;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 466:
    var $2125;
    var $pn2_74854;
    var $_25052;
    var $2126;
    var $2128 = __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $_25052, $2126 & 1, $noteIndex);
    if (($2128 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 467;
      break;
    }
   case 467:
    var $2131 = HEAP32[$8 >> 2];
    var $2136 = HEAP32[$2131 + 8 >> 2];
    var $2137 = HEAP32[$2131 >> 2];
    if ($2125) {
      __label__ = 468;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 468:
    var $2139 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps7, $cx, $cg);
    if ($2139) {
      __label__ = 469;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 469:
    if ($2126) {
      __label__ = 470;
      break;
    } else {
      __label__ = 471;
      break;
    }
   case 470:
    var $2142 = _js_EmitTree($cx, $cg, $pn2_74854);
    if (($2142 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 471;
      break;
    }
   case 471:
    var $2145 = HEAP32[$noteIndex >> 2];
    if (($2145 | 0) > -1) {
      __label__ = 472;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_25052;
      __label__ = 608;
      break;
    }
   case 472:
    var $2148 = HEAP32[$8 >> 2];
    var $2157 = $2137 - $2136 + HEAP32[$2148 + 8 >> 2] - HEAP32[$2148 >> 2] | 0;
    var $2158 = _js_SetSrcNoteOffset($cx, $cg, $2145, 0, $2157);
    if (($2158 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_25052;
      __label__ = 608;
      break;
    }
   case 473:
    var $2162 = HEAP32[$pn + 32 >> 2];
    var $2163 = _js_EmitTree($cx, $cg, $2162);
    if (($2163 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 474;
      break;
    }
   case 474:
    var $2167 = HEAP32[$cg + 232 >> 2];
    var $2168 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $2167);
    if (($2168 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 475;
      break;
    }
   case 475:
    var $2171 = __ZNK11JSParseNode5getOpEv($pn);
    var $2173 = $2168 >>> 8 & 255;
    var $2174 = $2168 & 255;
    var $2175 = _js_Emit3($cx, $cg, $2171, $2173, $2174);
    if (($2175 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 476;
      break;
    }
   case 476:
    var $2178 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $2178);
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 608;
    break;
   case 477:
    var $sharpnum_0;
    var $_3;
    var $2180 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($_3, 78);
    if ($2180) {
      __label__ = 478;
      break;
    } else {
      __label__ = 481;
      break;
    }
   case 478:
    var $2182 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 3, $_3, $sharpnum_0);
    if ($2182) {
      __label__ = 479;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 479:
    var $2184 = $cg + 232 | 0;
    var $2185 = HEAP32[$2184 >> 2];
    var $2188 = HEAP32[$cg + 192 >> 2] - 1 | 0;
    HEAP32[$2184 >> 2] = $2188;
    var $2190 = HEAP32[$_3 + 32 >> 2];
    var $2191 = _js_EmitTree($cx, $cg, $2190);
    if (($2191 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 480;
      break;
    }
   case 480:
    HEAP32[$2184 >> 2] = $2185;
    var $2194 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, 1);
    if ($2194) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 481:
    var $2196 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if ($2196) {
      __label__ = 486;
      break;
    } else {
      __label__ = 482;
      break;
    }
   case 482:
    if ((HEAP32[$_3 + 44 >> 2] & 2048 | 0) == 0) {
      __label__ = 483;
      break;
    } else {
      __label__ = 486;
      break;
    }
   case 483:
    if ((HEAP32[$_3 + 32 >> 2] | 0) == 0) {
      __label__ = 486;
      break;
    } else {
      __label__ = 484;
      break;
    }
   case 484:
    var $2208 = __ZN15JSCodeGenerator21checkSingletonContextEv($cg);
    if ($2208) {
      __label__ = 485;
      break;
    } else {
      __label__ = 486;
      break;
    }
   case 485:
    var $2210 = __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $_3);
    if ($2210) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 486:
    var $2212 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if ($2212) {
      __label__ = 487;
      break;
    } else {
      __label__ = 488;
      break;
    }
   case 487:
    var $2214 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 3, $_3, $sharpnum_0);
    if ($2214) {
      __label__ = 490;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 488:
    var $2216 = _js_EmitN($cx, $cg, 90, 3);
    if (($2216 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 489:
    var $2221 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2222 = $_3 + 40 | 0;
    HEAP8[$2216 + ($2221 + 1) | 0] = HEAPU32[$2222 >> 2] >>> 16 & 255;
    HEAP8[$2216 + ($2221 + 2) | 0] = HEAPU32[$2222 >> 2] >>> 8 & 255;
    HEAP8[$2216 + ($2221 + 3) | 0] = HEAP32[$2222 >> 2] & 255;
    __label__ = 490;
    break;
   case 490:
    var $pn2_8_in = $_3 + 32 | 0;
    var $atomIndex_0 = 0;
    __label__ = 491;
    break;
   case 491:
    var $atomIndex_0;
    var $pn2_8_in;
    var $pn2_8 = HEAPU32[$pn2_8_in >> 2];
    if (($pn2_8 | 0) == 0) {
      __label__ = 499;
      break;
    } else {
      __label__ = 492;
      break;
    }
   case 492:
    var $2240 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $atomIndex_0 >>> 0, $cg);
    if (($2240 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 493:
    var $2243 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_8, 3);
    if ($2243) {
      __label__ = 494;
      break;
    } else {
      __label__ = 496;
      break;
    }
   case 494:
    var $2245 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_8, 0);
    if ($2245) {
      __label__ = 495;
      break;
    } else {
      __label__ = 496;
      break;
    }
   case 495:
    var $2247 = _js_Emit1($cx, $cg, 221);
    if (($2247 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 497;
      break;
    }
   case 496:
    var $2250 = _js_EmitTree($cx, $cg, $pn2_8);
    if (($2250 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 497;
      break;
    }
   case 497:
    var $2253 = _js_Emit1($cx, $cg, 94);
    if (($2253 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 498:
    var $pn2_8_in = $pn2_8 + 24 | 0;
    var $atomIndex_0 = $atomIndex_0 + 1 | 0;
    __label__ = 491;
    break;
   case 499:
    if ((HEAP32[$_3 + 44 >> 2] & 16 | 0) == 0) {
      __label__ = 501;
      break;
    } else {
      __label__ = 500;
      break;
    }
   case 500:
    var $2265 = _js_NewSrcNote($cx, $cg, 5);
    if (($2265 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 501;
      break;
    }
   case 501:
    var $2268 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $atomIndex_0);
    if ($2268) {
      var $ok_059 = 1;
      var $_560 = $_3;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 502:
    var $sharpnum_1;
    var $_4;
    var $2270 = $_4 + 32 | 0;
    var $2273 = HEAP32[$_4 + 44 >> 2];
    if (($2273 & 512 | 0) == 0) {
      __label__ = 504;
      break;
    } else {
      __label__ = 503;
      break;
    }
   case 503:
    var $2279 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $2280 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $2279, $_4, 0, 224, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 613;
    break;
   case 504:
    var $2282 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if ($2282) {
      __label__ = 509;
      break;
    } else {
      __label__ = 505;
      break;
    }
   case 505:
    if (($2273 & 2048 | 0) == 0) {
      __label__ = 506;
      break;
    } else {
      __label__ = 509;
      break;
    }
   case 506:
    if ((HEAP32[$2270 >> 2] | 0) == 0) {
      __label__ = 509;
      break;
    } else {
      __label__ = 507;
      break;
    }
   case 507:
    var $2291 = __ZN15JSCodeGenerator21checkSingletonContextEv($cg);
    if ($2291) {
      __label__ = 508;
      break;
    } else {
      __label__ = 509;
      break;
    }
   case 508:
    var $2293 = __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $_4);
    if ($2293) {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 509:
    var $2294 = HEAP32[$8 >> 2];
    var $2301 = HEAP32[$2294 + 8 >> 2] - HEAP32[$2294 >> 2] | 0;
    var $2302 = __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, 1, $_4, $sharpnum_1);
    if ($2302) {
      __label__ = 510;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 510:
    var $2304 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if ($2304) {
      var $obj_0 = 0;
      __label__ = 513;
      break;
    } else {
      __label__ = 511;
      break;
    }
   case 511:
    var $2306 = $cg | 0;
    var $2307 = __ZNK13JSTreeContext12compileAndGoEv($2306);
    if ($2307) {
      __label__ = 512;
      break;
    } else {
      var $obj_0 = 0;
      __label__ = 513;
      break;
    }
   case 512:
    var $2310 = HEAP32[$_4 + 40 >> 2];
    var $2311 = __ZN2jsL17GuessObjectGCKindEjb1152($2310);
    var $2312 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $2311);
    if (($2312 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $obj_0 = $2312;
      __label__ = 513;
      break;
    }
   case 513:
    var $obj_0;
    var $2316 = $cx + 52 | 0;
    var $2317 = $cx;
    var $slowMethodInits_0 = 0;
    var $obj_1 = $obj_0;
    var $pn2_9_in = $2270 | 0;
    __label__ = 514;
    break;
   case 514:
    var $pn2_9_in;
    var $obj_1;
    var $slowMethodInits_0;
    var $pn2_9 = HEAPU32[$pn2_9_in >> 2];
    if (($pn2_9 | 0) == 0) {
      __label__ = 533;
      break;
    } else {
      __label__ = 515;
      break;
    }
   case 515:
    var $2322 = HEAPU32[$pn2_9 + 32 >> 2];
    var $2323 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2322, 30);
    if ($2323) {
      __label__ = 516;
      break;
    } else {
      __label__ = 517;
      break;
    }
   case 516:
    var $2326 = $2322 + 32 | 0;
    var $2327 = (tempDoubleI32[0] = HEAP32[$2326 >> 2], tempDoubleI32[1] = HEAP32[$2326 + 4 >> 2], tempDoubleF64[0]);
    var $2328 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $2327, $cg);
    if (($2328 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 517;
      break;
    }
   case 517:
    var $2331 = $pn2_9 + 36 | 0;
    var $2333 = HEAP32[$2331 >> 2];
    var $2334 = _js_EmitTree($cx, $cg, $2333);
    if (($2334 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 518;
      break;
    }
   case 518:
    var $2337 = __ZNK11JSParseNode5getOpEv($pn2_9);
    HEAP32[$op >> 2] = $2337;
    if (($2337 - 125 | 0) >>> 0 < 2) {
      __label__ = 519;
      break;
    } else {
      var $obj_2 = $obj_1;
      __label__ = 520;
      break;
    }
   case 519:
    var $2340 = _js_Emit1($cx, $cg, $2337);
    if (($2340 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $obj_2 = 0;
      __label__ = 520;
      break;
    }
   case 520:
    var $obj_2;
    var $2343 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2322, 30);
    if ($2343) {
      __label__ = 521;
      break;
    } else {
      __label__ = 523;
      break;
    }
   case 521:
    var $2345 = _js_NewSrcNote($cx, $cg, 1);
    if (($2345 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 522;
      break;
    }
   case 522:
    var $2348 = _js_Emit1($cx, $cg, 94);
    if (($2348 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $slowMethodInits_2 = $slowMethodInits_0;
      var $obj_6 = 0;
      __label__ = 532;
      break;
    }
   case 523:
    var $2352 = $2322 + 32 | 0;
    var $2353 = HEAP32[$2352 >> 2];
    var $2354 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2353, $index11);
    if ($2354) {
      __label__ = 524;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 524:
    var $2356 = HEAP32[$2331 >> 2];
    var $2357 = $2356;
    var $2358 = __ZNK11JSParseNode4isOpE4JSOp($2357, 130);
    if ((HEAP32[$op >> 2] | 0) != 93 | $2358 ^ 1) {
      __label__ = 527;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 525:
    var $2363 = HEAP32[$2356 + 32 >> 2];
    var $2364 = __ZNK13JSFunctionBox8joinableEv($2363);
    if ($2364) {
      __label__ = 526;
      break;
    } else {
      __label__ = 527;
      break;
    }
   case 526:
    HEAP32[$op >> 2] = 227;
    __ZN11JSParseNode5setOpE4JSOp($pn2_9, 227);
    var $obj_5 = 0;
    var $slowMethodInits_157 = $slowMethodInits_0;
    __label__ = 531;
    break;
   case 527:
    var $obj_3 = (HEAP32[$2352 >> 2] | 0) == (HEAP32[HEAP32[$2316 >> 2] + 210292 >> 2] | 0) ? 0 : $obj_2;
    HEAP32[$op >> 2] = 93;
    var $_slowMethodInits_0 = ($2358 & 1) + $slowMethodInits_0 | 0;
    if (($obj_3 | 0) == 0) {
      var $obj_5 = 0;
      var $slowMethodInits_157 = $_slowMethodInits_0;
      __label__ = 531;
      break;
    } else {
      __label__ = 528;
      break;
    }
   case 528:
    var $2375 = HEAP32[$2352 >> 2];
    var $2376 = __ZL12ATOM_TO_JSIDP6JSAtom1150($2375);
    __ZN2JSL14UndefinedValueEv1154($1);
    var $2377 = $obj_3;
    var $2378 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($2317, $2377, $2376, $1, 0, 0, 1, 0, 0, 0);
    if (($2378 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 529;
      break;
    }
   case 529:
    var $2381 = __ZNK8JSObject16inDictionaryModeEv($obj_3);
    if ($2381) {
      __label__ = 530;
      break;
    } else {
      var $obj_5 = $obj_3;
      var $slowMethodInits_157 = $_slowMethodInits_0;
      __label__ = 531;
      break;
    }
   case 530:
    var $obj_5 = 0;
    var $slowMethodInits_157 = $_slowMethodInits_0;
    __label__ = 531;
    break;
   case 531:
    var $slowMethodInits_157;
    var $obj_5;
    var $2383 = HEAP32[$op >> 2];
    var $2384 = HEAP32[$index11 >> 2];
    var $2385 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $2383, $2384, $cg, 0);
    if ($2385) {
      var $slowMethodInits_2 = $slowMethodInits_157;
      var $obj_6 = $obj_5;
      __label__ = 532;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 532:
    var $obj_6;
    var $slowMethodInits_2;
    var $slowMethodInits_0 = $slowMethodInits_2;
    var $obj_1 = $obj_6;
    var $pn2_9_in = $pn2_9 + 24 | 0;
    __label__ = 514;
    break;
   case 533:
    var $2390 = HEAP32[$cg + 80 >> 2];
    if (($2390 | 0) == 0) {
      var $obj_7 = $obj_1;
      __label__ = 536;
      break;
    } else {
      __label__ = 534;
      break;
    }
   case 534:
    var $2393 = __ZNK13JSFunctionBox13shouldUnbrandEjj($2390, undef, $slowMethodInits_0);
    if ($2393) {
      __label__ = 535;
      break;
    } else {
      var $obj_7 = $obj_1;
      __label__ = 536;
      break;
    }
   case 535:
    var $2395 = _js_Emit1($cx, $cg, 228);
    if (($2395 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $obj_7 = 0;
      __label__ = 536;
      break;
    }
   case 536:
    var $obj_7;
    var $2399 = HEAP32[$_4 + 40 >> 2];
    var $2400 = __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $2399);
    if ($2400) {
      __label__ = 537;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 537:
    if (($obj_7 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 608;
      break;
    } else {
      __label__ = 538;
      break;
    }
   case 538:
    var $2406 = HEAP32[$cg + 48 >> 2];
    var $2407 = __ZN2js6Parser12newObjectBoxEP8JSObject($2406, $obj_7);
    if (($2407 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 539;
      break;
    }
   case 539:
    var $2410 = $cg + 292 | 0;
    var $2411 = __ZN14JSCGObjectList5indexEP11JSObjectBox($2410, $2407);
    var $2412 = __ZL19FitsWithoutBigIndexj($2411);
    if ($2412) {
      __label__ = 540;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $_4;
      __label__ = 608;
      break;
    }
   case 540:
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + $2301 | 0] = 91;
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + ($2301 + 1) | 0] = $2411 >>> 8 & 255;
    HEAP8[HEAP32[HEAP32[$8 >> 2] >> 2] + ($2301 + 2) | 0] = $2411 & 255;
    var $ok_059 = 1;
    var $_560 = $_4;
    __label__ = 608;
    break;
   case 541:
    var $2432 = HEAPU32[$pn + 36 >> 2];
    var $2434 = HEAPU32[$pn + 32 >> 2];
    var $2435 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2434, 24);
    if ($2435) {
      var $_3 = $2434;
      var $sharpnum_0 = $2432;
      __label__ = 477;
      break;
    } else {
      __label__ = 542;
      break;
    }
   case 542:
    var $2437 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2434, 78);
    if ($2437) {
      var $_3 = $2434;
      var $sharpnum_0 = $2432;
      __label__ = 477;
      break;
    } else {
      __label__ = 543;
      break;
    }
   case 543:
    var $2439 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2434, 26);
    if ($2439) {
      var $_4 = $2434;
      var $sharpnum_1 = $2432;
      __label__ = 502;
      break;
    } else {
      __label__ = 544;
      break;
    }
   case 544:
    var $2441 = _js_EmitTree($cx, $cg, $2434);
    if (($2441 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 545:
    var $2444 = _js_EmitN($cx, $cg, 95, 4);
    if (($2444 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 546;
      break;
    }
   case 546:
    var $2449 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2450 = $cg + 104 | 0;
    HEAP8[$2444 + ($2449 + 1) | 0] = HEAPU32[$2450 >> 2] >>> 8 & 255;
    HEAP8[$2444 + ($2449 + 2) | 0] = HEAP32[$2450 >> 2] & 255;
    HEAP8[$2444 + ($2449 + 3) | 0] = $2432 >>> 8 & 255;
    HEAP8[$2444 + ($2449 + 4) | 0] = $2432 & 255;
    var $ok_059 = 1;
    var $_560 = $2434;
    __label__ = 608;
    break;
   case 547:
    var $2464 = _js_EmitN($cx, $cg, 96, 4);
    if (($2464 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 548;
      break;
    }
   case 548:
    var $2469 = HEAPU32[HEAP32[$8 >> 2] >> 2];
    var $2470 = $cg + 104 | 0;
    HEAP8[$2464 + ($2469 + 1) | 0] = HEAPU32[$2470 >> 2] >>> 8 & 255;
    HEAP8[$2464 + ($2469 + 2) | 0] = HEAP32[$2470 >> 2] & 255;
    var $2479 = $pn + 36 | 0;
    HEAP8[$2464 + ($2469 + 3) | 0] = HEAPU32[$2479 >> 2] >>> 8 & 255;
    HEAP8[$2464 + ($2469 + 4) | 0] = HEAP32[$2479 >> 2] & 255;
    var $ok_059 = 1;
    var $_560 = $pn;
    __label__ = 608;
    break;
   case 549:
    var $2488 = __ZNK11JSParseNode4isOpE4JSOp($pn, 0);
    if ($2488) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 550;
      break;
    }
   case 550:
    var $2490 = __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $pn, 0);
    if (($2490 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 551:
    var $2493 = __ZNK11JSParseNode5getOpEv($pn);
    var $2494 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $2493, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2494 & 1;
    __label__ = 607;
    break;
   case 552:
    var $2498 = $pn + 32 | 0;
    var $2499 = (tempDoubleI32[0] = HEAP32[$2498 >> 2], tempDoubleI32[1] = HEAP32[$2498 + 4 >> 2], tempDoubleF64[0]);
    var $2500 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $2499, $cg);
    var $_5 = $pn;
    var $ok_0 = $2500;
    __label__ = 607;
    break;
   case 553:
    var $2502 = $cg + 300 | 0;
    var $2505 = HEAP32[$pn + 32 >> 2];
    var $2506 = __ZN14JSCGObjectList5indexEP11JSObjectBox($2502, $2505);
    var $2507 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 162, $2506, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2507 & 1;
    __label__ = 607;
    break;
   case 554:
    var $2510 = __ZNK11JSParseNode5getOpEv($pn);
    var $2511 = _js_Emit1($cx, $cg, $2510);
    if (($2511 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 555:
    var $2514 = _js_Emit1($cx, $cg, 115);
    if (($2514 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 556:
    var $2517 = $pn + 32 | 0;
    var $2518 = HEAP32[$2517 >> 2];
    if (($2518 | 0) == 0) {
      __label__ = 558;
      break;
    } else {
      __label__ = 557;
      break;
    }
   case 557:
    var $2521 = __ZNK11JSParseNode7getKindEv($2518);
    if (($2521 - 59 | 0) >>> 0 < 3) {
      var $pn2_10_in = $2517;
      __label__ = 559;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2522 = _js_Emit1($cx, $cg, 194);
    if (($2522 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $pn2_10_in = $2517;
      __label__ = 559;
      break;
    }
   case 559:
    var $pn2_10_in;
    var $pn2_10 = HEAPU32[$pn2_10_in >> 2];
    if (($pn2_10 | 0) == 0) {
      __label__ = 566;
      break;
    } else {
      __label__ = 560;
      break;
    }
   case 560:
    var $2526 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_10, 25);
    if ($2526) {
      __label__ = 561;
      break;
    } else {
      __label__ = 562;
      break;
    }
   case 561:
    var $2528 = _js_Emit1($cx, $cg, 195);
    if (($2528 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 562;
      break;
    }
   case 562:
    var $2531 = _js_EmitTree($cx, $cg, $pn2_10);
    if (($2531 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 563;
      break;
    }
   case 563:
    if (($pn2_10 | 0) == (HEAP32[$2517 >> 2] | 0)) {
      __label__ = 565;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 564:
    var $2537 = _js_Emit1($cx, $cg, 27);
    if (($2537 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 565;
      break;
    }
   case 565:
    var $pn2_10_in = $pn2_10 + 24 | 0;
    __label__ = 559;
    break;
   case 566:
    if ((HEAP32[$pn + 44 >> 2] & 32 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 567;
      break;
    }
   case 567:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 568;
      break;
    } else {
      __label__ = 570;
      break;
    }
   case 568:
    var $2556 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $2557 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2556, $index16);
    if ($2557) {
      __label__ = 569;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 569:
    var $2559 = HEAP32[$index16 >> 2];
    var $2560 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2559, $cg, 0);
    if ($2560) {
      __label__ = 570;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 570:
    var $2562 = __ZNK11JSParseNode5getOpEv($pn);
    var $2563 = _js_Emit1($cx, $cg, $2562);
    if (($2563 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 571:
    var $2566 = _js_Emit1($cx, $cg, 194);
    if (($2566 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 572;
      break;
    }
   case 572:
    var $2569 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 60);
    var $2570 = $cx + 52 | 0;
    var $2571 = HEAP32[$2570 >> 2];
    var $_in = $2569 ? $2571 + 210388 | 0 : $2571 + 210408 | 0;
    var $2575 = HEAP32[$_in >> 2] | 0;
    var $2576 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2575, $index17);
    if ($2576) {
      __label__ = 573;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 573:
    var $2578 = HEAP32[$index17 >> 2];
    var $2579 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2578, $cg, 0);
    if ($2579) {
      __label__ = 574;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 574:
    var $2582 = HEAP32[$pn + 32 >> 2];
    var $2583 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2582, 25);
    if ($2583) {
      __label__ = 575;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 575:
    var $2585 = _js_Emit1($cx, $cg, 195);
    if (($2585 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 576:
    var $2588 = _js_EmitTree($cx, $cg, $2582);
    if (($2588 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 577;
      break;
    }
   case 577:
    var $2591 = _js_Emit1($cx, $cg, 27);
    if (($2591 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $i_0 = 0;
      var $_pn = $2582;
      __label__ = 578;
      break;
    }
   case 578:
    var $_pn;
    var $i_0;
    var $pn2_11 = HEAP32[$_pn + 24 >> 2];
    if (($pn2_11 | 0) == 0) {
      __label__ = 587;
      break;
    } else {
      __label__ = 579;
      break;
    }
   case 579:
    var $2595 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_11, 25);
    if ($2595) {
      __label__ = 580;
      break;
    } else {
      __label__ = 581;
      break;
    }
   case 580:
    var $2597 = _js_Emit1($cx, $cg, 195);
    if (($2597 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 581;
      break;
    }
   case 581:
    var $2600 = _js_EmitTree($cx, $cg, $pn2_11);
    if (($2600 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 582:
    var $2603 = $i_0 & 1;
    if (($2603 | 0) == 0) {
      __label__ = 585;
      break;
    } else {
      __label__ = 583;
      break;
    }
   case 583:
    var $2606 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_11, 25);
    if ($2606) {
      __label__ = 584;
      break;
    } else {
      __label__ = 585;
      break;
    }
   case 584:
    var $2608 = _js_Emit1($cx, $cg, 169);
    if (($2608 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 585;
      break;
    }
   case 585:
    var $2612 = _js_Emit1($cx, $cg, $2603 | 170);
    if (($2612 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 586;
      break;
    }
   case 586:
    var $i_0 = $i_0 + 1 | 0;
    var $_pn = $pn2_11;
    __label__ = 578;
    break;
   case 587:
    var $2617 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 61);
    var $2618 = HEAP32[$2570 >> 2];
    var $_in13 = $2617 ? $2618 + 210396 | 0 : $2618 + 210420 | 0;
    var $2622 = HEAP32[$_in13 >> 2] | 0;
    var $2623 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2622, $index19);
    if ($2623) {
      __label__ = 588;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 588:
    var $2625 = HEAP32[$index19 >> 2];
    var $2626 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 61, $2625, $cg, 0);
    if ($2626) {
      __label__ = 589;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 589:
    var $2628 = _js_Emit1($cx, $cg, 27);
    if (($2628 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 590;
      break;
    }
   case 590:
    if ((HEAP32[$pn + 44 >> 2] & 32 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 591:
    var $2637 = __ZNK11JSParseNode5getOpEv($pn);
    var $2638 = _js_Emit1($cx, $cg, $2637);
    if (($2638 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    }
   case 592:
    var $2641 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($2641) {
      __label__ = 593;
      break;
    } else {
      __label__ = 601;
      break;
    }
   case 593:
    var $2643 = $pn + 32 | 0;
    var $pn2_12_in = $2643;
    __label__ = 594;
    break;
   case 594:
    var $pn2_12_in;
    var $pn2_12 = HEAP32[$pn2_12_in >> 2];
    if (($pn2_12 | 0) == 0) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      __label__ = 595;
      break;
    }
   case 595:
    var $2647 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_12, 25);
    if ($2647) {
      __label__ = 596;
      break;
    } else {
      __label__ = 597;
      break;
    }
   case 596:
    var $2649 = _js_Emit1($cx, $cg, 195);
    if (($2649 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 597;
      break;
    }
   case 597:
    var $2652 = _js_EmitTree($cx, $cg, $pn2_12);
    if (($2652 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 598;
      break;
    }
   case 598:
    if (($pn2_12 | 0) == (HEAP32[$2643 >> 2] | 0)) {
      __label__ = 600;
      break;
    } else {
      __label__ = 599;
      break;
    }
   case 599:
    var $2658 = _js_Emit1($cx, $cg, 27);
    if (($2658 | 0) < 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      __label__ = 600;
      break;
    }
   case 600:
    var $pn2_12_in = $pn2_12 + 24 | 0;
    __label__ = 594;
    break;
   case 601:
    var $2663 = __ZNK11JSParseNode4isOpE4JSOp($pn, 80);
    if ($2663) {
      __label__ = 602;
      break;
    } else {
      __label__ = 603;
      break;
    }
   case 602:
    var $2667 = HEAP32[$pn + 32 >> 2];
    var $2668 = __ZNK11JSParseNode5getOpEv($pn);
    var $2669 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $2667, $2668, $cg);
    var $_5 = $pn;
    var $ok_0 = $2669;
    __label__ = 607;
    break;
   case 603:
    var $2671 = __ZNK11JSParseNode5getOpEv($pn);
    var $2672 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $2671, $cg, 0);
    var $_5 = $pn;
    var $ok_0 = $2672 & 1;
    __label__ = 607;
    break;
   case 604:
    var $2677 = HEAP32[$pn + 36 >> 2];
    var $2678 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $2677, $index21);
    if ($2678) {
      __label__ = 605;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 605:
    var $2680 = HEAP32[$index21 >> 2];
    var $2681 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $2680, $cg, 0);
    if ($2681) {
      __label__ = 606;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 606:
    var $2683 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 185, $cg, 0);
    if ($2683) {
      var $ok_059 = 1;
      var $_560 = $pn;
      __label__ = 608;
      break;
    } else {
      var $_1 = 0;
      __label__ = 613;
      break;
    }
   case 607:
    var $ok_0;
    var $_5;
    if (($ok_0 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 612;
      break;
    } else {
      var $ok_059 = $ok_0;
      var $_560 = $_5;
      __label__ = 608;
      break;
    }
   case 608:
    var $_560;
    var $ok_059;
    if ((HEAP32[$cg + 236 >> 2] | 0) == 1) {
      __label__ = 609;
      break;
    } else {
      var $ok_2 = $ok_059;
      __label__ = 612;
      break;
    }
   case 609:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      var $ok_1 = $ok_059;
      __label__ = 611;
      break;
    } else {
      __label__ = 610;
      break;
    }
   case 610:
    var $2694 = __ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator($cx, $cg);
    var $ok_1 = $2694;
    __label__ = 611;
    break;
   case 611:
    var $ok_1;
    var $2697 = HEAP32[$_560 + 16 >> 2];
    var $2698 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $2697);
    if (($2698 | 0) == 0) {
      var $_1 = 0;
      __label__ = 613;
      break;
    } else {
      var $ok_2 = $ok_1;
      __label__ = 612;
      break;
    }
   case 612:
    var $ok_2;
    var $_1 = $ok_2;
    __label__ = 613;
    break;
   case 613:
    var $_1;
    __ZN16EmitLevelManagerD1Ev($elm);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_EmitTree["X"] = 1;

function _INT_TO_JSID1151($i) {
  return $i << 1 | 1;
}

function _INT_FITS_IN_JSID($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function __ZNK11JSParseNode7getKindEv($this) {
  return HEAP32[$this >> 2] & 65535;
}

function __ZNK11JSParseNode5getOpEv($this) {
  return HEAPU32[$this >> 2] >>> 16 & 255;
}

function __ZNK13JSFunctionBox8functionEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN13JSTreeContext11setFunctionEP10JSFunction($this, $fun) {
  HEAP32[$this + 60 >> 2] = $fun;
  return;
}

function __ZN14JSCGObjectList5indexEP11JSObjectBox($this, $objbox) {
  var $1 = $this + 4 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$objbox + 4 >> 2] = $2;
  HEAP32[$1 >> 2] = $objbox;
  var $4 = $this | 0;
  var $5 = HEAP32[$4 >> 2];
  var $6 = $5 + 1 | 0;
  HEAP32[$4 >> 2] = $6;
  HEAP32[$objbox + 16 >> 2] = $5;
  return $5;
}

function __ZNK2js11UpvarCookie6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == -1;
}

function __ZNK2js11UpvarCookie4slotEv($this) {
  return HEAP32[$this >> 2] & 65535;
}

function __ZNK11JSParseNode4lastEv($this) {
  return HEAP32[$this + 36 >> 2] - 24 | 0;
}

function __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($this, $cx, $strictChecks, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $value3 = __stackBase__ + 8;
    var $idvalue = __stackBase__ + 16;
    var $id = __stackBase__ + 24;
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 30) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 31) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 33) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 24) {
      __label__ = 8;
      break;
    } else if (($1 | 0) == 26) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 2:
    var $4 = $this + 32 | 0;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    var $6 = __ZN2JS5Value9setNumberEd($vp, $5);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 3:
    var $11 = HEAP32[$this + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $11);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 4:
    var $13 = __ZNK11JSParseNode5getOpEv($this);
    if (($13 | 0) == 64) {
      __label__ = 5;
      break;
    } else if (($13 | 0) == 66) {
      __label__ = 6;
      break;
    } else if (($13 | 0) == 67) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 6:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 7:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 8:
    var $19 = HEAP32[$this + 40 >> 2];
    var $20 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $19, 0);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $pn_0_in = $this + 32 | 0;
    var $idx_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $idx_0;
    var $pn_0_in;
    var $pn_0 = HEAP32[$pn_0_in >> 2];
    if (($pn_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($pn_0, $cx, $strictChecks, $value);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 12:
    var $29 = _INT_TO_JSID1151($idx_0);
    var $30 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($20, $cx, $29, $value, 0, 0, 1);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $pn_0_in = $pn_0 + 24 | 0;
    var $idx_0 = $idx_0 + 1 | 0;
    __label__ = 10;
    break;
   case 14:
    __ZN2js5types12FixArrayTypeEP9JSContextP8JSObject($cx, $20);
    __ZN2JS5Value9setObjectER8JSObject($vp, $20);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 15:
    var $38 = HEAP32[$this + 40 >> 2];
    var $39 = __ZN2jsL17GuessObjectGCKindEjb1152($38);
    var $40 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $39);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $44 = $cx;
    var $45 = $40;
    var $pn2_0_in = $this + 32 | 0;
    __label__ = 17;
    break;
   case 17:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $51 = HEAP32[$pn2_0 + 36 >> 2];
    var $52 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($51, $cx, $strictChecks, $value3);
    if ($52) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 19:
    var $55 = HEAP32[$pn2_0 + 32 >> 2];
    var $56 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($55, 30);
    var $57 = $55 + 32 | 0;
    if ($56) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    var $59 = $57;
    var $60 = (tempDoubleI32[0] = HEAP32[$59 >> 2], tempDoubleI32[1] = HEAP32[$59 + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd1149($idvalue, $60);
    var $61 = __ZNK2JS5Value7isInt32Ev($idvalue);
    if ($61) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $63 = __ZNK2JS5Value7toInt32Ev($idvalue);
    var $64 = _INT_FITS_IN_JSID($63);
    if (($64 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $67 = _INT_TO_JSID1151($63);
    HEAP32[$id >> 2] = $67;
    var $71 = $67;
    __label__ = 25;
    break;
   case 23:
    var $69 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $40, $idvalue, $id);
    if ($69) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $71 = HEAP32[$id >> 2];
    __label__ = 25;
    break;
   case 25:
    var $71;
    var $72 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($40, $cx, $71, $value3, 0, 0, 1);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $76 = HEAP32[$57 >> 2];
    var $77 = __ZL12ATOM_TO_JSIDP6JSAtom1150($76);
    var $78 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($44, $45, $77, $value3, 0, 0, 1, 0, 0, 0);
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 17;
    break;
   case 28:
    __ZN2js5types13FixObjectTypeEP9JSContextP8JSObject($cx, $40);
    __ZN2JS5Value9setObjectER8JSObject($vp, $40);
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE["X"] = 1;

function __ZN2js5types12FixArrayTypeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject($5, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL17GuessObjectGCKindEjb1152($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($numSlots | 0) == 0) {
      var $_0 = 4;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gcL15GetGCObjectKindEjb1183($numSlots);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj, $idval, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($idval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj, $idval, $idp);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $idval, $idp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13FixObjectTypeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject($5, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16EmitLevelManagerC1EP15JSCodeGenerator($this, $cg) {
  __ZN16EmitLevelManagerC2EP15JSCodeGenerator($this, $cg);
  return;
}

function _js_NewSrcNote2($cx, $cg, $type, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, $type);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _js_SetSrcNoteOffset($cx, $cg, $1, 0, $offset);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_NewSrcNote($cx, $cg, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($1 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cg + 172 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $8 = HEAP32[$5 + 12 >> 2] + $1 | 0;
    var $15 = HEAP32[$5 + 8 >> 2] - HEAP32[$5 >> 2] | 0;
    var $16 = $5 + 24 | 0;
    var $18 = $15 - HEAP32[$16 >> 2] | 0;
    HEAP32[$16 >> 2] = $15;
    if (($18 | 0) > 7) {
      var $delta_0 = $18;
      var $sn_0 = $8;
      __label__ = 3;
      break;
    } else {
      var $delta_1 = $18;
      var $sn_1 = $8;
      var $index_0 = $1;
      __label__ = 5;
      break;
    }
   case 3:
    var $sn_0;
    var $delta_0;
    var $21 = ($delta_0 | 0) < 63 ? $delta_0 : 63;
    HEAP8[$sn_0] = ($21 | 192) & 255;
    var $24 = $delta_0 - $21 | 0;
    var $25 = __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($25 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $31 = HEAP32[HEAP32[$4 >> 2] + 12 >> 2] + $25 | 0;
    if (($24 | 0) > 7) {
      var $delta_0 = $24;
      var $sn_0 = $31;
      __label__ = 3;
      break;
    } else {
      var $delta_1 = $24;
      var $sn_1 = $31;
      var $index_0 = $25;
      __label__ = 5;
      break;
    }
   case 5:
    var $index_0;
    var $sn_1;
    var $delta_1;
    HEAP8[$sn_1] = ($delta_1 & 7 | $type << 3) & 255;
    var $n_0 = HEAP8[_js_SrcNoteSpec + ($type << 3) + 4 | 0] << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $n_0;
    if (($n_0 | 0) > 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $index_0;
      __label__ = 9;
      break;
    }
   case 7:
    var $43 = _js_NewSrcNote($cx, $cg, 0);
    if (($43 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $n_0 = $n_0 - 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_NewSrcNote["X"] = 1;

function __ZNK11JSParseNode7isArityE16JSParseNodeArity($this, $a) {
  var $1 = __ZNK11JSParseNode8getArityEv($this);
  return ($1 | 0) == ($a | 0);
}

function __ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj($cx, $cg, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote2($cx, $cg, 19, $index);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _js_Emit1($cx, $cg, 0);
    var $7 = ($4 | 0) > -1;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 616);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($4, $p1, $p2);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings8transferEP9JSContextPS0_($this, $cx, $bindings) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = $bindings;
    HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
    HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
    var $4 = HEAP32[$this >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js5Shape12inDictionaryEv($4);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $4 + 36 | 0;
    HEAP32[$9 >> 2] = $this;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN15JSCodeGeneratorD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $op, $index, $cg, $psuffix) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index);
    if (($1 | 0) == 66) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $index >>> 8 & 255;
    var $6 = $index & 255;
    var $7 = _js_Emit3($cx, $cg, $op, $5, $6);
    if (($7 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op);
    if (($psuffix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$psuffix >> 2] = $1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 5:
    if (($1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = _js_Emit1($cx, $cg, $1);
    var $_0 = ($15 | 0) > -1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg) {
  var $2 = HEAP32[$cg + 32 >> 2];
  var $3 = __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $2);
  return $3;
}

function __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $pn, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($2);
    var $3 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $dn_0 = HEAP32[$pn + 36 >> 2];
    __label__ = 5;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $dn_0 = $pn;
    __label__ = 5;
    break;
   case 5:
    var $dn_0;
    var $13 = __ZNK12JSDefinition8isGlobalEv($dn_0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom($cg, $dn_0 | 0, $pn, $atom);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator($cx, $op, $slot, $index, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index);
    if (($1 | 0) == 66) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _js_EmitN($cx, $cg, $op, 4);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$4 + ($10 + 1) | 0] = $slot >>> 8 & 255;
    HEAP8[$4 + ($10 + 2) | 0] = $slot & 255;
    HEAP8[$4 + ($10 + 3) | 0] = $index >>> 8 & 255;
    HEAP8[$4 + ($10 + 4) | 0] = $index & 255;
    if (($1 | 0) == 0) {
      var $26 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = _js_Emit1($cx, $cg, $1);
    var $26 = ($23 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $26;
    var $_0 = $26 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    var $atom = __stackBase__ + 4;
    var $cookie = __stackBase__ + 8;
    var $name = __stackBase__ + 12;
    var $_ = __stackBase__ + 16;
    var $_1 = __stackBase__ + 20;
    var $p = __stackBase__ + 20;
    var $index = __stackBase__ + 36;
    var $1 = $pn + 32 | 0;
    var $3 = $pn + 44 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 & 512 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 2:
    var $8 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$pn + 36 >> 2];
    var $12 = __ZNK11JSParseNode13isDeoptimizedEv($pn);
    if ($12) {
      var $_1 = 1;
      __label__ = 88;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    var $19 = HEAP32[$11 + 44 >> 2] & 2 | $4;
    HEAP32[$3 >> 2] = $19;
    var $dn_0 = $14;
    var $25 = $19;
    __label__ = 7;
    break;
   case 5:
    var $21 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 6:
    var $dn_0 = $pn;
    var $25 = $4;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $dn_0;
    var $26 = __ZNK11JSParseNode5getOpEv($pn);
    HEAP32[$op >> 2] = $26;
    if (($26 | 0) == 0) {
      var $_1 = 1;
      __label__ = 88;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = HEAP32[$1 >> 2];
    HEAP32[$atom >> 2] = $30;
    var $31 = $dn_0 | 0;
    var $33 = HEAP32[$dn_0 + 40 >> 2];
    HEAP32[$cookie >> 2] = $33;
    var $35 = __ZN12JSDefinition4kindEv($dn_0);
    if (($26 | 0) == 36) {
      __label__ = 9;
      break;
    } else if (($26 | 0) == 59 || ($26 | 0) == 14) {
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    if (($35 | 0) == 5) {
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[HEAP32[$cg + 48 >> 2] + 960 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = __ZNK11JSParseNode10isTopLevelEv($31);
    if ($45) {
      var $48 = $25;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN11JSParseNode5setOpE4JSOp($pn, 66);
    var $48 = HEAP32[$3 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $48;
    HEAP32[$3 >> 2] = $48 | 512;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 14:
    var $51 = __ZNK11JSParseNode7isConstEv($pn);
    if ($51) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $53 = $cg | 0;
    var $54 = __ZN13JSTreeContext16needStrictChecksEv($53);
    if ($54) {
      __label__ = 16;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 16:
    __ZN16JSAutoByteStringC1Ev($name);
    var $56 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $30, $name);
    if (($56 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $62 = __ZNK16JSAutoByteString3ptrEv($name);
    var $63 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $61, $53, $pn, 19, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $62, tempInt));
    if ($63) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_1 = 0;
    __label__ = 88;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($name);
    __label__ = 20;
    break;
   case 20:
    HEAP32[$op >> 2] = 59;
    __ZN11JSParseNode5setOpE4JSOp($pn, 59);
    __label__ = 21;
    break;
   case 21:
    var $67 = __ZNK12JSDefinition8isGlobalEv($dn_0);
    if ($67) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    if ((HEAP32[$op >> 2] | 0) == 59) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $73 = $pn + 40 | 0;
    var $74 = __ZNK2js11UpvarCookie6isFreeEv($73);
    if ($74) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN11JSParseNode5setOpE4JSOp($pn, 156);
    var $77 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $77;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 25:
    __ZN2js11UpvarCookie8makeFreeEv($cookie);
    __label__ = 26;
    break;
   case 26:
    var $80 = __ZNK2js11UpvarCookie6isFreeEv($cookie);
    if ($80) {
      __label__ = 27;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 27:
    var $85 = HEAP32[HEAP32[$cg + 48 >> 2] + 960 >> 2];
    if (($85 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ((HEAP32[$cg >> 2] & 16 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 29:
    var $93 = __ZNK2js10StackFrame13isGlobalFrameEv($85);
    if ($93) {
      __label__ = 30;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 30:
    var $95 = __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op);
    if ($95) {
      __label__ = 31;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 31:
    var $97 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $30, $_);
    if ($97) {
      __label__ = 32;
      break;
    } else {
      var $_1 = 0;
      __label__ = 88;
      break;
    }
   case 32:
    var $99 = HEAP32[$op >> 2];
    __ZN11JSParseNode5setOpE4JSOp($pn, $99);
    var $101 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $101;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 33:
    var $103 = $cg | 0;
    var $104 = __ZNK13JSTreeContext16mightAliasLocalsEv($103);
    if ($104) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $106 = __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op);
    if ($106) {
      __label__ = 35;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 35:
    var $108 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $30, $_1);
    if ($108) {
      __label__ = 36;
      break;
    } else {
      var $_1 = 0;
      __label__ = 88;
      break;
    }
   case 36:
    var $110 = HEAP32[$op >> 2];
    __ZN11JSParseNode5setOpE4JSOp($pn, $110);
    var $112 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $112;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 37:
    var $114 = __ZNK2js11UpvarCookie5levelEv($cookie);
    var $115 = $cg | 0;
    var $117 = HEAP32[$cg + 76 >> 2];
    var $118 = $114 & 65535;
    var $119 = $117 - $118 | 0;
    if (($117 | 0) == ($118 | 0)) {
      __label__ = 59;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if ((HEAP32[$op >> 2] | 0) != 59 | $119 >>> 0 > 15) {
      var $_1 = 1;
      __label__ = 88;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ((HEAP32[$cg >> 2] & 256 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 40:
    var $131 = __ZNK13JSTreeContext3funEv($115);
    var $132 = __ZNK10JSFunction13isFlatClosureEv($131);
    if ($132) {
      __label__ = 41;
      break;
    } else {
      var $_1 = 1;
      __label__ = 88;
      break;
    }
   case 41:
    var $134 = $cg + 308 | 0;
    var $135 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext($134, $cx);
    if ($135) {
      __label__ = 42;
      break;
    } else {
      var $_1 = 0;
      __label__ = 88;
      break;
    }
   case 42:
    var $137 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($134);
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $137, $atom);
    var $138 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($138 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $141 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $142 = HEAPU32[$141 >> 2];
    HEAP32[$index >> 2] = $142;
    var $191 = $142;
    __label__ = 58;
    break;
   case 44:
    var $144 = $cg + 92 | 0;
    var $145 = HEAP32[$atom >> 2];
    var $146 = __ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom($144, $cx, $145);
    if ($146) {
      __label__ = 45;
      break;
    } else {
      var $_1 = 0;
      __label__ = 88;
      break;
    }
   case 45:
    var $148 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($134);
    var $149 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($148);
    HEAP32[$index >> 2] = $149;
    var $150 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($148, $p, $atom, $index);
    if ($150) {
      __label__ = 46;
      break;
    } else {
      var $_1 = 0;
      __label__ = 88;
      break;
    }
   case 46:
    var $152 = $cg + 316 | 0;
    var $153 = $cg + 184 | 0;
    var $154 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($153);
    var $155 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($154);
    var $156 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv($152);
    if ($156) {
      __label__ = 47;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 47:
    if ($155 >>> 0 < 9) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $160 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($152, $155);
    __label__ = 51;
    break;
   case 49:
    var $162 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv($152);
    var $163 = $155 << 2;
    var $164 = __ZN2js15TempAllocPolicy7malloc_Ej($162, $163);
    if (($164 | 0) == 0) {
      var $_1 = 0;
      __label__ = 88;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $167 = $164;
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j($152, $167, $155);
    __label__ = 51;
    break;
   case 51:
    if (($155 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 52;
      break;
    }
   case 52:
    var $i_05;
    var $169 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($152, $i_05);
    HEAP32[$169 >> 2] = 0;
    var $170 = $i_05 + 1 | 0;
    if (($170 | 0) == ($155 | 0)) {
      __label__ = 53;
      break;
    } else {
      var $i_05 = $170;
      __label__ = 52;
      break;
    }
   case 53:
    var $171 = __ZNK2js11UpvarCookie4slotEv($cookie);
    if ($171 << 16 >> 16 == -1 | ($35 | 0) == 4) {
      var $slot_0 = $171;
      __label__ = 57;
      break;
    } else {
      var $tc_0 = $115;
      __label__ = 54;
      break;
    }
   case 54:
    var $tc_0;
    var $175 = HEAP32[$tc_0 + 72 >> 2];
    if ((HEAP32[$175 + 76 >> 2] | 0) == ($118 | 0)) {
      __label__ = 55;
      break;
    } else {
      var $tc_0 = $175;
      __label__ = 54;
      break;
    }
   case 55:
    var $180 = __ZNK13JSTreeContext10inFunctionEv($175);
    if ($180) {
      __label__ = 56;
      break;
    } else {
      var $slot_0 = $171;
      __label__ = 57;
      break;
    }
   case 56:
    var $182 = __ZNK13JSTreeContext3funEv($175);
    var $slot_0 = HEAP16[$182 + 56 >> 1] + $171 & 65535;
    __label__ = 57;
    break;
   case 57:
    var $slot_0;
    var $187 = HEAP32[$index >> 2];
    var $188 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($152, $187);
    var $189 = $119 & 65535;
    __ZN2js11UpvarCookie3setEtt($188, $189, $slot_0);
    var $191 = $187;
    __label__ = 58;
    break;
   case 58:
    var $191;
    __ZN11JSParseNode5setOpE4JSOp($pn, 136);
    var $193 = $pn + 40 | 0;
    __ZN2js11UpvarCookie3setEtt($193, 0, $191 & 65535);
    var $196 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $196;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 59:
    if (($35 | 0) == 2) {
      __label__ = 60;
      break;
    } else if (($35 | 0) == 4) {
      __label__ = 67;
      break;
    } else if (($35 | 0) == 0) {
      __label__ = 74;
      break;
    } else if (($35 | 0) == 5) {
      var $_1 = 1;
      __label__ = 88;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 60:
    var $199 = HEAPU32[$op >> 2];
    if (($199 | 0) == 59) {
      __label__ = 61;
      break;
    } else if (($199 | 0) == 111) {
      __label__ = 62;
      break;
    } else if (($199 | 0) == 41) {
      __label__ = 63;
      break;
    } else if (($199 | 0) == 47) {
      __label__ = 64;
      break;
    } else if (($199 | 0) == 44) {
      __label__ = 65;
      break;
    } else if (($199 | 0) == 50) {
      __label__ = 66;
      break;
    } else {
      var $237 = $199;
      __label__ = 87;
      break;
    }
   case 61:
    HEAP32[$op >> 2] = 86;
    var $237 = 86;
    __label__ = 87;
    break;
   case 62:
    HEAP32[$op >> 2] = 87;
    var $237 = 87;
    __label__ = 87;
    break;
   case 63:
    HEAP32[$op >> 2] = 101;
    var $237 = 101;
    __label__ = 87;
    break;
   case 64:
    HEAP32[$op >> 2] = 103;
    var $237 = 103;
    __label__ = 87;
    break;
   case 65:
    HEAP32[$op >> 2] = 102;
    var $237 = 102;
    __label__ = 87;
    break;
   case 66:
    HEAP32[$op >> 2] = 104;
    var $237 = 104;
    __label__ = 87;
    break;
   case 67:
    var $207 = HEAP32[$op >> 2];
    if (($207 | 0) == 59) {
      __label__ = 68;
      break;
    } else if (($207 | 0) == 111) {
      __label__ = 69;
      break;
    } else if (($207 | 0) == 41) {
      __label__ = 70;
      break;
    } else if (($207 | 0) == 47) {
      __label__ = 71;
      break;
    } else if (($207 | 0) == 44) {
      __label__ = 72;
      break;
    } else if (($207 | 0) == 50) {
      __label__ = 73;
      break;
    } else {
      var $237 = $207;
      __label__ = 87;
      break;
    }
   case 68:
    HEAP32[$op >> 2] = 84;
    var $237 = 84;
    __label__ = 87;
    break;
   case 69:
    HEAP32[$op >> 2] = 85;
    var $237 = 85;
    __label__ = 87;
    break;
   case 70:
    HEAP32[$op >> 2] = 97;
    var $237 = 97;
    __label__ = 87;
    break;
   case 71:
    HEAP32[$op >> 2] = 99;
    var $237 = 99;
    __label__ = 87;
    break;
   case 72:
    HEAP32[$op >> 2] = 98;
    var $237 = 98;
    __label__ = 87;
    break;
   case 73:
    HEAP32[$op >> 2] = 100;
    var $237 = 100;
    __label__ = 87;
    break;
   case 74:
    var $215 = __ZNK11JSParseNode4isOpE4JSOp($31, 131);
    if ($215) {
      __label__ = 75;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 75:
    if ((HEAP32[$cg >> 2] & 256 | 0) == 0) {
      __label__ = 77;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $225 = HEAP32[$op >> 2];
    __label__ = 78;
    break;
   case 77:
    HEAP32[$op >> 2] = 131;
    var $223 = HEAP32[$3 >> 2] | 2;
    HEAP32[$3 >> 2] = $223;
    var $225 = 131;
    __label__ = 78;
    break;
   case 78:
    var $225;
    __ZN11JSParseNode5setOpE4JSOp($pn, $225);
    var $227 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $227;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 79:
    var $228 = HEAP32[$op >> 2];
    if (($228 | 0) == 59) {
      __label__ = 80;
      break;
    } else if (($228 | 0) == 111) {
      __label__ = 81;
      break;
    } else if (($228 | 0) == 14) {
      __label__ = 82;
      break;
    } else if (($228 | 0) == 41) {
      __label__ = 83;
      break;
    } else if (($228 | 0) == 47) {
      __label__ = 84;
      break;
    } else if (($228 | 0) == 44) {
      __label__ = 85;
      break;
    } else if (($228 | 0) == 50) {
      __label__ = 86;
      break;
    } else {
      var $237 = $228;
      __label__ = 87;
      break;
    }
   case 80:
    HEAP32[$op >> 2] = 86;
    var $237 = 86;
    __label__ = 87;
    break;
   case 81:
    HEAP32[$op >> 2] = 87;
    var $237 = 87;
    __label__ = 87;
    break;
   case 82:
    HEAP32[$op >> 2] = 87;
    var $237 = 87;
    __label__ = 87;
    break;
   case 83:
    HEAP32[$op >> 2] = 101;
    var $237 = 101;
    __label__ = 87;
    break;
   case 84:
    HEAP32[$op >> 2] = 103;
    var $237 = 103;
    __label__ = 87;
    break;
   case 85:
    HEAP32[$op >> 2] = 102;
    var $237 = 102;
    __label__ = 87;
    break;
   case 86:
    HEAP32[$op >> 2] = 104;
    var $237 = 104;
    __label__ = 87;
    break;
   case 87:
    var $237;
    __ZN11JSParseNode5setOpE4JSOp($pn, $237);
    var $239 = $pn + 40 | 0;
    var $240 = __ZNK2js11UpvarCookie4slotEv($cookie);
    __ZN2js11UpvarCookie3setEtt($239, 0, $240);
    var $242 = HEAP32[$3 >> 2] | 512;
    HEAP32[$3 >> 2] = $242;
    var $_1 = 1;
    __label__ = 88;
    break;
   case 88:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext12parseMapPoolEv($cx);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE($5, $2);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_SetSrcNoteOffset($cx, $cg, $index, $which, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($offset >>> 0 > 8388607) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 3:
    var $4 = $cg + 172 | 0;
    var $5 = HEAPU32[$4 >> 2];
    var $7 = HEAPU32[$5 + 12 >> 2];
    var $8 = $index + ($7 + 1) | 0;
    if (($which | 0) == 0) {
      var $sn_0_lcssa = $8;
      __label__ = 5;
      break;
    } else {
      var $_013 = $which;
      var $sn_04 = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $sn_04;
    var $_013;
    var $sn_1 = HEAP8[$sn_04] << 24 >> 24 < 0 ? $sn_04 + 2 | 0 : $sn_04;
    var $13 = $sn_1 + 1 | 0;
    var $14 = $_013 - 1 | 0;
    if (($14 | 0) == 0) {
      var $sn_0_lcssa = $13;
      __label__ = 5;
      break;
    } else {
      var $_013 = $14;
      var $sn_04 = $13;
      __label__ = 4;
      break;
    }
   case 5:
    var $sn_0_lcssa;
    if (($offset | 0) > 127) {
      __label__ = 6;
      break;
    } else {
      var $sn_4 = $sn_0_lcssa;
      __label__ = 13;
      break;
    }
   case 6:
    if (HEAP8[$sn_0_lcssa] << 24 >> 24 < 0) {
      var $sn_3 = $sn_0_lcssa;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $sn_0_lcssa - $7 | 0;
    var $25 = HEAPU32[$5 + 16 >> 2];
    if (($25 + 1 | 0) >>> 0 < HEAPU32[$5 + 20 >> 2] >>> 0) {
      var $sn_2 = $sn_0_lcssa;
      var $40 = $5;
      var $39 = $25;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = HEAPU32[$4 >> 2];
    var $sn_2 = HEAP32[$34 + 12 >> 2] + $23 | 0;
    var $40 = $34;
    var $39 = HEAP32[$34 + 16 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $39;
    var $40;
    var $sn_2;
    HEAP32[$40 + 16 >> 2] = $39 + 2 | 0;
    var $46 = -3 - $23 + HEAP32[HEAP32[$4 >> 2] + 16 >> 2] | 0;
    if (($46 | 0) > 0) {
      __label__ = 11;
      break;
    } else {
      var $sn_3 = $sn_2;
      __label__ = 12;
      break;
    }
   case 11:
    _llvm_memmove_p0i8_p0i8_i32($sn_2 + 3 | 0, $sn_2 + 1 | 0, $46, 1, 0);
    var $sn_3 = $sn_2;
    __label__ = 12;
    break;
   case 12:
    var $sn_3;
    HEAP8[$sn_3] = ($offset >>> 16 | 128) & 255;
    HEAP8[$sn_3 + 1 | 0] = $offset >>> 8 & 255;
    var $sn_4 = $sn_3 + 2 | 0;
    __label__ = 13;
    break;
   case 13:
    var $sn_4;
    HEAP8[$sn_4] = $offset & 255;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_SetSrcNoteOffset["X"] = 1;

function __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, $op, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($off + 32768 | 0) >>> 0 > 65535;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($7 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $off >>> 8 & 255;
    var $12 = $off & 255;
    var $13 = _js_Emit3($cx, $cg, $op, $11, $12);
    if (($13 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAP32[HEAP32[$cg + 172 >> 2] >> 2] + $13 | 0;
    var $26 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $25, $25, $off);
    if (($26 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = $13;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType($cx, $cg, $toStmt, $lastp, $labelIndex, $noteType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, $toStmt);
    if (($1 | 0) == 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($labelIndex | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = _js_NewSrcNote2($cx, $cg, $noteType, $labelIndex);
    var $index_0 = $6;
    __label__ = 6;
    break;
   case 4:
    if (($noteType | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _js_NewSrcNote($cx, $cg, $noteType);
    var $index_0 = $10;
    __label__ = 6;
    break;
   case 6:
    var $index_0;
    if (($index_0 | 0) < 0) {
      var $_0 = -1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $lastp);
    if (($13 | 0) < 0) {
      var $_0 = $13;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $16 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $_ = ($16 | 0) == 0 ? -1 : $13;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo($cx, $cg, $pn, $stmtInfo) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1060;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tps = __stackBase__;
    var $intmap_space = __stackBase__ + 12;
    var $constVal = __stackBase__ + 1036;
    var $index = __stackBase__ + 1044;
    var $index1 = __stackBase__ + 1048;
    var $1 = __stackBase__ + 1052;
    var $2 = $pn + 36 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $3;
    __ZN12TempPopScopeC1Ev($tps);
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($4, 80);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $box_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = HEAP32[$3 + 32 >> 2];
    var $10 = $cg | 0;
    _js_PushBlockScope($10, $stmtInfo, $9, -1);
    HEAP16[$stmtInfo >> 1] = 5;
    var $12 = __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $4, $cg);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 3:
    var $14 = __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($14) {
      var $box_0 = $9;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 4:
    var $box_0;
    var $17 = HEAP32[$pn + 32 >> 2];
    var $18 = _js_EmitTree($cx, $cg, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $cg + 172 | 0;
    var $22 = HEAP32[$21 >> 2];
    var $29 = HEAP32[$22 + 8 >> 2] - HEAP32[$22 >> 2] | 0;
    var $30 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($4, 25);
    if ($30) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = $cg | 0;
    _js_PushStatement($32, $stmtInfo, 5, $29);
    var $top_0 = $29;
    var $pn2_0 = $4;
    __label__ = 9;
    break;
   case 7:
    var $34 = __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($tps, $cx, $cg);
    if ($34) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 137;
      break;
    }
   case 8:
    var $36 = HEAP32[$21 >> 2];
    var $43 = HEAP32[$36 + 8 >> 2] - HEAP32[$36 >> 2] | 0;
    HEAP32[$stmtInfo + 8 >> 2] = $43;
    var $45 = __ZNK11JSParseNode4exprEv($4);
    var $top_0 = $43;
    var $pn2_0 = $45;
    __label__ = 9;
    break;
   case 9:
    var $pn2_0;
    var $top_0;
    var $47 = $pn2_0 + 32 | 0;
    var $49 = HEAPU32[$pn2_0 + 40 >> 2];
    if (($49 | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($49 | 0) == 0) {
      var $switchOp_2 = 70;
      var $hasDefault_4 = 0;
      var $constPropagated_4 = 0;
      var $caseCount_2 = 0;
      var $tableLength_0 = 0;
      var $low_3 = 0;
      var $high_3 = -1;
      __label__ = 51;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $hasDefault_1 = 0;
    var $_pre_phi = $47 | 0;
    __label__ = 12;
    break;
   case 11:
    var $51 = $47 | 0;
    var $52 = HEAP32[$51 >> 2];
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($52, 39);
    var $54 = $53 & 1;
    if ($53) {
      var $switchOp_2 = 70;
      var $hasDefault_4 = $54;
      var $constPropagated_4 = 0;
      var $caseCount_2 = 0;
      var $tableLength_0 = 0;
      var $low_3 = 0;
      var $high_3 = -1;
      __label__ = 51;
      break;
    } else {
      var $hasDefault_1 = $54;
      var $_pre_phi = $51;
      __label__ = 12;
      break;
    }
   case 12:
    var $_pre_phi;
    var $hasDefault_1;
    var $56 = $constVal | 0;
    var $57 = $intmap_space | 0;
    var $intmap_bitlen_0 = 0;
    var $intmap_0 = 0;
    var $switchOp_0 = 70;
    var $hasDefault_2 = $hasDefault_1;
    var $constPropagated_0 = 0;
    var $pn3_0_in = $_pre_phi;
    var $caseCount_0 = $49;
    var $low_0 = 2147483647;
    var $high_0 = -2147483648;
    __label__ = 13;
    break;
   case 13:
    var $high_0;
    var $low_0;
    var $caseCount_0;
    var $pn3_0_in;
    var $constPropagated_0;
    var $hasDefault_2;
    var $switchOp_0;
    var $intmap_0;
    var $intmap_bitlen_0;
    var $pn3_0 = HEAPU32[$pn3_0_in >> 2];
    if (($pn3_0 | 0) == 0) {
      var $ok_5 = 1;
      var $constPropagated_3 = $constPropagated_0;
      __label__ = 42;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $61 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_0, 39);
    if ($61) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $intmap_bitlen_3 = $intmap_bitlen_0;
    var $intmap_3 = $intmap_0;
    var $switchOp_1 = $switchOp_0;
    var $hasDefault_3 = 1;
    var $constPropagated_2 = $constPropagated_0;
    var $caseCount_1 = $caseCount_0 - 1 | 0;
    var $low_2 = $low_0;
    var $high_2 = $high_0;
    __label__ = 41;
    break;
   case 16:
    if (($switchOp_0 | 0) == 120) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      var $pn3_0_pn = $pn3_0;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn3_0_pn;
    var $pn4_0 = HEAPU32[$pn3_0_pn + 32 >> 2];
    var $66 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn4_0, 28);
    if ($66) {
      var $pn3_0_pn = $pn4_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = __ZNK11JSParseNode7getKindEv($pn4_0);
    if (($68 | 0) == 30) {
      __label__ = 19;
      break;
    } else if (($68 | 0) == 31) {
      __label__ = 20;
      break;
    } else if (($68 | 0) == 29) {
      __label__ = 21;
      break;
    } else if (($68 | 0) == 33) {
      __label__ = 24;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 19:
    var $71 = $pn4_0 + 32 | 0;
    var $72 = (tempDoubleI32[0] = HEAP32[$71 >> 2], tempDoubleI32[1] = HEAP32[$71 + 4 >> 2], tempDoubleF64[0]);
    var $73 = __ZN2JS5Value9setNumberEd($constVal, $72);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 20:
    var $78 = HEAP32[$pn4_0 + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($constVal, $78);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 21:
    var $80 = __ZN11JSParseNode9maybeExprEv($pn4_0);
    if (($80 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $85 = HEAP32[$pn4_0 + 32 >> 2];
    __ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE($cx, $cg, $85, $constVal);
    var $86 = __ZNK2JS5Value7isMagicE10JSWhyMagic($constVal, undef);
    if ($86) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $88 = __ZNK2JS5Value8isObjectEv($constVal);
    if ($88) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      var $constPropagated_1 = 1;
      __label__ = 30;
      break;
    }
   case 24:
    var $90 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 67);
    if ($90) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    __ZN2JS5Value10setBooleanEb($constVal, 1);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 26:
    var $93 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 66);
    if ($93) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2JS5Value10setBooleanEb($constVal, 0);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 28:
    var $96 = __ZNK11JSParseNode4isOpE4JSOp($pn4_0, 64);
    if ($96) {
      __label__ = 29;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 120;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_0;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 29:
    __ZN2JS5Value7setNullEv($constVal);
    var $constPropagated_1 = $constPropagated_0;
    __label__ = 30;
    break;
   case 30:
    var $constPropagated_1;
    var $99 = __ZL22AllocateSwitchConstantP9JSContext($cx);
    var $100 = $pn3_0 + 40 | 0;
    var $101 = $100;
    HEAP32[$100 >> 2] = $99;
    if (($99 | 0) == 0) {
      var $ok_5 = 0;
      var $constPropagated_3 = $constPropagated_1;
      __label__ = 42;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $104$0 = HEAP32[$56 >> 2];
    var $104$1 = HEAP32[$56 + 4 >> 2];
    var $105 = $99 | 0;
    HEAP32[$105 >> 2] = $104$0;
    HEAP32[$105 + 4 >> 2] = $104$1;
    if (($switchOp_0 | 0) == 70) {
      __label__ = 32;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = $switchOp_0;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 32:
    var $108 = HEAP32[$101 >> 2];
    var $109 = __ZNK2JS5Value7isInt32Ev($108);
    if ($109) {
      __label__ = 33;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    }
   case 33:
    var $111 = __ZNK2JS5Value7toInt32Ev($108);
    if (($111 + 32768 | 0) >>> 0 > 65535) {
      var $intmap_bitlen_3 = $intmap_bitlen_0;
      var $intmap_3 = $intmap_0;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_0;
      var $high_2 = $high_0;
      __label__ = 41;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $low_1 = ($111 | 0) < ($low_0 | 0) ? $111 : $low_0;
    var $high_1 = ($high_0 | 0) < ($111 | 0) ? $111 : $high_0;
    var $_ = ($111 | 0) < 0 ? $111 + 65536 | 0 : $111;
    if (($_ | 0) < ($intmap_bitlen_0 | 0)) {
      var $intmap_bitlen_2 = $intmap_bitlen_0;
      var $intmap_2 = $intmap_0;
      __label__ = 39;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if (($intmap_0 | 0) == 0 & ($_ | 0) < 8192) {
      var $intmap_bitlen_1 = 8192;
      var $intmap_1 = $57;
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $124 = __ZN9JSContext7malloc_Ej($cx, 8192);
    var $125 = $124;
    if (($124 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      var $intmap_bitlen_1 = 65536;
      var $intmap_1 = $125;
      __label__ = 38;
      break;
    }
   case 37:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 137;
    break;
   case 38:
    var $intmap_1;
    var $intmap_bitlen_1;
    _memset($intmap_1, 0, $intmap_bitlen_1 >>> 3, 1);
    var $intmap_bitlen_2 = $intmap_bitlen_1;
    var $intmap_2 = $intmap_1;
    __label__ = 39;
    break;
   case 39:
    var $intmap_2;
    var $intmap_bitlen_2;
    var $133 = $intmap_2 + ($_ >> 5 << 2) | 0;
    var $134 = HEAP32[$133 >> 2];
    var $136 = 1 << ($_ & 31);
    if (($134 & $136 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      var $intmap_bitlen_3 = $intmap_bitlen_2;
      var $intmap_3 = $intmap_2;
      var $switchOp_1 = 71;
      var $hasDefault_3 = $hasDefault_2;
      var $constPropagated_2 = $constPropagated_1;
      var $caseCount_1 = $caseCount_0;
      var $low_2 = $low_1;
      var $high_2 = $high_1;
      __label__ = 41;
      break;
    }
   case 40:
    var $140 = $134 | $136;
    HEAP32[$133 >> 2] = $140;
    var $intmap_bitlen_3 = $intmap_bitlen_2;
    var $intmap_3 = $intmap_2;
    var $switchOp_1 = $switchOp_0;
    var $hasDefault_3 = $hasDefault_2;
    var $constPropagated_2 = $constPropagated_1;
    var $caseCount_1 = $caseCount_0;
    var $low_2 = $low_1;
    var $high_2 = $high_1;
    __label__ = 41;
    break;
   case 41:
    var $high_2;
    var $low_2;
    var $caseCount_1;
    var $constPropagated_2;
    var $hasDefault_3;
    var $switchOp_1;
    var $intmap_3;
    var $intmap_bitlen_3;
    var $intmap_bitlen_0 = $intmap_bitlen_3;
    var $intmap_0 = $intmap_3;
    var $switchOp_0 = $switchOp_1;
    var $hasDefault_2 = $hasDefault_3;
    var $constPropagated_0 = $constPropagated_2;
    var $pn3_0_in = $pn3_0 + 24 | 0;
    var $caseCount_0 = $caseCount_1;
    var $low_0 = $low_2;
    var $high_0 = $high_2;
    __label__ = 13;
    break;
   case 42:
    var $constPropagated_3;
    var $ok_5;
    if (($intmap_0 | 0) == 0 | ($intmap_0 | 0) == ($57 | 0)) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    __ZN9JSContext5free_EPv(undef, $intmap_0);
    __label__ = 44;
    break;
   case 44:
    if (($ok_5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if (($switchOp_0 | 0) == 70) {
      __label__ = 46;
      break;
    } else if (($switchOp_0 | 0) == 71) {
      __label__ = 49;
      break;
    } else {
      var $switchOp_2 = $switchOp_0;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = 0;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 46:
    var $153 = $high_0 - $low_0 + 1 | 0;
    if ($153 >>> 0 > 65535) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    if ($153 >>> 0 > $caseCount_0 << 1 >>> 0) {
      __label__ = 48;
      break;
    } else {
      var $switchOp_2 = $switchOp_0;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = $153;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 48:
    var $switchOp_2 = 71;
    var $hasDefault_4 = $hasDefault_2;
    var $constPropagated_4 = $constPropagated_3;
    var $caseCount_2 = $caseCount_0;
    var $tableLength_0 = $153;
    var $low_3 = $low_0;
    var $high_3 = $high_0;
    __label__ = 51;
    break;
   case 49:
    var $160 = $cg + 268 | 0;
    var $161 = __ZNK13JSGCConstList6lengthEv($160);
    if (($161 + $caseCount_0 | 0) >>> 0 > 65536) {
      __label__ = 50;
      break;
    } else {
      var $switchOp_2 = 71;
      var $hasDefault_4 = $hasDefault_2;
      var $constPropagated_4 = $constPropagated_3;
      var $caseCount_2 = $caseCount_0;
      var $tableLength_0 = 0;
      var $low_3 = $low_0;
      var $high_3 = $high_0;
      __label__ = 51;
      break;
    }
   case 50:
    var $switchOp_2 = 120;
    var $hasDefault_4 = $hasDefault_2;
    var $constPropagated_4 = $constPropagated_3;
    var $caseCount_2 = $caseCount_0;
    var $tableLength_0 = 0;
    var $low_3 = $low_0;
    var $high_3 = $high_0;
    __label__ = 51;
    break;
   case 51:
    var $high_3;
    var $low_3;
    var $tableLength_0;
    var $caseCount_2;
    var $constPropagated_4;
    var $hasDefault_4;
    var $switchOp_2;
    var $166 = _js_NewSrcNote3($cx, $cg, 18, 0, 0);
    if (($166 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $169 = ($switchOp_2 | 0) == 120;
    if ($169) {
      var $switchSize_0 = 0;
      __label__ = 56;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($switchOp_2 | 0) == 70) {
      __label__ = 54;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 54:
    var $switchSize_0 = ($tableLength_0 << 1) + 6 | 0;
    __label__ = 56;
    break;
   case 55:
    var $switchSize_0 = ($caseCount_2 << 2) + 4 | 0;
    __label__ = 56;
    break;
   case 56:
    var $switchSize_0;
    var $179 = _js_EmitN($cx, $cg, $switchOp_2, $switchSize_0);
    if (($179 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ($169) {
      __label__ = 58;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 58:
    var $beforeCases_0 = 1;
    var $caseNoteIndex_0 = -1;
    var $off_0 = -1;
    var $pn3_1_in = $47 | 0;
    __label__ = 59;
    break;
   case 59:
    var $pn3_1_in;
    var $off_0;
    var $caseNoteIndex_0;
    var $beforeCases_0;
    var $pn3_1 = HEAPU32[$pn3_1_in >> 2];
    if (($pn3_1 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $188 = HEAP32[$pn3_1 + 32 >> 2];
    var $189 = ($188 | 0) != 0;
    if ($189) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $191 = _js_EmitTree($cx, $cg, $188);
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if (($caseNoteIndex_0 | 0) > -1) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $196 = HEAP32[$21 >> 2];
    var $204 = HEAP32[$196 + 8 >> 2] - $off_0 - HEAP32[$196 >> 2] | 0;
    var $205 = _js_SetSrcNoteOffset($cx, $cg, $caseNoteIndex_0, 0, $204);
    if (($205 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($189) {
      __label__ = 65;
      break;
    } else {
      var $beforeCases_1 = $beforeCases_0;
      var $caseNoteIndex_2 = $caseNoteIndex_0;
      var $off_1 = $off_0;
      __label__ = 71;
      break;
    }
   case 65:
    var $209 = _js_NewSrcNote2($cx, $cg, 7, 0);
    if (($209 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $212 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 121, 0);
    if (($212 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    HEAP32[$pn3_1 + 20 >> 2] = $212;
    if (($beforeCases_0 | 0) == 0) {
      var $beforeCases_1 = 0;
      var $caseNoteIndex_2 = $209;
      var $off_1 = $212;
      __label__ = 71;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $220 = HEAP32[HEAP32[$21 >> 2] + 16 >> 2];
    var $221 = $212 - $top_0 | 0;
    var $222 = _js_SetSrcNoteOffset($cx, $cg, $166, 1, $221);
    if (($222 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $227 = HEAP32[HEAP32[$21 >> 2] + 16 >> 2];
    if (($227 | 0) == ($220 | 0)) {
      var $beforeCases_1 = 0;
      var $caseNoteIndex_2 = $209;
      var $off_1 = $212;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $beforeCases_1 = 0;
    var $caseNoteIndex_2 = $209 - $220 + $227 | 0;
    var $off_1 = $212;
    __label__ = 71;
    break;
   case 71:
    var $off_1;
    var $caseNoteIndex_2;
    var $beforeCases_1;
    var $beforeCases_0 = $beforeCases_1;
    var $caseNoteIndex_0 = $caseNoteIndex_2;
    var $off_0 = $off_1;
    var $pn3_1_in = $pn3_1 + 24 | 0;
    __label__ = 59;
    break;
   case 72:
    if (($hasDefault_4 | 0) == 0 & ($caseNoteIndex_0 | 0) > -1) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    var $238 = HEAP32[$21 >> 2];
    var $246 = HEAP32[$238 + 8 >> 2] - $off_0 - HEAP32[$238 >> 2] | 0;
    var $247 = _js_SetSrcNoteOffset($cx, $cg, $caseNoteIndex_0, 0, $246);
    if (($247 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $250 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 122, 0);
    if (($250 | 0) < 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      var $off_2 = $off_0;
      var $defaultOffset_0 = $250;
      var $table_1 = 0;
      __label__ = 102;
      break;
    }
   case 75:
    var $255 = HEAPU32[HEAP32[$21 >> 2] >> 2];
    var $256 = ($switchOp_2 | 0) == 70;
    if ($256) {
      __label__ = 76;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 76:
    HEAP8[$top_0 + ($255 + 3) | 0] = $low_3 >>> 8 & 255;
    HEAP8[$top_0 + ($255 + 4) | 0] = $low_3 & 255;
    HEAP8[$top_0 + ($255 + 5) | 0] = $high_3 >>> 8 & 255;
    var $267 = $top_0 + ($255 + 6) | 0;
    HEAP8[$267] = $high_3 & 255;
    if (($tableLength_0 | 0) == 0) {
      var $table_0 = 0;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $270 = $tableLength_0 << 2;
    var $271 = __ZN9JSContext7malloc_Ej($cx, $270);
    var $272 = $271;
    if (($271 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    _memset($271, 0, $270, 1);
    var $pn3_214 = HEAP32[$47 >> 2];
    if (($pn3_214 | 0) == 0) {
      var $table_0 = $272;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      var $pn3_215 = $pn3_214;
      __label__ = 79;
      break;
    }
   case 79:
    var $pn3_215;
    var $277 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_215, 39);
    if ($277) {
      __label__ = 81;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $281 = HEAP32[$pn3_215 + 40 >> 2];
    var $282 = __ZNK2JS5Value7toInt32Ev($281);
    var $284 = $272 + ($282 - $low_3 << 2) | 0;
    HEAP32[$284 >> 2] = $pn3_215;
    __label__ = 81;
    break;
   case 81:
    var $pn3_2 = HEAPU32[$pn3_215 + 24 >> 2];
    if (($pn3_2 | 0) == 0) {
      var $table_0 = $272;
      var $pc_0 = $267;
      __label__ = 83;
      break;
    } else {
      var $pn3_215 = $pn3_2;
      __label__ = 79;
      break;
    }
   case 82:
    HEAP8[$top_0 + ($255 + 3) | 0] = $caseCount_2 >>> 8 & 255;
    var $293 = $top_0 + ($255 + 4) | 0;
    HEAP8[$293] = $caseCount_2 & 255;
    var $table_0 = 0;
    var $pc_0 = $293;
    __label__ = 83;
    break;
   case 83:
    var $pc_0;
    var $table_0;
    if ((HEAP32[$cg + 208 >> 2] | 0) == 0) {
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $301 = HEAP32[HEAP32[$21 >> 2] >> 2] + $top_0 | 0;
    var $302 = __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $301);
    if (($302 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    if (($constPropagated_4 | 0) == 0) {
      var $off_2 = -1;
      var $defaultOffset_0 = -1;
      var $table_1 = $table_0;
      __label__ = 102;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $308 = HEAP32[$21 >> 2] + 8 | 0;
    var $309 = HEAP32[$308 >> 2];
    HEAP32[$308 >> 2] = $pc_0 + 1 | 0;
    if ($256) {
      var $i_1 = 0;
      var $pc_1 = $pc_0;
      __label__ = 87;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 87:
    var $pc_1;
    var $i_1;
    if (($i_1 | 0) < ($tableLength_0 | 0)) {
      __label__ = 88;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 88:
    var $314 = HEAP32[$table_0 + ($i_1 << 2) >> 2];
    if (($314 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $318 = HEAP32[$314 + 32 >> 2];
    if (($318 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $321 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($318, 29);
    if ($321) {
      __label__ = 91;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 91:
    var $325 = HEAP32[$318 + 32 >> 2];
    var $326 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $325, $index);
    if ($326) {
      __label__ = 92;
      break;
    } else {
      var $table_21 = $table_0;
      var $ok_92 = 0;
      __label__ = 132;
      break;
    }
   case 92:
    var $329 = HEAP32[$21 >> 2] + 8 | 0;
    HEAP32[$329 >> 2] = $pc_1;
    var $330 = HEAP32[$index >> 2];
    var $331 = _js_NewSrcNote2($cx, $cg, 13, $330);
    if (($331 | 0) < 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $i_1 = $i_1 + 1 | 0;
    var $pc_1 = $pc_1 + 2 | 0;
    __label__ = 87;
    break;
   case 94:
    var $pn3_3_in = $47 | 0;
    var $pc_2 = $pc_0;
    __label__ = 95;
    break;
   case 95:
    var $pc_2;
    var $pn3_3_in;
    var $pn3_3 = HEAP32[$pn3_3_in >> 2];
    if (($pn3_3 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $342 = HEAP32[$pn3_3 + 32 >> 2];
    if (($342 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $345 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($342, 29);
    if ($345) {
      __label__ = 98;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 98:
    var $349 = HEAP32[$342 + 32 >> 2];
    var $350 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $349, $index1);
    if ($350) {
      __label__ = 99;
      break;
    } else {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    }
   case 99:
    var $353 = HEAP32[$21 >> 2] + 8 | 0;
    HEAP32[$353 >> 2] = $pc_2;
    var $354 = HEAP32[$index1 >> 2];
    var $355 = _js_NewSrcNote2($cx, $cg, 13, $354);
    if (($355 | 0) < 0) {
      var $ok_9 = 0;
      var $table_2 = $table_0;
      __label__ = 131;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $pn3_3_in = $pn3_3 + 24 | 0;
    var $pc_2 = $pc_2 + 4 | 0;
    __label__ = 95;
    break;
   case 101:
    var $361 = HEAP32[$21 >> 2] + 8 | 0;
    HEAP32[$361 >> 2] = $309;
    var $off_2 = -1;
    var $defaultOffset_0 = -1;
    var $table_1 = $table_0;
    __label__ = 102;
    break;
   case 102:
    var $table_1;
    var $defaultOffset_0;
    var $off_2;
    var $363 = $47 | 0;
    var $off_3 = $off_2;
    var $pn3_4_in = $363;
    __label__ = 103;
    break;
   case 103:
    var $pn3_4_in;
    var $off_3;
    var $pn3_4 = HEAP32[$pn3_4_in >> 2];
    if (($pn3_4 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    if ($169) {
      __label__ = 105;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 105:
    var $368 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_4, 39);
    if ($368) {
      __label__ = 107;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $370 = HEAP32[$21 >> 2];
    var $372 = HEAP32[$370 >> 2];
    var $374 = HEAP32[$pn3_4 + 20 >> 2];
    var $375 = $372 + $374 | 0;
    var $380 = HEAP32[$370 + 8 >> 2] - ($372 + $374) | 0;
    var $381 = _js_SetJumpOffset($cx, $cg, $375, $380);
    if (($381 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $385 = HEAP32[$pn3_4 + 36 >> 2];
    var $386 = $385;
    var $387 = _js_EmitTree($cx, $cg, $386);
    if (($387 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $392 = HEAP32[$385 + 20 >> 2];
    var $393 = $pn3_4 + 20 | 0;
    HEAP32[$393 >> 2] = $392;
    var $394 = $392 - $top_0 | 0;
    var $395 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_4, 39);
    var $_off_3 = $395 ? $394 : $off_3;
    var $off_3 = $_off_3;
    var $pn3_4_in = $pn3_4 + 24 | 0;
    __label__ = 103;
    break;
   case 109:
    var $399 = HEAP32[$21 >> 2];
    if (($hasDefault_4 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $off_5 = $off_3;
    var $410 = HEAP32[$399 >> 2];
    __label__ = 112;
    break;
   case 111:
    var $404 = HEAP32[$399 >> 2];
    var $off_5 = HEAP32[$399 + 8 >> 2] - $top_0 - $404 | 0;
    var $410 = $404;
    __label__ = 112;
    break;
   case 112:
    var $410;
    var $off_5;
    if ($169) {
      __label__ = 113;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 113:
    var $415 = _js_SetJumpOffset($cx, $cg, $410 + $defaultOffset_0 | 0, $top_0 - $defaultOffset_0 + $off_5 | 0);
    if (($415 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      var $pc_3 = 0;
      __label__ = 116;
      break;
    }
   case 114:
    var $419 = _js_SetJumpOffset($cx, $cg, $410 + $top_0 | 0, $off_5);
    if (($419 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $pc_3 = $top_0 + ($410 + 2) | 0;
    __label__ = 116;
    break;
   case 116:
    var $pc_3;
    var $424 = HEAP32[$21 >> 2];
    var $432 = HEAP32[$424 + 8 >> 2] - $top_0 - HEAP32[$424 >> 2] | 0;
    var $433 = _js_SetSrcNoteOffset($cx, $cg, $166, 0, $432);
    if (($433 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    if (($switchOp_2 | 0) == 70) {
      __label__ = 118;
      break;
    } else if (($switchOp_2 | 0) == 71) {
      __label__ = 124;
      break;
    } else {
      var $ok_9 = $433;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 118:
    var $ok_6 = $433;
    var $i_2 = 0;
    var $pc_4 = $pc_3 + 4 | 0;
    __label__ = 119;
    break;
   case 119:
    var $pc_4;
    var $i_2;
    var $ok_6;
    if (($i_2 | 0) < ($tableLength_0 | 0)) {
      __label__ = 120;
      break;
    } else {
      var $ok_9 = $ok_6;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 120:
    var $442 = HEAP32[$table_1 + ($i_2 << 2) >> 2];
    if (($442 | 0) == 0) {
      var $449 = 0;
      __label__ = 122;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $449 = HEAP32[$442 + 20 >> 2] - $top_0 | 0;
    __label__ = 122;
    break;
   case 122:
    var $449;
    var $450 = _js_SetJumpOffset($cx, $cg, $pc_4, $449);
    if (($450 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $ok_6 = $450;
    var $i_2 = $i_2 + 1 | 0;
    var $pc_4 = $pc_4 + 2 | 0;
    __label__ = 119;
    break;
   case 124:
    var $457 = $cg + 268 | 0;
    var $458 = $1 | 0;
    var $ok_7 = $433;
    var $pn3_5_in = $363;
    var $pc_5 = $pc_3 + 2 | 0;
    __label__ = 125;
    break;
   case 125:
    var $pc_5;
    var $pn3_5_in;
    var $ok_7;
    var $pn3_5 = HEAPU32[$pn3_5_in >> 2];
    if (($pn3_5 | 0) == 0) {
      var $ok_9 = $ok_7;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $462 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_5, 39);
    if ($462) {
      var $ok_8 = $ok_7;
      var $pc_6 = $pc_5;
      __label__ = 130;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $467 = HEAP32[$pn3_5 + 40 >> 2] | 0;
    var $468$0 = HEAP32[$467 >> 2];
    var $468$1 = HEAP32[$467 + 4 >> 2];
    HEAP32[$458 >> 2] = $468$0;
    HEAP32[$458 + 4 >> 2] = $468$1;
    var $469 = __ZN13JSGCConstList6appendEN2JS5ValueE($457, $1);
    if ($469) {
      __label__ = 128;
      break;
    } else {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    }
   case 128:
    var $471 = __ZNK13JSGCConstList6lengthEv($457);
    HEAP8[$pc_5 + 1 | 0] = ($471 + 65535 | 0) >>> 8 & 255;
    var $476 = __ZNK13JSGCConstList6lengthEv($457);
    var $479 = $pc_5 + 2 | 0;
    HEAP8[$479] = $476 + 255 & 255;
    var $482 = HEAP32[$pn3_5 + 20 >> 2] - $top_0 | 0;
    var $483 = _js_SetJumpOffset($cx, $cg, $479, $482);
    if (($483 | 0) == 0) {
      var $ok_9 = 0;
      var $table_2 = $table_1;
      __label__ = 131;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $ok_8 = $483;
    var $pc_6 = $pc_5 + 4 | 0;
    __label__ = 130;
    break;
   case 130:
    var $pc_6;
    var $ok_8;
    var $ok_7 = $ok_8;
    var $pn3_5_in = $pn3_5 + 24 | 0;
    var $pc_5 = $pc_6;
    __label__ = 125;
    break;
   case 131:
    var $table_2;
    var $ok_9;
    if (($table_2 | 0) == 0) {
      var $ok_93 = $ok_9;
      __label__ = 133;
      break;
    } else {
      var $table_21 = $table_2;
      var $ok_92 = $ok_9;
      __label__ = 132;
      break;
    }
   case 132:
    var $ok_92;
    var $table_21;
    __ZN9JSContext5free_EPv(undef, $table_21);
    var $ok_93 = $ok_92;
    __label__ = 133;
    break;
   case 133:
    var $ok_93;
    if (($ok_93 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $494 = _js_PopStatementCG($cx, $cg);
    if (($494 | 0) == 0) {
      var $_0 = 0;
      __label__ = 137;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $498 = HEAP32[$2 >> 2];
    var $499 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($498, 80);
    if ($499) {
      __label__ = 136;
      break;
    } else {
      var $_0 = $494;
      __label__ = 137;
      break;
    }
   case 136:
    var $501 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $box_0);
    var $_0 = $501;
    __label__ = 137;
    break;
   case 137:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo["X"] = 1;

function __ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $nextpn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nextpn | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($nextpn, 25);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($nextpn, 5);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = HEAP32[$nextpn + 32 >> 2];
    if (($8 | 0) == 0) {
      var $_01 = $nextpn;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_01 = $8;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $13 = HEAP32[$_01 + 8 >> 2];
    var $14 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $13);
    if (($14 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = $cg + 612 | 0;
    var $18 = HEAPU16[$17 >> 1];
    if ($18 << 16 >> 16 == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[$17 >> 1] = $18 + 1 & 65535;
    __label__ = 9;
    break;
   case 9:
    var $24 = ($18 & 65535) >>> 8 & 255;
    var $25 = $18 & 255;
    var $26 = _js_Emit3($cx, $cg, 109, $24, $25);
    var $_0 = $26;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScopeC1Ev($this) {
  __ZN12TempPopScopeC2Ev($this);
  return;
}

function __ZN2jsL15TokenKindIsDeclENS_9TokenKindE($tt) {
  return ($tt | 0) == 46 | ($tt | 0) == 81;
}

function __ZNK11JSParseNode4exprEv($this) {
  return HEAP32[$this + 36 >> 2];
}

function __ZNK2js11UpvarCookie9asIntegerEv($this) {
  return HEAP32[$this >> 2];
}

function __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_js_CodeSpec + ($op << 3) + 4 >> 2] & 67108864 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cg + 614 | 0;
    var $7 = HEAP16[$6 >> 1];
    if ($7 << 16 >> 16 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $7 + 1 & 65535;
    HEAP16[$6 >> 1] = $10;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator($this, $cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = $cg + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    HEAP32[$this >> 2] = $3;
    var $6 = HEAP32[$cg + 28 >> 2];
    HEAP32[$this + 4 >> 2] = $6;
    var $9 = HEAP32[$cg + 32 >> 2];
    HEAP32[$this + 8 >> 2] = $9;
    if ((HEAP16[HEAP32[$2 >> 2] >> 1] - 12 & 65535 & 65535) < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _js_PopStatement($1);
    __label__ = 3;
    break;
   case 3:
    _js_PopStatement($1);
    var $16 = _js_Emit1($cx, $cg, 0);
    if (($16 | 0) > -1) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $22 = ($19 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $22;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator($this, $cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    HEAP32[$cg + 24 >> 2] = $2;
    var $5 = HEAP32[$this + 4 >> 2];
    HEAP32[$cg + 28 >> 2] = $5;
    var $8 = HEAP32[$this + 8 >> 2];
    HEAP32[$cg + 32 >> 2] = $8;
    var $10 = _js_Emit1($cx, $cg, 0);
    if (($10 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $16 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $13 = __ZL14EmitBlockChainP9JSContextP15JSCodeGenerator($cx, $cg);
    var $16 = ($13 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $16;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_($cx, $cg, $lhs, $op, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atomIndex = __stackBase__;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $7 = HEAP32[$2 + 8 >> 2];
    var $8 = HEAP32[$2 >> 2];
    HEAP32[$atomIndex >> 2] = -1;
    var $9 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($9 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($9 | 0) == 22) {
      __label__ = 8;
      break;
    } else if (($9 | 0) == 23) {
      __label__ = 10;
      break;
    } else if (($9 | 0) == 27) {
      __label__ = 12;
      break;
    } else if (($9 | 0) == 19) {
      __label__ = 13;
      break;
    } else {
      var $offset_0 = 1;
      __label__ = 15;
      break;
    }
   case 2:
    var $11 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $lhs);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $lhs + 40 | 0;
    var $16 = __ZNK2js11UpvarCookie6isFreeEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = __ZNK2js11UpvarCookie9asIntegerEv($15);
    HEAP32[$atomIndex >> 2] = $18;
    var $offset_0 = 1;
    __label__ = 15;
    break;
   case 5:
    var $22 = HEAP32[$lhs + 32 >> 2];
    var $23 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $22, $atomIndex);
    if ($23) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 6:
    var $25 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($25) {
      var $offset_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 157);
    var $28 = $27 ? 217 : 110;
    var $29 = HEAP32[$atomIndex >> 2];
    var $30 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $28, $29, $cg, 0);
    if ($30) {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 8:
    var $32 = __ZNK11JSParseNode4exprEv($lhs);
    var $33 = _js_EmitTree($cx, $cg, $32);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = HEAP32[$lhs + 32 >> 2];
    var $39 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $38, $atomIndex);
    if ($39) {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 10:
    var $42 = HEAP32[$lhs + 32 >> 2];
    var $43 = _js_EmitTree($cx, $cg, $42);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $48 = HEAP32[$lhs + 36 >> 2];
    var $49 = _js_EmitTree($cx, $cg, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 3;
      __label__ = 15;
      break;
    }
   case 12:
    var $52 = _js_EmitTree($cx, $cg, $lhs);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    }
   case 13:
    var $56 = HEAP32[$lhs + 32 >> 2];
    var $57 = _js_EmitTree($cx, $cg, $56);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $60 = _js_Emit1($cx, $cg, 172);
    if (($60 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      var $offset_0 = 2;
      __label__ = 15;
      break;
    }
   case 15:
    var $offset_0;
    var $63 = ($op | 0) != 0;
    if ($63) {
      __label__ = 16;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 16:
    var $65 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($65 | 0) == 29) {
      __label__ = 17;
      break;
    } else if (($65 | 0) == 22) {
      __label__ = 29;
      break;
    } else if (($65 | 0) == 23 || ($65 | 0) == 27 || ($65 | 0) == 19) {
      __label__ = 34;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 17:
    var $67 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($67) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $69 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 131);
    if ($69) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $71 = _js_Emit1($cx, $cg, 131);
    if (($71 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 20:
    var $74 = __ZNK11JSParseNode5getOpEv($lhs);
    var $75 = HEAP32[$atomIndex >> 2];
    var $76 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $74, $75, $cg, 0);
    if ($76) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 21:
    var $78 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 111);
    if ($78) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $80 = _js_Emit1($cx, $cg, 12);
    if (($80 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $83 = HEAP32[$atomIndex >> 2];
    var $84 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 198, $83, $cg, 0);
    if ($84) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 24:
    var $86 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 157);
    if ($86) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $90 = HEAP32[$lhs + 32 >> 2];
    var $91 = __ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom($cg, $lhs, $90);
    if ($91) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 26:
    var $93 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $lhs, 156, $cg, 0);
    __label__ = 36;
    break;
   case 27:
    var $95 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 85);
    var $96 = $95 ? 84 : 86;
    var $97 = HEAPU32[$atomIndex >> 2];
    var $99 = $97 >>> 8 & 255;
    var $100 = $97 & 255;
    var $101 = _js_Emit3($cx, $cg, $96, $99, $100);
    if (($101 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $104 = __ZNK11JSParseNode4isOpE4JSOp($lhs, 85);
    var $105 = $104 ? 84 : 86;
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $105);
    __label__ = 36;
    break;
   case 29:
    var $107 = _js_Emit1($cx, $cg, 12);
    if (($107 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $112 = HEAPU32[$lhs + 32 >> 2];
    var $114 = HEAP32[$cx + 52 >> 2];
    if (($112 | 0) == (HEAP32[$114 + 210292 >> 2] | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 31:
    var $120 = HEAP32[$atomIndex >> 2];
    var $121 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $120, $cg, 0);
    if ($121) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 32:
    var $123 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($123) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 33:
    var $129 = ($112 | 0) == (HEAP32[$114 + 210256 >> 2] | 0) ? 220 : 53;
    var $130 = HEAP32[$atomIndex >> 2];
    var $131 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $129, $130, $cg, 0);
    if ($131) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 34:
    var $133 = _js_Emit1($cx, $cg, 13);
    if (($133 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $136 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($136) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 36:
    var $138 = ($rhs | 0) != 0;
    if ($138) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $140 = _js_EmitTree($cx, $cg, $rhs);
    if (($140 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $143 = _js_Emit2($cx, $cg, 77, $offset_0);
    if (($143 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if ($63) {
      __label__ = 40;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 40:
    var $147 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($147) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $149 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($149) {
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $151 = _js_NewSrcNote($cx, $cg, 8);
    if (($151 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $154 = _js_Emit1($cx, $cg, $op);
    if (($154 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $157 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($157) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $159 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 24);
    if ($159) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $161 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 26);
    if ($161) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $163 = HEAP32[$1 >> 2];
    var $172 = $8 - $7 + HEAP32[$163 + 8 >> 2] - HEAP32[$163 >> 2] | 0;
    var $173 = _js_NewSrcNote2($cx, $cg, 12, $172);
    if (($173 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $176 = __ZNK11JSParseNode7getKindEv($lhs);
    if (($176 | 0) == 29) {
      __label__ = 49;
      break;
    } else if (($176 | 0) == 22) {
      __label__ = 52;
      break;
    } else if (($176 | 0) == 23 || ($176 | 0) == 27) {
      __label__ = 53;
      break;
    } else if (($176 | 0) == 24 || ($176 | 0) == 26) {
      __label__ = 54;
      break;
    } else if (($176 | 0) == 19) {
      __label__ = 55;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 49:
    var $178 = __ZNK11JSParseNode7isConstEv($lhs);
    if ($178) {
      __label__ = 50;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 50:
    if ($138) {
      __label__ = 56;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $183 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $184 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $183, $lhs, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 57;
    break;
   case 52:
    var $185 = __ZNK11JSParseNode5getOpEv($lhs);
    var $186 = HEAP32[$atomIndex >> 2];
    var $187 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $185, $186, $cg, 0);
    if ($187) {
      __label__ = 56;
      break;
    } else {
      var $_0 = 0;
      __label__ = 57;
      break;
    }
   case 53:
    var $189 = _js_Emit1($cx, $cg, 56);
    if (($189 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 54:
    var $192 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, 111, $lhs);
    if (($192 | 0) == 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 55:
    var $195 = _js_Emit1($cx, $cg, 173);
    if (($195 | 0) < 0) {
      var $_0 = 0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $_0 = 1;
    __label__ = 57;
    break;
   case 57:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_["X"] = 1;

function __ZNK11JSParseNode4isOpE4JSOp($this, $op) {
  var $1 = __ZNK11JSParseNode5getOpEv($this);
  return ($1 | 0) == ($op | 0);
}

function __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $prologOp, $pn_0_7_0_0_val, $pn_0_7_0_1_val, $pop) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pn_0_7_0_1_val;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0_7_0_0_val, 24);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 24);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$pn_0_7_0_1_val + 44 >> 2] & 1024 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    if (HEAPU32[$pn_0_7_0_0_val + 40 >> 2] >>> 0 > HEAPU32[$pn_0_7_0_1_val + 40 >> 2] >>> 0) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_($cx, $cg, $prologOp, $pn_0_7_0_0_val, $1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$pop >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj($cx, $cg, $kind, $stackDepth, $start, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 88 >> 2];
    var $4 = HEAP32[$cx + 96 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if ($9 >>> 0 > (HEAP32[$2 + 8 >> 2] - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $15 = $cx + 72 | 0;
    var $16 = _JS_ArenaAllocate($15, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $21 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP8[$21 | 0] = $kind & 255;
    HEAP16[$21 + 2 >> 1] = $stackDepth & 65535;
    HEAP32[$21 + 4 >> 2] = $start;
    HEAP32[$21 + 8 >> 2] = $end - $start | 0;
    var $32 = $cg + 204 | 0;
    var $33 = HEAP32[$32 >> 2];
    HEAP32[$21 + 12 >> 2] = $33;
    HEAP32[$32 >> 2] = $21;
    var $35 = $cg + 200 | 0;
    var $37 = HEAP32[$35 >> 2] + 1 | 0;
    HEAP32[$35 >> 2] = $37;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj["X"] = 1;

function __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $lastp) {
  var $2 = HEAP32[$cg + 172 >> 2];
  var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
  var $11 = $9 - HEAP32[$lastp >> 2] | 0;
  HEAP32[$lastp >> 2] = $9;
  var $12 = __ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi($cx, $cg, 151, $11);
  return $12;
}

function __ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox($cx, $cg, $box) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($box | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$box + 16 >> 2];
    var $5 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 188, $4, $cg, 0);
    var $_0 = $5 & 1;
    __label__ = 4;
    break;
   case 3:
    var $8 = _js_Emit1($cx, $cg, 189);
    var $_0 = $8 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, $op, $box) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$box + 8 >> 2];
    var $4 = __ZNK8JSObject13propertyCountEv($3);
    var $5 = $box + 16 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $6);
    if (($7 | 0) == 66) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $4 & 65535;
    var $12 = HEAP32[$5 >> 2] & 65535;
    var $13 = _js_Emit5($cx, $cg, $op, $10, $12);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      var $21 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = _js_Emit1($cx, $cg, $7);
    var $21 = ($18 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $21;
    var $_0 = $21 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $line) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cg + 172 >> 2] + 28 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $line - $4 | 0;
    if (($4 | 0) == ($line | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$3 >> 2] = $line;
    if ($5 >>> 0 < ((($line >>> 0 > 127 & 1) << 1) + 2 | 0) >>> 0) {
      var $delta__0 = $5;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = _js_NewSrcNote2($cx, $cg, 23, $line);
    if (($14 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $delta__0;
    var $16 = _js_NewSrcNote($cx, $cg, 22);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $delta__0 - 1 | 0;
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $delta__0 = $19;
      __label__ = 4;
      break;
    }
   case 6:
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12OpToDeclType4JSOp($prologOp);
    var $2 = _js_NewSrcNote2($cx, $cg, 6, $1);
    if (($2 | 0) < 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode5setOpE4JSOp($this, $op) {
  var $1 = $this;
  var $6 = HEAP32[$1 >> 2] & -16711681 | $op << 16 & 16711680;
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZNK11JSParseNode25isDirectivePrologueMemberEv($this) {
  return (HEAP32[$this + 40 >> 2] | 0) != 0;
}

function __ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi($cx, $cg, $pn, $inLetHead, $headNoteIndex) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op = __stackBase__;
    var $atomIndex = __stackBase__ + 4;
    HEAP32[$headNoteIndex >> 2] = -1;
    var $2 = $pn + 44 | 0;
    var $5 = (HEAP32[$2 >> 2] & 8 | 0) == 0;
    var $6 = $pn + 32 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = ($inLetHead | 0) == 0;
    var $9 = $cg | 0;
    var $10 = $cg + 172 | 0;
    var $11 = $pn + 40 | 0;
    var $pn2_0 = $7;
    var $noteIndex_0 = -1;
    var $off_0 = -1;
    var $13 = $7;
    __label__ = 2;
    break;
   case 2:
    var $13;
    var $off_0;
    var $noteIndex_0;
    var $pn2_0;
    var $14 = ($pn2_0 | 0) == ($13 | 0);
    var $16 = HEAPU32[$pn2_0 + 24 >> 2];
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 29);
    if ($17) {
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 24);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 26);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZNK11JSParseNode5getOpEv($pn);
    var $24 = __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $23, $pn2_0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 6:
    var $27 = $pn2_0 + 32 | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($28, 29);
    if ($29) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $pn3_0 = HEAP32[$pn2_0 + 36 >> 2];
    var $pn2_1 = $28;
    __label__ = 21;
    break;
   case 8:
    if ((HEAP32[$11 >> 2] | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      var $52 = $28;
      __label__ = 15;
      break;
    }
   case 9:
    HEAP32[$op >> 2] = 81;
    if ($8) {
      __label__ = 10;
      break;
    } else {
      var $41 = 81;
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = __ZNK11JSParseNode5getOpEv($pn);
    var $41 = $39;
    __label__ = 11;
    break;
   case 11:
    var $41;
    var $pn2_0_idx1_val = HEAP32[$pn2_0 + 36 >> 2];
    var $42 = __ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_($cx, $cg, $41, $28, $pn2_0_idx1_val, $op);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$op >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = HEAP32[$27 >> 2];
    __label__ = 15;
    break;
   case 14:
    var $50 = HEAP32[$2 >> 2] & -69 | 64;
    HEAP32[$2 >> 2] = $50;
    __label__ = 50;
    break;
   case 15:
    var $52;
    var $53 = __ZNK11JSParseNode5getOpEv($pn);
    var $54 = __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $53, $52);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = HEAP32[$pn2_0 + 36 >> 2];
    var $60 = _js_EmitTree($cx, $cg, $59);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ($8) {
      __label__ = 18;
      break;
    } else {
      var $66 = 81;
      __label__ = 19;
      break;
    }
   case 18:
    var $64 = __ZNK11JSParseNode5getOpEv($pn);
    var $66 = $64;
    __label__ = 19;
    break;
   case 19:
    var $66;
    var $67 = __ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $66, $52);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 20:
    var $70 = __ZN11JSParseNode9maybeExprEv($pn2_0);
    var $pn3_0 = $70;
    var $pn2_1 = $pn2_0;
    __label__ = 21;
    break;
   case 21:
    var $pn2_1;
    var $pn3_0;
    var $72 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn2_1);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $75 = __ZNK11JSParseNode5getOpEv($pn2_1);
    HEAP32[$op >> 2] = $75;
    if (($75 | 0) == 9) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP32[$atomIndex >> 2] = 0;
    __label__ = 33;
    break;
   case 24:
    var $79 = __ZNK11JSParseNode5getOpEv($pn);
    var $80 = __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $79, $pn2_1, $atomIndex);
    if ($80) {
      __label__ = 25;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 25:
    if (($pn3_0 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $84 = HEAP32[$op >> 2];
    if (($84 | 0) == 111) {
      __label__ = 27;
      break;
    } else if (($84 | 0) == 157) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    var $86 = HEAP32[$atomIndex >> 2];
    var $87 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 110, $86, $cg, 0);
    if ($87) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 28:
    var $89 = HEAP32[$atomIndex >> 2];
    var $90 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 217, $89, $cg, 0);
    if ($90) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 29:
    var $92 = __ZNK11JSParseNode4isOpE4JSOp($pn, 128);
    if ($92) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $96 = HEAP32[$pn2_1 + 32 >> 2];
    var $97 = _js_DefineCompileTimeConstant(undef, $cg, $96, $pn3_0);
    if (($97 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = HEAP32[$9 >> 2];
    var $101 = $100 & -17;
    HEAP32[$9 >> 2] = $101;
    var $102 = _js_EmitTree($cx, $cg, $pn3_0);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $107 = HEAP32[$9 >> 2] | $100 & 16;
    HEAP32[$9 >> 2] = $107;
    __label__ = 33;
    break;
   case 33:
    if ($5) {
      __label__ = 34;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 34:
    if ($14 & $8) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $111 = __ZNK11JSParseNode4isOpE4JSOp($pn, 128);
    if ($111) {
      var $116 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $113 = __ZNK11JSParseNode4isOpE4JSOp($pn, 129);
    var $114 = $113 ? 0 : 2;
    var $116 = $114;
    __label__ = 37;
    break;
   case 37:
    var $116;
    var $117 = _js_NewSrcNote2($cx, $cg, 6, $116);
    if (($117 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $119 = HEAPU32[$op >> 2];
    if (($119 | 0) == 9) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $122 = _js_Emit1($cx, $cg, 9);
    if (($122 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 40:
    var $127 = __ZNK2js11UpvarCookie6isFreeEv($pn2_1 + 40 | 0);
    var $128 = HEAPU32[$atomIndex >> 2];
    if ($127) {
      __label__ = 43;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $131 = $128 >>> 8 & 255;
    var $132 = $128 & 255;
    var $133 = _js_Emit3($cx, $cg, $119, $131, $132);
    if (($133 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $119);
    __label__ = 44;
    break;
   case 43:
    var $137 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $119, $128, $cg, 0);
    if ($137) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 58;
      break;
    }
   case 44:
    var $139 = HEAP32[$10 >> 2];
    var $146 = HEAP32[$139 + 8 >> 2] - HEAP32[$139 >> 2] | 0;
    if (($noteIndex_0 | 0) > -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $149 = $146 - $off_0 | 0;
    var $150 = _js_SetSrcNoteOffset($cx, $cg, $noteIndex_0, 0, $149);
    if (($150 | 0) == 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if (($16 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $155 = _js_NewSrcNote2($cx, $cg, 7, 0);
    if (($155 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $158 = _js_Emit1($cx, $cg, 81);
    if (($158 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $pn2_0 = $16;
    var $noteIndex_0 = $155;
    var $off_0 = $146;
    var $13 = HEAP32[$6 >> 2];
    __label__ = 2;
    break;
   case 50:
    if ($8) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $170 = HEAP32[$2 >> 2];
    __label__ = 55;
    break;
   case 52:
    var $161 = _js_NewSrcNote($cx, $cg, 6);
    HEAP32[$headNoteIndex >> 2] = $161;
    if (($161 | 0) < 0) {
      var $_0 = 0;
      __label__ = 58;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $164 = HEAPU32[$2 >> 2];
    if (($164 & 4 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      var $170 = $164;
      __label__ = 55;
      break;
    }
   case 54:
    var $168 = _js_Emit1($cx, $cg, 0);
    var $_0 = $168 >>> 31 ^ 1;
    __label__ = 58;
    break;
   case 55:
    var $170;
    if (($170 & 4 | 0) == 0) {
      var $177 = 1;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $174 = _js_Emit1($cx, $cg, 81);
    var $177 = ($174 | 0) > -1;
    __label__ = 57;
    break;
   case 57:
    var $177;
    var $_0 = $177 & 1;
    __label__ = 58;
    break;
   case 58:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi["X"] = 1;

function __ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo($cx, $cg, $toStmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $npops = __stackBase__;
    var $1 = $cg + 192 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$npops >> 2] = 0;
    var $stmt_0_in = $cg + 24 | 0;
    __label__ = 2;
    break;
   case 2:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == ($toStmt | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU16[$stmt_0 >> 1] & 65535;
    if (($9 | 0) == 9) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($9 | 0) == 13) {
      __label__ = 12;
      break;
    } else if (($9 | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 4:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = _js_NewSrcNote($cx, $cg, 11);
    if (($17 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $stmt_0 + 12 | 0;
    var $21 = __ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi($cx, $cg, $20);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = _js_NewSrcNote($cx, $cg, 11);
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = _js_Emit1($cx, $cg, 4);
    if (($33 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $42 = _js_NewSrcNote($cx, $cg, 11);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = _js_Emit1($cx, $cg, 78);
    if (($45 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = HEAP32[$npops >> 2] + 2 | 0;
    HEAP32[$npops >> 2] = $49;
    __label__ = 17;
    break;
   case 17:
    if ((HEAP16[$stmt_0 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $59 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $62 = _js_NewSrcNote($cx, $cg, 11);
    if (($62 | 0) < 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $67 = HEAP32[$stmt_0 + 20 >> 2];
    var $68 = __ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox($cx, $cg, 202, $67);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 2;
    break;
   case 23:
    if ((HEAP32[$npops >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    HEAP32[$1 >> 2] = $2;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo["X"] = 1;

function __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $pn, $answer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    if (($pn_tr | 0) == 0) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$answer >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode8getArityEv($pn_tr);
    if (($7 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($7 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      __label__ = 14;
      break;
    } else if (($7 | 0) == 2) {
      __label__ = 18;
      break;
    } else if (($7 | 0) == 1) {
      __label__ = 35;
      break;
    } else if (($7 | 0) == 6) {
      __label__ = 44;
      break;
    } else if (($7 | 0) == 7) {
      __label__ = 57;
      break;
    } else if (($7 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 5:
    HEAP32[$answer >> 2] = 0;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 6:
    var $10 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $12 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 68);
    if ($12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $14 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 69);
    if ($14) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $16 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 72);
    if ($16) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $18 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 73);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $pn2_01 = HEAP32[$pn_tr + 32 >> 2];
    if (($pn2_01 | 0) == 0) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      var $ok_02 = 1;
      var $pn2_03 = $pn2_01;
      __label__ = 12;
      break;
    }
   case 12:
    var $pn2_03;
    var $ok_02;
    var $22 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $pn2_03, $answer);
    var $23 = $22 & $ok_02;
    var $pn2_0 = HEAP32[$pn2_03 + 24 >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = $23;
      __label__ = 60;
      break;
    } else {
      var $ok_02 = $23;
      var $pn2_03 = $pn2_0;
      __label__ = 12;
      break;
    }
   case 13:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 14:
    var $29 = HEAP32[$pn_tr + 32 >> 2];
    var $30 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $29, $answer);
    if (($30 | 0) == 0) {
      var $45 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $35 = HEAP32[$pn_tr + 36 >> 2];
    var $36 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $35, $answer);
    if (($36 | 0) == 0) {
      var $45 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = HEAP32[$pn_tr + 40 >> 2];
    var $42 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $41, $answer);
    var $45 = ($42 | 0) != 0;
    __label__ = 17;
    break;
   case 17:
    var $45;
    var $_0 = $45 & 1;
    __label__ = 60;
    break;
   case 18:
    var $48 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 4);
    if ($48) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    var $51 = HEAPU32[$pn_tr + 32 >> 2];
    var $52 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($51, 29);
    if ($52) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 21:
    var $55 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $51);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $60 = HEAP32[$pn_tr + 36 >> 2];
    var $61 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $60, $answer);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if ((HEAP32[$answer >> 2] | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 24:
    var $67 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($67) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $69 = __ZNK11JSParseNode7isConstEv($51);
    if ($69) {
      var $_0 = 1;
      __label__ = 60;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 27:
    var $72 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 68);
    if ($72) {
      __label__ = 31;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $74 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 69);
    if ($74) {
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $76 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 72);
    if ($76) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $78 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 73);
    if ($78) {
      __label__ = 31;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 31:
    var $81 = HEAP32[$pn_tr + 32 >> 2];
    var $82 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $81, $answer);
    if (($82 | 0) == 0) {
      var $91 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $87 = HEAP32[$pn_tr + 36 >> 2];
    var $88 = __ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi($cx, $cg, $87, $answer);
    var $91 = ($88 | 0) != 0;
    __label__ = 33;
    break;
   case 33:
    var $91;
    var $_0 = $91 & 1;
    __label__ = 60;
    break;
   case 34:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 35:
    var $95 = __ZNK11JSParseNode7getKindEv($pn_tr);
    if (($95 | 0) == 50) {
      __label__ = 36;
      break;
    } else if (($95 | 0) == 19) {
      __label__ = 41;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 36:
    var $98 = HEAPU32[$pn_tr + 32 >> 2];
    var $99 = __ZNK11JSParseNode7getKindEv($98);
    if (($99 | 0) == 29) {
      __label__ = 37;
      break;
    } else if (($99 | 0) == 22 || ($99 | 0) == 73 || ($99 | 0) == 27 || ($99 | 0) == 23) {
      __label__ = 40;
      break;
    } else {
      var $pn_tr = $98;
      __label__ = 2;
      break;
    }
   case 37:
    var $101 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $98);
    if (($101 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $104 = __ZNK11JSParseNode7isConstEv($98);
    if ($104) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[$answer >> 2] = 0;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 40:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 41:
    var $107 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 32);
    if ($107) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $pn_tr = HEAP32[$pn_tr + 32 >> 2];
    __label__ = 2;
    break;
   case 43:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 44:
    var $113 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 29);
    if ($113) {
      __label__ = 45;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 45:
    var $115 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($115) {
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $117 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn_tr);
    if (($117 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $120 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 9);
    if ($120) {
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $122 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 131);
    if ($122) {
      __label__ = 51;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $126 = __ZNK2js11UpvarCookie6isFreeEv($pn_tr + 40 | 0);
    if ($126) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    HEAP32[$answer >> 2] = 1;
    __label__ = 51;
    break;
   case 51:
    var $129 = __ZN11JSParseNode9maybeExprEv($pn_tr);
    var $130 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 22);
    if ($130) {
      __label__ = 52;
      break;
    } else {
      var $pn_tr = $129;
      __label__ = 2;
      break;
    }
   case 52:
    var $132 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($129, 29);
    if ($132) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $134 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $129);
    if (($134 | 0) == 0) {
      var $_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $137 = __ZNK11JSParseNode4isOpE4JSOp($129, 9);
    if ($137) {
      __label__ = 55;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 55:
    if ((HEAP32[$pn_tr + 32 >> 2] | 0) == (HEAP32[HEAP32[$1 >> 2] + 210256 >> 2] | 0)) {
      var $pn_tr = $129;
      __label__ = 2;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    HEAP32[$answer >> 2] = 1;
    var $pn_tr = $129;
    __label__ = 2;
    break;
   case 57:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 58:
    var $153 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 58);
    if ($153) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 1;
      __label__ = 60;
      break;
    }
   case 59:
    HEAP32[$answer >> 2] = 1;
    var $_0 = 1;
    __label__ = 60;
    break;
   case 60:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi["X"] = 1;

function __ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi($cx, $cg, $pc, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = (HEAP32[$cg + 208 >> 2] | 0) == 0;
    if ($3 & ($delta | 0) < 32767) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$pc + 1 | 0] = $delta >>> 8 & 255;
    HEAP8[$pc + 2 | 0] = $delta & 255;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    if (($delta | 0) > 1073741823) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    HEAP32[$19 + 12 >> 2] = $delta << 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetJumpOffsetP15JSCodeGeneratorPh($cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$cg + 208 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) << 16 >> 16;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZL10GetSpanDepP15JSCodeGeneratorPh($cg, $pc);
    var $18 = HEAP32[$15 + 12 >> 2];
    if (($18 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $18 >> 1;
    __label__ = 9;
    break;
   case 5:
    var $25 = HEAP32[$15 >> 2];
    var $sd_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $sd_0;
    var $27 = $sd_0 - 16 | 0;
    if ($27 >>> 0 < $2 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$27 >> 2] | 0) == ($25 | 0)) {
      var $sd_0 = $27;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = HEAP32[($18 & -2) >> 2] - HEAP32[$sd_0 + 4 >> 2] | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op, $cg, $psuffix) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $4 = HEAP32[$pn + 32 >> 2];
    if (($op | 0) == 53) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $op;
      var $13 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    if (($4 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_01 = 53;
      var $13 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $_01 = 220;
    var $13 = $4;
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $_01;
    var $14 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $13, $index);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $_01, $16, $cg, $psuffix);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn_0_7_0_0_val, $op, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 & -17;
    HEAP32[$1 >> 2] = $3;
    var $4 = _js_EmitTree($cx, $cg, $pn_0_7_0_0_val);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$1 >> 2] | $2 & 16;
    HEAP32[$1 >> 2] = $9;
    var $11 = HEAP32[$cg + 172 >> 2];
    var $21 = HEAP32[$11 + 8 >> 2] - HEAP32[$pn_0_7_0_0_val + 20 >> 2] - HEAP32[$11 >> 2] | 0;
    var $22 = _js_NewSrcNote2($cx, $cg, 12, $21);
    if (($22 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $25 = _js_Emit1($cx, $cg, $op);
    var $_0 = $25 >>> 31 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $suffix = __stackBase__;
    HEAP32[$suffix >> 2] = 0;
    var $1 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op, $cg, $suffix);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 2:
    var $3 = _js_Emit1($cx, $cg, 0);
    if (($3 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $cg + 192 | 0;
    var $8 = HEAP32[$6 >> 2] - 1 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $cg + 172 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $17 = HEAP32[$10 + 8 >> 2] - HEAP32[$10 >> 2] | 0;
    var $18 = HEAP32[$suffix >> 2];
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = _js_Emit1($cx, $cg, $18);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $27 = ($25 & 33554432 | 0) != 0;
    var $29 = ($25 & 4096 | 0) != 0;
    var $33 = ($25 >>> 11 & 1 ^ 1) + 27 | 0;
    var $34 = $27 ? 217 : 110;
    var $35 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $34, $cg, 0);
    if ($35) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 6:
    var $37 = $27 ? 156 : 59;
    var $38 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $37, $cg, 0);
    if ($38) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $40 = _js_Emit1($cx, $cg, 35);
    if (($40 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $44 = _js_Emit1($cx, $cg, 12);
    if (($44 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = _js_Emit1($cx, $cg, 63);
    if (($47 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $50 = _js_Emit1($cx, $cg, $33);
    if (($50 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($29) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $54 = _js_Emit2($cx, $cg, 133, 2);
    if (($54 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = _js_Emit1($cx, $cg, 10);
    if (($57 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $60 = $27 ? 157 : 111;
    var $61 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $60, $cg, 0);
    if ($61) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 16:
    if ($29) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $64 = _js_Emit1($cx, $cg, 81);
    if (($64 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $cg_idx_val = HEAP32[$9 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $17);
    var $67 = HEAP32[$suffix >> 2];
    if (($67 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $70 = _js_Emit1($cx, $cg, $67);
    if (($70 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZNK11JSParseNode7isConstEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 2);
  return $1;
}

function __ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $suffix = __stackBase__;
    HEAP32[$suffix >> 2] = 0;
    var $1 = __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $op, $cg, 0, $suffix);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _js_Emit1($cx, $cg, 0);
    if (($4 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $cg + 172 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $15 = HEAP32[$8 + 8 >> 2] - HEAP32[$8 >> 2] | 0;
    var $16 = HEAP32[$suffix >> 2];
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = _js_Emit1($cx, $cg, $16);
    if (($19 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $25 = ($23 & 4096 | 0) != 0;
    var $29 = ($23 >>> 11 & 1 ^ 1) + 27 | 0;
    var $30 = _js_Emit1($cx, $cg, 12);
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 53, $cg, 0);
    if ($33) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $35 = _js_Emit1($cx, $cg, 35);
    if (($35 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = _js_Emit1($cx, $cg, 12);
    if (($39 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $42 = _js_Emit1($cx, $cg, 63);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = _js_Emit1($cx, $cg, $29);
    if (($45 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($25) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $49 = _js_Emit2($cx, $cg, 133, 2);
    if (($49 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = _js_Emit1($cx, $cg, 10);
    if (($52 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, 54, $cg, 0);
    if ($55) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 16:
    if ($25) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $58 = _js_Emit1($cx, $cg, 81);
    if (($58 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $cg_idx_val = HEAP32[$7 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $15);
    var $61 = HEAP32[$suffix >> 2];
    if (($61 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = _js_Emit1($cx, $cg, $61);
    if (($64 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 4:
    var $8 = _js_Emit1($cx, $cg, 0);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cg + 192 | 0;
    var $13 = HEAP32[$11 >> 2] + 1 | 0;
    HEAP32[$11 >> 2] = $13;
    var $14 = $cg + 172 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $22 = HEAP32[$15 + 8 >> 2] - HEAP32[$15 >> 2] | 0;
    var $24 = HEAPU32[_js_CodeSpec + ($op << 3) + 4 >> 2];
    var $26 = ($24 & 4096 | 0) != 0;
    var $30 = ($24 >>> 11 & 1 ^ 1) + 27 | 0;
    var $31 = _js_Emit1($cx, $cg, 231);
    if (($31 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = _js_Emit1($cx, $cg, 13);
    if (($34 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($37) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 8:
    var $39 = _js_Emit1($cx, $cg, 35);
    if (($39 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($26) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = _js_Emit1($cx, $cg, 12);
    if (($43 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $46 = _js_Emit1($cx, $cg, 63);
    if (($46 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = _js_Emit1($cx, $cg, $30);
    if (($49 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($26) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $53 = _js_Emit2($cx, $cg, 133, 3);
    if (($53 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $56 = _js_Emit2($cx, $cg, 133, 3);
    if (($56 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = _js_Emit2($cx, $cg, 133, 2);
    if (($59 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $62 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 56);
    if ($62) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    if ($26) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $65 = _js_Emit1($cx, $cg, 81);
    if (($65 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $cg_idx_val = HEAP32[$14 >> 2];
    var $cg_idx_val_idx_val = HEAP32[$cg_idx_val >> 2];
    var $cg_idx_val_idx1_val = HEAP32[$cg_idx_val + 8 >> 2];
    __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_idx_val_idx_val, $cg_idx_val_idx1_val, $22);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_($cx, $pn, $op, $cg, $callContext, $psuffix) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSParseNode9maybeExprEv($pn);
    if (($op | 0) == 187 || ($op | 0) == 53) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ((HEAP32[$pn + 32 >> 2] | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = _js_EmitTree($cx, $cg, $1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = ($callContext | 0) != 0 ? 196 : 55;
    var $20 = __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $19, $cg);
    var $_0 = $20 & 1;
    __label__ = 29;
    break;
   case 6:
    var $_not = ($callContext | 0) != 0;
    var $_mux = $_not ? 187 : $op;
    if ($_not | ($op | 0) != 53) {
      var $_02 = $_mux;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 22);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 8:
    var $26 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 29);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 9:
    var $28 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $1);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($31) {
      var $_02 = $op;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$pn + 32 >> 2] | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 12:
    var $43 = __ZNK11JSParseNode4isOpE4JSOp($1, 9);
    if ($43) {
      __label__ = 13;
      break;
    } else {
      var $_02 = $op;
      __label__ = 14;
      break;
    }
   case 13:
    var $45 = _js_Emit1($cx, $cg, 139);
    var $_0 = $45 >>> 31 ^ 1;
    __label__ = 29;
    break;
   case 14:
    var $_02;
    var $47 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($1, 22);
    if ($47) {
      __label__ = 15;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 15:
    var $49 = $cg + 172 | 0;
    var $50 = HEAP32[$49 >> 2];
    var $57 = HEAP32[$50 + 8 >> 2] - HEAP32[$50 >> 2] | 0;
    var $pnup_0 = 0;
    var $pndot_0 = $1;
    __label__ = 16;
    break;
   case 16:
    var $pndot_0;
    var $pnup_0;
    HEAP32[$pndot_0 + 20 >> 2] = $57;
    var $60 = $pndot_0 + 36 | 0;
    var $62 = HEAP32[$60 >> 2];
    HEAP32[$60 >> 2] = $pnup_0;
    var $63 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($62, 22);
    if ($63) {
      var $pnup_0 = $pndot_0;
      var $pndot_0 = $62;
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = _js_EmitTree($cx, $cg, $62);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = $cx + 52 | 0;
    var $pndown_0 = $62;
    var $pndot_1 = $pndot_0;
    __label__ = 19;
    break;
   case 19:
    var $pndot_1;
    var $pndown_0;
    var $69 = HEAP32[$49 >> 2];
    var $79 = HEAP32[$69 + 8 >> 2] - HEAP32[$pndown_0 + 20 >> 2] - HEAP32[$69 >> 2] | 0;
    var $80 = _js_NewSrcNote2($cx, $cg, 12, $79);
    if (($80 | 0) < 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $83 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pndot_1, 6);
    if ($83) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    if ((HEAP32[$pndot_1 + 32 >> 2] | 0) == (HEAP32[HEAP32[$67 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $94 = __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pndot_1, 55, $cg);
    if ($94) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 23:
    var $96 = __ZNK11JSParseNode5getOpEv($pndot_1);
    var $97 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pndot_1, $96, $cg, 0);
    if ($97) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $99 = $pndot_1 + 36 | 0;
    var $100 = HEAP32[$99 >> 2];
    var $101 = $100;
    HEAP32[$99 >> 2] = $pndown_0;
    if (($100 | 0) == 0) {
      var $_pre_phi = $49;
      __label__ = 27;
      break;
    } else {
      var $pndown_0 = $pndot_1;
      var $pndot_1 = $101;
      __label__ = 19;
      break;
    }
   case 25:
    var $104 = _js_EmitTree($cx, $cg, $1);
    if (($104 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $_pre_phi = $cg + 172 | 0;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi;
    var $106 = HEAP32[$_pre_phi >> 2];
    var $116 = HEAP32[$106 + 8 >> 2] - HEAP32[$1 + 20 >> 2] - HEAP32[$106 >> 2] | 0;
    var $117 = _js_NewSrcNote2($cx, $cg, 12, $116);
    if (($117 | 0) < 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $120 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $_02, $cg, $psuffix);
    var $_0 = $120 & 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_["X"] = 1;

function __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ltmp = __stackBase__;
    var $rtmp = __stackBase__ + 48;
    var $slot = __stackBase__ + 96;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
    var $10 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    var $12 = $pn + 32 | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $14 = __ZNK11JSParseNode4lastEv($pn);
    var $16 = HEAPU32[$13 + 24 >> 2];
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($13, 29);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 3:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($16, 30);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 4:
    var $21 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $13);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZNK11JSParseNode4isOpE4JSOp($13, 9);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 6:
    var $27 = $16 + 32 | 0;
    var $28 = (tempDoubleI32[0] = HEAP32[$27 >> 2], tempDoubleI32[1] = HEAP32[$27 + 4 >> 2], tempDoubleF64[0]);
    var $29 = _JSDOUBLE_IS_INT321163($28, $slot);
    var $31 = HEAPU32[$slot >> 2];
    if (($29 | 0) != 0 & $31 >>> 0 < 65536) {
      __label__ = 7;
      break;
    } else {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    }
   case 7:
    var $34 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($34) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $cg | 0;
    var $37 = __ZNK13JSTreeContext12inStrictModeEv($36);
    if ($37) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $39 = __ZNK13JSTreeContext16mutatesParameterEv($36);
    if ($39) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = __ZNK13JSTreeContext9callsEvalEv($36);
    if ($41) {
      var $next_0 = $16;
      var $left_0 = $13;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$16 + 20 >> 2] = $9;
    HEAP32[$13 + 20 >> 2] = $9;
    var $46 = $31 >>> 8 & 255;
    var $47 = $31 & 255;
    var $48 = _js_Emit3($cx, $cg, 138, $46, $47);
    if (($48 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 138);
    var $next_0 = HEAP32[$16 + 24 >> 2];
    var $left_0 = $16;
    __label__ = 13;
    break;
   case 13:
    var $left_0;
    var $next_0;
    if (($left_0 | 0) == (HEAP32[$12 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 15;
      break;
    }
   case 14:
    var $56 = _js_EmitTree($cx, $cg, $left_0);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 15;
      break;
    }
   case 15:
    var $next_1;
    if (($next_1 | 0) == ($14 | 0)) {
      var $right_1 = $14;
      __label__ = 39;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $60 = _js_EmitTree($cx, $cg, $next_1);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = HEAP32[$1 >> 2];
    var $71 = HEAP32[$63 + 8 >> 2] - $9 - HEAP32[$63 >> 2] | 0;
    var $72 = _js_NewSrcNote2($cx, $cg, 12, $71);
    if (($72 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $75 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($75) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 42;
      break;
    }
   case 19:
    var $next_1 = HEAP32[$next_1 + 24 >> 2];
    __label__ = 15;
    break;
   case 20:
    var $80 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($80) {
      __label__ = 21;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 21:
    var $82 = __ZN11JSParseNode9maybeExprEv($pn);
    if (($82 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $left_1 = $82;
    var $_pre_phi7 = $pn + 32 | 0;
    var $_pre_phi11 = $pn + 4 | 0;
    __label__ = 24;
    break;
   case 23:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($ltmp, 31);
    __ZN11JSParseNode5setOpE4JSOp($ltmp, 110);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($ltmp, 0);
    var $87 = $ltmp + 4 | 0;
    var $88 = $pn + 4 | 0;
    HEAP32[$87 >> 2] = HEAP32[$88 >> 2];
    HEAP32[$87 + 4 >> 2] = HEAP32[$88 + 4 >> 2];
    HEAP32[$87 + 8 >> 2] = HEAP32[$88 + 8 >> 2];
    HEAP32[$87 + 12 >> 2] = HEAP32[$88 + 12 >> 2];
    var $90 = $pn + 32 | 0;
    var $_c = HEAP32[$90 >> 2];
    HEAP32[$ltmp + 32 >> 2] = $_c;
    var $left_1 = $ltmp;
    var $_pre_phi7 = $90;
    var $_pre_phi11 = $88;
    __label__ = 24;
    break;
   case 24:
    var $_pre_phi11;
    var $_pre_phi7;
    var $left_1;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($rtmp, 31);
    var $95 = HEAP32[$_pre_phi7 >> 2] | 0;
    var $96 = __Z15js_IsIdentifierP14JSLinearString($95);
    var $98 = ($96 | 0) != 0 ? 165 : 61;
    __ZN11JSParseNode5setOpE4JSOp($rtmp, $98);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($rtmp, 0);
    var $100 = $rtmp + 4 | 0;
    HEAP32[$100 >> 2] = HEAP32[$_pre_phi11 >> 2];
    HEAP32[$100 + 4 >> 2] = HEAP32[$_pre_phi11 + 4 >> 2];
    HEAP32[$100 + 8 >> 2] = HEAP32[$_pre_phi11 + 8 >> 2];
    HEAP32[$100 + 12 >> 2] = HEAP32[$_pre_phi11 + 12 >> 2];
    var $_c4 = HEAP32[$_pre_phi7 >> 2];
    HEAP32[$rtmp + 32 >> 2] = $_c4;
    var $right_0 = $rtmp;
    var $left_2 = $left_1;
    __label__ = 26;
    break;
   case 25:
    var $right_0 = HEAP32[$pn + 36 >> 2];
    var $left_2 = HEAP32[$pn + 32 >> 2];
    __label__ = 26;
    break;
   case 26:
    var $left_2;
    var $right_0;
    if (($op | 0) == 55) {
      __label__ = 27;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 27:
    var $112 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left_2, 29);
    if ($112) {
      __label__ = 28;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 28:
    var $114 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right_0, 30);
    if ($114) {
      __label__ = 29;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 29:
    var $116 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $left_2);
    if (($116 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $119 = __ZNK11JSParseNode4isOpE4JSOp($left_2, 9);
    if ($119) {
      __label__ = 31;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 31:
    var $122 = $right_0 + 32 | 0;
    var $123 = (tempDoubleI32[0] = HEAP32[$122 >> 2], tempDoubleI32[1] = HEAP32[$122 + 4 >> 2], tempDoubleF64[0]);
    var $124 = _JSDOUBLE_IS_INT321163($123, $slot);
    if (($124 | 0) != 0 & HEAPU32[$slot >> 2] >>> 0 < 65536) {
      __label__ = 32;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 32:
    var $129 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($129) {
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $131 = $cg | 0;
    var $132 = __ZNK13JSTreeContext12inStrictModeEv($131);
    if ($132) {
      __label__ = 34;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 34:
    var $134 = __ZNK13JSTreeContext16mutatesParameterEv($131);
    if ($134) {
      __label__ = 38;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $136 = __ZNK13JSTreeContext9callsEvalEv($131);
    if ($136) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    HEAP32[$right_0 + 20 >> 2] = $9;
    HEAP32[$left_2 + 20 >> 2] = $9;
    var $140 = HEAPU32[$slot >> 2];
    var $142 = $140 >>> 8 & 255;
    var $143 = $140 & 255;
    var $144 = _js_Emit3($cx, $cg, 138, $142, $143);
    if (($144 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 138);
    var $_0 = 1;
    __label__ = 42;
    break;
   case 38:
    var $148 = _js_EmitTree($cx, $cg, $left_2);
    if (($148 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      var $right_1 = $right_0;
      __label__ = 39;
      break;
    }
   case 39:
    var $right_1;
    var $150 = _js_EmitTree($cx, $cg, $right_1);
    if (($150 | 0) == 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $153 = HEAP32[$1 >> 2];
    var $161 = HEAP32[$153 + 8 >> 2] - $9 - HEAP32[$153 >> 2] | 0;
    var $162 = _js_NewSrcNote2($cx, $cg, 12, $161);
    if (($162 | 0) < 0) {
      var $_0 = 0;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $165 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    var $_0 = $165 & 1;
    __label__ = 42;
    break;
   case 42:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator["X"] = 1;

function __ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei($cx, $cg, $pn, $callContext) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode5getOpEv($pn);
    var $5 = ($callContext | 0) != 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    if (($4 | 0) == 156) {
      __label__ = 4;
      break;
    } else if (($4 | 0) == 84) {
      __label__ = 5;
      break;
    } else if (($4 | 0) == 86) {
      __label__ = 6;
      break;
    } else if (($4 | 0) == 136) {
      __label__ = 7;
      break;
    } else if (($4 | 0) == 59) {
      var $op_02 = 57;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $op_02 = 214;
    __label__ = 12;
    break;
   case 5:
    var $op_02 = 216;
    __label__ = 12;
    break;
   case 6:
    var $op_02 = 215;
    __label__ = 12;
    break;
   case 7:
    var $op_02 = 137;
    __label__ = 12;
    break;
   case 8:
    if (($4 | 0) == 131 || ($4 | 0) == 9) {
      __label__ = 9;
      break;
    } else {
      var $op_02 = $4;
      __label__ = 12;
      break;
    }
   case 9:
    var $13 = _js_Emit1($cx, $cg, $4);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($5) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $17 = _js_Emit1($cx, $cg, 1);
    if (($17 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $op_02;
    var $20 = $pn + 40 | 0;
    var $21 = __ZNK2js11UpvarCookie6isFreeEv($20);
    if ($21) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $23 = __ZNK2js11UpvarCookie9asIntegerEv($20);
    var $25 = $23 >>> 8 & 255;
    var $26 = $23 & 255;
    var $27 = _js_Emit3($cx, $cg, $op_02, $25, $26);
    if (($27 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op_02);
    __label__ = 16;
    break;
   case 15:
    var $31 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $pn, $op_02, $cg, 0);
    if ($31) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19FitsWithoutBigIndexj($index) {
  return $index >>> 0 < 65536;
}

function __ZNK15JSCodeGenerator9hasSharpsEv($this) {
  return (HEAP32[$this >> 2] & 32768 | 0) != 0;
}

function __ZNK13JSTreeContext12compileAndGoEv($this) {
  return (HEAP32[$this >> 2] & 8192 | 0) != 0;
}

function __ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator($cx, $pn, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = $pn + 32 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $4, 201, $cg);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[HEAP32[$3 >> 2] + 8 >> 2];
    var $11 = __ZNK8JSObject12getFixedSlotEj($10, 0);
    var $12 = __ZNK2JS5Value7toInt32Ev($11);
    var $13 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $12);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = HEAPU32[__ZN2js10BlockClassE + 4 >> 2] >>> 8 & 255;
    var $19 = $10;
    var $20 = __ZNK8JSObject13propertyCountEv($19);
    if ($18 >>> 0 < ($18 + $20 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $23 = $20 + $18 | 0;
    var $slot_01 = $18;
    __label__ = 5;
    break;
   case 5:
    var $slot_01;
    var $25 = __ZNK8JSObject7getSlotEj($10, $slot_01);
    var $26 = __ZNK2JS5Value11isUndefinedEv($25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = __ZNK2JS5Value9toPrivateEv($25);
    var $29 = $28;
    var $31 = $28 + 40 | 0;
    var $32 = __ZNK2js11UpvarCookie5levelEv($31);
    var $33 = __ZNK11JSParseNode9frameSlotEv($29);
    var $35 = $33 + $13 & 65535;
    __ZN2js11UpvarCookie3setEtt($31, $32, $35);
    var $36 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $29);
    __ZN2JSL12BooleanValueEb1168($1, $36);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($10, $slot_01, $1);
    __label__ = 7;
    break;
   case 7:
    var $38 = $slot_01 + 1 | 0;
    if (($38 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $slot_01 = $38;
      __label__ = 5;
      break;
    }
   case 8:
    if ((HEAP32[$cg >> 2] & 536870912 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $44 = $cg + 92 | 0;
    var $45 = __ZNK2js8Bindings17extensibleParentsEv($44);
    if ($45) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    __ZN8JSObject16setBlockOwnShapeEP9JSContext($10, $cx);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator["X"] = 1;

function __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = __ZNK13JSTreeContext10inFunctionEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $slot;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $cg + 92 | 0;
    var $5 = __ZNK2js8Bindings9countVarsEv($4);
    var $7 = ($5 & 65535) + $slot | 0;
    if ($7 >>> 0 > 65535) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $13 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $12, 0, 0, 199, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = -1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei($cx, $cg, $key, $pn, $sharpnum) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $key & 255;
    var $2 = _js_Emit3($cx, $cg, 89, $1, 0);
    if (($2 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 3:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAPU32[$cg + 104 >> 2];
    var $14 = $12 >>> 8 & 255;
    var $15 = $12 & 255;
    var $16 = _js_Emit3($cx, $cg, 230, $14, $15);
    if (($16 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 230);
    __label__ = 6;
    break;
   case 6:
    if (($sharpnum | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $22 = _js_EmitN($cx, $cg, 95, 4);
    if (($22 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    var $29 = $cg + 104 | 0;
    HEAP8[$22 + ($28 + 1) | 0] = HEAPU32[$29 >> 2] >>> 8 & 255;
    HEAP8[$22 + ($28 + 2) | 0] = HEAP32[$29 >> 2] & 255;
    HEAP8[$22 + ($28 + 3) | 0] = $sharpnum >>> 8 & 255;
    HEAP8[$22 + ($28 + 4) | 0] = $sharpnum & 255;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei["X"] = 1;

function __ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj($cx, $cg, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK15JSCodeGenerator9hasSharpsEv($cg);
    if (($count | 0) == 0 | $1 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$cg + 104 >> 2];
    var $7 = $5 >>> 8 & 255;
    var $8 = $5 & 255;
    var $9 = _js_Emit3($cx, $cg, 230, $7, $8);
    if (($9 | 0) < 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 230);
    __label__ = 4;
    break;
   case 4:
    var $13 = _js_Emit1($cx, $cg, 92);
    var $_0 = ($13 | 0) > -1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15JSCodeGenerator21checkSingletonContextEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK13JSTreeContext12compileAndGoEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = __ZNK13JSTreeContext10inFunctionEv($1);
    if ($4) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $stmt_0_in = $this + 24 | 0;
    __label__ = 4;
    break;
   case 4:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAPU16[$stmt_0 >> 1] & 65535) > 10) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 4;
    break;
   case 7:
    var $16 = $this | 0;
    var $18 = HEAP32[$16 >> 2] | 134217728;
    HEAP32[$16 >> 2] = $18;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $1 = $cg | 0;
    var $2 = __ZN13JSTreeContext16needStrictChecksEv($1);
    var $3 = __ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE($pn, $cx, $2, $value);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$cg + 48 >> 2];
    var $7 = __ZNK2JS5Value8toObjectEv($value);
    var $8 = $6;
    var $9 = __ZN2js6Parser12newObjectBoxEP8JSObject($8, $7);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $9, 80, $cg);
    var $_0 = ($12 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $dval, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ival = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = _JSDOUBLE_IS_INT321163($dval, $ival);
    if (($2 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$ival >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = _js_Emit1($cx, $cg, 62);
    var $_0 = $7 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 4:
    var $9 = _js_Emit1($cx, $cg, 63);
    var $_0 = $9 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 5:
    var $11 = $5 & 255;
    if (($11 << 24 >> 24 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = _js_Emit2($cx, $cg, 218, $11);
    var $_0 = $15 >>> 31 ^ 1;
    __label__ = 17;
    break;
   case 7:
    if ($5 >>> 0 < 65536) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = $5 >>> 8 & 255;
    var $21 = _js_Emit3($cx, $cg, 88, $20, $11);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 88);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 10:
    if ($5 >>> 0 < 16777216) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = _js_EmitN($cx, $cg, 190, 3);
    if (($27 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$27 + ($33 + 1) | 0] = $5 >>> 16 & 255;
    HEAP8[$27 + ($33 + 2) | 0] = $5 >>> 8 & 255;
    HEAP8[$27 + ($33 + 3) | 0] = $11;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 13:
    var $42 = _js_EmitN($cx, $cg, 219, 4);
    if (($42 | 0) < 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $48 = HEAPU32[HEAP32[$cg + 172 >> 2] >> 2];
    HEAP8[$42 + ($48 + 1) | 0] = $5 >>> 24 & 255;
    HEAP8[$42 + ($48 + 2) | 0] = $5 >>> 16 & 255;
    HEAP8[$42 + ($48 + 3) | 0] = $5 >>> 8 & 255;
    HEAP8[$42 + ($48 + 4) | 0] = $11;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 15:
    var $60 = $cg + 268 | 0;
    __ZN2JSL11DoubleValueEd1164($1, $dval);
    var $61 = __ZN13JSGCConstList6appendEN2JS5ValueE($60, $1);
    if ($61) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $63 = __ZNK13JSGCConstList6lengthEv($60);
    var $64 = $63 - 1 | 0;
    var $65 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 60, $64, $cg, 0);
    var $_0 = $65 & 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator["X"] = 1;

function __ZN2JSL14UndefinedValueEv1154($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZNK8JSObject16inDictionaryModeEv($this) {
  var $1 = __ZNK8JSObject12lastPropertyEv($this);
  var $2 = __ZNK2js5Shape12inDictionaryEv($1);
  return $2;
}

function __ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator($cx, $objbox, $op, $cg) {
  var $1 = $cg + 292 | 0;
  var $2 = __ZN14JSCGObjectList5indexEP11JSObjectBox($1, $objbox);
  var $3 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $op, $2, $cg, 0);
  return $3 & 1;
}

function _js_SrcNoteLength($sn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$sn];
    if (($1 & 255) > 191) {
      var $7 = 24;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 & 255) >>> 3;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $9 = HEAPU8[_js_SrcNoteSpec + ($7 << 3) + 4 | 0];
    var $_01 = $sn + 1 | 0;
    if ($9 << 24 >> 24 == 0) {
      var $_0_lcssa = $_01;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $arity_02 = $9 << 24 >> 24;
    var $sn_pn3 = $sn;
    var $_04 = $_01;
    __label__ = 5;
    break;
   case 5:
    var $_04;
    var $sn_pn3;
    var $arity_02;
    var $_1 = HEAP8[$_04] << 24 >> 24 < 0 ? $sn_pn3 + 3 | 0 : $_04;
    var $16 = $arity_02 - 1 | 0;
    var $_0 = $_1 + 1 | 0;
    if (($16 | 0) == 0) {
      var $_0_lcssa = $_0;
      __label__ = 6;
      break;
    } else {
      var $arity_02 = $16;
      var $sn_pn3 = $_1;
      var $_04 = $_0;
      __label__ = 5;
      break;
    }
   case 6:
    var $_0_lcssa;
    return $_0_lcssa - $sn | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetSrcNoteOffset($sn, $which) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_014 = $sn + 1 | 0;
    var $3 = HEAPU8[$_014] & 255;
    var $5 = ($3 & 128 | 0) != 0;
    if (($which | 0) == 0) {
      var $sn_pn_lcssa = $sn;
      var $_lcssa = $3;
      var $_lcssa3 = $5;
      __label__ = 3;
      break;
    } else {
      var $_025 = $which;
      var $sn_pn6 = $sn;
      var $_017 = $_014;
      var $6 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $6;
    var $_017;
    var $sn_pn6;
    var $_025;
    var $_1 = $6 ? $sn_pn6 + 3 | 0 : $_017;
    var $8 = $_025 - 1 | 0;
    var $_01 = $_1 + 1 | 0;
    var $11 = HEAPU8[$_01] & 255;
    var $13 = ($11 & 128 | 0) != 0;
    if (($8 | 0) == 0) {
      var $sn_pn_lcssa = $_1;
      var $_lcssa = $11;
      var $_lcssa3 = $13;
      __label__ = 3;
      break;
    } else {
      var $_025 = $8;
      var $sn_pn6 = $_1;
      var $_017 = $_01;
      var $6 = $13;
      __label__ = 2;
      break;
    }
   case 3:
    var $_lcssa3;
    var $_lcssa;
    var $sn_pn_lcssa;
    if ($_lcssa3) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $_lcssa;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAPU8[$sn_pn_lcssa + 3 | 0] & 255 | $_lcssa << 16 & 8323072 | (HEAPU8[$sn_pn_lcssa + 2 | 0] & 255) << 8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $5 = $cg + 208 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $7 = $cg + 220 | 0;
    var $9 = $6 + (HEAP32[$7 >> 2] << 4) | 0;
    var $14 = HEAP32[$2 + 8 >> 2] - $4 | 0;
    var $15 = $cg + 212 | 0;
    var $growth_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $growth_0;
    var $pc_0 = 0;
    var $sd_0 = $6;
    var $sdtop_0 = 0;
    var $delta_0 = 0;
    var $top_0 = -1;
    var $pivot_0 = -1;
    var $done_0 = 1;
    var $op_0 = 0;
    var $type_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $type_0;
    var $op_0;
    var $done_0;
    var $pivot_0;
    var $top_0;
    var $delta_0;
    var $sdtop_0;
    var $sd_0;
    var $pc_0;
    if ($sd_0 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 4:
    var $20 = $sd_0 + 4 | 0;
    var $22 = HEAP32[$20 >> 2] + $delta_0 | 0;
    HEAP32[$20 >> 2] = $22;
    var $24 = HEAPU32[$sd_0 >> 2];
    if (($24 | 0) == ($top_0 | 0)) {
      var $pc_1 = $pc_0;
      var $sdtop_1 = $sdtop_0;
      var $top_1 = $top_0;
      var $pivot_1 = $pivot_0;
      var $op_1 = $op_0;
      var $type_1 = $type_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = $4 + $24 | 0;
    var $29 = HEAPU8[$27] & 255;
    var $32 = HEAP32[_js_CodeSpec + ($29 << 3) + 4 >> 2] & 31;
    if (($32 - 9 | 0) >>> 0 < 3) {
      var $pc_2 = $27;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sd_0;
      var $delta_2 = $delta_0;
      var $top_2 = $24;
      var $pivot_2 = $22;
      var $done_1 = $done_0;
      var $op_3 = $29;
      var $type_2 = $32;
      __label__ = 28;
      break;
    } else {
      var $pc_1 = $27;
      var $sdtop_1 = $sd_0;
      var $top_1 = $24;
      var $pivot_1 = $22;
      var $op_1 = $29;
      var $type_1 = $32;
      __label__ = 6;
      break;
    }
   case 6:
    var $type_1;
    var $op_1;
    var $pivot_1;
    var $top_1;
    var $sdtop_1;
    var $pc_1;
    if (($type_1 - 9 | 0) >>> 0 < 3) {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $42 = HEAP32[$sd_0 + 12 >> 2] & -2;
    if (($42 | 0) == 0) {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((32768 - $pivot_1 + HEAP32[$42 >> 2] | 0) >>> 0 > 65535) {
      __label__ = 9;
      break;
    } else {
      var $pc_2 = $pc_1;
      var $sd_1 = $sd_0;
      var $sdtop_2 = $sdtop_1;
      var $delta_2 = $delta_0;
      var $top_2 = $top_1;
      var $pivot_2 = $pivot_1;
      var $done_1 = $done_0;
      var $op_3 = $op_1;
      var $type_2 = $type_1;
      __label__ = 28;
      break;
    }
   case 9:
    if (($op_1 | 0) == 7) {
      __label__ = 10;
      break;
    } else if (($op_1 | 0) == 8) {
      __label__ = 11;
      break;
    } else if (($op_1 | 0) == 68) {
      __label__ = 12;
      break;
    } else if (($op_1 | 0) == 69) {
      __label__ = 13;
      break;
    } else if (($op_1 | 0) == 116) {
      __label__ = 14;
      break;
    } else if (($op_1 | 0) == 121) {
      __label__ = 15;
      break;
    } else if (($op_1 | 0) == 122) {
      __label__ = 16;
      break;
    } else if (($op_1 | 0) == 70) {
      __label__ = 17;
      break;
    } else if (($op_1 | 0) == 71) {
      __label__ = 18;
      break;
    } else if (($op_1 | 0) == 6) {
      var $op_2 = 141;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 10:
    var $op_2 = 142;
    __label__ = 20;
    break;
   case 11:
    var $op_2 = 143;
    __label__ = 20;
    break;
   case 12:
    var $op_2 = 144;
    __label__ = 20;
    break;
   case 13:
    var $op_2 = 145;
    __label__ = 20;
    break;
   case 14:
    var $op_2 = 146;
    __label__ = 20;
    break;
   case 15:
    var $op_2 = 147;
    __label__ = 20;
    break;
   case 16:
    var $op_2 = 148;
    __label__ = 20;
    break;
   case 17:
    var $op_2 = 149;
    __label__ = 20;
    break;
   case 18:
    var $op_2 = 150;
    __label__ = 20;
    break;
   case 19:
    var $cg_idx6_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx6_val);
    var $_0 = 0;
    __label__ = 82;
    break;
   case 20:
    var $op_2;
    HEAP8[$pc_1] = $op_2 & 255;
    var $deltaFromTop_0 = 0;
    var $sd2_0 = $sdtop_1;
    var $delta_1 = $delta_0;
    __label__ = 21;
    break;
   case 21:
    var $delta_1;
    var $sd2_0;
    var $deltaFromTop_0;
    if ($sd2_0 >>> 0 < $9 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 22:
    if ((HEAP32[$sd2_0 >> 2] | 0) == ($top_1 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $70 = $sd2_0 + 4 | 0;
    var $71 = HEAP32[$70 >> 2];
    if ($sd2_0 >>> 0 > $sd_0 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $73 = $71 + $deltaFromTop_0 | 0;
    HEAP32[$70 >> 2] = $73;
    var $deltaFromTop_1 = $deltaFromTop_0 + 2 | 0;
    var $78 = $73;
    __label__ = 26;
    break;
   case 25:
    var $76 = $71 + $delta_1 | 0;
    HEAP32[$70 >> 2] = $76;
    var $deltaFromTop_1 = $deltaFromTop_0;
    var $78 = $76;
    __label__ = 26;
    break;
   case 26:
    var $78;
    var $deltaFromTop_1;
    var $79 = $delta_1 + 2 | 0;
    var $80 = HEAP32[$15 >> 2];
    __ZL17UpdateJumpTargetsP12JSJumpTargetii($80, $78);
    var $deltaFromTop_0 = $deltaFromTop_1;
    var $sd2_0 = $sd2_0 + 16 | 0;
    var $delta_1 = $79;
    __label__ = 21;
    break;
   case 27:
    var $pc_2 = $pc_1;
    var $sd_1 = $sd2_0 - 16 | 0;
    var $sdtop_2 = $sdtop_1;
    var $delta_2 = $delta_1;
    var $top_2 = $top_1;
    var $pivot_2 = $pivot_1;
    var $done_1 = 0;
    var $op_3 = $op_2;
    var $type_2 = $type_1;
    __label__ = 28;
    break;
   case 28:
    var $type_2;
    var $op_3;
    var $done_1;
    var $pivot_2;
    var $top_2;
    var $delta_2;
    var $sdtop_2;
    var $sd_1;
    var $pc_2;
    var $pc_0 = $pc_2;
    var $sd_0 = $sd_1 + 16 | 0;
    var $sdtop_0 = $sdtop_2;
    var $delta_0 = $delta_2;
    var $top_0 = $top_2;
    var $pivot_0 = $pivot_2;
    var $done_0 = $done_1;
    var $op_0 = $op_3;
    var $type_0 = $type_2;
    __label__ = 3;
    break;
   case 29:
    var $85 = $delta_0 + $growth_0 | 0;
    if (($done_0 | 0) == 0) {
      var $growth_0 = $85;
      __label__ = 2;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $88 = ($85 | 0) != 0;
    if ($88) {
      __label__ = 31;
      break;
    } else {
      var $base_1 = $4;
      __label__ = 36;
      break;
    }
   case 31:
    var $90 = HEAPU32[$1 >> 2];
    var $93 = $85 + $14 | 0;
    var $94 = $4 + $93 | 0;
    if ($94 >>> 0 > HEAPU32[$90 + 4 >> 2] >>> 0) {
      __label__ = 32;
      break;
    } else {
      var $base_0 = $4;
      var $next_0 = $94;
      var $107 = $90;
      __label__ = 35;
      break;
    }
   case 32:
    var $97 = __ZN9JSContext8realloc_EPvj($cx, $4, $93);
    if (($97 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 82;
    break;
   case 34:
    var $102 = HEAP32[$1 >> 2] | 0;
    HEAP32[$102 >> 2] = $97;
    var $103 = $97 + $93 | 0;
    var $105 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$105 >> 2] = $103;
    var $base_0 = $97;
    var $next_0 = $103;
    var $107 = HEAP32[$1 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $107;
    var $next_0;
    var $base_0;
    HEAP32[$107 + 8 >> 2] = $next_0;
    HEAP32[$guard >> 2] = -1;
    HEAP32[$guard + 4 >> 2] = $93;
    HEAP32[$guard + 8 >> 2] = $14;
    HEAP32[$guard + 12 >> 2] = 0;
    var $base_1 = $base_0;
    __label__ = 36;
    break;
   case 36:
    var $base_1;
    var $sd_2_ph = $sd_0;
    var $offset_0_ph = $14;
    var $top_3_ph = -1;
    var $pivot_3_ph = $pivot_0;
    var $type_3_ph = $type_0;
    __label__ = 37;
    break;
   case 37:
    var $type_3_ph;
    var $pivot_3_ph;
    var $top_3_ph;
    var $offset_0_ph;
    var $sd_2_ph;
    var $sd_2 = $sd_2_ph;
    var $top_3 = $top_3_ph;
    var $pivot_3 = $pivot_3_ph;
    var $type_3 = $type_3_ph;
    __label__ = 38;
    break;
   case 38:
    var $type_3;
    var $pivot_3;
    var $top_3;
    var $sd_2;
    var $115 = $sd_2 - 16 | 0;
    if ($115 >>> 0 < $6 >>> 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $119 = HEAPU32[$115 >> 2];
    if (($119 | 0) == ($top_3 | 0)) {
      var $top_4 = $top_3;
      var $pivot_4 = $pivot_3;
      var $type_4 = $type_3;
      __label__ = 45;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $127 = HEAP32[_js_CodeSpec + ((HEAPU8[$base_1 + $119 | 0] & 255) << 3) + 4 >> 2] & 31;
    var $sd2_1 = $sd_2 - 32 | 0;
    __label__ = 41;
    break;
   case 41:
    var $sd2_1;
    if ($sd2_1 >>> 0 < $6 >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ((HEAP32[$sd2_1 >> 2] | 0) == ($119 | 0)) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $sd2_1 = $sd2_1 - 16 | 0;
    __label__ = 41;
    break;
   case 44:
    var $top_4 = $119;
    var $pivot_4 = HEAP32[$sd2_1 + 20 >> 2];
    var $type_4 = $127;
    __label__ = 45;
    break;
   case 45:
    var $type_4;
    var $pivot_4;
    var $top_4;
    var $141 = HEAPU32[$sd_2 - 16 + 8 >> 2];
    var $145 = HEAP32[$sd_2 - 16 + 12 >> 2] & -2;
    if (($145 | 0) == 0) {
      var $153 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $153 = HEAP32[$145 >> 2] - $pivot_4 | 0;
    __label__ = 47;
    break;
   case 47:
    var $153;
    if (($type_4 - 9 | 0) >>> 0 < 3) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    HEAP8[$141 + ($base_1 + 1) | 0] = $153 >>> 8 & 255;
    HEAP8[$141 + ($base_1 + 2) | 0] = $153 & 255;
    var $sd_2 = $115;
    var $top_3 = $top_4;
    var $pivot_3 = $pivot_4;
    var $type_3 = $type_4;
    __label__ = 38;
    break;
   case 49:
    var $164 = HEAPU32[$sd_2 - 16 + 4 >> 2];
    var $166 = $141 + 1 | 0;
    var $167 = $offset_0_ph - $141 - 3 | 0;
    if (($167 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $170 = $164 + ($base_1 + 5) | 0;
    var $171 = $141 + ($base_1 + 3) | 0;
    _llvm_memmove_p0i8_p0i8_i32($170, $171, $167, 1, 0);
    __label__ = 51;
    break;
   case 51:
    HEAP8[$164 + ($base_1 + 1) | 0] = $153 >>> 24 & 255;
    HEAP8[$164 + ($base_1 + 2) | 0] = $153 >>> 16 & 255;
    HEAP8[$164 + ($base_1 + 3) | 0] = $153 >>> 8 & 255;
    HEAP8[$164 + ($base_1 + 4) | 0] = $153 & 255;
    var $sd_2_ph = $115;
    var $offset_0_ph = $166;
    var $top_3_ph = $top_4;
    var $pivot_3_ph = $pivot_4;
    var $type_3_ph = $type_4;
    __label__ = 37;
    break;
   case 52:
    if ($88) {
      __label__ = 53;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 53:
    var $186 = $cg + 152 | 0;
    var $187 = HEAP32[$186 >> 2];
    var $188 = $cg + 156 | 0;
    var $191 = $6;
    var $sd_3 = $6;
    var $snlimit_0 = $187 + HEAP32[$188 >> 2] | 0;
    var $sn_0 = $187;
    var $offset_1 = 0;
    var $growth_1 = 0;
    var $193 = $187;
    __label__ = 54;
    break;
   case 54:
    var $193;
    var $growth_1;
    var $offset_1;
    var $sn_0;
    var $snlimit_0;
    var $sd_3;
    if ($sn_0 >>> 0 < $snlimit_0 >>> 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 55:
    var $196 = HEAPU8[$sn_0];
    var $_v = ($196 & 255) > 191 ? 63 : 7;
    var $200 = ($_v & ($196 & 255)) + $offset_1 | 0;
    var $sd_4_ph = $sd_3;
    var $snlimit_1_ph = $snlimit_0;
    var $sn_1_ph = $sn_0;
    var $growth_2_ph = $growth_1;
    var $201 = $193;
    __label__ = 56;
    break;
   case 56:
    var $201;
    var $growth_2_ph;
    var $sn_1_ph;
    var $snlimit_1_ph;
    var $sd_4_ph;
    var $sd_4 = $sd_4_ph;
    __label__ = 57;
    break;
   case 57:
    var $sd_4;
    if ($sd_4 >>> 0 < $9 >>> 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 58:
    if ((HEAP32[$sd_4 + 8 >> 2] | 0) < ($200 | 0)) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $209 = $sd_4 + 16 | 0;
    var $sd2_2 = ($209 | 0) == ($9 | 0) ? $guard : $209;
    var $215 = HEAP32[$sd2_2 + 4 >> 2] - $growth_2_ph - HEAP32[$sd2_2 + 8 >> 2] | 0;
    if (($215 | 0) > 0) {
      __label__ = 60;
      break;
    } else {
      var $sd_4 = $209;
      __label__ = 57;
      break;
    }
   case 60:
    var $218 = _js_AddToSrcNoteDelta($cx, $cg, $sn_1_ph, $215);
    if (($218 | 0) == 0) {
      var $_0 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $221 = HEAPU32[$186 >> 2];
    var $sd_4_ph = $209;
    var $snlimit_1_ph = $221 + HEAP32[$188 >> 2] | 0;
    var $sn_1_ph = $218;
    var $growth_2_ph = $215 + $growth_2_ph | 0;
    var $201 = $221;
    __label__ = 56;
    break;
   case 62:
    var $225 = HEAPU8[$sn_1_ph];
    if (($225 & 255) > 191) {
      var $231 = 24;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $231 = ($225 & 255) >>> 3;
    __label__ = 64;
    break;
   case 64:
    var $231;
    var $232 = _js_SrcNoteSpec + ($231 << 3) + 6 | 0;
    if (HEAP8[$232] << 24 >> 24 == 0) {
      var $snlimit_5 = $snlimit_1_ph;
      var $sn_5 = $sn_1_ph;
      var $281 = $225;
      var $280 = $201;
      __label__ = 72;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $239 = (HEAPU8[_js_SrcNoteSpec + ($231 << 3) + 5 | 0] & 255) + $200 | 0;
    var $242 = HEAP8[_js_SrcNoteSpec + ($231 << 3) + 4 | 0] << 24 >> 24;
    var $245 = $sd_4 - $191 >> 4;
    var $sum = $239 + $growth_2_ph | 0;
    var $i_0 = 0;
    var $snlimit_3 = $snlimit_1_ph;
    var $sn_3 = $sn_1_ph;
    var $247 = $201;
    __label__ = 66;
    break;
   case 66:
    var $247;
    var $sn_3;
    var $snlimit_3;
    var $i_0;
    if ($i_0 >>> 0 < $242 >>> 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 67:
    var $250 = _js_GetSrcNoteOffset($sn_3, $i_0);
    if (($250 | 0) == 0) {
      var $snlimit_4 = $snlimit_3;
      var $sn_4 = $sn_3;
      var $278 = $247;
      __label__ = 70;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $254 = HEAP8[$232] << 24 >> 24;
    var $255 = $254 * $250 | 0;
    var $256 = $255 + $239 | 0;
    var $258 = ($255 | 0) > -1 ? $245 : 0;
    var $cg_idx4_val = HEAP32[$5 >> 2];
    var $cg_idx5_val = HEAP32[$7 >> 2];
    var $259 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx4_val, $cg_idx5_val, $256, $258, $guard);
    var $266 = $254 * ($256 - $sum + HEAP32[$259 + 4 >> 2] - HEAP32[$259 + 8 >> 2]) | 0;
    var $269 = $sn_3 - $247 | 0;
    var $270 = _js_SetSrcNoteOffset($cx, $cg, $269, $i_0, $266);
    if (($270 | 0) == 0) {
      var $_0 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $273 = HEAP32[$186 >> 2];
    var $snlimit_4 = $273 + HEAP32[$188 >> 2] | 0;
    var $sn_4 = $273 + $269 | 0;
    var $278 = $273;
    __label__ = 70;
    break;
   case 70:
    var $278;
    var $sn_4;
    var $snlimit_4;
    var $i_0 = $i_0 + 1 | 0;
    var $snlimit_3 = $snlimit_4;
    var $sn_3 = $sn_4;
    var $247 = $278;
    __label__ = 66;
    break;
   case 71:
    var $snlimit_5 = $snlimit_3;
    var $sn_5 = $sn_3;
    var $281 = HEAP8[$sn_3];
    var $280 = $247;
    __label__ = 72;
    break;
   case 72:
    var $280;
    var $281;
    var $sn_5;
    var $snlimit_5;
    if (($281 & 255) > 191) {
      var $287 = 24;
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $287 = ($281 & 255) >>> 3;
    __label__ = 74;
    break;
   case 74:
    var $287;
    if (HEAP8[_js_SrcNoteSpec + ($287 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $294 = 1;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $292 = _js_SrcNoteLength($sn_5);
    var $294 = $292;
    __label__ = 76;
    break;
   case 76:
    var $294;
    var $sd_3 = $sd_4;
    var $snlimit_0 = $snlimit_5;
    var $sn_0 = $sn_5 + $294 | 0;
    var $offset_1 = $200;
    var $growth_1 = $growth_2_ph;
    var $193 = $280;
    __label__ = 54;
    break;
   case 77:
    var $297 = $cg + 164 | 0;
    var $299 = HEAP32[$297 >> 2] + $growth_1 | 0;
    HEAP32[$297 >> 2] = $299;
    var $tryNode_021 = HEAP32[$cg + 204 >> 2];
    if (($tryNode_021 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      var $tryNode_022 = $tryNode_021;
      __label__ = 78;
      break;
    }
   case 78:
    var $tryNode_022;
    var $302 = $tryNode_022 + 4 | 0;
    var $303 = HEAP32[$302 >> 2];
    var $cg_idx2_val = HEAP32[$5 >> 2];
    var $cg_idx3_val = HEAP32[$7 >> 2];
    var $304 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx2_val, $cg_idx3_val, $303, 0, $guard);
    var $309 = HEAP32[$304 + 4 >> 2] - HEAP32[$304 + 8 >> 2] | 0;
    var $310 = $309 + $303 | 0;
    HEAP32[$302 >> 2] = $310;
    var $311 = $tryNode_022 + 8 | 0;
    var $312 = HEAP32[$311 >> 2];
    var $313 = $312 + $303 | 0;
    var $316 = $304 - $191 >> 4;
    var $cg_idx_val = HEAP32[$5 >> 2];
    var $cg_idx1_val = HEAP32[$7 >> 2];
    var $317 = __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_idx_val, $cg_idx1_val, $313, $316, $guard);
    if (($317 | 0) == ($304 | 0)) {
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $326 = $312 - $309 + HEAP32[$317 + 4 >> 2] - HEAP32[$317 + 8 >> 2] | 0;
    HEAP32[$311 >> 2] = $326;
    __label__ = 80;
    break;
   case 80:
    var $tryNode_0 = HEAP32[$tryNode_022 + 12 >> 2];
    if (($tryNode_0 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      var $tryNode_022 = $tryNode_0;
      __label__ = 78;
      break;
    }
   case 81:
    var $331 = HEAP32[$5 >> 2];
    __ZN9JSContext5free_EPv(undef, $331);
    HEAP32[$5 >> 2] = 0;
    var $332 = HEAP32[$15 >> 2];
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $332);
    HEAP32[$15 >> 2] = 0;
    HEAP32[$cg + 224 >> 2] = 0;
    HEAP32[$7 >> 2] = 0;
    var $334 = HEAP32[$1 >> 2];
    var $341 = HEAP32[$334 + 8 >> 2] - HEAP32[$334 >> 2] | 0;
    HEAP32[$cg + 228 >> 2] = $341;
    var $_0 = 1;
    __label__ = 82;
    break;
   case 82:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator["X"] = 1;

function __ZN16EmitLevelManagerD1Ev($this) {
  __ZN16EmitLevelManagerD2Ev($this);
  return;
}

function __ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$2 + 12 >> 2];
    var $6 = HEAP32[$2 + 16 >> 2];
    var $8 = HEAP32[$2 + 20 >> 2];
    if (($6 | 0) == ($8 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $26 = $2;
      __label__ = 8;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZN9JSContext7malloc_Ej($cx, 1024);
    var $newlength_0 = 1024;
    var $newnotes_0 = $13;
    __label__ = 5;
    break;
   case 4:
    var $15 = $8 << 1;
    var $16 = __ZN9JSContext8realloc_EPvj($cx, $4, $15);
    var $newlength_0 = $15;
    var $newnotes_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $newnotes_0;
    var $newlength_0;
    if (($newnotes_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = -1;
    __label__ = 9;
    break;
   case 7:
    var $22 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$22 >> 2] = $newnotes_0;
    var $24 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$24 >> 2] = $newlength_0;
    var $26 = HEAP32[$1 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $26;
    var $27 = $6 + 1 | 0;
    HEAP32[$26 + 16 >> 2] = $27;
    var $_0 = $6;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_NewSrcNote3($cx, $cg, $type, $offset1, $offset2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, $type);
    if (($1 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = _js_SetSrcNoteOffset($cx, $cg, $1, 0, $offset1);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _js_SetSrcNoteOffset($cx, $cg, $1, 1, $offset2);
    if (($7 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddToSrcNoteDelta($cx, $cg, $sn, $delta) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$sn];
    var $2 = $1 & 255;
    var $3 = $2 & 248;
    var $4 = ($1 & 255) > 191;
    var $_v = $4 ? 63 : 7;
    var $6 = $4 ? 64 : 8;
    var $7 = ($_v & $2) + $delta | 0;
    if (($7 | 0) < ($6 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$sn] = ($7 | 192) & 255;
    var $_0 = $sn;
    __label__ = 9;
    break;
   case 4:
    HEAP8[$sn] = ($7 & 7 | $3) & 255;
    var $_0 = $sn;
    __label__ = 9;
    break;
   case 5:
    var $18 = $cg + 152 | 0;
    var $22 = $sn - HEAP32[$18 >> 2] | 0;
    var $23 = $cg + 156 | 0;
    var $24 = HEAP32[$23 >> 2];
    if (($24 | 0) == (HEAP32[$cg + 160 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $sn;
      var $35 = $24;
      __label__ = 8;
      break;
    }
   case 6:
    var $29 = __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_01 = HEAP32[$18 >> 2] + $22 | 0;
    var $35 = HEAP32[$23 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $35;
    var $_01;
    var $36 = $35 - $22 | 0;
    HEAP32[$23 >> 2] = $35 + 1 | 0;
    var $38 = $_01 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($38, $_01, $36, 1, 0);
    HEAP8[$_01] = ($delta | 192) & 255;
    var $_0 = $38;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_AddToSrcNoteDelta["X"] = 1;

function __ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $5 = HEAP32[$2 + 20 >> 2] << 1;
    var $7 = HEAP32[$2 + 12 >> 2];
    var $8 = __ZN9JSContext8realloc_EPvj($cx, $7, $5);
    if (($8 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$13 >> 2] = $8;
    var $15 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$15 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_0_0_6_val) {
  var __stackBase__ = STACKTOP;
  var $1 = __ZL13StatementNameP15JSCodeGenerator($cg_0_0_6_val);
  _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1, tempInt));
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN14JSCGObjectList6finishEP13JSObjectArray($this, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objbox_0 = HEAP32[$this + 4 >> 2];
    var $cursor_0 = HEAP32[$array >> 2] + (HEAP32[$array + 4 >> 2] << 2) | 0;
    __label__ = 2;
    break;
   case 2:
    var $cursor_0;
    var $objbox_0;
    var $9 = $cursor_0 - 4 | 0;
    var $11 = HEAP32[$objbox_0 + 8 >> 2];
    HEAP32[$9 >> 2] = $11;
    var $13 = HEAP32[$objbox_0 + 4 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $objbox_0 = $13;
      var $cursor_0 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZN9JSContext12parseMapPoolEv($this) {
  return HEAP32[$this + 100 >> 2];
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function _js_FinishTakingSrcNotes($cx, $cg, $notes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 108 | 0;
    var $2 = $cg + 124 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cg + 188 >> 2];
    if ((HEAP32[$cg + 136 >> 2] | 0) == ($9 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $cg + 172 | 0;
    HEAP32[$12 >> 2] = $1;
    var $13 = _js_NewSrcNote2($cx, $cg, 23, $9);
    if (($13 | 0) < 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$2 >> 2];
    HEAP32[$12 >> 2] = $cg + 140 | 0;
    var $prologCount_0 = $16;
    __label__ = 15;
    break;
   case 5:
    var $28 = HEAP32[$cg + 116 >> 2] - HEAP32[$1 >> 2] - HEAP32[$cg + 132 >> 2] | 0;
    if (($28 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    }
   case 6:
    if ((HEAP32[$cg + 156 >> 2] | 0) == 0) {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $35 = $cg + 152 | 0;
    var $36 = HEAPU32[$35 >> 2];
    var $37 = HEAPU8[$36];
    var $38 = $37 & 255;
    if (($37 & 255) > 191) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $45 = $38 & 63 ^ 63;
    __label__ = 10;
    break;
   case 9:
    var $45 = $38 & 7 ^ 7;
    __label__ = 10;
    break;
   case 10:
    var $45;
    if (($28 | 0) < ($45 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $sn_0 = $36;
      var $delta_0 = $45;
      var $offset_0 = $28;
      __label__ = 12;
      break;
    }
   case 11:
    var $sn_0 = $36;
    var $delta_0 = $28;
    var $offset_0 = $28;
    __label__ = 12;
    break;
   case 12:
    var $offset_0;
    var $delta_0;
    var $sn_0;
    var $48 = _js_AddToSrcNoteDelta($cx, $cg, $sn_0, $delta_0);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = $offset_0 - $delta_0 | 0;
    if (($offset_0 | 0) == ($delta_0 | 0)) {
      var $prologCount_0 = $3;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $55 = ($51 | 0) < 63 ? $51 : 63;
    var $sn_0 = HEAP32[$35 >> 2];
    var $delta_0 = $55;
    var $offset_0 = $51;
    __label__ = 12;
    break;
   case 15:
    var $prologCount_0;
    var $58 = HEAP32[$cg + 156 >> 2];
    var $59 = $58 + $prologCount_0 | 0;
    if (($prologCount_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $63 = HEAP32[$cg + 120 >> 2];
    _memcpy($notes, $63, $prologCount_0, 1);
    __label__ = 17;
    break;
   case 17:
    var $65 = $notes + $prologCount_0 | 0;
    var $67 = HEAP32[$cg + 152 >> 2];
    _memcpy($65, $67, $58, 1);
    HEAP8[$notes + $59 | 0] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_FinishTakingSrcNotes["X"] = 1;

function _js_FinishTakingTryNotes($cg, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tn_0 = HEAP32[$array >> 2] + HEAP32[$array + 4 >> 2] * 12 | 0;
    var $tryNode_0 = HEAP32[$cg + 204 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $tryNode_0;
    var $tn_0;
    var $9 = $tn_0 - 12 | 0;
    var $10 = $9 | 0;
    var $11 = $tryNode_0 | 0;
    HEAP32[$10 >> 2] = HEAP32[$11 >> 2];
    HEAP32[$10 + 4 >> 2] = HEAP32[$11 + 4 >> 2];
    HEAP32[$10 + 8 >> 2] = HEAP32[$11 + 8 >> 2];
    var $13 = HEAP32[$tryNode_0 + 12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $tn_0 = $9;
      var $tryNode_0 = $13;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSGCConstList6finishEP12JSConstArray($this, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($1);
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $src_01 = $2;
    var $dst_02 = HEAP32[$array >> 2];
    __label__ = 3;
    break;
   case 3:
    var $dst_02;
    var $src_01;
    var $8 = $src_01 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $dst_02 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = $src_01 + 8 | 0;
    if (($11 | 0) == ($3 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $src_01 = $11;
      var $dst_02 = $dst_02 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js12ParseMapPool7recycleEPv($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $map;
  var $2 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t & 65535;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 >> 2] = $6$0;
    HEAP32[$4 + 4 >> 2] = $6$1;
    __label__ = 3;
    break;
   case 3:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $10;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $14 = __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($1);
    var $15 = $14;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $6 = __ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev($1);
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 98,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $5 + 8 | 0;
    var $st$10$0 = $9 | 0;
    HEAP32[$st$10$0 >> 2] = $8$0;
    var $st$10$1 = $9 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($27, $1);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 24 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv($rhs);
  var $8 = $7 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIP6JSAtomjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv($rhs);
  var $9 = $8 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($2);
  var $11 = $10 | 0;
  var $12$0 = HEAP32[$11 >> 2];
  var $12$1 = HEAP32[$11 + 4 >> 2];
  var $13 = $this + 8 | 0;
  HEAP32[$13 >> 2] = $12$0;
  HEAP32[$13 + 4 >> 2] = $12$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN2js12ParseMapPool8allocateEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 140 | 0;
    var $2 = __ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js12ParseMapPool13allocateFreshEv($this);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv($1);
    var $7 = __ZN2js12ParseMapPool9asAtomMapEPv($6);
    __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($7);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv($this) {
  var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv($this);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$this + 4 >> 2];
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext($1, $3);
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext12parseMapPoolEv($cx);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE($5, $2);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext($this, $cx) {
  HEAP32[$this + 4 >> 2] = $cx;
  var $2 = $this | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv($2);
  return;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv($this) {
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($src_01);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv($src_01);
    var $27 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv($src_01);
    var $28 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $27);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE($28, $1);
    __label__ = 7;
    break;
   case 7:
    var $30 = $src_01 + 12 | 0;
    if (($30 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $30;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $9);
  var $10 = __ZNK2js7MoveRefIjEcvRjEv($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomjEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomjEC2Ev($this);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function _JSDOUBLE_IS_NEGZERO1166($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode7setKindEN2js9TokenKindE($this, $kind) {
  var $2 = $this;
  var $5 = HEAP32[$2 >> 2] & -65536 | $kind & 65535;
  HEAP32[$2 >> 2] = $5;
  return;
}

function __ZN11JSParseNode8setArityE16JSParseNodeArity($this, $a) {
  var $1 = $this;
  var $6 = HEAP32[$1 >> 2] & -520093697 | $a << 24 & 520093696;
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZNK11JSParseNode8getArityEv($this) {
  return HEAPU32[$this >> 2] >>> 24 & 31;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv($this) {
  return (HEAP32[$this + 24 >> 2] | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZL13StatementNameP15JSCodeGenerator($cg_0_0_6_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($cg_0_0_6_val | 0) == 0) {
      var $_0 = STRING_TABLE.__str33670 | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZL13statementName + ((HEAPU16[$cg_0_0_6_val >> 1] & 65535) << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16EmitLevelManagerD2Ev($this) {
  var $3 = HEAP32[$this >> 2] + 236 | 0;
  var $5 = HEAP32[$3 >> 2] - 1 | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep($cg_0_11_val, $cg_0_14_val, $offset, $lo, $guard) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hi_0_ph = $cg_0_14_val - 1 | 0;
    var $_01_ph = $lo;
    __label__ = 2;
    break;
   case 2:
    var $_01_ph;
    var $hi_0_ph;
    var $hi_0 = $hi_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $hi_0;
    if (($_01_ph | 0) > ($hi_0 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = ($hi_0 + $_01_ph | 0) / 2 & -1;
    var $8 = HEAP32[$cg_0_11_val + ($6 << 4) + 8 >> 2];
    if (($8 | 0) == ($offset | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_0 = $cg_0_11_val + ($6 << 4) | 0;
    __label__ = 11;
    break;
   case 6:
    if (($8 | 0) < ($offset | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $hi_0_ph = $hi_0;
    var $_01_ph = $6 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $hi_0 = $6 - 1 | 0;
    __label__ = 3;
    break;
   case 9:
    if (($_01_ph | 0) == ($cg_0_14_val | 0)) {
      var $_0 = $guard;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = $cg_0_11_val + ($_01_ph << 4) | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape12inDictionaryEv($this) {
  return (HEAP8[$this + 29 | 0] & 2) << 24 >> 24 != 0;
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK13JSTreeContext12inStrictModeEv($this) {
  return (HEAP32[$this >> 2] & 262144 | 0) != 0;
}

function __ZNK13JSTreeContext16mutatesParameterEv($this) {
  return (HEAP32[$this >> 2] & 16777216 | 0) != 0;
}

function __ZL21UpdateDecomposeLengthP15JSCodeGeneratorj($cg_0_3_val_0_0_val, $cg_0_3_val_0_2_val, $start) {
  HEAP8[$cg_0_3_val_0_0_val + ($start - 1) | 0] = $cg_0_3_val_0_2_val - $start - $cg_0_3_val_0_0_val & 255;
  return;
}

function __ZNK11JSParseNode4testEj($this, $flag) {
  return ($flag & 4095 & HEAP32[$this + 44 >> 2] | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE($1);
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv($1);
  return $2;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    var $5 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($4);
    var $10 = $5;
    __label__ = 4;
    break;
   case 3:
    var $10 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv($1);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($11);
    var $14 = $12;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $3 = HEAP32[$this >> 2];
  var $4 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv($3);
  return $4;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZL17UpdateJumpTargetsP12JSJumpTargetii($jt, $pivot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $jt_tr = $jt;
    __label__ = 2;
    break;
   case 2:
    var $jt_tr;
    var $1 = $jt_tr | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) > ($pivot | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = $2 + 2 | 0;
    HEAP32[$1 >> 2] = $5;
    var $7 = HEAP32[$jt_tr + 8 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL17UpdateJumpTargetsP12JSJumpTargetii($7, $pivot);
    __label__ = 5;
    break;
   case 5:
    var $12 = HEAP32[$jt_tr + 12 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $jt_tr = $12;
      __label__ = 2;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $jt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $jt + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $2);
    __label__ = 3;
    break;
   case 3:
    var $7 = HEAP32[$jt + 12 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget($cg, $7);
    __label__ = 5;
    break;
   case 5:
    var $11 = $cg + 216 | 0;
    var $12 = HEAP32[$11 >> 2];
    HEAP32[$1 >> 2] = $12;
    HEAP32[$11 >> 2] = $jt;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT321163($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO1166($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSGCConstList6appendEN2JS5ValueE($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $2 = __stackBase__;
  var $_02 = $0 | 0;
  var $tmp$0 = HEAP32[$_02 >> 2];
  var $tmp$1 = HEAP32[$_02 + 4 >> 2];
  var $3 = $this | 0;
  var $_03 = $2 | 0;
  HEAP32[$_03 >> 2] = $tmp$0;
  HEAP32[$_03 + 4 >> 2] = $tmp$1;
  var $4 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($3, $2);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN2JSL11DoubleValueEd1164($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZNK13JSGCConstList6lengthEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($1);
  return $2;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_04 = $2 | 0;
    HEAP32[$_04 >> 2] = $tmp$0;
    HEAP32[$_04 + 4 >> 2] = $tmp$1;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_02 = $0 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $_03 = $2 | 0;
    HEAP32[$_03 >> 2] = $tmp$0;
    HEAP32[$_03 + 4 >> 2] = $tmp$1;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $14 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($1);
    var $15 = $14 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $6 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($1);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16needStrictChecksEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$this + 48 >> 2] + 12 >> 2];
    var $5 = __ZNK9JSContext15hasStrictOptionEv($4);
    if ($5) {
      var $9 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK13JSTreeContext12inStrictModeEv($this);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode9frameSlotEv($this) {
  var $2 = $this + 40 | 0;
  var $3 = __ZNK2js11UpvarCookie4slotEv($2);
  return $3 & 65535;
}

function __ZN2JSL12BooleanValueEb1168($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN8JSObject16setBlockOwnShapeEP9JSContext($this, $cx) {
  var $1 = __Z16js_GenerateShapeP9JSContext($cx);
  __ZN8JSObject11setOwnShapeEj($this, $1);
  return;
}

function __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_Emit1($cx, $cg, $op);
    if (($1 | 0) < 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $op);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode9maybeExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1073741824 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK11JSParseNode4exprEv($this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, $op, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $3 = HEAP32[$pn + 32 >> 2];
    var $4 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $3, $index);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$index >> 2];
    var $7 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, 165, $6, $cg, 0);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, $op);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi($cx, $cg, $npops) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewSrcNote($cx, $cg, 11);
    if (($1 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$npops >> 2];
    var $6 = $4 >>> 8 & 255;
    var $7 = $4 & 255;
    var $8 = _js_Emit3($cx, $cg, 11, $6, $7);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 11);
    HEAP32[$npops >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    var $3 = HEAP32[$pn + 32 >> 2];
    if ($1) {
      var $pn2_0 = $3;
      __label__ = 2;
      break;
    } else {
      var $pn2_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 3);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 29);
    var $_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode = $8 ? 100 : 102;
    var $9 = FUNCTION_TABLE[$_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode]($cx, $cg, $prologOp, $pn2_0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[$pn2_1 + 36 >> 2];
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 29);
    var $_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode1 = $19 ? 100 : 102;
    var $20 = FUNCTION_TABLE[$_ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode1]($cx, $cg, $prologOp, $18);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $pn2_1 = HEAP32[$pn2_1 + 24 >> 2];
    __label__ = 6;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12OpToDeclType4JSOp($op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 128) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 129) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 0) {
      var $_0 = 2;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext15asCodeGeneratorEv($this) {
  return $this;
}

function __ZNK11JSParseNode6isUsedEv($this) {
  return (HEAP32[$this >> 2] & 1073741824 | 0) != 0;
}

function __ZN12TempPopScopeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK13JSTreeContext10scopeChainEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZNK2js5Shape16hasDefaultGetterEv($this) {
  return (HEAP32[$this + 16 >> 2] | 0) == 0;
}

function __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $prologOp, $pn, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atomIndex = __stackBase__;
    var $2 = $pn + 40 | 0;
    var $3 = __ZNK2js11UpvarCookie6isFreeEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js11UpvarCookie4slotEv($2);
    HEAP32[$atomIndex >> 2] = $5 & 65535;
    __label__ = 4;
    break;
   case 3:
    var $10 = HEAP32[$pn + 32 >> 2];
    var $11 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($cg, $10, $atomIndex);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $13 = __ZNK11JSParseNode5getOpEv($pn);
    var $18 = $cg | 0;
    if ((HEAP32[_js_CodeSpec + ($13 << 3) + 4 >> 2] & 31 | 0) == 2) {
      __label__ = 5;
      break;
    } else {
      var $_pre_phi = $18;
      __label__ = 11;
      break;
    }
   case 5:
    var $20 = __ZNK13JSTreeContext10inFunctionEv($18);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    if ((HEAP32[$cg >> 2] & 256 | 0) == 0) {
      var $_pre_phi = $18;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$pn + 44 >> 2] & 64 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_pre_phi = $18;
      __label__ = 11;
      break;
    }
   case 8:
    var $34 = $cg + 172 | 0;
    HEAP32[$34 >> 2] = $cg + 108 | 0;
    var $36 = HEAP32[$pn + 8 >> 2];
    var $37 = __ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj($cx, $cg, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = HEAP32[$atomIndex >> 2];
    var $41 = __ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_($cx, $prologOp, $40, $cg, 0);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    HEAP32[$34 >> 2] = $cg + 140 | 0;
    var $_pre_phi = $18;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $44 = __ZNK13JSTreeContext10inFunctionEv($_pre_phi);
    if ($44) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $46 = __ZNK11JSParseNode5getOpEv($pn);
    if ((HEAP32[_js_CodeSpec + ($46 << 3) + 4 >> 2] & 31 | 0) == 7) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $52 = __ZNK2js11UpvarCookie4slotEv($2);
    var $53 = $cg + 92 | 0;
    var $54 = __ZNK2js8Bindings9countVarsEv($53);
    if (($52 & 65535) < ($54 & 65535)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $57 = __ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode($cg, $pn);
    if ($57) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $59 = $cg + 564 | 0;
    var $60 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_($59, $52);
    if ($60) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    if (($result | 0) == 0) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = HEAP32[$atomIndex >> 2];
    HEAP32[$result >> 2] = $64;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj["X"] = 1;

function __ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode($cx, $cg, $prologOp, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj($cx, $cg, $prologOp, $pn, 0);
    var $_0 = $4 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = _js_Emit1($cx, $cg, 12);
    if (($5 | 0) > -1) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = _js_Emit1($cx, $cg, 81);
    var $11 = ($8 | 0) > -1;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 24;
    break;
   case 5:
    var $14 = $pn + 32 | 0;
    var $pn2_0_in = $14;
    var $index_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $index_0;
    var $pn2_0_in;
    var $pn2_0 = HEAPU32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($pn2_0 | 0) == (HEAP32[$14 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = _js_NewSrcNote($cx, $cg, 5);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = _js_Emit1($cx, $cg, 12);
    if (($24 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $30 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $index_0 >>> 0, $cg);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $pn3_01 = $pn2_0;
      __label__ = 18;
      break;
    }
   case 12:
    var $34 = HEAPU32[$pn2_0 + 32 >> 2];
    var $35 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($34, 30);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $37 = _js_NewSrcNote($cx, $cg, 1);
    if (($37 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = $34 + 32 | 0;
    var $42 = (tempDoubleI32[0] = HEAP32[$41 >> 2], tempDoubleI32[1] = HEAP32[$41 + 4 >> 2], tempDoubleF64[0]);
    var $43 = __ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator($cx, $42, $cg);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn3_01 = HEAP32[$pn2_0 + 36 >> 2];
    __label__ = 18;
    break;
   case 16:
    var $49 = __ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_($cx, $34, 53, $cg, 0);
    if ($49) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $pn3_02 = HEAP32[$pn2_0 + 36 >> 2];
    __label__ = 19;
    break;
   case 18:
    var $pn3_01;
    var $53 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 55);
    if ($53) {
      var $pn3_02 = $pn3_01;
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 19:
    var $pn3_02;
    var $55 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_02, 3);
    if ($55) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $57 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn3_02, 0);
    if ($57) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $59 = _js_Emit1($cx, $cg, 81);
    if (($59 | 0) < 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $62 = __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn3_02);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 6;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 24);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 26);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = _js_Emit1($cx, $cg, 81);
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 5:
    var $11 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $13 = __ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK11JSParseNode7isConstEv($pn);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZNK11JSParseNode13isInitializedEv($pn);
    if ($18) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = _js_Emit1($cx, $cg, 81);
    var $_0 = $20 >>> 31 ^ 1;
    __label__ = 21;
    break;
   case 10:
    var $22 = __ZNK11JSParseNode5getOpEv($pn);
    if (($22 | 0) == 111 || ($22 | 0) == 157) {
      __label__ = 11;
      break;
    } else if (($22 | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($22 | 0) == 87) {
      __label__ = 13;
      break;
    } else if (($22 | 0) == 85) {
      __label__ = 15;
      break;
    } else if (($22 | 0) == 124) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $24 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, 124, $cg);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 12:
    var $27 = __ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator($cx, $pn, 209, $cg);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    var $31 = $pn + 40 | 0;
    var $32 = __ZNK2js11UpvarCookie9asIntegerEv($31);
    var $34 = $32 >>> 8 & 255;
    var $35 = $32 & 255;
    var $36 = _js_Emit3($cx, $cg, 132, $34, $35);
    if (($36 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 132);
    __label__ = 20;
    break;
   case 15:
    var $41 = $pn + 40 | 0;
    var $42 = __ZNK2js11UpvarCookie9asIntegerEv($41);
    var $44 = $42 >>> 8 & 255;
    var $45 = $42 & 255;
    var $46 = _js_Emit3($cx, $cg, 85, $44, $45);
    if (($46 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, $49);
    var $50 = _js_Emit1($cx, $cg, 81);
    if (($50 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $53 = $cg + 172 | 0;
    var $54 = HEAP32[$53 >> 2];
    var $56 = HEAP32[$54 + 8 >> 2];
    var $58 = HEAP32[$54 >> 2];
    var $59 = _js_EmitTree($cx, $cg, $pn);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = HEAP32[$53 >> 2];
    var $73 = $58 - $56 + HEAP32[$64 + 8 >> 2] - HEAP32[$64 >> 2] | 0;
    var $74 = _js_NewSrcNote2($cx, $cg, 12, $73);
    if (($74 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $77 = __ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp($cx, $cg, 124);
    if ($77) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode["X"] = 1;

function __ZNK11JSParseNode13isInitializedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 4);
  return $1;
}

function __ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj($cx, $cg, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL19FitsWithoutBigIndexj($index);
    if ($1) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $index >>> 16;
    if ($index >>> 0 < 262144) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $3 + 210 | 0;
    var $7 = _js_Emit1($cx, $cg, $6);
    var $_0 = ($7 >> 31 & -127) + 193 | 0;
    __label__ = 7;
    break;
   case 4:
    if ($index >>> 0 > 8388607) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 14, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 66;
    __label__ = 7;
    break;
   case 6:
    var $15 = $3 & 255;
    var $16 = _js_Emit2($cx, $cg, 191, $15);
    var $_0 = ($16 >> 31 & -126) + 192 | 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_($cx, $cg, $prologOp, $lhs, $rhs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 192 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $pn_0_in = $rhs + 32 | 0;
    var $limit_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $limit_0;
    var $pn_0_in;
    var $pn_0 = HEAP32[$pn_0_in >> 2];
    if (($pn_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($limit_0 | 0) == 65536) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$cg + 48 >> 2] + 40 | 0;
    var $12 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $11, $rhs, 0, 200, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 5:
    var $14 = _js_EmitTree($cx, $cg, $pn_0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $pn_0_in = $pn_0 + 24 | 0;
    var $limit_0 = $limit_0 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    var $20 = __ZL12OpToDeclType4JSOp($prologOp);
    var $21 = _js_NewSrcNote2($cx, $cg, 7, $20);
    if (($21 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $pn_1_in = $lhs + 32 | 0;
    var $i_0 = $2;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $pn_1_in;
    var $pn_1 = HEAPU32[$pn_1_in >> 2];
    if (($pn_1 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = __ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori($cg, $i_0);
    if (($28 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = $28 >>> 8 & 255;
    var $33 = $28 & 255;
    var $34 = _js_Emit3($cx, $cg, 86, $32, $33);
    if (($34 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 86);
    var $37 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_1, 3);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $39 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_1, 0);
    if ($39) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $41 = _js_Emit1($cx, $cg, 81);
    if (($41 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $44 = __ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode($cx, $cg, $pn_1);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $pn_1_in = $pn_1 + 24 | 0;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 17:
    var $50 = $limit_0 - $2 | 0;
    var $52 = $50 >>> 8 & 255;
    var $53 = $50 & 255;
    var $54 = _js_Emit3($cx, $cg, 11, $52, $53);
    if (($54 | 0) < 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp($cg, 11);
    HEAP32[$1 >> 2] = $2;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_["X"] = 1;

function __ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE($cx, $cg, $atom, $constp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $atom;
    __ZN2JS5Value8setMagicE10JSWhyMagic($constp, 5);
    var $3 = $2 | 0;
    var $_01 = $cg;
    var $5 = $atom;
    __label__ = 2;
    break;
   case 2:
    var $5;
    var $_01;
    var $6 = $_01 | 0;
    var $7 = __ZNK13JSTreeContext10inFunctionEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK13JSTreeContext12compileAndGoEv($6);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $50 = $5;
      __label__ = 15;
      break;
    }
   case 4:
    var $11 = _js_LexicalLookup($6, $5, 0, 0);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($p, $_01 + 240 | 0, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($2, $p);
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p);
    var $19 = $18 + 8 | 0;
    var $st$2$0 = $19 | 0;
    var $20$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$2$1 >> 2];
    var $21 = $constp | 0;
    var $st$7$0 = $21 | 0;
    HEAP32[$st$7$0 >> 2] = $20$0;
    var $st$7$1 = $21 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $20$1;
    __label__ = 17;
    break;
   case 7:
    var $23 = __ZNK13JSTreeContext10inFunctionEv($6);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = HEAP32[$1 >> 2];
    var $27 = __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($_01 + 92 | 0, $cx, $26);
    if ($27) {
      __label__ = 17;
      break;
    } else {
      var $50 = $26;
      __label__ = 15;
      break;
    }
   case 9:
    var $29 = __ZNK13JSTreeContext10scopeChainEv($6);
    var $30 = HEAP32[$1 >> 2];
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom1150($30);
    var $32 = __ZN8JSObject12nativeLookupEP9JSContexti($29, $cx, $31);
    if (($32 | 0) == 0) {
      var $50 = $30;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $32;
    var $36 = __ZNK2js5Shape8writableEv($35);
    if ($36) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK2js5Shape12configurableEv($35);
    if ($38) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZNK2js5Shape16hasDefaultGetterEv($32);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    var $43 = HEAP32[$32 + 24 >> 2];
    var $44 = __ZNK8JSObject12containsSlotEj($29, $43);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $46 = __ZNK8JSObject7getSlotEj($29, $43);
    var $47 = $46 | 0;
    var $st$2$0 = $47 | 0;
    var $48$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $47 + 4 | 0;
    var $48$1 = HEAP32[$st$2$1 >> 2];
    var $49 = $constp | 0;
    var $st$7$0 = $49 | 0;
    HEAP32[$st$7$0 >> 2] = $48$0;
    var $st$7$1 = $49 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $48$1;
    __label__ = 17;
    break;
   case 15:
    var $50;
    var $52 = HEAP32[$_01 + 72 >> 2];
    if (($52 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = __ZN13JSTreeContext15asCodeGeneratorEv($52);
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_01 = $55;
      var $5 = $50;
      __label__ = 2;
      break;
    }
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE["X"] = 1;

function __ZL22AllocateSwitchConstantP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 88 >> 2];
    var $4 = HEAP32[$cx + 96 >> 2];
    var $7 = $4 + 8 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if ($9 >>> 0 > (HEAP32[$2 + 8 >> 2] - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $15 = $cx + 72 | 0;
    var $16 = _JS_ArenaAllocate($15, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh($cx, $cg, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$pc];
    var $10 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) << 16 >> 16;
    var $11 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = $pc + 4 | 0;
    var $22 = (HEAPU8[$pc + 3 | 0] & 255) << 8 | HEAPU8[$19] & 255;
    if ($1 << 24 >> 24 == 70) {
      __label__ = 3;
      break;
    } else {
      var $indexlen_0_ph = 2;
      var $njumps_0_ph = $22;
      var $pc2_0_ph = $19;
      __label__ = 4;
      break;
    }
   case 3:
    var $29 = $pc + 6 | 0;
    var $indexlen_0_ph = 0;
    var $njumps_0_ph = 1 - ($22 << 16 >> 16) + (((HEAPU8[$pc + 5 | 0] & 255) << 8 | HEAPU8[$29] & 255) << 16 >> 16) | 0;
    var $pc2_0_ph = $29;
    __label__ = 4;
    break;
   case 4:
    var $pc2_0_ph;
    var $njumps_0_ph;
    var $indexlen_0_ph;
    var $_sum1 = $indexlen_0_ph | 1;
    var $_sum = $indexlen_0_ph + 2 | 0;
    var $njumps_0 = $njumps_0_ph;
    var $pc2_0 = $pc2_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $pc2_0;
    var $njumps_0;
    if (($njumps_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $44 = $pc2_0 + $_sum | 0;
    var $48 = ((HEAPU8[$pc2_0 + $_sum1 | 0] & 255) << 8 | HEAPU8[$44] & 255) << 16 >> 16;
    var $49 = __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc2_0 + $indexlen_0_ph | 0, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $njumps_0 = $njumps_0 - 1 | 0;
    var $pc2_0 = $44;
    __label__ = 5;
    break;
   case 8:
    var $_0 = $pc2_0 + 1 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh["X"] = 1;

function __ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i($cx, $cg, $pc, $pc2, $off) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 220 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $2 + 1 | 0;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $cg_idx1_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx1_val);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $10 = $cg + 208 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if (($2 - 1 & $2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $21 = $11;
      __label__ = 7;
      break;
    }
   case 4:
    var $13 = ($11 | 0) != 0;
    if ($2 >>> 0 > 255 | $13 ^ 1) {
      __label__ = 5;
      break;
    } else {
      var $21 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $phitmp_ = $13 ? $2 << 5 : 4096;
    var $16 = $11;
    var $17 = __ZN9JSContext8realloc_EPvj($cx, $16, $phitmp_);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $17;
    HEAP32[$10 >> 2] = $20;
    var $21 = $20;
    __label__ = 7;
    break;
   case 7:
    var $21;
    HEAP32[$1 >> 2] = $3;
    var $22 = $21 + ($2 << 4) | 0;
    var $23 = $cg + 172 | 0;
    var $29 = $pc - HEAP32[HEAP32[$23 >> 2] >> 2] | 0;
    HEAP32[$22 >> 2] = $29;
    var $36 = $pc2 - HEAP32[HEAP32[$23 >> 2] >> 2] | 0;
    HEAP32[$21 + ($2 << 4) + 8 >> 2] = $36;
    HEAP32[$21 + ($2 << 4) + 4 >> 2] = $36;
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) + 4 >> 2] & 32768 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (($off | 0) > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cg_idx_val = HEAP32[$cg + 24 >> 2];
    __ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator($cx, $cg_idx_val);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 10:
    HEAP32[$21 + ($2 << 4) + 12 >> 2] = $off << 1;
    __label__ = 14;
    break;
   case 11:
    if (($off | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$21 + ($2 << 4) + 12 >> 2] = 1;
    __label__ = 14;
    break;
   case 13:
    var $57 = __ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi($cx, $cg, $22, $off);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $index_0 = $2 >>> 0 < 65535 ? $2 : 65535;
    HEAP8[$pc2 + 1 | 0] = $index_0 >>> 8 & 255;
    HEAP8[$pc2 + 2 | 0] = $index_0 & 255;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i["X"] = 1;

function __ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($1, $2, $name, 0);
  return ($3 | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK11JSParseNode13isDeoptimizedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 1024);
  return $1;
}

function __ZN12JSDefinition4kindEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK11JSParseNode7getKindEv($1);
    if (($2 | 0) == 34) {
      var $_0 = 3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK11JSParseNode4isOpE4JSOp($1, 0);
    if ($5) {
      var $_0 = 5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($1, 84);
    if ($7) {
      var $_0 = 4;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK11JSParseNode7isConstEv($1);
    if ($9) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZNK11JSParseNode5isLetEv($1);
    var $_ = $11 ? 2 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode10isTopLevelEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 16);
  return $1;
}

function __ZNK12JSDefinition8isGlobalEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK11JSParseNode4testEj($1, 64);
  return $2;
}

function __ZL14JSID_FROM_BITSj1189($bits) {
  return $bits;
}

function __ZNK13JSTreeContext16mightAliasLocalsEv($this) {
  return (HEAP32[$this >> 2] & 67108864 | 0) != 0;
}

function __ZNK13JSTreeContext3funEv($this) {
  return HEAP32[$this + 60 >> 2];
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv($this) {
  return $this | 0;
}

function __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this) {
  return HEAPU32[$this >> 2] >>> 0 > 24;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN13JSTreeContext8compilerEv($this) {
  return HEAP32[$this + 48 >> 2];
}

function __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP8[$this + 8 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN16EmitLevelManagerC2EP15JSCodeGenerator($this, $cg) {
  HEAP32[$this >> 2] = $cg;
  var $2 = $cg + 236 | 0;
  var $4 = HEAP32[$2 >> 2] + 1 | 0;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1183($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSTreeContext13usesArgumentsEv($this) {
  return (HEAP32[$this >> 2] & 128 | 0) != 0;
}

function __ZL18BalanceJumpTargetsPP12JSJumpTarget($jtp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$jtp >> 2];
    var $2 = $1 + 4 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (($3 | 0) < -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $doubleRotate_0 = (HEAP32[HEAP32[$1 + 8 >> 2] + 4 >> 2] | 0) > 0 & 1;
    var $dir_0 = 1;
    __label__ = 5;
    break;
   case 3:
    if (($3 | 0) > 1) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $doubleRotate_0 = HEAPU32[HEAP32[$1 + 12 >> 2] + 4 >> 2] >>> 31;
    var $dir_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $dir_0;
    var $doubleRotate_0;
    var $20 = 1 - $dir_0 | 0;
    var $22 = $1 + 8 + ($20 << 2) | 0;
    var $23 = HEAPU32[$22 >> 2];
    if (($doubleRotate_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $23 + 8 + ($dir_0 << 2) | 0;
    var $26 = HEAPU32[$25 >> 2];
    HEAP32[$jtp >> 2] = $26;
    var $27 = $26 + 8 + ($dir_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    HEAP32[$22 >> 2] = $28;
    HEAP32[$27 >> 2] = $1;
    var $29 = $26 + 8 + ($20 << 2) | 0;
    var $30 = HEAP32[$29 >> 2];
    HEAP32[$25 >> 2] = $30;
    HEAP32[$29 >> 2] = $23;
    var $31 = $26 + 4 | 0;
    var $32 = HEAP32[$31 >> 2];
    var $34 = ($32 | 0) > 0 ? -$32 | 0 : 0;
    var $37 = HEAP32[$26 + 8 >> 2] + 4 | 0;
    HEAP32[$37 >> 2] = $34;
    var $38 = HEAP32[$31 >> 2];
    var $40 = ($38 | 0) < 0 ? -$38 | 0 : 0;
    var $43 = HEAP32[$26 + 12 >> 2] + 4 | 0;
    HEAP32[$43 >> 2] = $40;
    HEAP32[$31 >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    HEAP32[$jtp >> 2] = $23;
    var $45 = $23 + 8 + ($dir_0 << 2) | 0;
    var $46 = HEAP32[$45 >> 2];
    HEAP32[$22 >> 2] = $46;
    HEAP32[$45 >> 2] = $1;
    var $47 = $23 + 4 | 0;
    var $48 = HEAPU32[$47 >> 2];
    var $50 = ($48 | 0) != 0 & 1;
    var $storemerge_v = ($dir_0 | 0) == 0 ? -1 : 1;
    var $storemerge = $48 + $storemerge_v | 0;
    HEAP32[$47 >> 2] = $storemerge;
    HEAP32[$2 >> 2] = -$storemerge | 0;
    var $_0 = $50;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18BalanceJumpTargetsPP12JSJumpTarget["X"] = 1;

function __ZNK2js11TokenStream11getFilenameEv($this) {
  return HEAP32[$this + 172 >> 2];
}

function __ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp($cg, $pn, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg | 0;
    var $2 = __ZNK13JSTreeContext12compileAndGoEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $4 = __ZN13JSTreeContext8compilerEv($1);
    if ((HEAP32[HEAP32[$4 + 992 >> 2] >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK13JSTreeContext16mightAliasLocalsEv($1);
    if ($11) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK11JSParseNode13isDeoptimizedEv($pn);
    if ($13) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$cg >> 2] & 262144 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $20 = HEAP32[$op >> 2];
    if (($20 | 0) == 59) {
      __label__ = 7;
      break;
    } else if (($20 | 0) == 111) {
      __label__ = 8;
      break;
    } else if (($20 | 0) == 41) {
      __label__ = 9;
      break;
    } else if (($20 | 0) == 47) {
      __label__ = 10;
      break;
    } else if (($20 | 0) == 44) {
      __label__ = 11;
      break;
    } else if (($20 | 0) == 50) {
      __label__ = 12;
      break;
    } else if (($20 | 0) == 14 || ($20 | 0) == 36) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    HEAP32[$op >> 2] = 156;
    __label__ = 13;
    break;
   case 8:
    HEAP32[$op >> 2] = 157;
    __label__ = 13;
    break;
   case 9:
    HEAP32[$op >> 2] = 158;
    __label__ = 13;
    break;
   case 10:
    HEAP32[$op >> 2] = 160;
    __label__ = 13;
    break;
   case 11:
    HEAP32[$op >> 2] = 159;
    __label__ = 13;
    break;
   case 12:
    HEAP32[$op >> 2] = 161;
    __label__ = 13;
    break;
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom($this, $cx, $name) {
  var $1 = $this;
  var $2 = $cx;
  var $3 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($1, $2, $name, 4);
  return $3;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($3);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$this + 4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j($this, $p, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    if ($length >>> 0 < 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $this + 16 | 0;
    var $9 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($8);
    var $10 = $9;
    HEAP32[$this + 4 >> 2] = $10;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = 8;
    var $14 = $p + ($length << 2) | 0;
    __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($10, $p, $14);
    var $15 = $p;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $15);
    __label__ = 6;
    break;
   case 5:
    HEAP32[$this + 4 >> 2] = $p;
    HEAP32[$this + 8 >> 2] = $length;
    HEAP32[$this + 12 >> 2] = $length;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02 | 0;
    HEAP32[$5 >> 2] = 0;
    __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $6 = __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($1);
    var $8 = HEAP32[$6 >> 2];
    HEAP32[$5 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 4 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 2;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01 | 0;
    HEAP32[$13 >> 2] = 0;
    __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $14 = __ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev($1);
    var $16 = HEAP32[$14 >> 2];
    HEAP32[$13 >> 2] = $16;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 4 | 0;
    var $19 = $src_02 + 4 | 0;
    var $20 = __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_($agg_result, $t);
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv($1);
  return $2;
}

function __ZNK11JSParseNode5isLetEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 1);
  return $1;
}

function __ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom($cg, $dn, $pn, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $2 = $cg | 0;
    var $3 = __ZNK13JSTreeContext16mightAliasLocalsEv($2);
    if ($3) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN13JSTreeContext8compilerEv($2);
    var $7 = HEAP32[$5 + 992 >> 2];
    var $8 = $dn + 40 | 0;
    var $9 = $8;
    var $10 = __ZNK2js11UpvarCookie6isFreeEv($9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $7 + 216 | 0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_($p, $12, $1);
    var $13 = __ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv($p);
    var $index_0_in = $13;
    var $31 = HEAP32[$1 >> 2];
    __label__ = 7;
    break;
   case 4:
    var $16 = HEAP32[$7 + 4 >> 2];
    if (($16 | 0) == ($cg | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = HEAP32[$8 >> 2];
    HEAP32[$pn + 40 >> 2] = $20;
    var $22 = $pn + 44 | 0;
    var $24 = HEAP32[$22 >> 2] | 512;
    HEAP32[$22 >> 2] = $24;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $26 = $16 + 364 | 0;
    var $27 = __ZNK2js11UpvarCookie9asIntegerEv($9);
    var $28 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($26, $27);
    var $index_0_in = $28 + 4 | 0;
    var $31 = $atom;
    __label__ = 7;
    break;
   case 7:
    var $31;
    var $index_0_in;
    var $index_0 = HEAP32[$index_0_in >> 2];
    var $33 = $pn + 40 | 0;
    var $34 = __ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE($cg, $31, $index_0, $33);
    if ($34) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $36 = __ZNK2js11UpvarCookie6isFreeEv($33);
    if ($36) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = $pn + 44 | 0;
    var $41 = HEAP32[$39 >> 2] | 512;
    HEAP32[$39 >> 2] = $41;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom["X"] = 1;

function __ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $5, $key);
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $10 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($10 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($10);
    var $14 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE($this, $p);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $jtp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$jtp >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $5 = HEAPU32[$args + 4 >> 2];
    var $6 = $5 + 216 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$7 + 8 >> 2];
    HEAP32[$6 >> 2] = $11;
    var $jt_0 = $7;
    __label__ = 9;
    break;
   case 4:
    var $13 = $args | 0;
    var $14 = HEAPU32[$13 >> 2];
    var $16 = HEAP32[$14 + 88 >> 2];
    var $18 = HEAP32[$14 + 96 >> 2];
    var $21 = $18 + 16 & ($18 ^ -1);
    var $22 = $16 + 12 | 0;
    var $23 = HEAPU32[$22 >> 2];
    var $25 = HEAPU32[$16 + 8 >> 2];
    if ($21 >>> 0 > $25 >>> 0 | $23 >>> 0 > ($25 - $21 | 0) >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $30 = $14 + 72 | 0;
    var $31 = _JS_ArenaAllocate($30, $21);
    var $_p_0 = $31;
    __label__ = 7;
    break;
   case 6:
    var $34 = $21 + $23 | 0;
    HEAP32[$22 >> 2] = $34;
    var $_p_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $jt_0 = $_p_0;
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$13 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($39);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 9:
    var $jt_0;
    var $42 = HEAP32[$args + 8 >> 2];
    HEAP32[$jt_0 >> 2] = $42;
    HEAP32[$jt_0 + 4 >> 2] = 0;
    HEAP32[$jt_0 + 12 >> 2] = 0;
    HEAP32[$jt_0 + 8 >> 2] = 0;
    var $47 = $5 + 224 | 0;
    var $49 = HEAP32[$47 >> 2] + 1 | 0;
    HEAP32[$47 >> 2] = $49;
    HEAP32[$args + 12 >> 2] = $jt_0;
    HEAP32[$jtp >> 2] = $jt_0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 10:
    var $53 = HEAP32[$1 >> 2];
    var $55 = HEAP32[$args + 8 >> 2];
    if (($53 | 0) == ($55 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$args + 12 >> 2] = $1;
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    if (($55 | 0) < ($53 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $62 = $1 + 8 | 0;
    var $63 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $62);
    var $balanceDelta_0 = -$63 | 0;
    __label__ = 15;
    break;
   case 14:
    var $66 = $1 + 12 | 0;
    var $67 = __ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget($args, $66);
    var $balanceDelta_0 = $67;
    __label__ = 15;
    break;
   case 15:
    var $balanceDelta_0;
    if ((HEAP32[$args + 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $73 = $1 + 4 | 0;
    var $75 = HEAP32[$73 >> 2] + $balanceDelta_0 | 0;
    HEAP32[$73 >> 2] = $75;
    if (($balanceDelta_0 | 0) == 0 | ($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $79 = __ZL18BalanceJumpTargetsPP12JSJumpTarget($jtp);
    var $_0 = 1 - $79 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget["X"] = 1;

function _js_GetStackUses($cs_0_1_val, $op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_1_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_1_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetVariableStackUses($op, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi1190($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev($this) {
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev($this);
  return;
}

function __ZN2js9AtomDeclsD1Ev($this) {
  __ZN2js9AtomDeclsD2Ev($this);
  return;
}

function __ZN2js9AtomDeclsD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    var $7 = __ZN9JSContext12parseMapPoolEv($6);
    __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE($7, $2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE($this, $map) {
  var $1 = $map;
  __ZN2js12ParseMapPool7recycleEPv($this, $1);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$this + 4 >> 2];
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($1, $3);
  return;
}

function __ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSGCConstListD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN14JSCGObjectListC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js9AtomDeclsC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK8JSObject7isErrorEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js10ErrorClassE | 0);
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls4initEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN9JSContext12parseMapPoolEv($2);
  var $4 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v($3);
  HEAP32[$this + 4 >> 2] = $4;
  return ($4 | 0) != 0;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext12parseMapPoolEv($cx);
    var $6 = __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v($5);
    HEAP32[$1 >> 2] = $6;
    var $_0 = ($6 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v($this) {
  var $1 = __ZN2js12ParseMapPool8allocateEv($this);
  return $1;
}

function __ZN13JSGCConstListC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js9AtomDeclsC1EP9JSContext($this, $cx) {
  __ZN2js9AtomDeclsC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext($this, $cx) {
  __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext($this, $cx) {
  HEAP32[$this + 4 >> 2] = $cx;
  var $2 = $this | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($2);
  return;
}

function __ZL11exn_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    HEAP32[$objp >> 2] = 0;
    var $6 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZL12JSID_IS_ATOMi1253($id);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = _JSID_TO_STRING1254($id);
    var $14 = HEAP32[$cx + 52 >> 2];
    if (($12 | 0) == (HEAP32[$14 + 210264 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $21 = HEAP32[$6 + 4 >> 2];
    if (($21 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _STRING_TO_JSVAL1211($1, $21);
    var $_06 = $1 | 0;
    var $attrs_0 = 0;
    var $prop_0 = STRING_TABLE._js_message_str | 0;
    var $v_0_0_0$1 = HEAP32[$_06 + 4 >> 2];
    var $v_0_0_0$0 = HEAP32[$_06 >> 2];
    __label__ = 13;
    break;
   case 6:
    if (($12 | 0) == (HEAP32[$14 + 210216 >> 2] | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $31 = HEAP32[$6 + 8 >> 2];
    _STRING_TO_JSVAL1211($2, $31);
    var $_07 = $2 | 0;
    var $st$4$0 = $_07 | 0;
    var $st$4$1 = $_07 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_fileName_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 8:
    if (($12 | 0) == (HEAP32[$14 + 210260 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = HEAP32[$6 + 12 >> 2];
    _INT_TO_JSVAL($3, $39);
    var $_09 = $3 | 0;
    var $st$4$0 = $_09 | 0;
    var $st$4$1 = $_09 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_lineNumber_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 10:
    if (($12 | 0) == (HEAP32[$14 + 210304 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 11:
    var $46 = __ZL18StackTraceToStringP9JSContextP12JSExnPrivate($cx, $6);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$6 + 16 >> 2] = 0;
    _STRING_TO_JSVAL1211($4, $46);
    var $_011 = $4 | 0;
    var $st$4$0 = $_011 | 0;
    var $st$4$1 = $_011 + 4 | 0;
    var $attrs_0 = 1;
    var $prop_0 = STRING_TABLE._js_stack_str | 0;
    var $v_0_0_0$1 = HEAP32[$st$4$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$4$0 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $prop_0;
    var $attrs_0;
    var $_013 = $5 | 0;
    HEAP32[$_013 >> 2] = $v_0_0_0$0;
    HEAP32[$_013 + 4 >> 2] = $v_0_0_0$1;
    var $51 = $cx;
    var $52 = $obj;
    var $53 = _JS_DefineProperty($51, $52, $prop_0, $5, 0, 0, $attrs_0);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11exn_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZL12exn_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    __ZN9JSContext5free_EPv(undef, $8);
    __label__ = 4;
    break;
   case 4:
    var $10 = $1;
    __ZN9JSContext5free_EPv(undef, $10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9exn_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13GetExnPrivateP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$1 + 4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($8, $5, undef);
    __label__ = 4;
    break;
   case 4:
    var $11 = HEAP32[$1 + 8 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($14, $11, undef);
    __label__ = 6;
    break;
   case 6:
    var $16 = $1 + 16 | 0;
    if ((HEAP32[$16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = $trc + 4 | 0;
    var $21 = $trc;
    var $elem_012 = $1 + 24 | 0;
    var $vcount_013 = 0;
    var $i_014 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_014;
    var $vcount_013;
    var $elem_012;
    var $24 = HEAP32[$elem_012 >> 2];
    if (($24 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($21, $24, undef);
    __label__ = 10;
    break;
   case 10:
    if ((HEAP32[$20 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $31 = HEAP32[$elem_012 + 8 >> 2];
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __Z21js_MarkScriptFilenamePKc($31);
    __label__ = 13;
    break;
   case 13:
    var $36 = HEAP32[$elem_012 + 4 >> 2] + $vcount_013 | 0;
    var $37 = $i_014 + 1 | 0;
    if (($37 | 0) == (HEAP32[$16 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $elem_012 = $elem_012 + 16 | 0;
      var $vcount_013 = $36;
      var $i_014 = $37;
      __label__ = 8;
      break;
    }
   case 14:
    if (($36 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $42 = __ZL24GetStackTraceValueBufferP12JSExnPrivate($1);
    var $i_110 = 0;
    var $vp_011 = $42;
    __label__ = 16;
    break;
   case 16:
    var $vp_011;
    var $i_110;
    var $vp_03_0 = $vp_011 | 0;
    var $tmp$0 = HEAP32[$vp_03_0 >> 2];
    var $tmp$1 = HEAP32[$vp_03_0 + 4 >> 2];
    var $44 = _JSVAL_IS_TRACEABLE($tmp$0, $tmp$1);
    if (($44 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $47 = _JSVAL_TO_GCTHING($tmp$0, $tmp$1);
    var $48 = _JSVAL_TRACE_KIND($tmp$0, $tmp$1);
    _JS_CallTracer($21, $47, $48);
    __label__ = 18;
    break;
   case 18:
    var $50 = $i_110 + 1 | 0;
    if (($50 | 0) == ($36 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $i_110 = $50;
      var $vp_011 = $vp_011 + 8 | 0;
      __label__ = 16;
      break;
    }
   case 19:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9exn_traceP8JSTracerP8JSObject["X"] = 1;

function __Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE($cx, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $2 = _JSVAL_IS_PRIMITIVE($tmp$0, $tmp$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = _JSVAL_TO_OBJECT1203($tmp$0, $tmp$1);
    var $6 = __ZNK8JSObject7isErrorEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZL13GetExnPrivateP8JSObject($5);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = HEAP32[$8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL1252($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT1203($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL1225($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL13GetExnPrivateP8JSObject($obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  return $2;
}

function __ZL12exn_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $localroots = __stackBase__;
    var $tvr = __stackBase__ + 24;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $lineno = __stackBase__ + 56;
    var $3 = $localroots | 0;
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$7$0 = $$emscripten$temp$0 | 0;
    var $4$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $$emscripten$temp$0 + 4 | 0;
    var $4$1 = HEAP32[$st$7$1 >> 2];
    var $5 = $localroots | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    var $6 = $localroots + 8 | 0;
    HEAP32[$6 >> 2] = $4$0;
    HEAP32[$6 + 4 >> 2] = $4$1;
    var $7 = $localroots + 16 | 0;
    HEAP32[$7 >> 2] = $4$0;
    HEAP32[$7 + 4 >> 2] = $4$1;
    var $8 = $vp + 8 | 0;
    var $9 = $cx;
    var $10 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $8);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 210272 >> 2];
    var $18 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($10, $9, $17, $vp);
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = $cx;
    var $22 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $vp);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setStringEP8JSString($vp, $22);
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $9, 3, $3);
    var $25 = _JS_GetProperty($9, $10, STRING_TABLE._js_message_str | 0, $3);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $28 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($21, $3);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL1211($1, $28);
    var $31 = $1 | 0;
    var $st$2$0 = $31 | 0;
    var $32$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $31 + 4 | 0;
    var $32$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$5 >> 2] = $32$0;
    HEAP32[$5 + 4 >> 2] = $32$1;
    var $33 = $localroots + 8 | 0;
    var $34 = _JS_GetProperty($9, $10, STRING_TABLE._js_fileName_str | 0, $33);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $37 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($21, $33);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    _STRING_TO_JSVAL1211($2, $37);
    var $40 = $2 | 0;
    var $st$2$0 = $40 | 0;
    var $41$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$2$1 >> 2];
    var $42 = $33 | 0;
    var $st$7$0 = $42 | 0;
    HEAP32[$st$7$0 >> 2] = $41$0;
    var $st$7$1 = $42 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $41$1;
    var $43 = $localroots + 16 | 0;
    var $44 = _JS_GetProperty($9, $10, STRING_TABLE._js_lineNumber_str | 0, $43);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($9, $43, $lineno);
    if ($47) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 10:
    if ((HEAP32[$lineno >> 2] | 0) == 0) {
      var $lineno_length_0 = 0;
      var $lineno_as_str_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $43);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $55 = __ZNK8JSString6lengthEv($52);
    var $lineno_length_0 = $55;
    var $lineno_as_str_0 = $52;
    __label__ = 13;
    break;
   case 13:
    var $lineno_as_str_0;
    var $lineno_length_0;
    var $57 = __ZNK8JSString6lengthEv($22);
    var $58 = __ZNK8JSString6lengthEv($28);
    var $60 = $58 + ($57 + 8) | 0;
    var $61 = __ZNK8JSString6lengthEv($37);
    var $62 = ($61 | 0) != 0;
    if ($62) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $65 = $61 + ($60 + 2) | 0;
    if (($lineno_as_str_0 | 0) == 0) {
      var $length_0 = $65;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0 = $65 + ($lineno_length_0 + 2) | 0;
    __label__ = 18;
    break;
   case 16:
    if (($lineno_as_str_0 | 0) == 0) {
      var $length_0 = $60;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $length_0 = $60 + ($lineno_length_0 + 6) | 0;
    __label__ = 18;
    break;
   case 18:
    var $length_0;
    var $78 = __ZN9JSContext7malloc_Ej($9, ($length_0 << 1) + 2 | 0);
    var $79 = $78;
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $83 = $78 + 2 | 0;
    HEAP16[$79 >> 1] = 40;
    var $85 = $78 + 4 | 0;
    HEAP16[$83 >> 1] = 110;
    var $87 = $78 + 6 | 0;
    HEAP16[$85 >> 1] = 101;
    var $89 = $78 + 8 | 0;
    HEAP16[$87 >> 1] = 119;
    var $90 = $78 + 10 | 0;
    HEAP16[$89 >> 1] = 32;
    var $91 = __ZN8JSString8getCharsEP9JSContext($22, $9);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $94 = $90;
    var $95 = $91;
    var $96 = $57 << 1;
    _memcpy($90, $95, $96, 1);
    var $_sum = $57 + 1 | 0;
    var $98 = $94 + ($_sum << 1) | 0;
    HEAP16[$94 + ($57 << 1) >> 1] = 40;
    var $99 = __ZN8JSString8getCharsEP9JSContext($28, $9);
    if (($99 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($58 | 0) == 0) {
      var $cp_0 = $98;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $104 = $98;
    var $105 = $99;
    var $106 = $58 << 1;
    _memcpy($104, $105, $106, 1);
    var $cp_0 = $94 + ($_sum + $58 << 1) | 0;
    __label__ = 23;
    break;
   case 23:
    var $cp_0;
    if ($62) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    HEAP16[$cp_0 >> 1] = 44;
    HEAP16[$cp_0 + 2 >> 1] = 32;
    var $111 = __ZN8JSString8getCharsEP9JSContext($37, $9);
    if (($111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if (($lineno_as_str_0 | 0) == 0) {
      var $cp_2 = $cp_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP16[$cp_0 >> 1] = 44;
    HEAP16[$cp_0 + 2 >> 1] = 32;
    HEAP16[$cp_0 + 4 >> 1] = 34;
    HEAP16[$cp_0 + 6 >> 1] = 34;
    var $cp_15 = $cp_0 + 8 | 0;
    __label__ = 28;
    break;
   case 27:
    var $122 = $111;
    var $123 = $61 << 1;
    _memcpy($cp_0 + 4 | 0, $122, $123, 1);
    var $124 = $cp_0 + ($61 + 2 << 1) | 0;
    if (($lineno_as_str_0 | 0) == 0) {
      var $cp_2 = $124;
      __label__ = 30;
      break;
    } else {
      var $cp_15 = $124;
      __label__ = 28;
      break;
    }
   case 28:
    var $cp_15;
    HEAP16[$cp_15 >> 1] = 44;
    HEAP16[$cp_15 + 2 >> 1] = 32;
    var $128 = __ZN8JSString8getCharsEP9JSContext($lineno_as_str_0, $9);
    if (($128 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $133 = $128;
    _memcpy($cp_15 + 4 | 0, $133, $lineno_length_0 << 1, 1);
    var $cp_2 = $cp_15 + ($lineno_length_0 + 2 << 1) | 0;
    __label__ = 30;
    break;
   case 30:
    var $cp_2;
    HEAP16[$cp_2 >> 1] = 41;
    HEAP16[$cp_2 + 2 >> 1] = 41;
    HEAP16[$cp_2 + 4 >> 1] = 0;
    var $138 = __Z12js_NewStringP9JSContextPtj($21, $79, $length_0);
    if (($138 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN9JSContext5free_EPv(undef, $78);
    var $_0 = 0;
    __label__ = 33;
    break;
   case 32:
    var $142 = $138 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $142);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12exn_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12exn_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 52 | 0;
    var $10 = HEAP32[HEAP32[$6 >> 2] + 210272 >> 2];
    var $11 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($3, $2, $10, $v);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $v | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = _JSVAL_IS_STRING($15$0, $15$1);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $st$0$0 = $14 | 0;
    var $19$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $19$1 = HEAP32[$st$0$1 >> 2];
    var $20 = _JSVAL_TO_STRING($19$0, $19$1);
    var $27 = $20;
    __label__ = 6;
    break;
   case 5:
    var $27 = HEAP32[HEAP32[$6 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 6:
    var $27;
    __ZN2JS5Value9setStringEP8JSString($vp, $27);
    var $28 = _JS_GetProperty($2, $3, STRING_TABLE._js_message_str | 0, $v);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $st$0$0 = $14 | 0;
    var $31$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $31$1 = HEAP32[$st$0$1 >> 2];
    var $32 = _JSVAL_IS_STRING($31$0, $31$1);
    if (($32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $st$0$0 = $14 | 0;
    var $35$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $14 + 4 | 0;
    var $35$1 = HEAP32[$st$0$1 >> 2];
    var $36 = _JSVAL_TO_STRING($35$0, $35$1);
    var $43 = $36;
    __label__ = 10;
    break;
   case 9:
    var $43 = HEAP32[HEAP32[$6 >> 2] + 144136 >> 2] | 0;
    __label__ = 10;
    break;
   case 10:
    var $43;
    var $44 = __ZNK8JSString6lengthEv($43);
    if (($44 | 0) == 0) {
      var $result_0 = $27;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $47 = __ZNK8JSString6lengthEv($27);
    var $48 = $47 + 2 | 0;
    var $49 = ($47 | 0) != 0;
    var $_ = $49 ? $48 : 0;
    var $50 = $_ + $44 | 0;
    var $52 = ($50 << 1) + 2 | 0;
    var $53 = __ZN9JSContext7malloc_Ej($2, $52);
    var $54 = $53;
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($49) {
      __label__ = 13;
      break;
    } else {
      var $cp_0 = $54;
      __label__ = 15;
      break;
    }
   case 13:
    var $58 = __ZN8JSString8getCharsEP9JSContext($27, $2);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $61 = $58;
    var $62 = $47 << 1;
    _memcpy($53, $61, $62, 1);
    var $64 = $54 + ($47 + 1 << 1) | 0;
    HEAP16[$54 + ($47 << 1) >> 1] = 58;
    var $65 = $54 + ($48 << 1) | 0;
    HEAP16[$64 >> 1] = 32;
    var $cp_0 = $65;
    __label__ = 15;
    break;
   case 15:
    var $cp_0;
    var $67 = __ZN8JSString8getCharsEP9JSContext($43, $2);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $71 = $67;
    var $72 = $44 << 1;
    _memcpy($cp_0, $71, $72, 1);
    HEAP16[$cp_0 + ($44 << 1) >> 1] = 0;
    var $74 = $cx;
    var $75 = __Z12js_NewStringP9JSContextPtj($74, $54, $50);
    var $76 = $75 | 0;
    if (($75 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $result_0 = $76;
      __label__ = 18;
      break;
    }
   case 17:
    __ZN9JSContext5free_EPv(undef, $53);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 18:
    var $result_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $result_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12exn_toStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z23js_InitExceptionClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectProto = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $objectProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$objectProto >> 2];
    var $11 = __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $3, 0, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $cx;
    var $15 = $11;
    var $16 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($14, $15, 0, __ZL17exception_methods);
    if ($16) {
      var $i_0 = 1;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if (($i_0 | 0) < 8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $19 = __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $3, $i_0, $11);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject($cx, $global, $type, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $empty = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __ZL20GetExceptionProtoKeyi($type);
    var $5 = $cx + 52 | 0;
    var $8 = HEAP32[HEAP32[$5 >> 2] + 210020 + ($4 << 2) >> 2];
    var $9 = $global;
    var $10 = $cx;
    var $11 = $proto;
    var $12 = __ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject($9, $10, __ZN2js10ErrorClassE, $11);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $19 = HEAP32[HEAP32[$5 >> 2] + 144136 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString1239($empty, $19);
    var $20 = HEAP32[$5 >> 2];
    var $23 = HEAP32[$20 + 210272 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom1223($23);
    var $26 = HEAP32[$20 + 210264 >> 2];
    var $29 = HEAP32[$20 + 210216 >> 2] | 0;
    var $30 = __ZL12ATOM_TO_JSIDP6JSAtom1223($29);
    var $33 = HEAP32[$20 + 210260 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom1223($33);
    var $35 = $8 | 0;
    __ZN2JSL11StringValueEP8JSString1239($1, $35);
    var $36 = $cx;
    var $37 = $12;
    var $38 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $24, $1, 10, 12, 0, 0, 0, 0);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $41 = $26 | 0;
    var $42 = __ZL12ATOM_TO_JSIDP6JSAtom1223($41);
    var $43 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $42, $empty, 10, 12, 0, 0, 0, 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $46 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $30, $empty, 10, 12, 1, 0, 0, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL10Int32ValueEi1240($2, 0);
    var $49 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($36, $37, $34, $2, 10, 12, 1, 0, 0, 0);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $52 = $8;
    var $53 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($9, $10, 104, __ZN2js10ErrorClassE, $52, 1);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL10Int32ValueEi1240($3, $type);
    var $56 = $53;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($56, 0, $3);
    var $57 = $53 | 0;
    var $58 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($10, $57, $12);
    if ($58) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $60 = $cx;
    var $61 = $global;
    var $62 = $12;
    var $63 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($60, $61, $4, $56, $62);
    var $_ = $63 ? $13 : 0;
    var $_0 = $_;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject["X"] = 1;

function __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($cx, $userRef, $locale, $errorNumber) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 36 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = FUNCTION_TABLE[$6]($userRef, $locale, $errorNumber);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $errorString_1 = $9;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __Z18js_GetErrorMessagePvPKcj(undef, undef, $errorNumber);
    var $errorString_1 = $11;
    __label__ = 5;
    break;
   case 5:
    var $errorString_1;
    return $errorString_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetExceptionProtoKeyi($exn) {
  return $exn + 14 | 0;
}

function __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($cx, $message, $reportp, $callback, $userRef) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $errProto = __stackBase__ + 32;
    var $tvr = __stackBase__ + 36;
    var $1 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $3 = __stackBase__ + 68;
    var $4 = __stackBase__ + 76;
    var $5 = __stackBase__ + 84;
    var $6 = $reportp + 24 | 0;
    if ((HEAP32[$6 >> 2] & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    var $12 = HEAP32[$reportp + 28 >> 2];
    if (($callback | 0) == 0 | ($callback | 0) == 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = __Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj($cx, 0, 0, $12);
    var $errorString_0 = $16;
    __label__ = 5;
    break;
   case 4:
    var $18 = FUNCTION_TABLE[$callback]($userRef, 0, $12);
    var $errorString_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $errorString_0;
    if (($errorString_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAP16[$errorString_0 + 6 >> 1];
    var $24 = $23 << 16 >> 16;
    if ($23 << 16 >> 16 == -1) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $cx + 44 | 0;
    if (HEAP8[$27] << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 8:
    HEAP8[$27] = 1;
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_($tv);
    var $31 = $tv | 0;
    var $32 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $32, 4, $31);
    var $33 = __ZL20GetExceptionProtoKeyi($24);
    var $34 = $cx;
    var $35 = $errProto;
    var $36 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($34, 0, $33, $35, 0);
    if (($36 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = HEAP32[$errProto >> 2];
    _OBJECT_TO_JSVAL1210($1, $39);
    var $40 = $1 | 0;
    var $41$0 = HEAP32[$40 >> 2];
    var $41$1 = HEAP32[$40 + 4 >> 2];
    var $42 = $tv | 0;
    HEAP32[$42 >> 2] = $41$0;
    HEAP32[$42 + 4 >> 2] = $41$1;
    var $43 = $39;
    var $44 = __ZNK8JSObject9getParentEv($43);
    var $45 = $44;
    var $46 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $39, $45);
    if (($46 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL1210($2, $46);
    var $49 = $2 | 0;
    var $st$2$0 = $49 | 0;
    var $50$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $49 + 4 | 0;
    var $50$1 = HEAP32[$st$2$1 >> 2];
    var $51 = $tv + 8 | 0;
    var $st$7$0 = $51 | 0;
    HEAP32[$st$7$0 >> 2] = $50$0;
    var $st$7$1 = $51 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $50$1;
    var $52 = _JS_NewStringCopyZ($32, $message);
    if (($52 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _STRING_TO_JSVAL1211($3, $52);
    var $55 = $3 | 0;
    var $st$2$0 = $55 | 0;
    var $56$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $55 + 4 | 0;
    var $56$1 = HEAP32[$st$2$1 >> 2];
    var $57 = $tv + 16 | 0;
    var $st$7$0 = $57 | 0;
    HEAP32[$st$7$0 >> 2] = $56$0;
    var $st$7$1 = $57 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $56$1;
    var $59 = HEAP32[$reportp >> 2];
    var $60 = _JS_NewStringCopyZ($32, $59);
    if (($60 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _STRING_TO_JSVAL1211($4, $60);
    var $63 = $4 | 0;
    var $st$2$0 = $63 | 0;
    var $64$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $63 + 4 | 0;
    var $64$1 = HEAP32[$st$2$1 >> 2];
    var $65 = $tv + 24 | 0;
    var $st$7$0 = $65 | 0;
    HEAP32[$st$7$0 >> 2] = $64$0;
    var $st$7$1 = $65 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $64$1;
    var $67 = HEAP32[$reportp + 4 >> 2];
    var $68 = __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $46, $52, $60, $67, $reportp, $24);
    var $69 = $68 & 1;
    if ($68) {
      __label__ = 13;
      break;
    } else {
      var $ok_0 = $69;
      __label__ = 14;
      break;
    }
   case 13:
    _OBJECT_TO_JSVAL1210($5, $46);
    _JS_SetPendingException($32, $5);
    var $72 = HEAP32[$6 >> 2] | 2;
    HEAP32[$6 >> 2] = $72;
    var $ok_0 = $69;
    __label__ = 14;
    break;
   case 14:
    var $ok_0;
    HEAP8[$27] = 0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_0 = $ok_0;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function _OBJECT_TO_JSVAL1210($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL1238($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js10ErrorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1230($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231($cx, $proto, $parent, $4);
  return $5;
}

function _STRING_TO_JSVAL1211($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL1229($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $exnObject, $message, $filename, $lineno, $report, $exnType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 120;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $frames = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $values = __stackBase__ + 28;
    var $2 = __stackBase__ + 52;
    var $seg = __stackBase__ + 56;
    var $i = __stackBase__ + 68;
    var $v = __stackBase__ + 108;
    var $3 = __stackBase__ + 116;
    var $4 = $cx;
    var $5 = _JS_GetSecurityCallbacks($4);
    if (($5 | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$5 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    var $12 = $1;
    __ZN2js15TempAllocPolicyC1EP9JSContext($12, $4);
    __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_($frames, $1);
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $4);
    var $13 = $values;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($13, $2);
    __ZN19SuppressErrorsGuardC1EP9JSContext($seg, $cx);
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $4, 0);
    var $14 = $cx + 56 | 0;
    var $15 = ($11 | 0) == 0;
    var $16 = $cx + 52 | 0;
    var $17 = $cx;
    __label__ = 4;
    break;
   case 4:
    var $19 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($19) {
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $22 = $21;
    var $23 = __ZNK2js10StackFrame11compartmentEv($22);
    if (($23 | 0) == (HEAP32[$14 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 6:
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($21);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN2JSL9NullValueEv1222($v);
    var $33 = HEAP32[HEAP32[$16 >> 2] + 210196 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom1223($33);
    var $35 = __ZNK2js10StackFrame6calleeEv($21);
    var $36 = $35;
    var $37 = FUNCTION_TABLE[$11]($cx, $36, $34, 4, $v);
    if (($37 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj($frames, 1);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 10:
    var $42 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv($frames);
    var $43 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($21);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $45 = __ZNK2js10StackFrame3funEv($21);
    var $46 = $45 + 72 | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_in = $46;
    __label__ = 14;
    break;
   case 13:
    var $_in = HEAP32[$16 >> 2] + 144136 | 0;
    __label__ = 14;
    break;
   case 14:
    var $_in;
    var $56 = HEAP32[$_in >> 2] | 0;
    HEAP32[$42 >> 2] = $56;
    var $58 = __ZNK2js10StackFrame13numActualArgsEv($21);
    HEAP32[$42 + 4 >> 2] = $58;
    __ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($3, $values);
    var $60 = __ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj($22, $3, 0, -1);
    if ($60) {
      __label__ = 16;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    HEAP32[$42 >> 2] = 0;
    HEAP32[$42 + 4 >> 2] = 0;
    __label__ = 16;
    break;
   case 16:
    var $65 = __ZNK2js10StackFrame13isScriptFrameEv($21);
    if ($65) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $67 = __ZNK2js10StackFrame6scriptEv($21);
    var $69 = HEAP32[$67 + 52 >> 2];
    HEAP32[$42 + 8 >> 2] = $69;
    var $71 = __ZNK2js13FrameRegsIter2pcEv($i);
    var $72 = $21;
    var $73 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($17, $72, $71);
    HEAP32[$42 + 12 >> 2] = $73;
    __label__ = 19;
    break;
   case 18:
    HEAP32[$42 + 12 >> 2] = 0;
    HEAP32[$42 + 8 >> 2] = 0;
    __label__ = 19;
    break;
   case 19:
    var $79 = __ZN2js13FrameRegsIterppEv($i);
    __label__ = 4;
    break;
   case 20:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $81 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames);
    var $82 = $81 << 4;
    var $83 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($13);
    var $86 = $82 + 24 + ($83 << 3) | 0;
    var $87 = __ZN9JSContext7malloc_Ej($4, $86);
    if (($87 | 0) == 0) {
      var $_1 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($report | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $92 = __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $report);
    HEAP32[$87 >> 2] = $92;
    if (($92 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    __ZN9JSContext5free_EPv(undef, $87);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 24:
    HEAP32[$87 >> 2] = 0;
    __label__ = 25;
    break;
   case 25:
    HEAP32[$87 + 4 >> 2] = $message;
    HEAP32[$87 + 8 >> 2] = $filename;
    HEAP32[$87 + 12 >> 2] = $lineno;
    var $105 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames);
    HEAP32[$87 + 16 >> 2] = $105;
    HEAP32[$87 + 20 >> 2] = $exnType;
    var $111 = $87 + 24 | 0;
    var $112 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($frames);
    var $114 = $111 + ($112 << 4) | 0;
    var $115 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv($frames);
    __ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j($111, $115, $112);
    var $116 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($13);
    var $117 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv($13);
    __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224($114, $116, $117);
    var $118 = $exnObject;
    __ZN8JSObject10setPrivateEPv($118, $87);
    var $_1 = 1;
    __label__ = 28;
    break;
   case 26:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 27:
    __ZN19SuppressErrorsGuardD1Ev($seg);
    var $_1 = 0;
    __label__ = 28;
    break;
   case 28:
    var $_1;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($13);
    __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev($frames);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti["X"] = 1;

function __Z26js_ReportUncaughtExceptionP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 140;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exn = __stackBase__;
    var $roots = __stackBase__ + 8;
    var $report = __stackBase__ + 48;
    var $tvr = __stackBase__ + 88;
    var $1 = __stackBase__ + 104;
    var $bytesStorage = __stackBase__ + 112;
    var $2 = __stackBase__ + 116;
    var $filename = __stackBase__ + 124;
    var $lineno = __stackBase__ + 128;
    var $3 = __stackBase__ + 132;
    var $4 = $cx;
    var $5 = _JS_IsExceptionPending($4);
    if (($5 | 0) == 0) {
      var $_2 = 1;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _JS_GetPendingException($4, $exn);
    if (($8 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_($roots);
    var $11 = $roots | 0;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $4, 5, $11);
    var $12 = $exn | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = _JSVAL_IS_PRIMITIVE($13$0, $13$1);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $exnObject_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = _JSVAL_TO_OBJECT1203($13$0, $13$1);
    var $18 = $roots | 0;
    var $st$2$0 = $18 | 0;
    HEAP32[$st$2$0 >> 2] = $13$0;
    var $st$2$1 = $18 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $13$1;
    var $exnObject_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $exnObject_0;
    _JS_ClearPendingException($4);
    var $20 = $1 | 0;
    HEAP32[$20 >> 2] = $13$0;
    HEAP32[$20 + 4 >> 2] = $13$1;
    var $21 = __Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE(undef, $1);
    var $22 = $cx;
    var $23 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($22, $exn);
    __ZN16JSAutoByteStringC1Ev($bytesStorage);
    if (($23 | 0) == 0) {
      var $bytes_0 = STRING_TABLE.__str1193 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL1211($2, $23);
    var $26 = $2 | 0;
    var $st$2$0 = $26 | 0;
    var $27$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$2$1 >> 2];
    var $28 = $roots + 8 | 0;
    var $st$7$0 = $28 | 0;
    HEAP32[$st$7$0 >> 2] = $27$0;
    var $st$7$1 = $28 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $27$1;
    var $29 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytesStorage, $4, $23);
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZNK16JSAutoByteString3ptrEv($bytesStorage);
    var $bytes_0 = $32;
    __label__ = 8;
    break;
   case 8:
    var $bytes_0;
    __ZN16JSAutoByteStringC1Ev($filename);
    if (($21 | 0) != 0 | ($exnObject_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZNK8JSObject7isErrorEv($exnObject_0);
    if ($37) {
      __label__ = 10;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 10:
    var $39 = $roots + 16 | 0;
    var $40 = $exnObject_0;
    var $41 = _JS_GetProperty($4, $40, STRING_TABLE._js_message_str | 0, $39);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $39 | 0;
    var $45$0 = HEAP32[$44 >> 2];
    var $45$1 = HEAP32[$44 + 4 >> 2];
    var $46 = _JSVAL_IS_STRING($45$0, $45$1);
    if (($46 | 0) == 0) {
      var $bytes_1 = $bytes_0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN16JSAutoByteString5clearEv($bytesStorage);
    var $49 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($bytesStorage, $4, $23);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = __ZNK16JSAutoByteString3ptrEv($bytesStorage);
    var $bytes_1 = $52;
    __label__ = 14;
    break;
   case 14:
    var $bytes_1;
    var $54 = $roots + 24 | 0;
    var $55 = _JS_GetProperty($4, $40, STRING_TABLE._js_fileName_str | 0, $54);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($22, $54);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $61 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($filename, $4, $58);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = $roots + 32 | 0;
    var $65 = _JS_GetProperty($4, $40, STRING_TABLE._js_lineNumber_str | 0, $64);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($4, $64, $lineno);
    if ($68) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 19:
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214($report);
    var $70 = __ZNK16JSAutoByteString3ptrEv($filename);
    HEAP32[$report >> 2] = $70;
    var $72 = HEAP32[$lineno >> 2];
    HEAP32[$report + 4 >> 2] = $72;
    var $st$7$0 = $44 | 0;
    var $74$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $44 + 4 | 0;
    var $74$1 = HEAP32[$st$7$1 >> 2];
    var $75 = _JSVAL_IS_STRING($74$0, $74$1);
    if (($75 | 0) == 0) {
      var $bytes_21 = $bytes_1;
      var $reportp_02 = $report;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $78$0 = HEAP32[$44 >> 2];
    var $78$1 = HEAP32[$44 + 4 >> 2];
    var $79 = _JSVAL_TO_STRING($78$0, $78$1);
    var $80 = __ZN8JSString11ensureFixedEP9JSContext($79, $4);
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $83 = $80 | 0;
    var $84 = __ZNK14JSLinearString5charsEv($83);
    HEAP32[$report + 32 >> 2] = $84;
    var $bytes_21 = $bytes_1;
    var $reportp_02 = $report;
    __label__ = 24;
    break;
   case 22:
    if (($21 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $bytes_21 = $bytes_0;
      var $reportp_02 = $21;
      __label__ = 24;
      break;
    }
   case 23:
    _JS_ReportErrorNumber($4, 2, 0, 147, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $bytes_0, tempInt));
    var $_0 = 1;
    __label__ = 25;
    break;
   case 24:
    var $reportp_02;
    var $bytes_21;
    var $89 = $reportp_02 + 24 | 0;
    var $91 = HEAP32[$89 >> 2] | 2;
    HEAP32[$89 >> 2] = $91;
    var $92$0 = HEAP32[$12 >> 2];
    var $92$1 = HEAP32[$12 + 4 >> 2];
    var $93 = $3 | 0;
    HEAP32[$93 >> 2] = $92$0;
    HEAP32[$93 + 4 >> 2] = $92$1;
    _JS_SetPendingException($4, $3);
    __Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport($4, $bytes_21, $reportp_02);
    _JS_ClearPendingException($4);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($filename);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    __ZN16JSAutoByteStringD1Ev($bytesStorage);
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_2 = $_1;
    __label__ = 27;
    break;
   case 27:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z26js_ReportUncaughtExceptionP9JSContext["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function _JSVAL_IS_STRING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL1221($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN16JSAutoByteString5clearEv($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  __ZN2js10Foreground5free_EPv($2);
  HEAP32[$1 >> 2] = 0;
  return;
}

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function _JSVAL_TO_STRING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL1217($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_($cx, $errobj, $scope) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $autoFree = __stackBase__;
    var $messageAnchor = __stackBase__ + 8;
    var $filenameAnchor = __stackBase__ + 12;
    var $proto = __stackBase__ + 16;
    var $1 = $cx;
    var $2 = __ZL13GetExnPrivateP8JSObject($errobj);
    var $4 = HEAP32[$2 + 16 >> 2];
    if (($4 | 0) == 0) {
      var $valueCount_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $valueCount_01 = 0;
      var $i_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_02;
    var $valueCount_01;
    var $8 = HEAP32[$2 + 24 + ($i_02 << 4) + 4 >> 2] + $valueCount_01 | 0;
    var $9 = $i_02 + 1 | 0;
    if (($9 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $valueCount_01 = $8;
      var $i_02 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    var $valueCount_0_lcssa = $8 << 3;
    __label__ = 4;
    break;
   case 4:
    var $valueCount_0_lcssa;
    var $13 = ($4 << 4) + 24 + $valueCount_0_lcssa | 0;
    var $14 = __ZN9JSContext7malloc_Ej($1, $13);
    if (($14 | 0) == 0) {
      var $_3 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $14;
    HEAP32[$autoFree >> 2] = $cx;
    var $19 = $autoFree + 4 | 0;
    HEAP32[$19 >> 2] = $17;
    var $21 = HEAP32[$2 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $21);
    var $25 = $14;
    HEAP32[$25 >> 2] = $24;
    if (($24 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $28 = $14;
    HEAP32[$28 >> 2] = 0;
    __label__ = 8;
    break;
   case 8:
    var $31 = HEAP32[$2 + 4 >> 2];
    var $33 = $14 + 4 | 0;
    HEAP32[$33 >> 2] = $31;
    var $34 = $cx + 56 | 0;
    var $36 = HEAP32[$34 >> 2];
    var $37 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($36, $1, $33);
    if ($37) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    var $39 = HEAP32[$33 >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($messageAnchor, $39);
    var $41 = HEAP32[$2 + 8 >> 2];
    var $43 = $14 + 8 | 0;
    HEAP32[$43 >> 2] = $41;
    var $45 = HEAP32[$34 >> 2];
    var $46 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($45, $1, $43);
    if ($46) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    var $48 = HEAP32[$43 >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($filenameAnchor, $48);
    var $50 = HEAP32[$2 + 12 >> 2];
    var $52 = $14 + 12 | 0;
    HEAP32[$52 >> 2] = $50;
    var $54 = $14 + 16 | 0;
    HEAP32[$54 >> 2] = 0;
    var $56 = HEAP32[$2 + 20 >> 2];
    var $58 = $14 + 20 | 0;
    HEAP32[$58 >> 2] = $56;
    var $59 = $scope;
    var $60 = __ZNK8JSObject9getGlobalEv($59);
    var $61 = __ZL20GetExceptionProtoKeyi($56);
    var $62 = $cx;
    var $63 = $60 | 0;
    var $64 = $proto;
    var $65 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($62, $63, $61, $64, 0);
    if (($65 | 0) == 0) {
      var $_2 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $68 = HEAP32[$proto >> 2];
    var $69 = $68;
    var $70 = __ZNK8JSObject9getParentEv($69);
    var $71 = $70;
    var $72 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $68, $71);
    var $73 = $72;
    __ZN8JSObject10setPrivateEPv($73, $14);
    HEAP32[$19 >> 2] = 0;
    var $_2 = $72;
    __label__ = 12;
    break;
   case 12:
    var $_2;
    __ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev($autoFree);
    var $_3 = $_2;
    __label__ = 13;
    break;
   case 13:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_["X"] = 1;

function __ZL14JSID_FROM_BITSj1226($bits) {
  return $bits;
}

function _JSVAL_TO_STRING_IMPL1217($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL1221($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_TO_OBJECT_IMPL1225($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 4) | 0;
}

function __ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values) {
  HEAP32[$this >> 2] = $values;
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 4) | 0;
}

function __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _STRING_TO_JSVAL_IMPL1229($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1230($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL_IMPL1238($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL15CopyErrorReportP9JSContextP13JSErrorReport($cx, $report) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $report | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _strlen($2);
    var $8 = $5 + 1 | 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    var $9 = $report + 8 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _strlen($10);
    var $16 = $13 + 1 | 0;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $17 = $report + 16 | 0;
    var $18 = HEAP32[$17 >> 2];
    if (($18 | 0) == 0) {
      var $25 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __Z9js_strlenPKt($18);
    var $25 = ($21 << 1) + 2 | 0;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $26 = $report + 32 | 0;
    var $27 = HEAP32[$26 >> 2];
    if (($27 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 0;
      var $ucmessageSize_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __Z9js_strlenPKt($27);
    var $32 = ($30 << 1) + 2 | 0;
    var $34 = HEAP32[$report + 36 >> 2];
    if (($34 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 0;
      var $ucmessageSize_0 = $32;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = HEAP32[$34 >> 2];
    if (($36 | 0) == 0) {
      var $argsCopySize_1 = 0;
      var $argsArraySize_0 = 4;
      var $ucmessageSize_0 = $32;
      __label__ = 12;
      break;
    } else {
      var $i_01 = 0;
      var $argsCopySize_02 = 0;
      var $38 = $36;
      __label__ = 10;
      break;
    }
   case 10:
    var $38;
    var $argsCopySize_02;
    var $i_01;
    var $39 = __Z9js_strlenPKt($38);
    var $42 = $argsCopySize_02 + 2 + ($39 << 1) | 0;
    var $43 = $i_01 + 1 | 0;
    var $45 = HEAP32[$34 + ($43 << 2) >> 2];
    if (($45 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i_01 = $43;
      var $argsCopySize_02 = $42;
      var $38 = $45;
      __label__ = 10;
      break;
    }
   case 11:
    var $argsCopySize_1 = $42;
    var $argsArraySize_0 = ($43 << 2) + 4 | 0;
    var $ucmessageSize_0 = $32;
    __label__ = 12;
    break;
   case 12:
    var $ucmessageSize_0;
    var $argsArraySize_0;
    var $argsCopySize_1;
    var $48 = $argsArraySize_0 + 40 | 0;
    var $54 = $cx;
    var $55 = __ZN9JSContext7malloc_Ej($54, $16 + $8 + $25 + $ucmessageSize_0 + $argsCopySize_1 + $48 | 0);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $58 = $55;
    _memset($55, 0, 40, 1);
    var $59 = $55 + 40 | 0;
    if (($argsArraySize_0 | 0) == 0) {
      var $cursor_1 = $59;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $62 = $59;
    var $64 = $55 + 36 | 0;
    HEAP32[$64 >> 2] = $62;
    var $65 = $55 + $48 | 0;
    var $66 = $report + 36 | 0;
    if ((HEAP32[HEAP32[$66 >> 2] >> 2] | 0) == 0) {
      var $i_1_lcssa = 0;
      var $cursor_0_lcssa = $65;
      var $86 = $62;
      __label__ = 16;
      break;
    } else {
      var $i_14 = 0;
      var $cursor_05 = $65;
      var $70 = $62;
      __label__ = 15;
      break;
    }
   case 15:
    var $70;
    var $cursor_05;
    var $i_14;
    HEAP32[$70 + ($i_14 << 2) >> 2] = $cursor_05;
    var $75 = HEAP32[HEAP32[$66 >> 2] + ($i_14 << 2) >> 2];
    var $76 = __Z9js_strlenPKt($75);
    var $78 = ($76 << 1) + 2 | 0;
    var $79 = $75;
    _memcpy($cursor_05, $79, $78, 1);
    var $80 = $cursor_05 + $78 | 0;
    var $81 = $i_14 + 1 | 0;
    var $_pre = HEAP32[$64 >> 2];
    if ((HEAP32[HEAP32[$66 >> 2] + ($81 << 2) >> 2] | 0) == 0) {
      var $i_1_lcssa = $81;
      var $cursor_0_lcssa = $80;
      var $86 = $_pre;
      __label__ = 16;
      break;
    } else {
      var $i_14 = $81;
      var $cursor_05 = $80;
      var $70 = $_pre;
      __label__ = 15;
      break;
    }
   case 16:
    var $86;
    var $cursor_0_lcssa;
    var $i_1_lcssa;
    HEAP32[$86 + ($i_1_lcssa << 2) >> 2] = 0;
    var $cursor_1 = $cursor_0_lcssa;
    __label__ = 17;
    break;
   case 17:
    var $cursor_1;
    if ((HEAP32[$26 >> 2] | 0) == 0) {
      var $cursor_2 = $cursor_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    HEAP32[$55 + 32 >> 2] = $cursor_1;
    var $96 = HEAP32[$26 >> 2];
    _memcpy($cursor_1, $96, $ucmessageSize_0, 1);
    var $cursor_2 = $cursor_1 + $ucmessageSize_0 | 0;
    __label__ = 19;
    break;
   case 19:
    var $cursor_2;
    if ((HEAP32[$17 >> 2] | 0) == 0) {
      var $cursor_3 = $cursor_2;
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $104 = $55 + 16 | 0;
    HEAP32[$104 >> 2] = $cursor_2;
    var $106 = HEAP32[$17 >> 2];
    _memcpy($cursor_2, $106, $25, 1);
    var $107 = $cursor_2 + $25 | 0;
    var $109 = HEAP32[$report + 20 >> 2];
    if (($109 | 0) == 0) {
      var $cursor_3 = $107;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $118 = HEAP32[$104 >> 2] + ($109 - HEAP32[$17 >> 2] >> 1 << 1) | 0;
    HEAP32[$55 + 20 >> 2] = $118;
    var $cursor_3 = $107;
    __label__ = 22;
    break;
   case 22:
    var $cursor_3;
    if ((HEAP32[$9 >> 2] | 0) == 0) {
      var $cursor_4 = $cursor_3;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $126 = $55 + 8 | 0;
    HEAP32[$126 >> 2] = $cursor_3;
    var $127 = HEAP32[$9 >> 2];
    _memcpy($cursor_3, $127, $16, 1);
    var $128 = $cursor_3 + $16 | 0;
    var $130 = HEAP32[$report + 12 >> 2];
    if (($130 | 0) == 0) {
      var $cursor_4 = $128;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $138 = HEAP32[$126 >> 2] + ($130 - HEAP32[$9 >> 2]) | 0;
    HEAP32[$55 + 12 >> 2] = $138;
    var $cursor_4 = $128;
    __label__ = 25;
    break;
   case 25:
    var $cursor_4;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    HEAP32[$55 >> 2] = $cursor_4;
    var $146 = HEAP32[$1 >> 2];
    _memcpy($cursor_4, $146, $8, 1);
    __label__ = 27;
    break;
   case 27:
    var $149 = HEAP32[$report + 4 >> 2];
    HEAP32[$55 + 4 >> 2] = $149;
    var $153 = HEAP32[$report + 28 >> 2];
    HEAP32[$55 + 28 >> 2] = $153;
    var $157 = HEAP32[$report + 24 >> 2];
    HEAP32[$55 + 24 >> 2] = $157;
    var $_0 = $58;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15CopyErrorReportP9JSContextP13JSErrorReport["X"] = 1;

function __ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    __ZN9JSContext5free_EPv(undef, $7);
    var $9 = HEAP32[$1 >> 2];
    __ZN9JSContext5free_EPv(undef, $9);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN19SuppressErrorsGuardC1EP9JSContext($this, $cx) {
  __ZN19SuppressErrorsGuardC2EP9JSContext($this, $cx);
  return;
}

function __ZNK2js10StackFrame11compartmentEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  var $3 = $2;
  var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
  return $4;
}

function __ZN2JSL9NullValueEv1222($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom1223($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1226($1);
  return $2;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj($this, $incr) {
  var $1 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 16 | 0;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj($this, $op, $start, $count) {
  var __stackBase__ = STACKTOP;
  var tempParam = $op;
  $op = STACKTOP;
  STACKTOP += 4;
  HEAP32[$op >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10StackFrame3funEv($1);
    var $5 = HEAPU16[$2 + 56 >> 1] & 65535;
    var $6 = __ZNK2js10StackFrame13formalArgsEndEv($1);
    var $7 = __ZNK2js10StackFrame13numActualArgsEv($1);
    var $_02 = ($count | 0) == -1 ? $7 - $start | 0 : $count;
    var $10 = $_02 + $start | 0;
    var $12 = $6 + ($start - $5 << 3) | 0;
    if ($10 >>> 0 > $5 >>> 0) {
      var $_1 = $start;
      var $p1_0 = $12;
      __label__ = 5;
      break;
    } else {
      var $_01 = $start;
      var $p_0 = $12;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_0;
    var $_01;
    if ($_01 >>> 0 < $10 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    var $15 = __ZN9AppendArgclEjPN2JS5ValueE($op, undef, $p_0);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $_01 = $_01 + 1 | 0;
    var $p_0 = $p_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    var $p1_0;
    var $_1;
    if ($_1 >>> 0 < $5 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $21 = __ZN9AppendArgclEjPN2JS5ValueE($op, undef, $p1_0);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $_1 = $_1 + 1 | 0;
    var $p1_0 = $p1_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    var $p2_0 = $6 + (-2 - $5 - $7 + $_1 << 3) | 0;
    var $_2 = $_1;
    __label__ = 9;
    break;
   case 9:
    var $_2;
    var $p2_0;
    if ($_2 >>> 0 < $10 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 10:
    var $31 = __ZN9AppendArgclEjPN2JS5ValueE($op, undef, $p2_0);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $p2_0 = $p2_0 + 8 | 0;
    var $_2 = $_2 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values) {
  __ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE($this, $values);
  return;
}

function __ZN19SuppressErrorsGuardD1Ev($this) {
  __ZN19SuppressErrorsGuardD2Ev($this);
  return;
}

function __ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 4) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_03;
    var $6 = $_012;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $7 = $_012 + 16 | 0;
    if (($7 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $7;
      var $_03 = $_03 + 16 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $11 = $dst;
    var $12 = $src;
    var $13 = $nelem << 4;
    _memcpy($11, $12, $13, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $_03 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN19SuppressErrorsGuardD2Ev($this) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2];
  var $6 = HEAP32[$this + 8 >> 2];
  _JS_RestoreExceptionState($5, $6);
  var $10 = HEAP32[$1 >> 2];
  var $11 = HEAP32[$this + 4 >> 2];
  var $12 = _JS_SetErrorReporter($10, $11);
  return;
}

function __ZN9AppendArgclEjPN2JS5ValueE($this, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $2 = __stackBase__;
  var $4 = HEAP32[$this >> 2];
  var $5 = $vp | 0;
  var $6$0 = HEAP32[$5 >> 2];
  var $6$1 = HEAP32[$5 + 4 >> 2];
  var $7 = $2 | 0;
  HEAP32[$7 >> 2] = $6$0;
  HEAP32[$7 + 4 >> 2] = $6$1;
  var $8 = $4;
  var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($8, $2);
  STACKTOP = __stackBase__;
  return $9;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    var $12 = $11 + ($incr << 4) | 0;
    __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_($11, $12);
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $p_01;
    HEAP32[$4 >> 2] = 0;
    HEAP32[$4 + 4 >> 2] = 0;
    HEAP32[$4 + 8 >> 2] = 0;
    HEAP32[$4 + 12 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $6 = $p_01 + 16 | 0;
    if (($6 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $6;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 4;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $newcap << 4;
    var $3 = $v;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    HEAP32[$13 + 8 >> 2] = 0;
    HEAP32[$13 + 12 >> 2] = 0;
    __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $14 = __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($1);
    var $15 = $14;
    HEAP32[$13 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$13 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    HEAP32[$13 + 12 >> 2] = HEAP32[$15 + 12 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $17 = $dst_01 + 16 | 0;
    var $18 = $src_02 + 16 | 0;
    var $19 = __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($18 | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      __label__ = 3;
      break;
    }
   case 6:
    var $21 = $v + 4 | 0;
    var $23 = HEAP32[$21 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $23);
    HEAP32[$21 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($this, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_($this, $t);
  return;
}

function __ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    HEAP32[$5 + 8 >> 2] = 0;
    HEAP32[$5 + 12 >> 2] = 0;
    __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $6 = __ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev($1);
    var $7 = $6;
    HEAP32[$5 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$7 + 12 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9 = $p_01 + 16 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 16 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_($agg_result, $t);
  return;
}

function __ZN19SuppressErrorsGuardC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  var $3 = $cx;
  var $4 = _JS_SetErrorReporter($3, 0);
  HEAP32[$2 >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = _JS_SaveExceptionState($3);
  HEAP32[$6 >> 2] = $7;
  return;
}

function __ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js10ErrorClassE, $3, $10, 0, (__ZN2js10ErrorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js10ErrorClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1239($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1240($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _JSID_IS_STRING1247($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSVAL_IS_PRIMITIVE_IMPL1252($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSID_TO_STRING1254($iden) {
  return $iden;
}

function _JSVAL_TO_GCTHING_IMPL1256($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_TRACEABLE_IMPL1257($l_0$0, $l_0$1) {
  var $2 = $l_0$1;
  return (($2 | 0) == -123 | ($2 | 0) == -121) & 1;
}

function _INT32_TO_JSVAL_IMPL1251($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL24GetStackTraceValueBufferP12JSExnPrivate($priv) {
  return $priv + 24 + (HEAP32[$priv + 16 >> 2] << 4) | 0;
}

function _JS_GetAnonymousString($rt) {
  return HEAP32[$rt + 210168 >> 2] | 0;
}

function _JS_GetCompartmentPrincipals($compartment) {
  return HEAP32[$compartment + 4 >> 2];
}

function __ZN2JS23AutoPreserveCompartmentC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN2JS23AutoPreserveCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $5 = HEAP32[$this >> 2] + 56 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZL9ExceptionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $protov = __stackBase__ + 8;
    var $iter = __stackBase__ + 16;
    var $lineno = __stackBase__ + 56;
    var $1 = __stackBase__ + 60;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($args, $argc, $vp);
    var $2 = $args | 0;
    var $3 = __ZNK2js12CallReceiver6calleeEv($2);
    var $4 = $cx + 52 | 0;
    var $8 = $cx;
    var $9 = HEAP32[HEAP32[$4 >> 2] + 210200 >> 2];
    var $10 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($3, $8, $9, $protov);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZNK2JS5Value8isObjectEv($protov);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($8, 2, 0, 135, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_Error_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 27;
    break;
   case 4:
    var $16 = __ZNK2JS5Value8toObjectEv($protov);
    var $17 = $16;
    var $18 = __ZNK8JSObject9getParentEv($16);
    var $19 = $18;
    var $20 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_($cx, $17, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = __ZNK2js8CallArgs4argcEv($args);
    if (($23 | 0) == 0) {
      var $message_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = __ZNK2js8CallArgsixEj($args, 0);
    var $27 = __ZNK2JS5Value11isUndefinedEv($26);
    if ($27) {
      var $message_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = $cx;
    var $30 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($29, $26);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $33 = __ZNK2js8CallArgsixEj($args, 0);
    __ZN2JS5Value9setStringEP8JSString($33, $30);
    var $message_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $message_0;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $8, 0);
    __label__ = 10;
    break;
   case 10:
    var $36 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $39 = __ZNK2js10StackFrame13isScriptFrameEv($38);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 10;
    break;
   case 13:
    var $42 = __ZNK2js8CallArgs4argcEv($args);
    if ($42 >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $45 = __ZNK2js8CallArgsixEj($args, 1);
    var $46 = $cx;
    var $47 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($46, $45);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = __ZNK2js8CallArgsixEj($args, 1);
    __ZN2JS5Value9setStringEP8JSString($50, $47);
    var $filename_0 = $47;
    __label__ = 19;
    break;
   case 16:
    if ($36) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $54 = __ZNK2js10StackFrame6scriptEv($53);
    var $56 = HEAP32[$54 + 52 >> 2];
    var $57 = __ZL16FilenameToStringP9JSContextPKc($cx, $56);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      var $filename_0 = $57;
      __label__ = 19;
      break;
    }
   case 18:
    var $filename_0 = HEAP32[HEAP32[$4 >> 2] + 144136 >> 2] | 0;
    __label__ = 19;
    break;
   case 19:
    var $filename_0;
    var $65 = __ZNK2js8CallArgs4argcEv($args);
    if ($65 >>> 0 > 2) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $68 = __ZNK2js8CallArgsixEj($args, 2);
    var $69 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($8, $68, $lineno);
    if ($69) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 21:
    var $81 = HEAP32[$lineno >> 2];
    __label__ = 25;
    break;
   case 22:
    var $71 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($71) {
      var $79 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $73 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $74 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $75 = $cx;
    var $76 = $73;
    var $77 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($75, $76, $74);
    var $79 = $77;
    __label__ = 24;
    break;
   case 24:
    var $79;
    HEAP32[$lineno >> 2] = $79;
    var $81 = $79;
    __label__ = 25;
    break;
   case 25:
    var $81;
    var $82 = __ZNK2js12CallReceiver6calleeEv($2);
    __ZNK8JSObject15getReservedSlotEj($1, $82, 0);
    var $83 = __ZNK2JS5Value7toInt32Ev($1);
    var $84 = __ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti($cx, $20, $message_0, $filename_0, $81, 0, $83);
    if ($84) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 26:
    var $86 = __ZNK2js12CallReceiver4rvalEv($2);
    var $87 = $20;
    __ZN2JS5Value9setObjectER8JSObject($86, $87);
    var $_0 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ExceptionP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16FilenameToStringP9JSContextPKc($cx, $filename) {
  var $1 = $cx;
  var $2 = _JS_NewStringCopyZ($1, $filename);
  return $2;
}

function __ZL12JSID_IS_ATOMi1253($id) {
  var $1 = _JSID_IS_STRING1247($id);
  return $1;
}

function _INT_TO_JSVAL($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL1251($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout1228($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL18StackTraceToStringP9JSContextP12JSExnPrivate($cx, $priv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ulnbuf = __stackBase__;
    var $1 = __ZL24GetStackTraceValueBufferP12JSExnPrivate($priv);
    var $5 = $priv + 24 + (HEAP32[$priv + 16 >> 2] << 4) | 0;
    var $6 = $cx;
    var $7 = $ulnbuf | 0;
    var $stackbuf_0 = 0;
    var $stacklen_0 = 0;
    var $stackmax_0 = 0;
    var $elem_0 = $priv + 24 | 0;
    var $values_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $values_0;
    var $elem_0;
    var $stackmax_0;
    var $stacklen_0;
    var $stackbuf_0;
    if (($elem_0 | 0) == ($5 | 0)) {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$elem_0 >> 2];
    if (($12 | 0) == 0) {
      var $stackbuf_8 = $stackbuf_0;
      var $stacklen_3 = $stacklen_0;
      var $stackmax_8 = $stackmax_0;
      var $values_2 = $values_0;
      __label__ = 37;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK8JSString6lengthEv($12);
    var $16 = __ZN8JSString8getCharsEP9JSContext($12, $6);
    if (($16 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_0;
      __label__ = 71;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($15 >>> 0 > ($stackmax_0 - $stacklen_0 | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $stackbuf_1 = $stackbuf_0;
    var $stackmax_1 = $stackmax_0;
    var $_pre_phi = $15 + $stacklen_0 | 0;
    __label__ = 11;
    break;
   case 7:
    if ($stackmax_0 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($15 >>> 0 < (1048576 - $stacklen_0 | 0) >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $stackbuf_17 = $stackbuf_0;
      var $stacklen_7 = $stacklen_0;
      var $stackmax_17 = $stackmax_0;
      __label__ = 64;
      break;
    }
   case 9:
    var $27 = $15 + $stacklen_0 | 0;
    var $28 = _JS_CeilingLog2($27);
    var $29 = 1 << $28;
    var $32 = ($29 << 1) + 2 | 0;
    var $33 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_0, $32);
    if (($33 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_0;
      __label__ = 71;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $stackbuf_1 = $33;
    var $stackmax_1 = $29;
    var $_pre_phi = $27;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $stackmax_1;
    var $stackbuf_1;
    var $40 = $16;
    var $41 = $15 << 1;
    _memcpy($stackbuf_1 + ($stacklen_0 << 1) | 0, $40, $41, 1);
    if (($_pre_phi | 0) == ($stackmax_1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $stackbuf_2 = $stackbuf_1;
      var $stackmax_2 = $stackmax_1;
      __label__ = 15;
      break;
    }
   case 12:
    if ($stackmax_1 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_1;
      var $stacklen_7 = $_pre_phi;
      var $stackmax_17 = $stackmax_1;
      __label__ = 64;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_ = ($stackmax_1 | 0) == 0 ? 64 : $stackmax_1 << 1;
    var $51 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_1, $_ << 1 | 2);
    if (($51 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_1;
      __label__ = 71;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $stackbuf_2 = $51;
    var $stackmax_2 = $_;
    __label__ = 15;
    break;
   case 15:
    var $stackmax_2;
    var $stackbuf_2;
    HEAP16[$stackbuf_2 + ($_pre_phi << 1) >> 1] = 40;
    var $58 = $elem_0 + 4 | 0;
    var $stackbuf_3 = $stackbuf_2;
    var $stacklen_1 = $_pre_phi + 1 | 0;
    var $stackmax_3 = $stackmax_2;
    var $i_0 = 0;
    var $values_1 = $values_0;
    __label__ = 16;
    break;
   case 16:
    var $values_1;
    var $i_0;
    var $stackmax_3;
    var $stacklen_1;
    var $stackbuf_3;
    if (($i_0 | 0) == (HEAP32[$58 >> 2] | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if (($i_0 | 0) == 0) {
      var $stackbuf_5 = $stackbuf_3;
      var $stacklen_2 = $stacklen_1;
      var $stackmax_5 = $stackmax_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($stacklen_1 | 0) == ($stackmax_3 | 0)) {
      __label__ = 19;
      break;
    } else {
      var $stackbuf_4 = $stackbuf_3;
      var $stackmax_4 = $stackmax_3;
      __label__ = 22;
      break;
    }
   case 19:
    if ($stackmax_3 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_3;
      var $stacklen_7 = $stacklen_1;
      var $stackmax_17 = $stackmax_3;
      __label__ = 64;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_1 = ($stackmax_3 | 0) == 0 ? 64 : $stackmax_3 << 1;
    var $74 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_3, $_1 << 1 | 2);
    if (($74 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_3;
      __label__ = 71;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $stackbuf_4 = $74;
    var $stackmax_4 = $_1;
    __label__ = 22;
    break;
   case 22:
    var $stackmax_4;
    var $stackbuf_4;
    HEAP16[$stackbuf_4 + ($stacklen_1 << 1) >> 1] = 44;
    var $stackbuf_5 = $stackbuf_4;
    var $stacklen_2 = $stacklen_1 + 1 | 0;
    var $stackmax_5 = $stackmax_4;
    __label__ = 23;
    break;
   case 23:
    var $stackmax_5;
    var $stacklen_2;
    var $stackbuf_5;
    var $82 = __ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE($cx, $values_1);
    if (($82 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $85 = __ZNK8JSString6lengthEv($82);
    var $86 = __ZN8JSString8getCharsEP9JSContext($82, $6);
    if (($86 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($85 >>> 0 > ($stackmax_5 - $stacklen_2 | 0) >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $stackbuf_6 = $stackbuf_5;
    var $stackmax_6 = $stackmax_5;
    var $_pre_phi15 = $85 + $stacklen_2 | 0;
    __label__ = 31;
    break;
   case 27:
    if ($stackmax_5 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_5;
      var $stacklen_7 = $stacklen_2;
      var $stackmax_17 = $stackmax_5;
      __label__ = 64;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ($85 >>> 0 < (1048576 - $stacklen_2 | 0) >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $stackbuf_17 = $stackbuf_5;
      var $stacklen_7 = $stacklen_2;
      var $stackmax_17 = $stackmax_5;
      __label__ = 64;
      break;
    }
   case 29:
    var $97 = $85 + $stacklen_2 | 0;
    var $98 = _JS_CeilingLog2($97);
    var $99 = 1 << $98;
    var $102 = ($99 << 1) + 2 | 0;
    var $103 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_5, $102);
    if (($103 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_5;
      __label__ = 71;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $stackbuf_6 = $103;
    var $stackmax_6 = $99;
    var $_pre_phi15 = $97;
    __label__ = 31;
    break;
   case 31:
    var $_pre_phi15;
    var $stackmax_6;
    var $stackbuf_6;
    var $110 = $86;
    var $111 = $85 << 1;
    _memcpy($stackbuf_6 + ($stacklen_2 << 1) | 0, $110, $111, 1);
    var $stackbuf_3 = $stackbuf_6;
    var $stacklen_1 = $_pre_phi15;
    var $stackmax_3 = $stackmax_6;
    var $i_0 = $i_0 + 1 | 0;
    var $values_1 = $values_1 + 8 | 0;
    __label__ = 16;
    break;
   case 32:
    if (($stacklen_1 | 0) == ($stackmax_3 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $stackbuf_7 = $stackbuf_3;
      var $stackmax_7 = $stackmax_3;
      __label__ = 36;
      break;
    }
   case 33:
    if ($stackmax_3 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_3;
      var $stacklen_7 = $stacklen_1;
      var $stackmax_17 = $stackmax_3;
      __label__ = 64;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $_2 = ($stackmax_3 | 0) == 0 ? 64 : $stackmax_3 << 1;
    var $124 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_3, $_2 << 1 | 2);
    if (($124 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_3;
      __label__ = 71;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $stackbuf_7 = $124;
    var $stackmax_7 = $_2;
    __label__ = 36;
    break;
   case 36:
    var $stackmax_7;
    var $stackbuf_7;
    HEAP16[$stackbuf_7 + ($stacklen_1 << 1) >> 1] = 41;
    var $stackbuf_8 = $stackbuf_7;
    var $stacklen_3 = $stacklen_1 + 1 | 0;
    var $stackmax_8 = $stackmax_7;
    var $values_2 = $values_1;
    __label__ = 37;
    break;
   case 37:
    var $values_2;
    var $stackmax_8;
    var $stacklen_3;
    var $stackbuf_8;
    if (($stacklen_3 | 0) == ($stackmax_8 | 0)) {
      __label__ = 38;
      break;
    } else {
      var $stackbuf_9 = $stackbuf_8;
      var $stackmax_9 = $stackmax_8;
      __label__ = 41;
      break;
    }
   case 38:
    if ($stackmax_8 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_8;
      var $stacklen_7 = $stacklen_3;
      var $stackmax_17 = $stackmax_8;
      __label__ = 64;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $_3 = ($stackmax_8 | 0) == 0 ? 64 : $stackmax_8 << 1;
    var $141 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_8, $_3 << 1 | 2);
    if (($141 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_8;
      __label__ = 71;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $stackbuf_9 = $141;
    var $stackmax_9 = $_3;
    __label__ = 41;
    break;
   case 41:
    var $stackmax_9;
    var $stackbuf_9;
    var $146 = $stacklen_3 + 1 | 0;
    HEAP16[$stackbuf_9 + ($stacklen_3 << 1) >> 1] = 64;
    var $149 = HEAP32[$elem_0 + 8 >> 2];
    if (($149 | 0) == 0) {
      var $stackbuf_12 = $stackbuf_9;
      var $stacklen_5 = $146;
      var $stackmax_12 = $stackmax_9;
      __label__ = 48;
      break;
    } else {
      var $cp_0 = $149;
      var $stackbuf_10 = $stackbuf_9;
      var $stacklen_4 = $146;
      var $stackmax_10 = $stackmax_9;
      __label__ = 42;
      break;
    }
   case 42:
    var $stackmax_10;
    var $stacklen_4;
    var $stackbuf_10;
    var $cp_0;
    var $151 = HEAPU8[$cp_0];
    if ($151 << 24 >> 24 == 0) {
      var $stackbuf_12 = $stackbuf_10;
      var $stacklen_5 = $stacklen_4;
      var $stackmax_12 = $stackmax_10;
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if (($stacklen_4 | 0) == ($stackmax_10 | 0)) {
      __label__ = 44;
      break;
    } else {
      var $stackbuf_11 = $stackbuf_10;
      var $stackmax_11 = $stackmax_10;
      var $168 = $151;
      __label__ = 47;
      break;
    }
   case 44:
    if ($stackmax_10 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_10;
      var $stacklen_7 = $stacklen_4;
      var $stackmax_17 = $stackmax_10;
      __label__ = 64;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $_4 = ($stackmax_10 | 0) == 0 ? 64 : $stackmax_10 << 1;
    var $163 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_10, $_4 << 1 | 2);
    if (($163 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_10;
      __label__ = 71;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $stackbuf_11 = $163;
    var $stackmax_11 = $_4;
    var $168 = HEAP8[$cp_0];
    __label__ = 47;
    break;
   case 47:
    var $168;
    var $stackmax_11;
    var $stackbuf_11;
    HEAP16[$stackbuf_11 + ($stacklen_4 << 1) >> 1] = $168 << 24 >> 24;
    var $cp_0 = $cp_0 + 1 | 0;
    var $stackbuf_10 = $stackbuf_11;
    var $stacklen_4 = $stacklen_4 + 1 | 0;
    var $stackmax_10 = $stackmax_11;
    __label__ = 42;
    break;
   case 48:
    var $stackmax_12;
    var $stacklen_5;
    var $stackbuf_12;
    if (($stacklen_5 | 0) == ($stackmax_12 | 0)) {
      __label__ = 49;
      break;
    } else {
      var $stackbuf_13 = $stackbuf_12;
      var $stackmax_13 = $stackmax_12;
      __label__ = 52;
      break;
    }
   case 49:
    if ($stackmax_12 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_12;
      var $stacklen_7 = $stacklen_5;
      var $stackmax_17 = $stackmax_12;
      __label__ = 64;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $_5 = ($stackmax_12 | 0) == 0 ? 64 : $stackmax_12 << 1;
    var $182 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_12, $_5 << 1 | 2);
    if (($182 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_12;
      __label__ = 71;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $stackbuf_13 = $182;
    var $stackmax_13 = $_5;
    __label__ = 52;
    break;
   case 52:
    var $stackmax_13;
    var $stackbuf_13;
    HEAP16[$stackbuf_13 + ($stacklen_5 << 1) >> 1] = 58;
    var $189 = HEAP32[$elem_0 + 12 >> 2];
    var $190 = _JS_snprintf($7, 11, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $189, tempInt));
    var $cp_1 = $7;
    var $stackbuf_14 = $stackbuf_13;
    var $stacklen_6_in = $stacklen_5;
    var $stackmax_14 = $stackmax_13;
    __label__ = 53;
    break;
   case 53:
    var $stackmax_14;
    var $stacklen_6_in;
    var $stackbuf_14;
    var $cp_1;
    var $stacklen_6 = $stacklen_6_in + 1 | 0;
    var $192 = HEAPU8[$cp_1];
    var $194 = ($stacklen_6 | 0) == ($stackmax_14 | 0);
    if ($192 << 24 >> 24 == 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    if ($194) {
      __label__ = 55;
      break;
    } else {
      var $stackbuf_15 = $stackbuf_14;
      var $stackmax_15 = $stackmax_14;
      var $209 = $192;
      __label__ = 58;
      break;
    }
   case 55:
    if ($stackmax_14 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_14;
      var $stacklen_7 = $stacklen_6;
      var $stackmax_17 = $stackmax_14;
      __label__ = 64;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $_6 = ($stackmax_14 | 0) == 0 ? 64 : $stackmax_14 << 1;
    var $204 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_14, $_6 << 1 | 2);
    if (($204 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_14;
      __label__ = 71;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $stackbuf_15 = $204;
    var $stackmax_15 = $_6;
    var $209 = HEAP8[$cp_1];
    __label__ = 58;
    break;
   case 58:
    var $209;
    var $stackmax_15;
    var $stackbuf_15;
    HEAP16[$stackbuf_15 + ($stacklen_6 << 1) >> 1] = $209 << 24 >> 24;
    var $cp_1 = $cp_1 + 1 | 0;
    var $stackbuf_14 = $stackbuf_15;
    var $stacklen_6_in = $stacklen_6;
    var $stackmax_14 = $stackmax_15;
    __label__ = 53;
    break;
   case 59:
    if ($194) {
      __label__ = 60;
      break;
    } else {
      var $stackbuf_16 = $stackbuf_14;
      var $stackmax_16 = $stackmax_14;
      __label__ = 63;
      break;
    }
   case 60:
    if ($stackmax_14 >>> 0 > 1048575) {
      var $stackbuf_17 = $stackbuf_14;
      var $stacklen_7 = $stacklen_6;
      var $stackmax_17 = $stackmax_14;
      __label__ = 64;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $_7 = ($stackmax_14 | 0) == 0 ? 64 : $stackmax_14 << 1;
    var $222 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_14, $_7 << 1 | 2);
    if (($222 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_14;
      __label__ = 71;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $stackbuf_16 = $222;
    var $stackmax_16 = $_7;
    __label__ = 63;
    break;
   case 63:
    var $stackmax_16;
    var $stackbuf_16;
    HEAP16[$stackbuf_16 + ($stacklen_6 << 1) >> 1] = 10;
    var $stackbuf_0 = $stackbuf_16;
    var $stacklen_0 = $stacklen_6_in + 2 | 0;
    var $stackmax_0 = $stackmax_16;
    var $elem_0 = $elem_0 + 16 | 0;
    var $values_0 = $values_2;
    __label__ = 2;
    break;
   case 64:
    var $stackmax_17;
    var $stacklen_7;
    var $stackbuf_17;
    if (($stacklen_7 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 73;
    break;
   case 66:
    if ($stacklen_7 >>> 0 < $stackmax_17 >>> 0) {
      __label__ = 67;
      break;
    } else {
      var $stackbuf_18 = $stackbuf_17;
      __label__ = 69;
      break;
    }
   case 67:
    var $243 = __ZN9JSContext8realloc_EPvj($6, $stackbuf_17, ($stacklen_7 << 1) + 2 | 0);
    if (($243 | 0) == 0) {
      var $stackbuf_18 = $stackbuf_17;
      __label__ = 69;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $stackbuf_18 = $243;
    __label__ = 69;
    break;
   case 69:
    var $stackbuf_18;
    HEAP16[$stackbuf_18 + ($stacklen_7 << 1) >> 1] = 0;
    var $249 = $cx;
    var $250 = __Z12js_NewStringP9JSContextPtj($249, $stackbuf_18, $stacklen_7);
    if (($250 | 0) == 0) {
      var $stackbuf_19 = $stackbuf_18;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $_0 = $250 | 0;
    __label__ = 73;
    break;
   case 71:
    var $stackbuf_19;
    if (($stackbuf_19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    __ZN9JSContext5free_EPv(undef, $stackbuf_19);
    var $_0 = 0;
    __label__ = 73;
    break;
   case 73:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18StackTraceToStringP9JSContextP12JSExnPrivate["X"] = 1;

function __ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 156;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $ac = __stackBase__ + 4;
    var $buf = __stackBase__ + 56;
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($3, $v);
    var $_1 = $4;
    __label__ = 14;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($v);
    var $7 = $cx;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $7, $6);
    var $8 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject10isFunctionEv($6);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($6);
    var $13 = _JS_GetFunctionId($12);
    HEAP32[$str >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $16 = $cx;
    var $17 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($16, $v);
    HEAP32[$str >> 2] = $17;
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    _JS_ClearPendingException($7);
    var $20 = _JS_NewStringCopyZ($7, STRING_TABLE.__str31196 | 0);
    HEAP32[$str >> 2] = $20;
    var $29 = $20;
    __label__ = 10;
    break;
   case 8:
    var $22 = $buf | 0;
    var $23 = __ZNK8JSObject8getClassEv($6);
    var $25 = HEAP32[$23 >> 2];
    var $26 = _JS_snprintf($22, 100, STRING_TABLE.__str41197 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $25, tempInt));
    var $27 = _JS_NewStringCopyZ($7, $22);
    HEAP32[$str >> 2] = $27;
    var $29 = $27;
    __label__ = 10;
    break;
   case 9:
    __ZN2js15AutoCompartment5leaveEv($ac);
    __label__ = 11;
    break;
   case 10:
    var $29;
    __ZN2js15AutoCompartment5leaveEv($ac);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = HEAP32[$cx + 56 >> 2];
    var $35 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($34, $7, $str);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 13;
    break;
   case 13:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_1 = $_0;
    __label__ = 14;
    break;
   case 14:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE["X"] = 1;

function _JSVAL_IS_TRACEABLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_TRACEABLE_IMPL1257($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_GCTHING($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_GCTHING_IMPL1256($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TRACE_KIND($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1218($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TRACE_KIND_IMPL($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TRACE_KIND_IMPL($l_0$0, $l_0$1) {
  var $1 = _JSVAL_IS_STRING_IMPL1221($l_0$0, $l_0$1);
  return $1;
}

function _JS_FindCompilationScope($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isWrapperEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $obj;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject6unwrapEPj($obj, 0);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $5 = __ZNK8JSObject8getClassEv($_0);
    var $7 = HEAP32[$5 + 76 >> 2];
    if (($7 | 0) == 0) {
      var $_1 = $_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = FUNCTION_TABLE[$7]($cx, $_0);
    var $_1 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_UnwrapObject($obj) {
  var $1 = __ZN8JSObject6unwrapEPj($obj, 0);
  return $1;
}

function _JS_GetFrameScopeChainRaw($fp) {
  var $1 = __ZN2js8ValueifyEP12JSStackFrame($fp);
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  return $2;
}

function _JS_SplicePrototype($cx, $obj, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject16hasSingletonTypeEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _JS_SetPrototype($cx, $obj, $proto);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($obj, $cx, $proto);
    var $_0 = $5 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_NewObjectWithUniqueType($cx, $clasp, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JS_NewObject($cx, $clasp, $proto, $parent);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $cx;
    var $6 = __ZN8JSObject16setSingletonTypeEP9JSContext($4, $5);
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_ObjectCountDynamicSlots($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13hasSlotsArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8numSlotsEv($obj);
    var $4 = __ZNK8JSObject15numDynamicSlotsEj($obj, $3);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject13hasSlotsArrayEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 32 >> 2];
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject10fixedSlotsEv($this);
    var $8 = ($2 | 0) != ($5 | 0);
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject15numDynamicSlotsEj($this, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isDenseArrayEv($this);
    if ($1) {
      var $6 = $capacity;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject13numFixedSlotsEv($this);
    var $6 = $capacity - $3 | 0;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_WrapPropertyDescriptor($cx, $desc) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($2, $cx, $desc);
  return $3 & 1;
}

function __ZN2JS21AutoSwitchCompartmentC2EP9JSContextP13JSCompartment($this, $cx, $newCompartment) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  var $5 = $cx;
  var $6 = $newCompartment;
  __ZN9JSContext14setCompartmentEP13JSCompartment($5, $6);
  return;
}

function __ZN2JS21AutoSwitchCompartmentC2EP9JSContextP8JSObject($this, $cx, $target) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  var $5 = $target;
  var $6 = __ZNK2js2gc4Cell11compartmentEv($5);
  var $7 = $cx;
  var $8 = $6;
  __ZN9JSContext14setCompartmentEP13JSCompartment($7, $8);
  return;
}

function _JS_GetE4XObjectsCreated($0) {
  return HEAP32[_sE4XObjectsCreated >> 2];
}

function _JS_SetProtoCalled($0) {
  return HEAP32[_sSetProtoCalled >> 2];
}

function _JS_GetCustomIteratorCount($cx) {
  return HEAP32[_sCustomIteratorCount >> 2];
}

function _JSID_IS_INT1285($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1286($iden) {
  return $iden >> 1;
}

function __ZN2JS21AutoSwitchCompartmentD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $5 = HEAP32[$this >> 2] + 56 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZNK2js10StackFrame17hasOverriddenArgsEv($this) {
  return (HEAP32[$this >> 2] & 1024 | 0) != 0;
}

function __ZNK2js10StackFrame16isEvalInFunctionEv($this) {
  return (HEAP32[$this >> 2] & 10 | 0) == 10;
}

function __ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE($this, $obj) {
  HEAP32[$this + 8 >> 2] = $obj;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 32768;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2jsL20CallObjectLambdaNameEP10JSFunction($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$fun + 72 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj | 0;
  var $3 = $this | 0;
  var $5 = HEAP32[$3 >> 2] | 540672;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $fp, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $fp;
    var $4 = __ZNK2js10StackFrame7callObjEv($3);
    var $5 = $4;
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2];
    var $10 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($5, $cx, $9, $vp);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $fp);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame16isEvalInFunctionEv($fp);
    if ($2) {
      var $_012 = $fp;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $_012;
    var $3 = __ZNK2js10StackFrame4prevEv($_012);
    var $4 = __ZNK2js10StackFrame16isEvalInFunctionEv($3);
    if ($4) {
      var $_012 = $3;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa;
    var $5 = __ZNK2js10StackFrame6scriptEv($_01_lcssa);
    if ((HEAP8[$5 + 38 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $5);
    __label__ = 5;
    break;
   case 5:
    var $12 = __ZNK2js10StackFrame10hasArgsObjEv($_01_lcssa);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = __ZNK2js10StackFrame7argsObjEv($_01_lcssa);
    var $_0 = $14 | 0;
    __label__ = 12;
    break;
   case 7:
    var $17 = __ZNK2js10StackFrame13numActualArgsEv($_01_lcssa);
    var $18 = __ZNK2js10StackFrame6calleeEv($_01_lcssa);
    var $19 = __ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject($cx, $17, $18);
    var $21 = $19 | 0;
    if (($19 | 0) == 0) {
      var $_0 = $21;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZNK8JSObject17isStrictArgumentsEv($21);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $25 = __ZNK2js15ArgumentsObject4dataEv($19);
    var $26 = $25 + 8 | 0;
    __ZN6PutArgC1EPN2JS5ValueE($1, $26);
    var $27 = __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($_01_lcssa, $1, 0, -1);
    __label__ = 11;
    break;
   case 10:
    var $29 = $19;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($29, $_01_lcssa);
    __label__ = 11;
    break;
   case 11:
    __ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE($_01_lcssa, $19);
    var $_0 = $21;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $fp, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = $fp;
    var $4 = __ZNK2js10StackFrame7callObjEv($3);
    var $5 = $4;
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2];
    var $10 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($5, $cx, $9, $v);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $cx;
    var $16 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($15, $v);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $obj_0 = $17;
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = __ZNK2JS5Value8toObjectEv($v);
    var $obj_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    var $22 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj_0, $cx, $id, $vp);
    var $_0 = $22;
    __label__ = 22;
    break;
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $24 = _JSID_IS_INT1285($id);
    if (($24 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = _JSID_TO_INT1286($id);
    var $28 = __ZNK2js10StackFrame12maybeArgsObjEv($fp);
    var $29 = __ZNK2js10StackFrame13numActualArgsEv($fp);
    var $31 = ($28 | 0) != 0;
    if ($27 >>> 0 < $29 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $34 = __ZNK2js15ArgumentsObject7elementEj($28, $27);
    var $35 = __ZNK2JS5Value7isMagicE10JSWhyMagic($34, undef);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = $28 | 0;
    var $38 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($37, $cx, $id, $vp);
    var $_0 = $38;
    __label__ = 22;
    break;
   case 12:
    var $40 = __ZNK2js10StackFrame14functionScriptEv($fp);
    if ((HEAP8[$40 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = $34 | 0;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = $vp | 0;
    HEAP32[$48 >> 2] = $47$0;
    HEAP32[$48 + 4 >> 2] = $47$1;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 14:
    var $50 = __ZNK2js10StackFrame18canonicalActualArgEj($fp, $27);
    var $51 = $50 | 0;
    var $52$0 = HEAP32[$51 >> 2];
    var $52$1 = HEAP32[$51 + 4 >> 2];
    var $53 = $vp | 0;
    HEAP32[$53 >> 2] = $52$0;
    HEAP32[$53 + 4 >> 2] = $52$1;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 15:
    if ($31) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 16:
    var $56 = $28 | 0;
    var $57 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($56, $cx, $id, $vp);
    var $_0 = $57;
    __label__ = 22;
    break;
   case 17:
    var $63 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $64 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $63);
    if (($64 | 0) == 0) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = __ZNK2js10StackFrame12maybeArgsObjEv($fp);
    if (($67 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $70 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($67);
    if ($70) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $72 = $67 | 0;
    var $73 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($72, $cx, $id, $vp);
    var $_0 = $73;
    __label__ = 22;
    break;
   case 21:
    var $75 = __ZNK2js10StackFrame13numActualArgsEv($fp);
    __ZN2JS5Value8setInt32Ei($vp, $75);
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE["X"] = 1;

function __ZNK2js10StackFrame12maybeArgsObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10hasArgsObjEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame7argsObjEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame14functionScriptEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 8 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZNK2js10StackFrame3funEv($this);
    var $8 = __ZNK10JSFunction6scriptEv($7);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom1293($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject($cx, $argc, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = $callee;
    var $2 = __ZNK8JSObject9getGlobalEv($1);
    var $3 = $cx;
    var $4 = $2 | 0;
    var $5 = $proto;
    var $6 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($3, $4, 1, $5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$proto >> 2];
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($9, $cx, 0, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext($cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = ($argc << 3) + 8 | 0;
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $21;
    var $26 = $21 + 8 | 0;
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288($26, $argc);
    var $27 = __ZNK8JSObject18getFunctionPrivateEv($callee);
    var $28 = __ZNK10JSFunction12inStrictModeEv($27);
    var $29 = $28 ? __ZN2js26StrictArgumentsObjectClassE : __ZN2js26NormalArgumentsObjectClassE;
    var $30 = __ZNK8JSObject9getParentEv($9);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, undef, $29, $10, $30, 0, 0);
    var $31 = $16 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($13, $31);
    var $32 = __ZN8JSObject11asArgumentsEv($13);
    __ZN2js15ArgumentsObject16setInitialLengthEj($32, $argc);
    __ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE($32, $callee, $24);
    var $_0 = $32;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext($cx) {
  var $3 = HEAP32[$cx + 56 >> 2] + 748 | 0;
  var $4 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, __ZN2js26NormalArgumentsObjectClassE, $3);
  return $4;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288($vec, $len) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378($vec, $1);
  return;
}

function __ZN2js15ArgumentsObject16setInitialLengthEj($this, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $length << 1;
  __ZN2JSL10Int32ValueEi1375($1, $3);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE($this, $callee, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $data;
  __ZN2JSL12PrivateValueEPv1335($1, $3);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 1, $1);
  var $4 = $data | 0;
  __ZN2JS5Value9setObjectER8JSObject($4, $callee);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($this, $op, $start, $count) {
  var __stackBase__ = STACKTOP;
  var tempParam = $op;
  $op = STACKTOP;
  STACKTOP += 4;
  HEAP32[$op >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $4 = HEAPU16[$1 + 56 >> 1] & 65535;
    var $5 = __ZNK2js10StackFrame13formalArgsEndEv($this);
    var $6 = __ZNK2js10StackFrame13numActualArgsEv($this);
    var $_02 = ($count | 0) == -1 ? $6 - $start | 0 : $count;
    var $9 = $_02 + $start | 0;
    var $11 = $5 + ($start - $4 << 3) | 0;
    if ($9 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($4 >>> 0 > $start >>> 0) {
      var $p1_013 = $11;
      var $_114 = $start;
      __label__ = 5;
      break;
    } else {
      var $_1_lcssa = $start;
      __label__ = 6;
      break;
    }
   case 3:
    if ($9 >>> 0 > $start >>> 0) {
      var $p_06 = $11;
      var $_017 = $start;
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $_017;
    var $p_06;
    var $14 = __ZN6PutArgclEjPN2JS5ValueE($op, undef, $p_06);
    var $16 = $_017 + 1 | 0;
    if (($16 | 0) == ($9 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $p_06 = $p_06 + 8 | 0;
      var $_017 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    var $_114;
    var $p1_013;
    var $17 = __ZN6PutArgclEjPN2JS5ValueE($op, undef, $p1_013);
    var $19 = $_114 + 1 | 0;
    if (($19 | 0) == ($4 | 0)) {
      var $_1_lcssa = $4;
      __label__ = 6;
      break;
    } else {
      var $p1_013 = $p1_013 + 8 | 0;
      var $_114 = $19;
      __label__ = 5;
      break;
    }
   case 6:
    var $_1_lcssa;
    if ($_1_lcssa >>> 0 < $9 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $_29 = $_1_lcssa;
    var $p2_010 = $5 + (-2 - $4 - $6 + $_1_lcssa << 3) | 0;
    __label__ = 8;
    break;
   case 8:
    var $p2_010;
    var $_29;
    var $24 = __ZN6PutArgclEjPN2JS5ValueE($op, undef, $p2_010);
    var $26 = $_29 + 1 | 0;
    if (($26 | 0) == ($9 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $_29 = $26;
      var $p2_010 = $p2_010 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN6PutArgC1EPN2JS5ValueE($this, $dst) {
  __ZN6PutArgC2EPN2JS5ValueE($this, $dst);
  return;
}

function __Z16js_PutArgsObjectPN2js10StackFrameE($fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $3 = $2;
    var $4 = __ZNK8JSObject17isNormalArgumentsEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js15ArgumentsObject4dataEv($2);
    var $7 = $6 + 8 | 0;
    __ZN6PutArgC1EPN2JS5ValueE($1, $7);
    var $8 = __ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj($fp, $1, 0, -1);
    var $9 = $2;
    __ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE($9, 0);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN8JSObject11asArgumentsEv($obj);
    var $3 = _JSID_IS_INT1285($id);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = _JSID_TO_INT1286($id);
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($2);
    if ($6 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    __ZN2JSL10MagicValueE10JSWhyMagic1374($1);
    __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($2, $6, $1);
    __label__ = 8;
    break;
   case 4:
    var $12 = HEAPU32[$cx + 52 >> 2];
    var $15 = HEAP32[$12 + 210256 >> 2] | 0;
    var $16 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $15);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js15ArgumentsObject20markLengthOverriddenEv($2);
    __label__ = 8;
    break;
   case 6:
    var $22 = HEAP32[$12 + 210192 >> 2] | 0;
    var $23 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $22);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $2 | 0;
    var $27 = __ZN8JSObject17asNormalArgumentsEv($26);
    __ZN2js21NormalArgumentsObject11clearCalleeEv($27);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14args_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $2 = $1 | 0;
    var $3 = __ZNK2js15ArgumentsObject13initialLengthEv($2);
    var $4 = $cx;
    var $5 = $1;
    var $6 = $cx + 52 | 0;
    var $i_0 = -2;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($i_0 | 0) == -2) {
      __label__ = 4;
      break;
    } else if (($i_0 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$6 >> 2] + 210256 >> 2] | 0;
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom1293($14);
    var $25 = $15;
    __label__ = 7;
    break;
   case 5:
    var $20 = HEAP32[HEAP32[$6 >> 2] + 210192 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom1293($20);
    var $25 = $21;
    __label__ = 7;
    break;
   case 6:
    var $23 = _INT_TO_JSID1373($i_0);
    var $25 = $23;
    __label__ = 7;
    break;
   case 7:
    var $25;
    var $26 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($4, $5, $25, $pobj, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12args_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $undef = __stackBase__;
    HEAP32[$objp >> 2] = 0;
    var $1 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $2 = _JSID_IS_INT1285($id);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT1286($id);
    var $6 = $1 | 0;
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($6);
    if ($5 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7elementEj($6, $5);
    var $11 = __ZNK2JS5Value7isMagicE10JSWhyMagic($10, undef);
    if ($11) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 193;
      __label__ = 8;
      break;
    }
   case 4:
    var $14 = HEAPU32[$cx + 52 >> 2];
    var $17 = HEAP32[$14 + 210256 >> 2] | 0;
    var $18 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $17);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $1 | 0;
    var $22 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($21);
    if ($22) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 192;
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = HEAP32[$14 + 210192 >> 2] | 0;
    var $27 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $26);
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = __ZNK2js21NormalArgumentsObject6calleeEv($1);
    var $31 = __ZNK2JS5Value7isMagicE10JSWhyMagic($30, undef);
    if ($31) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      var $attrs_0 = 192;
      __label__ = 8;
      break;
    }
   case 8:
    var $attrs_0;
    __ZN2JSL14UndefinedValueEv1350($undef);
    var $33 = $cx;
    var $34 = $1;
    var $35 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($33, $34, $id, $undef, 110, 112, $attrs_0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$objp >> 2] = $1 | 0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13args_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZN8JSObject11asArgumentsEv($obj);
  var $2 = __ZNK2js15ArgumentsObject4dataEv($1);
  var $3 = $2;
  __ZN9JSContext5free_EPv(undef, $3);
  return;
}

function __ZL10args_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject11asArgumentsEv($obj);
    var $2 = __ZNK2js15ArgumentsObject7onTraceEv($1);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js15ArgumentsObject4dataEv($1);
    var $5 = $4 | 0;
    var $6 = __ZNK2JS5Value8isObjectEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toObjectEv($5);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $8, undef);
    __label__ = 4;
    break;
   case 4:
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($1);
    var $11 = $4 + 8 | 0;
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $10, $11, undef);
    var $12 = $1 | 0;
    __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $12);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20strictargs_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom1293($6);
    var $8 = $cx;
    var $9 = $1;
    var $10 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $7, $pobj, $prop);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = HEAP32[HEAP32[$2 >> 2] + 210192 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom1293($16);
    var $18 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $17, $pobj, $prop);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $24 = HEAP32[HEAP32[$2 >> 2] + 210196 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom1293($24);
    var $26 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $25, $pobj, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $29 = $1 | 0;
    var $30 = __ZNK2js15ArgumentsObject13initialLengthEv($29);
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $30 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $34 = _INT_TO_JSID1373($i_0);
    var $35 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($8, $9, $34, $pobj, $prop);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $undef = __stackBase__;
    HEAP32[$objp >> 2] = 0;
    var $1 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $2 = _JSID_IS_INT1285($id);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT1286($id);
    var $6 = $1 | 0;
    var $7 = __ZNK2js15ArgumentsObject13initialLengthEv($6);
    if ($5 >>> 0 < $7 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 3:
    var $10 = __ZNK2js15ArgumentsObject7elementEj($6, $5);
    var $11 = __ZNK2JS5Value7isMagicE10JSWhyMagic($10, undef);
    if ($11) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $setter_0 = 108;
      var $getter_0 = 106;
      var $attrs_0 = 193;
      __label__ = 9;
      break;
    }
   case 4:
    var $14 = HEAPU32[$cx + 52 >> 2];
    var $17 = HEAP32[$14 + 210256 >> 2] | 0;
    var $18 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $17);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $1 | 0;
    var $22 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($21);
    if ($22) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $setter_0 = 108;
      var $getter_0 = 106;
      var $attrs_0 = 192;
      __label__ = 9;
      break;
    }
   case 6:
    var $26 = HEAP32[$14 + 210192 >> 2] | 0;
    var $27 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $26);
    if (($27 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = HEAP32[$14 + 210196 >> 2] | 0;
    var $33 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $32);
    if (($33 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $1 | 0;
    var $37 = __ZNK8JSObject17getThrowTypeErrorEv($36);
    var $38 = __ZN2jsL16CastAsPropertyOpEP8JSObject1357($37);
    var $39 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($37);
    var $setter_0 = $39;
    var $getter_0 = $38;
    var $attrs_0 = 116;
    __label__ = 9;
    break;
   case 9:
    var $attrs_0;
    var $getter_0;
    var $setter_0;
    __ZN2JSL14UndefinedValueEv1350($undef);
    var $41 = $cx;
    var $42 = $1;
    var $43 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($41, $42, $id, $undef, $getter_0, $setter_0, $attrs_0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$objp >> 2] = $1 | 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $3 = __ZNK2js10StackFrame3funEv($fp);
    var $4 = __ZN2jsL20CallObjectLambdaNameEP10JSFunction($3);
    if (($4 | 0) == 0) {
      var $scopeChain_0 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE($cx, $fp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL12ATOM_TO_JSIDP6JSAtom1293($4);
    var $11 = __ZNK2js10StackFrame6calleeEv($fp);
    __ZN2JSL11ObjectValueER8JSObject1294($1, $11);
    var $12 = $cx;
    var $13 = $7;
    var $14 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($12, $13, $10, $1, 0, 0, 6, 0, 0, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $scopeChain_0 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $scopeChain_0;
    var $17 = __ZNK2js10StackFrame6scriptEv($fp);
    var $18 = __ZNK2js10StackFrame6calleeEv($fp);
    var $19 = __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $17, $scopeChain_0, $18);
    var $20 = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($20, $fp);
    __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($fp, $20);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext($cx);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $8 = $fp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($1, undef, __ZN2js12DeclEnvClassE, __ZN2js5types15emptyTypeObjectE, $7, $8, 0);
    var $9 = $4 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($1, $9);
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom1293($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1372($1);
  return $2;
}

function __ZN2JSL11ObjectValueER8JSObject1294($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($this, $frame) {
  var $1 = $this | 0;
  var $2 = $frame;
  __ZN8JSObject10setPrivateEPv($1, $2);
  return;
}

function __ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame6scriptEv($fp);
    var $2 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $3 = __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $1, $2, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($4, $fp);
    __ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE($fp, $4);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z26js_CreateCallObjectOnTraceP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $callee, $scopeChain) {
  var $1 = __ZNK10JSFunction6scriptEv($fun);
  var $2 = __ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_($cx, $1, $scopeChain, $callee);
  return $2 | 0;
}

function __ZeqRK8JSObjectS1_($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function __ZNK2js8Bindings9countArgsEv($this) {
  return HEAP16[$this + 4 >> 1];
}

function __ZN10JSFunction14compiledFunObjEv($this) {
  return $this | 0;
}

function __ZN8JSObject16hasMethodBarrierEv($this) {
  return (HEAP32[$this + 8 >> 2] & 32 | 0) != 0;
}

function __ZNK2js5Shape7hasSlotEv($this) {
  return (HEAP8[$this + 28 | 0] & 64) << 24 >> 24 == 0;
}

function __ZN8JSObject11clearParentEv($this) {
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN8JSObject9clearTypeEv($this) {
  HEAP32[$this + 36 >> 2] = __ZN2js5types15emptyTypeObjectE;
  return;
}

function __Z16js_PutCallObjectPN2js10StackFrameE($fp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $fp;
    var $3 = __ZNK2js10StackFrame7callObjEv($2);
    var $4 = $3;
    var $5 = __ZN8JSObject6asCallEv($4);
    var $6 = $5;
    var $7 = __ZNK2js10StackFrame10hasArgsObjEv($fp);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackFrame17hasOverriddenArgsEv($fp);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $12 = $11 | 0;
    __ZN2JSL11ObjectValueER8JSObject1294($1, $12);
    __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($6, $1);
    __label__ = 4;
    break;
   case 4:
    __Z16js_PutArgsObjectPN2js10StackFrameE($fp);
    __label__ = 5;
    break;
   case 5:
    var $15 = __ZNK2js10StackFrame6scriptEv($fp);
    var $16 = $15 + 64 | 0;
    var $17 = __ZNK2js10CallObject9isForEvalEv($6);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZNK2js8Bindings9countVarsEv($16);
    var $20 = $19 & 65535;
    var $21 = __ZNK2js10StackFrame5slotsEv($2);
    __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($6, 0, 0, $20, $21);
    __label__ = 21;
    break;
   case 7:
    var $23 = __ZNK2js10StackFrame3funEv($fp);
    var $24 = __ZNK2js8Bindings16countArgsAndVarsEv($16);
    if (($24 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK10JSFunction6scriptEv($23);
    if ((HEAP8[$27 + 36 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZNK2js8Bindings9countArgsEv($16);
    var $34 = __ZNK2js8Bindings9countVarsEv($16);
    var $35 = $33 & 65535;
    var $36 = $34 & 65535;
    var $37 = __ZNK2js10StackFrame10formalArgsEv($fp);
    var $38 = __ZNK2js10StackFrame5slotsEv($2);
    __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($6, $35, $37, $36, $38);
    __label__ = 16;
    break;
   case 10:
    var $41 = HEAPU16[$27 + 48 >> 1];
    if ($41 << 16 >> 16 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = $41 & 65535;
    var $i_02 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_02;
    var $45 = __ZN8JSScript12getClosedArgEj($27, $i_02);
    var $46 = __ZNK2js10StackFrame9formalArgEj($fp, $45);
    __ZN2js10CallObject6setArgEjRKN2JS5ValueE($6, $45, $46);
    var $47 = $i_02 + 1 | 0;
    if (($47 | 0) == ($43 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $i_02 = $47;
      __label__ = 12;
      break;
    }
   case 13:
    var $49 = HEAPU16[$27 + 50 >> 1];
    if ($49 << 16 >> 16 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $51 = __ZNK2js10StackFrame5slotsEv($2);
    var $52 = $49 & 65535;
    var $i2_01 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i2_01;
    var $54 = __ZN8JSScript12getClosedVarEj($27, $i2_01);
    var $55 = $51 + ($54 << 3) | 0;
    __ZN2js10CallObject6setVarEjRKN2JS5ValueE($6, $54, $55);
    var $56 = $i2_01 + 1 | 0;
    if (($56 | 0) == ($52 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $i2_01 = $56;
      __label__ = 15;
      break;
    }
   case 16:
    var $57 = $27;
    var $58 = __ZNK8JSScript7nestingEv($57);
    if (($58 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP8[$27 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = __ZN2js10CallObject8argArrayEv($6);
    HEAP32[$58 + 16 >> 2] = $66;
    var $68 = __ZN2js10CallObject8varArrayEv($6);
    HEAP32[$58 + 20 >> 2] = $68;
    __label__ = 19;
    break;
   case 19:
    var $71 = $23;
    var $72 = __Z16js_IsNamedLambdaP10JSFunction($71);
    if ($72) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $74 = $5 | 0;
    var $75 = __ZNK8JSObject9getParentEv($74);
    __ZN8JSObject10setPrivateEPv($75, 0);
    __label__ = 21;
    break;
   case 21:
    __ZN2js10CallObject13setStackFrameEPNS_10StackFrameE($6, 0);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_PutCallObjectPN2js10StackFrameE["X"] = 1;

function __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($this, $v) {
  var $1 = $this | 0;
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($1, 1, $v);
  return;
}

function __ZNK2js10CallObject9isForEvalEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $3 = __ZNK2JS5Value6isNullEv($2);
  return $3;
}

function __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($this, $nargs, $argv, $nvars, $slots) {
  var $1 = $this;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, 2, $argv, $nargs);
  var $2 = $nargs + 2 | 0;
  __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($1, $2, $slots, $nvars);
  return;
}

function __ZN2js10CallObject6setArgEjRKN2JS5ValueE($this, $i, $v) {
  var $1 = $this | 0;
  var $2 = $i + 2 | 0;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($1, $2, $v);
  return;
}

function __ZN2js10CallObject6setVarEjRKN2JS5ValueE($this, $i, $v) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $7 = $i + 2 + (HEAPU16[$1 + 56 >> 1] & 65535) | 0;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $7, $v);
  return;
}

function __ZN2js10CallObject8argArrayEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN8JSObject14getSlotAddressEj($1, 2);
  return $2;
}

function __ZN2js10CallObject8varArrayEv($this) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $6 = (HEAPU16[$1 + 56 >> 1] & 65535) + 2 | 0;
  var $7 = __ZN8JSObject14getSlotAddressEj($2, $6);
  return $7;
}

function __Z23js_PutCallObjectOnTraceP8JSObjectjPN2JS5ValueEjS3_($obj, $nargs, $argv, $nvars, $slots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($nargs | 0) == (-$nvars | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject6asCallEv($obj);
    var $5 = $4;
    __ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_($5, $nargs, $argv, $nvars, $slots);
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame9formalArgEj($5, $4);
    var $9 = $8 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$2$1 >> 2];
    var $11 = $vp | 0;
    var $st$7$0 = $11 | 0;
    HEAP32[$st$7$0 >> 2] = $10$0;
    var $st$7$1 = $11 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZNK2js10CallObject3argEj($2, $4);
    var $14 = $13 | 0;
    var $st$2$0 = $14 | 0;
    var $15$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$2$1 >> 2];
    var $16 = $vp | 0;
    var $st$7$0 = $16 | 0;
    HEAP32[$st$7$0 >> 2] = $15$0;
    var $st$7$1 = $16 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $15$1;
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject15maybeStackFrameEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  return $2;
}

function __ZNK2js10CallObject3argEj($this, $i) {
  var $1 = $this | 0;
  var $2 = $i + 2 | 0;
  var $3 = __ZNK8JSObject7getSlotEj($1, $2);
  return $3;
}

function __ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame9formalArgEj($5, $4);
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2js10CallObject6setArgEjRKN2JS5ValueE($2, $4, $vp);
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZNK2js10CallObject17getCalleeFunctionEv($2);
    var $15 = __ZNK10JSFunction6scriptEv($14);
    var $16 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($15, $cx, $14);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $15, $4, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject17getCalleeFunctionEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  var $4 = __ZNK8JSObject18getFunctionPrivateEv($3);
  return $4;
}

function __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($this, $cx, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 100 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN8JSScript9makeTypesEP9JSContextP10JSFunction($this, $cx, $fun);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $script, $arg, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $value);
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $arg, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN8JSObject6asCallEv($obj);
  var $2 = $1;
  var $3 = _JSID_TO_INT1286($id);
  var $4 = $3 & 65535;
  var $5 = __ZNK2js10CallObject9getCalleeEv($2);
  var $6 = __ZN8JSObject19getFlatClosureUpvarEj($5, $4);
  var $7 = $6 | 0;
  var $8$0 = HEAP32[$7 >> 2];
  var $8$1 = HEAP32[$7 + 4 >> 2];
  var $9 = $vp | 0;
  HEAP32[$9 >> 2] = $8$0;
  HEAP32[$9 + 4 >> 2] = $8$1;
  return 1;
}

function __ZNK2js10CallObject9getCalleeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 0);
  var $3 = __ZNK2JS5Value14toObjectOrNullEv($2);
  return $3;
}

function __ZN8JSObject19getFlatClosureUpvarEj($this, $i) {
  var $1 = __ZNK8JSObject20getFlatClosureUpvarsEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var $1 = __ZN8JSObject6asCallEv($obj);
  var $2 = $1;
  var $3 = _JSID_TO_INT1286($id);
  var $4 = $3 & 65535;
  var $5 = __ZNK2js10CallObject9getCalleeEv($2);
  __ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE($5, $4, $vp);
  return 1;
}

function __ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE($this, $i, $v) {
  var $1 = __ZNK8JSObject20getFlatClosureUpvarsEv($this);
  var $2 = $v | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 + ($i << 3) | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10StackFrame7varSlotEj($5, $4);
    var $9 = $8 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$2$1 >> 2];
    var $11 = $vp | 0;
    var $st$7$0 = $11 | 0;
    HEAP32[$st$7$0 >> 2] = $10$0;
    var $st$7$1 = $11 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZNK2js10CallObject3varEj($2, $4);
    var $14 = $13 | 0;
    var $st$2$0 = $14 | 0;
    var $15$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$2$1 >> 2];
    var $16 = $vp | 0;
    var $st$7$0 = $16 | 0;
    HEAP32[$st$7$0 >> 2] = $15$0;
    var $st$7$1 = $16 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $15$1;
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame7varSlotEj($this, $i) {
  var $1 = $this;
  var $2 = __ZNK2js10StackFrame5slotsEv($1);
  return $2 + ($i << 3) | 0;
}

function __ZNK2js10CallObject3varEj($this, $i) {
  var $1 = __ZNK2js10CallObject17getCalleeFunctionEv($this);
  var $2 = $this | 0;
  var $7 = $i + 2 + (HEAPU16[$1 + 56 >> 1] & 65535) | 0;
  var $8 = __ZNK8JSObject7getSlotEj($2, $7);
  return $8;
}

function __ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = _JSID_TO_INT1286($id);
    var $4 = $3 & 65535;
    var $5 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js10StackFrame7varSlotEj($5, $4);
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2js10CallObject6setVarEjRKN2JS5ValueE($2, $4, $vp);
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZNK2js10CallObject17getCalleeFunctionEv($2);
    var $15 = __ZNK10JSFunction6scriptEv($14);
    var $16 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($15, $cx, $14);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $15, $4, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $script, $local, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $value);
    __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $local, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12call_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL12JSID_IS_ATOMi1319($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN8JSObject6asCallEv($obj);
    var $6 = $5;
    var $7 = __ZNK2js10CallObject9getCalleeEv($6);
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0;
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom1293($14);
    if (($15 | 0) == ($id | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv1350($1);
    var $18 = $cx;
    var $19 = $obj;
    var $20 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($18, $19, $id, $1, 114, 116, 69, 0, 0, 2);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10call_traceP8JSTracerP8JSObject($trc, $obj) {
  __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $obj);
  return;
}

function __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $clone = __stackBase__ + 8;
    var $1 = __ZNK2js10StackFrame15isFunctionFrameEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 3:
    var $4 = __ZNK2js10StackFrame3funEv($this);
    var $5 = __ZNK2js10StackFrame6calleeEv($this);
    __ZN2JS5Value9setObjectER8JSObject($vp, $5);
    var $6 = __ZNK2js10StackFrame12functionThisEv($this);
    var $7 = __ZNK2JS5Value8isObjectEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 4:
    var $9 = __ZN10JSFunction14compiledFunObjEv($4);
    var $10 = __ZeqRK8JSObjectS1_($9, $5);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 5:
    var $12 = __ZNK10JSFunction10methodAtomEv($4);
    if (($12 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZNK2JS5Value8toObjectEv($6);
    var $16 = $v | 0;
    var $first_barriered_thisp_0 = 0;
    var $thisp_0 = $15;
    __label__ = 7;
    break;
   case 7:
    var $thisp_0;
    var $first_barriered_thisp_0;
    var $18 = __ZNK8JSObject8isNativeEv($thisp_0);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 8:
    var $20 = __ZN8JSObject16hasMethodBarrierEv($thisp_0);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 9:
    var $22 = __ZNK10JSFunction10methodAtomEv($4);
    var $23 = __ZL12ATOM_TO_JSIDP6JSAtom1293($22);
    var $24 = __ZN8JSObject12nativeLookupEP9JSContexti($thisp_0, $cx, $23);
    if (($24 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZNK2js5Shape8isMethodEv($24);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $29 = __ZNK2js5Shape12methodObjectEv($24);
    var $30 = __ZeqRK8JSObjectS1_($29, $5);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $32 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($thisp_0, $cx, $24, $vp);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $35 = __ZNK2JS5Value8toObjectEv($vp);
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $35);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 14:
    var $37 = __ZNK2js5Shape7hasSlotEv($24);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $40 = HEAP32[$24 + 24 >> 2];
    var $41 = __ZNK8JSObject7getSlotEj($thisp_0, $40);
    var $42 = $41 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    HEAP32[$16 >> 2] = $43$0;
    HEAP32[$16 + 4 >> 2] = $43$1;
    var $44 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($v, $clone);
    if ($44) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $46 = HEAP32[$clone >> 2];
    var $47 = __ZNK8JSObject18getFunctionPrivateEv($46);
    if (($47 | 0) == ($4 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $50 = __ZNK8JSObject12hasMethodObjERKS_($46, $thisp_0);
    if ($50) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $52$0 = HEAP32[$16 >> 2];
    var $52$1 = HEAP32[$16 + 4 >> 2];
    var $53 = $vp | 0;
    HEAP32[$53 >> 2] = $52$0;
    HEAP32[$53 + 4 >> 2] = $52$1;
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $46);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 19:
    if (($first_barriered_thisp_0 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $first_barriered_thisp_1 = $first_barriered_thisp_0;
      __label__ = 21;
      break;
    }
   case 20:
    var $first_barriered_thisp_1 = $thisp_0;
    __label__ = 21;
    break;
   case 21:
    var $first_barriered_thisp_1;
    var $58 = __ZNK8JSObject8getProtoEv($thisp_0);
    if (($58 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $first_barriered_thisp_0 = $first_barriered_thisp_1;
      var $thisp_0 = $58;
      __label__ = 7;
      break;
    }
   case 22:
    if (($first_barriered_thisp_1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($cx, $4);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject12setMethodObjERS_($63, $first_barriered_thisp_1);
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $63);
    __ZN2JS5Value9setObjectER8JSObject($vp, $63);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZNK2js10StackFrame12functionThisEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pn = $this;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $_pn = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pn;
    return $_pn - 8 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSFunction10methodAtomEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK10JSFunction8joinableEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this | 0;
    var $4 = __ZNK8JSObject7getSlotEj($3, 0);
    var $5 = __ZNK2JS5Value8isStringEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toStringEv($4);
    var $8 = __ZNK8JSString6asAtomEv($7);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame15overwriteCalleeER8JSObject($this, $newCallee) {
  var $1 = __ZNK2js10StackFrame14mutableCalleevEv($this);
  __ZN2JS5Value9setObjectER8JSObject($1, $newCallee);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject12hasMethodObjERKS_($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($this);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject12getFixedSlotEj($this, 1);
    var $5 = __ZNK2JS5Value8isObjectEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($4);
    var $8 = __ZeqRK8JSObjectS1_($7, $obj);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstword = __stackBase__;
    var $flagsword = __stackBase__ + 4;
    var $funNameBytes = __stackBase__ + 8;
    var $tvr = __stackBase__ + 12;
    var $script = __stackBase__ + 28;
    var $2 = HEAPU32[$xdr + 8 >> 2];
    var $3 = $xdr | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = HEAP32[$objp >> 2];
    var $8 = __ZNK8JSObject18getFunctionPrivateEv($7);
    var $9 = __ZNK10JSFunction13isInterpretedEv($8);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $11 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($2, $8, $funNameBytes);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($2, 2, 0, 11, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($funNameBytes);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 6:
    var $25 = (HEAP32[$8 + 72 >> 2] | 0) != 0 & 1 | (HEAPU16[$8 + 64 >> 1] & 65535) << 2;
    HEAP32[$firstword >> 2] = $25;
    var $33 = (HEAPU16[$8 + 56 >> 1] & 65535) << 16 | HEAPU16[$8 + 58 >> 1] & 65535;
    HEAP32[$flagsword >> 2] = $33;
    var $fun_0 = $8;
    __label__ = 9;
    break;
   case 7:
    var $35 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($2, 0, 0, 0, 16384, 0, 0);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $38 = $35 | 0;
    __ZN8JSObject11clearParentEv($38);
    __ZN8JSObject9clearTypeEv($38);
    var $fun_0 = $35;
    __label__ = 9;
    break;
   case 9:
    var $fun_0;
    var $40 = $fun_0 | 0;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $2, $40);
    var $41 = $xdr;
    var $42 = _JS_XDRUint32($41, $firstword);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$firstword >> 2] & 1 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = _js_XDRAtom($41, $fun_0 + 72 | 0);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $54 = _JS_XDRUint32($41, $flagsword);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP16[$fun_0 + 56 >> 1] = HEAPU32[$flagsword >> 2] >>> 16 & 65535;
    HEAP16[$fun_0 + 58 >> 1] = HEAP32[$flagsword >> 2] & 65535;
    HEAP16[$fun_0 + 64 >> 1] = HEAPU32[$firstword >> 2] >>> 2 & 65535;
    __label__ = 15;
    break;
   case 15:
    var $73 = $fun_0 + 60 | 0;
    var $74 = $73;
    var $75 = HEAP32[$74 >> 2];
    HEAP32[$script >> 2] = $75;
    var $76 = $xdr;
    var $77 = $script;
    var $78 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($76, $77);
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_c = HEAP32[$script >> 2];
    HEAP32[$73 >> 2] = $_c;
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 17:
    HEAP32[$objp >> 2] = $40;
    var $86 = HEAP32[$74 >> 2];
    var $87 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($86, $2, $fun_0, 0);
    if ($87) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $89 = __ZNK10JSFunction6scriptEv($fun_0);
    var $90 = $2;
    var $91 = $89;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($90, $91, $fun_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, $funobj, $native, $nargs, $flags, $parent, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($funobj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject9setParentEPS_($funobj, $parent);
    var $_01 = $funobj;
    __label__ = 6;
    break;
   case 3:
    var $4 = __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($native | 0) == 0) {
      var $_01 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $4;
    var $10 = $cx;
    var $11 = __ZN8JSObject16setSingletonTypeEP9JSContext($9, $10);
    var $_01 = $4;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $13 = $_01;
    HEAP16[$_01 + 56 >> 1] = $nargs & 65535;
    HEAP16[$13 + 58 >> 1] = $flags & 65535 & -6152;
    var $21 = $_01 + 60 | 0;
    var $22 = $21 + 4 | 0;
    if (($flags & 49152) >>> 0 > 16383) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP16[$22 >> 1] = 0;
    HEAP32[$21 >> 2] = 0;
    __label__ = 11;
    break;
   case 8:
    HEAP32[$22 >> 2] = 0;
    if (($flags & 8192 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$21 + 8 >> 2] = 0;
    __label__ = 11;
    break;
   case 10:
    HEAP32[$21 >> 2] = $native;
    HEAP32[$21 + 8 >> 2] = 0;
    __label__ = 11;
    break;
   case 11:
    HEAP32[$_01 + 72 >> 2] = $atom;
    __ZN8JSObject10setPrivateEPv($_01, $_01);
    var $_0 = $13;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom["X"] = 1;

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZL13fun_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __ZNK8JSObject15isBoundFunctionEv($obj);
    var $_pre = $cx + 52 | 0;
    if ($1) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[HEAP32[$_pre >> 2] + 210200 >> 2] | 0;
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom1293($6);
    var $8 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $7, $found, 1);
    if ($8) {
      var $_pre_phi = $_pre;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $_pre_phi;
    var $12 = HEAP32[HEAP32[$_pre_phi >> 2] + 210256 >> 2] | 0;
    var $13 = __ZL12ATOM_TO_JSIDP6JSAtom1293($12);
    var $14 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $13, $found, 1);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$_pre_phi >> 2] + 210272 >> 2] | 0;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom1293($19);
    var $21 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $20, $found, 1);
    if ($21) {
      var $i_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < 2) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $32 = HEAP32[HEAP32[$_pre_phi >> 2] + 209948 + (HEAPU16[__ZL15poisonPillProps + ($i_0 << 1) >> 1] & 65535) >> 2];
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom1293($32);
    var $34 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($obj, $cx, $33, $found, 1);
    if ($34) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11fun_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZL12JSID_IS_ATOMi1319($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($obj);
    var $7 = HEAPU32[$cx + 52 >> 2];
    var $10 = HEAP32[$7 + 210200 >> 2] | 0;
    var $11 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $10);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $5;
    var $15 = __ZNK10JSFunction8isNativeEv($14);
    if ($15) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZNK10JSFunction19isFunctionPrototypeEv($5);
    if ($17) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject($cx, $obj);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 7:
    var $25 = HEAP32[$7 + 210256 >> 2] | 0;
    var $26 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $25);
    if (($26 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $31 = HEAP32[$7 + 210272 >> 2] | 0;
    var $32 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $31);
    if (($32 | 0) == 0) {
      var $i_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $37 = HEAPU16[$5 + 56 >> 1] & 65535;
    __ZN2JS5Value8setInt32Ei($v, $37);
    __label__ = 13;
    break;
   case 10:
    var $40 = HEAPU32[$5 + 72 >> 2];
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $46 = $40;
      __label__ = 12;
      break;
    }
   case 11:
    var $46 = HEAP32[$7 + 144136 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $46;
    __ZN2JS5Value9setStringEP8JSString($v, $46 | 0);
    __label__ = 13;
    break;
   case 13:
    var $49 = $cx;
    var $50 = $obj;
    var $51 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($49, $50, $id, $v, 10, 12, 6, 0, 0, 0);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 15:
    var $i_0;
    if ($i_0 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 16:
    var $63 = HEAP32[$7 + 209948 + (HEAPU16[__ZL15poisonPillProps + ($i_0 << 1) >> 1] & 65535) >> 2];
    var $64 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $63);
    if (($64 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $67 = __ZNK10JSFunction13isInterpretedEv($5);
    if ($67) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $69 = __ZNK10JSFunction12inStrictModeEv($5);
    if ($69) {
      __label__ = 20;
      break;
    } else {
      var $attrs_0 = 4;
      var $setter_0 = 12;
      var $getter_0 = 118;
      __label__ = 21;
      break;
    }
   case 19:
    var $71 = __ZNK8JSObject15isBoundFunctionEv($obj);
    if ($71) {
      __label__ = 20;
      break;
    } else {
      var $attrs_0 = 4;
      var $setter_0 = 12;
      var $getter_0 = 118;
      __label__ = 21;
      break;
    }
   case 20:
    var $73 = __ZNK8JSObject17getThrowTypeErrorEv($obj);
    var $74 = __ZN2jsL16CastAsPropertyOpEP8JSObject1357($73);
    var $75 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($73);
    var $attrs_0 = 52;
    var $setter_0 = $75;
    var $getter_0 = $74;
    __label__ = 21;
    break;
   case 21:
    var $getter_0;
    var $setter_0;
    var $attrs_0;
    __ZN2JSL14UndefinedValueEv1350($1);
    var $77 = $cx;
    var $78 = $obj;
    var $79 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($77, $78, $id, $1, $getter_0, $setter_0, $attrs_0, 0, 0, 0);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 23:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 15;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11fun_resolveP9JSContextP8JSObjectijPS2_["X"] = 1;

function __ZL12fun_finalizeP9JSContextP8JSObject($cx, $obj) {
  __ZN8JSObject27finalizeUpvarsIfFlatClosureEv($obj);
  return;
}

function __ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pval = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZNK8JSObject10isFunctionEv($_01);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject15isBoundFunctionEv($_01);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject22getBoundFunctionTargetEv($_01);
    var $_01 = $7;
    __label__ = 2;
    break;
   case 5:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $13 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($_01, $cx, $12, $pval);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2JS5Value11isPrimitiveEv($pval);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject1294($1, $_01);
    var $18 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 135, -1, $1, 0, 0, 0);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $20 = __ZNK2JS5Value8toObjectEv($pval);
    var $21 = $20;
    var $22 = __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE(undef, $21, $v);
    HEAP32[$bp >> 2] = $22 & 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9fun_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1;
    if (($5 | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $5, undef);
    var $8 = __ZNK10JSFunction13isFlatClosureEv($2);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 4:
    var $10 = __ZNK10JSFunction6scriptEv($2);
    var $11 = $10 + 64 | 0;
    var $12 = __ZNK2js8Bindings9hasUpvarsEv($11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 5:
    var $14 = __ZNK2js8Bindings11countUpvarsEv($11);
    var $15 = $14 & 65535;
    var $16 = __ZNK8JSObject20getFlatClosureUpvarsEv($obj);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $15, $16, undef);
    __label__ = 11;
    break;
   case 6:
    var $20 = HEAP32[$1 + 72 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $20 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $23, undef);
    __label__ = 8;
    break;
   case 8:
    var $25 = __ZNK10JSFunction13isInterpretedEv($2);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $27 = __ZNK10JSFunction6scriptEv($2);
    if (($27 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $27, undef);
    __label__ = 11;
    break;
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $obj, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $p = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $str = __stackBase__ + 16;
    var $2 = __ZNK8JSObject10isFunctionEv($obj);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject15isFunctionProxyEv($obj);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj($cx, $obj, $indent);
    var $_0 = $6;
    __label__ = 17;
    break;
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_Function_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_toString_str | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE._js_object_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 5:
    var $9 = __ZNK8JSObject18getFunctionPrivateEv($obj);
    HEAP32[$fun >> 2] = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = ($indent | 0) != 0;
    if ($12) {
      var $28 = $9;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = HEAP32[$cx + 56 >> 2] + 1836 | 0;
    var $17 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($16);
    if ($17) {
      var $28 = $9;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($16);
    __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($p, $19, $fun);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = HEAP32[$fun >> 2];
    __label__ = 11;
    break;
   case 10:
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($p);
    var $_0 = HEAP32[$24 + 4 >> 2];
    __label__ = 17;
    break;
   case 11:
    var $28;
    var $29 = _JS_DecompileFunction($cx, $28, $indent);
    HEAP32[$str >> 2] = $29;
    var $30 = ($29 | 0) == 0;
    var $_mux = $30 ? 0 : $29;
    if ($30 | $12) {
      var $_0 = $_mux;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $34 = HEAP32[$cx + 56 >> 2] + 1836 | 0;
    var $35 = __ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv($34);
    if ($35) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_pre4 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($34);
    var $_pre_phi = $_pre4;
    __label__ = 15;
    break;
   case 14:
    __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv($34);
    var $37 = __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv($34);
    var $38 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($37, 0);
    if ($38) {
      var $_pre_phi = $37;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    var $_pre_phi;
    var $40 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_($_pre_phi, $fun, $str);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18fun_toStringHelperP9JSContextP8JSObjectj["X"] = 1;

function __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 120,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this | 0;
    var $3 = __ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv($2);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_($3, $1);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 24 | 0] = 1;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$v >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($2);
    HEAP32[$8 + 4 >> 2] = $7;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_fun_callP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $thisv = __stackBase__ + 8;
    var $args = __stackBase__ + 16;
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $fval | 0;
    var $st$9$0 = $3 | 0;
    HEAP32[$st$9$0 >> 2] = $2$0;
    var $st$9$1 = $3 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $2$1;
    var $4 = __ZL13js_IsCallableRKN2JS5ValueE1306($fval);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 3:
    var $7 = $vp + 16 | 0;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($thisv);
    var $_01 = 0;
    var $argv_0 = $7;
    __label__ = 6;
    break;
   case 5:
    var $11 = $7 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $thisv | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_01 = $argc - 1 | 0;
    var $argv_0 = $vp + 24 | 0;
    __label__ = 6;
    break;
   case 6:
    var $argv_0;
    var $_01;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $18 = $cx + 60 | 0;
    var $19 = $cx;
    var $20 = $args;
    var $21 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($18, $19, $_01, $20);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $args | 0;
    var $24 = __ZNK2js12CallReceiver7calleevEv($23);
    var $25 = $24 | 0;
    HEAP32[$25 >> 2] = $2$0;
    HEAP32[$25 + 4 >> 2] = $2$1;
    var $26 = __ZNK2js12CallReceiver5thisvEv($23);
    var $27 = $thisv | 0;
    var $st$9$0 = $27 | 0;
    var $28$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$9$1 >> 2];
    var $29 = $26 | 0;
    HEAP32[$29 >> 2] = $28$0;
    HEAP32[$29 + 4 >> 2] = $28$1;
    var $30 = $args | 0;
    var $31 = __ZNK2js8CallArgs4argvEv($30);
    var $32 = $31;
    _memcpy($32, $argv_0, $_01 << 3, 1);
    var $35 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $36 = __ZNK2js12CallReceiver4rvalEv($23);
    var $37 = $36 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $vp | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $_0 = $35 & 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11js_fun_callP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13js_IsCallableRKN2JS5ValueE1306($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_fun_applyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $length = __stackBase__ + 8;
    var $args = __stackBase__ + 12;
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAPU32[$1 >> 2];
    var $2$1 = HEAPU32[$1 + 4 >> 2];
    var $3 = $fval | 0;
    var $st$9$0 = $3 | 0;
    HEAP32[$st$9$0 >> 2] = $2$0;
    var $st$9$1 = $3 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $2$1;
    var $4 = __ZL13js_IsCallableRKN2JS5ValueE1306($fval);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 3:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = __ZNK2JS5Value17isNullOrUndefinedEv($9);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = ($argc | 0) != 0 & 1;
    var $14 = __Z11js_fun_callP9JSContextjPN2JS5ValueE($cx, $13, $vp);
    var $_1 = $14;
    __label__ = 16;
    break;
   case 6:
    var $16 = __ZNK2JS5Value8isObjectEv($9);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 154, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_apply_str | 0, tempInt));
    var $_1 = 0;
    __label__ = 16;
    break;
   case 8:
    var $19 = __ZNK2JS5Value8toObjectEv($9);
    var $20 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $19, $length);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = HEAPU32[$length >> 2];
    if ($23 >>> 0 > 491520) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    _JS_ReportErrorNumber($cx, 2, 0, 61, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 16;
    break;
   case 11:
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $28 = $cx + 60 | 0;
    var $29 = $cx;
    var $30 = $args;
    var $31 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($28, $29, $23, $30);
    if ($31) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $33 = $args | 0;
    var $34 = __ZNK2js12CallReceiver7calleevEv($33);
    var $35 = $34 | 0;
    HEAP32[$35 >> 2] = $2$0;
    HEAP32[$35 + 4 >> 2] = $2$1;
    var $36 = __ZNK2js12CallReceiver5thisvEv($33);
    var $37 = $vp + 16 | 0;
    var $st$9$0 = $37 | 0;
    var $38$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $37 + 4 | 0;
    var $38$1 = HEAP32[$st$9$1 >> 2];
    var $39 = $36 | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = $args | 0;
    var $41 = __ZNK2js8CallArgs4argvEv($40);
    var $42 = __ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $19, $23, $41);
    if ($42) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 13:
    var $44 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $46 = __ZNK2js12CallReceiver4rvalEv($33);
    var $47 = $46 | 0;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = $vp | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_fun_applyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = __ZNK2JS5Value8toObjectEv($vp);
    var $2 = __ZN2jsL14IsConstructingEPKN2JS5ValueE1307($vp);
    var $3 = __ZNK8JSObject29getBoundFunctionArgumentCountEv($1);
    var $4 = $3 + $argc | 0;
    if ($4 >>> 0 > 491520) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_1 = 0;
    __label__ = 11;
    break;
   case 3:
    var $8 = __ZNK8JSObject22getBoundFunctionTargetEv($1);
    var $9 = __ZNK8JSObject20getBoundFunctionThisEv($1);
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $11 = $cx + 60 | 0;
    var $12 = $cx;
    var $13 = $args;
    var $14 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($11, $12, $4, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $16 = $args | 0;
    if (($3 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $i_01;
    var $17 = __ZNK2js8CallArgsixEj($16, $i_01);
    var $18 = __ZNK8JSObject24getBoundFunctionArgumentEj($1, $i_01);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $17 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $22 = $i_01 + 1 | 0;
    if (($22 | 0) == ($3 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = $22;
      __label__ = 5;
      break;
    }
   case 6:
    var $23 = __ZNK2js8CallArgs4argvEv($16);
    var $25 = $23 + ($3 << 3) | 0;
    var $27 = $vp + 16 | 0;
    var $28 = $argc << 3;
    _memcpy($25, $27, $28, 1);
    var $29 = $args | 0;
    var $30 = __ZNK2js12CallReceiver7calleevEv($29);
    __ZN2JS5Value9setObjectER8JSObject($30, $8);
    if ($2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZNK2js12CallReceiver5thisvEv($29);
    var $33 = $9 | 0;
    var $st$2$0 = $33 | 0;
    var $34$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $33 + 4 | 0;
    var $34$1 = HEAP32[$st$2$1 >> 2];
    var $35 = $32 | 0;
    var $st$7$0 = $35 | 0;
    HEAP32[$st$7$0 >> 2] = $34$0;
    var $st$7$1 = $35 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $34$1;
    var $36 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $37 = __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args);
    if ($37) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $39 = __ZNK2js12CallReceiver4rvalEv($29);
    var $40 = $39 | 0;
    var $st$2$0 = $40 | 0;
    var $41$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$2$1 >> 2];
    var $42 = $vp | 0;
    var $st$7$0 = $42 | 0;
    HEAP32[$st$7$0 >> 2] = $41$0;
    var $st$7$1 = $42 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $41$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE1307($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZNK8JSObject29getBoundFunctionArgumentCountEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 1);
  var $2 = __ZNK2JS5Value15toPrivateUint32Ev($1);
  return $2;
}

function __ZNK8JSObject22getBoundFunctionTargetEv($this) {
  var $1 = __ZNK8JSObject9getParentEv($this);
  return $1;
}

function __ZNK8JSObject20getBoundFunctionThisEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 0);
  return $1;
}

function __ZNK8JSObject24getBoundFunctionArgumentEj($this, $which) {
  var $1 = $which + 2 | 0;
  var $2 = __ZNK8JSObject7getSlotEj($this, $1);
  return $2;
}

function __ZL12fun_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $2, 32768);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12fun_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $indent = __stackBase__;
    HEAP32[$indent >> 2] = 0;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $3, $indent);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = $vp + 8 | 0;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$indent >> 2];
    var $11 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $7, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $11);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8fun_bindP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $thisArg = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = __ZL13js_IsCallableRKN2JS5ValueE1306($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js13FunctionClassE);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($1);
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $argslen_0 = 0;
      var $args_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $argslen_0 = $argc - 1 | 0;
    var $args_0 = $vp + 24 | 0;
    __label__ = 5;
    break;
   case 5:
    var $args_0;
    var $argslen_0;
    var $11 = __ZNK8JSObject10isFunctionEv($5);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $length_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $13 = __ZNK8JSObject18getFunctionPrivateEv($5);
    var $16 = HEAPU16[$13 + 56 >> 1] & 65535;
    var $_ = $16 >>> 0 > $argslen_0 >>> 0 ? $16 - $argslen_0 | 0 : 0;
    var $length_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $length_0;
    var $20 = __ZNK8JSObject10isFunctionEv($5);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $26 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $22 = __ZNK8JSObject18getFunctionPrivateEv($5);
    var $26 = HEAP32[$22 + 72 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $26;
    var $27 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 122, $length_0, 512, $5, $26);
    var $28 = $27 | 0;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = $vp + 16 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $thisArg | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    __label__ = 13;
    break;
   case 12:
    __ZN2JSL14UndefinedValueEv1350($thisArg);
    __label__ = 13;
    break;
   case 13:
    var $38 = __ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j($28, $cx, $thisArg, $args_0, $argslen_0);
    if ($38) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2JS5Value9setObjectER8JSObject($vp, $28);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8fun_bindP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = $vp + 8 | 0;
    var $4 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($3, $funobj);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb1348($1, 0);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 6;
    break;
   case 3:
    var $10 = HEAP32[$funobj >> 2];
    var $11 = __ZNK8JSObject18getFunctionPrivateEv($10);
    var $12 = __ZNK10JSFunction13isInterpretedEv($11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $result_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK10JSFunction6scriptEv($11);
    var $result_0 = HEAP8[HEAP32[$14 >> 2]] << 24 >> 24 == -51;
    __label__ = 5;
    break;
   case 5:
    var $result_0;
    __ZN2JSL12BooleanValueEb1348($2, $result_0);
    var $20 = $2 | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $vp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_($t1, $t2) {
  var $2 = $t1 >>> 0 < $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __ZNK2js11TokenStream12currentTokenEv($this) {
  return $this + 4 + (HEAP32[$this + 132 >> 2] << 5) | 0;
}

function __ZN2JS6AnchorIP8JSStringE3setERKS2_($this, $t) {
  var $1 = HEAP32[$t >> 2];
  HEAP32[$this >> 2] = $1;
  return;
}

function __ZNK2js8Bindings11countUpvarsEv($this) {
  return HEAP16[$this + 8 >> 1];
}

function __ZNK2js8Bindings9hasUpvarsEv($this) {
  return HEAP16[$this + 8 >> 1] << 16 >> 16 != 0;
}

function __ZNK8JSObject10isDelegateEv($this) {
  return (HEAP32[$this + 8 >> 2] & 1 | 0) != 0;
}

function __ZN8JSObject13clearDelegateEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js8FunctionEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 960;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $bindings = __stackBase__ + 8;
    var $lineno = __stackBase__ + 20;
    var $aaa = __stackBase__ + 24;
    var $ts = __stackBase__ + 32;
    var $name = __stackBase__ + 944;
    var $dummy = __stackBase__ + 948;
    var $strAnchor = __stackBase__ + 952;
    var $str = __stackBase__ + 956;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $1 = $call | 0;
    var $2 = __ZNK2js12CallReceiver6calleeEv($1);
    var $3 = $2;
    var $4 = __ZNK8JSObject9getGlobalEv($3);
    var $5 = $4;
    var $6 = $cx;
    var $7 = __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($5, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 247, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_7 = 0;
    __label__ = 36;
    break;
   case 3:
    __ZN2js8BindingsC1EP9JSContext($bindings, undef);
    var $10 = __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($cx, $lineno, 1);
    var $11 = __ZNK2js8CallArgs4argvEv($call);
    var $12 = $argc - 1 | 0;
    var $13 = ($argc | 0) != 0;
    var $_ = $13 ? $12 : 0;
    if (($_ | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $cx;
    var $i_0 = 0;
    var $args_length_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $args_length_0;
    var $i_0;
    if ($i_0 >>> 0 < $_ >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $19 = $11 + ($i_0 << 3) | 0;
    var $20 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($15, $19);
    if (($20 | 0) == 0) {
      var $_7 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($19, $20);
    var $23 = __ZNK8JSString6lengthEv($20);
    var $uadd = _llvm_uadd_with_overflow_i32($args_length_0, $23);
    var $24 = $uadd.f1;
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_7 = 0;
    __label__ = 36;
    break;
   case 9:
    var $27 = $uadd.f0;
    var $i_0 = $i_0 + 1 | 0;
    var $args_length_0 = $27;
    __label__ = 5;
    break;
   case 10:
    var $30 = $args_length_0 + $_ | 0;
    var $31 = $30 - 1 | 0;
    if ($31 >>> 0 < $args_length_0 >>> 0 | $31 >>> 0 > 2147483646) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __Z27js_ReportAllocationOverflowP9JSContext($cx);
    var $_7 = 0;
    __label__ = 36;
    break;
   case 12:
    var $36 = $cx + 72 | 0;
    __ZN2js18AutoArenaAllocatorC1EP11JSArenaPool($aaa, $36);
    var $37 = __ZN2js18AutoArenaAllocator5allocItEEPT_j($aaa, $30);
    if (($37 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i2_0 = 0;
      var $cp_0 = $37;
      __label__ = 14;
      break;
    }
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 28;
    break;
   case 14:
    var $cp_0;
    var $i2_0;
    if ($i2_0 >>> 0 < $_ >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $42 = $11 + ($i2_0 << 3) | 0;
    var $43 = __ZNK2JS5Value8toStringEv($42);
    var $44 = __ZNK8JSString6lengthEv($43);
    var $45 = __ZN8JSString8getCharsEP9JSContext($43, $cx);
    if (($45 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = $45;
    var $50 = $44 << 1;
    _memcpy($cp_0, $49, $50, 1);
    var $52 = $i2_0 + 1 | 0;
    var $54 = $52 >>> 0 < $_ >>> 0 ? 44 : 0;
    var $55 = $cp_0 + ($44 + 1 << 1) | 0;
    HEAP16[$cp_0 + ($44 << 1) >> 1] = $54;
    var $i2_0 = $52;
    var $cp_0 = $55;
    __label__ = 14;
    break;
   case 17:
    __ZN2js11TokenStreamC2EP9JSContext($ts, $cx);
    var $57 = HEAP32[$lineno >> 2];
    var $58 = __ZNK9JSContext11findVersionEv($cx);
    var $59 = __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($ts, $37, $31, $10, $57, $58);
    var $60 = __ZN2js11TokenStream8getTokenEv($ts);
    if (($60 | 0) == 0) {
      var $_14 = 0;
      __label__ = 29;
      break;
    } else {
      var $tt_0 = $60;
      __label__ = 18;
      break;
    }
   case 18:
    var $tt_0;
    if (($tt_0 | 0) == 29) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $tt_0);
    var $_14 = 1;
    __label__ = 29;
    break;
   case 20:
    var $65 = __ZNK2js11TokenStream12currentTokenEv($ts);
    var $67 = HEAPU32[$65 + 28 >> 2];
    var $68 = __ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom($bindings, $cx, $67);
    if ($68) {
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    __ZN16JSAutoByteStringC1Ev($name);
    var $70 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $67, $name);
    if (($70 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_14 = 1;
    __label__ = 29;
    break;
   case 23:
    var $73 = __ZNK16JSAutoByteString3ptrEv($name);
    var $74 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $ts, 0, 5, 111, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $73, tempInt));
    var $_8 = $74 & 1 ^ 1;
    __ZN16JSAutoByteStringD1Ev($name);
    if ($74) {
      __label__ = 24;
      break;
    } else {
      var $_14 = $_8;
      __label__ = 29;
      break;
    }
   case 24:
    var $77 = __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($bindings, $cx, $67, $dummy);
    if ($77) {
      __label__ = 25;
      break;
    } else {
      var $_14 = 1;
      __label__ = 29;
      break;
    }
   case 25:
    var $79 = __ZN2js11TokenStream8getTokenEv($ts);
    if (($79 | 0) == 3) {
      __label__ = 27;
      break;
    } else if (($79 | 0) == 0) {
      var $_14 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $79);
    var $_14 = 1;
    __label__ = 29;
    break;
   case 27:
    var $82 = __ZN2js11TokenStream8getTokenEv($ts);
    var $tt_0 = $82;
    __label__ = 18;
    break;
   case 28:
    __ZN2js18AutoArenaAllocatorD1Ev($aaa);
    var $_7 = 0;
    __label__ = 36;
    break;
   case 29:
    var $_14;
    __ZN2js11TokenStreamD2Ev($ts);
    __ZN2js18AutoArenaAllocatorD1Ev($aaa);
    if (($_14 | 0) == 1) {
      var $_7 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($strAnchor, 0);
    if ($13) {
      __label__ = 31;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 31:
    var $85 = $11 + ($12 << 3) | 0;
    var $86 = $cx;
    var $87 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($86, $85);
    HEAP32[$str >> 2] = $87;
    if (($87 | 0) == 0) {
      var $_7 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JS6AnchorIP8JSStringE3setERKS2_($strAnchor, $str);
    var $90 = HEAP32[$str >> 2];
    var $91 = __ZN8JSString8getCharsEP9JSContext($90, $cx);
    var $92 = __ZNK8JSString6lengthEv($90);
    var $length_0 = $92;
    var $chars_0 = $91;
    var $101 = HEAP32[$cx + 52 >> 2];
    __label__ = 34;
    break;
   case 33:
    var $95 = HEAP32[$cx + 52 >> 2];
    var $98 = HEAP32[$95 + 144136 >> 2] | 0;
    var $99 = __ZNK14JSLinearString5charsEv($98);
    var $length_0 = 0;
    var $chars_0 = $99;
    var $101 = $95;
    __label__ = 34;
    break;
   case 34:
    var $101;
    var $chars_0;
    var $length_0;
    var $102 = $4;
    var $105 = HEAP32[$101 + 210168 >> 2] | 0;
    var $106 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, 0, 0, 16392, $102, $105);
    if (($106 | 0) == 0) {
      var $_7 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $109 = $cx;
    var $110 = __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $109);
    var $111 = $110;
    var $112 = HEAP32[$lineno >> 2];
    var $113 = __ZNK9JSContext11findVersionEv($cx);
    var $114 = __ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion($cx, $106, $111, $bindings, $chars_0, $length_0, $10, $112, $113);
    var $115 = __ZNK2js12CallReceiver4rvalEv($1);
    var $116 = $106 | 0;
    __ZN2JS5Value9setObjectER8JSObject($115, $116);
    var $_7 = $114 & 1;
    __label__ = 36;
    break;
   case 36:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8FunctionEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($cx, $linenop, $opt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($opt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext4regsEv($cx);
    var $5 = HEAPU32[$3 + 4 >> 2];
    HEAP32[$linenop >> 2] = (HEAPU8[$5 + 4 | 0] & 255) << 8 | HEAPU8[$5 + 5 | 0] & 255;
    var $14 = __ZNK9JSContext2fpEv($cx);
    var $15 = __ZNK2js10StackFrame6scriptEv($14);
    var $_0 = HEAP32[$15 + 52 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $19 = $cx;
    var $20 = __ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj($19, $linenop);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoArenaAllocator5allocItEEPT_j($this, $elems) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    var $4 = HEAP32[$2 + 16 >> 2];
    var $7 = HEAP32[$2 + 24 >> 2];
    var $10 = $7 + ($elems << 1) & ($7 ^ -1);
    var $11 = $4 + 12 | 0;
    var $12 = HEAPU32[$11 >> 2];
    var $14 = HEAPU32[$4 + 8 >> 2];
    if ($10 >>> 0 > $14 >>> 0 | $12 >>> 0 > ($14 - $10 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $19 = _JS_ArenaAllocate($2, $10);
    var $_p_0 = $19;
    __label__ = 4;
    break;
   case 3:
    var $22 = $10 + $12 | 0;
    HEAP32[$11 >> 2] = $22;
    var $_p_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8getTokenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 136 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - 1 | 0;
    HEAP32[$1 >> 2] = $5;
    var $6 = $this + 132 | 0;
    var $9 = HEAP32[$6 >> 2] + 1 & 3;
    HEAP32[$6 >> 2] = $9;
    var $10 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $_0 = HEAP32[$10 >> 2];
    __label__ = 4;
    break;
   case 3:
    var $14 = __ZN2js11TokenStream16getTokenInternalEv($this);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11OnBadFormalP9JSContextN2js9TokenKindE($cx, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tt | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 20, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28IsBuiltinFunctionConstructorEP10JSFunction($fun) {
  var $1 = $fun;
  var $2 = __ZNK10JSFunction11maybeNativeEv($1);
  return ($2 | 0) == 34;
}

function __ZN2js34LookupInterpretedFunctionPrototypeEP9JSContextP8JSObject($cx, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2] | 0;
    var $6 = __ZL12ATOM_TO_JSIDP6JSAtom1293($5);
    var $7 = __ZN8JSObject12nativeLookupEP9JSContexti($funobj, $cx, $6);
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $7;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject($cx, $funobj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN8JSObject12nativeLookupEP9JSContexti($funobj, $cx, $6);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objProto = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZNK8JSObject9getParentEv($obj);
    var $4 = $cx;
    var $5 = $3;
    var $6 = $objProto;
    var $7 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, $5, 1, $6, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$objProto >> 2];
    var $11 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, __ZN2js11ObjectClassE, $10, $3);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    var $15 = $cx;
    var $16 = __ZN8JSObject16setSingletonTypeEP9JSContext($14, $15);
    var $17 = $cx + 52 | 0;
    var $21 = HEAP32[HEAP32[$17 >> 2] + 210200 >> 2] | 0;
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom1293($21);
    __ZN2JSL11ObjectValueER8JSObject1294($1, $11);
    var $23 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $22, $1, 10, 12, 4);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $29 = HEAP32[HEAP32[$17 >> 2] + 210204 >> 2] | 0;
    var $30 = __ZL12ATOM_TO_JSIDP6JSAtom1293($29);
    __ZN2JSL11ObjectValueER8JSObject1294($2, $obj);
    var $31 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($11, $cx, $30, $2, 10, 12, 0);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent) {
  var $1 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342($cx, $parent);
  return $1;
}

function __Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_($cx, $fun, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = $fun;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, __ZN2js13FunctionClassE, $proto, $parent);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $fun | 0;
    var $11 = __ZNK8JSObject8getProtoEv($10);
    if (($11 | 0) == ($proto | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = __ZNK8JSObject16hasSingletonTypeEv($10);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK8JSObject4typeEv($10);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($7, $16);
    __label__ = 6;
    break;
   case 6:
    var $18 = $fun;
    __ZN8JSObject10setPrivateEPv($7, $18);
    var $_0 = $7;
    __label__ = 12;
    break;
   case 7:
    var $20 = __ZN2jsL11NewFunctionEP9JSContextP8JSObject($cx, $parent);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = $20;
    var $25 = HEAP16[$fun + 56 >> 1];
    HEAP16[$20 + 56 >> 1] = $25;
    var $29 = HEAP16[$fun + 58 >> 1];
    HEAP16[$23 + 58 >> 1] = $29;
    var $31 = $20 + 60 | 0;
    var $32 = $fun | 0;
    var $33 = __ZNK8JSObject18getFunctionPrivateEv($32);
    var $35 = $31;
    var $36 = $33 + 60 | 0;
    HEAP32[$35 >> 2] = HEAP32[$36 >> 2];
    HEAP32[$35 + 4 >> 2] = HEAP32[$36 + 4 >> 2];
    HEAP32[$35 + 8 >> 2] = HEAP32[$36 + 8 >> 2];
    var $_c = HEAP32[$fun + 72 >> 2];
    HEAP32[$20 + 72 >> 2] = $_c;
    var $40 = $20;
    __ZN8JSObject10setPrivateEPv($20, $40);
    var $41 = __ZNK10JSFunction13isInterpretedEv($23);
    if ($41) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $20;
      __label__ = 12;
      break;
    }
   case 9:
    var $43 = __ZNK10JSFunction6scriptEv($23);
    HEAP32[$31 >> 2] = 0;
    var $44 = $cx;
    var $45 = $43;
    var $46 = __Z14js_CloneScriptP9JSContextP8JSScript($44, $45);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $49 = $46;
    HEAP32[$31 >> 2] = $46;
    var $50 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($49, $cx, $23, 0);
    if ($50) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $52 = __ZNK10JSFunction6scriptEv($23);
    var $53 = $52;
    var $54 = $20;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($44, $53, $54);
    var $55 = __ZNK10JSFunction6scriptEv($23);
    __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $55, $20, 1);
    var $_0 = $20;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb1337($4);
  var $6 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($cx, $script, $obj, $kind);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $fun, $scopeChain) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $fun, $scopeChain, 1);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK10JSFunction6scriptEv($fun);
    var $5 = $4 + 64 | 0;
    var $6 = __ZNK2js8Bindings11countUpvarsEv($5);
    if ($6 << 16 >> 16 == 0) {
      var $_0 = $1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($6 & 65535) << 3;
    var $11 = __ZN9JSContext7malloc_Ej($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11;
    __ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE($1, $14);
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE($this, $upvars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $upvars;
  __ZN2JSL12PrivateValueEPv1335($1, $2);
  __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($this, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $fun, $op, $oplen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK9JSContext2fpEv($cx);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = __Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject($cx, $fun, $3);
    if (($4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK10JSFunction6scriptEv($fun);
    var $8 = $7 + 64 | 0;
    var $9 = __ZNK2js8Bindings9hasUpvarsEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $11 = __ZNK8JSObject20getFlatClosureUpvarsEv($4);
    var $14 = HEAPU16[$7 + 46 >> 1] & 65535;
    var $15 = __ZN8JSScript6upvarsEv($7);
    var $17 = HEAPU32[$15 + 4 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $15 | 0;
    var $20 = $1 | 0;
    var $i_01 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_01;
    var $24 = HEAP32[HEAP32[$19 >> 2] + ($i_01 << 2) >> 2];
    HEAP32[$20 >> 2] = $24;
    var $25 = __ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE($cx, $14, $1);
    var $26 = $25 | 0;
    var $27$0 = HEAP32[$26 >> 2];
    var $27$1 = HEAP32[$26 + 4 >> 2];
    var $28 = $11 + ($i_01 << 3) | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $29 = $i_01 + 1 | 0;
    if (($29 | 0) == ($17 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_01 = $29;
      __label__ = 5;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj($cx, $obj, $id, $native, $nargs, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = ($attrs & 4096 | 0) == 0;
    var $_01 = $3 ? $attrs : $attrs & -4097;
    var $gop_0 = $3 ? 0 : 10;
    var $sop_0 = $3 ? 0 : 12;
    var $5 = __ZNK8JSObject10isDelegateEv($obj);
    var $6 = $_01 & 10232;
    var $7 = __ZL12JSID_IS_ATOMi1319($id);
    if (($7 | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZL12JSID_TO_ATOMi1320($id);
    var $12 = $10;
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $13 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($cx, 0, $native, $nargs, $6, $obj, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK8JSObject10isDelegateEv($obj);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN8JSObject13clearDelegateEv($obj);
    __label__ = 7;
    break;
   case 7:
    var $20 = $13 | 0;
    __ZN2JSL11ObjectValueER8JSObject1294($1, $20);
    var $21 = $_01 & -2041;
    var $22 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $id, $1, $gop_0, $sop_0, $21);
    var $_ = ($22 | 0) == 0 ? 0 : $13;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMi1319($id) {
  var $1 = _JSID_IS_STRING1333($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi1320($id) {
  var $1 = _JSID_TO_STRING1332($id);
  return $1;
}

function __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($vp, $funobj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = HEAP32[$funobj >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $i = __stackBase__ + 24;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $3 = $flags >>> 7 & 1 | 22;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $cx, 0);
    var $4 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $7 = __ZNK2js10StackFrame6scriptEv($6);
    var $8 = __ZNK2js13FrameRegsIter2pcEv($i);
    var $9 = _js_ReconstructStackDepth($cx, $7, $8);
    var $10 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $11 = $10;
    var $12 = __ZNK2js10StackFrame4baseEv($11);
    var $13 = $12 + ($9 << 3) | 0;
    if ($12 >>> 0 > $vp >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZNK2js13FrameRegsIter2spEv($i);
    var $17 = __ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_($13, $16);
    if ($17 >>> 0 > $vp >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = $vp - $13 >> 3;
    if (($23 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $spindex_1 = $23;
      __label__ = 6;
      break;
    }
   case 5:
    var $spindex_1 = $flags >>> 16 & 1;
    __label__ = 6;
    break;
   case 6:
    var $spindex_1;
    var $27 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, $3, $spindex_1, $vp, 0, 0, 0);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj($cx, $vp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funobj = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303($vp, $funobj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$funobj >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $vp, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = __ZN8JSObject10isCallableEv($3);
    if ($4) {
      var $_0 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, $flags);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13FrameRegsIter2spEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js9StackIter2spEv($1);
  return $2;
}

function __ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function _JSVAL_TO_PRIVATE_UINT32_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function _JSID_TO_STRING1332($iden) {
  return $iden;
}

function _JSID_IS_STRING1333($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js13FunctionClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject1357($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358($object) {
  return $object;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIP8JSStringEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIP8JSStringEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefIP10JSFunctionEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js9StackIter2spEv($this) {
  return HEAP32[$this + 24 >> 2];
}

function __ZN2js2gcL15GetGCObjectKindEjb1337($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _PRIVATE_UINT32_TO_JSVAL_IMPL($agg_result, $ui) {
  HEAP32[$agg_result + 4 >> 2] = 0;
  HEAP32[$agg_result >> 2] = $ui;
  return;
}

function __ZNK8JSObject15isBoundFunctionEv($this) {
  return (HEAP32[$this + 8 >> 2] & 1024 | 0) != 0;
}

function __ZNK10JSFunction19isFunctionPrototypeEv($this) {
  return (HEAP16[$this + 58 >> 1] & 2048) << 16 >> 16 != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIP8JSStringEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefIP10JSFunctionEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP8JSStringEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIP8JSStringEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP8JSStringEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefIP10JSFunctionEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP10JSFunctionEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev($this) {
  __ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZN6PutArgclEjPN2JS5ValueE($this, $0, $src) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZNK2JS5Value7isMagicE10JSWhyMagic($3, undef);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $src | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $3 | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    var $10 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    HEAP32[$2 >> 2] = $10 + 8 | 0;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv1335($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, $clasp, $1, $parent, 0, $7);
    var $8 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, $clasp, $kind);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $11);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342($cx, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = $cx;
    var $11 = __Z16js_NewGCFunctionP9JSContext($10);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = $12;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $19 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK8JSObject9getParentEv($4);
    var $19 = $17;
    __label__ = 7;
    break;
   case 7:
    var $19;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($12, undef, __ZN2js13FunctionClassE, $9, $19, 0, (__ZN2js13FunctionClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $20 = __ZNK2js5Class8isNativeEv(__ZN2js13FunctionClassE);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $22 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344($cx, $12, $9);
    if ($22) {
      var $_0 = $12;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($12);
    var $_0 = $12;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js13FunctionClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344($cx, $obj, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js13FunctionClassE + 4 >> 2] >>> 8 & 255;
    var $4 = __ZNK8JSObject8numSlotsEv($obj);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js13FunctionClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js13FunctionClassE, 2);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js13FunctionClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb1348($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2JSL14UndefinedValueEv1350($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j($this, $cx, $thisArg, $args, $argslen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 8 | 0;
    var $4 = HEAP32[$2 >> 2] | 1024;
    HEAP32[$2 >> 2] = $4;
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 0, $thisArg);
    __ZN2JSL18PrivateUint32ValueEj($1, $argslen);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, 1, $1);
    if (($argslen | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject8getClassEv($this);
    var $8 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8 | 0;
    var $12 = $8 + 4 | 0;
    var $14 = HEAP32[$12 >> 2] + $argslen | 0;
    HEAP32[$12 >> 2] = $14;
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $11);
    var $15 = $this;
    var $16 = $cx;
    var $17 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($15, $16, $argslen);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($15, 2, $args, $argslen);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL18PrivateUint32ValueEj($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __ZN2JS5Value16setPrivateUint32Ej($this, $ui) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _PRIVATE_UINT32_TO_JSVAL_IMPL($1, $ui);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2JS5Value15toPrivateUint32Ev($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TO_PRIVATE_UINT32_IMPL($2$0, $2$1);
  return $3;
}

function __ZN8JSObject27finalizeUpvarsIfFlatClosureEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject18getFunctionPrivateEv($this);
    if (($1 | 0) == 0 | ($1 | 0) == ($this | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK10JSFunction13isFlatClosureEv($1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject7getSlotEj($this, 0);
    var $9 = __ZNK2JS5Value8isDoubleEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value9toPrivateEv($8);
    __ZN2js10Foreground5free_EPv($11);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject17getThrowTypeErrorEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject9getGlobalEv($1);
  var $3 = $2;
  var $4 = __ZNK2js12GlobalObject17getThrowTypeErrorEv($3);
  return $4;
}

function __ZL14JSID_FROM_BITSj1372($bits) {
  return $bits;
}

function __ZN2js2gc5Arena13staticAssertsEv() {
  return;
}

function __ZN2js7analyzeL7ArgSlotEj1371($arg) {
  return $arg + 2 | 0;
}

function _INT_TO_JSID1373($i) {
  return $i << 1 | 1;
}

function __ZN8JSObject17asStrictArgumentsEv($this) {
  return $this;
}

function __ZN8JSObject17asNormalArgumentsEv($this) {
  return $this;
}

function __ZNK10JSFunction8joinableEv($this) {
  return (HEAP16[$this + 58 >> 1] & 1) << 16 >> 16 != 0;
}

function __ZNK2js10StackFrame19isFloatingGeneratorEv($this) {
  return (HEAP32[$this >> 2] & 64 | 0) != 0;
}

function __ZN2js10StackFrame17setOverriddenArgsEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1024;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN6PutArgC2EPN2JS5ValueE($this, $dst) {
  HEAP32[$this >> 2] = $dst;
  return;
}

function __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($this) {
  HEAP32[$this + 12 >> 2] = 20;
  return;
}

function __ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE($this, $comp, $kind) {
  HEAP32[$this >> 2] = $comp;
  var $4 = $this + 12 | 0;
  var $7 = HEAP32[$4 >> 2] & -256 | $kind & 255;
  HEAP32[$4 >> 2] = $7;
  HEAP32[$this + 8 >> 2] = 268374016;
  return;
}

function __ZNK2js2gc5Chunk18hasAvailableArenasEv($this) {
  return (HEAP32[$this + 1048336 >> 2] | 0) != 0;
}

function __ZN2js2gc5Chunk23removeFromAvailableListEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1048320 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $this + 1048324 | 0;
    var $4 = HEAP32[$3 >> 2];
    HEAP32[$4 >> 2] = $2;
    var $5 = HEAP32[$1 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$3 >> 2];
    var $9 = $5 + 1048324 | 0;
    HEAP32[$9 >> 2] = $8;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$3 >> 2] = 0;
    HEAP32[$1 >> 2] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $2 = __ZNK8JSObject10isFunctionEv($_01);
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK8JSObject8getProtoEv($_01);
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $_01 = $4;
      __label__ = 2;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject18getFunctionPrivateEv($_01);
    var $8 = __ZNK10JSFunction13isInterpretedEv($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK10JSFunction6scriptEv($7);
    var $11 = $10 + 38 | 0;
    var $13 = HEAP8[$11] | 4;
    HEAP8[$11] = $13;
    var $14 = $7 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $14, 1048576);
    __label__ = 6;
    break;
   case 6:
    __ZN2JS5Value7setNullEv($vp);
    var $16 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359($cx);
    if (($16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $fp_0 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $fp_0;
    var $18 = __ZNK2js10StackFrame15isFunctionFrameEv($fp_0);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $20 = __ZNK2js10StackFrame3funEv($fp_0);
    if (($20 | 0) == ($7 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = __ZNK2js10StackFrame4prevEv($fp_0);
    if (($22 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      var $fp_0 = $22;
      __label__ = 7;
      break;
    }
   case 10:
    var $26 = HEAP32[$cx + 52 >> 2];
    var $29 = HEAP32[$26 + 210176 >> 2] | 0;
    var $30 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $29);
    if (($30 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33 = _JS_ReportErrorFlagsAndNumber($cx, 5, 2, 0, 158, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_arguments_str | 0, tempInt));
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $fp_0, $vp);
    var $_0 = $36;
    __label__ = 24;
    break;
   case 13:
    var $40 = HEAP32[$26 + 210196 >> 2] | 0;
    var $41 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $40);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $44 = __ZNK2js10StackFrame4prevEv($fp_0);
    if (($44 | 0) == 0) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($cx, $44);
    if (($47 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $50 = __ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE($47, $cx, $vp);
    if ($50) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $52 = __ZNK2JS5Value8isObjectEv($vp);
    if ($52) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 18:
    var $54 = __ZNK2JS5Value8toObjectEv($vp);
    var $55 = $54;
    var $56 = __ZNK2js2gc4Cell11compartmentEv($55);
    if (($56 | 0) == (HEAP32[$cx + 56 >> 2] | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 20:
    var $62 = __ZNK8JSObject10isFunctionEv($54);
    if ($62) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 21:
    var $64 = __ZNK8JSObject18getFunctionPrivateEv($54);
    var $65 = __ZNK10JSFunction13isInterpretedEv($64);
    if ($65) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 22:
    var $67 = __ZNK10JSFunction12inStrictModeEv($64);
    if ($67) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 23:
    var $69 = _JS_ReportErrorFlagsAndNumber($cx, 0, 2, 0, 256, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZNK2js12GlobalObject17getThrowTypeErrorEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject7getSlotEj($1, 111);
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  return $3;
}

function __ZN8JSObject11hasPropertyEP9JSContextiPbj($this, $cx, $id, $foundp, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $rf = __stackBase__ + 8;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, $flags);
    var $1 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($this, $cx, $id, $pobj, $prop);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$foundp] = (HEAP32[$prop >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18MaybeMarkGeneratorP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZNK2js10StackFrame19isFloatingGeneratorEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $1;
    var $8 = __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($7);
    var $10 = HEAP32[$8 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $10, undef);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame17hasOverriddenArgsEv($3);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE($cx, $3);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $12 = __ZNK2js10CallObject12getArgumentsEv($2);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject6asCallEv($obj);
    var $2 = $1;
    var $3 = __ZNK2js10CallObject15maybeStackFrameEv($2);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10StackFrame17setOverriddenArgsEv($3);
    __label__ = 3;
    break;
   case 3:
    __ZN2js10CallObject12setArgumentsERKN2JS5ValueE($2, $vp);
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10CallObject12getArgumentsEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 1);
  return $2;
}

function __ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $local, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $enter = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $local);
    var $7 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $7;
    var $9 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($5, $1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $11 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $local);
    HEAP32[$2 >> 2] = $7;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($11, $cx, $2);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($script, $i) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  var $6 = HEAPU16[$script + 22 >> 1] & 65535;
  var $7 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1368($script, $i);
  return $3 + ($6 + $7) * 12 | 0;
}

function __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($this, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet7unknownEv($this);
    if ($1) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($3) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveEv($type);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = HEAP32[$this >> 2];
    var $9 = __ZNK2js5types4Type9primitiveEv($type);
    var $10 = __ZN2js5types17PrimitiveTypeFlagE11JSValueType($9);
    var $_0 = ($10 & $8 | 0) != 0;
    __label__ = 7;
    break;
   case 5:
    var $14 = __ZNK2js5types4Type11isAnyObjectEv($type);
    var $18 = (HEAP32[$this >> 2] & 128 | 0) != 0;
    if ($14 | $18) {
      var $_0 = $18 | $14 ^ 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$this + 4 >> 2];
    var $22 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    var $23 = __ZNK2js5types4Type9objectKeyEv($type);
    var $24 = __ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_($21, $22, $23);
    var $_0 = ($24 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj1366($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_($values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($count | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $values;
    var $3 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($2);
    var $5 = ($3 | 0) == ($key | 0) ? $2 : 0;
    var $_0 = $5;
    __label__ = 11;
    break;
   case 3:
    if ($count >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $count >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $11 = HEAPU32[$values + ($i_0 << 2) >> 2];
    var $12 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($11);
    if (($12 | 0) == ($key | 0)) {
      var $_0 = $11;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $17 = __ZN2js5typesL15HashSetCapacityEj1366($count);
    var $18 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367($key);
    var $19 = $17 - 1 | 0;
    var $_pn = $18;
    __label__ = 8;
    break;
   case 8:
    var $_pn;
    var $pos_0 = $_pn & $19;
    var $22 = HEAP32[$values + ($pos_0 << 2) >> 2];
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($22);
    if (($25 | 0) == ($key | 0)) {
      var $_0 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_pn = $pos_0 + 1 | 0;
    __label__ = 8;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj1368($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSScript8functionEv($script);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE($cx, $script, $arg, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $enter = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script, $arg);
    var $7 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $7;
    var $9 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($5, $1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $11 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script, $arg);
    HEAP32[$2 >> 2] = $7;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($11, $cx, $2);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($script, $i) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  var $6 = HEAPU16[$script + 22 >> 1] & 65535;
  var $7 = __ZN2js7analyzeL7ArgSlotEj1371($i);
  return $3 + ($6 + $7) * 12 | 0;
}

function __ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext($cx) {
  var $3 = HEAP32[$cx + 56 >> 2] + 760 | 0;
  var $4 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, __ZN2js12DeclEnvClassE, $3);
  return $4;
}

function __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($cx, $clasp, $shapep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$shapep >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$shapep >> 2] = $4;
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject17isStrictArgumentsEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $4 = _JSID_IS_INT1285($id);
    if (($4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_INT1286($id);
    var $8 = $3 | 0;
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $12 = __ZNK2js15ArgumentsObject7elementEj($8, $7);
    var $13 = __ZNK2JS5Value7isMagicE10JSWhyMagic($12, undef);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $12 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    __label__ = 8;
    break;
   case 6:
    var $19 = $3 | 0;
    var $20 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($19);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZNK2js15ArgumentsObject13initialLengthEv($19);
    __ZN2JS5Value8setInt32Ei($vp, $22);
    __label__ = 8;
    break;
   case 8:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZNK8JSObject17isStrictArgumentsEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject17asStrictArgumentsEv($obj);
    var $4 = _JSID_IS_INT1285($id);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _JSID_TO_INT1286($id);
    var $8 = $3 | 0;
    var $9 = __ZNK2js15ArgumentsObject13initialLengthEv($8);
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($8, $7, $vp);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $13 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $14 = $cx;
    var $15 = $3;
    var $16 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($14, $15, $id, $13, $strict);
    if (($16 | 0) == 0) {
      var $22 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($14, $15, $id, 0, $vp, $strict);
    var $22 = ($19 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $22;
    var $23 = $22 & 1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE($this, $i, $v) {
  var $1 = __ZNK2js15ArgumentsObject4dataEv($this);
  var $2 = $v | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 + 8 + ($i << 3) | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  return;
}

function __ZNK2js21NormalArgumentsObject6calleeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js15ArgumentsObject4dataEv($1);
  return $2 | 0;
}

function __ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $5 = _JSID_IS_INT1285($id);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _JSID_TO_INT1286($id);
    var $9 = $4 | 0;
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    if ($8 >>> 0 < $10 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($9);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK2js10StackFrame18canonicalActualArgEj($13, $8);
    var $17 = $16 | 0;
    var $st$2$0 = $17 | 0;
    var $18$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$2$1 >> 2];
    var $19 = $vp | 0;
    var $st$7$0 = $19 | 0;
    HEAP32[$st$7$0 >> 2] = $18$0;
    var $st$7$1 = $19 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $18$1;
    __label__ = 12;
    break;
   case 6:
    var $21 = __ZNK2js15ArgumentsObject7elementEj($9, $8);
    var $22 = $21 | 0;
    var $st$2$0 = $22 | 0;
    var $23$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$2$1 >> 2];
    var $24 = $vp | 0;
    var $st$7$0 = $24 | 0;
    HEAP32[$st$7$0 >> 2] = $23$0;
    var $st$7$1 = $24 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $23$1;
    __label__ = 12;
    break;
   case 7:
    var $30 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $31 = __ZL12JSID_IS_ATOMiP6JSAtom1287($id, $30);
    if (($31 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $4 | 0;
    var $35 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($34);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZNK2js15ArgumentsObject13initialLengthEv($34);
    __ZN2JS5Value8setInt32Ei($vp, $37);
    __label__ = 12;
    break;
   case 10:
    var $39 = __ZNK2js21NormalArgumentsObject6calleeEv($4);
    var $40 = __ZNK2JS5Value7isMagicE10JSWhyMagic($39, undef);
    if ($40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $39 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $vp | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = $obj;
    var $2 = __ZNK8JSObject17isNormalArgumentsEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject17asNormalArgumentsEv($obj);
    var $5 = _JSID_IS_INT1285($id);
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _JSID_TO_INT1286($id);
    var $9 = $4 | 0;
    var $10 = __ZNK2js15ArgumentsObject13initialLengthEv($9);
    if ($8 >>> 0 < $10 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $13 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($9);
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZNK2js10StackFrame14functionScriptEv($13);
    if ((HEAP8[$16 + 36 | 0] & 64) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZNK2js10StackFrame13numFormalArgsEv($13);
    if ($8 >>> 0 < $22 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $16, $8, $vp);
    __label__ = 8;
    break;
   case 8:
    var $26 = __ZNK2js10StackFrame18canonicalActualArgEj($13, $8);
    var $27 = $vp | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $26 | 0;
    HEAP32[$29 >> 2] = $28$0;
    HEAP32[$29 + 4 >> 2] = $28$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 9:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $31 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $32 = $cx;
    var $33 = $4;
    var $34 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($32, $33, $id, $31, 0);
    if (($34 | 0) == 0) {
      var $40 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($32, $33, $id, $vp, 0, 0, 1);
    var $40 = ($37 | 0) != 0;
    __label__ = 11;
    break;
   case 11:
    var $40;
    var $41 = $40 & 1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN2JSL10MagicValueE10JSWhyMagic1374($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 1);
  return;
}

function __ZN2js15ArgumentsObject20markLengthOverriddenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = __ZNK8JSObject7getSlotEj($2, 0);
  var $4 = __ZNK2JS5Value7toInt32Ev($3);
  var $5 = $4 | 1;
  __ZN2JSL10Int32ValueEi1375($1, $5);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js21NormalArgumentsObject11clearCalleeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = __ZNK2js15ArgumentsObject4dataEv($2);
  __ZN2JSL10MagicValueE10JSWhyMagic1374($1);
  var $4 = $1 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $3 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL10Int32ValueEi1375($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk4initEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1032192 | 0;
    var $prevp_01 = $this + 1048328 | 0;
    var $a_02 = $this | 0;
    __label__ = 2;
    break;
   case 2:
    var $a_02;
    var $prevp_01;
    var $4 = $a_02 | 0;
    HEAP32[$prevp_01 >> 2] = $4;
    __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($4);
    var $6 = $a_02 + 4096 | 0;
    if (($6 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $prevp_01 = $a_02 + 4 | 0;
      var $a_02 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$this + 1028100 >> 2] = 0;
    var $9 = $this + 1032192 | 0;
    __ZN2js2gc11ChunkBitmap5clearEv($9);
    HEAP32[$this + 1048332 >> 2] = 0;
    HEAP32[$this + 1048336 >> 2] = 252;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap5clearEv($this) {
  var $1 = $this | 0;
  __ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_($1);
  return;
}

function __ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE($this, $comp, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1048328 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $4;
    __ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE($2, $comp, $thingKind);
    var $5 = $this + 1048336 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = __ZNK2js2gc5Chunk18hasAvailableArenasEv($this);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc5Chunk23removeFromAvailableListEv($this);
    __label__ = 3;
    break;
   case 3:
    var $13 = HEAP32[$comp >> 2] + 140 | 0;
    var $15 = HEAP32[$13 >> 2] + 4096 | 0;
    HEAP32[$13 >> 2] = $15;
    var $16 = $comp + 328 | 0;
    var $18 = HEAP32[$16 >> 2] + 4096 | 0;
    HEAP32[$16 >> 2] = $18;
    if ($18 >>> 0 < HEAPU32[$comp + 332 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js20TriggerCompartmentGCEP13JSCompartment($comp);
    __label__ = 5;
    break;
   case 5:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL3MaxIjEET_S1_S1_($t1) {
  var $2 = $t1 >>> 0 > 31457280 ? $t1 : 31457280;
  return $2;
}

function __ZN2jsL3MinIfEET_S1_S1_($t1, $t2) {
  var $2 = $t1 < $t2 ? $t1 : $t2;
  return $2;
}

function __ZNK2JS5Value11payloadWordEv($this) {
  return $this;
}

function __ZNK2js2gc5Chunk6unusedEv($this) {
  return (HEAP32[$this + 1048336 >> 2] | 0) == 252;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN9JSRuntime20reduceGCTriggerBytesEj($this, $amount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 144 | 0;
    var $3 = HEAP32[$1 >> 2] - $amount | 0;
    if ($3 >>> 0 < 94371840) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSCompartment20reduceGCTriggerBytesEj($this, $amount) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 332 | 0;
    var $3 = HEAP32[$1 >> 2] - $amount | 0;
    if ($3 >>> 0 < 94371840) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11IsGCAllowedEP9JSContext($cx) {
  return (HEAP8[HEAP32[$cx + 52 >> 2] + 144304 | 0] & 1) << 24 >> 24 == 0;
}

function __ZN2js20TriggerCompartmentGCEP13JSCompartment($comp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $comp | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 4;
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    if ((HEAP32[$2 + 192 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if ((HEAP32[$2 >> 2] | 0) == ($comp | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9TriggerGCEP9JSRuntime($2);
    __label__ = 14;
    break;
   case 7:
    var $18 = $2 + 196 | 0;
    if ((HEAP32[$18 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $2 + 144076 | 0;
    if ((HEAP32[$22 >> 2] | 0) == ($comp | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$22 >> 2] = 0;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAPU32[$2 + 140 >> 2];
    if ($28 >>> 0 > 8192) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ($28 >>> 0 < ((HEAPU32[$2 + 144 >> 2] >>> 1) * 3 | 0) >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js9TriggerGCEP9JSRuntime($2);
    __label__ = 14;
    break;
   case 13:
    HEAP32[$18 >> 2] = 1;
    HEAP32[$2 + 144076 >> 2] = $comp;
    var $39 = HEAP32[$1 >> 2];
    __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($39);
    __label__ = 14;
    break;
   case 14:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($this, $aheader) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $aheader | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$3 >> 2];
    var $6 = $5 + 140 | 0;
    var $8 = HEAP32[$6 >> 2] - 4096 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $3 + 328 | 0;
    var $11 = HEAP32[$9 >> 2] - 4096 | 0;
    HEAP32[$9 >> 2] = $11;
    __ZN2js2gc11ArenaHeader17setAsNotAllocatedEv($aheader);
    var $12 = $this + 1048328 | 0;
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$aheader + 4 >> 2] = $13;
    HEAP32[$12 >> 2] = $aheader;
    var $15 = $this + 1048336 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $16 + 1 | 0;
    HEAP32[$15 >> 2] = $17;
    if (($16 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $20 = HEAP32[$2 >> 2];
    __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($this, $20);
    __label__ = 5;
    break;
   case 3:
    var $22 = __ZNK2js2gc5Chunk6unusedEv($this);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $24 = $5 + 48 | 0;
    HEAP32[$1 >> 2] = $this;
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_($24, $1);
    __ZN2js2gc5Chunk23removeFromAvailableListEv($this);
    HEAP32[$this + 1048332 >> 2] = 0;
    var $26 = $5 + 80 | 0;
    var $27 = HEAP32[$26 >> 2];
    HEAP32[$this + 1048320 >> 2] = $27;
    HEAP32[$26 >> 2] = $this;
    var $29 = $5 + 84 | 0;
    var $31 = HEAP32[$29 >> 2] + 1 | 0;
    HEAP32[$29 >> 2] = $31;
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($this, $comp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z21GetAvailableChunkListP13JSCompartment($comp);
    var $2 = $this + 1048320 | 0;
    HEAP32[$this + 1048324 >> 2] = $1;
    var $4 = HEAP32[$1 >> 2];
    var $_pre = $2 | 0;
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 1048324 | 0;
    HEAP32[$7 >> 2] = $_pre;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$_pre >> 2] = $4;
    HEAP32[$1 >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_($p, $this, $l);
    __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0 | ($6 | 0) == ($2 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = __ZNK2js2gc4Cell8isMarkedEj($1, 0);
    var $_0 = $10 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc4Cell8isMarkedEj($this, $color) {
  var $1 = __ZNK2js2gc4Cell5chunkEv($this);
  var $2 = $1 + 1032192 | 0;
  var $3 = __ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj($2, $this, $color);
  return $3;
}

function __Z18js_GCThingIsMarkedPvj($thing, $color) {
  var $1 = $thing;
  var $2 = __ZNK2js2gc4Cell8isMarkedEj($1, $color);
  return $2;
}

function __Z9js_InitGCP9JSRuntimej($rt, $maxbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 48 | 0;
    var $2 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj($1, 16);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $rt + 88 | 0;
    var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($4, 256);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = $rt + 112 | 0;
    var $8 = __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj($7, 256);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$rt + 152 >> 2] = $maxbytes;
    __ZN9JSRuntime19setGCMaxMallocBytesEj($rt, $maxbytes);
    HEAP32[$rt + 160 >> 2] = 3e4;
    __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($rt, 8192, 0);
    var $12 = _PRMJ_Now();
    var $12$0 = $12[0];
    var $12$1 = $12[1];
    var $13$0 = (i64Math.add($12$0, $12$1, 6e7, 0), i64Math.result[0]);
    var $13$1 = i64Math.result[1];
    var $14 = $rt + 184 | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj($1, $len);
  return $2;
}

function __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($this, $lastBytes, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 148 >> 2] = $lastBytes;
    if (($gckind | 0) == 2) {
      var $6 = $lastBytes;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_($lastBytes);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $11 = HEAPU32[$this + 152 >> 2] >>> 0;
    var $12 = __ZN2jsL3MinIfEET_S1_S1_($11, ($6 >>> 0) * 3);
    var $13 = $12 >= 0 ? Math.floor($12) : Math.ceil($12);
    HEAP32[$this + 144 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($trc, $beginv, $endv) {
  var $1 = __ZNK2JS5Value11payloadWordEv($beginv);
  var $2 = __ZNK2JS5Value11payloadWordEv($endv);
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $1, $2);
  return;
}

function __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $2 = HEAP32[$i_01 >> 2];
    __ZN2jsL22MarkWordConservativelyEP8JSTracerj($trc, $2);
    var $3 = $i_01 + 4 | 0;
    if (($3 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js26MarkConservativeStackRootsEP8JSTracer($trc) {
  var $5 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144280 | 0;
  __ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE($trc, $5);
  return;
}

function __ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE($trc, $td) {
  var $2 = HEAP32[$td + 65600 >> 2];
  var $4 = HEAP32[$td + 65608 >> 2];
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $2, $4);
  var $5 = $td + 65612 | 0;
  var $6 = $td + 65652 | 0;
  __ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_($trc, $5, $6);
  return;
}

function __ZN2js24ConservativeGCThreadData14recordStackTopEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  var setjmpTable = {
    "1": (function(value) {
      __label__ = 2;
      $4 = value;
    }),
    dummy: 0
  };
  while (1) try {
    switch (__label__) {
     case 1:
      HEAP32[$this >> 2] = __stackBase__;
      var $4 = (HEAP32[$this + 4 >> 2] = __label__, 0);
      __label__ = 2;
      break;
     case 2:
      STACKTOP = __stackBase__;
      return;
     default:
      assert(0, "bad label: " + __label__);
    }
  } catch (e) {
    if (!e.longjmp) throw e;
    setjmpTable[e.label](e.value);
  }
}

function __Z11js_FinishGCP9JSRuntime($rt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $rt + 4 | 0;
    var $2 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($1);
    var $3 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_05 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_05;
    var $5 = HEAP32[$c_05 >> 2];
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($5);
    var $6 = $c_05 + 4 | 0;
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($1);
    if (($6 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_05 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv($1);
    HEAP32[$rt >> 2] = 0;
    HEAP32[$rt + 72 >> 2] = 0;
    HEAP32[$rt + 76 >> 2] = 0;
    var $12 = $rt + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($r, $12);
    var $13 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $15 = HEAP32[$14 >> 2];
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE(undef, $15);
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $16 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv($12);
    var $17 = $rt + 80 | 0;
    var $18 = HEAP32[$17 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $chunk_01 = $18;
      __label__ = 6;
      break;
    }
   case 6:
    var $chunk_01;
    var $21 = HEAP32[$chunk_01 + 1048320 >> 2];
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE(undef, $chunk_01);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $chunk_01 = $21;
      __label__ = 6;
      break;
    }
   case 7:
    HEAP32[$17 >> 2] = 0;
    HEAP32[$rt + 84 >> 2] = 0;
    var $24 = $rt + 88 | 0;
    __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($24);
    var $25 = $rt + 112 | 0;
    __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv($25);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $1);
  return;
}

function __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE($rt, $p) {
  var $1 = $p;
  __ZN2js11FreeGCChunkEPv($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv($1);
  return;
}

function __Z10js_AddRootP9JSContextPN2JS5ValueEPKc($cx, $vp, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = _js_AddRootRT($2, $vp, $name);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportOutOfMemory($cx);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddRootRT($rt, $vp, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $lock = __stackBase__;
  var $1 = __stackBase__ + 4;
  var $2 = __stackBase__ + 8;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $3 = $rt + 88 | 0;
  HEAP32[$1 >> 2] = $vp;
  __ZN2js8RootInfoC1EPKc12JSGCRootType($2, $name, 0);
  var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($3, $1, $2);
  var $7 = ($5 | 0) != 0 & 1;
  STACKTOP = __stackBase__;
  return $7;
}

function __Z17js_AddGCThingRootP9JSContextPPvPKc($cx, $rp, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = _js_AddGCThingRootRT($2, $rp, $name);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportOutOfMemory($cx);
    __label__ = 3;
    break;
   case 3:
    return $3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_AddGCThingRootRT($rt, $rp, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $lock = __stackBase__;
  var $1 = __stackBase__ + 4;
  var $2 = __stackBase__ + 8;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $3 = $rt + 88 | 0;
  HEAP32[$1 >> 2] = $rp;
  __ZN2js8RootInfoC1EPKc12JSGCRootType($2, $name, 1);
  var $5 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($3, $1, $2);
  var $7 = ($5 | 0) != 0 & 1;
  STACKTOP = __stackBase__;
  return $7;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($2);
    var $9 = $v;
    var $10 = $7 + 4 | 0;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($2);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 3:
    var $14 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($2);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8RootInfoC1EPKc12JSGCRootType($this, $name, $type) {
  __ZN2js8RootInfoC2EPKc12JSGCRootType($this, $name, $type);
  return;
}

function _js_RemoveRoot($rt, $rp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $lock = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $rp;
  __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
  var $2 = $rt + 88 | 0;
  __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_($2, $1);
  HEAP8[$rt + 144088 | 0] = 1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $this, $l);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_MapGCRootsP9JSRuntimePFiPv12JSGCRootTypePKcS1_ES1_($rt, $map, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $e = __stackBase__ + 4;
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    var $1 = $rt + 88 | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($e, $1);
    var $2 = $e | 0;
    var $ct_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $ct_0;
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($2);
    if ($4) {
      var $ct_1 = $ct_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($2);
    var $7 = $ct_0 + 1 | 0;
    var $9 = HEAP32[$6 >> 2];
    var $11 = HEAP32[$6 + 8 >> 2];
    var $13 = HEAP32[$6 + 4 >> 2];
    var $14 = FUNCTION_TABLE[$map]($9, $11, $13, $data);
    if (($14 & 2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e);
    __label__ = 5;
    break;
   case 5:
    if (($14 & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $ct_1 = $7;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($2);
    var $ct_0 = $7;
    __label__ = 2;
    break;
   case 7:
    var $ct_1;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return $ct_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($this, $lastBytes, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 336 >> 2] = $lastBytes;
    if (($gckind | 0) == 2) {
      var $6 = $lastBytes;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_($lastBytes);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    var $13 = HEAPU32[HEAP32[$this >> 2] + 152 >> 2] >>> 0;
    var $14 = __ZN2jsL3MinIfEET_S1_S1_($13, ($6 >>> 0) * 3);
    var $15 = $14 >= 0 ? Math.floor($14) : Math.ceil($14);
    HEAP32[$this + 332 >> 2] = $15;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 0);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 2);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 4);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 6);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 8);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 10);
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 12);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 16);
  return;
}

function __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind) {
  var $1 = $this + 160 + ($thingKind << 3) | 0;
  __ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $1, $thingKind);
  return;
}

function __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, $thingKind);
  return;
}

function __ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 17);
  __ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE($this, $cx, 18);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 19);
  return;
}

function __ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 14);
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 15);
  return;
}

function __ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext($this, $cx) {
  __ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE($this, $cx, 13);
  return;
}

function __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $2 = HEAPU32[$cx + 56 >> 2];
    var $4 = HEAPU32[$2 >> 2];
    var $8 = $4 + 140 | 0;
    var $9 = $4 + 152 | 0;
    var $10 = $2 + 8 | 0;
    var $runGC_0 = (HEAP32[$4 + 196 >> 2] | 0) != 0;
    __label__ = 2;
    break;
   case 2:
    var $runGC_0;
    if ($runGC_0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $13 = __ZN2js2gc11IsGCAllowedEP9JSContext($cx);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    __ZN2js2gcL14RunLastDitchGCEP9JSContext($cx);
    if (HEAPU32[$8 >> 2] >>> 0 > HEAPU32[$9 >> 2] >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $20 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($10, $thingKind, $19);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $20;
      __label__ = 14;
      break;
    }
   case 6:
    var $23 = __ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE($10, $2, $thingKind);
    if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $23;
      __label__ = 14;
      break;
    }
   case 7:
    if ($runGC_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZN2js2gc11IsGCAllowedEP9JSContext($cx);
    if ($27) {
      var $runGC_0 = 1;
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $4);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[__ZN2js8gcReasonE >> 2] = 8;
    __label__ = 12;
    break;
   case 11:
    var $33 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $33;
    __label__ = 12;
    break;
   case 12:
    __ZN2js9TriggerGCEP9JSRuntime($4);
    __label__ = 13;
    break;
   case 13:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL14RunLastDitchGCEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $keep = __stackBase__;
    var $2 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($keep, $2);
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js8gcReasonE >> 2] = 5;
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    var $10 = HEAP32[$2 + 144076 >> 2];
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $10, 0);
    __ZN2js13AutoKeepAtomsD1Ev($keep);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE($this, $comp, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $maybeLock = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2js10AutoLockGCC1EP9JSRuntime($maybeLock, 0);
    var $2 = $this + 160 + ($thingKind << 3) + 4 | 0;
    var $4 = HEAP32[HEAP32[$2 >> 2] >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 4 | 0;
    HEAP32[$2 >> 2] = $7;
    var $8 = $this + ($thingKind << 3) | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($1, $4);
    var $9 = $1;
    var $10 = $8;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($4);
    var $12 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $13 = __ZN2js2gc8FreeSpan18infallibleAllocateEj($8, $12);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZNK2js10AutoLockGC6lockedEv($maybeLock);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = HEAP32[$comp >> 2];
    __ZN2js10AutoLockGC4lockEP9JSRuntime($maybeLock, $18);
    __label__ = 5;
    break;
   case 5:
    var $20 = __ZL9PickChunkP13JSCompartment($comp);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE($20, $comp, $thingKind);
    var $24 = $this + 160 + ($thingKind << 3) | 0;
    var $25 = HEAP32[$24 >> 2];
    var $26 = $23 + 4 | 0;
    HEAP32[$26 >> 2] = $25;
    if ((HEAP32[$24 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$2 >> 2] = $26;
    __label__ = 8;
    break;
   case 8:
    HEAP32[$24 >> 2] = $23;
    var $31 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($23);
    var $32 = $this + ($thingKind << 3) | 0;
    var $33 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($thingKind);
    var $34 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $35 = __ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj($32, $31, $33, $34);
    var $_0 = $35;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE["X"] = 1;

function __ZN2js9TriggerGCEP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 196 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 1;
    HEAP32[$rt + 144076 >> 2] = 0;
    __ZN2js28TriggerAllOperationCallbacksEP9JSRuntime($rt);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_GetGCThingTraceKindPv($thing) {
  var $1 = __ZN2js2gc19GetGCThingTraceKindEPKv($thing);
  return $1;
}

function __ZN2js2gc19GetGCThingTraceKindEPKv($thing) {
  var $1 = $thing;
  var $2 = __ZNK2js2gc4Cell12getAllocKindEv($1);
  var $3 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($2);
  return $3;
}

function __ZN2js8GCMarkerD2Ev($this) {
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv($this) {
  return HEAP32[$this + 12 >> 2] << 3 & -4096;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js2gc18GCCompartmentsIter4doneEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZN2js2gc18GCCompartmentsIter4nextEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __Z16js_LockGCThingRTP9JSRuntimePv($rt, $thing) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lock = __stackBase__ + 4;
    var $p = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $thing;
    if (($thing | 0) == 0) {
      var $_1 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    var $6 = $rt + 112 | 0;
    HEAP32[$2 >> 2] = 0;
    __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj($p, $6, $1, $2);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrcvMSB_FvvEEv($3, $p);
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      var $_1 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrptEv($p);
    var $12 = $11 + 4 | 0;
    var $14 = HEAP32[$12 >> 2] + 1 | 0;
    HEAP32[$12 >> 2] = $14;
    var $_1 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj($agg_result, $this, $k, $defaultValue) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrcvMSB_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$agg_result >> 2] = $8;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E6AddPtrERKS1_RKj($this, $p, $k, $defaultValue);
    var $13 = HEAP32[$p >> 2];
    HEAP32[$agg_result >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrcvMSB_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 124,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __Z18js_UnlockGCThingRTP9JSRuntimePv($rt, $thing) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $lock = __stackBase__ + 4;
    var $p = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $thing;
    if (($thing | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    var $6 = $rt + 112 | 0;
    __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6lookupERKS1_($p, $6, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrcvMSB_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$rt + 144088 | 0] = 1;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrptEv($p);
    var $13 = $12 + 4 | 0;
    var $15 = HEAP32[$13 >> 2] - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    if (($15 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = HEAP32[$p >> 2];
    HEAP32[$3 >> 2] = $19;
    __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E3PtrE($6, $3);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeENSA_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8GCMarkerC2EP9JSContext($this, $cx) {
  HEAP32[$this + 24 >> 2] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  var $3 = $this + 36 | 0;
  var $4 = $cx + 52 | 0;
  var $6 = HEAP32[$4 >> 2] + 204 | 0;
  __ZN2js9MarkStackIP8JSObjectEC1EPPvj($3, $6, 131072);
  var $7 = $this + 48 | 0;
  var $9 = HEAP32[$4 >> 2] + 131276 | 0;
  __ZN2js9MarkStackIP6JSRopeEC1EPPvj($7, $9, 4096);
  var $10 = $this + 60 | 0;
  var $12 = HEAP32[$4 >> 2] + 135372 | 0;
  __ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj($10, $12, 4096);
  var $13 = $this + 72 | 0;
  var $15 = HEAP32[$4 >> 2] + 139468 | 0;
  __ZN2js9MarkStackIP5JSXMLEC1EPPvj($13, $15, 4096);
  var $16 = $this + 84 | 0;
  var $18 = HEAP32[$4 >> 2] + 143564 | 0;
  __ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj($16, $18, 512);
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = -1;
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js9MarkStackIP8JSObjectEC1EPPvj($this, $buffer, $size) {
  __ZN2js9MarkStackIP8JSObjectEC2EPPvj($this, $buffer, $size);
  return;
}

function __ZN2js9MarkStackIP6JSRopeEC1EPPvj($this, $buffer, $size) {
  __ZN2js9MarkStackIP6JSRopeEC2EPPvj($this, $buffer, $size);
  return;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj($this, $buffer, $size) {
  __ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj($this, $buffer, $size);
  return;
}

function __ZN2js9MarkStackIP5JSXMLEC1EPPvj($this, $buffer, $size) {
  __ZN2js9MarkStackIP5JSXMLEC2EPPvj($this, $buffer, $size);
  return;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj($this, $buffer, $size) {
  __ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj($this, $buffer, $size);
  return;
}

function __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js2gc4Cell11arenaHeaderEv($1);
    if ((HEAP32[$2 + 12 >> 2] & 256 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $this + 28 | 0;
    var $10 = HEAP32[$9 >> 2];
    __ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE($2, $10);
    var $11 = __ZN2js2gc11ArenaHeader8getArenaEv($2);
    HEAP32[$9 >> 2] = $11;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE($this, $arena) {
  var $2 = $this + 12 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZNK2js2gc5Arena7addressEv($arena);
  var $9 = $3 & 255 | $4 >>> 3 & 536870400 | 256;
  HEAP32[$2 >> 2] = $9;
  return;
}

function __ZN2js2gc11ArenaHeader8getArenaEv($this) {
  var $1 = __ZNK2js2gc11ArenaHeader12arenaAddressEv($this);
  return $1;
}

function __ZN2js8GCMarker19markDelayedChildrenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $6 = __ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv($4 | 0);
    HEAP32[$1 >> 2] = $6;
    var $8 = $4 + 12 | 0;
    var $10 = HEAP32[$8 >> 2] & -257;
    HEAP32[$8 >> 2] = $10;
    __ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE($this, $4);
    var $11 = HEAP32[$1 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $11;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE($trc, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a | 0;
    var $2 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($1);
    var $3 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($2);
    var $4 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($2);
    var $5 = __ZN2js2gc5Arena9thingsEndEv($a);
    var $6 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($a, $2);
    if (($6 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $trc | 0;
    var $thing_01 = $6;
    __label__ = 3;
    break;
   case 3:
    var $thing_01;
    var $10 = $thing_01;
    var $11 = __ZNK2js2gc4Cell8isMarkedEj($10, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    _JS_TraceChildren($8, $10 | 0, $3);
    __label__ = 5;
    break;
   case 5:
    var $15 = $thing_01 + $4 | 0;
    if (($15 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $thing_01 = $15;
      __label__ = 3;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($trc, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    var $2 = __ZNK2js10StackFrame12isDummyFrameEv($fp);
    if ($2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js10StackFrame10hasArgsObjEv($fp);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2js10StackFrame7argsObjEv($fp);
    var $7 = $6 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $7, undef);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame6scriptEv($fp);
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $9, undef);
    var $10 = __ZNK2js10StackFrame6scriptEv($fp);
    var $11 = $10;
    var $12 = __ZNK2js2gc4Cell11compartmentEv($11);
    HEAP8[$12 + 712 | 0] = 1;
    var $14 = $fp;
    var $15 = __ZN2js10StackFrame11returnValueEv($14);
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $15, undef);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19AutoEnumStateRooter5traceEP8JSTracer($this, $trc) {
  var $2 = HEAP32[$this + 12 >> 2];
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $2, undef);
  return;
}

function __ZN2js11MarkContextEP8JSTracerP9JSContext($trc, $acx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$acx + 132 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK9JSContext12hasRunOptionEj($acx, 8192);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $3, undef);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZN9JSContext18isExceptionPendingEv($acx);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext19getPendingExceptionEv($1, $acx);
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $1, undef);
    __label__ = 6;
    break;
   case 6:
    var $gcr_01 = HEAP32[$acx + 196 >> 2];
    if (($gcr_01 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $gcr_02 = $gcr_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $gcr_02;
    __ZN2js12AutoGCRooter5traceEP8JSTracer($gcr_02, $trc);
    var $gcr_0 = HEAP32[$gcr_02 >> 2];
    if (($gcr_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $gcr_02 = $gcr_0;
      __label__ = 7;
      break;
    }
   case 8:
    var $16 = $acx + 136 | 0;
    if ((HEAP32[$16 >> 2] | 0) > 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $21 = $trc;
    var $22 = $16;
    __Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap($21, $22);
    __label__ = 10;
    break;
   case 10:
    var $24 = $acx + 224 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $24, undef);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoGCRooter5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == -1) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == -3) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == -5) {
      __label__ = 4;
      break;
    } else if (($2 | 0) == -6) {
      __label__ = 5;
      break;
    } else if (($2 | 0) == -7) {
      __label__ = 6;
      break;
    } else if (($2 | 0) == -13) {
      __label__ = 8;
      break;
    } else if (($2 | 0) == -8) {
      __label__ = 16;
      break;
    } else if (($2 | 0) == -9) {
      __label__ = 17;
      break;
    } else if (($2 | 0) == -10) {
      __label__ = 18;
      break;
    } else if (($2 | 0) == -11) {
      __label__ = 20;
      break;
    } else if (($2 | 0) == -12) {
      __label__ = 21;
      break;
    } else if (($2 | 0) == -14) {
      __label__ = 22;
      break;
    } else if (($2 | 0) == -15) {
      __label__ = 24;
      break;
    } else if (($2 | 0) == -4) {
      __label__ = 25;
      break;
    } else if (($2 | 0) == -16) {
      __label__ = 26;
      break;
    } else if (($2 | 0) == -2) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $5, undef);
    __label__ = 29;
    break;
   case 3:
    var $7 = $this;
    __ZN2js6Parser5traceEP8JSTracer($7, $trc);
    __label__ = 29;
    break;
   case 4:
    var $9 = $this;
    __ZN2js19AutoEnumStateRooter5traceEP8JSTracer($9, $trc);
    __label__ = 29;
    break;
   case 5:
    var $13 = HEAP32[$this + 12 >> 2];
    var $15 = HEAP32[$13 >> 2];
    var $16 = $13 + 4 | 0;
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $15, $16, undef);
    __label__ = 29;
    break;
   case 6:
    var $19 = $this + 12 | 0;
    var $20 = __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv($19);
    if (($20 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_01;
    var $22 = __ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj($19, $i_01);
    var $23 = $22 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $23, undef);
    var $24 = $22 + 8 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $24, undef);
    var $25 = $22 + 16 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $25, undef);
    var $26 = $22 + 24 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $26, undef);
    var $27 = $i_01 + 1 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 29;
      break;
    } else {
      var $i_01 = $27;
      __label__ = 7;
      break;
    }
   case 8:
    var $29 = $this + 16 | 0;
    var $31 = HEAP32[$29 >> 2];
    if (($31 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $31, undef);
    __label__ = 10;
    break;
   case 10:
    var $36 = $29 + 16 | 0;
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $36, undef);
    var $37 = $29 + 4 | 0;
    var $38 = HEAP32[$37 >> 2];
    if (($38 & 16 | 0) == 0) {
      var $49 = $38;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = HEAP32[$29 + 8 >> 2];
    if (($44 | 0) == 0) {
      var $49 = $38;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $47 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($44);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $47, undef);
    var $49 = HEAP32[$37 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $49;
    if (($49 & 32 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $55 = HEAP32[$29 + 12 >> 2];
    if (($55 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($55);
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $58, undef);
    __label__ = 29;
    break;
   case 16:
    var $62 = HEAP32[$this + 12 >> 2];
    var $65 = HEAP32[$this + 20 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $62, $65, undef);
    var $69 = HEAP32[$this + 24 >> 2];
    var $70 = $trc;
    __ZN16JSXMLArrayCursor5traceEP8JSTracer($69, $70);
    __label__ = 29;
    break;
   case 17:
    var $75 = $trc;
    var $76 = HEAP32[$this + 12 >> 2];
    _js_TraceXML($75, $76);
    __label__ = 29;
    break;
   case 18:
    var $80 = HEAP32[$this + 12 >> 2];
    if (($80 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $80, undef);
    __label__ = 29;
    break;
   case 20:
    var $86 = HEAP32[$this + 12 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $86, undef);
    __label__ = 29;
    break;
   case 21:
    var $89 = $this + 12 | 0;
    var $90 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv($89);
    var $91 = __ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv($89);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $90, $91, undef);
    __label__ = 29;
    break;
   case 22:
    var $95 = HEAP32[$this + 12 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $95, undef);
    __label__ = 29;
    break;
   case 24:
    var $100 = $this + 12 | 0;
    var $101 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($100);
    var $102 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($100);
    __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $101, $102, undef);
    __label__ = 29;
    break;
   case 25:
    var $105 = $this + 12 | 0;
    var $106 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($105);
    var $107 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($105);
    __ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc($trc, $106, $107, undef);
    __label__ = 29;
    break;
   case 26:
    var $110 = $this + 12 | 0;
    var $111 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv($110);
    var $112 = __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv($110);
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $111, $112, undef);
    __label__ = 29;
    break;
   case 27:
    var $114 = $this;
    var $115 = __ZNK2js14AutoValueArray6lengthEv($114);
    var $116 = __ZNK2js14AutoValueArray5startEv($114);
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $115, $116, undef);
    __label__ = 29;
    break;
   case 28:
    var $120 = HEAP32[$this + 12 >> 2];
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $2, $120, undef);
    __label__ = 29;
    break;
   case 29:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12AutoGCRooter5traceEP8JSTracer["X"] = 1;

function __ZN2js11MarkRuntimeEP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $r1 = __stackBase__ + 8;
    var $iter = __stackBase__ + 16;
    var $c = __stackBase__ + 20;
    var $i = __stackBase__ + 28;
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    if ((HEAP32[$4 + 24 >> 2] | 0) == 3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js26MarkConservativeStackRootsEP8JSTracer($trc);
    __label__ = 3;
    break;
   case 3:
    var $10 = $4 + 88 | 0;
    __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($r, $10);
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $_idx_val = HEAP32[$12 >> 2];
    var $_idx1_val = HEAP32[$12 + 8 >> 2];
    __ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE($trc, $_idx_val, $_idx1_val);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $13 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $14 = $4 + 112 | 0;
    __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv($r1, $14);
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($r1);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv($r1);
    var $_idx2_val = HEAP32[$16 >> 2];
    __ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer($_idx2_val, $trc);
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv($r1);
    var $17 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv($r1);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 7:
    __Z17js_TraceAtomStateP8JSTracer($trc);
    var $18 = $4 + 210584 | 0;
    __ZN2js13StaticStrings5traceEP8JSTracer($18, $trc);
    HEAP32[$iter >> 2] = 0;
    var $19 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($4, 1, $iter);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $21 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $21;
    __ZN2js11MarkContextEP8JSTracerP9JSContext($trc, $21);
    var $22 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($4, 1, $iter);
    if (($22 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $21 = $22;
      __label__ = 8;
      break;
    }
   case 9:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $4);
    var $24 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($24) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZNK2js2gc18GCCompartmentsIterptEv($c);
    if ((HEAP8[$25 + 372 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN13JSCompartment9markTypesEP8JSTracer($25, $trc);
    __label__ = 12;
    break;
   case 12:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $32 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 13:
    __ZN2js14ThreadDataIterC1EP9JSRuntime($i, $4);
    var $33 = __ZNK2js14ThreadDataIter5emptyEv($i);
    if ($33) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $34 = __ZNK2js14ThreadDataIter10threadDataEv($i);
    __ZN2js10ThreadData4markEP8JSTracer($34, $trc);
    __ZN2js14ThreadDataIter8popFrontEv($i);
    var $35 = __ZNK2js14ThreadDataIter5emptyEv($i);
    if ($35) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 15:
    var $37 = HEAP32[$4 + 144100 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $41 = HEAP32[$4 + 144104 >> 2];
    FUNCTION_TABLE[$37]($trc, $41);
    __label__ = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11MarkRuntimeEP8JSTracer["X"] = 1;

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE($trc, $entry_0_0_val, $entry_0_1_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($entry_0_1_1_val | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$entry_0_0_val >> 2];
    __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $4);
    __label__ = 4;
    break;
   case 3:
    var $6 = $entry_0_0_val;
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $6);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv($agg_result, $1);
  return;
}

function __ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer($entry_0_0_val, $trc) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPvPKc($trc, $entry_0_0_val, undef);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($this, $rt) {
  __ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime($this, $rt);
  return;
}

function __ZNK2js2gc18GCCompartmentsIterptEv($this) {
  var $1 = __ZNK2js2gc18GCCompartmentsIter3getEv($this);
  return $1;
}

function __ZN2js10ThreadData4markEP8JSTracer($this, $trc) {
  var $2 = $this + 4 | 0;
  var $3 = $trc;
  __ZN2js10StackSpace4markEP8JSTracer($2, $3);
  return;
}

function __ZN2js7MaybeGCEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$cx + 52 >> 2];
    var $4 = HEAPU32[$cx + 56 >> 2];
    if ((HEAP32[$2 + 196 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $13;
    __label__ = 5;
    break;
   case 5:
    var $18 = ($4 | 0) == (HEAP32[$2 + 144076 >> 2] | 0) ? $4 : 0;
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $18, 0);
    __label__ = 20;
    break;
   case 6:
    var $21 = HEAPU32[$4 + 328 >> 2];
    if ($21 >>> 0 > 8192) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    if ($21 >>> 0 < ((HEAPU32[$4 + 332 >> 2] >>> 2) * 3 | 0) >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 11;
    break;
   case 10:
    var $34 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $34;
    __label__ = 11;
    break;
   case 11:
    var $39 = (HEAP32[$2 + 192 >> 2] | 0) == 1 ? $4 : 0;
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $39, 0);
    __label__ = 20;
    break;
   case 12:
    var $41 = _PRMJ_Now();
    var $41$0 = $41[0];
    var $41$1 = $41[1];
    var $42 = $2 + 176 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    if (($43$0 == 0 && $43$1 == 0) | (($43$1 | 0) > ($41$1 | 0) || ($43$1 | 0) == ($41$1 | 0) && $43$0 >>> 0 > $41$0 >>> 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP8[$2 + 172 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if ((HEAP32[$2 + 80 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[__ZN2js8gcReasonE >> 2] = 1;
    __label__ = 18;
    break;
   case 17:
    var $60 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $60;
    __label__ = 18;
    break;
   case 18:
    __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, 0, 2);
    __label__ = 20;
    break;
   case 19:
    var $63$0 = (i64Math.add($41$0, $41$1, 2e7, 0), i64Math.result[0]);
    var $63$1 = i64Math.result[1];
    HEAP32[$42 >> 2] = $63$0;
    HEAP32[$42 + 4 >> 2] = $63$1;
    __label__ = 20;
    break;
   case 20:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7MaybeGCEP9JSContext["X"] = 1;

function __ZN2js2gc10RunDebugGCEP9JSContext($cx) {
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN13AutoGCSessionC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP8[HEAP32[$cx + 52 >> 2] + 144090 | 0] = 1;
  return;
}

function __ZN13AutoGCSessionD2Ev($this) {
  HEAP8[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 144090 | 0] = 0;
  return;
}

function __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($thingKind) {
  return HEAP32[__ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map + ($thingKind << 2) >> 2];
}

function __ZNK2js2gc12CellIterImpl7getCellEv($this) {
  return HEAP32[$this + 28 >> 2];
}

function __ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj($this, $buffer, $size) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = ($size >>> 3) - 1 | 0;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP5JSXMLEC2EPPvj($this, $buffer, $size) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = ($size >>> 2) - 1 | 0;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj($this, $buffer, $size) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = ($size >>> 2) - 1 | 0;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP6JSRopeEC2EPPvj($this, $buffer, $size) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = ($size >>> 2) - 1 | 0;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js9MarkStackIP8JSObjectEC2EPPvj($this, $buffer, $size) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = ($size >>> 2) - 1 | 0;
  HEAP32[$this >> 2] = $buffer;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPvjEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPvEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPvEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind($cx, $comp, $gckind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gcTimer = __stackBase__;
    var $autoGCProbe = __stackBase__ + 80;
    var $lock = __stackBase__ + 84;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $6 = ($gckind | 0) == 1;
    if ((HEAP32[$2 + 24 >> 2] | 0) == 2 | $6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($2);
    __ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment($gcTimer, $2, $comp);
    __ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_($autoGCProbe, $comp);
    var $10 = $2 + 144092 | 0;
    var $11 = $2 + 144088 | 0;
    __label__ = 3;
    break;
   case 3:
    var $12 = HEAP32[$10 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = FUNCTION_TABLE[$12]($cx, 0);
    if (($15 | 0) != 0 | $6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    HEAP8[$11] = 0;
    __ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE($cx, $comp, $gckind, $gcTimer);
    var $18 = HEAP32[$10 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = FUNCTION_TABLE[$18]($cx, 1);
    __label__ = 7;
    break;
   case 7:
    if ($6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if ((HEAP8[$11] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 9:
    var $27 = _PRMJ_Now();
    var $27$0 = $27[0];
    var $27$1 = $27[1];
    var $28$0 = (i64Math.add($27$0, $27$1, 2e7, 0), i64Math.result[0]);
    var $28$1 = i64Math.result[1];
    var $29 = $2 + 176 | 0;
    var $st$7$0 = $29 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $29 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    HEAP8[$2 + 172 | 0] = 0;
    __ZN2js7GCTimer6finishEb($gcTimer, undef);
    __label__ = 10;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind["X"] = 1;

function __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($cx_0_11_val) {
  var $1 = $cx_0_11_val + 209888 | 0;
  __ZN2js24ConservativeGCThreadData14recordStackTopEv($1);
  return;
}

function __ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE($cx, $comp, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gcsession = __stackBase__;
    var $sc = __stackBase__ + 4;
    var $unlock = __stackBase__ + 16;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 144089 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    __ZN13AutoGCSessionC2EP9JSContext($gcsession, $cx);
    if ((HEAP32[$2 + 229028 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    __ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment($sc, $cx, 0);
    var $12 = $2 + 144080 | 0;
    HEAP32[$12 >> 2] = $comp;
    HEAP8[$3] = 1;
    __ZN2js12AutoUnlockGCC1EP9JSRuntime($unlock, $2);
    __ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE($cx, $gckind, $gcTimer);
    HEAP8[$3] = 0;
    HEAP8[$2 + 144091 | 0] = 0;
    var $15 = HEAP32[$2 + 140 >> 2];
    __ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind($2, $15, $gckind);
    HEAP32[$12 >> 2] = 0;
    var $16 = $2 + 200 | 0;
    HEAP32[$16 >> 2] = 0;
    var $17 = $2 + 4 | 0;
    var $18 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($17);
    var $19 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($17);
    if (($18 | 0) == ($19 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_01 = $18;
      __label__ = 4;
      break;
    }
   case 4:
    var $c_01;
    var $21 = HEAP32[$c_01 >> 2];
    var $23 = HEAP32[$21 + 328 >> 2];
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($21, $23, $gckind);
    var $24 = $c_01 + 4 | 0;
    var $25 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($17);
    if (($24 | 0) == ($25 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_01 = $24;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js19SwitchToCompartmentD1Ev($sc);
    __label__ = 6;
    break;
   case 6:
    __ZN13AutoGCSessionD2Ev($gcsession);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12TraceRuntimeEP8JSTracer($trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $copy = __stackBase__;
  var $1 = $trc | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
  __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($copy, $4);
  var $_idx_val = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
  __ZN2jsL25RecordNativeStackTopForGCEP9JSContext($_idx_val);
  __ZN2js11MarkRuntimeEP8JSTracer($trc);
  __ZN2js24AutoCopyFreeListToArenasD1Ev($copy);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($this, $rt) {
  __ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js24AutoCopyFreeListToArenasD1Ev($this) {
  __ZN2js24AutoCopyFreeListToArenasD2Ev($this);
  return;
}

function __ZN2js30IterateCompartmentsArenasCellsEP9JSContextPvPFvS1_S2_P13JSCompartmentEPFvS1_S2_PNS_2gc5ArenaE13JSGCTraceKindjEPFvS1_S2_S2_SA_jE($cx, $data, $compartmentCallback, $arenaCallback, $cellCallback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $gcsession = __stackBase__ + 4;
    var $unlock = __stackBase__ + 8;
    var $copy = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 36;
    var $4 = HEAP32[$cx + 52 >> 2];
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $4);
    __ZN13AutoGCSessionC2EP9JSContext($gcsession, $cx);
    __ZN2js12AutoUnlockGCC1EP9JSRuntime($unlock, $4);
    __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($copy, $4);
    var $5 = $4 + 4 | 0;
    var $6 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($5);
    var $7 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($5);
    if (($6 | 0) == ($7 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_02 = $6;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_02;
    var $9 = HEAP32[$c_02 >> 2];
    FUNCTION_TABLE[$compartmentCallback]($cx, $data, $9);
    var $thingKind_01 = 0;
    __label__ = 3;
    break;
   case 3:
    var $thingKind_01;
    var $11 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($thingKind_01);
    var $12 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind_01);
    __ZN2js22IterateArenaCallbackOpC1EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j($1, $cx, $data, $arenaCallback, $11, $12);
    __ZN2js21IterateCellCallbackOpC1EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j($2, $cx, $data, $cellCallback, $11, $12);
    __ZN2js2gc19ForEachArenaAndCellINS_22IterateArenaCallbackOpENS_21IterateCellCallbackOpEEEvP13JSCompartmentNS0_9AllocKindET_T0_($9, $thingKind_01, $1, $2);
    var $13 = $thingKind_01 + 1 | 0;
    if (($13 | 0) == 20) {
      __label__ = 4;
      break;
    } else {
      var $thingKind_01 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    var $16 = $c_02 + 4 | 0;
    var $17 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($5);
    if (($16 | 0) == ($17 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $c_02 = $16;
      __label__ = 2;
      break;
    }
   case 5:
    __ZN2js24AutoCopyFreeListToArenasD1Ev($copy);
    __ZN13AutoGCSessionD2Ev($gcsession);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoUnlockGCC1EP9JSRuntime($this, $rt) {
  __ZN2js12AutoUnlockGCC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js22IterateArenaCallbackOpC1EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j($this, $cx, $data, $callback, $traceKind, $thingSize) {
  __ZN2js22IterateArenaCallbackOpC2EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j($this, $cx, $data, $callback, $traceKind, $thingSize);
  return;
}

function __ZN2js21IterateCellCallbackOpC1EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j($this, $cx, $data, $callback, $traceKind, $thingSize) {
  __ZN2js21IterateCellCallbackOpC2EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j($this, $cx, $data, $callback, $traceKind, $thingSize);
  return;
}

function __ZN2js2gc19ForEachArenaAndCellINS_22IterateArenaCallbackOpENS_21IterateCellCallbackOpEEEvP13JSCompartmentNS0_9AllocKindET_T0_($compartment, $thingKind, $arenaOp, $cellOp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $arenaOp;
  $arenaOp = STACKTOP;
  STACKTOP += 20;
  HEAP32[$arenaOp >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$arenaOp + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$arenaOp + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  HEAP32[$arenaOp + 12 >> 2] = HEAP32[tempParam + 12 >> 2];
  HEAP32[$arenaOp + 16 >> 2] = HEAP32[tempParam + 16 >> 2];
  var tempParam = $cellOp;
  $cellOp = STACKTOP;
  STACKTOP += 20;
  HEAP32[$cellOp >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$cellOp + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$cellOp + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  HEAP32[$cellOp + 12 >> 2] = HEAP32[tempParam + 12 >> 2];
  HEAP32[$cellOp + 16 >> 2] = HEAP32[tempParam + 16 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstSpan = __stackBase__;
    var $1 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $2 = $compartment + 8 | 0;
    var $3 = __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($2, $thingKind);
    if (($3 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $aheader_01;
    var $5 = __ZN2js2gc11ArenaHeader8getArenaEv($aheader_01);
    __ZN2js22IterateArenaCallbackOpclEPNS_2gc5ArenaE($arenaOp, $5);
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($firstSpan, $aheader_01);
    var $6 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($5, $thingKind);
    var $thing_0 = $6;
    var $span_0 = $firstSpan;
    __label__ = 3;
    break;
   case 3:
    var $span_0;
    var $thing_0;
    if (($thing_0 | 0) == (HEAP32[$span_0 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZNK2js2gc8FreeSpan7hasNextEv($span_0);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $15 = HEAP32[$span_0 + 4 >> 2];
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($span_0);
    var $thing_1 = $15;
    var $span_1 = $16;
    __label__ = 7;
    break;
   case 6:
    __ZN2js21IterateCellCallbackOpclEPNS_2gc4CellE($cellOp, $thing_0);
    var $thing_1 = $thing_0;
    var $span_1 = $span_0;
    __label__ = 7;
    break;
   case 7:
    var $span_1;
    var $thing_1;
    var $thing_0 = $thing_1 + $1 | 0;
    var $span_0 = $span_1;
    __label__ = 3;
    break;
   case 8:
    var $23 = HEAP32[$aheader_01 + 4 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $23;
      __label__ = 2;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE($cx, $compartment, $thingKind, $data, $cellCallback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $gcsession = __stackBase__ + 4;
    var $unlock = __stackBase__ + 8;
    var $copy = __stackBase__ + 12;
    var $i = __stackBase__ + 16;
    var $i1 = __stackBase__ + 48;
    var $2 = HEAP32[$cx + 52 >> 2];
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    __ZN13AutoGCSessionC2EP9JSContext($gcsession, $cx);
    __ZN2js12AutoUnlockGCC1EP9JSRuntime($unlock, $2);
    __ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime($copy, $2);
    var $3 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($thingKind);
    var $4 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    if (($compartment | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i, $compartment, $thingKind);
    var $7 = $i | 0;
    var $8 = __ZNK2js2gc12CellIterImpl4doneEv($7);
    if ($8) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js2gc12CellIterImpl7getCellEv($7);
    var $10 = $9 | 0;
    FUNCTION_TABLE[$cellCallback]($cx, $data, $10, $3, $4);
    __ZN2js2gc12CellIterImpl4nextEv($7);
    var $11 = __ZNK2js2gc12CellIterImpl4doneEv($7);
    if ($11) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $13 = $2 + 4 | 0;
    var $14 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($13);
    var $15 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($13);
    if (($14 | 0) == ($15 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $i1 | 0;
    var $c_03 = $14;
    __label__ = 6;
    break;
   case 6:
    var $c_03;
    var $19 = HEAP32[$c_03 >> 2];
    __ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE($i1, $19, $thingKind);
    var $20 = __ZNK2js2gc12CellIterImpl4doneEv($17);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = __ZNK2js2gc12CellIterImpl7getCellEv($17);
    var $22 = $21 | 0;
    FUNCTION_TABLE[$cellCallback]($cx, $data, $22, $3, $4);
    __ZN2js2gc12CellIterImpl4nextEv($17);
    var $23 = __ZNK2js2gc12CellIterImpl4doneEv($17);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 8:
    var $24 = $c_03 + 4 | 0;
    var $25 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($13);
    if (($24 | 0) == ($25 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $c_03 = $24;
      __label__ = 6;
      break;
    }
   case 9:
    __ZN2js24AutoCopyFreeListToArenasD1Ev($copy);
    __ZN13AutoGCSessionD2Ev($gcsession);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE["X"] = 1;

function __ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals($cx, $principals) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    var $2 = HEAPU32[$cx + 52 >> 2];
    var $3 = __ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_($cx, $2);
    if (($3 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN13JSCompartment4initEP9JSContext($3, $cx);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    if (($principals | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $2;
    var $11 = __ZNK9JSRuntime17trustedPrincipalsEv($10);
    HEAP8[$3 + 341 | 0] = ($11 | 0) == ($principals | 0) & 1;
    HEAP32[$3 + 4 >> 2] = $principals;
    var $17 = $principals + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    __label__ = 6;
    break;
   case 5:
    HEAP8[$3 + 341 | 0] = 0;
    __label__ = 6;
    break;
   case 6:
    __ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind($3, 8192, 0);
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $2);
    var $22 = $2 + 4 | 0;
    var $23 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($22, $3);
    if ($23) {
      var $_1 = $3;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 8;
    break;
   case 8:
    __ZN2js10Foreground7delete_I13JSCompartmentEEvPT_($3);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 1988);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN13JSCompartmentC2EP9JSRuntime($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_NewGCXMLP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($cx);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[_sE4XObjectsCreated >> 2] + 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    var $6 = __Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj($cx, 16, 72);
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22IterateArenaCallbackOpclEPNS_2gc5ArenaE($this, $arena) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  var $6 = HEAP32[$this + 4 >> 2];
  var $8 = HEAP32[$this + 12 >> 2];
  var $10 = HEAP32[$this + 16 >> 2];
  FUNCTION_TABLE[$2]($4, $6, $arena, $8, $10);
  return;
}

function __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind) {
  var $1 = __ZNK2js2gc5Arena7addressEv($this);
  var $2 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($thingKind);
  return $2 | $1;
}

function __ZN2js21IterateCellCallbackOpclEPNS_2gc4CellE($this, $cell) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  var $6 = HEAP32[$this + 4 >> 2];
  var $7 = $cell | 0;
  var $9 = HEAP32[$this + 12 >> 2];
  var $11 = HEAP32[$this + 16 >> 2];
  FUNCTION_TABLE[$2]($4, $6, $7, $9, $11);
  return;
}

function __ZNK2js2gc5Arena7addressEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js2gc11ArenaHeader7addressEv($1);
  return $2;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + HEAP32[$this + 4 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeENSA_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPvjEEEENS_7MoveRefIT_EERS5_($1, $8);
  __ZN2js12HashMapEntryIPvjEaSENS_7MoveRefIS2_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPvjEaSENS_7MoveRefIS2_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPvjEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefIPvEcvRS1_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIPvjEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIjEENS_7MoveRefIT_EERS2_($2, $9);
  var $10 = __ZNK2js7MoveRefIjEcvRjEv($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPvjEEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC2ERS3_($this, $t);
  return;
}

function __ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefIPvEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPvEC1ERS1_($this, $t) {
  __ZN2js7MoveRefIPvEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvjEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPvjEC1Ev($this) {
  __ZN2js12HashMapEntryIPvjEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js11GCPtrHasher5matchEPvS1_($l, $k) {
  return ($l | 0) == ($k | 0);
}

function __ZN2js11GCPtrHasher4hashEPv($key) {
  return $key >>> 3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIPvLj2EE4hashERKS1_($l) {
  return HEAP32[$l >> 2] >>> 2;
}

function __ZN2js12HashMapEntryIPvjEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIPvjEaSERKS2_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $6 = $rhs + 4 | 0;
  var $7 = $this + 4 | 0;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_8RootInfoEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvjEC1Ev($1);
  __ZN2js12HashMapEntryIPvjEaSERKS2_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvjEC1Ev($1);
  __ZN2js12HashMapEntryIPvjEaSERKS2_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11prepareHashERKS3_($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN2js11GCPtrHasher4hashEPv($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5matchERNS0_14HashTableEntryIS4_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5matchERNS0_14HashTableEntryIS4_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5matchERNS0_14HashTableEntryIS4_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = HEAP32[$l >> 2];
  var $5 = __ZN2js11GCPtrHasher5matchEPvS1_($3, $4);
  return $5;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E6AddPtrERKS1_RKj($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrEPPS4_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrEPPS4_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($1);
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($1);
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($this) {
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefIPvEcvRS1_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = $this + 4 | 0;
  var $9 = __ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv($rhs);
  var $10 = $9 + 4 | 0;
  __ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_($2, $10);
  var $11 = __ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev($2);
  var $12 = $11;
  var $13 = $8;
  var $14$0 = HEAP32[$12 >> 2];
  var $14$1 = HEAP32[$12 + 4 >> 2];
  HEAP32[$13 >> 2] = $14$0;
  HEAP32[$13 + 4 >> 2] = $14$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8RootInfoEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_8RootInfoEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8RootInfoEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 126,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l) {
  var $1 = __ZN2js13PointerHasherIPvLj2EE4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($1);
  var $3 = __ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = $v;
    var $9 = $5 + 4 | 0;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    var $st$11$0 = $9 | 0;
    HEAP32[$st$11$0 >> 2] = $10$0;
    var $st$11$1 = $9 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($t) {
  return $t;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_($k, $l) {
  return ($k | 0) == ($l | 0);
}

function __ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE($chunk) {
  return $chunk >>> 20;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js21IterateCellCallbackOpC2EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j($this, $cx, $data, $callback, $traceKind, $thingSize) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $data;
  HEAP32[$this + 8 >> 2] = $callback;
  HEAP32[$this + 12 >> 2] = $traceKind;
  HEAP32[$this + 16 >> 2] = $thingSize;
  return;
}

function __ZN2js22IterateArenaCallbackOpC2EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j($this, $cx, $data, $callback, $traceKind, $thingSize) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $data;
  HEAP32[$this + 8 >> 2] = $callback;
  HEAP32[$this + 12 >> 2] = $traceKind;
  HEAP32[$this + 16 >> 2] = $thingSize;
  return;
}

function __ZN2js12AutoUnlockGCC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($this) {
  HEAP32[$this + 8 >> 2] = 268374016;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv($this) {
  var $3 = HEAP32[$this + 20 >> 2];
  var $6 = HEAP32[$this + 4 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + ($6 << 4) | 0;
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $e_01;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE($e_01, $1);
    var $9 = $e_01 + 16 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + ($6 << 3) | 0;
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $e_01;
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($e_01, $1);
    var $9 = $e_01 + 8 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_($1, $7);
  var $8 = __ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev($this);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_($this, $t);
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 128,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $2);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = HEAP32[$l >> 2];
  var $5 = __ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_($3, $4);
  return $5;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js24AutoCopyFreeListToArenasD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = HEAP32[$1 >> 2] + 4 | 0;
    var $4 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($3);
    var $5 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($3);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_01;
    var $8 = HEAP32[$c_01 >> 2] + 8 | 0;
    __ZN2js2gc10ArenaLists22clearFreeListsInArenasEv($8);
    var $9 = $c_01 + 4 | 0;
    var $11 = HEAP32[$1 >> 2] + 4 | 0;
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($11);
    if (($9 | 0) == ($12 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists22clearFreeListsInArenasEv($this) {
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 0);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 1);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 2);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 3);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 4);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 5);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 6);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 7);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 8);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 9);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 10);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 11);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 12);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 13);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 14);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 15);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 16);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 17);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 18);
  __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, 19);
  return;
}

function __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($this, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + ($kind << 3) | 0;
    var $2 = __ZNK2js2gc8FreeSpan7isEmptyEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($1);
    __ZN2js2gc11ArenaHeader14setAsFullyUsedEv($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $rt;
    var $2 = $rt + 4 | 0;
    var $3 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($2);
    var $4 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($2);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $c_01;
    var $7 = HEAP32[$c_01 >> 2] + 8 | 0;
    __ZN2js2gc10ArenaLists21copyFreeListsToArenasEv($7);
    var $8 = $c_01 + 4 | 0;
    var $9 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($2);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $c_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists21copyFreeListsToArenasEv($this) {
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 0);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 1);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 2);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 3);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 4);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 5);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 6);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 7);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 8);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 9);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 10);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 11);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 12);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 13);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 14);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 15);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 16);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 17);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 18);
  __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, 19);
  return;
}

function __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($this, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + ($thingKind << 3) | 0;
    var $2 = __ZNK2js2gc8FreeSpan7isEmptyEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($1);
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE($cx, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var $gcmarker = __stackBase__;
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = $2 + 164 | 0;
  var $5 = HEAP32[$3 >> 2] + 1 | 0;
  HEAP32[$3 >> 2] = $5;
  var $6 = $2 + 196 | 0;
  HEAP32[$6 >> 2] = 0;
  var $7 = $2 + 144076 | 0;
  HEAP32[$7 >> 2] = 0;
  __ZN9JSRuntime18resetGCMallocBytesEv($2);
  __ZN2js8GCMarkerC2EP9JSContext($gcmarker, $cx);
  var $8 = $2 + 168 | 0;
  HEAP32[$8 >> 2] = $gcmarker;
  __ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gcTimer);
  __ZN2js8GCMarker14drainMarkStackEv($gcmarker);
  __ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker);
  __ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gckind, $gcTimer);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) == 20) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$this + 160 + ($i_0 << 3) >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_($begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($begin | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $begin;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    if (($p_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$p_01 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $5 = $p_01 + 4 | 0;
    if (($5 | 0) == ($end | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $5;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js2gc18GCCompartmentsIter3getEv($this) {
  return HEAP32[HEAP32[$this >> 2] >> 2];
}

function __ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_($this, $comp) {
  HEAP32[$this >> 2] = $comp;
  return;
}

function __ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js14AutoValueArray6lengthEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js14AutoValueArray5startEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js2gc8FreeSpan18infallibleAllocateEj($this, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ($2 >>> 0 < HEAPU32[$this + 4 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $2 + $thingSize | 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = $2;
    var $10 = $this;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    __label__ = 4;
    break;
   case 4:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10AutoLockGC6lockedEv($this) {
  return (HEAP32[$this >> 2] | 0) != 0;
}

function __ZN2js10AutoLockGC4lockEP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  return;
}

function __ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj($this, $arenaAddr, $firstThingOffset, $thingSize) {
  var $1 = $firstThingOffset | $arenaAddr;
  HEAP32[$this >> 2] = $1 + $thingSize | 0;
  HEAP32[$this + 4 >> 2] = $arenaAddr | 4095;
  return $1;
}

function __Z21GetAvailableChunkListP13JSCompartment($comp) {
  var $2 = HEAP32[$comp >> 2];
  var $9 = (HEAP8[$comp + 341 | 0] & 1) << 24 >> 24 != 0 ? $2 + 72 | 0 : $2 + 76 | 0;
  return $9;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js13AutoKeepAtomsD2Ev($this) {
  var $3 = HEAP32[$this >> 2] + 136 | 0;
  var $5 = HEAP32[$3 >> 2] - 1 | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js13AutoKeepAtomsC2EP9JSRuntime($this, $rt) {
  HEAP32[$this >> 2] = $rt;
  var $2 = $rt + 136 | 0;
  var $4 = HEAP32[$2 >> 2] + 1 | 0;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $r = __stackBase__ + 12;
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $2 + 209944 | 0;
    if ((HEAP32[$3 >> 2] & 16777216 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$2 + 144091 | 0] = 1;
    HEAP32[$3 >> 2] = 0;
    var $9 = $2 + 44 | 0;
    HEAP32[$9 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $2);
    var $11 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK2js2gc18GCCompartmentsIterptEv($c);
    __ZN13JSCompartment5purgeEP9JSContext($12, undef);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $13 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    __Z15js_PurgeThreadsP9JSContext($cx);
    HEAP32[$iter >> 2] = 0;
    var $14 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($2, 1, $iter);
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $16 = $14;
      __label__ = 6;
      break;
    }
   case 6:
    var $16;
    __ZN9JSContext5purgeEv($16);
    var $17 = __Z18js_ContextIteratorP9JSRuntimeiPP9JSContext($2, 1, $iter);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $16 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    if ((HEAP8[$gcTimer + 77 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = _PRMJ_Now();
    var $24$1 = $24[1];
    var $25 = $gcTimer + 12 | 0;
    HEAP32[$25 >> 2] = $24[0];
    HEAP32[$25 + 4 >> 2] = $24$1;
    __label__ = 9;
    break;
   case 9:
    var $27 = $2 + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv($r, $27);
    var $28 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv($r);
    var $31 = HEAP32[$29 >> 2] + 1032192 | 0;
    __ZN2js2gc11ChunkBitmap5clearEv($31);
    __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv($r);
    var $32 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv($r);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 11:
    if ((HEAP32[$2 + 144080 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_pre_phi = $gcmarker | 0;
    __label__ = 16;
    break;
   case 13:
    var $37 = $2 + 4 | 0;
    var $38 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($37);
    var $39 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($37);
    var $_pre1 = $gcmarker | 0;
    if (($38 | 0) == ($39 | 0)) {
      var $_pre_phi2 = $_pre1;
      __label__ = 15;
      break;
    } else {
      var $c1_01 = $38;
      __label__ = 14;
      break;
    }
   case 14:
    var $c1_01;
    var $41 = HEAP32[$c1_01 >> 2];
    __ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer($41, $_pre1);
    var $42 = $c1_01 + 4 | 0;
    var $43 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($37);
    if (($42 | 0) == ($43 | 0)) {
      var $_pre_phi2 = $_pre1;
      __label__ = 15;
      break;
    } else {
      var $c1_01 = $42;
      __label__ = 14;
      break;
    }
   case 15:
    var $_pre_phi2;
    __ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer($_pre_phi2);
    var $_pre_phi = $_pre_phi2;
    __label__ = 16;
    break;
   case 16:
    var $_pre_phi;
    __ZN2js11MarkRuntimeEP8JSTracer($_pre_phi);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE["X"] = 1;

function __ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $gcmarker | 0;
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer($3);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer($3);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE($gcmarker);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js8GCMarker14drainMarkStackEv($gcmarker);
    __label__ = 2;
    break;
   case 6:
    var $11 = $2 + 168 | 0;
    HEAP32[$11 >> 2] = 0;
    var $13 = HEAP32[$2 + 144092 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = FUNCTION_TABLE[$13]($cx, 2);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE($cx, $gcmarker, $gckind, $gcTimer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c = __stackBase__;
    var $c1 = __stackBase__ + 8;
    var $c2 = __stackBase__ + 16;
    var $c3 = __stackBase__ + 24;
    var $c4 = __stackBase__ + 32;
    var $c5 = __stackBase__ + 40;
    var $c6 = __stackBase__ + 48;
    var $c7 = __stackBase__ + 56;
    var $1 = $cx + 52 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $gcTimer + 77 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _PRMJ_Now();
    var $8$1 = $8[1];
    var $9 = $gcTimer + 20 | 0;
    var $st$4$0 = $9 | 0;
    HEAP32[$st$4$0 >> 2] = $8[0];
    var $st$4$1 = $9 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $8$1;
    __label__ = 3;
    break;
   case 3:
    var $11 = $gcmarker | 0;
    __ZN2js11WeakMapBase8sweepAllEP8JSTracer($11);
    __Z17js_SweepAtomStateP9JSContext($cx);
    __ZN2js13WatchpointMap8sweepAllEP9JSContext($cx);
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c, $2);
    var $12 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c);
    var $13 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $14 = $2 + 144080 | 0;
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $21 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2js8Debugger8sweepAllEP9JSContext($cx);
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $cx_idx_val = HEAP32[$1 >> 2];
    var $20 = __ZL25ComputeJitReleaseIntervalP9JSContext($cx_idx_val);
    var $21 = $20;
    __label__ = 8;
    break;
   case 8:
    var $21;
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c1, $2);
    var $22 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c1);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = __ZNK2js2gc18GCCompartmentsIterptEv($c1);
    __ZN13JSCompartment5sweepEP9JSContextj($23, $cx, $21);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c1);
    var $24 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c1);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 10:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c2, $2);
    var $25 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c2);
    if ($25) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZNK2js2gc18GCCompartmentsIterptEv($c2);
    var $27 = $26 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext($27, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c2);
    var $28 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c2);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 12:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $33 = _PRMJ_Now();
    var $33$1 = $33[1];
    var $34 = $gcTimer + 28 | 0;
    var $st$4$0 = $34 | 0;
    HEAP32[$st$4$0 >> 2] = $33[0];
    var $st$4$1 = $34 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $33$1;
    __label__ = 14;
    break;
   case 14:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c3, $2);
    var $36 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c3);
    if ($36) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = __ZNK2js2gc18GCCompartmentsIterptEv($c3);
    var $38 = $37 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext($38, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c3);
    var $39 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c3);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 16:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = _PRMJ_Now();
    var $44$1 = $44[1];
    var $45 = $gcTimer + 36 | 0;
    var $st$4$0 = $45 | 0;
    HEAP32[$st$4$0 >> 2] = $44[0];
    var $st$4$1 = $45 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $44$1;
    __label__ = 18;
    break;
   case 18:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c4, $2);
    var $47 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c4);
    if ($47) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $48 = __ZNK2js2gc18GCCompartmentsIterptEv($c4);
    var $49 = $48 + 8 | 0;
    __ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext($49, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c4);
    var $50 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c4);
    if ($50) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 20:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $55 = _PRMJ_Now();
    var $55$1 = $55[1];
    var $56 = $gcTimer + 44 | 0;
    var $st$4$0 = $56 | 0;
    HEAP32[$st$4$0 >> 2] = $55[0];
    var $st$4$1 = $56 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $55$1;
    __label__ = 22;
    break;
   case 22:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c5, $2);
    var $58 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c5);
    if ($58) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $59 = __ZNK2js2gc18GCCompartmentsIterptEv($c5);
    var $60 = $59 + 8 | 0;
    __ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext($60, $cx);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c5);
    var $61 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c5);
    if ($61) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 24:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $66 = _PRMJ_Now();
    var $66$1 = $66[1];
    var $67 = $gcTimer + 52 | 0;
    var $st$4$0 = $67 | 0;
    HEAP32[$st$4$0 >> 2] = $66[0];
    var $st$4$1 = $67 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $66$1;
    __label__ = 26;
    break;
   case 26:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c6, $2);
    var $69 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c6);
    if ($69) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js2gc18GCCompartmentsIter4nextEv($c6);
    var $70 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c6);
    if ($70) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 28:
    __ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime($c7, $2);
    var $71 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c7);
    if ($71) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $72 = __ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv($c7);
    var $73 = $72;
    __Z23js_SweepScriptFilenamesP13JSCompartment($73);
    __ZN2js2gc18GCCompartmentsIter4nextEv($c7);
    var $74 = __ZNK2js2gc18GCCompartmentsIter4doneEv($c7);
    if ($74) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 30:
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind($cx, $gckind);
    __label__ = 32;
    break;
   case 32:
    __ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind($2, $gckind);
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $83 = _PRMJ_Now();
    var $83$1 = $83[1];
    var $84 = $gcTimer + 60 | 0;
    var $st$4$0 = $84 | 0;
    HEAP32[$st$4$0 >> 2] = $83[0];
    var $st$4$1 = $84 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $83$1;
    __label__ = 34;
    break;
   case 34:
    var $87 = HEAP32[$2 + 144092 >> 2];
    if (($87 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $90 = FUNCTION_TABLE[$87]($cx, 3);
    __label__ = 36;
    break;
   case 36:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE["X"] = 1;

function __ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv($this) {
  var $1 = __ZNK2js2gc18GCCompartmentsIter3getEv($this);
  return $1;
}

function __ZL25ComputeJitReleaseIntervalP9JSContext($cx_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _PRMJ_Now();
    var $1$0 = $1[0];
    var $1$1 = $1[1];
    var $2 = $cx_0_11_val + 184 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    if (($1$1 | 0) < ($3$1 | 0) || ($1$1 | 0) == ($3$1 | 0) && $1$0 >>> 0 < $3$0 >>> 0) {
      var $releaseInterval_1 = 0;
      __label__ = 4;
      break;
    } else {
      var $releaseInterval_01 = 8;
      var $5$1 = $3$1;
      var $5$0 = $3$0;
      __label__ = 2;
      break;
    }
   case 2:
    var $5$0;
    var $5$1;
    var $releaseInterval_01;
    var $6 = $releaseInterval_01 - 1 | 0;
    var $7 = ($6 | 0) == 1;
    var $8$0 = $7 ? $1$0 : $5$0;
    var $8$1 = $7 ? $1$1 : $5$1;
    var $9$0 = (i64Math.add($8$0, $8$1, 6e7, 0), i64Math.result[0]);
    var $9$1 = i64Math.result[1];
    if (($1$1 | 0) < ($9$1 | 0) || ($1$1 | 0) == ($9$1 | 0) && $1$0 >>> 0 < $9$0 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $releaseInterval_01 = $6;
      var $5$1 = $9$1;
      var $5$0 = $9$0;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$2 >> 2] = $9$0;
    HEAP32[$2 + 4 >> 2] = $9$1;
    var $releaseInterval_1 = $6;
    __label__ = 4;
    break;
   case 4:
    var $releaseInterval_1;
    return $releaseInterval_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind($cx, $gckind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $4 = HEAPU32[$2 + 32 >> 2];
    var $5 = $2 + 4 | 0;
    var $6 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($5);
    var $7 = $6 + 4 | 0;
    var $8 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($5);
    var $9 = ($gckind | 0) == 1;
    var $10 = ($4 | 0) == 0;
    var $write_0_ph = $7;
    var $read_0_ph = $7;
    __label__ = 2;
    break;
   case 2:
    var $read_0_ph;
    var $write_0_ph;
    var $read_0 = $read_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $read_0;
    if ($read_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 4:
    var $14 = $read_0 + 4 | 0;
    var $15 = HEAPU32[$read_0 >> 2];
    if ((HEAP8[$15 + 340 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $21 = $15 + 8 | 0;
    var $22 = __ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv($21);
    if ($22 | $9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = FUNCTION_TABLE[$4]($cx, $15, 0);
    __label__ = 8;
    break;
   case 8:
    var $27 = $15 + 4 | 0;
    var $28 = HEAP32[$27 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $28 + 12 | 0;
    var $33 = HEAP32[$31 >> 2] - 1 | 0;
    HEAP32[$31 >> 2] = $33;
    var $35 = HEAP32[$27 >> 2];
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = HEAP32[$35 + 16 >> 2];
    FUNCTION_TABLE[$38]($cx, $35);
    __label__ = 11;
    break;
   case 11:
    __ZN9JSContext7delete_I13JSCompartmentEEvPT_(undef, $15);
    var $read_0 = $14;
    __label__ = 3;
    break;
   case 12:
    HEAP32[$write_0_ph >> 2] = $15;
    var $write_0_ph = $write_0_ph + 4 | 0;
    var $read_0_ph = $14;
    __label__ = 2;
    break;
   case 13:
    var $43 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($5);
    var $47 = $write_0_ph - $43 >> 2;
    var $48 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj($5, $47);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind["X"] = 1;

function __ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind($rt, $gckind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lock = __stackBase__;
    __ZN2js10AutoLockGCC1EP9JSRuntime($lock, $rt);
    var $2 = ($gckind | 0) == 2;
    var $3 = $rt + 84 | 0;
    var $chunkp_0_ph = $rt + 80 | 0;
    __label__ = 2;
    break;
   case 2:
    var $chunkp_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAP32[$chunkp_0_ph >> 2];
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $5 + 1048332 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = HEAP32[$5 + 1048320 >> 2];
    HEAP32[$chunkp_0_ph >> 2] = $14;
    var $16 = HEAP32[$3 >> 2] - 1 | 0;
    HEAP32[$3 >> 2] = $16;
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE(undef, $5);
    __label__ = 3;
    break;
   case 7:
    var $18 = $10 + 1 | 0;
    HEAP32[$9 >> 2] = $18;
    var $chunkp_0_ph = $5 + 1048320 | 0;
    __label__ = 2;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_I13JSCompartmentEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSCompartmentD2Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $newLength - $2 | 0;
    var $6 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj($this, $5);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = $2 - $newLength | 0;
    __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj($this, $8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj($this, $incr) {
  var $1 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 4 | 0;
    if ((HEAP32[$this + 8 >> 2] - HEAP32[$3 >> 2] | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    var $11 = $10 + ($incr << 2) | 0;
    __ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_($10, $11);
    var $13 = HEAP32[$3 >> 2] + $incr | 0;
    HEAP32[$3 >> 2] = $13;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime($this, $rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 144080 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this >> 2] = $1;
    HEAP32[$this + 4 >> 2] = $1 + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = $rt + 4 | 0;
    var $10 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($9);
    HEAP32[$this >> 2] = $10;
    var $12 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($9);
    HEAP32[$this + 4 >> 2] = $12;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena9thingsEndEv($this) {
  var $1 = __ZNK2js2gc5Arena7addressEv($this);
  return $1 + 4096 | 0;
}

function __ZL9PickChunkP13JSCompartment($comp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chunk = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = HEAP32[$comp >> 2];
    var $3 = __Z21GetAvailableChunkListP13JSCompartment($comp);
    var $4 = HEAP32[$3 >> 2];
    HEAP32[$chunk >> 2] = $4;
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = $2 + 80 | 0;
    var $8 = HEAP32[$7 >> 2];
    HEAP32[$chunk >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$8 + 1048320 >> 2];
    HEAP32[$7 >> 2] = $12;
    var $13 = $2 + 84 | 0;
    var $15 = HEAP32[$13 >> 2] - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    __label__ = 6;
    break;
   case 4:
    var $17 = __Z15AllocateGCChunkP9JSRuntime(undef);
    HEAP32[$chunk >> 2] = $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js2gc5Chunk4initEv($17);
    HEAP8[$2 + 172 | 0] = 1;
    __label__ = 6;
    break;
   case 6:
    var $22 = $2 + 48 | 0;
    __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_($p, $22, $chunk);
    var $23 = __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_($22, $p, $chunk);
    var $24 = HEAP32[$chunk >> 2];
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE(undef, $24);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $27 = $24 + 1048324 | 0;
    HEAP32[$27 >> 2] = 0;
    var $28 = $24 + 1048320 | 0;
    HEAP32[$28 >> 2] = 0;
    __ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment($24, $comp);
    var $_0 = $24;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15AllocateGCChunkP9JSRuntime($rt) {
  var $1 = __ZN2js12AllocGCChunkEv();
  return $1;
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js13AutoKeepAtomsC1EP9JSRuntime($this, $rt) {
  __ZN2js13AutoKeepAtomsC2EP9JSRuntime($this, $rt);
  return;
}

function __ZN2js13AutoKeepAtomsD1Ev($this) {
  __ZN2js13AutoKeepAtomsD2Ev($this);
  return;
}

function __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) != 268374016;
}

function __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($this, $thingSize) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK16JSExternalString12externalTypeEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 0 || ($thingKind | 0) == 1 || ($thingKind | 0) == 2 || ($thingKind | 0) == 3 || ($thingKind | 0) == 4 || ($thingKind | 0) == 5 || ($thingKind | 0) == 6 || ($thingKind | 0) == 7 || ($thingKind | 0) == 8 || ($thingKind | 0) == 9 || ($thingKind | 0) == 10 || ($thingKind | 0) == 11 || ($thingKind | 0) == 12) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 13) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 14) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 15) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 16) {
      __label__ = 6;
      break;
    } else if (($thingKind | 0) == 18) {
      __label__ = 7;
      break;
    } else if (($thingKind | 0) == 17) {
      __label__ = 8;
      break;
    } else if (($thingKind | 0) == 19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    __ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind);
    __label__ = 10;
    break;
   case 3:
    __ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 13);
    __label__ = 10;
    break;
   case 4:
    __ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 14);
    __label__ = 10;
    break;
   case 5:
    __ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 15);
    __label__ = 10;
    break;
   case 6:
    __ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 16);
    __label__ = 10;
    break;
   case 7:
    __ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 18);
    __label__ = 10;
    break;
   case 8:
    __ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 17);
    __label__ = 10;
    break;
   case 9:
    __ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, 19);
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj($7, undef, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj($7, undef, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE($cx, $al, $thingKind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $available = __stackBase__;
    __ZN2js2gc10ArenaLists9ArenaListC1Ev($available);
    var $1 = $al | 0;
    var $2 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $3 = $available + 4 | 0;
    var $ap_0_ph = $1;
    __label__ = 2;
    break;
   case 2:
    var $ap_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = HEAP32[$ap_0_ph >> 2];
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN2js2gc11ArenaHeader8getArenaEv($4);
    var $8 = __ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj($7, $cx, $thingKind, $2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = HEAP32[$4 + 4 >> 2];
    HEAP32[$ap_0_ph >> 2] = $11;
    var $12 = __ZNK2js2gc11ArenaHeader5chunkEv($4);
    __ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE($12, $4);
    __label__ = 3;
    break;
   case 6:
    var $14 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $15 = $4 + 4 | 0;
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $ap_0_ph = $15;
      __label__ = 2;
      break;
    }
   case 7:
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$ap_0_ph >> 2] = $17;
    var $18 = HEAP32[$3 >> 2];
    HEAP32[$18 >> 2] = $4;
    HEAP32[$3 >> 2] = $15;
    __label__ = 3;
    break;
   case 8:
    var $20 = HEAP32[$3 >> 2];
    HEAP32[$20 >> 2] = 0;
    var $22 = HEAP32[$available >> 2];
    HEAP32[$ap_0_ph >> 2] = $22;
    HEAP32[$al + 4 >> 2] = $ap_0_ph;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN16JSExternalString8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN16JSExternalString8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK16JSExternalString12externalTypeEv($this);
    var $3 = HEAP32[__ZN16JSExternalString14str_finalizersE + ($1 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this | 0;
    FUNCTION_TABLE[$3]($cx, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSString8finalizeEP9JSContext($thing_0, undef);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN8JSString8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6isFlatEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString6asFlatEv($this);
    __ZN12JSFlatString8finalizeEP9JSRuntime($3, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN5JSXML8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN5JSXML8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    if (HEAPU32[$1 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $this + 24 | 0;
    var $7 = $cx;
    __ZN10JSXMLArray6finishEP9JSContext($6, $7);
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $this + 40 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($12, $7);
    var $14 = $this + 56 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($14, $7);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Chunk17withinArenasRangeEj($addr) {
  return ($addr & 1032192) >>> 0 < 1032192;
}

function __ZN2js2gc5Chunk10arenaIndexEj($addr) {
  return $addr >>> 12 & 255;
}

function __ZN2js14FindChunkStartEPv($p) {
  return $p + 1048575 & -1048576;
}

function _JSID_IS_STRING1510($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1511($iden) {
  return $iden;
}

function _JSID_IS_OBJECT1512($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1513($iden) {
  return $iden & -8;
}

function __ZN2js8RootInfoC2EPKc12JSGCRootType($this, $name, $type) {
  HEAP32[$this >> 2] = $name;
  HEAP32[$this + 4 >> 2] = $type;
  return;
}

function __ZNK2js2gc11ArenaHeader9allocatedEv($this) {
  return (HEAP32[$this + 12 >> 2] & 252) >>> 0 < 20;
}

function __ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $8 = $cx;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $10 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 >> 2];
    if (($13 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $17 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $18 = $17;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    HEAP32[$7 >> 2] = $19$0;
    HEAP32[$7 + 4 >> 2] = $19$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $13;
    __label__ = 9;
    break;
   case 5:
    var $22 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $23 = ($newFreeSpanStart_0 | 0) == 0;
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($23) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $29 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $29;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $23 ? $thing_0 : $newFreeSpanStart_0;
    __ZN2js5Shape8finalizeEP9JSContext($thing_0, $8);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $10 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $8 = $cx;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $10 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 >> 2];
    if (($13 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $17 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $18 = $17;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    HEAP32[$7 >> 2] = $19$0;
    HEAP32[$7 + 4 >> 2] = $19$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $13;
    __label__ = 9;
    break;
   case 5:
    var $22 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $23 = ($newFreeSpanStart_0 | 0) == 0;
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($23) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $29 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $29;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $23 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSScript8finalizeEP9JSContext($thing_0, $8);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $10 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj($this, $cx, $thingKind, $thingSize) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nextFree = __stackBase__;
    var $newListHead = __stackBase__ + 8;
    var $1 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($this, $thingKind);
    var $2 = __ZN2js2gc5Arena9thingsEndEv($this);
    var $3 = $2 - 1 | 0;
    var $4 = $this | 0;
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($nextFree, $4);
    var $5 = $nextFree + 4 | 0;
    var $6 = $nextFree | 0;
    var $7 = $nextFree;
    var $allClear_0 = 1;
    var $newFreeSpanStart_0 = 0;
    var $newListTail_0 = $newListHead;
    var $thing_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $thing_0;
    var $newListTail_0;
    var $newFreeSpanStart_0;
    var $allClear_0;
    var $9 = HEAP32[$6 >> 2];
    if (($thing_0 | 0) == ($9 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[$5 >> 2];
    if (($12 | 0) == ($3 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newFreeSpanStart_1 = ($newFreeSpanStart_0 | 0) == 0 ? $thing_0 : $newFreeSpanStart_0;
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($nextFree);
    var $17 = $16;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    HEAP32[$7 >> 2] = $18$0;
    HEAP32[$7 + 4 >> 2] = $18$1;
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_1;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $12;
    __label__ = 9;
    break;
   case 5:
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($thing_0, 0);
    var $22 = ($newFreeSpanStart_0 | 0) == 0;
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if ($22) {
      var $allClear_1 = 0;
      var $newFreeSpanStart_3 = 0;
      var $newListTail_1 = $newListTail_0;
      var $thing_1 = $thing_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$newListTail_0 >> 2] = $newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $thing_0 - $thingSize | 0;
    var $28 = __ZNK2js2gc8FreeSpan17nextSpanUncheckedEj($newListTail_0, undef);
    var $allClear_1 = 0;
    var $newFreeSpanStart_3 = 0;
    var $newListTail_1 = $28;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 8:
    var $newFreeSpanStart_2 = $22 ? $thing_0 : $newFreeSpanStart_0;
    __ZN8JSObject8finalizeEP9JSContext($thing_0, $cx);
    var $allClear_1 = $allClear_0;
    var $newFreeSpanStart_3 = $newFreeSpanStart_2;
    var $newListTail_1 = $newListTail_0;
    var $thing_1 = $thing_0;
    __label__ = 9;
    break;
   case 9:
    var $thing_1;
    var $newListTail_1;
    var $newFreeSpanStart_3;
    var $allClear_1;
    var $allClear_0 = $allClear_1;
    var $newFreeSpanStart_0 = $newFreeSpanStart_3;
    var $newListTail_0 = $newListTail_1;
    var $thing_0 = $thing_1 + $thingSize | 0;
    __label__ = 2;
    break;
   case 10:
    if (($allClear_0 & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $_newFreeSpanStart_0 = ($newFreeSpanStart_0 | 0) == 0 ? $9 : $newFreeSpanStart_0;
    HEAP32[$newListTail_0 >> 2] = $_newFreeSpanStart_0;
    HEAP32[$newListTail_0 + 4 >> 2] = $3;
    __ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE($4, $newListHead);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj["X"] = 1;

function __ZN8JSObject8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isNewbornEv($this);
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8getClassEv($this);
    var $5 = HEAP32[$3 + 36 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    FUNCTION_TABLE[$5]($cx, $this);
    __label__ = 4;
    break;
   case 4:
    __ZN8JSObject6finishEP9JSContext($this, undef);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject6finishEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13hasSlotsArrayEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    __ZN9JSContext5free_EPv(undef, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22MarkWordConservativelyEP8JSTracerj($trc, $w) {
  var $1 = __ZN2js17MarkIfGCThingWordEP8JSTracerj($trc, $w);
  return;
}

function __ZN2js17MarkIfGCThingWordEP8JSTracerj($trc, $w) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $chunk = __stackBase__;
    if (($w & 3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $w & -8;
    var $5 = __ZN2js2gc5Chunk11fromAddressEj($4);
    HEAP32[$chunk >> 2] = $5;
    var $10 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 48 | 0;
    var $11 = __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_($10, $chunk);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 3;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = __ZN2js2gc5Chunk17withinArenasRangeEj($4);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 2;
      __label__ = 8;
      break;
    }
   case 4:
    var $15 = __ZN2js2gc5Chunk10arenaIndexEj($4);
    var $17 = HEAP32[$chunk >> 2] + ($15 << 12) | 0;
    var $18 = __ZNK2js2gc11ArenaHeader9allocatedEv($17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 4;
      __label__ = 8;
      break;
    }
   case 5:
    var $20 = __ZNK2js2gc11ArenaHeader12getAllocKindEv($17);
    var $21 = $w & 4088;
    var $22 = __ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE($20);
    if ($21 >>> 0 < $22 >>> 0) {
      var $_0 = 2;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $21 - $22 | 0;
    var $26 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($20);
    var $28 = $4 - ($25 >>> 0) % ($26 >>> 0) | 0;
    var $29 = __ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj($17, $28);
    if ($29) {
      var $_0 = 5;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $28;
    var $32 = __ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE($20);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $31, $32);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_($1, $3, $l);
  __ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($2, $1);
  var $6 = (HEAP32[$2 >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj($aheader, $addr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstSpan = __stackBase__;
    var $1 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($aheader);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($firstSpan, $aheader);
    var $span_0 = $firstSpan;
    __label__ = 3;
    break;
   case 3:
    var $span_0;
    if (HEAPU32[$span_0 >> 2] >>> 0 > $addr >>> 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAPU32[$span_0 + 4 >> 2] >>> 0 < $addr >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK2js2gc8FreeSpan8nextSpanEv($span_0);
    var $span_0 = $12;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj($this, $cell, $color) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $word = __stackBase__;
  var $mask = __stackBase__ + 4;
  __ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_($this, $cell, $color, $word, $mask);
  var $5 = (HEAP32[$mask >> 2] & HEAP32[HEAP32[$word >> 2] >> 2] | 0) != 0;
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 16128, 1);
  return;
}

function __ZN2js12AllocGCChunkEv() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL8MapPagesPvj(0, 2097152);
    var $2 = $1;
    var $3 = $2 + 1048576 | 0;
    var $4 = $2 & 1048575;
    var $5 = $3 - $4 | 0;
    var $6 = $5;
    if (($3 | 0) == ($4 | 0)) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($5 & 1048575 | 0) == 0) {
      var $_0 = $6;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL10UnmapPagesPvj($6, 1048576);
    var $12 = __ZN2js14FindChunkStartEPv($6);
    var $13 = __ZL8MapPagesPvj($12, 1048576);
    var $p_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    if (($p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $p_0;
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = __ZL8MapPagesPvj(0, 2097152);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZL10UnmapPagesPvj($17, 2097152);
    var $20 = __ZN2js14FindChunkStartEPv($17);
    var $21 = __ZL8MapPagesPvj($20, 1048576);
    var $p_0 = $21;
    __label__ = 4;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8MapPagesPvj($addr, $size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _mmap($addr, $size, 3, 4098, -1, 0);
    if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($addr | 0) == 0 | ($1 | 0) == ($addr | 0)) {
      var $_0 = $1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _munmap($1, $size);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10UnmapPagesPvj($addr, $size) {
  var $1 = _munmap($addr, $size);
  return;
}

function __ZN2js11FreeGCChunkEPv($p) {
  __ZL10UnmapPagesPvj($p, 1048576);
  return;
}

function __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $str) {
  __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $str);
  return;
}

function __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $str, $name) {
  __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $str);
  return;
}

function __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $obj, $name) {
  __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $obj);
  return;
}

function __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc($trc, $obj, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($6 | 0) == ($10 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $obj, undef);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $obj, $printer, $arg, $index) {
  __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $obj);
  return;
}

function __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $script, $name) {
  __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $script);
  return;
}

function __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $shape, $name) {
  __ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_($trc, $shape);
  return;
}

function __ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $type, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($type | 0) == (__ZN2js5types15emptyTypeObjectE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_($trc, $type);
    if ((HEAP32[$trc + 4 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $8 = HEAP32[$type + 4 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $8, undef);
    __label__ = 5;
    break;
   case 5:
    var $13 = HEAP32[$type + 28 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $16, undef);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc7MarkXMLEP8JSTracerP5JSXMLPKc($trc, $xml, $name) {
  __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $xml);
  return;
}

function __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $len, $vec, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc($trc, $len, $vec, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc6MarkIdEP8JSTraceri($trc, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1510($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1511($id);
    __ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_($trc, $4);
    __label__ = 5;
    break;
   case 3:
    var $6 = _JSID_IS_OBJECT1512($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_OBJECT1513($id);
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $9);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $id, $name) {
  __ZN2js2gc6MarkIdEP8JSTraceri($trc, $id);
  return;
}

function __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($trc, $beg, $end, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $idp_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $idp_01;
    var $2 = HEAP32[$idp_01 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceri($trc, $2);
    var $3 = $idp_01 + 4 | 0;
    if (($3 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $idp_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc($trc, $len, $vec, $name) {
  var $1 = $vec + ($len << 2) | 0;
  __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($trc, $vec, $1, undef);
  return;
}

function __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($kind | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($kind | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($kind | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($kind | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $2 = $thing;
    __ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_($trc, $2);
    __label__ = 8;
    break;
   case 3:
    var $4 = $thing;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSString($trc, $4);
    __label__ = 8;
    break;
   case 4:
    var $6 = $thing;
    __ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_($trc, $6);
    __label__ = 8;
    break;
   case 5:
    var $8 = $thing;
    __ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_($trc, $8);
    __label__ = 8;
    break;
   case 6:
    var $10 = $thing;
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $10, undef);
    __label__ = 8;
    break;
   case 7:
    var $12 = $thing;
    __ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_($trc, $12);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject10typeFromGCEv($this) {
  return HEAP32[$this + 36 >> 2];
}

function __ZNK6JSRope10rightChildEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN8JSScript6constsEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 21 | 0] & 255) | 0;
}

function __ZNK2js5Shape14hasGetterValueEv($this) {
  return (HEAP8[$this + 28 | 0] & 16) << 24 >> 24 != 0;
}

function __ZNK2js5Shape12getterObjectEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZNK2js5Shape14hasSetterValueEv($this) {
  return (HEAP8[$this + 28 | 0] & 32) << 24 >> 24 != 0;
}

function __ZNK2js5Shape12setterObjectEv($this) {
  return HEAP32[$this + 20 >> 2];
}

function __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js9MarkStackIP6JSRopeE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($17, $thing);
    __label__ = 6;
    break;
   case 5:
    var $19 = $thing;
    var $20 = __ZN2js2gc19GetGCThingTraceKindEPKv($19);
    FUNCTION_TABLE[$14]($trc, $19, $20);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value9toGCThingEv($v);
    var $4 = __ZNK2JS5Value6gcKindEv($v);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $3, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value6gcKindEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_TRACE_KIND_IMPL1545($2$0, $2$1);
  return $3;
}

function __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v, $name) {
  __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $v);
  return;
}

function __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5Value9toGCThingEv($v);
    var $12 = $11;
    var $13 = __ZNK2js2gc4Cell11compartmentEv($12);
    if (($13 | 0) == ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $v, undef);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc($trc, $beg, $end, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($beg >>> 0 < $end >>> 0) {
      var $vp_01 = $beg;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $vp_01;
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $vp_01);
    var $2 = $vp_01 + 8 | 0;
    if ($2 >>> 0 < $end >>> 0) {
      var $vp_01 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $len, $vec, $name) {
  var $1 = $vec + ($len << 3) | 0;
  __ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc($trc, $vec, $1, undef);
  return;
}

function __ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc($trc, $beg, $end, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($beg >>> 0 < $end >>> 0) {
      var $sp_01 = $beg;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $sp_01;
    var $2 = HEAP32[$sp_01 >> 2];
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $2, undef);
    var $3 = $sp_01 + 4 | 0;
    if ($3 >>> 0 < $end >>> 0) {
      var $sp_01 = $3;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc($trc, $len, $vec, $name) {
  var $1 = $vec + ($len << 2) | 0;
  __ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc($trc, $vec, $1, undef);
  return;
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thing | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thing | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js2gc19GetGCThingTraceKindEPKv($thing);
    __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPvPKc($trc, $thing, $name) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing);
  return;
}

function __ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj($trc, $thing, $name, $index) {
  __ZN2js2gc11MarkGCThingEP8JSTracerPv($trc, $thing);
  return;
}

function __ZN2js2gc4MarkEP8JSTracerPv13JSGCTraceKindPKc($trc, $thing, $kind, $name) {
  __ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind($trc, $thing, $kind);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerP8JSObjectPKc($trc, $thing, $name) {
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerP8JSStringPKc($trc, $thing, $name) {
  __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerP8JSScriptPKc($trc, $thing, $name) {
  __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerPKNS_5ShapeEPKc($trc, $thing, $name) {
  __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $thing, $name) {
  __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc8MarkRootEP8JSTracerP5JSXMLPKc($trc, $thing, $name) {
  __ZN2js2gc7MarkXMLEP8JSTracerP5JSXMLPKc($trc, $thing, undef);
  return;
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isNewbornEv($obj);
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject10typeFromGCEv($obj);
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $3, undef);
    var $4 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAP32[$obj + 16 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc($trc, $7, undef);
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZNK8JSObject9getParentEv($obj);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $11, undef);
    __label__ = 7;
    break;
   case 7:
    var $15 = __ZNK8JSObject8getClassEv($obj);
    var $17 = HEAP32[$15 + 64 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    FUNCTION_TABLE[$17]($trc, $obj);
    __label__ = 9;
    break;
   case 9:
    var $21 = __ZNK8JSObject8isNativeEv($obj);
    if ($21) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $24 = HEAP32[$obj >> 2];
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $24, undef);
    var $25 = __ZNK8JSObject8slotSpanEv($obj);
    if (($25 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $i_01;
    var $27 = __ZNK8JSObject13nativeGetSlotEj($obj, $i_01);
    __ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE($trc, $27);
    var $28 = $i_01 + 1 | 0;
    if (($28 | 0) == ($25 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_01 = $28;
      __label__ = 11;
      break;
    }
   case 12:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSString($trc, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString11isDependentEv($str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString11asDependentEv($str);
    var $4 = __ZNK17JSDependentString4baseEv($3);
    var $5 = $4 | 0;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $5, undef);
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZNK8JSString6isRopeEv($str);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN8JSString6asRopeEv($str);
    var $10 = __ZNK6JSRope9leftChildEv($9);
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $10, undef);
    var $11 = __ZNK6JSRope10rightChildEv($9);
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($trc, $11, undef);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($trc, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$script + 40 >> 2];
    var $4 = HEAP32[$script + 56 >> 2];
    __ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc($trc, $2, $4);
    var $6 = HEAP8[$script + 16 | 0];
    var $7 = __ZN8JSScript13isValidOffsetEh($6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN8JSScript7objectsEv($script);
    var $11 = HEAP32[$9 + 4 >> 2];
    var $13 = HEAP32[$9 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $11, $13, undef);
    __label__ = 3;
    break;
   case 3:
    var $16 = HEAP8[$script + 18 | 0];
    var $17 = __ZN8JSScript13isValidOffsetEh($16);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = $script;
    var $20 = __ZN8JSScript7regexpsEv($19);
    var $22 = HEAP32[$20 + 4 >> 2];
    var $24 = HEAP32[$20 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($trc, $22, $24, undef);
    __label__ = 5;
    break;
   case 5:
    var $27 = HEAP8[$script + 21 | 0];
    var $28 = __ZN8JSScript13isValidOffsetEh($27);
    if ($28) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = __ZN8JSScript6constsEv($script);
    var $32 = HEAP32[$30 + 4 >> 2];
    var $34 = HEAP32[$30 >> 2];
    __ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc($trc, $32, $34, undef);
    __label__ = 7;
    break;
   case 7:
    if (HEAP8[$script + 37 | 0] << 24 >> 24 < 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $41 = HEAP32[$script + 84 >> 2];
    if (($41 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $41, undef);
    __label__ = 10;
    break;
   case 10:
    if ((HEAP32[$trc + 4 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $50 = HEAP32[$script + 52 >> 2];
    if (($50 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __Z21js_MarkScriptFilenamePKc($50);
    __label__ = 13;
    break;
   case 13:
    var $55 = $script + 64 | 0;
    var $56 = $trc;
    __ZN2js8Bindings5traceEP8JSTracer($55, $56);
    var $58 = HEAP32[$script + 100 >> 2];
    if (($58 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js5types10TypeScript5traceEP8JSTracer($58, $trc);
    __label__ = 15;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript["X"] = 1;

function __ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc($trc, $len, $vec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($len | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_01;
    var $3 = HEAP32[$vec + ($i_01 << 2) >> 2];
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_($trc, $3);
    __label__ = 4;
    break;
   case 4:
    var $7 = $i_01 + 1 | 0;
    if (($7 | 0) == ($len | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $5, undef);
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZN2js5types10TypeScript8hasScopeEv($this);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = HEAP32[$this + 8 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $13, undef);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE($trc, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $shape;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $3 = HEAP32[$_0 + 12 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $3, undef);
    var $4 = __ZNK2js5Shape14hasGetterValueEv($_0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZNK2js5Shape6getterEv($_0);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js5Shape12getterObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $9, undef, undef, undef);
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZNK2js5Shape14hasSetterValueEv($_0);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZNK2js5Shape6setterEv($_0);
    if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2js5Shape12setterObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $16, undef, undef, undef);
    __label__ = 8;
    break;
   case 8:
    var $18 = __ZNK2js5Shape8isMethodEv($_0);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = __ZNK2js5Shape12methodObjectEv($_0);
    __ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj($trc, $20, undef, undef, undef);
    __label__ = 10;
    break;
   case 10:
    var $22 = __ZNK2js5Shape8previousEv($_0);
    if (($22 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = $22;
      __label__ = 2;
      break;
    }
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE($trc, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type + 4 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZN2js5types10TypeObject16getPropertyCountEv($type);
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_03;
    var $7 = __ZN2js5types10TypeObject11getPropertyEj($type, $i_03);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $11, undef);
    __label__ = 5;
    break;
   case 5:
    var $13 = $i_03 + 1 | 0;
    if (($13 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = $13;
      __label__ = 3;
      break;
    }
   case 6:
    var $14 = $type + 8 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i2_01 = 0;
      var $17 = $15;
      __label__ = 7;
      break;
    }
   case 7:
    var $17;
    var $i2_01;
    var $19 = HEAP32[$17 + ($i2_01 << 2) >> 2];
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $19 | 0;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $22, undef);
    __label__ = 9;
    break;
   case 9:
    var $24 = $i2_01 + 1 | 0;
    if (($24 | 0) == 12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i2_01 = $24;
    var $17 = HEAP32[$14 >> 2];
    __label__ = 7;
    break;
   case 11:
    var $26 = HEAP32[$type >> 2];
    if (($26 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $26, undef);
    __label__ = 13;
    break;
   case 13:
    var $29 = HEAP32[$1 >> 2];
    if (($29 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $29, undef);
    __label__ = 15;
    break;
   case 15:
    var $33 = $type + 16 | 0;
    var $34 = HEAP32[$33 >> 2];
    if (($34 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $39 = HEAP32[$34 >> 2] | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $39, undef);
    var $42 = HEAP32[HEAP32[$33 >> 2] + 8 >> 2];
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($trc, $42, undef);
    __label__ = 17;
    break;
   case 17:
    var $45 = HEAP32[$type + 28 >> 2];
    if (($45 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $48 = $45 | 0;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $48, undef);
    __label__ = 19;
    break;
   case 19:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE["X"] = 1;

function __ZN2js5types10TypeObject16getPropertyCountEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
    if ($1 >>> 0 > 8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1539($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11getPropertyEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
    var $4 = HEAP32[$this + 24 >> 2];
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$4 + ($i << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($trc, $xml) {
  var $1 = $trc;
  var $2 = $xml;
  _js_TraceXML($1, $2);
  return;
}

function __ZN2js8GCMarker14drainMarkStackEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this | 0;
    var $6 = HEAP32[HEAP32[$this >> 2] + 52 >> 2];
    var $8 = HEAP32[$6 + 144080 >> 2];
    var $9 = $6 + 144084 | 0;
    HEAP32[$9 >> 2] = $8;
    var $10 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($10) {
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $this + 48 | 0;
    var $12 = $this + 36 | 0;
    var $13 = $this + 60 | 0;
    var $14 = $this + 72 | 0;
    var $15 = $this + 84 | 0;
    __label__ = 3;
    break;
   case 3:
    var $16 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($11);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN2js9MarkStackIP6JSRopeE3popEv($11);
    __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($this, $17);
    var $18 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($11);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 5:
    var $19 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($12);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2js9MarkStackIP8JSObjectE3popEv($12);
    __ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject($this, $20);
    var $21 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($12);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 7:
    var $22 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($13);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv($13);
    __ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE($this, $23);
    var $24 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($13);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 9:
    var $25 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($14);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = __ZN2js9MarkStackIP5JSXMLE3popEv($14);
    __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($2, $26);
    var $27 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($14);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 11:
    var $28 = __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($15);
    if ($28) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $30 = __ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv($15);
    var $31 = __ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE($this, $30);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js9MarkStackINS_13LargeMarkItemEE3popEv($1, $15);
    __label__ = 14;
    break;
   case 14:
    var $34 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2js8GCMarker19markDelayedChildrenEv($this);
    __label__ = 16;
    break;
   case 16:
    var $36 = __ZN2js8GCMarker16isMarkStackEmptyEv($this);
    if ($36) {
      __label__ = 17;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 17:
    HEAP32[$9 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8GCMarker14drainMarkStackEv["X"] = 1;

function __ZN2js8GCMarker16isMarkStackEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 36 | 0;
    var $2 = __ZN2js9MarkStackIP8JSObjectE7isEmptyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $16 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = $this + 48 | 0;
    var $5 = __ZN2js9MarkStackIP6JSRopeE7isEmptyEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $16 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = $this + 60 | 0;
    var $8 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $16 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = $this + 72 | 0;
    var $11 = __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $16 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $13 = $this + 84 | 0;
    var $14 = __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($13);
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($gcmarker, $rope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $rope;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = __ZNK6JSRope10rightChildEv($_0);
    var $3 = __ZNK8JSString6isRopeEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = $2;
    var $6 = __ZNK2js2gc4Cell14markIfUnmarkedEj($5, 0);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZN8JSString6asRopeEv($2);
    __ZN2js8GCMarker8pushRopeEP6JSRope($gcmarker, $8);
    __label__ = 6;
    break;
   case 5:
    var $10 = __ZN8JSString8asLinearEv($2);
    __ZN14JSLinearString4markEP8JSTracer($10, undef);
    __label__ = 6;
    break;
   case 6:
    var $12 = __ZNK6JSRope9leftChildEv($_0);
    var $13 = __ZNK8JSString8isLinearEv($12);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = __ZN8JSString8asLinearEv($12);
    __ZN14JSLinearString4markEP8JSTracer($15, undef);
    __label__ = 9;
    break;
   case 8:
    var $17 = __ZN8JSString6asRopeEv($12);
    var $18 = $12;
    var $19 = __ZNK2js2gc4Cell14markIfUnmarkedEj($18, 0);
    if ($19) {
      var $_0 = $17;
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject($gcmarker, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __ZNK8JSObject9isNewbornEv($obj);
    if ($3) {
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject10typeFromGCEv($obj);
    if (($5 | 0) == (__ZN2js5types15emptyTypeObjectE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $5);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK8JSObject9getParentEv($obj);
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $9);
    __label__ = 6;
    break;
   case 6:
    var $13 = __ZNK8JSObject8getClassEv($obj);
    var $14 = $13 + 64 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($13 | 0) == (__ZN2js10ArrayClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $20 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if ($20 >>> 0 > 2048) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $23 = $gcmarker + 84 | 0;
    __ZN2js13LargeMarkItemC1EP8JSObject($1, $obj);
    var $24 = __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($23, $1);
    if ($24) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = HEAP32[$14 >> 2];
    var $27 = $gcmarker | 0;
    FUNCTION_TABLE[$26]($27, $obj);
    __label__ = 17;
    break;
   case 11:
    var $29 = $gcmarker | 0;
    FUNCTION_TABLE[$15]($29, $obj);
    __label__ = 17;
    break;
   case 12:
    var $32 = HEAP32[$obj + 16 >> 2];
    if (($32 | 0) == 0) {
      var $36 = $15;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $32);
    var $36 = HEAP32[$14 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $36;
    var $37 = $gcmarker | 0;
    FUNCTION_TABLE[$36]($37, $obj);
    __label__ = 17;
    break;
   case 15:
    var $40 = HEAP32[$obj + 16 >> 2];
    if (($40 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $40);
    __label__ = 17;
    break;
   case 17:
    var $44 = __ZNK8JSObject8isNativeEv($obj);
    if ($44) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $47 = HEAP32[$obj >> 2];
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $47);
    var $51 = HEAP32[HEAP32[$gcmarker >> 2] + 52 >> 2];
    if ((HEAP8[$51 + 144091 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = HEAP32[$47 >> 2];
    var $59 = __ZNK8JSObject11hasOwnShapeEv($obj);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      var $newShape_0 = $58;
      __label__ = 21;
      break;
    }
   case 20:
    var $61 = __ZL23js_RegenerateShapeForGCP9JSRuntime($51);
    var $newShape_0 = $61;
    __label__ = 21;
    break;
   case 21:
    var $newShape_0;
    HEAP32[$obj + 12 >> 2] = $newShape_0;
    __label__ = 22;
    break;
   case 22:
    var $65 = __ZNK8JSObject8slotSpanEv($obj);
    if ($65 >>> 0 > 2048) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $68 = $gcmarker + 84 | 0;
    __ZN2js13LargeMarkItemC1EP8JSObject($2, $obj);
    var $69 = __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($68, $2);
    if ($69) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN8JSObject9scanSlotsEPN2js8GCMarkerE($obj, $gcmarker);
    __label__ = 25;
    break;
   case 25:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject["X"] = 1;

function _JSVAL_IS_STRING_IMPL1546($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function __ZN2js9MarkStackIP8JSObjectE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackIP5JSXMLE7isEmptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js9MarkStackIP5JSXMLE3popEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP32[HEAP32[$this >> 2] + ($3 << 2) >> 2];
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] - 1 << 3) | 0;
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE3popEv($agg_result, $this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  var $7 = HEAP32[$this >> 2] + ($3 << 3) | 0;
  var $8 = $agg_result;
  var $9$0 = HEAP32[$7 >> 2];
  var $9$1 = HEAP32[$7 + 4 >> 2];
  HEAP32[$8 >> 2] = $9$0;
  HEAP32[$8 + 4 >> 2] = $9$1;
  return;
}

function __ZNK2js8GCMarker12getMarkColorEv($this) {
  return HEAP32[$this + 24 >> 2];
}

function __ZL23js_RegenerateShapeForGCP9JSRuntime($rt) {
  var $1 = $rt + 209944 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $5 = $2 + 1 | $2 & 16777216;
  HEAP32[$1 >> 2] = $5;
  return $5;
}

function __ZN2js9MarkStackIP8JSObjectE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MarkStackIP5JSXMLE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_($this, $item) {
  var __stackBase__ = STACKTOP;
  var tempParam = $item;
  $item = STACKTOP;
  STACKTOP += 8;
  HEAP32[$item >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$item + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $11 = $item;
    var $12 = HEAP32[$this >> 2] + ($2 << 3) | 0;
    var $13$0 = HEAP32[$11 >> 2];
    var $13$1 = HEAP32[$11 + 4 >> 2];
    var $st$11$0 = $12 | 0;
    HEAP32[$st$11$0 >> 2] = $13$0;
    var $st$11$1 = $12 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11hasOwnShapeEv($this) {
  return (HEAP32[$this + 8 >> 2] & 128 | 0) != 0;
}

function __ZN2js13LargeMarkItemC2EP8JSObject($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js9MarkStackIP6JSRopeE4pushES2_($this, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $10 = HEAP32[$this >> 2] + ($2 << 2) | 0;
    HEAP32[$10 >> 2] = $item;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8hasScopeEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) != 1;
}

function _JS_GetGCInfoEnabled($rt) {
  return (HEAP8[$rt + 229041 | 0] & 1) << 24 >> 24 != 0;
}

function _JS_SetGCInfoEnabled($rt, $enabled) {
  HEAP8[$rt + 229041 | 0] = $enabled & 1;
  return;
}

function _JS_GCInfoFront($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$rt + 234936 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $rt + 229044 + HEAP32[$rt + 234932 >> 2] * 92 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GCInfoPopFront($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 234936 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = $rt + 234932 | 0;
    if ($2 >>> 0 > 63) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$4 >> 2] = 0;
    var $_0 = 1;
    var $storemerge = 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = HEAP32[$4 >> 2] + 1 & 63;
    HEAP32[$4 >> 2] = $9;
    var $_0 = 0;
    var $storemerge = $2 - 1 | 0;
    __label__ = 4;
    break;
   case 4:
    var $storemerge;
    var $_0;
    HEAP32[$1 >> 2] = $storemerge;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$type + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = __ZN2js5types10TypeObject16getPropertyCountEv($type);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_03;
    var $7 = __ZN2js5types10TypeObject11getPropertyEj($type, $i_03);
    if (($7 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$7 >> 2];
    var $12 = _JSID_IS_STRING1510($11);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = _JSID_TO_STRING1511($11);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $15);
    __label__ = 6;
    break;
   case 6:
    var $17 = $i_03 + 1 | 0;
    if (($17 | 0) == ($5 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $i_03 = $17;
      __label__ = 3;
      break;
    }
   case 7:
    var $18 = $type + 8 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = HEAP32[$19 >> 2];
    if (($21 | 0) == 0) {
      var $26 = $19;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = $21 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $24);
    var $26 = HEAP32[$18 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $26;
    var $28 = HEAP32[$26 + 4 >> 2];
    if (($28 | 0) == 0) {
      var $48 = $26;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $31 = HEAP32[$type >> 2];
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $31);
    __label__ = 13;
    break;
   case 13:
    var $35 = $type + 16 | 0;
    var $36 = HEAP32[$35 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = HEAP32[$36 >> 2];
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction($gcmarker, $40);
    var $43 = HEAP32[HEAP32[$35 >> 2] + 8 >> 2];
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $43);
    __label__ = 15;
    break;
   case 15:
    return;
   case 16:
    var $46 = $28 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $46);
    var $48 = HEAP32[$18 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $48;
    var $50 = HEAP32[$48 + 8 >> 2];
    if (($50 | 0) == 0) {
      var $55 = $48;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $53 = $50 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $53);
    var $55 = HEAP32[$18 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $55;
    var $57 = HEAP32[$55 + 12 >> 2];
    if (($57 | 0) == 0) {
      var $62 = $55;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $60 = $57 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $60);
    var $62 = HEAP32[$18 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $62;
    var $64 = HEAP32[$62 + 16 >> 2];
    if (($64 | 0) == 0) {
      var $69 = $62;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $67 = $64 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $67);
    var $69 = HEAP32[$18 >> 2];
    __label__ = 23;
    break;
   case 23:
    var $69;
    var $71 = HEAP32[$69 + 20 >> 2];
    if (($71 | 0) == 0) {
      var $76 = $69;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $74 = $71 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $74);
    var $76 = HEAP32[$18 >> 2];
    __label__ = 25;
    break;
   case 25:
    var $76;
    var $78 = HEAP32[$76 + 24 >> 2];
    if (($78 | 0) == 0) {
      var $83 = $76;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $81 = $78 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $81);
    var $83 = HEAP32[$18 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $83;
    var $85 = HEAP32[$83 + 28 >> 2];
    if (($85 | 0) == 0) {
      var $90 = $83;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $88 = $85 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $88);
    var $90 = HEAP32[$18 >> 2];
    __label__ = 29;
    break;
   case 29:
    var $90;
    var $92 = HEAP32[$90 + 32 >> 2];
    if (($92 | 0) == 0) {
      var $97 = $90;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $95 = $92 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $95);
    var $97 = HEAP32[$18 >> 2];
    __label__ = 31;
    break;
   case 31:
    var $97;
    var $99 = HEAP32[$97 + 36 >> 2];
    if (($99 | 0) == 0) {
      var $104 = $97;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $102 = $99 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $102);
    var $104 = HEAP32[$18 >> 2];
    __label__ = 33;
    break;
   case 33:
    var $104;
    var $106 = HEAP32[$104 + 40 >> 2];
    if (($106 | 0) == 0) {
      var $111 = $104;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $109 = $106 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $109);
    var $111 = HEAP32[$18 >> 2];
    __label__ = 35;
    break;
   case 35:
    var $111;
    var $113 = HEAP32[$111 + 44 >> 2];
    if (($113 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $116 = $113 | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $116);
    __label__ = 11;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE["X"] = 1;

function __ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE($gcmarker, $item) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$item >> 2];
    var $3 = $item + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = __ZNK8JSObject12isDenseArrayEv($2);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($2);
    var $8 = $4 + 2048 | 0;
    var $_ = $8 >>> 0 < $7 >>> 0 ? $8 : $7;
    if ($_ >>> 0 > $4 >>> 0) {
      var $i_04 = $_;
      __label__ = 3;
      break;
    } else {
      var $capacity_0 = $7;
      var $stop_0 = $_;
      __label__ = 6;
      break;
    }
   case 3:
    var $i_04;
    var $11 = $i_04 - 1 | 0;
    var $12 = __ZN8JSObject20getDenseArrayElementEj($2, $11);
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $12);
    if ($11 >>> 0 > $4 >>> 0) {
      var $i_04 = $11;
      __label__ = 3;
      break;
    } else {
      var $capacity_0 = $7;
      var $stop_0 = $_;
      __label__ = 6;
      break;
    }
   case 4:
    var $15 = __ZNK8JSObject8slotSpanEv($2);
    var $16 = $4 + 2048 | 0;
    var $_1 = $16 >>> 0 < $15 >>> 0 ? $16 : $15;
    if ($_1 >>> 0 > $4 >>> 0) {
      var $i1_02 = $_1;
      __label__ = 5;
      break;
    } else {
      var $capacity_0 = $15;
      var $stop_0 = $_1;
      __label__ = 6;
      break;
    }
   case 5:
    var $i1_02;
    var $19 = $i1_02 - 1 | 0;
    var $20 = __ZNK8JSObject13nativeGetSlotEj($2, $19);
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $20);
    if ($19 >>> 0 > $4 >>> 0) {
      var $i1_02 = $19;
      __label__ = 5;
      break;
    } else {
      var $capacity_0 = $15;
      var $stop_0 = $_1;
      __label__ = 6;
      break;
    }
   case 6:
    var $stop_0;
    var $capacity_0;
    if (($stop_0 | 0) == ($capacity_0 | 0)) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAP32[$3 >> 2] + 2048 | 0;
    HEAP32[$3 >> 2] = $25;
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_TraceChildren($trc, $thing, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($kind | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($kind | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($kind | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($kind | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($kind | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $2 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject($trc, $2);
    __label__ = 8;
    break;
   case 3:
    var $4 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSString($trc, $4);
    __label__ = 8;
    break;
   case 4:
    var $6 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($trc, $6);
    __label__ = 8;
    break;
   case 5:
    var $8 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE($trc, $8);
    __label__ = 8;
    break;
   case 6:
    var $10 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE($trc, $10);
    __label__ = 8;
    break;
   case 7:
    var $12 = $thing;
    __ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML($trc, $12);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE($gcmarker, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $gcmarker | 0;
    var $_0 = $shape;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $5 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
    if ((HEAP8[$5 + 144091 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL23js_RegenerateShapeForGCP9JSRuntime($5);
    HEAP32[$_0 >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    var $15 = HEAP32[$_0 + 12 >> 2];
    var $16 = _JSID_IS_STRING1510($15);
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = _JSID_TO_STRING1511($15);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $19);
    __label__ = 8;
    break;
   case 6:
    var $21 = _JSID_IS_OBJECT1512($15);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = _JSID_TO_OBJECT1513($15);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $24);
    __label__ = 8;
    break;
   case 8:
    var $26 = __ZNK2js5Shape14hasGetterValueEv($_0);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZNK2js5Shape6getterEv($_0);
    if (($28 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZNK2js5Shape12getterObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $31);
    __label__ = 11;
    break;
   case 11:
    var $33 = __ZNK2js5Shape14hasSetterValueEv($_0);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $35 = __ZNK2js5Shape6setterEv($_0);
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZNK2js5Shape12setterObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $38);
    __label__ = 14;
    break;
   case 14:
    var $40 = __ZNK2js5Shape8isMethodEv($_0);
    if ($40) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $42 = __ZNK2js5Shape12methodObjectEv($_0);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $42);
    __label__ = 16;
    break;
   case 16:
    var $44 = __ZNK2js5Shape8previousEv($_0);
    if (($44 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $47 = $44;
    var $48 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $49 = __ZNK2js2gc4Cell14markIfUnmarkedEj($47, $48);
    if ($49) {
      var $_0 = $44;
      __label__ = 2;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE["X"] = 1;

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString8isLinearEv($str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSString8asLinearEv($str);
    __ZN14JSLinearString4markEP8JSTracer($3, undef);
    __label__ = 5;
    break;
   case 3:
    var $5 = $str;
    var $6 = __ZNK2js2gc4Cell14markIfUnmarkedEj($5, 0);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZN8JSString6asRopeEv($str);
    __ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope($gcmarker, $8);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker10pushObjectEP8JSObject($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker10pushObjectEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 36 | 0;
    var $2 = __ZN2js9MarkStackIP8JSObjectE4pushES2_($1, $obj);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $obj;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker7pushXMLEP5JSXML($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker7pushXMLEP5JSXML($this, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 72 | 0;
    var $2 = __ZN2js9MarkStackIP5JSXMLE4pushES2_($1, $xml);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $xml;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE($gcmarker, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE($this, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 60 | 0;
    var $2 = __ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_($1, $type);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $type;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $gcmarker | 0;
    __ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript($5, $thing);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value6gcKindEv($v);
    if (($3 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toStringEv($v);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($gcmarker, $6);
    __label__ = 5;
    break;
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($v);
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject($gcmarker, $8);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction($gcmarker, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $thing;
    var $2 = __ZNK2js8GCMarker12getMarkColorEv($gcmarker);
    var $3 = __ZNK2js2gc4Cell14markIfUnmarkedEj($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $thing | 0;
    __ZN2js8GCMarker10pushObjectEP8JSObject($gcmarker, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13LargeMarkItemC1EP8JSObject($this, $obj) {
  __ZN2js13LargeMarkItemC2EP8JSObject($this, $obj);
  return;
}

function __ZN8JSObject9scanSlotsEPN2js8GCMarkerE($this, $gcmarker) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8slotSpanEv($this);
    var $2 = $this + 32 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13numFixedSlotsEv($this);
    if ($1 >>> 0 > $6 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    if (($6 | 0) == 0) {
      var $i_0_lcssa = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject10fixedSlotsEv($this);
    var $i_03 = 0;
    var $vp_04 = $10;
    __label__ = 5;
    break;
   case 5:
    var $vp_04;
    var $i_03;
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp_04);
    var $12 = $i_03 + 1 | 0;
    if (($12 | 0) == ($6 | 0)) {
      var $i_0_lcssa = $6;
      __label__ = 6;
      break;
    } else {
      var $i_03 = $12;
      var $vp_04 = $vp_04 + 8 | 0;
      __label__ = 5;
      break;
    }
   case 6:
    var $i_0_lcssa;
    if ($i_0_lcssa >>> 0 < $1 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $i_11 = $i_0_lcssa;
    var $vp_12 = HEAP32[$2 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $vp_12;
    var $i_11;
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp_12);
    var $17 = $i_11 + 1 | 0;
    if (($17 | 0) == ($1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_11 = $17;
      var $vp_12 = $vp_12 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($1 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $21 = __ZNK8JSObject10fixedSlotsEv($this);
    var $i_27 = 0;
    var $vp1_08 = $21;
    __label__ = 11;
    break;
   case 11:
    var $vp1_08;
    var $i_27;
    __ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE($gcmarker, $vp1_08);
    var $23 = $i_27 + 1 | 0;
    if (($23 | 0) == ($1 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $i_27 = $23;
      var $vp1_08 = $vp1_08 + 8 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8GCMarker8pushRopeEP6JSRope($this, $rope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 48 | 0;
    var $2 = __ZN2js9MarkStackIP6JSRopeE4pushES2_($1, $rope);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $rope;
    __ZN2js8GCMarker20delayMarkingChildrenEPKv($this, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL15HashSetCapacityEj1539($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_($trc, $thing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAP32[HEAP32[HEAP32[$trc >> 2] + 52 >> 2] + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $thing;
    var $10 = __ZNK2js2gc4Cell11compartmentEv($9);
    if (($10 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$trc + 4 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $trc;
    var $18 = $thing | 0;
    __ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString($17, $18);
    __label__ = 6;
    break;
   case 5:
    var $20 = $thing;
    var $21 = __ZN2js2gc19GetGCThingTraceKindEPKv($20);
    FUNCTION_TABLE[$14]($trc, $20, $21);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TRACE_KIND_IMPL1545($l_0$0, $l_0$1) {
  var $1 = _JSVAL_IS_STRING_IMPL1546($l_0$0, $l_0$1);
  return $1;
}

function _JS_CompareValues($v1, $v2) {
  return ($v1 | 0) == ($v2 | 0) & 1;
}

function __ZN9JSRuntime6GCData14isTimerEnabledEv($this) {
  return (HEAP8[$this + 9 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN9JSRuntime6GCData13setFirstEnterEy($this, $v$0, $v$1) {
  var $1 = $this | 0;
  HEAP32[$1 >> 2] = $v$0;
  HEAP32[$1 + 4 >> 2] = $v$1;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function _JS_HashString($key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$key];
    if ($1 << 24 >> 24 == 0) {
      var $h_0_lcssa = 0;
      __label__ = 3;
      break;
    } else {
      var $h_01 = 0;
      var $s_02 = $key;
      var $3 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $3;
    var $s_02;
    var $h_01;
    var $8 = $3 & 255 ^ ($h_01 << 4 | $h_01 >>> 28);
    var $9 = $s_02 + 1 | 0;
    var $10 = HEAPU8[$9];
    if ($10 << 24 >> 24 == 0) {
      var $h_0_lcssa = $8;
      __label__ = 3;
      break;
    } else {
      var $h_01 = $8;
      var $s_02 = $9;
      var $3 = $10;
      __label__ = 2;
      break;
    }
   case 3:
    var $h_0_lcssa;
    return $h_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment($this, $rt, $comp) {
  HEAP32[$this >> 2] = $rt;
  HEAP8[$this + 76 | 0] = ($comp | 0) != 0 & 1;
  var $5 = $this + 77 | 0;
  var $6 = $rt + 229032 | 0;
  var $7 = __ZN9JSRuntime6GCData14isTimerEnabledEv($6);
  HEAP8[$5] = $7 & 1;
  __ZN2js7GCTimer15clearTimestampsEv($this);
  var $9 = __ZN2js7GCTimer13getFirstEnterEv($this);
  var $10 = _PRMJ_Now();
  var $10$1 = $10[1];
  var $11 = $this + 4 | 0;
  HEAP32[$11 >> 2] = $10[0];
  HEAP32[$11 + 4 >> 2] = $10$1;
  return;
}

function __ZN2js7GCTimer15clearTimestampsEv($this) {
  var $1 = $this + 4 | 0;
  var $2 = $1;
  var $8 = ($this + 68 - $1 >> 3) + 8 | 0;
  _memset($2, 0, $8, 1);
  return;
}

function __ZN2js7GCTimer13getFirstEnterEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = $2 + 229032 | 0;
    if ((HEAP8[$this + 77 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$2 + 229040 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = _PRMJ_Now();
    var $14$0 = $14[0];
    var $14$1 = $14[1];
    __ZN9JSRuntime6GCData13setFirstEnterEy($3, $14$0, $14$1);
    __label__ = 4;
    break;
   case 4:
    var $16 = $3 | 0;
    return [ HEAP32[$16 >> 2], HEAP32[$16 + 4 >> 2] ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7GCTimer6finishEb($this, $lastGC) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 77 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[__ZN2js13newChunkCountE >> 2] = 0;
    HEAP32[__ZN2js17destroyChunkCountE >> 2] = 0;
    __label__ = 6;
    break;
   case 3:
    var $7 = _PRMJ_Now();
    var $7$1 = $7[1];
    var $8 = $this + 68 | 0;
    HEAP32[$8 >> 2] = $7[0];
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = $this + 12 | 0;
    if (HEAP32[$9 >> 2] == 0 && HEAP32[$9 + 4 >> 2] == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $this + 4 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = __ZN2js7GCTimer13getFirstEnterEv($this);
    var $15$0 = $15[0];
    var $15$1 = $15[1];
    var $16$0 = (i64Math.subtract($14$0, $14$1, $15$0, $15$1), i64Math.result[0]);
    var $16$1 = i64Math.result[1];
    var $18 = ($16$0 + $16$1 * 4294967296) / 1e3;
    var $19$0 = HEAP32[$8 >> 2];
    var $19$1 = HEAP32[$8 + 4 >> 2];
    var $20$0 = HEAP32[$13 >> 2];
    var $20$1 = HEAP32[$13 + 4 >> 2];
    var $21$0 = (i64Math.subtract($19$0, $19$1, $20$0, $20$1), i64Math.result[0]);
    var $21$1 = i64Math.result[1];
    var $23 = ($21$0 + $21$1 * 4294967296) / 1e3;
    var $24$0 = HEAP32[$9 >> 2];
    var $24$1 = HEAP32[$9 + 4 >> 2];
    var $25$0 = (i64Math.subtract($24$0, $24$1, $20$0, $20$1), i64Math.result[0]);
    var $25$1 = i64Math.result[1];
    var $27 = ($25$0 + $25$1 * 4294967296) / 1e3;
    var $28 = $this + 20 | 0;
    var $29$0 = HEAP32[$28 >> 2];
    var $29$1 = HEAP32[$28 + 4 >> 2];
    var $30$0 = (i64Math.subtract($29$0, $29$1, $24$0, $24$1), i64Math.result[0]);
    var $30$1 = i64Math.result[1];
    var $32 = ($30$0 + $30$1 * 4294967296) / 1e3;
    var $33 = $this + 60 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35$0 = (i64Math.subtract($34$0, $34$1, $29$0, $29$1), i64Math.result[0]);
    var $35$1 = i64Math.result[1];
    var $37 = ($35$0 + $35$1 * 4294967296) / 1e3;
    var $38 = $this + 28 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40$0 = (i64Math.subtract($39$0, $39$1, $29$0, $29$1), i64Math.result[0]);
    var $40$1 = i64Math.result[1];
    var $42 = ($40$0 + $40$1 * 4294967296) / 1e3;
    var $43 = $this + 36 | 0;
    var $44$0 = HEAP32[$43 >> 2];
    var $44$1 = HEAP32[$43 + 4 >> 2];
    var $45$0 = (i64Math.subtract($44$0, $44$1, $39$0, $39$1), i64Math.result[0]);
    var $45$1 = i64Math.result[1];
    var $47 = ($45$0 + $45$1 * 4294967296) / 1e3;
    var $48 = $this + 44 | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50$0 = (i64Math.subtract($49$0, $49$1, $44$0, $44$1), i64Math.result[0]);
    var $50$1 = i64Math.result[1];
    var $52 = ($50$0 + $50$1 * 4294967296) / 1e3;
    var $53 = $this + 52 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55$0 = (i64Math.subtract($54$0, $54$1, $49$0, $49$1), i64Math.result[0]);
    var $55$1 = i64Math.result[1];
    var $57 = ($55$0 + $55$1 * 4294967296) / 1e3;
    var $58$0 = (i64Math.subtract($34$0, $34$1, $54$0, $54$1), i64Math.result[0]);
    var $58$1 = i64Math.result[1];
    var $60 = ($58$0 + $58$1 * 4294967296) / 1e3;
    var $61$0 = (i64Math.subtract($19$0, $19$1, $34$0, $34$1), i64Math.result[0]);
    var $61$1 = i64Math.result[1];
    var $63 = ($61$0 + $61$1 * 4294967296) / 1e3;
    var $65 = HEAPU32[$this >> 2];
    var $68 = $65 + 234936 | 0;
    var $69 = HEAP32[$68 >> 2];
    var $71 = $69 + HEAP32[$65 + 234932 >> 2] & 63;
    var $72 = $69 + 1 | 0;
    HEAP32[$68 >> 2] = $72;
    var $73 = $65 + 229044 + $71 * 92 | 0;
    tempDoubleF64[0] = $18, HEAP32[$73 >> 2] = tempDoubleI32[0], HEAP32[$73 + 4 >> 2] = tempDoubleI32[1];
    var $74 = $65 + 229044 + $71 * 92 + 8 | 0;
    tempDoubleF64[0] = $23, HEAP32[$74 >> 2] = tempDoubleI32[0], HEAP32[$74 + 4 >> 2] = tempDoubleI32[1];
    var $75 = $65 + 229044 + $71 * 92 + 16 | 0;
    tempDoubleF64[0] = $27, HEAP32[$75 >> 2] = tempDoubleI32[0], HEAP32[$75 + 4 >> 2] = tempDoubleI32[1];
    var $76 = $65 + 229044 + $71 * 92 + 24 | 0;
    tempDoubleF64[0] = $32, HEAP32[$76 >> 2] = tempDoubleI32[0], HEAP32[$76 + 4 >> 2] = tempDoubleI32[1];
    var $77 = $65 + 229044 + $71 * 92 + 32 | 0;
    tempDoubleF64[0] = $37, HEAP32[$77 >> 2] = tempDoubleI32[0], HEAP32[$77 + 4 >> 2] = tempDoubleI32[1];
    var $78 = $65 + 229044 + $71 * 92 + 40 | 0;
    tempDoubleF64[0] = $42, HEAP32[$78 >> 2] = tempDoubleI32[0], HEAP32[$78 + 4 >> 2] = tempDoubleI32[1];
    var $79 = $65 + 229044 + $71 * 92 + 48 | 0;
    tempDoubleF64[0] = $47, HEAP32[$79 >> 2] = tempDoubleI32[0], HEAP32[$79 + 4 >> 2] = tempDoubleI32[1];
    var $80 = $65 + 229044 + $71 * 92 + 56 | 0;
    tempDoubleF64[0] = $52, HEAP32[$80 >> 2] = tempDoubleI32[0], HEAP32[$80 + 4 >> 2] = tempDoubleI32[1];
    var $81 = $65 + 229044 + $71 * 92 + 64 | 0;
    tempDoubleF64[0] = $57, HEAP32[$81 >> 2] = tempDoubleI32[0], HEAP32[$81 + 4 >> 2] = tempDoubleI32[1];
    var $82 = $65 + 229044 + $71 * 92 + 72 | 0;
    tempDoubleF64[0] = $60, HEAP32[$82 >> 2] = tempDoubleI32[0], HEAP32[$82 + 4 >> 2] = tempDoubleI32[1];
    var $83 = $65 + 229044 + $71 * 92 + 80 | 0;
    tempDoubleF64[0] = $63, HEAP32[$83 >> 2] = tempDoubleI32[0], HEAP32[$83 + 4 >> 2] = tempDoubleI32[1];
    var $86 = HEAP8[$this + 76 | 0] & 1;
    HEAP8[$65 + 229044 + $71 * 92 + 88 | 0] = $86;
    __label__ = 5;
    break;
   case 5:
    HEAP32[__ZN2js13newChunkCountE >> 2] = 0;
    HEAP32[__ZN2js17destroyChunkCountE >> 2] = 0;
    HEAP32[__ZN2js8gcReasonE >> 2] = 10;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7GCTimer6finishEb["X"] = 1;

function _JS_NewHashTable($n, $keyHash, $keyCompare, $valueCompare, $allocOps, $allocPriv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($n >>> 0 < 17) {
      var $_01 = 4;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = _JS_CeilingLog2($n);
    if (($3 | 0) < 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01;
    var $_02 = ($allocOps | 0) == 0 ? __ZL19defaultHashAllocOps : $allocOps;
    var $7 = $_02 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = FUNCTION_TABLE[$8]($allocPriv, 32);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _memset($9, 0, 32, 1);
    var $15 = $9 + 8 | 0;
    HEAP32[$15 >> 2] = 32 - $_01 | 0;
    var $16 = 4 << $_01;
    var $17 = HEAP32[$7 >> 2];
    var $18 = FUNCTION_TABLE[$17]($allocPriv, $16);
    var $19 = $18;
    var $20 = $9;
    HEAP32[$20 >> 2] = $19;
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = HEAP32[$_02 + 4 >> 2];
    FUNCTION_TABLE[$24]($allocPriv, $9, $16);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    _memset($18, 0, $16, 1);
    var $27 = $9 + 12 | 0;
    HEAP32[$27 >> 2] = $keyHash;
    var $29 = $9 + 16 | 0;
    HEAP32[$29 >> 2] = $keyCompare;
    var $31 = $9 + 20 | 0;
    HEAP32[$31 >> 2] = $valueCompare;
    var $33 = $9 + 24 | 0;
    HEAP32[$33 >> 2] = $_02;
    var $35 = $9 + 28 | 0;
    HEAP32[$35 >> 2] = $allocPriv;
    var $_0 = $10;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_NewHashTable["X"] = 1;

function _JS_HashTableDestroy($ht) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$ht + 24 >> 2];
    var $4 = HEAPU32[$ht + 28 >> 2];
    var $8 = 1 << 32 - HEAP32[$ht + 8 >> 2];
    var $9 = $ht | 0;
    var $10 = $2 + 12 | 0;
    var $i_01 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_01;
    var $12 = HEAP32[$9 >> 2] + ($i_01 << 2) | 0;
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $15 = $13;
      __label__ = 3;
      break;
    }
   case 3:
    var $15;
    var $17 = HEAP32[$15 >> 2];
    HEAP32[$12 >> 2] = $17;
    var $18 = HEAP32[$10 >> 2];
    FUNCTION_TABLE[$18]($4, $15, 1);
    var $19 = HEAPU32[$12 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $15 = $19;
      __label__ = 3;
      break;
    }
   case 4:
    var $21 = $i_01 + 1 | 0;
    if ($21 >>> 0 < $8 >>> 0) {
      var $i_01 = $21;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $2 + 4 | 0;
    var $25 = HEAP32[$24 >> 2];
    var $27 = HEAP32[$9 >> 2];
    var $28 = $8 << 2;
    FUNCTION_TABLE[$25]($4, $27, $28);
    var $29 = HEAP32[$24 >> 2];
    var $30 = $ht;
    FUNCTION_TABLE[$29]($4, $30, 32);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRawLookup($ht, $keyHash, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $7 = HEAP32[$ht >> 2] + (($keyHash * -1640531527 | 0) >>> (HEAPU32[$ht + 8 >> 2] >>> 0) << 2) | 0;
    var $8 = $ht + 16 | 0;
    var $hep_0 = $7;
    __label__ = 2;
    break;
   case 2:
    var $hep_0;
    var $10 = HEAPU32[$hep_0 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = $hep_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$10 + 4 >> 2] | 0) == ($keyHash | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $17 = HEAP32[$8 >> 2];
    var $19 = HEAP32[$10 + 8 >> 2];
    var $20 = FUNCTION_TABLE[$17]($key, $19);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($hep_0 | 0) == ($7 | 0)) {
      var $_0 = $7;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $10 | 0;
    var $26 = HEAP32[$25 >> 2];
    HEAP32[$hep_0 >> 2] = $26;
    var $27 = HEAP32[$7 >> 2];
    HEAP32[$25 >> 2] = $27;
    HEAP32[$7 >> 2] = $10;
    var $_0 = $7;
    __label__ = 8;
    break;
   case 7:
    var $hep_0 = $10 | 0;
    __label__ = 2;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRawAdd($ht, $hep, $keyHash, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$ht + 8 >> 2];
    var $4 = 1 << 32 - $2;
    var $5 = $ht + 4 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 < ($4 - ($4 >>> 3) | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 - 1 | 0;
    var $12 = __ZL6ResizeP11JSHashTablej($ht, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = _JS_HashTableRawLookup($ht, $keyHash, $key);
    HEAP32[$hep >> 2] = $15;
    __label__ = 4;
    break;
   case 4:
    var $20 = HEAP32[HEAP32[$ht + 24 >> 2] + 8 >> 2];
    var $22 = HEAP32[$ht + 28 >> 2];
    var $23 = FUNCTION_TABLE[$20]($22, $key);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = $23 + 4 | 0;
    HEAP32[$26 >> 2] = $keyHash;
    var $27 = $23 + 8 | 0;
    HEAP32[$27 >> 2] = $key;
    var $28 = $23 + 12 | 0;
    HEAP32[$28 >> 2] = $value;
    var $30 = HEAP32[HEAP32[$hep >> 2] >> 2];
    var $31 = $23 | 0;
    HEAP32[$31 >> 2] = $30;
    var $32 = HEAP32[$hep >> 2];
    HEAP32[$32 >> 2] = $23;
    var $34 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $34;
    var $_0 = $23;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6ResizeP11JSHashTablej($ht, $newshift) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ht + 8 | 0;
    var $3 = 32 - HEAP32[$1 >> 2] | 0;
    var $5 = 1 << 32 - $newshift;
    if ($5 >>> 0 > 1073741823) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5 << 2;
    var $9 = $ht | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $11 = $ht + 24 | 0;
    var $14 = HEAP32[HEAP32[$11 >> 2] >> 2];
    var $15 = $ht + 28 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = FUNCTION_TABLE[$14]($16, $8);
    var $18 = $17;
    HEAP32[$9 >> 2] = $18;
    if (($17 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$9 >> 2] = $10;
    var $_0 = 0;
    __label__ = 13;
    break;
   case 4:
    _memset($17, 0, $8, 1);
    HEAP32[$1 >> 2] = $newshift;
    var $23 = HEAP32[$ht + 4 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_07_ph = 0;
      var $nentries_08_ph = $23;
      __label__ = 5;
      break;
    }
   case 5:
    var $nentries_08_ph;
    var $i_07_ph;
    var $i_07 = $i_07_ph;
    __label__ = 6;
    break;
   case 6:
    var $i_07;
    var $26 = HEAP32[$10 + ($i_07 << 2) >> 2];
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $nentries_11 = $nentries_08_ph;
      var $he_02 = $26;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_07 = $i_07 + 1 | 0;
    __label__ = 6;
    break;
   case 8:
    var $he_02;
    var $nentries_11;
    var $29 = $nentries_11 - 1 | 0;
    var $30 = $he_02 | 0;
    var $31 = HEAPU32[$30 >> 2];
    var $38 = HEAP32[$9 >> 2] + ((HEAP32[$he_02 + 4 >> 2] * -1640531527 | 0) >>> (HEAPU32[$1 >> 2] >>> 0) << 2) | 0;
    var $39 = HEAPU32[$38 >> 2];
    if (($39 | 0) == 0) {
      var $hep_0_lcssa = $38;
      __label__ = 10;
      break;
    } else {
      var $41 = $39;
      __label__ = 9;
      break;
    }
   case 9:
    var $41;
    var $42 = $41 | 0;
    var $43 = HEAP32[$42 >> 2];
    if (($43 | 0) == 0) {
      var $hep_0_lcssa = $42;
      __label__ = 10;
      break;
    } else {
      var $41 = $43;
      __label__ = 9;
      break;
    }
   case 10:
    var $hep_0_lcssa;
    HEAP32[$30 >> 2] = 0;
    HEAP32[$hep_0_lcssa >> 2] = $he_02;
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $nentries_11 = $29;
      var $he_02 = $31;
      __label__ = 8;
      break;
    }
   case 11:
    if (($29 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $i_07_ph = $i_07 + 1 | 0;
      var $nentries_08_ph = $29;
      __label__ = 5;
      break;
    }
   case 12:
    var $50 = HEAP32[HEAP32[$11 >> 2] + 4 >> 2];
    var $51 = HEAP32[$15 >> 2];
    var $52 = $10;
    var $53 = 4 << $3;
    FUNCTION_TABLE[$50]($51, $52, $53);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6ResizeP11JSHashTablej["X"] = 1;

function _JS_HashTableAdd($ht, $key, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hep = __stackBase__;
    var $2 = HEAP32[$ht + 12 >> 2];
    var $3 = FUNCTION_TABLE[$2]($key);
    var $4 = _JS_HashTableRawLookup($ht, $3, $key);
    HEAP32[$hep >> 2] = $4;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$ht + 20 >> 2];
    var $10 = $5 + 12 | 0;
    var $11 = HEAP32[$10 >> 2];
    var $12 = FUNCTION_TABLE[$9]($11, $value);
    if (($12 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$10 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = HEAP32[HEAP32[$ht + 24 >> 2] + 12 >> 2];
    var $23 = HEAP32[$ht + 28 >> 2];
    FUNCTION_TABLE[$21]($23, $5, 0);
    __label__ = 5;
    break;
   case 5:
    HEAP32[$10 >> 2] = $value;
    var $_0 = $5;
    __label__ = 7;
    break;
   case 6:
    var $26 = _JS_HashTableRawAdd($ht, $hep, $3, $key, $value);
    var $_0 = $26;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRawRemove($ht, $hep, $he) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$he >> 2];
    HEAP32[$hep >> 2] = $2;
    var $6 = HEAP32[HEAP32[$ht + 24 >> 2] + 12 >> 2];
    var $8 = HEAP32[$ht + 28 >> 2];
    FUNCTION_TABLE[$6]($8, $he, 1);
    var $10 = HEAPU32[$ht + 8 >> 2];
    var $12 = 1 << 32 - $10;
    var $13 = $ht + 4 | 0;
    var $15 = HEAP32[$13 >> 2] - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    var $_ = $12 >>> 0 > 16 ? $12 >>> 2 : 0;
    if ($15 >>> 0 < $_ >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $20 = $10 + 1 | 0;
    var $21 = __ZL6ResizeP11JSHashTablej($ht, $20);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableRemove($ht, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$ht + 12 >> 2];
    var $3 = FUNCTION_TABLE[$2]($key);
    var $4 = _JS_HashTableRawLookup($ht, $3, $key);
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_HashTableRawRemove($ht, $4, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableLookup($ht, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$ht + 12 >> 2];
    var $3 = FUNCTION_TABLE[$2]($key);
    var $4 = _JS_HashTableRawLookup($ht, $3, $key);
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$5 + 12 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_HashTableEnumerateEntries($ht, $f, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ht + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $5 = $ht + 24 | 0;
    var $6 = $ht + 28 | 0;
    var $n_0 = 0;
    var $bucket_0 = HEAP32[$ht >> 2];
    __label__ = 2;
    break;
   case 2:
    var $bucket_0;
    var $n_0;
    if (($n_0 | 0) == ($2 | 0)) {
      var $n_2 = $n_0;
      __label__ = 8;
      break;
    } else {
      var $n_1 = $n_0;
      var $hep_0 = $bucket_0;
      __label__ = 3;
      break;
    }
   case 3:
    var $hep_0;
    var $n_1;
    var $9 = HEAP32[$hep_0 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = FUNCTION_TABLE[$f]($9, $n_1, $arg);
    var $13 = $n_1 + 1 | 0;
    var $16 = $9 | 0;
    if (($12 & 2 | 0) == 0) {
      var $hep_1 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$16 >> 2];
    HEAP32[$hep_0 >> 2] = $18;
    var $21 = HEAP32[HEAP32[$5 >> 2] + 12 >> 2];
    var $22 = HEAP32[$6 >> 2];
    FUNCTION_TABLE[$21]($22, $9, 1);
    var $24 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $24;
    var $hep_1 = $hep_0;
    __label__ = 6;
    break;
   case 6:
    var $hep_1;
    if (($12 & 1 | 0) == 0) {
      var $n_1 = $13;
      var $hep_0 = $hep_1;
      __label__ = 3;
      break;
    } else {
      var $n_2 = $13;
      __label__ = 8;
      break;
    }
   case 7:
    var $n_0 = $n_1;
    var $bucket_0 = $bucket_0 + 4 | 0;
    __label__ = 2;
    break;
   case 8:
    var $n_2;
    var $30 = HEAPU32[$1 >> 2];
    if (($30 | 0) == ($2 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = 1 << 32 - HEAP32[$ht + 8 >> 2];
    if ($36 >>> 0 > 16 & $30 >>> 0 < $36 >>> 2 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $41 = _JS_CeilingLog2($30);
    var $43 = $41 >>> 0 < 4 ? 28 : 32 - $41 | 0;
    var $44 = __ZL6ResizeP11JSHashTablej($ht, $43);
    __label__ = 11;
    break;
   case 11:
    return $n_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_HashTableEnumerateEntries["X"] = 1;

function _JS_HashTableDump($ht, $dump, $fp) {
  var $1 = $fp;
  var $2 = _JS_HashTableEnumerateEntries($ht, $dump, $1);
  return $2;
}

function __ZL17DefaultAllocTablePvj($pool, $size) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej($size);
  return $1;
}

function __ZL16DefaultFreeTablePvS_j($pool, $item, $size) {
  __ZN2js10Foreground5free_EPv($item);
  return;
}

function __ZL17DefaultAllocEntryPvPKv($pool, $key) {
  var $1 = __ZN2js11OffTheBooks7malloc_Ej(16);
  return $1;
}

function __ZL16DefaultFreeEntryPvP11JSHashEntryj($pool, $he, $flag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flag | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $he;
    __ZN2js10Foreground5free_EPv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types11TypeFailureEP9JSContextPKcz($cx, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 2052;
  var $msgbuf = __stackBase__;
  var $errbuf = __stackBase__ + 1024;
  var $ap = __stackBase__ + 2048;
  HEAP32[$ap >> 2] = arguments[__ZN2js5types11TypeFailureEP9JSContextPKcz.length];
  var $2 = $errbuf | 0;
  var $3 = HEAP32[$ap >> 2];
  var $4 = _JS_vsnprintf($2, 1024, $fmt, $3);
  var $5 = $msgbuf | 0;
  var $6 = _JS_snprintf($5, 1024, STRING_TABLE.__str1568 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2, tempInt));
  var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
  __ZN2js5types15TypeCompartment5printEP9JSContextb($9, $cx, 1);
  _JS_Assert($5, STRING_TABLE.__str11569 | 0, 341);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types15TypeCompartment5printEP9JSContextb($this, $cx, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __ZN2js5types15TypeCompartment11compartmentEv($this);
    if ($force) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL15InferSpewActiveN2js5types11SpewChannelE();
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i, undef, $1, 13);
    var $5 = $i | 0;
    var $6 = __ZNK2js2gc12CellIterImpl4doneEv($5);
    if ($6) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($5);
    var $8 = __ZN8JSScript11hasAnalysisEv($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $10 = __ZN8JSScript8analysisEv($7);
    var $11 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext($10, $cx);
    __label__ = 7;
    break;
   case 7:
    __ZN2js2gc12CellIterImpl4nextEv($5);
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($5);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 8:
    STACKTOP = __stackBase__;
    return;
   case 9:
    __ZN2js2gc8CellIterD1Ev($i);
    var $16 = _printf(STRING_TABLE.__str231593 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $18 = HEAP32[$this + 56 >> 2];
    var $19 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $18, tempInt));
    var $putchar_1 = _putchar(47);
    var $21 = HEAP32[$this + 60 >> 2];
    var $22 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $21, tempInt));
    var $putchar_2 = _putchar(47);
    var $24 = HEAP32[$this + 64 >> 2];
    var $25 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $24, tempInt));
    var $putchar_3 = _putchar(47);
    var $27 = HEAP32[$this + 68 >> 2];
    var $28 = _printf(STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    var $30 = HEAP32[$this + 72 >> 2];
    var $31 = _printf(STRING_TABLE.__str261596 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $30, tempInt));
    var $33 = HEAP32[$this + 16 >> 2];
    var $34 = _printf(STRING_TABLE.__str271597 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    __label__ = 8;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet4makeEP9JSContextPKc($cx, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 56 | 0;
    var $3 = HEAP32[$1 >> 2] + 344 | 0;
    var $4 = __ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool($3);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($8, $cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js5types7TypeSetC1Ev($23);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$cx + 56 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    __label__ = 4;
    break;
   case 4:
    HEAP8[$1] = 1;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types7TypeSet18isDefinitePropertyEv($this) {
  return (HEAP32[$this >> 2] & 1048576 | 0) != 0;
}

function __ZNK2js5types7TypeSet12definiteSlotEv($this) {
  return HEAPU32[$this >> 2] >>> 24;
}

function __ZN2js5types7TypeSet5printEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 & 262144 | 0) == 0) {
      var $9 = $3;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = _printf(STRING_TABLE.__str31571 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $9 = HEAP32[$2 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    if (($9 & 524288 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = _printf(STRING_TABLE.__str41572 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 5;
    break;
   case 5:
    var $15 = __ZNK2js5types7TypeSet18isDefinitePropertyEv($this);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZNK2js5types7TypeSet12definiteSlotEv($this);
    var $18 = _printf(STRING_TABLE.__str51573 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $17, tempInt));
    __label__ = 7;
    break;
   case 7:
    var $20 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($23 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = _printf(STRING_TABLE.__str61574 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 33;
    break;
   case 10:
    var $27 = HEAP32[$2 >> 2];
    if (($27 & 65536 | 0) == 0) {
      var $33 = $27;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = _printf(STRING_TABLE.__str71575 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $33 = HEAP32[$2 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $33;
    if (($33 & 128 | 0) == 0) {
      var $39 = $33;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $37 = _printf(STRING_TABLE.__str81576 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $39 = HEAP32[$2 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $39;
    if (($39 & 1 | 0) == 0) {
      var $45 = $39;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $43 = _printf(STRING_TABLE.__str91577 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $45 = HEAP32[$2 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $45;
    if (($45 & 2 | 0) == 0) {
      var $51 = $45;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $49 = _printf(STRING_TABLE.__str101578 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $51 = HEAP32[$2 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $51;
    if (($51 & 4 | 0) == 0) {
      var $57 = $51;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = _printf(STRING_TABLE.__str111579 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $57 = HEAP32[$2 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $57;
    if (($57 & 8 | 0) == 0) {
      var $63 = $57;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = _printf(STRING_TABLE.__str121580 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $63 = HEAP32[$2 >> 2];
    __label__ = 22;
    break;
   case 22:
    var $63;
    if (($63 & 16 | 0) == 0) {
      var $69 = $63;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $67 = _printf(STRING_TABLE.__str131581 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $69 = HEAP32[$2 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $69;
    if (($69 & 32 | 0) == 0) {
      var $75 = $69;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $73 = _printf(STRING_TABLE.__str141582 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $75 = HEAP32[$2 >> 2];
    __label__ = 26;
    break;
   case 26:
    var $75;
    if (($75 & 64 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $79 = _printf(STRING_TABLE.__str151583 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 28;
    break;
   case 28:
    var $81 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($81 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $84 = _printf(STRING_TABLE.__str161584 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $81, tempInt));
    var $85 = __ZN2js5types7TypeSet14getObjectCountEv($this);
    if (($85 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 30;
      break;
    }
   case 30:
    var $i_01;
    var $87 = __ZN2js5types7TypeSet9getObjectEj($this, $i_01);
    if (($87 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($1, $87);
    var $90 = _printf(STRING_TABLE.__str442717 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 32;
    break;
   case 32:
    var $92 = $i_01 + 1 | 0;
    if (($92 | 0) == ($85 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $i_01 = $92;
      __label__ = 30;
      break;
    }
   case 33:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet5printEP9JSContext["X"] = 1;

function __ZN2js5types7TypeSet14getObjectCountEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if ($1 >>> 0 > 8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet9getObjectEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    var $4 = HEAP32[$this + 4 >> 2];
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $_0 = HEAP32[$4 + ($i << 2) >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($agg_result, $obj) {
  var $1 = $obj;
  __ZN2js5types4TypeC1Ej($agg_result, $1);
  return;
}

function __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($this, $cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $target;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $constraint, $callExisting) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    if (($constraint | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    __label__ = 16;
    break;
   case 3:
    var $11 = $this + 8 | 0;
    var $12 = HEAP32[$11 >> 2];
    HEAP32[$constraint + 4 >> 2] = $12;
    HEAP32[$11 >> 2] = $constraint;
    if ($callExisting) {
      __label__ = 4;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 4:
    var $15 = $this | 0;
    var $16 = HEAP32[$15 >> 2];
    var $19 = $cx + 56 | 0;
    if (($16 & 65536 | 0) == 0) {
      var $flag_02 = 1;
      var $25 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($22, $cx, $constraint, $this, $1);
    var $24 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($24, $cx);
    __label__ = 16;
    break;
   case 6:
    var $25;
    var $flag_02;
    if (($25 & $flag_02 | 0) == 0) {
      var $33 = $25;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = __ZN2js5types17TypeFlagPrimitiveEj($flag_02);
    __ZN2js5types4Type13PrimitiveTypeE11JSValueType($2, $29);
    var $31 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($31, $cx, $constraint, $this, $2);
    var $33 = HEAP32[$15 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $33;
    var $34 = $flag_02 << 1;
    if ($34 >>> 0 < 128) {
      var $flag_02 = $34;
      var $25 = $33;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($33 & 128 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type13AnyObjectTypeEv($3);
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($41, $cx, $constraint, $this, $3);
    var $43 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($43, $cx);
    __label__ = 16;
    break;
   case 11:
    var $45 = __ZN2js5types7TypeSet14getObjectCountEv($this);
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 12;
      break;
    }
   case 12:
    var $i_01;
    var $47 = __ZN2js5types7TypeSet9getObjectEj($this, $i_01);
    if (($47 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($4, $47);
    __ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE($51, $cx, $constraint, $this, $4);
    __label__ = 14;
    break;
   case 14:
    var $53 = $i_01 + 1 | 0;
    if (($53 | 0) == ($45 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $i_01 = $53;
      __label__ = 12;
      break;
    }
   case 15:
    var $55 = HEAP32[$19 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment14resolvePendingEP9JSContext($55, $cx);
    __label__ = 16;
    break;
   case 16:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb["X"] = 1;

function __ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($this, $cx, $script, $pc, $target, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  HEAP32[$4 >> 2] = $id;
  var $8 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  HEAP8[$5] = 0;
  var $9 = __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($8, $1, $2, $3, $4, $5);
  var $10 = $9 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $10, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($pool, $a, $b, $c, $d, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $27 = HEAP32[$d >> 2];
    var $30 = (HEAP8[$e] & 1) << 24 >> 24 != 0;
    __ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib($23, $24, $25, $26, $27, $30);
    var $32 = $23;
    __label__ = 6;
    break;
   case 6:
    var $32;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($this, $cx, $script, $pc, $target, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  var $5 = __stackBase__ + 16;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  HEAP32[$4 >> 2] = $id;
  var $8 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  HEAP8[$5] = 1;
  var $9 = __ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($8, $1, $2, $3, $4, $5);
  var $10 = $9 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $10, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi($this, $cx, $script, $pc, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $callpc = __stackBase__ + 8;
    var $untrap = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $script;
    HEAP32[$2 >> 2] = $id;
    var $3 = __ZN8JSScript8analysisEv($script);
    var $4 = __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($3, $pc);
    HEAP32[$callpc >> 2] = $4;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $4);
    if (HEAP8[$4] << 24 >> 24 == 82) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $11 = __ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($10, $1, $callpc, $2);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $12, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($this, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $8 = $pc - HEAP32[HEAP32[$2 >> 2] >> 2] | 0;
  __ZN2js7analyze8SSAValue11PushedValueEjj($1, $8, 1);
  var $9 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $1);
  var $17 = HEAP32[HEAP32[$2 >> 2] >> 2] + (HEAPU32[HEAP32[$9 >> 2] >> 2] >>> 1) | 0;
  STACKTOP = __stackBase__;
  return $17;
}

function __ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN22TypeConstraintCallPropC1EP8JSScriptPhi($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_($this, $cx, $script, $pc, $objectTypes, $valueTypes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  var $4 = __stackBase__ + 12;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $objectTypes;
  HEAP32[$4 >> 2] = $valueTypes;
  var $7 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $8 = __ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($7, $1, $2, $3, $4);
  var $9 = $8 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $9, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $29 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $27 = HEAP32[$d >> 2];
    __ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_($23, $24, $25, $26, $27);
    var $29 = $23;
    __label__ = 6;
    break;
   case 6:
    var $29;
    return $29;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE($this, $cx, $site) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $site;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($this, $cx, $target, $other) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $target;
  HEAP32[$2 >> 2] = $other;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_($this, $cx, $script, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $target;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($this, $cx, $script, $pc, $type, $types) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $callpc = __stackBase__ + 8;
    var $untrap = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $script;
    HEAP32[$2 >> 2] = $types;
    var $3 = __ZN8JSScript8analysisEv($script);
    var $4 = __ZN2js7analyze14ScriptAnalysis9getCallPCEPh($3, $pc);
    HEAP32[$callpc >> 2] = $4;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $4);
    if (HEAP8[$4] << 24 >> 24 == 82) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $11 = __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($10, $1, $callpc, $type, $2);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $12, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + 24 & ($5 ^ -1);
    var $9 = $3 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$3 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $_p_0;
    var $25 = HEAP32[$a >> 2];
    var $26 = HEAP32[$b >> 2];
    var $28 = HEAP32[$c >> 2];
    HEAP32[$1 >> 2] = $28;
    var $30 = HEAP32[$d >> 2];
    __ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($24, $25, $26, $1, $30);
    var $32 = $24;
    __label__ = 6;
    break;
   case 6:
    var $32;
    STACKTOP = __stackBase__;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($this, $cx, $target, $filter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$1 >> 2] = $target;
  HEAP32[$2 >> 2] = $filter;
  var $5 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $6 = __ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_($5, $1, $2);
  var $7 = $6 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $7, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj($this, $cx, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
    var $4 = $1 | 0;
    var $pbarrier_0_ph = $2 + 40 | 0;
    __label__ = 2;
    break;
   case 2:
    var $pbarrier_0_ph;
    var $6 = HEAP32[$pbarrier_0_ph >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    if (($6 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$6 + 4 >> 2];
    var $12 = HEAP32[$6 + 8 >> 2];
    HEAP32[$4 >> 2] = $12;
    var $13 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($10, $1);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $storemerge = HEAP32[$6 >> 2];
    HEAP32[$pbarrier_0_ph >> 2] = $storemerge;
    var $6 = $storemerge;
    __label__ = 3;
    break;
   case 6:
    var $15 = $6 + 12 | 0;
    var $16 = HEAP32[$15 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = HEAP32[$6 + 16 >> 2];
    var $21 = __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $16, $20);
    if (($21 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = HEAP32[$15 >> 2];
    var $26 = HEAP32[$21 + 24 >> 2];
    var $27 = __ZNK8JSObject13nativeGetSlotEj($24, $26);
    var $28 = __ZNK2JS5Value11isUndefinedEv($27);
    if ($28) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 9:
    var $pbarrier_0_ph = $6 | 0;
    __label__ = 2;
    break;
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4Type11isPrimitiveE11JSValueType($this, $type) {
  return ($type & 255 | 0) == (HEAP32[$this >> 2] | 0);
}

function __ZN2js5types7TypeSet21hasPropagatedPropertyEv($this) {
  return (HEAP32[$this >> 2] & 131072 | 0) != 0;
}

function __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    if (($1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    if ((HEAP32[$1 + 24 >> 2] | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $1;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($this, $cx, $offset, $all) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    __ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj($this, $cx, $offset);
    var $4 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
    var $6 = $1 | 0;
    var $7 = $2 | 0;
    var $8 = $3 | 0;
    var $pbarrier_0_ph = $4 + 40 | 0;
    __label__ = 2;
    break;
   case 2:
    var $pbarrier_0_ph;
    var $9 = HEAP32[$pbarrier_0_ph >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    if (($9 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9 + 4 | 0;
    var $13 = HEAP32[$12 >> 2];
    var $14 = $9 + 8 | 0;
    var $15 = $14 | 0;
    var $16 = HEAP32[$15 >> 2];
    HEAP32[$6 >> 2] = $16;
    var $17 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($13, $1);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = HEAP32[$9 >> 2];
    HEAP32[$pbarrier_0_ph >> 2] = $20;
    var $9 = $20;
    __label__ = 3;
    break;
   case 6:
    if ($all) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = HEAP32[$12 >> 2];
    var $24 = HEAP32[$15 >> 2];
    HEAP32[$7 >> 2] = $24;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($23, $cx, $2);
    var $26 = HEAPU32[$9 >> 2];
    HEAP32[$pbarrier_0_ph >> 2] = $26;
    var $9 = $26;
    __label__ = 3;
    break;
   case 8:
    var $28 = __ZNK2js5types4Type9isUnknownEv($14);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = __ZNK2js5types4Type11isAnyObjectEv($14);
    if ($30) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $32 = __ZNK2js5types4Type8isObjectEv($14);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $34 = HEAPU32[$12 >> 2];
    var $35 = __ZN2js5types7TypeSet14getObjectCountEv($34);
    if ($35 >>> 0 > 9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $38 = HEAP32[$15 >> 2];
    HEAP32[$8 >> 2] = $38;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($34, $cx, $3);
    var $40 = HEAPU32[$9 >> 2];
    HEAP32[$pbarrier_0_ph >> 2] = $40;
    var $9 = $40;
    __label__ = 3;
    break;
   case 13:
    var $pbarrier_0_ph = $9 | 0;
    __label__ = 2;
    break;
   case 14:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($this, $cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js7analyze8SSAValue4kindEv($v);
    if (($1 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($v);
    if (HEAP8[HEAP32[HEAP32[$this >> 2] >> 2] + $4 | 0] << 24 >> 24 == 53) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZN2js7analyze14ScriptAnalysis11poppedValueEjj($this, $4, 0);
    __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($this, $cx, $13);
    __label__ = 4;
    break;
   case 4:
    __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($this, $cx, $4, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($this, $cx, $script, $pc, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __stackBase__ + 8;
  HEAP32[$1 >> 2] = $script;
  HEAP32[$2 >> 2] = $pc;
  HEAP32[$3 >> 2] = $target;
  var $6 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $7 = __ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($6, $1, $2, $3);
  var $8 = $7 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $8, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_($this, $cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $target;
  var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $5 = __ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($4, $1);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $3, $5);
    var $6 = HEAP32[$2 >> 2];
    var $8 = HEAP32[$type >> 2];
    var $9 = __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($6, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $15 = HEAP32[$4 >> 2];
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $21 = $15 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $6, $21, 0);
    __label__ = 13;
    break;
   case 4:
    var $24 = HEAP32[$this + 20 >> 2];
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $6, $15, $24);
    __label__ = 13;
    break;
   case 5:
    var $26 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 4);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    if ((HEAP8[$this + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $34 = HEAP32[$this + 24 >> 2];
    if (($34 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2];
    var $37 = __ZL9id_lengthP9JSContext($cx_idx_val_idx_val);
    if (($34 | 0) == ($37 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    var $39 = HEAP32[$4 >> 2];
    var $41 = HEAP32[$this + 20 >> 2];
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $6, $39, $41);
    __label__ = 13;
    break;
   case 10:
    var $44 = HEAP32[$this + 20 >> 2];
    __ZN2js5types4Type9Int32TypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($44, $cx, $1);
    __label__ = 13;
    break;
   case 11:
    var $46 = __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $6, $8);
    if (($46 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = HEAP32[$2 >> 2];
    var $50 = HEAP32[$4 >> 2];
    var $54 = (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 != 0;
    var $56 = HEAP32[$this + 20 >> 2];
    var $58 = HEAP32[$this + 24 >> 2];
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $49, $50, $46, $54, $56, $58);
    __label__ = 13;
    break;
   case 13:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($script, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    HEAP32[$type >> 2] = $type_0;
    var $1 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($1) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($3) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type8isObjectEv($type);
    if ($5) {
      var $10 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK8JSScript9hasGlobalEv($script);
    var $10 = $7 ^ 1;
    __label__ = 5;
    break;
   case 5:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb($this, $cx, $script, $offset, $returnOnly) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __ZN8JSScript8analysisEv($script);
    var $4 = HEAP32[$script >> 2] + $offset | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $4);
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($1, $4);
    var $7 = $5 + 1 | 0;
    var $8 = HEAPU8[$7];
    var $9 = $returnOnly ? 8 : 4;
    if (($8 & $9) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$4] & 255) << 3) + 4 >> 2] & 2097152 | 0) == 0) {
      var $21 = $8;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $8 | 8;
    HEAP8[$7] = $19;
    var $21 = $19;
    __label__ = 4;
    break;
   case 4:
    var $21;
    if ($returnOnly) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$7] = $21 | 4;
    __label__ = 6;
    break;
   case 6:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = __ZNK8JSScript8functionEv($script);
    var $31 = $30 | 0;
    var $32 = __ZNK8JSObject11hasLazyTypeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZNK8JSObject4typeEv($31);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $34, 0, 1);
    __label__ = 9;
    break;
   case 9:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $script, $pc, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $pc_val = HEAP8[$pc];
    var $3 = __ZL22UsePropertyTypeBarrierPh($pc_val);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN8JSScript8analysisEv($script);
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($5, $cx, $pc, $target, $1);
    __label__ = 4;
    break;
   case 3:
    __ZN2js5types4Type11UnknownTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($target, $cx, $2);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9id_lengthP9JSContext($cx_0_11_val_0_70_28_val) {
  var $1 = $cx_0_11_val_0_70_28_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js5types4Type9Int32TypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 1);
  return;
}

function __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $script, $type_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    HEAP32[$type >> 2] = $type_0;
    var $1 = __ZNK2js5types4Type12isTypeObjectEv($type);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type10typeObjectEv($type);
    var $_0 = $3;
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK2js5types4Type14isSingleObjectEv($type);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type12singleObjectEv($type);
    var $8 = $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject7getTypeEP9JSContext($8, $9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 5:
    var $13 = __ZNK2js5types4Type9primitiveEv($type);
    var $14 = $13 & 255;
    if (($14 | 0) == 1 || ($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 3) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 5) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $16 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script, 8);
    var $object_0 = $16;
    __label__ = 9;
    break;
   case 7:
    var $18 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script, 4);
    var $object_0 = $18;
    __label__ = 9;
    break;
   case 8:
    var $20 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script, 9);
    var $object_0 = $20;
    __label__ = 9;
    break;
   case 9:
    var $object_0;
    if (($object_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $object_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($26, $cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $script, $pc, $object, $assign, $target, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($object);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($assign) {
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE($cx, $script, $pc, $target);
    __label__ = 16;
    break;
   case 4:
    var $5 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($object, $cx, $id, $assign);
    if (($5 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($assign) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($target, $cx, $5);
    __label__ = 16;
    break;
   case 7:
    var $10 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($5);
    if ($10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($object, $cx, $id, $5, 0);
    __label__ = 9;
    break;
   case 9:
    var $pc_val = HEAP8[$pc];
    var $13 = __ZL22UsePropertyTypeBarrierPh($pc_val);
    if ($13) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($5, $cx, $script, $pc, $target);
    var $15 = $object + 4 | 0;
    var $16 = HEAP32[$15 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $19 = _JSID_IS_VOID1691($id);
    if (($19 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $22 = __ZL17GetSingletonShapeP9JSContextP8JSObjecti($cx, $16, $id);
    if (($22 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $25 = HEAP32[$15 >> 2];
    var $27 = HEAP32[$22 + 24 >> 2];
    var $28 = __ZNK8JSObject13nativeGetSlotEj($25, $27);
    var $29 = __ZNK2JS5Value11isUndefinedEv($28);
    if ($29) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $31 = __ZN8JSScript8analysisEv($script);
    __ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti($31, $cx, $pc, $target, $25, $id);
    __label__ = 16;
    break;
   case 15:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($5, $cx, $target);
    __label__ = 16;
    break;
   case 16:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 8 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $3, $5);
    var $6 = HEAP32[$2 >> 2];
    var $8 = HEAP32[$type >> 2];
    var $9 = __ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE($6, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = HEAP32[$4 >> 2] - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $6, $16, 0);
    __label__ = 10;
    break;
   case 3:
    var $18 = __ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE($cx, $6, $8);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = __ZN2js5types10TypeObject17unknownPropertiesEv($18);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = HEAP32[$2 >> 2];
    var $29 = HEAP32[$4 >> 2] - HEAP32[$23 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $23, $29, 0);
    __label__ = 10;
    break;
   case 6:
    var $31 = $this + 16 | 0;
    var $32 = HEAP32[$31 >> 2];
    var $33 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($18, $cx, $32, 0);
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($33);
    if ($36) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $38 = HEAP32[$31 >> 2];
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($18, $cx, $38, $33, 0);
    __label__ = 9;
    break;
   case 9:
    var $42 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = 0;
    var $43 = __ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($42, $2, $4, $type, $1);
    var $44 = $43 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($33, $cx, $44, 1);
    __label__ = 10;
    break;
   case 10:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($this, $cx, $id, $types, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($force) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($types);
    if ($3) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types7TypeSet21setPropagatedPropertyEv($types);
    var $5 = $this | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $6;
    var $10 = $cx;
    var $11 = __ZN8JSObject7getTypeEP9JSContext($9, $10);
    var $12 = $11;
    var $13 = __ZN2js5types10TypeObject17unknownPropertiesEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $1);
    __label__ = 8;
    break;
   case 6:
    var $16 = HEAP32[$5 >> 2];
    var $17 = __ZNK8JSObject4typeEv($16);
    var $18 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($17, $cx, $id, 0);
    if (($18 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($18, $cx, $types);
    var $21 = HEAP32[$5 >> 2];
    var $22 = __ZNK8JSObject4typeEv($21);
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($22, $cx, $id, $18, 0);
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 1);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 0);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = HEAP32[$this + 16 >> 2];
    var $10 = HEAP32[$this + 8 >> 2];
    var $12 = HEAP32[$this + 12 >> 2];
    var $14 = HEAP32[$this + 20 >> 2];
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($8, $cx, $10, $12, $14, 2);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $6 = HEAPU32[$4 >> 2];
    var $8 = HEAPU32[$4 + 4 >> 2];
    var $9 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = $8 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $6, $17, 0);
    __label__ = 28;
    break;
   case 4:
    var $19 = __ZNK2js5types4Type14isSingleObjectEv($type);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    var $21 = __ZNK2js5types4Type12singleObjectEv($type);
    var $22 = __ZNK8JSObject10isFunctionEv($21);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 6:
    var $24 = __ZNK8JSObject18getFunctionPrivateEv($21);
    var $25 = $24;
    var $26 = __ZNK10JSFunction8isNativeEv($25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $callee_0 = $24;
      __label__ = 19;
      break;
    }
   case 7:
    var $32 = $8 - HEAP32[$6 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $6, $32, 1);
    var $33 = __ZNK8JSObject18getFunctionPrivateEv($21);
    var $34 = $33;
    var $35 = __ZNK10JSFunction6nativeEv($34);
    if (($35 | 0) == 130) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $37 = HEAP32[$3 >> 2];
    if ((HEAP32[$37 + 16 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $i_011 = 0;
      var $41 = $37;
      __label__ = 9;
      break;
    }
   case 9:
    var $41;
    var $i_011;
    var $43 = HEAP32[$41 + 20 >> 2];
    var $47 = HEAP32[HEAP32[$41 + 12 >> 2] + ($i_011 << 2) >> 2];
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($43, $cx, $6, $8, $47, 2);
    var $48 = $i_011 + 1 | 0;
    var $49 = HEAPU32[$3 >> 2];
    if ($48 >>> 0 < HEAPU32[$49 + 16 >> 2] >>> 0) {
      var $i_011 = $48;
      var $41 = $49;
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($35 | 0) == 132) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[$3 >> 2];
    var $56 = HEAP32[$54 + 20 >> 2];
    var $58 = HEAP32[$54 + 24 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($56, $cx, $6, $8, $58, 2);
    __label__ = 28;
    break;
   case 12:
    if (($35 | 0) == 66) {
      __label__ = 13;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 13:
    var $62 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $6, $8, 3);
    if (($62 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $67 = HEAP32[HEAP32[$3 >> 2] + 24 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($1, $62);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($67, $cx, $1);
    var $68 = HEAPU32[$3 >> 2];
    if (HEAPU32[$68 + 16 >> 2] >>> 0 > 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 15:
    var $i1_07 = 0;
    var $73 = $68;
    __label__ = 16;
    break;
   case 16:
    var $73;
    var $i1_07;
    var $77 = HEAP32[HEAP32[$73 + 12 >> 2] + ($i1_07 << 2) >> 2];
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($cx, $6, $8, $62, 1, $77, 2);
    var $78 = $i1_07 + 1 | 0;
    var $79 = HEAPU32[$3 >> 2];
    if ($78 >>> 0 < HEAPU32[$79 + 16 >> 2] >>> 0) {
      var $i1_07 = $78;
      var $73 = $79;
      __label__ = 16;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    var $84 = __ZNK2js5types4Type12isTypeObjectEv($type);
    if ($84) {
      __label__ = 18;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 18:
    var $86 = __ZNK2js5types4Type10typeObjectEv($type);
    var $88 = HEAP32[$86 + 28 >> 2];
    if (($88 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $callee_0 = $88;
      __label__ = 19;
      break;
    }
   case 19:
    var $callee_0;
    var $91 = __ZNK10JSFunction6scriptEv($callee_0);
    var $92 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($91, $cx, $callee_0);
    if ($92) {
      __label__ = 20;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 20:
    var $95 = HEAPU16[$callee_0 + 56 >> 1];
    var $96 = $95 & 65535;
    var $97 = HEAPU32[$3 >> 2];
    var $99 = HEAPU32[$97 + 16 >> 2];
    if (($99 | 0) != 0 & $95 << 16 >> 16 != 0) {
      var $i2_04 = 0;
      var $105 = $97;
      __label__ = 22;
      break;
    } else {
      var $_lcssa2 = $99;
      var $102 = $97;
      __label__ = 21;
      break;
    }
   case 21:
    var $102;
    var $_lcssa2;
    var $103 = $_lcssa2 >>> 0 < $96 >>> 0;
    var $104 = __ZNK10JSFunction6scriptEv($callee_0);
    if ($103) {
      var $i3_01 = $_lcssa2;
      var $118 = $104;
      __label__ = 23;
      break;
    } else {
      var $_lcssa = $104;
      var $122 = $102;
      __label__ = 25;
      break;
    }
   case 22:
    var $105;
    var $i2_04;
    var $109 = HEAP32[HEAP32[$105 + 12 >> 2] + ($i2_04 << 2) >> 2];
    var $110 = __ZNK10JSFunction6scriptEv($callee_0);
    var $111 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($110, $i2_04);
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($109, $cx, $6, $8, $111);
    var $112 = $i2_04 + 1 | 0;
    var $113 = HEAPU32[$3 >> 2];
    var $115 = HEAPU32[$113 + 16 >> 2];
    if ($112 >>> 0 < $115 >>> 0 & $112 >>> 0 < $96 >>> 0) {
      var $i2_04 = $112;
      var $105 = $113;
      __label__ = 22;
      break;
    } else {
      var $_lcssa2 = $115;
      var $102 = $113;
      __label__ = 21;
      break;
    }
   case 23:
    var $118;
    var $i3_01;
    var $119 = __ZN2js5types10TypeScript8ArgTypesEP8JSScriptj($118, $i3_01);
    __ZN2js5types4Type13UndefinedTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($119, $cx, $2);
    var $120 = $i3_01 + 1 | 0;
    var $121 = __ZNK10JSFunction6scriptEv($callee_0);
    if (($120 | 0) == ($96 | 0)) {
      __label__ = 24;
      break;
    } else {
      var $i3_01 = $120;
      var $118 = $121;
      __label__ = 23;
      break;
    }
   case 24:
    var $_lcssa = $121;
    var $122 = HEAP32[$3 >> 2];
    __label__ = 25;
    break;
   case 25:
    var $122;
    var $_lcssa;
    var $123 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($_lcssa);
    var $129 = HEAP32[$122 + 24 >> 2];
    if ((HEAP8[$122 + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $131 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($_lcssa);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($131, $cx, $129);
    var $134 = HEAP32[HEAP32[$3 >> 2] + 24 >> 2];
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($123, $cx, $134, 0);
    __label__ = 28;
    break;
   case 27:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($123, $cx, $129);
    __label__ = 28;
    break;
   case 28:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZL25GetValueTypeFromTypeFlagsj($flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags | 0) == 2) {
      __label__ = 2;
      break;
    } else if (($flags | 0) == 4) {
      __label__ = 3;
      break;
    } else if (($flags | 0) == 8) {
      __label__ = 4;
      break;
    } else if (($flags | 0) == 24) {
      __label__ = 5;
      break;
    } else if (($flags | 0) == 32) {
      __label__ = 6;
      break;
    } else if (($flags | 0) == 64) {
      __label__ = 7;
      break;
    } else if (($flags | 0) == 1) {
      var $_0 = 2;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $_0 = 6;
    __label__ = 9;
    break;
   case 3:
    var $_0 = 3;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 8:
    var $_0 = 32;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5types4Type12singleObjectEv($this) {
  return HEAP32[$this >> 2] ^ 1;
}

function __ZNK2js5types7TypeSet13unknownObjectEv($this) {
  return (HEAP32[$this >> 2] & 65664 | 0) != 0;
}

function __ZN2js5types10TypeObject11hasAnyFlagsEj($this, $flags) {
  return (HEAP32[$this + 12 >> 2] & $flags | 0) != 0;
}

function __ZNK2js5types4Type14isSingleObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types4Type8isObjectEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = (HEAP32[$this >> 2] & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($agg_result, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$obj + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 | 1;
    __ZN2js5types4TypeC1Ej($agg_result, $6);
    __label__ = 4;
    break;
   case 3:
    var $8 = $obj;
    __ZN2js5types4TypeC1Ej($agg_result, $8);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  return $3 + ((HEAPU16[$script + 22 >> 1] & 65535) + 1) * 12 | 0;
}

function __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($script) {
  var $2 = HEAP32[$script + 100 >> 2];
  var $3 = __ZN2js5types10TypeScript9typeArrayEv($2);
  return $3 + (HEAPU16[$script + 22 >> 1] & 65535) * 12 | 0;
}

function __ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = HEAP32[$this + 8 >> 2];
    var $14 = HEAP32[$this + 12 >> 2] - HEAP32[$7 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $cx, $7, $14, 0);
    __label__ = 13;
    break;
   case 4:
    var $16 = __ZNK2js5types4Type14isSingleObjectEv($type);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $18 = __ZNK2js5types4Type12singleObjectEv($type);
    var $19 = __ZNK8JSObject10isFunctionEv($18);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $21 = __ZNK8JSObject18getFunctionPrivateEv($18);
    var $22 = __ZNK10JSFunction13isInterpretedEv($21);
    if ($22) {
      var $callee_0 = $21;
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $24 = __ZNK2js5types4Type12isTypeObjectEv($type);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $26 = __ZNK2js5types4Type10typeObjectEv($type);
    var $28 = HEAP32[$26 + 28 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $callee_0 = $28;
      __label__ = 9;
      break;
    }
   case 9:
    var $callee_0;
    var $31 = __ZNK10JSFunction6scriptEv($callee_0);
    var $32 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($31, $cx, $callee_0);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $34 = __ZNK10JSFunction6scriptEv($callee_0);
    var $35 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($34);
    var $37 = HEAP32[$this + 20 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($37, $cx, $35);
    __label__ = 13;
    break;
   case 12:
    var $42 = HEAP32[$this + 16 >> 2];
    HEAP32[$1 >> 2] = $42;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($35, $cx, $1);
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $9 = $this + 12 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = ($10 | 0) == 0;
    var $12 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($11) {
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = __ZNK2js5types7TypeSet7unknownEv($10);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($18, $cx, $1);
    __label__ = 21;
    break;
   case 5:
    var $20 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 0);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $22 = __ZNK2js5types7TypeSet10hasAnyFlagEj($10, 159);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js5types7TypeSet14getObjectCountEv($10);
    if (($24 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($28, $cx, $2);
    __label__ = 21;
    break;
   case 9:
    var $30 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 5);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10StringTypeEv($3);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($33, $cx, $3);
    __label__ = 21;
    break;
   case 11:
    var $35 = __ZNK2js5types7TypeSet10hasAnyFlagEj($10, 143);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $37 = __ZN2js5types7TypeSet14getObjectCountEv($10);
    if (($37 | 0) == 0) {
      var $43 = $10;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type9Int32TypeEv($4);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($41, $cx, $4);
    var $43 = HEAP32[$9 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $43;
    var $44 = __ZNK2js5types7TypeSet10hasAnyFlagEj($43, 16);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $47 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($5);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($47, $cx, $5);
    __label__ = 21;
    break;
   case 16:
    if ($12) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $51 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($6);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($51, $cx, $6);
    __label__ = 21;
    break;
   case 18:
    var $53 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 0);
    var $55 = HEAP32[$this + 8 >> 2];
    if ($53) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    __ZN2js5types4Type10DoubleTypeEv($7);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($55, $cx, $7);
    __label__ = 21;
    break;
   case 20:
    __ZN2js5types4Type9Int32TypeEv($8);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($55, $cx, $8);
    __label__ = 21;
    break;
   case 21:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZNK2js5types7TypeSet10hasAnyFlagEj($this, $flags) {
  var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
  return ($1 & $flags | 0) != 0;
}

function __ZN2js5types4Type10StringTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 5);
  return;
}

function __ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js5types4Type8isObjectEv($type);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAPU32[$this + 8 >> 2];
    if ((HEAP8[$11 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP32[$this + 12 >> 2];
    var $20 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $20;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($18, $cx, $1);
    __label__ = 17;
    break;
   case 6:
    var $23 = __ZNK8JSScript9hasGlobalEv($11);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $25 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 6);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 2);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = HEAP32[$this + 12 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($30, $cx, $2);
    __label__ = 17;
    break;
   case 10:
    var $32 = __ZNK2js5types4Type9primitiveEv($type);
    var $33 = $32 & 255;
    if (($33 | 0) == 1 || ($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else if (($33 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($33 | 0) == 5) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $35 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $11, 8);
    var $object_0 = $35;
    __label__ = 14;
    break;
   case 12:
    var $37 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $11, 4);
    var $object_0 = $37;
    __label__ = 14;
    break;
   case 13:
    var $39 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $11, 9);
    var $object_0 = $39;
    __label__ = 14;
    break;
   case 14:
    var $object_0;
    if (($object_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $45 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($45, $cx);
    __label__ = 17;
    break;
   case 16:
    var $48 = HEAP32[$this + 12 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($3, $object_0);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($48, $cx, $3);
    __label__ = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE["X"] = 1;

function __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($cx, $script, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = __ZNK8JSScript6globalEv($script);
    var $2 = $cx;
    var $3 = $1;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $key, $4, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$proto >> 2];
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($8, $cx, 0, 0);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet9addFreezeEP9JSContext($this, $cx) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = $2 + 344 | 0;
  var $4 = $2 + 400 | 0;
  var $5 = __ZN2js8ArenaNewI20TypeConstraintFreezeP8JSScriptEEPT_R11JSArenaPoolRKT0_($3, $4);
  var $6 = $5 | 0;
  __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $6, 0);
  return;
}

function __ZN2js8ArenaNewI20TypeConstraintFreezeP8JSScriptEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN20TypeConstraintFreezeC1EP8JSScript($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet15getKnownTypeTagEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
    var $2 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($1 | 0) != 0 ? 32 : 7;
    var $type_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZL25GetValueTypeFromTypeFlagsj($1);
    var $type_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $type_0;
    var $11 = ($1 | 0) == 0 ? ($2 | 0) != 0 : 1;
    var $13 = HEAP32[$cx + 56 >> 2];
    var $14 = $13 + 400 | 0;
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($11 & $type_0 << 24 >> 24 == 32) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $13 + 344 | 0;
    var $21 = __ZN2js8ArenaNewI27TypeConstraintFreezeTypeTagP8JSScriptEEPT_R11JSArenaPoolRKT0_($20, $14);
    var $22 = $21 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $22, 0);
    __label__ = 7;
    break;
   case 7:
    return $type_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI27TypeConstraintFreezeTypeTagP8JSScriptEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN27TypeConstraintFreezeTypeTagC1EP8JSScript($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14hasObjectFlagsEP9JSContextj($this, $cx, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZNK2js5types7TypeSet13unknownObjectEv($this);
    if ($2) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js5types7TypeSet14getObjectCountEv($this);
    var $8 = $cx;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $12 = __ZN2js5types7TypeSet13getTypeObjectEj($this, $i_0);
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $object_02 = $12;
      __label__ = 8;
      break;
    }
   case 6:
    var $15 = __ZN2js5types7TypeSet15getSingleObjectEj($this, $i_0);
    if (($15 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $15;
    var $19 = __ZN8JSObject7getTypeEP9JSContext($18, $8);
    var $20 = $19;
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $object_02 = $20;
      __label__ = 8;
      break;
    }
   case 8:
    var $object_02;
    var $22 = __ZN2js5types10TypeObject11hasAnyFlagsEj($object_02, $flags);
    if ($22) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 10:
    var $26 = HEAP32[$cx + 56 >> 2];
    var $27 = $26 + 344 | 0;
    var $28 = $26 + 400 | 0;
    var $29 = __ZN2js8ArenaNewI34TypeConstraintFreezeObjectFlagsSetP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_($27, $28, $1);
    var $30 = $29 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $30, 1);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet13getTypeObjectEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types7TypeSet9getObjectEj($this, $i);
    if (($1 | 0) == 0) {
      var $10 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $1;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet15getSingleObjectEj($this, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types7TypeSet9getObjectEj($this, $i);
    var $2 = $1;
    if (($2 & 1 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $2 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI34TypeConstraintFreezeObjectFlagsSetP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 20 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN34TypeConstraintFreezeObjectFlagsSetC1EP8JSScriptj($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet14HasObjectFlagsEP9JSContextPNS0_10TypeObjectEj($cx, $object, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $flags;
    var $2 = __ZN2js5types10TypeObject11hasAnyFlagsEj($object, $flags);
    if ($2) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($object, $cx, 4, 0);
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$cx + 56 >> 2];
    var $9 = $8 + 344 | 0;
    var $10 = $8 + 400 | 0;
    var $11 = __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_($9, $10, $1);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($4, $cx, $12, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptj($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $1 = $script + 38 | 0;
    var $3 = HEAP8[$1] | 6;
    HEAP8[$1] = $3;
    var $4 = __ZNK8JSScript8functionEv($script);
    var $5 = $4 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $5, 1572864);
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 3:
    var $12 = __ZN8JSScript8analysisEv($script);
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx, 0);
    var $13 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $15 = __ZNK2js10StackFrame13isScriptFrameEv($14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 5:
    var $17 = __ZNK2js10StackFrame6scriptEv($14);
    if (($17 | 0) == ($script | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $20 = $14;
    var $21 = __ZNK2js10StackFrame4baseEv($20);
    var $22 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $23 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($12, $22);
    var $26 = $21 + (HEAP32[$23 + 4 >> 2] << 3) | 0;
    var $27 = __ZNK2js10StackFrame5slotsEv($20);
    if ($27 >>> 0 < $26 >>> 0) {
      var $vp_01 = $27;
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $vp_01;
    var $29 = __ZNK2JS5Value12isMagicCheckE10JSWhyMagic($vp_01, 9);
    if ($29) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $31 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $14, $vp_01);
    if (($31 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JS5Value7setNullEv($vp_01);
    __label__ = 10;
    break;
   case 10:
    var $35 = $vp_01 + 8 | 0;
    if ($35 >>> 0 < $26 >>> 0) {
      var $vp_01 = $35;
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __ZN2js13FrameRegsIterppEv($iter);
    var $38 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 12:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 13;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript["X"] = 1;

function __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($this, $cx, $fun, $scope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($this, $cx, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 100 >> 2];
    var $5 = __ZN2js5types10TypeScript8hasScopeEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $this, $scope);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = __ZN8JSScript11hasAnalysisEv($this);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN8JSScript12makeAnalysisEP9JSContext($this, $cx);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this, $pc) {
  var $7 = $pc - HEAP32[HEAP32[$this >> 2] >> 2] | 0;
  var $8 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $7);
  return $8;
}

function __ZNK2JS5Value12isMagicCheckE10JSWhyMagic($this, $why) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isMagicEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = (HEAP32[$this >> 2] | 0) == ($why | 0);
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet22WatchObjectStateChangeEP9JSContextPNS0_10TypeObjectE($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($obj, $cx, 4, 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$cx + 56 >> 2];
    var $7 = $6 + 344 | 0;
    var $8 = $6 + 400 | 0;
    HEAP32[$1 >> 2] = 0;
    var $9 = __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptiEEPT_R11JSArenaPoolRKT0_RKT1_($7, $8, $1);
    var $10 = $9 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($2, $cx, $10, 1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptiEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptj($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment19addPendingRecompileEP9JSContextP8JSScript($this, $cx, $script) {
  return;
}

function __ZN2jsL3MaxIjEET_S1_S1_1674($t2) {
  var $2 = $t2 >>> 0 < 100 ? 100 : $t2;
  return $2;
}

function __ZNK2js5types7TypeSet13isOwnPropertyEb($this, $configurable) {
  var $3 = $configurable ? 524288 : 262144;
  return (HEAP32[$this >> 2] & $3 | 0) != 0;
}

function __ZNK8JSScript6globalEv($this) {
  return HEAP32[HEAP32[$this + 100 >> 2] + 8 >> 2];
}

function __ZN2js5types7TypeSet13isOwnPropertyEP9JSContextPNS0_10TypeObjectEb($this, $cx, $object, $configurable) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP8[$1] = $configurable & 1;
    var $3 = $object + 12 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if (($4 & 4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$object + 16 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$9 >> 2];
    __ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction($cx, $object, $13);
    __label__ = 5;
    break;
   case 4:
    HEAP32[$3 >> 2] = $4 & -5;
    __label__ = 5;
    break;
   case 5:
    var $17 = __ZNK2js5types7TypeSet13isOwnPropertyEb($this, $configurable);
    if ($17) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$cx + 56 >> 2];
    var $21 = $20 + 344 | 0;
    var $22 = $20 + 400 | 0;
    var $23 = __ZN2js8ArenaNewI31TypeConstraintFreezeOwnPropertyP8JSScriptbEEPT_R11JSArenaPoolRKT0_RKT1_($21, $22, $1);
    var $24 = $23 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $24, 0);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction($cx, $type, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $baseobj = __stackBase__;
    var $initializerList = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $done = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = __ZN2js5types10TypeObject17unknownPropertiesEv($type);
    if ($3) {
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK10JSFunction6scriptEv($fun);
    if ((HEAP8[$5 + 37 | 0] & 32) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 3:
    var $11 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751($cx);
    HEAP32[$baseobj >> 2] = $11;
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP32[$type + 16 >> 2] | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 22;
    break;
   case 6:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_($initializerList, $1);
    var $19 = __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $type, $fun, $baseobj, $initializerList);
    var $20 = HEAP32[$baseobj >> 2];
    if (($20 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZNK8JSObject8slotSpanEv($20);
    if (($23 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$type + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$type + 16 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 21;
    break;
   case 11:
    var $36 = $type + 16 | 0;
    if ((HEAP32[$36 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject($type, $20);
    if ($40) {
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($type, $cx);
    __label__ = 21;
    break;
   case 14:
    var $43 = __ZN2js2gcL15GetGCObjectKindEjb1752($23);
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($done, 3, 0);
    var $44 = HEAP32[$baseobj >> 2];
    var $45 = __ZNK8JSObject9getParentEv($44);
    var $46 = __ZNK8JSObject12lastPropertyEv($44);
    var $47 = $cx;
    var $48 = $type;
    var $49 = $45;
    var $50 = $46;
    var $51 = __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($47, $48, $49, $43, $50);
    var $52 = $51;
    HEAP32[$baseobj >> 2] = $52;
    if (($51 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($type, $cx, $52);
    if ($55) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $57 = $done;
    var $58 = $2;
    var $59$0 = HEAP32[$57 >> 2];
    var $59$1 = HEAP32[$57 + 4 >> 2];
    HEAP32[$58 >> 2] = $59$0;
    HEAP32[$58 + 4 >> 2] = $59$1;
    var $60 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $2);
    if ($60) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($64, $cx);
    __label__ = 21;
    break;
   case 18:
    var $66 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList);
    var $68 = ($66 << 3) + 16 | 0;
    var $69 = __ZN9JSContext7calloc_Ej($cx, $68);
    HEAP32[$36 >> 2] = $69;
    if (($69 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $75 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($75, $cx);
    __label__ = 21;
    break;
   case 20:
    HEAP32[$69 >> 2] = $fun;
    var $79 = HEAP32[$36 >> 2] + 4 | 0;
    HEAP32[$79 >> 2] = $43;
    var $80 = HEAP32[$baseobj >> 2];
    var $81 = __ZNK8JSObject12lastPropertyEv($80);
    var $83 = HEAP32[$36 >> 2] + 8 | 0;
    HEAP32[$83 >> 2] = $81;
    var $84 = HEAP32[$36 >> 2];
    var $86 = $84 + 16 | 0;
    var $87 = $84 + 12 | 0;
    HEAP32[$87 >> 2] = $86;
    var $90 = HEAP32[HEAP32[$36 >> 2] + 12 >> 2];
    var $91 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv($initializerList);
    var $92 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList);
    __ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j($90, $91, $92);
    __label__ = 21;
    break;
   case 21:
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev($initializerList);
    __label__ = 22;
    break;
   case 22:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction["X"] = 1;

function __ZN2js8ArenaNewI31TypeConstraintFreezeOwnPropertyP8JSScriptbEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $29 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $27 = (HEAP8[$b] & 1) << 24 >> 24 != 0;
    __ZN31TypeConstraintFreezeOwnPropertyC1EP8JSScriptb($23, $24, $27);
    var $29 = $23;
    __label__ = 6;
    break;
   case 6:
    var $29;
    return $29;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet13knownNonEmptyEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$cx + 56 >> 2];
    var $9 = $8 + 344 | 0;
    var $10 = $8 + 400 | 0;
    var $11 = __ZN2js8ArenaNewI20TypeConstraintFreezeP8JSScriptEEPT_R11JSArenaPoolRKT0_($9, $10);
    var $12 = $11 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $12, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet17getTypedArrayTypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types7TypeSet14getObjectCountEv($this);
    var $i_0 = 0;
    var $arrayType_0 = 9;
    __label__ = 2;
    break;
   case 2:
    var $arrayType_0;
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 3:
    var $5 = __ZN2js5types7TypeSet15getSingleObjectEj($this, $i_0);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject8getProtoEv($5);
    var $proto_0 = $8;
    __label__ = 7;
    break;
   case 5:
    var $10 = __ZN2js5types7TypeSet13getTypeObjectEj($this, $i_0);
    if (($10 | 0) == 0) {
      var $arrayType_1 = $arrayType_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $proto_0 = HEAP32[$10 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $proto_0;
    if (($proto_0 | 0) == 0) {
      var $arrayType_1 = $arrayType_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = __ZNK8JSObject8getClassEv($proto_0);
    var $21 = ($18 - __ZN2js10TypedArray11slowClassesE | 0) / 232 & -1;
    if (($arrayType_0 | 0) == 9) {
      var $arrayType_1 = $21;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($arrayType_0 | 0) == ($21 | 0)) {
      var $arrayType_1 = $arrayType_0;
      __label__ = 10;
      break;
    } else {
      var $_0 = 9;
      __label__ = 12;
      break;
    }
   case 10:
    var $arrayType_1;
    var $i_0 = $i_0 + 1 | 0;
    var $arrayType_0 = $arrayType_1;
    __label__ = 2;
    break;
   case 11:
    __ZN2js5types7TypeSet9addFreezeEP9JSContext($this, $cx);
    var $_0 = $arrayType_0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet12getSingletonEP9JSContextb($this, $cx, $freeze) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet9baseFlagsEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if (($4 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = __ZN2js5types7TypeSet15getSingleObjectEj($this, 0);
    if (($7 | 0) == 0 | $freeze ^ 1) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP32[$cx + 56 >> 2];
    var $12 = $11 + 344 | 0;
    var $13 = $11 + 400 | 0;
    var $14 = __ZN2js8ArenaNewI20TypeConstraintFreezeP8JSScriptEEPT_R11JSArenaPoolRKT0_($12, $13);
    var $15 = $14 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $15, 0);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet15hasGlobalObjectEP9JSContextP8JSObject($this, $cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $global;
    var $3 = __ZNK2js5types7TypeSet13unknownObjectEv($this);
    if ($3) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js5types7TypeSet14getObjectCountEv($this);
    var $_01 = $2 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = __ZN2js5types7TypeSet9getObjectEj($this, $i_0);
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE($2, $9);
    var $_01_val = HEAP32[$_01 >> 2];
    var $12 = __ZL13TypeHasGlobalN2js5types4TypeEP8JSObject($_01_val, $global);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 7:
    var $17 = HEAP32[$cx + 56 >> 2];
    var $18 = $17 + 344 | 0;
    var $19 = $17 + 400 | 0;
    var $20 = __ZN2js8ArenaNewI26TypeConstraintFreezeGlobalP8JSScriptP8JSObjectEEPT_R11JSArenaPoolRKT0_RKT1_($18, $19, $1);
    var $21 = $20 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($this, $cx, $21, 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13TypeHasGlobalN2js5types4TypeEP8JSObject($type_0, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    HEAP32[$type >> 2] = $type_0;
    var $1 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($1) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($3) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type14isSingleObjectEv($type);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type12singleObjectEv($type);
    var $8 = $7;
    var $9 = __ZNK8JSObject9getGlobalEv($8);
    var $_0 = ($9 | 0) == ($global | 0);
    __label__ = 7;
    break;
   case 5:
    var $13 = __ZNK2js5types4Type12isTypeObjectEv($type);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = __ZNK2js5types4Type10typeObjectEv($type);
    var $16 = __ZN2js5types10TypeObject9getGlobalEv($15);
    var $_0 = ($16 | 0) == ($global | 0);
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI26TypeConstraintFreezeGlobalP8JSScriptP8JSObjectEEPT_R11JSArenaPoolRKT0_RKT1_($pool, $a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $27 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    __ZN26TypeConstraintFreezeGlobalC1EP8JSScriptP8JSObject($23, $24, $25);
    var $27 = $23;
    __label__ = 6;
    break;
   case 6:
    var $27;
    return $27;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObjectC1EP8JSObjectbb($this, $proto, $function, $unknown) {
  __ZN2js5types10TypeObjectC2EP8JSObjectbb($this, $proto, $function, $unknown);
  return;
}

function __ZN2js5types15TypeCompartment4initEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_($this);
    if (($cx | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext13getRunOptionsEv($cx);
    if (($3 & 262144 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$this | 0] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_($t) {
  var $1 = $t | 0;
  _memset($1, 0, 76, 1);
  return;
}

function __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb($this, $cx, $script, $key, $proto, $unknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj($cx, 15, 32);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($key | 0) == 2;
    __ZN2js5types10TypeObjectC1EP8JSObjectbb($1, $proto, $4, $unknown);
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $1 + 12 | 0;
    var $9 = HEAP32[$7 >> 2] | 33488904;
    HEAP32[$7 >> 2] = $9;
    var $_0 = $1;
    __label__ = 5;
    break;
   case 4:
    __ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey($1, $cx, $key);
    var $_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $4 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($3, $kind, $thingSize);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($cx, $kind);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey($this, $cx, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($key | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($key | 0) == 2 || ($key | 0) == 1) {
      var $flags_0 = 458752;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $flags_0 = 262144;
    __label__ = 4;
    break;
   case 3:
    var $flags_0 = 196608;
    __label__ = 4;
    break;
   case 4:
    var $flags_0;
    var $4 = __ZN2js5types10TypeObject11hasAllFlagsEj($this, $flags_0);
    if ($4) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($this, $cx, $flags_0);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE($this, $cx, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $p = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $res = __stackBase__ + 20;
    var $untrap = __stackBase__ + 24;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $1 = $this + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $14 = $2;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($5, 0);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = HEAP32[$1 >> 2];
    __label__ = 6;
    break;
   case 5:
    var $12 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($12, $cx);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 6:
    var $14;
    __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $14, $key);
    var $15 = $key | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = __ZNK8JSScript6globalEv($16);
    var $19 = $key + 4 | 0;
    var $21 = HEAPU32[$19 >> 2] >>> 24;
    var $22 = $cx;
    var $23 = $17;
    var $24 = $proto;
    var $25 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($22, $23, $21, $24, 0);
    if (($25 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAPU32[$19 >> 2] >>> 24;
    var $30 = HEAP32[$proto >> 2];
    var $31 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, $29, $30, 0);
    HEAP32[$res >> 2] = $31;
    if (($31 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $36 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($36, $cx);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 9:
    var $38 = HEAP32[$15 >> 2];
    var $40 = HEAPU32[$38 >> 2];
    var $42 = HEAP32[$19 >> 2] & 16777215;
    var $43 = $40 + $42 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $38, $43);
    if (HEAP8[$43] << 24 >> 24 == 91) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $47 = HEAP32[$15 >> 2];
    var $55 = (HEAPU8[$42 + ($40 + 1) | 0] & 255) << 8 | HEAPU8[$42 + ($40 + 2) | 0] & 255;
    var $56 = __ZN8JSScript9getObjectEj($47, $55);
    var $57 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($31, $cx, $56);
    if ($57) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $59 = HEAP32[$1 >> 2];
    var $60 = __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($59, $p, $key, $res);
    if ($60) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $64 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($64, $cx);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_0 = HEAP32[$res >> 2];
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE["X"] = 1;

function __ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($this);
    if ($1) {
      var $_1 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $3 = __ZNK8JSObject12lastPropertyEv($obj);
    var $shape_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $shape_0;
    var $6 = HEAP32[$shape_0 + 12 >> 2];
    var $7 = _JSID_IS_EMPTY($6);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 4:
    var $10 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $6);
    var $11 = _JSID_IS_VOID1691($10);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $14 = $shape_0 + 24 | 0;
    var $15 = HEAPU32[$14 >> 2];
    var $16 = __ZN8JSObject11isFixedSlotEj($obj, $15);
    if ($16 & $15 >>> 0 < 16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $10, 1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$14 >> 2];
    __ZN2js5types7TypeSet11setDefiniteEj($19, $22);
    __label__ = 8;
    break;
   case 8:
    var $24 = __ZNK2js5Shape8previousEv($shape_0);
    var $shape_0 = $24;
    __label__ = 3;
    break;
   case 9:
    var $_0;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k;
    var $6 = $4;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = $7$0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $7$1;
    var $8 = HEAP32[$v >> 2];
    var $9 = $4 + 8 | 0;
    HEAP32[$9 >> 2] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $pc);
    if (HEAP8[$pc] << 24 >> 24 == 82) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $pc + 3 | 0;
    if (HEAP8[$4] << 24 >> 24 == 54) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($cx, $script, $4);
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $9 = __ZL12id_prototypeP9JSContext($cx_idx_val_idx_val);
    if (($8 | 0) == ($9 | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($cx, $script, $pc) {
  var $1 = _js_GetIndexFromBytecode($cx, $script, $pc, 0);
  var $2 = __ZN8JSScript7getAtomEj($script, $1);
  var $3 = __ZL12ATOM_TO_JSIDP6JSAtom1694($2);
  var $4 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $3);
  return $4;
}

function __ZL12id_prototypeP9JSContext($cx_0_11_val_0_70_14_val) {
  var $1 = $cx_0_11_val_0_70_14_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 48 | 0;
    var $3 = HEAP32[$1 >> 2] << 1;
    var $4 = __ZN2jsL3MaxIjEET_S1_S1_1674($3);
    var $5 = $4 * 12 | 0;
    var $6 = __ZN2js11OffTheBooks7calloc_Ej($5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($11, $cx);
    __label__ = 4;
    break;
   case 3:
    var $13 = $6;
    var $14 = $this + 40 | 0;
    var $16 = HEAP32[$14 >> 2];
    var $19 = HEAP32[$this + 44 >> 2] * 12 | 0;
    _memcpy($6, $16, $19, 1);
    var $21 = HEAP32[$14 >> 2];
    __ZN9JSContext5free_EPv(undef, $21);
    HEAP32[$14 >> 2] = $13;
    HEAP32[$1 >> 2] = $4;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext($this, $cx) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  __ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_(undef, $2);
  return;
}

function __ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment9nukeTypesEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this | 0] = 0;
    var $8 = $cx + 52 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $cl_01 = HEAP32[$9 + 144140 >> 2];
    if (($cl_01 | 0) == ($9 + 144140 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $cl_02 = $cl_01;
      __label__ = 4;
      break;
    }
   case 4:
    var $cl_02;
    var $13 = __ZN9JSContext13fromLinkFieldEP10JSCListStr($cl_02);
    var $16 = $13;
    var $17 = HEAP32[$13 + 56 >> 2];
    __ZN9JSContext14setCompartmentEP13JSCompartment($16, $17);
    var $cl_0 = HEAP32[$cl_02 >> 2];
    if (($cl_0 | 0) == (HEAP32[$8 >> 2] + 144140 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $cl_02 = $cl_0;
      __label__ = 4;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL11ExtendedDefEPh1682($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $pc_val & 255;
    if (($1 | 0) == 85 || ($1 | 0) == 97 || ($1 | 0) == 98 || ($1 | 0) == 99 || ($1 | 0) == 100 || ($1 | 0) == 87 || ($1 | 0) == 132 || ($1 | 0) == 140 || ($1 | 0) == 223 || ($1 | 0) == 101 || ($1 | 0) == 102 || ($1 | 0) == 103 || ($1 | 0) == 104) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN8JSScript11hasAnalysisEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 100 >> 2];
    if (($2 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = (HEAP32[$2 >> 2] | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($this) {
  return (HEAP8[$this + 23 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js5types4TypeeqES1_($this, $o) {
  var __stackBase__ = STACKTOP;
  var tempParam = $o;
  $o = STACKTOP;
  STACKTOP += 4;
  HEAP32[$o >> 2] = HEAP32[tempParam >> 2];
  var $5 = (HEAP32[$this >> 2] | 0) == (HEAP32[$o >> 2] | 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN2js5types15TypeCompartment11compartmentEv($this) {
  return $this - 376 | 0;
}

function __ZNK2js5types4TypeneES1_($this, $o) {
  var __stackBase__ = STACKTOP;
  var tempParam = $o;
  $o = STACKTOP;
  STACKTOP += 4;
  HEAP32[$o >> 2] = HEAP32[tempParam >> 2];
  var $5 = (HEAP32[$this >> 2] | 0) != (HEAP32[$o >> 2] | 0);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $object, $markingUnknown, $force) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($object);
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($object, undef, 4);
    if ($markingUnknown) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $object + 12 | 0;
    var $7 = HEAP32[$5 >> 2] | 33488896;
    HEAP32[$5 >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    if (($3 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $constraint_01 = HEAP32[$3 + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 6;
      break;
    }
   case 6:
    var $constraint_02;
    var $16 = HEAP32[HEAP32[$constraint_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$16]($constraint_02, $cx, $object, $force);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 6;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE($this, $cx, $target) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 148;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $pending = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $i = __stackBase__ + 36;
    var $2 = __stackBase__ + 76;
    var $3 = __stackBase__ + 80;
    var $i3 = __stackBase__ + 84;
    var $4 = __stackBase__ + 124;
    var $5 = __stackBase__ + 128;
    var $untrap = __stackBase__ + 132;
    var $6 = __stackBase__ + 140;
    var $7 = __stackBase__ + 144;
    var $8 = $target + 12 | 0;
    var $10 = HEAP32[$8 >> 2] | 8;
    HEAP32[$8 >> 2] = $10;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_($pending, $1);
    var $11 = $cx + 56 | 0;
    var $12 = HEAP32[$11 >> 2];
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i, undef, $12, 15);
    var $13 = $i | 0;
    var $14 = __ZNK2js2gc12CellIterImpl4doneEv($13);
    if ($14) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js2gc8CellIterD1Ev($i);
    var $15 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($pending);
    if (($15 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i2_09 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $17 = __ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v($13);
    var $18 = __ZN2js5types10TypeObject16getPropertyCountEv($17);
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $i1_013 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i1_013;
    var $20 = __ZN2js5types10TypeObject11getPropertyEj($17, $i1_013);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $20 + 4 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($2, $target);
    var $24 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($23, $2);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($pending, $23);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAP32[$11 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($29, $cx);
    __label__ = 8;
    break;
   case 8:
    var $31 = $i1_013 + 1 | 0;
    if (($31 | 0) == ($18 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i1_013 = $31;
      __label__ = 4;
      break;
    }
   case 9:
    __ZN2js2gc12CellIterImpl4nextEv($13);
    var $32 = __ZNK2js2gc12CellIterImpl4doneEv($13);
    if ($32) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 10:
    var $i2_09;
    var $33 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj($pending, $i2_09);
    var $34 = HEAP32[$33 >> 2];
    __ZN2js5types4Type13AnyObjectTypeEv($3);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($34, $cx, $3);
    var $35 = $i2_09 + 1 | 0;
    var $36 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv($pending);
    if ($35 >>> 0 < $36 >>> 0) {
      var $i2_09 = $35;
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = HEAP32[$11 >> 2];
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i3, undef, $38, 13);
    var $39 = $i3 | 0;
    var $40 = __ZNK2js2gc12CellIterImpl4doneEv($39);
    if ($40) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js2gc8CellIterD1Ev($i3);
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev($pending);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   case 13:
    var $41 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($39);
    var $43 = HEAP32[$41 + 100 >> 2];
    if (($43 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $46 = __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($41);
    var $47 = __ZN2js5types10TypeScript9typeArrayEv($43);
    if (($46 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $i5_01 = 0;
      __label__ = 15;
      break;
    }
   case 15:
    var $i5_01;
    var $49 = $47 + $i5_01 * 12 | 0;
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($4, $target);
    var $50 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($49, $4);
    if ($50) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    __ZN2js5types4Type13AnyObjectTypeEv($5);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($49, $cx, $5);
    __label__ = 17;
    break;
   case 17:
    var $53 = $i5_01 + 1 | 0;
    if (($53 | 0) == ($46 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $i5_01 = $53;
      __label__ = 15;
      break;
    }
   case 18:
    var $54 = __ZN8JSScript11hasAnalysisEv($41);
    if ($54) {
      __label__ = 19;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 19:
    var $56 = __ZN8JSScript8analysisEv($41);
    var $57 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($56);
    if ($57) {
      __label__ = 20;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 20:
    var $58 = $41 + 8 | 0;
    var $59 = HEAP32[$58 >> 2];
    if (($59 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $61 = $41 | 0;
    var $i6_06 = 0;
    var $63 = $59;
    __label__ = 22;
    break;
   case 22:
    var $63;
    var $i6_06;
    var $64 = __ZN8JSScript8analysisEv($41);
    var $65 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($64, $i6_06);
    if (($65 | 0) == 0) {
      var $90 = $63;
      __label__ = 30;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $69 = HEAP32[$61 >> 2] + $i6_06 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $41, $69);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$69] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 24:
    var $77 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($41, $i6_06);
    var $_val = HEAP8[$69];
    var $78 = __ZN2js7analyzeL11ExtendedDefEPh1682($_val);
    var $79 = $78 & 1;
    if (($79 | 0) == (-$77 | 0)) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $81 = $77 + $79 | 0;
    var $j_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $j_03;
    var $83 = __ZN8JSScript8analysisEv($41);
    var $84 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($83, $69, $j_03);
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($6, $target);
    var $85 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($84, $6);
    if ($85) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2js5types4Type13AnyObjectTypeEv($7);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($84, $cx, $7);
    __label__ = 28;
    break;
   case 28:
    var $88 = $j_03 + 1 | 0;
    if (($88 | 0) == ($81 | 0)) {
      __label__ = 29;
      break;
    } else {
      var $j_03 = $88;
      __label__ = 26;
      break;
    }
   case 29:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $90 = HEAP32[$58 >> 2];
    __label__ = 30;
    break;
   case 30:
    var $90;
    var $91 = $i6_06 + 1 | 0;
    if ($91 >>> 0 < $90 >>> 0) {
      var $i6_06 = $91;
      var $63 = $90;
      __label__ = 22;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN2js2gc12CellIterImpl4nextEv($39);
    var $93 = __ZNK2js2gc12CellIterImpl4doneEv($39);
    if ($93) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE["X"] = 1;

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, $cx, $comp, $kind) {
  __ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, undef, $comp, $kind);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc8CellIterD1Ev($this) {
  __ZN2js2gc8CellIterD2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($script) {
  var $3 = HEAPU16[$script + 22 >> 1] & 65535;
  var $4 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script);
  return $3 + $4 | 0;
}

function __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($script, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script >> 2];
    var $3 = $2 + $offset | 0;
    var $5 = HEAPU8[$3] & 255;
    var $7 = HEAPU8[_js_CodeSpec + ($5 << 3) + 2 | 0];
    var $8 = $7 << 24 >> 24;
    if ($7 << 24 >> 24 == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = _js_GetEnterBlockStackDefs(0, $script, $3);
    var $_0 = $11;
    __label__ = 7;
    break;
   case 3:
    if (($5 | 0) == 176) {
      __label__ = 4;
      break;
    } else if (($5 | 0) == 133) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 68 || ($5 | 0) == 144 || ($5 | 0) == 69 || ($5 | 0) == 145) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 5:
    var $_0 = (HEAPU8[$offset + ($2 + 1) | 0] & 255) + 1 | 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $8;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($this, $pc, $which) {
  var $7 = $pc - HEAP32[HEAP32[$this >> 2] >> 2] | 0;
  var $8 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $7, $which);
  return $8;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this, $cx, $pc, $target, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $target;
    var $6 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this, $pc);
    var $7 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js5types4Type8isObjectEv($type);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = __ZN2js5types7TypeSet14getObjectCountEv($target);
    if ($13 >>> 0 > 9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = HEAP32[$type >> 2];
    HEAP32[$2 >> 2] = $17;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($target, $cx, $2);
    __label__ = 17;
    break;
   case 6:
    var $20 = $6 + 40 | 0;
    if ((HEAP32[$20 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $25 = HEAP32[$this >> 2];
    if ((HEAP8[$25 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = __ZNK8JSScript8functionEv($25);
    var $32 = $31 | 0;
    var $33 = __ZNK8JSObject11hasLazyTypeEv($32);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = __ZNK8JSObject4typeEv($32);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $35, 0, 1);
    __label__ = 10;
    break;
   case 10:
    var $37 = HEAP32[$type >> 2];
    var $38 = $3 | 0;
    var $barrier_0_in = $20;
    __label__ = 11;
    break;
   case 11:
    var $barrier_0_in;
    var $barrier_0 = HEAP32[$barrier_0_in >> 2];
    if (($barrier_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$barrier_0 + 4 >> 2] | 0) == ($target | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $46 = $barrier_0 + 8 | 0;
    HEAP32[$38 >> 2] = $37;
    var $47 = __ZNK2js5types4TypeeqES1_($46, $3);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if ((HEAP32[$barrier_0 + 12 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $barrier_0_in = $barrier_0 | 0;
    __label__ = 11;
    break;
   case 16:
    var $57 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$4 >> 2] = 0;
    HEAP32[$5 >> 2] = 2;
    var $58 = __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($57, $1, $type, $4, $5);
    var $59 = HEAP32[$20 >> 2];
    var $60 = $58 | 0;
    HEAP32[$60 >> 2] = $59;
    HEAP32[$20 >> 2] = $58;
    __label__ = 17;
    break;
   case 17:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE["X"] = 1;

function __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($pool, $a, $b, $c, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + 20 & ($5 ^ -1);
    var $9 = $3 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$3 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $_p_0;
    var $25 = HEAP32[$a >> 2];
    var $27 = HEAP32[$b >> 2];
    HEAP32[$1 >> 2] = $27;
    var $29 = HEAP32[$c >> 2];
    var $30 = HEAP32[$d >> 2];
    __ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($24, $25, $1, $29, $30);
    var $32 = $24;
    __label__ = 6;
    break;
   case 6:
    var $32;
    STACKTOP = __stackBase__;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti($this, $cx, $pc, $target, $singleton, $singletonId) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $target;
    HEAP32[$2 >> 2] = $singleton;
    HEAP32[$3 >> 2] = $singletonId;
    var $5 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this, $pc);
    var $6 = $5 + 40 | 0;
    if ((HEAP32[$6 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = HEAP32[$this >> 2];
    if ((HEAP8[$11 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = __ZNK8JSScript8functionEv($11);
    var $18 = $17 | 0;
    var $19 = __ZNK8JSObject11hasLazyTypeEv($18);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = __ZNK8JSObject4typeEv($18);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $21, 0, 1);
    __label__ = 5;
    break;
   case 5:
    var $25 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    __ZN2js5types4Type13UndefinedTypeEv($4);
    var $26 = __ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_($25, $1, $4, $2, $3);
    var $27 = HEAP32[$6 >> 2];
    var $28 = $26 | 0;
    HEAP32[$28 >> 2] = $27;
    HEAP32[$6 >> 2] = $26;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InferSpewActiveN2js5types11SpewChannelE() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b]) {
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b] = 1;
    __ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_();
    var $2 = _getenv(STRING_TABLE.__str741644 | 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = _strstr($2, STRING_TABLE.__str751645 | 0);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active | 0] = 1;
    __label__ = 5;
    break;
   case 5:
    var $9 = _strstr($2, STRING_TABLE.__str761646 | 0);
    if (($9 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active + 1 | 0] = 1;
    __label__ = 7;
    break;
   case 7:
    var $13 = _strstr($2, STRING_TABLE.__str771647 | 0);
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active >> 1] = 257;
    __label__ = 9;
    break;
   case 9:
    var $_0 = (HEAP8[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active + 1 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $untrap = __stackBase__ + 8;
    __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($enter, $cx);
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if ((HEAP32[$2 + 8 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $4 + 448 | 0;
    var $offset_06 = 0;
    var $10 = $2;
    __label__ = 3;
    break;
   case 3:
    var $10;
    var $offset_06;
    var $11 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $offset_06);
    if (($11 | 0) == 0) {
      var $67 = $10;
      __label__ = 17;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$10 >> 2] + $offset_06 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $10, $16);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$16] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $24 = HEAP32[$1 >> 2];
    var $25 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($24, $offset_06);
    if (($25 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_05;
    var $27 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $offset_06, $i_05);
    var $28 = __ZNK2js5types7TypeSet7unknownEv($27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $31 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $31;
    __label__ = 15;
    break;
   case 8:
    var $33 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 128);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = __ZN2js5types7TypeSet14getObjectCountEv($27);
    if (($35 | 0) == 0) {
      var $typeCount_1_ph = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $typeCount_1_ph = 1;
    __label__ = 11;
    break;
   case 11:
    var $typeCount_1_ph;
    var $38 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 1);
    var $_typeCount_1 = ($38 & 1) + $typeCount_1_ph | 0;
    var $40 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 2);
    var $_typeCount_1_1 = ($40 & 1) + $_typeCount_1 | 0;
    var $42 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 4);
    var $_typeCount_1_2 = ($42 & 1) + $_typeCount_1_1 | 0;
    var $44 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 8);
    var $_typeCount_1_3 = ($44 & 1) + $_typeCount_1_2 | 0;
    var $46 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 16);
    var $_typeCount_1_4 = ($46 & 1) + $_typeCount_1_3 | 0;
    var $48 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 32);
    var $_typeCount_1_5 = ($48 & 1) + $_typeCount_1_4 | 0;
    var $50 = __ZNK2js5types7TypeSet10hasAnyFlagEj($27, 64);
    var $_typeCount_11 = ($46 << 31 >> 31) + (($50 & 1) + $_typeCount_1_5) | 0;
    if ($_typeCount_11 >>> 0 > 4) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $56 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $56;
    __label__ = 15;
    break;
   case 13:
    if (($_typeCount_11 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $61 = $4 + 432 + ($_typeCount_11 - 1 << 2) | 0;
    var $63 = HEAP32[$61 >> 2] + 1 | 0;
    HEAP32[$61 >> 2] = $63;
    __label__ = 15;
    break;
   case 15:
    var $65 = $i_05 + 1 | 0;
    if (($65 | 0) == ($25 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $i_05 = $65;
      __label__ = 6;
      break;
    }
   case 16:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $67 = HEAP32[$1 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $67;
    var $68 = $offset_06 + 1 | 0;
    if ($68 >>> 0 < HEAPU32[$67 + 8 >> 2] >>> 0) {
      var $offset_06 = $68;
      var $10 = $67;
      __label__ = 3;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2js7analyze17AutoEnterAnalysisD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext["X"] = 1;

function __ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $type = __stackBase__ + 8;
    var $ntype = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $key = __stackBase__ + 20;
    var $p = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $objType = __stackBase__ + 44;
    var $3 = __stackBase__ + 48;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $4 = $this + 32 | 0;
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = __ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$4 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($8, 0);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$4 >> 2] = 0;
    var $15 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($15, $cx);
    __label__ = 20;
    break;
   case 5:
    var $17 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj);
    if (($17 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN8JSObject20getDenseArrayElementEj($obj, 0);
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($type, $20);
    var $21 = $type | 0;
    var $22 = $1 | 0;
    var $23 = $ntype | 0;
    var $i_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $17 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $27 = __ZN8JSObject20getDenseArrayElementEj($obj, $i_0);
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($ntype, $27);
    var $28 = HEAPU32[$21 >> 2];
    HEAP32[$22 >> 2] = $28;
    var $29 = __ZNK2js5types4TypeneES1_($ntype, $1);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $31 = HEAP32[$23 >> 2];
    var $32 = __ZL11NumberTypesN2js5types4TypeES1_($28, $31);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 10:
    __ZN2js5types4Type10DoubleTypeEv($type);
    __label__ = 11;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    __ZN2js5types13ArrayTableKeyC1Ev($key);
    var $37 = HEAPU32[$21 >> 2];
    HEAP32[$key >> 2] = $37;
    var $39 = __ZNK8JSObject8getProtoEv($obj);
    HEAP32[$key + 4 >> 2] = $39;
    var $41 = HEAP32[$4 >> 2];
    __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($p, $41, $key);
    var $42 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $42);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $47 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($42);
    var $49 = HEAP32[$47 + 8 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj, $49);
    __label__ = 20;
    break;
   case 14:
    var $51 = __ZNK8JSObject8getProtoEv($obj);
    var $52 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, 3, $51, 0);
    HEAP32[$objType >> 2] = $52;
    if (($52 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $57 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($57, $cx);
    __label__ = 20;
    break;
   case 16:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj, $52);
    var $59 = __ZN2js5types10TypeObject17unknownPropertiesEv($52);
    if ($59) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$3 >> 2] = $37;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($52, $cx, 2, $3);
    __label__ = 18;
    break;
   case 18:
    var $63 = HEAP32[$4 >> 2];
    var $64 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($63, $p, $key, $objType);
    if ($64) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $68 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($68, $cx);
    __label__ = 20;
    break;
   case 20:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject["X"] = 1;

function __ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($agg_result, $v) {
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($agg_result, undef, $v);
  return;
}

function _JSID_IS_EMPTY($iden) {
  return ($iden | 0) == 4 & 1;
}

function _JSID_IS_VOID1691($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js5types7TypeSet21setPropagatedPropertyEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 131072;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5types7TypeSet11setDefiniteEj($this, $slot) {
  var $2 = $this | 0;
  var $5 = $slot << 24 | HEAP32[$2 >> 2] | 1048576;
  HEAP32[$2 >> 2] = $5;
  return;
}

function __ZL11NumberTypesN2js5types4TypeES1_($a_0, $b_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    HEAP32[$b >> 2] = $b_0;
    var $a = STACKTOP;
    STACKTOP += 4;
    HEAP32[$a >> 2] = $a_0;
    var $1 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($a, 1);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($a, 0);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $9 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($b, 1);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($b, 0);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13ArrayTableKeyC1Ev($this) {
  __ZN2js5types13ArrayTableKeyC2Ev($this);
  return;
}

function __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 134,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($this, $cx, $id, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $3 = HEAP32[$type >> 2];
  HEAP32[$1 >> 2] = $3;
  __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_($1, $k, $v);
  var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_($2, $p, $k, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $enter = __stackBase__ + 4;
    var $p = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $ntype = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $4 = __stackBase__ + 36;
    var $type = __stackBase__ + 40;
    var $5 = __stackBase__ + 44;
    var $6 = __stackBase__ + 48;
    var $7 = __stackBase__ + 52;
    var $key = __stackBase__ + 56;
    var $entry = __stackBase__ + 72;
    HEAP32[$1 >> 2] = $obj;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $8 = $this + 36 | 0;
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $12 = __ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v($cx);
    HEAP32[$8 >> 2] = $12;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj($12, 0);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$8 >> 2] = 0;
    var $19 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($19, $cx);
    __label__ = 36;
    break;
   case 5:
    var $21 = __ZNK8JSObject8slotSpanEv($obj);
    if (($21 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = __ZNK8JSObject16inDictionaryModeEv($obj);
    if ($24) {
      __label__ = 36;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$8 >> 2];
    __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($p, $26, $1);
    var $27 = HEAPU32[$1 >> 2];
    var $28 = __ZNK8JSObject12lastPropertyEv($27);
    var $29 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($2, $29);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($29);
    var $36 = HEAP32[$34 + 20 >> 2];
    var $37 = $3 | 0;
    var $38 = $ntype | 0;
    var $39 = $4 | 0;
    var $40 = $type | 0;
    var $41 = $5 | 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    var $43 = __ZNK8JSObject8slotSpanEv($27);
    if ($i_0 >>> 0 < $43 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 10:
    var $46 = __ZNK8JSObject7getSlotEj($27, $i_0);
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($ntype, $46);
    var $47 = $36 + ($i_0 << 2) | 0;
    var $48 = $47 | 0;
    var $49 = HEAP32[$48 >> 2];
    HEAP32[$37 >> 2] = $49;
    var $50 = __ZNK2js5types4TypeneES1_($ntype, $3);
    if ($50) {
      __label__ = 11;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 11:
    var $52 = HEAP32[$38 >> 2];
    var $53 = __ZL11NumberTypesN2js5types4TypeES1_($52, $49);
    if ($53) {
      __label__ = 12;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 12:
    var $55 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($47, 1);
    if ($55) {
      __label__ = 13;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 13:
    __ZN2js5types4Type10DoubleTypeEv($4);
    var $57 = HEAP32[$39 >> 2];
    HEAP32[$48 >> 2] = $57;
    var $shape_0 = $28;
    __label__ = 14;
    break;
   case 14:
    var $shape_0;
    var $59 = $shape_0 + 12 | 0;
    var $60 = HEAP32[$59 >> 2];
    var $61 = _JSID_IS_EMPTY($60);
    if (($61 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    if ((HEAP32[$shape_0 + 24 >> 2] | 0) == ($i_0 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    __ZN2js5types4Type10DoubleTypeEv($type);
    var $68 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($29);
    var $70 = HEAP32[$68 + 16 >> 2];
    var $71 = __ZN2js5types10TypeObject17unknownPropertiesEv($70);
    if ($71) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $73 = HEAP32[$59 >> 2];
    var $74 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $73);
    var $75 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($29);
    var $77 = HEAP32[$75 + 16 >> 2];
    var $78 = HEAP32[$40 >> 2];
    HEAP32[$41 >> 2] = $78;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($77, $cx, $74, $5);
    __label__ = 19;
    break;
   case 18:
    var $80 = __ZNK2js5Shape8previousEv($shape_0);
    var $shape_0 = $80;
    __label__ = 14;
    break;
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 20:
    var $83 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($29);
    var $85 = HEAP32[$83 + 16 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($27, $85);
    __label__ = 36;
    break;
   case 21:
    var $87 = __ZNK8JSObject8getProtoEv($27);
    var $88 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, 1, $87, 0);
    if (($88 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $91 = __ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject($88, $cx, $27);
    if ($91) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $95 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($95, $cx);
    __label__ = 36;
    break;
   case 24:
    var $97 = __ZNK8JSObject8slotSpanEv($27);
    var $98 = $97 << 2;
    var $99 = __ZN9JSContext7calloc_Ej($cx, $98);
    var $100 = $99;
    if (($99 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $105 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($105, $cx);
    __label__ = 36;
    break;
   case 26:
    var $107 = __ZNK8JSObject8slotSpanEv($27);
    var $108 = $107 << 2;
    var $109 = __ZN9JSContext7calloc_Ej($cx, $108);
    var $110 = $109;
    if (($109 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $112 = $28 + 12 | 0;
    var $113 = HEAP32[$112 >> 2];
    var $114 = _JSID_IS_EMPTY($113);
    if (($114 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 28:
    var $116 = $6 | 0;
    var $117 = $7 | 0;
    var $shape2_04 = $28;
    var $124 = $112;
    var $123 = $113;
    __label__ = 30;
    break;
   case 29:
    var $121 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($121, $cx);
    __label__ = 36;
    break;
   case 30:
    var $123;
    var $124;
    var $shape2_04;
    var $125 = $shape2_04 + 24 | 0;
    var $127 = $100 + (HEAP32[$125 >> 2] << 2) | 0;
    HEAP32[$127 >> 2] = $123;
    var $128 = HEAP32[$125 >> 2];
    var $129 = __ZNK8JSObject7getSlotEj($27, $128);
    __ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE($6, $129);
    var $130 = HEAP32[$116 >> 2];
    var $131 = $110 + ($128 << 2) | 0;
    HEAP32[$131 >> 2] = $130;
    var $132 = __ZN2js5types10TypeObject17unknownPropertiesEv($88);
    if ($132) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $134 = HEAP32[$124 >> 2];
    var $135 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $134);
    var $138 = HEAP32[$110 + (HEAP32[$125 >> 2] << 2) >> 2];
    HEAP32[$117 >> 2] = $138;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE($88, $cx, $135, $7);
    __label__ = 32;
    break;
   case 32:
    var $140 = __ZNK2js5Shape8previousEv($shape2_04);
    var $141 = $140 + 12 | 0;
    var $142 = HEAP32[$141 >> 2];
    var $143 = _JSID_IS_EMPTY($142);
    if (($143 | 0) == 0) {
      var $shape2_04 = $140;
      var $124 = $141;
      var $123 = $142;
      __label__ = 30;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    HEAP32[$key >> 2] = $100;
    var $146 = __ZNK8JSObject8slotSpanEv($27);
    HEAP32[$key + 4 >> 2] = $146;
    var $148 = __ZNK8JSObject13numFixedSlotsEv($27);
    HEAP32[$key + 8 >> 2] = $148;
    var $150 = __ZNK8JSObject8getProtoEv($27);
    HEAP32[$key + 12 >> 2] = $150;
    HEAP32[$entry >> 2] = $88;
    HEAP32[$entry + 4 >> 2] = $110;
    var $154 = HEAP32[$8 >> 2];
    __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($p, $154, $1);
    var $155 = HEAP32[$8 >> 2];
    var $156 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_($155, $p, $key, $entry);
    if ($156) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $160 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($160, $cx);
    __label__ = 36;
    break;
   case 35:
    var $162 = HEAP32[$1 >> 2];
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($162, $88);
    __label__ = 36;
    break;
   case 36:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject["X"] = 1;

function __ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1, $len);
  return $2;
}

function __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 136,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $4;
    var $6 = $k;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $8 = $v;
    var $9 = $4 + 16 | 0;
    var $10$0 = HEAP32[$8 >> 2];
    var $10$1 = HEAP32[$8 + 4 >> 2];
    var $st$11$0 = $9 | 0;
    HEAP32[$st$11$0 >> 2] = $10$0;
    var $st$11$1 = $9 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE($this, $cx, $id, $pprop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $id;
    var $2 = $cx + 56 | 0;
    var $4 = HEAP32[$2 >> 2] + 344 | 0;
    var $5 = __ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_($4, $1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[$2 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($9, $cx);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $11 = $this + 4 | 0;
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$1 >> 2];
    var $16 = _JSID_IS_VOID1691($15);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZNK8JSObject12lastPropertyEv($12);
    var $21 = HEAP32[$19 + 12 >> 2];
    var $22 = _JSID_IS_EMPTY($21);
    if (($22 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $24 = $5 + 4 | 0;
    var $shape_01 = $19;
    var $26 = $21;
    __label__ = 7;
    break;
   case 7:
    var $26;
    var $shape_01;
    var $27 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $26);
    var $28 = _JSID_IS_VOID1691($27);
    if (($28 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$11 >> 2];
    __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $24, $31, $shape_01, 1);
    __label__ = 9;
    break;
   case 9:
    var $33 = __ZNK2js5Shape8previousEv($shape_01);
    var $35 = HEAP32[$33 + 12 >> 2];
    var $36 = _JSID_IS_EMPTY($35);
    if (($36 | 0) == 0) {
      var $shape_01 = $33;
      var $26 = $35;
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $39 = __ZN8JSObject12nativeLookupEP9JSContexti($12, $cx, $15);
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $5 + 4 | 0;
    var $43 = HEAP32[$11 >> 2];
    __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $42, $43, $39, 0);
    __label__ = 12;
    break;
   case 12:
    HEAP32[$pprop >> 2] = $5;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE["X"] = 1;

function __ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN2js5types8PropertyC1Ei($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb($cx, $types, $obj, $shape, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __ZNK2js5Shape14hasGetterValueEv($shape);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js5Shape14hasSetterValueEv($shape);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $1);
    __label__ = 9;
    break;
   case 4:
    var $8 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($shape);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$shape + 24 >> 2];
    if (($11 | 0) == -1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZNK8JSObject13nativeGetSlotEj($obj, $11);
    if ($force) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2JS5Value11isUndefinedEv($14);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($2, undef, $14);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($types, $cx, $2);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11isFixedSlotEj($this, $slot) {
  var $1 = __ZNK8JSObject13numFixedSlotsEv($this);
  return $1 >>> 0 > $slot >>> 0;
}

function __ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 3:
    var $5 = __ZN2js5types10TypeObject11getPropertyEj($this, $i_0);
    if (($5 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $5 + 4 | 0;
    var $9 = __ZNK2js5types7TypeSet18isDefinitePropertyEv($8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $11 = __ZNK2js5types7TypeSet12definiteSlotEv($8);
    var $12 = __ZNK8JSObject12lastPropertyEv($obj);
    var $13 = $5 | 0;
    var $shape_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $shape_0;
    var $16 = HEAP32[$shape_0 + 12 >> 2];
    var $17 = _JSID_IS_EMPTY($16);
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP32[$shape_0 + 24 >> 2] | 0) == ($11 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if (($16 | 0) == (HEAP32[$13 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZNK2js5Shape8previousEv($shape_0);
    var $shape_0 = $27;
    __label__ = 6;
    break;
   case 10:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $obj, $id, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $3 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($obj, $cx, $id, 1);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $7;
    var $9 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($3, $1);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$2 >> 2] = $7;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($3, $cx, $2);
    __label__ = 4;
    break;
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE($this, $cx, $id, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $value);
  __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($this, $cx, $name, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    if (($name | 0) == 0) {
      var $id_0 = 2;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strlen($name);
    var $5 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($cx, $name, $4, 0, 0);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $10 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($10, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 6;
    break;
   case 4:
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom1694($5);
    var $id_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $id_0;
    var $15 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $15;
    __Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE($cx, $this, $id_0, $1);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom1694($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1765($1);
  return $2;
}

function __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE($this, $cx, $name, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $value);
  __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($this, $cx, $name, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti($this, $cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $1 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $id);
    var $2 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($this, $cx, $1, 1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($2, $cx, 1);
    __label__ = 3;
    break;
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject15markStateChangeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN2js5types10TypeObject17unknownPropertiesEv($this);
    if ($1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $3 = __ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti($this, undef, 4);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $constraint_01 = HEAP32[$3 + 8 >> 2];
    if (($constraint_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $constraint_02 = $constraint_01;
      __label__ = 4;
      break;
    }
   case 4:
    var $constraint_02;
    var $11 = HEAP32[HEAP32[$constraint_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$11]($constraint_02, $cx, $this, 1);
    var $constraint_0 = HEAP32[$constraint_02 + 4 >> 2];
    if (($constraint_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $constraint_02 = $constraint_0;
      __label__ = 4;
      break;
    }
   case 5:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject8setFlagsEP9JSContextj($this, $cx, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = $this + 12 | 0;
    if ((HEAP32[$1 >> 2] & $flags | 0) == ($flags | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $7 = HEAP32[$1 >> 2] | $flags;
    HEAP32[$1 >> 2] = $7;
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $this, 0, 0);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject11markUnknownEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    if ((HEAP32[$this + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($this, $cx);
    __label__ = 3;
    break;
   case 3:
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $this, 1, 1);
    var $8 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_01;
    var $10 = __ZN2js5types10TypeObject11getPropertyEj($this, $i_01);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10 + 4 | 0;
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($13, $cx, $1);
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($13, $cx, 1);
    __label__ = 6;
    break;
   case 6:
    var $15 = $i_01 + 1 | 0;
    if (($15 | 0) == ($8 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $i_01 = $15;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL7ArgSlotEj1706($arg) {
  return $arg + 2 | 0;
}

function __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($this) {
  return (HEAP8[$this + 24 | 0] & 64) << 24 >> 24 != 0;
}

function __ZN2jsL20CallObjectLambdaNameEP10JSFunction1708($fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP16[$fun + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$fun + 72 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $iter = __stackBase__ + 8;
    var $1 = $this + 12 | 0;
    var $3 = HEAP32[$1 >> 2] | 2;
    HEAP32[$1 >> 2] = $3;
    var $4 = $this + 16 | 0;
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $8 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    if (($8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $i_05 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_05;
    var $10 = __ZN2js5types10TypeObject11getPropertyEj($this, $i_05);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10 + 4 | 0;
    var $14 = __ZNK2js5types7TypeSet18isDefinitePropertyEv($13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb($13, $cx, 1);
    __label__ = 6;
    break;
   case 6:
    var $17 = $i_05 + 1 | 0;
    var $18 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    if ($17 >>> 0 < $18 >>> 0) {
      var $i_05 = $17;
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $cx, 0);
    var $20 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($20) {
      __label__ = 31;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = $cx + 60 | 0;
    var $22 = $21;
    __label__ = 9;
    break;
   case 9:
    var $24 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $25 = __ZNK2js10StackFrame13isScriptFrameEv($24);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 10:
    var $27 = __ZNK2js10StackFrame14isConstructingEv($24);
    if ($27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 11:
    var $29 = __ZNK2js10StackFrame3funEv($24);
    var $30 = HEAPU32[$4 >> 2];
    if (($29 | 0) == (HEAP32[$30 >> 2] | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 12:
    var $35 = __ZNK2js10StackFrame9thisValueEv($24);
    var $36 = __ZNK2JS5Value8isObjectEv($35);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 13:
    var $38 = __ZNK2JS5Value8toObjectEv($35);
    var $39 = __ZNK8JSObject11hasLazyTypeEv($38);
    if ($39) {
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = __ZNK8JSObject4typeEv($38);
    if (($41 | 0) == ($this | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 15:
    var $44 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $init_0 = HEAP32[$30 + 12 >> 2];
    var $depth_0 = 0;
    var $numProperties_0 = 0;
    var $fp_0 = $24;
    var $pc_0 = $44;
    __label__ = 16;
    break;
   case 16:
    var $pc_0;
    var $fp_0;
    var $numProperties_0;
    var $depth_0;
    var $init_0;
    var $48 = __ZNK2js10StackFrame6scriptEv($fp_0);
    var $53 = $pc_0 - HEAP32[$48 >> 2] | 0;
    var $55 = HEAP32[$init_0 >> 2];
    if (($55 | 0) == 0) {
      __label__ = 17;
      break;
    } else if (($55 | 0) == 1) {
      __label__ = 20;
      break;
    } else if (($55 | 0) == 2) {
      __label__ = 26;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 17:
    if (($depth_0 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    if (HEAPU32[$init_0 + 4 >> 2] >>> 0 > $53 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $depth_1 = $depth_0;
    var $numProperties_1 = $numProperties_0 + 1 | 0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 28;
    break;
   case 20:
    if (($depth_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $depth_1 = $depth_0 + 1 | 0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 28;
    break;
   case 22:
    var $70 = HEAPU32[$init_0 + 4 >> 2];
    if ($70 >>> 0 > $53 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if (($70 | 0) == ($53 | 0)) {
      __label__ = 24;
      break;
    } else {
      var $depth_1 = 1;
      var $numProperties_1 = $numProperties_0;
      var $fp_1 = $fp_0;
      var $pc_1 = $pc_0;
      __label__ = 28;
      break;
    }
   case 24:
    var $75 = __ZNK2js12ContextStack5spaceEv($21);
    var $76 = $75;
    var $77 = $fp_0;
    var $78 = __ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE($76, $77);
    var $79 = __ZNK2js12StackSegment7maybefpEv($78);
    if (($79 | 0) == ($fp_0 | 0)) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $83 = __ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE($78, $77);
    var $84 = $83;
    var $85 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($83, $22, 0, 0);
    var $depth_1 = $depth_0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $84;
    var $pc_1 = $85;
    __label__ = 28;
    break;
   case 26:
    if (($depth_0 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $depth_1 = $depth_0 - 1 | 0;
    var $numProperties_1 = $numProperties_0;
    var $fp_1 = $fp_0;
    var $pc_1 = $pc_0;
    __label__ = 28;
    break;
   case 28:
    var $pc_1;
    var $fp_1;
    var $numProperties_1;
    var $depth_1;
    var $init_0 = $init_0 + 8 | 0;
    var $depth_0 = $depth_1;
    var $numProperties_0 = $numProperties_1;
    var $fp_0 = $fp_1;
    var $pc_0 = $pc_1;
    __label__ = 16;
    break;
   case 29:
    __ZN8JSObject18rollbackPropertiesEP9JSContextj($38, $cx, $numProperties_0);
    __label__ = 30;
    break;
   case 30:
    var $92 = __ZN2js13FrameRegsIterppEv($iter);
    var $93 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($93) {
      __label__ = 31;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 31:
    var $95 = HEAP32[$4 >> 2];
    __ZN9JSContext5free_EPv(undef, $95);
    HEAP32[$4 >> 2] = 0;
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($this, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 32;
    break;
   case 32:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject14clearNewScriptEP9JSContext["X"] = 1;

function __ZN2js5types10TypeObject5printEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$this >> 2];
    if (($3 | 0) == 0) {
      var $7 = STRING_TABLE.__ZN2js6Probes8nullNameE | 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types4Type10ObjectTypeEP8JSObject($1, $3);
    var $7 = 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = _printf(STRING_TABLE.__str311601 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = 0, HEAP32[tempInt + 4 >> 2] = $7, tempInt));
    var $9 = __ZN2js5types10TypeObject17unknownPropertiesEv($this);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = _printf(STRING_TABLE.__str71575 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 17;
    break;
   case 5:
    var $13 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 131072);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = _printf(STRING_TABLE.__str331603 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 7:
    var $17 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 65536);
    if ($17) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = _printf(STRING_TABLE.__str341604 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 9;
    break;
   case 9:
    var $21 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 262144);
    if ($21) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = _printf(STRING_TABLE.__str351605 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 11;
    break;
   case 11:
    var $25 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 1048576);
    if ($25) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $27 = _printf(STRING_TABLE.__str361606 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 13;
    break;
   case 13:
    var $29 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 2097152);
    if ($29) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $31 = _printf(STRING_TABLE.__str371607 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 15;
    break;
   case 15:
    var $33 = __ZN2js5types10TypeObject11hasAnyFlagsEj($this, 4194304);
    if ($33) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $35 = _printf(STRING_TABLE.__str381608 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 17;
    break;
   case 17:
    var $37 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    if (($37 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $puts = _puts(STRING_TABLE._str | 0);
    __label__ = 24;
    break;
   case 19:
    var $40 = _printf(STRING_TABLE.__str401610 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $i_02 = 0;
    __label__ = 20;
    break;
   case 20:
    var $i_02;
    var $42 = __ZN2js5types10TypeObject11getPropertyEj($this, $i_02);
    if (($42 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $45 = _printf(STRING_TABLE.__str411611 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str781648 | 0, tempInt));
    var $46 = $42 + 4 | 0;
    __ZN2js5types7TypeSet5printEP9JSContext($46, undef);
    __label__ = 22;
    break;
   case 22:
    var $48 = $i_02 + 1 | 0;
    if (($48 | 0) == ($37 | 0)) {
      __label__ = 23;
      break;
    } else {
      var $i_02 = $48;
      __label__ = 20;
      break;
    }
   case 23:
    var $puts1 = _puts(STRING_TABLE._str1 | 0);
    __label__ = 24;
    break;
   case 24:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject5printEP9JSContext["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($agg_result, $this, $cx, $id, $addDependency) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_($agg_result);
    var $1 = __ZL12JSID_IS_ATOMi1703($id);
    if (($1 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12JSID_TO_ATOMi1704($id);
    var $6 = $cx;
    var $script_0 = HEAP32[$this >> 2];
    __label__ = 3;
    break;
   case 3:
    var $script_0;
    if ((HEAP8[$script_0 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $script_0;
    var $14 = __ZNK8JSScript7nestingEv($13);
    if (($14 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script_0, $cx);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 6:
    var $19 = __ZN8JSScript8analysisEv($script_0);
    var $20 = __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($19);
    if ($20) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$script_0 >> 2];
    var $24 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($script_0, $23);
    if (($24 | 0) == 205) {
      __label__ = 18;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($script_0 + 64 | 0, $6, $4, $index);
    if (($29 - 1 | 0) >>> 0 < 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    var $32 = ($29 | 0) == 1;
    var $33 = __ZNK8JSScript8functionEv($script_0);
    var $34 = $33;
    var $35 = $cx;
    var $36 = __ZN8JSObject7getTypeEP9JSContext($34, $35);
    if ($addDependency) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = $36;
    var $39 = __ZN2js5types7TypeSet14HasObjectFlagsEP9JSContextPNS0_10TypeObjectEj($cx, $38, 8388608);
    if ($39) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$agg_result >> 2] = $script_0;
    var $42 = __ZNK8JSScript7nestingEv($13);
    HEAP32[$agg_result + 4 >> 2] = $42;
    var $45 = HEAPU32[$index >> 2];
    if ($32) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $47 = __ZN2js7analyzeL7ArgSlotEj1706($45);
    var $51 = $47;
    __label__ = 14;
    break;
   case 13:
    var $49 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script_0, $45);
    var $51 = $49;
    __label__ = 14;
    break;
   case 14:
    var $51;
    HEAP32[$agg_result + 8 >> 2] = $51;
    HEAP8[$agg_result + 12 | 0] = $32 & 1;
    HEAP32[$agg_result + 16 >> 2] = $45;
    __label__ = 18;
    break;
   case 15:
    if (($29 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $59 = __ZNK8JSScript8functionEv($script_0);
    var $60 = __ZN2jsL20CallObjectLambdaNameEP10JSFunction1708($59);
    if (($4 | 0) == ($60 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = __ZNK8JSScript7nestingEv($13);
    var $65 = HEAPU32[$63 >> 2];
    if (($65 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $script_0 = $65;
      __label__ = 3;
      break;
    }
   case 18:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib["X"] = 1;

function __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 20, 1);
  return;
}

function __ZL12JSID_IS_ATOMi1703($id) {
  var $1 = _JSID_IS_STRING1730($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi1704($id) {
  var $1 = _JSID_TO_STRING1731($id);
  return $1;
}

function __ZN8JSScript18ensureRanInferenceEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($this, $cx, 0, 0);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZN8JSScript8analysisEv($this);
    var $4 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($3);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $6 = __ZN8JSScript8analysisEv($this);
    __ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext($6, $cx);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN8JSScript8analysisEv($this);
    var $9 = __ZN2js7analyze14ScriptAnalysis3OOMEv($8);
    var $_0 = $9 ^ 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, $local) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $11 = 2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSScript8functionEv($script);
    var $11 = (HEAPU16[$6 + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11 + $local | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE($this, $cx, $offset, $state) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 280;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $pc = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 12;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 20;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 28;
    var $8 = __stackBase__ + 32;
    var $9 = __stackBase__ + 36;
    var $10 = __stackBase__ + 40;
    var $11 = __stackBase__ + 44;
    var $12 = __stackBase__ + 48;
    var $13 = __stackBase__ + 52;
    var $14 = __stackBase__ + 56;
    var $15 = __stackBase__ + 60;
    var $16 = __stackBase__ + 64;
    var $17 = __stackBase__ + 68;
    var $access = __stackBase__ + 72;
    var $18 = __stackBase__ + 92;
    var $19 = __stackBase__ + 96;
    var $20 = __stackBase__ + 100;
    var $access7 = __stackBase__ + 104;
    var $21 = __stackBase__ + 124;
    var $22 = __stackBase__ + 128;
    var $23 = __stackBase__ + 132;
    var $24 = __stackBase__ + 136;
    var $25 = __stackBase__ + 140;
    var $26 = __stackBase__ + 144;
    var $27 = __stackBase__ + 148;
    var $28 = __stackBase__ + 152;
    var $29 = __stackBase__ + 156;
    var $30 = __stackBase__ + 160;
    var $31 = __stackBase__ + 164;
    var $32 = __stackBase__ + 168;
    var $33 = __stackBase__ + 172;
    var $34 = __stackBase__ + 176;
    var $35 = __stackBase__ + 180;
    var $argCount = __stackBase__ + 184;
    var $36 = __stackBase__ + 188;
    var $37 = __stackBase__ + 192;
    var $38 = __stackBase__ + 196;
    var $39 = __stackBase__ + 200;
    var $40 = __stackBase__ + 204;
    var $41 = __stackBase__ + 208;
    var $42 = __stackBase__ + 212;
    var $43 = __stackBase__ + 216;
    var $44 = __stackBase__ + 220;
    var $45 = __stackBase__ + 224;
    var $46 = __stackBase__ + 228;
    var $47 = __stackBase__ + 232;
    var $48 = __stackBase__ + 236;
    var $49 = __stackBase__ + 240;
    var $50 = __stackBase__ + 244;
    var $51 = __stackBase__ + 248;
    var $52 = __stackBase__ + 252;
    var $53 = __stackBase__ + 256;
    var $54 = __stackBase__ + 260;
    var $55 = __stackBase__ + 264;
    var $56 = __stackBase__ + 268;
    var $57 = __stackBase__ + 272;
    var $58 = __stackBase__ + 276;
    HEAP32[$1 >> 2] = $cx;
    var $59 = $this | 0;
    var $60 = HEAPU32[$59 >> 2];
    var $63 = HEAP32[$60 >> 2] + $offset | 0;
    HEAP32[$pc >> 2] = $63;
    var $64 = HEAPU8[$63];
    var $65 = $64 & 255;
    var $66 = __ZN2js7analyze14ScriptAnalysis7getCodeEj($this, $offset);
    var $67 = __ZN2js7analyzeL11GetDefCountEP8JSScriptj1681($60, $offset);
    var $_val = HEAP8[HEAP32[$pc >> 2]];
    var $69 = __ZN2js7analyzeL11ExtendedDefEPh1682($_val);
    var $defCount_0 = ($69 & 1) + $67 | 0;
    var $74 = HEAP32[HEAP32[$1 >> 2] + 56 >> 2] + 344 | 0;
    var $75 = __ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj($74, $defCount_0);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j($75, $defCount_0);
    HEAP32[$66 + 36 >> 2] = $75;
    var $80 = HEAP32[$66 + 32 >> 2];
    if (($80 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $82 = $state | 0;
    var $newv_0 = $80;
    __label__ = 4;
    break;
   case 4:
    var $newv_0;
    if ((HEAP32[$newv_0 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $88 = $newv_0 + 4 | 0;
    var $89 = __ZNK2js7analyze8SSAValue4kindEv($88);
    if (($89 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $92 = __ZNK2js7analyze8SSAValue9phiOffsetEv($88);
    if (($92 | 0) == ($offset | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $newv_0 = $newv_0 + 12 | 0;
    __label__ = 4;
    break;
   case 8:
    var $95 = __ZNK2js7analyze8SSAValue7phiNodeEv($88);
    var $96 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($82, $95);
    if ($96) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 176;
      break;
    }
   case 9:
    var $97 = HEAPU32[$pc >> 2];
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$97] & 255) << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 10:
    if (($65 | 0) == 40 || ($65 | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($65 | 0) == 62 || ($65 | 0) == 63 || ($65 | 0) == 218 || ($65 | 0) == 219 || ($65 | 0) == 88 || ($65 | 0) == 190 || ($65 | 0) == 17 || ($65 | 0) == 15 || ($65 | 0) == 16 || ($65 | 0) == 33 || ($65 | 0) == 25 || ($65 | 0) == 24 || ($65 | 0) == 26) {
      __label__ = 12;
      break;
    } else if (($65 | 0) == 66 || ($65 | 0) == 67 || ($65 | 0) == 18 || ($65 | 0) == 19 || ($65 | 0) == 20 || ($65 | 0) == 21 || ($65 | 0) == 22 || ($65 | 0) == 23 || ($65 | 0) == 32 || ($65 | 0) == 72 || ($65 | 0) == 73 || ($65 | 0) == 113 || ($65 | 0) == 114 || ($65 | 0) == 186) {
      __label__ = 13;
      break;
    } else if (($65 | 0) == 60) {
      __label__ = 14;
      break;
    } else if (($65 | 0) == 61 || ($65 | 0) == 39 || ($65 | 0) == 200 || ($65 | 0) == 165 || ($65 | 0) == 180 || ($65 | 0) == 169 || ($65 | 0) == 170 || ($65 | 0) == 171 || ($65 | 0) == 181) {
      __label__ = 15;
      break;
    } else if (($65 | 0) == 64) {
      __label__ = 16;
      break;
    } else if (($65 | 0) == 162) {
      __label__ = 17;
      break;
    } else if (($65 | 0) == 80) {
      __label__ = 21;
      break;
    } else if (($65 | 0) == 197) {
      __label__ = 22;
      break;
    } else if (($65 | 0) == 68 || ($65 | 0) == 144 || ($65 | 0) == 69 || ($65 | 0) == 145) {
      __label__ = 24;
      break;
    } else if (($65 | 0) == 12) {
      __label__ = 25;
      break;
    } else if (($65 | 0) == 13) {
      __label__ = 26;
      break;
    } else if (($65 | 0) == 10 || ($65 | 0) == 133) {
      __label__ = 27;
      break;
    } else if (($65 | 0) == 156 || ($65 | 0) == 214) {
      __label__ = 32;
      break;
    } else if (($65 | 0) == 59 || ($65 | 0) == 57) {
      __label__ = 42;
      break;
    } else if (($65 | 0) == 157) {
      __label__ = 48;
      break;
    } else if (($65 | 0) == 111) {
      __label__ = 49;
      break;
    } else if (($65 | 0) == 14) {
      __label__ = 53;
      break;
    } else if (($65 | 0) == 198 || ($65 | 0) == 136 || ($65 | 0) == 137) {
      __label__ = 54;
      break;
    } else if (($65 | 0) == 84 || ($65 | 0) == 216 || ($65 | 0) == 86 || ($65 | 0) == 215) {
      __label__ = 56;
      break;
    } else if (($65 | 0) == 85 || ($65 | 0) == 87 || ($65 | 0) == 132) {
      __label__ = 63;
      break;
    } else if (($65 | 0) == 97 || ($65 | 0) == 98 || ($65 | 0) == 99 || ($65 | 0) == 100 || ($65 | 0) == 101 || ($65 | 0) == 102 || ($65 | 0) == 103 || ($65 | 0) == 104) {
      __label__ = 67;
      break;
    } else if (($65 | 0) == 9) {
      __label__ = 72;
      break;
    } else if (($65 | 0) == 54 || ($65 | 0) == 226) {
      __label__ = 77;
      break;
    } else if (($65 | 0) == 220 || ($65 | 0) == 53 || ($65 | 0) == 187) {
      __label__ = 78;
      break;
    } else if (($65 | 0) == 55 || ($65 | 0) == 196) {
      __label__ = 83;
      break;
    } else if (($65 | 0) == 56) {
      __label__ = 87;
      break;
    } else if (($65 | 0) == 231) {
      __label__ = 88;
      break;
    } else if (($65 | 0) == 65) {
      __label__ = 89;
      break;
    } else if (($65 | 0) == 5 || ($65 | 0) == 154) {
      __label__ = 90;
      break;
    } else if (($65 | 0) == 27) {
      __label__ = 92;
      break;
    } else if (($65 | 0) == 28 || ($65 | 0) == 29 || ($65 | 0) == 31 || ($65 | 0) == 30) {
      __label__ = 93;
      break;
    } else if (($65 | 0) == 34 || ($65 | 0) == 35) {
      __label__ = 94;
      break;
    } else if (($65 | 0) == 130 || ($65 | 0) == 224 || ($65 | 0) == 127 || ($65 | 0) == 222 || ($65 | 0) == 140 || ($65 | 0) == 223) {
      __label__ = 95;
      break;
    } else if (($65 | 0) == 58 || ($65 | 0) == 123 || ($65 | 0) == 108 || ($65 | 0) == 79 || ($65 | 0) == 82) {
      __label__ = 105;
      break;
    } else if (($65 | 0) == 89 || ($65 | 0) == 90 || ($65 | 0) == 91) {
      __label__ = 116;
      break;
    } else if (($65 | 0) == 94) {
      __label__ = 120;
      break;
    } else if (($65 | 0) == 125 || ($65 | 0) == 126) {
      __label__ = 131;
      break;
    } else if (($65 | 0) == 221) {
      __label__ = 132;
      break;
    } else if (($65 | 0) == 93 || ($65 | 0) == 227) {
      __label__ = 133;
      break;
    } else if (($65 | 0) == 75) {
      __label__ = 144;
      break;
    } else if (($65 | 0) == 77) {
      __label__ = 150;
      break;
    } else if (($65 | 0) == 76) {
      __label__ = 151;
      break;
    } else if (($65 | 0) == 124 || ($65 | 0) == 209 || ($65 | 0) == 207) {
      __label__ = 152;
      break;
    } else if (($65 | 0) == 118) {
      __label__ = 153;
      break;
    } else if (($65 | 0) == 37 || ($65 | 0) == 38 || ($65 | 0) == 36) {
      __label__ = 154;
      break;
    } else if (($65 | 0) == 210) {
      __label__ = 155;
      break;
    } else if (($65 | 0) == 121 || ($65 | 0) == 147) {
      __label__ = 156;
      break;
    } else if (($65 | 0) == 228) {
      __label__ = 157;
      break;
    } else if (($65 | 0) == 205) {
      __label__ = 158;
      break;
    } else if (($65 | 0) == 206) {
      __label__ = 164;
      break;
    } else if (($65 | 0) == 199) {
      __label__ = 165;
      break;
    } else if (($65 | 0) == 174) {
      __label__ = 166;
      break;
    } else if (($65 | 0) == 173) {
      __label__ = 167;
      break;
    } else if (($65 | 0) == 178 || ($65 | 0) == 179 || ($65 | 0) == 185 || ($65 | 0) == 183 || ($65 | 0) == 184 || ($65 | 0) == 175 || ($65 | 0) == 168 || ($65 | 0) == 166 || ($65 | 0) == 167 || ($65 | 0) == 164 || ($65 | 0) == 208) {
      __label__ = 168;
      break;
    } else if (($65 | 0) == 176) {
      __label__ = 169;
      break;
    } else if (($65 | 0) == 177) {
      __label__ = 170;
      break;
    } else if (($65 | 0) == 96) {
      __label__ = 171;
      break;
    } else if (($65 | 0) == 131) {
      __label__ = 172;
      break;
    } else if (($65 | 0) == 81 || ($65 | 0) == 0 || ($65 | 0) == 109 || ($65 | 0) == 182 || ($65 | 0) == 6 || ($65 | 0) == 141 || ($65 | 0) == 7 || ($65 | 0) == 142 || ($65 | 0) == 8 || ($65 | 0) == 143 || ($65 | 0) == 119 || ($65 | 0) == 128 || ($65 | 0) == 4 || ($65 | 0) == 202 || ($65 | 0) == 155 || ($65 | 0) == 78 || ($65 | 0) == 153 || ($65 | 0) == 116 || ($65 | 0) == 146 || ($65 | 0) == 117 || ($65 | 0) == 120 || ($65 | 0) == 122 || ($65 | 0) == 148 || ($65 | 0) == 11 || ($65 | 0) == 229 || ($65 | 0) == 194 || ($65 | 0) == 195 || ($65 | 0) == 163 || ($65 | 0) == 230 || ($65 | 0) == 191 || ($65 | 0) == 211 || ($65 | 0) == 212 || ($65 | 0) == 213 || ($65 | 0) == 192 || ($65 | 0) == 193 || ($65 | 0) == 188 || ($65 | 0) == 189 || ($65 | 0) == 2 || ($65 | 0) == 115 || ($65 | 0) == 74 || ($65 | 0) == 70 || ($65 | 0) == 149 || ($65 | 0) == 71 || ($65 | 0) == 150 || ($65 | 0) == 134 || ($65 | 0) == 217 || ($65 | 0) == 110 || ($65 | 0) == 129 || ($65 | 0) == 92 || ($65 | 0) == 3 || ($65 | 0) == 201 || ($65 | 0) == 112 || ($65 | 0) == 135 || ($65 | 0) == 172 || ($65 | 0) == 95) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 11:
    var $105 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $105, $2);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 12:
    var $107 = HEAP32[$1 >> 2];
    __ZN2js5types4Type9Int32TypeEv($3);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $107, $3);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 13:
    var $109 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($4);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $109, $4);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 14:
    var $111 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10DoubleTypeEv($5);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $111, $5);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 15:
    var $113 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10StringTypeEv($6);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $113, $6);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 16:
    var $115 = HEAP32[$1 >> 2];
    __ZN2js5types4Type8NullTypeEv($7);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $115, $7);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 17:
    var $117 = HEAP32[$59 >> 2];
    var $118 = __ZNK8JSScript9hasGlobalEv($117);
    var $119 = HEAP32[$1 >> 2];
    if ($118) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    var $121 = __ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey($119, $117, 10);
    if (($121 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $124 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($8, $121);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $124, $8);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 20:
    __ZN2js5types4Type11UnknownTypeEv($9);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $119, $9);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 21:
    var $127 = HEAP32[$1 >> 2];
    var $128 = HEAP32[$59 >> 2];
    var $129 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($127, $128, $97, 0);
    var $130 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEP8JSObject($10, $129);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $130, $10);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 22:
    var $132 = HEAP32[$59 >> 2];
    if ((HEAP8[$132 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $138 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($132);
    var $139 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($11);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($138, $139, $11);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 24:
    var $141 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $142 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($141, $142, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 25:
    var $144 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $145 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($144, $145, $75);
    var $146 = HEAP32[$pc >> 2];
    var $147 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $146, 0);
    var $148 = HEAP32[$1 >> 2];
    var $149 = $75 + 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($147, $148, $149);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 26:
    var $151 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $152 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($151, $152, $75);
    var $153 = HEAP32[$pc >> 2];
    var $154 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $153, 0);
    var $155 = HEAP32[$1 >> 2];
    var $156 = $75 + 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($154, $155, $156);
    var $157 = HEAP32[$pc >> 2];
    var $158 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $157, 1);
    var $159 = HEAP32[$1 >> 2];
    var $160 = $75 + 24 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($158, $159, $160);
    var $161 = HEAP32[$pc >> 2];
    var $162 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $161, 0);
    var $163 = HEAP32[$1 >> 2];
    var $164 = $75 + 36 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($162, $163, $164);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 27:
    if ($64 << 24 >> 24 == 10) {
      var $172 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $172 = HEAPU8[$97 + 1 | 0] & 255;
    __label__ = 29;
    break;
   case 29:
    var $172;
    var $173 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, $172);
    var $174 = HEAP32[$1 >> 2];
    var $175 = $75 + $172 * 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($173, $174, $175);
    if (($172 | 0) == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $177 = $172 - 1 | 0;
    var $i1_013 = 0;
    __label__ = 31;
    break;
   case 31:
    var $i1_013;
    var $179 = HEAP32[$pc >> 2];
    var $180 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $179, $i1_013);
    var $181 = HEAP32[$1 >> 2];
    var $183 = $75 + ($177 - $i1_013) * 12 | 0;
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($180, $181, $183);
    var $184 = $i1_013 + 1 | 0;
    if (($184 | 0) == ($172 | 0)) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      var $i1_013 = $184;
      __label__ = 31;
      break;
    }
   case 32:
    var $186 = HEAP32[$1 >> 2];
    var $187 = HEAP32[$59 >> 2];
    var $188 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($186, $187, $97);
    var $189 = HEAP32[$pc >> 2];
    var $190 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this, $189);
    var $191 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($190, $191, $75);
    var $192 = HEAP32[$1 >> 2];
    var $194 = HEAP32[$192 + 52 >> 2];
    var $197 = HEAP32[$194 + 209984 >> 2] | 0;
    var $198 = __ZL12ATOM_TO_JSIDP6JSAtom1694($197);
    if (($188 | 0) == ($198 | 0)) {
      __label__ = 33;
      break;
    } else {
      var $203 = $192;
      var $202 = $194;
      __label__ = 34;
      break;
    }
   case 33:
    __ZN2js5types4Type13UndefinedTypeEv($12);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($190, $192, $12);
    var $_pre = HEAP32[$1 >> 2];
    var $203 = $_pre;
    var $202 = HEAP32[$_pre + 52 >> 2];
    __label__ = 34;
    break;
   case 34:
    var $202;
    var $203;
    var $206 = HEAP32[$202 + 210380 >> 2] | 0;
    var $207 = __ZL12ATOM_TO_JSIDP6JSAtom1694($206);
    if (($188 | 0) == ($207 | 0)) {
      __label__ = 35;
      break;
    } else {
      var $212 = $203;
      var $211 = $202;
      __label__ = 36;
      break;
    }
   case 35:
    __ZN2js5types4Type10DoubleTypeEv($13);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($190, $203, $13);
    var $_pre5 = HEAP32[$1 >> 2];
    var $212 = $_pre5;
    var $211 = HEAP32[$_pre5 + 52 >> 2];
    __label__ = 36;
    break;
   case 36:
    var $211;
    var $212;
    var $215 = HEAP32[$211 + 210376 >> 2] | 0;
    var $216 = __ZL12ATOM_TO_JSIDP6JSAtom1694($215);
    if (($188 | 0) == ($216 | 0)) {
      __label__ = 37;
      break;
    } else {
      var $220 = $212;
      __label__ = 38;
      break;
    }
   case 37:
    __ZN2js5types4Type10DoubleTypeEv($14);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($190, $212, $14);
    var $220 = HEAP32[$1 >> 2];
    __label__ = 38;
    break;
   case 38:
    var $220;
    var $221 = HEAP32[$59 >> 2];
    var $222 = HEAP32[$pc >> 2];
    var $223 = __ZNK8JSScript6globalEv($221);
    var $224 = $223;
    var $226 = __ZN8JSObject7getTypeEP9JSContext($224, $220);
    var $227 = $226;
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($220, $221, $222, $227, 0, $190, $188);
    if ($64 << 24 >> 24 == -42) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $230 = $75 + 12 | 0;
    var $231 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($15);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($230, $231, $15);
    var $232 = HEAP32[$1 >> 2];
    var $233 = HEAP32[$59 >> 2];
    var $234 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($16);
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $232, $233, $234, $16, 0);
    __label__ = 40;
    break;
   case 40:
    var $236 = HEAP32[$pc >> 2];
    var $237 = __ZL13CheckNextTestPh($236);
    if ($237) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 41:
    var $239 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($17);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $239, $17);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 42:
    var $241 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this, $97);
    var $242 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($241, $242, $75);
    var $243 = HEAP32[$1 >> 2];
    var $244 = HEAP32[$59 >> 2];
    var $245 = HEAP32[$pc >> 2];
    var $246 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($243, $244, $245);
    var $247 = HEAP32[$1 >> 2];
    __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($access, $this, $247, $246, 0);
    var $249 = HEAP32[$access >> 2];
    if (($249 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ((HEAP8[$249 + 38 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $258 = HEAP32[$access + 8 >> 2];
    var $259 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($249, $258);
    var $260 = HEAP32[$1 >> 2];
    var $261 = HEAP32[$59 >> 2];
    var $262 = HEAP32[$pc >> 2];
    __ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_($259, $260, $261, $262, $241);
    __label__ = 46;
    break;
   case 45:
    var $264 = HEAP32[$1 >> 2];
    var $265 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($18);
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this, $264, $265, $241, $18);
    __label__ = 46;
    break;
   case 46:
    if ($64 << 24 >> 24 == 57) {
      __label__ = 47;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 47:
    var $269 = $75 + 12 | 0;
    var $270 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($19);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($269, $270, $19);
    var $271 = HEAP32[$1 >> 2];
    var $272 = HEAP32[$59 >> 2];
    var $273 = HEAP32[$pc >> 2];
    __ZN2js5types4Type11UnknownTypeEv($20);
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $271, $272, $273, $20, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 48:
    var $275 = HEAP32[$1 >> 2];
    var $276 = HEAP32[$59 >> 2];
    var $277 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($275, $276, $97);
    var $278 = HEAP32[$1 >> 2];
    var $279 = HEAP32[$59 >> 2];
    var $280 = HEAP32[$pc >> 2];
    var $281 = __ZNK8JSScript6globalEv($279);
    var $282 = $281;
    var $283 = $278;
    var $284 = __ZN8JSObject7getTypeEP9JSContext($282, $283);
    var $285 = $284;
    var $286 = HEAP32[$pc >> 2];
    var $287 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $286, 0);
    __ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi($278, $279, $280, $285, 1, $287, $277);
    var $288 = HEAP32[$pc >> 2];
    var $289 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $288, 0);
    var $290 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($289, $290, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 49:
    var $292 = HEAP32[$1 >> 2];
    var $293 = HEAP32[$59 >> 2];
    var $294 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($292, $293, $97);
    var $295 = HEAP32[$1 >> 2];
    __ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib($access7, $this, $295, $294, 0);
    var $297 = HEAP32[$access7 >> 2];
    if (($297 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $301 = HEAP32[$access7 + 8 >> 2];
    var $302 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($297, $301);
    var $303 = HEAP32[$pc >> 2];
    var $304 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $303, 0);
    var $305 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($304, $305, $302);
    __label__ = 52;
    break;
   case 51:
    var $307 = HEAP32[$1 >> 2];
    var $308 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $307, $308, $offset, 0);
    __label__ = 52;
    break;
   case 52:
    var $310 = HEAP32[$pc >> 2];
    var $311 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $310, 0);
    var $312 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($311, $312, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 53:
    var $314 = HEAP32[$1 >> 2];
    var $315 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $314, $315, $offset, 0);
    var $316 = HEAP32[$pc >> 2];
    var $317 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $316, 0);
    var $318 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($317, $318, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 54:
    var $320 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this, $97);
    var $321 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($21);
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($this, $321, $97, $320, $21);
    var $322 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($320, $322, $75);
    if ($64 << 24 >> 24 == -119) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 55:
    var $325 = $75 + 12 | 0;
    var $326 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($22);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($325, $326, $22);
    var $327 = HEAP32[$1 >> 2];
    var $328 = HEAP32[$59 >> 2];
    var $329 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($23);
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $327, $328, $329, $23, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 56:
    var $331 = HEAPU32[$59 >> 2];
    var $332 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($331, $97);
    var $333 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $332);
    if ($333) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $335 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $336 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($335, $336, $75);
    __label__ = 61;
    break;
   case 58:
    var $338 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($331);
    if ($332 >>> 0 < $338 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 59:
    var $341 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($331, $332);
    var $342 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($341, $342, $75);
    __label__ = 61;
    break;
   case 60:
    var $344 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($24);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $344, $24);
    __label__ = 61;
    break;
   case 61:
    if (($64 + 41 & 255 & 255) < 2) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 62:
    var $348 = $75 + 12 | 0;
    var $349 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($25);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($348, $349, $25);
    var $350 = HEAP32[$1 >> 2];
    var $351 = HEAP32[$59 >> 2];
    var $352 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($26);
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $350, $351, $352, $26, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 63:
    var $354 = HEAPU32[$59 >> 2];
    var $355 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($354, $97);
    var $356 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $355);
    if ($356) {
      var $365 = $97;
      __label__ = 66;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $358 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($354);
    if ($355 >>> 0 < $358 >>> 0) {
      __label__ = 65;
      break;
    } else {
      var $365 = $97;
      __label__ = 66;
      break;
    }
   case 65:
    var $361 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($354, $355);
    var $362 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $363 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($362, $363, $361);
    var $365 = HEAP32[$pc >> 2];
    __label__ = 66;
    break;
   case 66:
    var $365;
    var $366 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $365, 0);
    var $367 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($366, $367, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 67:
    var $369 = HEAPU32[$59 >> 2];
    var $370 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($369, $97);
    var $371 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $370);
    if ($371) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $373 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $374 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($373, $374, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 69:
    var $376 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($369);
    if ($370 >>> 0 < $376 >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 70:
    var $379 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($369, $370);
    var $380 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($379, $380, $379, 0);
    var $381 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($379, $381, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 71:
    var $383 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($27);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $383, $27);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 72:
    var $385 = HEAP32[$59 >> 2];
    var $386 = __ZNK8JSScript8functionEv($385);
    var $388 = $386;
    var $389 = HEAP32[$1 >> 2];
    var $390 = __ZN8JSObject7getTypeEP9JSContext($388, $389);
    var $391 = $390;
    var $392 = __ZN2js5types10TypeObject17unknownPropertiesEv($391);
    if ($392) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $394 = __ZN2js5types10TypeObject11hasAnyFlagsEj($391, 524288);
    if ($394) {
      __label__ = 74;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 74:
    var $396 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($28);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $396, $28);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 75:
    var $398 = HEAP32[$1 >> 2];
    var $399 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($391, $398, 4, 0);
    if (($399 | 0) == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $402 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_($399, $402, $75);
    var $403 = HEAP32[$1 >> 2];
    __ZN2js5types4Type12LazyArgsTypeEv($29);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $403, $29);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 77:
    var $405 = HEAP32[$1 >> 2];
    var $406 = HEAP32[$59 >> 2];
    var $407 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($405, $406, $97);
    var $408 = HEAP32[$pc >> 2];
    var $409 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $408, 1);
    var $410 = HEAP32[$1 >> 2];
    var $411 = HEAP32[$59 >> 2];
    var $412 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $408, 0);
    __ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i($409, $410, $411, $408, $412, $407);
    var $413 = HEAP32[$pc >> 2];
    var $414 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $413, 0);
    var $415 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($414, $415, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 78:
    var $417 = HEAP32[$1 >> 2];
    var $418 = HEAP32[$59 >> 2];
    var $419 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($417, $418, $97);
    var $420 = HEAP32[$59 >> 2];
    var $421 = __ZN8JSScript8analysisEv($420);
    var $422 = HEAP32[$pc >> 2];
    var $423 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($421, $422);
    var $424 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $422, 0);
    var $425 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($424, $425, $420, $422, $423, $419);
    if ($64 << 24 >> 24 == -69) {
      __label__ = 79;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 79:
    var $428 = HEAP32[$pc >> 2];
    var $429 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $428, 0);
    var $430 = HEAP32[$1 >> 2];
    var $431 = HEAP32[$59 >> 2];
    __ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi($429, $430, $431, $428, $419);
    var $432 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($423, $432, $75);
    var $433 = HEAP32[$pc >> 2];
    var $434 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $433, 0);
    var $435 = HEAP32[$1 >> 2];
    var $436 = $75 + 12 | 0;
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($434, $435, $436, 1);
    __label__ = 81;
    break;
   case 80:
    var $437 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($423, $437, $75);
    __label__ = 81;
    break;
   case 81:
    var $439 = HEAP32[$pc >> 2];
    var $440 = __ZL13CheckNextTestPh($439);
    if ($440) {
      __label__ = 82;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 82:
    var $442 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($30);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $442, $30);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 83:
    var $444 = HEAP32[$59 >> 2];
    var $445 = __ZN8JSScript8analysisEv($444);
    var $446 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($445, $97);
    var $447 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $448 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i($447, $448, $444, $97, $446, 2);
    var $449 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($446, $449, $75);
    if ($64 << 24 >> 24 == -60) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    var $452 = HEAP32[$pc >> 2];
    var $453 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $452, 1);
    var $454 = HEAP32[$1 >> 2];
    var $455 = $75 + 12 | 0;
    __ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE($453, $454, $455, 1);
    var $456 = HEAP32[$1 >> 2];
    var $457 = HEAP32[$59 >> 2];
    var $458 = HEAP32[$pc >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($31);
    __ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_($75, $456, $457, $458, $31, $455);
    __label__ = 85;
    break;
   case 85:
    var $460 = HEAP32[$pc >> 2];
    var $461 = __ZL13CheckNextTestPh($460);
    if ($461) {
      __label__ = 86;
      break;
    } else {
      var $_0 = 1;
      __label__ = 176;
      break;
    }
   case 86:
    var $463 = HEAP32[$1 >> 2];
    __ZN2js5types4Type13UndefinedTypeEv($32);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $463, $32);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 87:
    var $465 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $466 = HEAP32[$1 >> 2];
    var $467 = HEAP32[$59 >> 2];
    var $468 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 2);
    var $469 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    __ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_($465, $466, $467, $97, $468, $469);
    var $470 = HEAP32[$pc >> 2];
    var $471 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $470, 0);
    var $472 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($471, $472, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 88:
    var $474 = HEAP32[$1 >> 2];
    __ZN2js5types4Type9Int32TypeEv($33);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $474, $33);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 89:
    var $476 = HEAP32[$59 >> 2];
    var $477 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($476);
    var $478 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_($477, $478, $476, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 90:
    var $480 = HEAP32[$59 >> 2];
    if ((HEAP8[$480 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $486 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $487 = HEAP32[$1 >> 2];
    var $488 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($480);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($486, $487, $488);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 92:
    var $490 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $491 = HEAP32[$1 >> 2];
    var $492 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($490, $491, $75, $492);
    var $493 = HEAP32[$pc >> 2];
    var $494 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $493, 1);
    var $495 = HEAP32[$1 >> 2];
    var $496 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $493, 0);
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($494, $495, $75, $496);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 93:
    var $498 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $499 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($498, $499, $75, 0);
    var $500 = HEAP32[$pc >> 2];
    var $501 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $500, 1);
    var $502 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($501, $502, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 94:
    var $504 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $505 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_($504, $505, $75, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 95:
    if ($64 << 24 >> 24 == -116) {
      __label__ = 96;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 96:
    var $508 = HEAP32[$1 >> 2];
    var $509 = HEAP32[$59 >> 2];
    var $510 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($508, $509, $97, 2);
    var $517 = $510;
    __label__ = 98;
    break;
   case 97:
    var $phitmp = $64 << 24 >> 24 == -33 ? 2 : 0;
    var $513 = HEAP32[$1 >> 2];
    var $514 = HEAP32[$59 >> 2];
    var $515 = __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($513, $514, $97, $phitmp);
    if ($64 << 24 >> 24 == -33) {
      var $517 = $515;
      __label__ = 98;
      break;
    } else if ($64 << 24 >> 24 == -32 || $64 << 24 >> 24 == -126) {
      var $res_0 = $75;
      var $525 = $515;
      __label__ = 100;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 98:
    var $517;
    var $518 = HEAP32[$59 >> 2];
    var $519 = HEAP32[$pc >> 2];
    var $520 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($518, $519);
    var $521 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $520);
    if ($521) {
      var $res_0 = $75;
      var $525 = $517;
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $523 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($518, $520);
    var $res_0 = $523;
    var $525 = $517;
    __label__ = 100;
    break;
   case 100:
    var $525;
    var $res_0;
    if (($res_0 | 0) == 0) {
      __label__ = 104;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $528 = HEAP32[$59 >> 2];
    var $529 = __ZNK8JSScript9hasGlobalEv($528);
    var $530 = HEAP32[$1 >> 2];
    if ($529) {
      __label__ = 102;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 102:
    __ZN2js5types4Type10ObjectTypeEP8JSObject($34, $525);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($res_0, $530, $34);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 103:
    __ZN2js5types4Type11UnknownTypeEv($35);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($res_0, $530, $35);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 104:
    var $533 = HEAP32[$1 >> 2];
    var $534 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $533, $534, $offset, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 105:
    var $536 = HEAP32[$59 >> 2];
    var $537 = __ZN8JSScript8analysisEv($536);
    var $538 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($537, $97);
    var $539 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($538, $539, $75);
    var $_idx_val = HEAP32[HEAP32[$59 >> 2] >> 2];
    var $541 = __ZN2js7analyzeL11GetUseCountEP8JSScriptj1711($_idx_val, $offset);
    var $542 = $541 - 2 | 0;
    HEAP32[$argCount >> 2] = $542;
    var $546 = HEAP32[HEAP32[$1 >> 2] + 56 >> 2] + 344 | 0;
    HEAP8[$36] = $64 << 24 >> 24 == 82 & 1;
    var $549 = __ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($546, $1, $59, $pc, $36, $argCount);
    if (($549 | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $552 = HEAPU32[$argCount >> 2];
    var $553 = ($552 | 0) == 0;
    if ($553) {
      __label__ = 112;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    if ((HEAP32[$549 + 12 >> 2] | 0) == 0) {
      __label__ = 108;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 108:
    var $559 = HEAP32[$1 >> 2];
    var $562 = HEAP32[$559 + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($562, $559);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 109:
    var $564 = HEAP32[$pc >> 2];
    var $565 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $564, $552);
    var $566 = $549 + 20 | 0;
    HEAP32[$566 >> 2] = $565;
    var $567 = $549 + 24 | 0;
    HEAP32[$567 >> 2] = $538;
    if ($553) {
      __label__ = 113;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $568 = $549 + 12 | 0;
    var $i23_011 = 0;
    __label__ = 111;
    break;
   case 111:
    var $i23_011;
    var $569 = HEAP32[$pc >> 2];
    var $571 = $552 + ($i23_011 ^ -1) | 0;
    var $572 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $569, $571);
    var $574 = HEAP32[$568 >> 2] + ($i23_011 << 2) | 0;
    HEAP32[$574 >> 2] = $572;
    var $575 = $i23_011 + 1 | 0;
    if ($575 >>> 0 < $552 >>> 0) {
      var $i23_011 = $575;
      __label__ = 111;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 112:
    var $577 = HEAP32[$pc >> 2];
    var $578 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $577, $552);
    var $579 = $549 + 20 | 0;
    HEAP32[$579 >> 2] = $578;
    var $580 = $549 + 24 | 0;
    HEAP32[$580 >> 2] = $538;
    __label__ = 113;
    break;
   case 113:
    if ($64 << 24 >> 24 == 108 || $64 << 24 >> 24 == 79) {
      __label__ = 114;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 114:
    var $582 = HEAP32[$1 >> 2];
    var $583 = HEAP32[$59 >> 2];
    var $589 = HEAP32[$pc >> 2] - HEAP32[$583 >> 2] | 0;
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $582, $583, $589, 0);
    __label__ = 115;
    break;
   case 115:
    var $591 = HEAP32[$pc >> 2];
    var $592 = $552 + 1 | 0;
    var $593 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $591, $592);
    var $594 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE($593, $594, $549);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 116:
    var $596 = HEAP32[$1 >> 2];
    var $597 = HEAP32[$59 >> 2];
    var $598 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($596, $597, $97);
    var $599 = HEAP32[$59 >> 2];
    var $600 = __ZNK8JSScript9hasGlobalEv($599);
    if ($600) {
      __label__ = 117;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 117:
    if (($598 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    var $604 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($37, $598);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $604, $37);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 119:
    var $606 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($38);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $606, $38);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 120:
    var $608 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this, $97, 2);
    var $609 = HEAP32[$59 >> 2];
    var $611 = HEAP32[$609 >> 2];
    var $612 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($608);
    var $613 = $611 + $612 | 0;
    var $614 = HEAP32[$1 >> 2];
    var $615 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($614, $609, $613);
    var $617 = HEAP32[$1 >> 2];
    if (($615 | 0) == 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($39, $615);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $617, $39);
    var $619 = __ZN2js5types10TypeObject17unknownPropertiesEv($615);
    if ($619) {
      __label__ = 130;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $621 = HEAP32[$1 >> 2];
    var $622 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($615, $621, 2, 1);
    if (($622 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    if ((HEAP8[$state + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 125;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $630 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($40);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($622, $630, $40);
    __label__ = 130;
    break;
   case 125:
    if ((HEAP8[$state + 25 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $637 = __ZN2js5types10TypeObject17unknownPropertiesEv($615);
    if ($637) {
      __label__ = 130;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $639 = HEAP32[$1 >> 2];
    __ZN2js5types10TypeObject8setFlagsEP9JSContextj($615, $639, 131072);
    __label__ = 130;
    break;
   case 128:
    var $641 = HEAP32[$pc >> 2];
    var $642 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $641, 0);
    var $643 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($642, $643, $622);
    __label__ = 130;
    break;
   case 129:
    __ZN2js5types4Type11UnknownTypeEv($41);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $617, $41);
    __label__ = 130;
    break;
   case 130:
    HEAP8[$state + 24 | 0] = 0;
    HEAP8[$state + 25 | 0] = 0;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 131:
    HEAP8[$state + 24 | 0] = 1;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 132:
    HEAP8[$state + 25 | 0] = 1;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 133:
    var $653 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this, $97, 1);
    var $654 = HEAP32[$59 >> 2];
    var $656 = HEAP32[$654 >> 2];
    var $657 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($653);
    var $658 = $656 + $657 | 0;
    var $659 = HEAP32[$1 >> 2];
    var $660 = __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($659, $654, $658);
    var $662 = HEAP32[$1 >> 2];
    if (($660 | 0) == 0) {
      __label__ = 142;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($42, $660);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $662, $42);
    var $664 = __ZN2js5types10TypeObject17unknownPropertiesEv($660);
    if ($664) {
      __label__ = 143;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $666 = HEAP32[$1 >> 2];
    var $667 = HEAP32[$59 >> 2];
    var $668 = HEAP32[$pc >> 2];
    var $669 = __ZL9GetAtomIdP9JSContextP8JSScriptPKhj($666, $667, $668);
    var $670 = HEAP32[$1 >> 2];
    var $671 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($660, $670, $669, 1);
    if (($671 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $674 = HEAP32[$1 >> 2];
    var $_idx1_val = HEAP32[$674 + 52 >> 2];
    var $_idx1_val_idx_val = HEAP32[$_idx1_val + 210292 >> 2];
    var $675 = __ZL12id___proto__P9JSContext($_idx1_val_idx_val);
    if (($669 | 0) == ($675 | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $_idx2_val_idx_val = HEAP32[$_idx1_val + 210200 >> 2];
    var $678 = __ZL12id_prototypeP9JSContext($_idx2_val_idx_val);
    if (($669 | 0) == ($678 | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $681 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $674, $681, $offset, 0);
    __label__ = 143;
    break;
   case 139:
    if ((HEAP8[$state + 24 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    __ZN2js5types4Type11UnknownTypeEv($43);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($671, $674, $43);
    __label__ = 143;
    break;
   case 141:
    var $689 = HEAP32[$pc >> 2];
    var $690 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $689, 0);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($690, $674, $671);
    __label__ = 143;
    break;
   case 142:
    __ZN2js5types4Type11UnknownTypeEv($44);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $662, $44);
    __label__ = 143;
    break;
   case 143:
    HEAP8[$state + 24 | 0] = 0;
    var $_0 = 1;
    __label__ = 176;
    break;
   case 144:
    var $695 = $state + 28 | 0;
    var $696 = HEAP32[$695 >> 2];
    if (($696 | 0) == 0) {
      __label__ = 145;
      break;
    } else {
      var $704 = $696;
      var $703 = $97;
      __label__ = 147;
      break;
    }
   case 145:
    var $699 = HEAP32[$1 >> 2];
    var $700 = __ZN2js5types7TypeSet4makeEP9JSContextPKc($699, undef);
    HEAP32[$695 >> 2] = $700;
    if (($700 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $704 = $700;
    var $703 = HEAP32[$pc >> 2];
    __label__ = 147;
    break;
   case 147:
    var $703;
    var $704;
    var $709 = HEAP32[$1 >> 2];
    if ((HEAP8[$703 + 1 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 149;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    __ZN2js5types4Type11UnknownTypeEv($45);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($704, $709, $45);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 149:
    __ZN2js5types4Type10StringTypeEv($46);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($704, $709, $46);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 150:
    var $714 = HEAP32[$state + 28 >> 2];
    var $715 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($714, $715, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 151:
    var $717 = $75 + 12 | 0;
    var $718 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($47);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($717, $718, $47);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 152:
    var $720 = HEAP32[$1 >> 2];
    var $721 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $720, $721, $offset, 0);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 153:
    var $723 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($48);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $723, $48);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 154:
    var $725 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11BooleanTypeEv($49);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $725, $49);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 155:
    var $727 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $728 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($727, $728, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 156:
    var $730 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $731 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($730, $731, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 157:
    var $733 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $734 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($733, $734, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 158:
    var $736 = HEAP32[$59 >> 2];
    if ((HEAP8[$736 + 37 | 0] & 4) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 176;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    var $742 = __ZNK8JSScript9hasGlobalEv($736);
    if ($742) {
      __label__ = 160;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 160:
    var $744 = __ZNK8JSScript6globalEv($736);
    var $745 = HEAP32[$1 >> 2];
    var $746 = __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($744, $745);
    if (($746 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $749 = HEAP32[$1 >> 2];
    var $750 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($746, $749, 0, 0);
    if (($750 | 0) == 0) {
      var $_0 = 0;
      __label__ = 176;
      break;
    } else {
      __label__ = 162;
      break;
    }
   case 162:
    var $753 = HEAP32[$59 >> 2];
    var $754 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($753);
    var $755 = HEAP32[$1 >> 2];
    __ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE($50, $750);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($754, $755, $50);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 163:
    var $757 = __ZN2js5types10TypeScript11ReturnTypesEP8JSScript($736);
    var $758 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($51);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($757, $758, $51);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 164:
    var $760 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($52);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $760, $52);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 165:
    var $762 = $75 + 12 | 0;
    var $763 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($53);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($762, $763, $53);
    __label__ = 166;
    break;
   case 166:
    var $765 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($54);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $765, $54);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 167:
    var $767 = HEAP32[$1 >> 2];
    var $768 = HEAP32[$59 >> 2];
    __ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb(undef, $767, $768, $offset, 0);
    var $769 = HEAP32[$pc >> 2];
    var $770 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $769, 0);
    var $771 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($770, $771, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 168:
    var $773 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($55);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $773, $55);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 169:
    var $775 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 0);
    var $776 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($775, $776, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 170:
    var $778 = __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $97, 1);
    var $779 = HEAP32[$1 >> 2];
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($778, $779, $75);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 171:
    var $781 = HEAP32[$1 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($56);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $781, $56);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 172:
    var $783 = HEAP32[$59 >> 2];
    var $784 = __ZNK8JSScript9hasGlobalEv($783);
    var $785 = HEAP32[$1 >> 2];
    if ($784) {
      __label__ = 173;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 173:
    var $787 = __ZNK8JSScript8functionEv($783);
    var $788 = $787 | 0;
    __ZN2js5types4Type10ObjectTypeEP8JSObject($57, $788);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $785, $57);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 174:
    __ZN2js5types4Type11UnknownTypeEv($58);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($75, $785, $58);
    var $_0 = 1;
    __label__ = 176;
    break;
   case 175:
    var $791 = HEAP32[_stderr >> 2];
    var $792 = _fprintf($791, STRING_TABLE.__str471617 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $65, HEAP32[tempInt + 4 >> 2] = 0, HEAP32[tempInt + 8 >> 2] = $offset, tempInt));
    var $793 = HEAP32[$1 >> 2];
    __ZN2js5types11TypeFailureEP9JSContextPKcz($793, STRING_TABLE.__str481618 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $65, tempInt));
    var $_0 = 1;
    __label__ = 176;
    break;
   case 176:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE["X"] = 1;

function __ZN2js7analyze14ScriptAnalysis3OOMEv($this) {
  return (HEAP8[$this + 12 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis6ranSSAEv($this) {
  return (HEAP8[$this + 21 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv($this) {
  return (HEAP8[$this + 24 | 0] & 2) << 24 >> 24 != 0;
}

function __ZN2js7analyze14ScriptAnalysis12extendsScopeEv($this) {
  return (HEAP8[$this + 24 | 0] & 32) << 24 >> 24 != 0;
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js7analyze14ScriptAnalysis16localsAliasStackEv($this) {
  return HEAP8[$this + 24 | 0] << 24 >> 24 < 0;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + $count * 12 & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem * 12 | 0;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types4Type11BooleanTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 3);
  return;
}

function __ZN2js5types4Type8NullTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 6);
  return;
}

function __ZL15GetScriptObjectP9JSContextP8JSScriptPKhj($cx, $script, $pc, $offset) {
  var $1 = _js_GetIndexFromBytecode($cx, $script, $pc, $offset);
  var $2 = __ZN8JSScript9getObjectEj($script, $1);
  return $2;
}

function __ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj($this, $pc, $which) {
  var $1 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($this, $pc, $which);
  var $2 = __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $1);
  return $2;
}

function __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($this, $pc) {
  var $1 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($this, $pc);
  return HEAP32[$1 + 16 >> 2];
}

function __ZL13CheckNextTestPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($pc);
    var $4 = HEAPU8[$pc + $1 | 0] & 255;
    if (($4 | 0) == 7 || ($4 | 0) == 8 || ($4 | 0) == 32 || ($4 | 0) == 68 || ($4 | 0) == 144 || ($4 | 0) == 69 || ($4 | 0) == 145 || ($4 | 0) == 39 || ($4 | 0) == 200) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$pc] & 255;
    if (($2 | 0) == 84 || ($2 | 0) == 216 || ($2 | 0) == 85 || ($2 | 0) == 97 || ($2 | 0) == 98 || ($2 | 0) == 99 || ($2 | 0) == 100) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 86 || ($2 | 0) == 215 || ($2 | 0) == 87 || ($2 | 0) == 132 || ($2 | 0) == 140 || ($2 | 0) == 223 || ($2 | 0) == 101 || ($2 | 0) == 102 || ($2 | 0) == 103 || ($2 | 0) == 104) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 65) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $12 = __ZN2js7analyzeL7ArgSlotEj1706($11);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 3:
    var $21 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $22 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, $21);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script) {
  var $1 = __ZN2js7analyzeL9LocalSlotEP8JSScriptj1707($script, 0);
  return (HEAPU16[$script + 14 >> 1] & 65535) + $1 | 0;
}

function __ZN2js5types4Type12LazyArgsTypeEv($agg_result) {
  __ZN2js5types4TypeC1Ej($agg_result, 4);
  return;
}

function __ZN2js7analyzeL11GetUseCountEP8JSScriptj1711($script_0_0_val, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script_0_0_val + $offset | 0;
    var $2 = HEAPU8[$1];
    var $3 = $2 & 255;
    if ($2 << 24 >> 24 == -123) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$offset + ($script_0_0_val + 1) | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = HEAPU8[_js_CodeSpec + ($3 << 3) + 1 | 0];
    if ($12 << 24 >> 24 == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = _js_GetVariableStackUses($3, $1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $_0 = $12 << 24 >> 24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_($pool, $a, $b, $c, $d, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 28 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $32 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    var $29 = (HEAP8[$d] & 1) << 24 >> 24 != 0;
    var $30 = HEAP32[$e >> 2];
    __ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj($23, $24, $25, $26, $29, $30);
    var $32 = $23;
    __label__ = 6;
    break;
   case 6:
    var $32;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18GetInitializerTypeP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $1 = __ZNK8JSScript9hasGlobalEv($script);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $pc);
    var $3 = HEAP8[$pc];
    if ($3 << 24 >> 24 == 90) {
      var $12 = 3;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($3 << 24 >> 24 == 89) {
      __label__ = 4;
      break;
    } else {
      var $12 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = HEAP8[$pc + 1 | 0] << 24 >> 24 == 3 ? 3 : 1;
    var $12 = $phitmp;
    __label__ = 5;
    break;
   case 5:
    var $12;
    var $13 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script, $pc, $12);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12id___proto__P9JSContext($cx_0_11_val_0_70_37_val) {
  var $1 = $cx_0_11_val_0_70_37_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN8JSObject10getSlotRefEj($1, 112);
    var $3 = __ZNK2JS5Value8isObjectEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $this;
    var $7 = __Z22js_InitIteratorClassesP9JSContextP8JSObject($5, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK2JS5Value8toObjectEv($2);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $state = __stackBase__ + 4;
    var $untrap = __stackBase__ + 36;
    var $2 = __stackBase__ + 44;
    var $3 = __stackBase__ + 48;
    var $seen = __stackBase__ + 52;
    var $4 = __stackBase__ + 76;
    var $5 = __stackBase__ + 80;
    var $6 = __ZN2js7analyze14ScriptAnalysis3OOMEv($this);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($10, $cx);
    __label__ = 54;
    break;
   case 3:
    var $12 = $this | 0;
    var $13 = HEAP32[$12 >> 2];
    var $14 = __ZNK8JSScript16hasClearedGlobalEv($13);
    if ($14) {
      __label__ = 54;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js7analyze14ScriptAnalysis6ranSSAEv($this);
    if ($16) {
      var $20 = $13;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext($this, $cx);
    var $18 = __ZN2js7analyze14ScriptAnalysis6failedEv($this);
    if ($18) {
      __label__ = 54;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$12 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $20;
    HEAP8[$this + 23 | 0] = 1;
    if (HEAP16[$20 + 14 >> 1] << 16 >> 16 == 0) {
      var $_lcssa18 = $20;
      __label__ = 9;
      break;
    } else {
      var $i_019 = 0;
      var $25 = $20;
      __label__ = 8;
      break;
    }
   case 8:
    var $25;
    var $i_019;
    var $26 = __ZN2js5types10TypeScript10LocalTypesEP8JSScriptj($25, $i_019);
    __ZN2js5types4Type13UndefinedTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($26, $cx, $1);
    var $27 = $i_019 + 1 | 0;
    var $28 = HEAPU32[$12 >> 2];
    if ($27 >>> 0 < (HEAPU16[$28 + 14 >> 1] & 65535) >>> 0) {
      var $i_019 = $27;
      var $25 = $28;
      __label__ = 8;
      break;
    } else {
      var $_lcssa18 = $28;
      __label__ = 9;
      break;
    }
   case 9:
    var $_lcssa18;
    if ((HEAP8[$_lcssa18 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = __ZNK8JSScript7nestingEv($_lcssa18);
    if (($39 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = $39;
    var $43 = HEAP32[$42 >> 2];
    if (($43 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = __ZN8JSScript18ensureRanInferenceEP9JSContext($43, $cx);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 13:
    var $48 = __ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv($this);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = HEAP32[$12 >> 2];
    if ((HEAP8[$50 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZL19DetachNestingParentP8JSScript($50);
    __label__ = 21;
    break;
   case 16:
    var $57 = __ZN2js7analyze14ScriptAnalysis12extendsScopeEv($this);
    if ($57) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $59 = HEAP32[$12 >> 2];
    __ZL19DetachNestingParentP8JSScript($59);
    __label__ = 21;
    break;
   case 18:
    var $61 = HEAP32[$42 >> 2];
    var $62 = __ZN8JSScript8analysisEv($61);
    var $63 = __ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv($62);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $66 = HEAP32[$61 >> 2];
    var $67 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($61, $66);
    if (($67 | 0) == 205) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $69 = HEAP32[$12 >> 2];
    __ZL19DetachNestingParentP8JSScript($69);
    __label__ = 21;
    break;
   case 21:
    __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext($state, $cx);
    var $offset_0 = 0;
    __label__ = 22;
    break;
   case 22:
    var $offset_0;
    var $71 = HEAPU32[$12 >> 2];
    if ($offset_0 >>> 0 < HEAPU32[$71 + 8 >> 2] >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $75 = $state | 0;
    var $76 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($75);
    if (($76 | 0) == 0) {
      var $109 = $71;
      __label__ = 33;
      break;
    } else {
      var $i1_015 = 0;
      __label__ = 28;
      break;
    }
   case 24:
    var $79 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $offset_0);
    var $82 = HEAP32[$71 >> 2] + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $71, $82);
    if (($79 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $85 = __ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE($this, $cx, $offset_0, $state);
    if ($85) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $86 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($82);
    var $87 = $86 + $offset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $offset_0 = $87;
    __label__ = 22;
    break;
   case 27:
    var $91 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($91, $cx);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 53;
    break;
   case 28:
    var $i1_015;
    var $92 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj($75, $i1_015);
    var $93 = HEAP32[$92 >> 2];
    var $94 = $93 + 16 | 0;
    if ((HEAP32[$94 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $97 = $93 + 20 | 0;
    var $98 = $93 | 0;
    var $j_010 = 0;
    __label__ = 30;
    break;
   case 30:
    var $j_010;
    var $101 = HEAP32[$97 >> 2] + ($j_010 << 3) | 0;
    var $102 = __ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE($this, $101);
    __ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_($102, $cx, $98);
    var $103 = $j_010 + 1 | 0;
    if ($103 >>> 0 < HEAPU32[$94 >> 2] >>> 0) {
      var $j_010 = $103;
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $106 = $i1_015 + 1 | 0;
    var $107 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv($75);
    if ($106 >>> 0 < $107 >>> 0) {
      var $i1_015 = $106;
      __label__ = 28;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $109 = HEAP32[$12 >> 2];
    __label__ = 33;
    break;
   case 33:
    var $109;
    var $result_08 = HEAP32[HEAP32[$109 + 100 >> 2] + 16 >> 2];
    if (($result_08 | 0) == 0) {
      var $129 = $109;
      __label__ = 40;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $114 = $state + 28 | 0;
    var $115 = $2 | 0;
    var $result_09 = $result_08;
    __label__ = 35;
    break;
   case 35:
    var $result_09;
    var $118 = HEAP32[$result_09 >> 2];
    if (($118 | 0) == -1) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $121 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($this, $118, 0);
    var $123 = HEAP32[$result_09 + 4 >> 2];
    HEAP32[$115 >> 2] = $123;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($121, $cx, $2);
    __label__ = 38;
    break;
   case 37:
    var $125 = HEAP32[$114 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($3);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($125, $cx, $3);
    __label__ = 38;
    break;
   case 38:
    var $result_0 = HEAP32[$result_09 + 8 >> 2];
    if (($result_0 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      var $result_09 = $result_0;
      __label__ = 35;
      break;
    }
   case 39:
    var $129 = HEAP32[$12 >> 2];
    __label__ = 40;
    break;
   case 40:
    var $129;
    var $132 = HEAP32[$129 + 36 >> 2];
    if (($132 & 64 | 0) != 0 & ($132 & 131072 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 41:
    var $138 = __ZNK8JSScript8functionEv($129);
    var $139 = __ZNK10JSFunction13isHeavyweightEv($138);
    if ($139) {
      __label__ = 44;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $142 = HEAP32[$cx + 56 >> 2];
    var $143 = __ZNK13JSCompartment9debugModeEv($142);
    if ($143) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $145 = __ZN2js7analyze14ScriptAnalysis16localsAliasStackEv($this);
    if ($145) {
      __label__ = 44;
      break;
    } else {
      var $offset_2 = 0;
      var $147 = $129;
      __label__ = 45;
      break;
    }
   case 44:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $129);
    __label__ = 53;
    break;
   case 45:
    var $147;
    var $offset_2;
    if ($offset_2 >>> 0 < HEAPU32[$147 + 8 >> 2] >>> 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 46:
    var $152 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($this, $offset_2);
    var $155 = HEAP32[$147 >> 2] + $offset_2 | 0;
    if (($152 | 0) == 0) {
      var $_pre2 = $147;
      __label__ = 51;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    if (HEAP8[$155] << 24 >> 24 == 9) {
      __label__ = 48;
      break;
    } else {
      var $_pre2 = $147;
      __label__ = 51;
      break;
    }
   case 48:
    __ZN2js15TempAllocPolicyC1EP9JSContext($4, $cx);
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_($seen, $4);
    __ZN2js7analyze8SSAValue11PushedValueEjj($5, $offset_2, 0);
    var $161 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $5, $seen);
    if ($161) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $162 = HEAP32[$12 >> 2];
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $162);
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($seen);
    __label__ = 53;
    break;
   case 50:
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($seen);
    var $_pre2 = HEAP32[$12 >> 2];
    __label__ = 51;
    break;
   case 51:
    var $_pre2;
    var $165 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($155);
    var $offset_2 = $165 + $offset_2 | 0;
    var $147 = $_pre2;
    __label__ = 45;
    break;
   case 52:
    var $168 = $147 + 38 | 0;
    var $170 = HEAP8[$168] | 1;
    HEAP8[$168] = $170;
    __label__ = 53;
    break;
   case 53:
    __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev($state);
    __label__ = 54;
    break;
   case 54:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext["X"] = 1;

function __ZNK8JSScript16hasClearedGlobalEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$this + 100 >> 2] + 8 >> 2];
    if (($4 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js12GlobalObject9isClearedEv($4);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19DetachNestingParentP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK8JSScript7nestingEv($1);
    if (($2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    var $10 = __ZNK8JSScript7nestingEv($9);
    var $11 = $10 + 4 | 0;
    var $pscript_023 = HEAP32[$11 >> 2];
    var $12 = __ZNK8JSScript7nestingEv($pscript_023);
    if (($12 | 0) == ($2 | 0)) {
      var $pscript_0_in_lcssa = $11;
      __label__ = 5;
      break;
    } else {
      var $14 = $12;
      __label__ = 4;
      break;
    }
   case 4:
    var $14;
    var $15 = $14 + 8 | 0;
    var $pscript_02 = HEAP32[$15 >> 2];
    var $16 = __ZNK8JSScript7nestingEv($pscript_02);
    if (($16 | 0) == ($2 | 0)) {
      var $pscript_0_in_lcssa = $15;
      __label__ = 5;
      break;
    } else {
      var $14 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    var $pscript_0_in_lcssa;
    var $19 = HEAP32[$2 + 8 >> 2];
    HEAP32[$pscript_0_in_lcssa >> 2] = $19;
    HEAP32[$2 >> 2] = 0;
    if ((HEAP8[$script + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN8JSScript12clearNestingEv($script);
    __label__ = 7;
    break;
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext($this, $cx) {
  __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7analyzeL17GetBytecodeLengthEPh1712($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU8[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) | 0];
    if ($4 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $4 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $9 = __Z28js_GetVariableBytecodeLengthPh($pc);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $v, $seen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE(undef, $v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv($seen);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $3 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj($seen, $i_0);
    var $8 = __ZNK2js7analyze8SSAValue6equalsERKS1_($v, $7);
    if ($8) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $12 = $v;
    var $13 = $1;
    var $14$0 = HEAP32[$12 >> 2];
    var $14$1 = HEAP32[$12 + 4 >> 2];
    HEAP32[$13 >> 2] = $14$0;
    HEAP32[$13 + 4 >> 2] = $14$1;
    var $15 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($seen, $1);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($19, $cx);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 8:
    var $21 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($this, $v);
    var $use_0_in = $21;
    __label__ = 9;
    break;
   case 9:
    var $use_0_in;
    var $use_0 = HEAP32[$use_0_in >> 2];
    if (($use_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $use_0, $seen);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $use_0_in = $use_0 + 8 | 0;
    __label__ = 9;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue11PushedValueEjj($agg_result, $offset, $index) {
  __ZN2js7analyze8SSAValue10initPushedEjj($agg_result, $offset, $index);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev($this) {
  __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev($this);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 3) | 0;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $t;
    var $11 = $1;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE($this, $cx, $use, $seen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    if ((HEAP8[$use | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAPU32[$use >> 2] >>> 1;
    var $15 = HEAP32[$use + 4 >> 2];
    __ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE($1, $12, $15);
    var $16 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $1, $seen);
    var $_0 = $16;
    __label__ = 10;
    break;
   case 3:
    var $19 = HEAPU32[$this >> 2];
    var $22 = $use;
    var $24 = HEAPU32[$22 >> 2] >>> 1;
    var $25 = HEAP32[$19 >> 2] + $24 | 0;
    var $26 = HEAP8[$25];
    if ($26 << 24 >> 24 == 55) {
      __label__ = 4;
      break;
    } else if ($26 << 24 >> 24 == 87) {
      __label__ = 5;
      break;
    } else if ($26 << 24 >> 24 == 86) {
      __label__ = 8;
      break;
    } else if ($26 << 24 >> 24 == 81 || $26 << 24 >> 24 == 11 || $26 << 24 >> 24 == -36) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    if ((HEAP32[$use + 4 >> 2] | 0) == 1) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $32 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($19, $25);
    var $33 = __ZN2js7analyze14ScriptAnalysis9trackSlotEj($this, $32);
    if ($33) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    __ZN2js7analyze8SSAValue11PushedValueEjj($2, $24, 0);
    var $35 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $2, $seen);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $38 = HEAPU32[$22 >> 2] >>> 1;
    __ZN2js7analyze8SSAValue10WrittenVarEjj($3, $32, $38);
    var $39 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $3, $seen);
    var $_0 = $39;
    __label__ = 10;
    break;
   case 8:
    __ZN2js7analyze8SSAValue11PushedValueEjj($4, $24, 0);
    var $41 = __ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE($this, $cx, $4, $seen);
    var $_0 = $41;
    __label__ = 10;
    break;
   case 9:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE($agg_result, $offset, $node) {
  __ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE($agg_result, $offset, $node);
  return;
}

function __ZN2js7analyze8SSAValue10WrittenVarEjj($agg_result, $slot, $offset) {
  __ZN2js7analyze8SSAValue11initWrittenEjj($agg_result, $slot, $offset);
  return;
}

function __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($this, $cx) {
  __ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7analyze17AutoEnterAnalysisD1Ev($this) {
  __ZN2js7analyze17AutoEnterAnalysisD2Ev($this);
  return;
}

function __ZN2js5types23MarkIteratorUnknownSlowEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $untrap = __stackBase__ + 4;
    var $enter = __stackBase__ + 12;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 24;
    var $3 = $cx + 60 | 0;
    var $4 = __ZNK2js12ContextStack13currentScriptEPPh($3, $pc);
    if (($4 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$pc >> 2];
    if (($7 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $4, $7);
    if (HEAP8[HEAP32[$pc >> 2]] << 24 >> 24 == 75) {
      __label__ = 4;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $14 = $4 + 100 | 0;
    var $result_0_in = HEAP32[$14 >> 2] + 16 | 0;
    __label__ = 5;
    break;
   case 5:
    var $result_0_in;
    var $result_0 = HEAP32[$result_0_in >> 2];
    if (($result_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$result_0 >> 2] | 0) == -1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $result_0_in = $result_0 + 8 | 0;
    __label__ = 5;
    break;
   case 8:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $26 = __ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_($cx, -1, $1);
    if (($26 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($31, $cx);
    __label__ = 21;
    break;
   case 10:
    var $35 = HEAP32[HEAP32[$14 >> 2] + 16 >> 2];
    HEAP32[$26 + 8 >> 2] = $35;
    var $38 = HEAP32[$14 >> 2] + 16 | 0;
    HEAP32[$38 >> 2] = $26;
    var $39 = __ZN8JSScript11hasAnalysisEv($4);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 11:
    var $41 = __ZN8JSScript8analysisEv($4);
    var $42 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($41);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 12:
    var $43 = $4 + 8 | 0;
    if ((HEAP32[$43 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = $4 | 0;
    var $i_01 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_01;
    var $48 = HEAP32[$46 >> 2] + $i_01 | 0;
    var $49 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($41, $48);
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $52 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705($4, $48);
    if (($52 | 0) == 77) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $55 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($41, $48, 0);
    __ZN2js5types4Type11UnknownTypeEv($2);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($55, $cx, $2);
    __label__ = 17;
    break;
   case 17:
    var $56 = $i_01 + 1 | 0;
    if ($56 >>> 0 < HEAPU32[$43 >> 2] >>> 0) {
      var $i_01 = $56;
      __label__ = 14;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP8[$4 + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = __ZNK8JSScript8functionEv($4);
    var $65 = $64 | 0;
    var $66 = __ZNK8JSObject11hasLazyTypeEv($65);
    if ($66) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $68 = __ZNK8JSObject4typeEv($65);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $68, 0, 1);
    __label__ = 21;
    break;
   case 21:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 22;
    break;
   case 22:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __label__ = 23;
    break;
   case 23:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types23MarkIteratorUnknownSlowEP9JSContext["X"] = 1;

function __ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_($this, $p1, $p2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p2;
  $p2 = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p2 >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 12);
    if (($2 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $7 = HEAP32[$p2 >> 2];
    HEAP32[$1 >> 2] = $7;
    __ZN2js5types10TypeResultC1EjNS0_4TypeE($5, $p1, $1);
    var $10 = $5;
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb($cx, $callee, $args, $constructing) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($callee);
    var $4 = HEAPU16[$2 + 56 >> 1];
    var $5 = $4 & 65535;
    var $6 = __ZNK10JSFunction6scriptEv($2);
    if ($constructing) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $args | 0;
    var $9 = __ZNK2js12CallReceiver5thisvEv($8);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $6, $9);
    __label__ = 3;
    break;
   case 3:
    var $10 = __ZNK2js8CallArgs4argcEv($args);
    if (($10 | 0) != 0 & $4 << 16 >> 16 != 0) {
      var $arg_03 = 0;
      __label__ = 5;
      break;
    } else {
      var $arg_0_lcssa = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $arg_0_lcssa;
    if ($arg_0_lcssa >>> 0 < $5 >>> 0) {
      var $arg_11 = $arg_0_lcssa;
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $arg_03;
    var $14 = __ZNK2js8CallArgsixEj($args, $arg_03);
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $6, $arg_03, $14);
    var $15 = $arg_03 + 1 | 0;
    var $16 = __ZNK2js8CallArgs4argcEv($args);
    if ($15 >>> 0 < $16 >>> 0 & $15 >>> 0 < $5 >>> 0) {
      var $arg_03 = $15;
      __label__ = 5;
      break;
    } else {
      var $arg_0_lcssa = $15;
      __label__ = 4;
      break;
    }
   case 6:
    var $arg_11;
    __ZN2JSL14UndefinedValueEv1713($1);
    __ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE($cx, $6, $arg_11, $1);
    var $19 = $arg_11 + 1 | 0;
    if (($19 | 0) == ($5 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $arg_11 = $19;
      __label__ = 6;
      break;
    }
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $script, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($1, undef, $value);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($cx, $script, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1713($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $untrap = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 28;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 36;
    var $7 = __stackBase__ + 40;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $pc);
    var $9 = HEAPU8[$pc] & 255;
    var $11 = HEAPU32[_js_CodeSpec + ($9 << 3) + 4 >> 2];
    if (($11 & 67108864 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($19, $cx);
    __label__ = 29;
    break;
   case 4:
    var $21 = __ZN8JSScript8analysisEv($script);
    var $22 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($21, $pc);
    var $24 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $24;
    var $26 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($22, $1);
    if ($26) {
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$2 >> 2] = $24;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($22, $cx, $2);
    __label__ = 29;
    break;
   case 6:
    if (($11 & 3072 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($9 - 97 | 0) >>> 0 < 8) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $34 = __ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709($script, $pc);
    var $35 = __ZN2js7analyzeL10TotalSlotsEP8JSScript1710($script);
    if ($34 >>> 0 < $35 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $38 = __ZN2js5types10TypeScript9SlotTypesEP8JSScriptj($script, $34);
    var $40 = HEAP32[$type >> 2];
    HEAP32[$3 >> 2] = $40;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($38, $cx, $3);
    __label__ = 10;
    break;
   case 10:
    var $43 = __ZN8JSScript11hasAnalysisEv($script);
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $45 = __ZN8JSScript8analysisEv($script);
    var $46 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($45);
    if ($46) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $48 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($45, $pc, 0);
    var $50 = HEAPU32[$type >> 2];
    HEAP32[$4 >> 2] = $50;
    var $52 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($48, $4);
    if ($52) {
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $82 = $50;
    var $_pre_phi = $script | 0;
    var $_pre_phi3 = $pc;
    __label__ = 21;
    break;
   case 14:
    var $55 = HEAP32[$script + 100 >> 2] + 16 | 0;
    var $56 = $script | 0;
    var $57 = $pc;
    var $59 = HEAPU32[$type >> 2];
    var $60 = $5 | 0;
    var $presult_0 = $55;
    __label__ = 15;
    break;
   case 15:
    var $presult_0;
    var $62 = HEAP32[$presult_0 >> 2];
    if (($62 | 0) == 0) {
      var $82 = $59;
      var $_pre_phi = $56;
      var $_pre_phi3 = $57;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$62 >> 2] | 0) == ($57 - HEAP32[$56 >> 2] | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $72 = $62 + 4 | 0;
    HEAP32[$60 >> 2] = $59;
    var $73 = __ZNK2js5types4TypeeqES1_($72, $5);
    if ($73) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    if (($presult_0 | 0) == ($55 | 0)) {
      __label__ = 29;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $77 = $62 + 8 | 0;
    var $78 = HEAP32[$77 >> 2];
    HEAP32[$presult_0 >> 2] = $78;
    var $79 = HEAP32[$55 >> 2];
    HEAP32[$77 >> 2] = $79;
    HEAP32[$55 >> 2] = $62;
    __label__ = 29;
    break;
   case 20:
    var $presult_0 = $62 + 8 | 0;
    __label__ = 15;
    break;
   case 21:
    var $_pre_phi3;
    var $_pre_phi;
    var $82;
    var $85 = $_pre_phi3 - HEAP32[$_pre_phi >> 2] | 0;
    HEAP32[$6 >> 2] = $82;
    var $87 = __ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_($cx, $85, $6);
    if (($87 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $92 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($92, $cx);
    __label__ = 29;
    break;
   case 23:
    var $94 = $script + 100 | 0;
    var $97 = HEAP32[HEAP32[$94 >> 2] + 16 >> 2];
    var $98 = $87 + 8 | 0;
    HEAP32[$98 >> 2] = $97;
    var $100 = HEAP32[$94 >> 2] + 16 | 0;
    HEAP32[$100 >> 2] = $87;
    var $101 = __ZN8JSScript11hasAnalysisEv($script);
    if ($101) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $103 = __ZN8JSScript8analysisEv($script);
    var $104 = __ZN2js7analyze14ScriptAnalysis12ranInferenceEv($103);
    if ($104) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $106 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($103, $pc, 0);
    HEAP32[$7 >> 2] = $82;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($106, $cx, $7);
    __label__ = 26;
    break;
   case 26:
    if ((HEAP8[$script + 37 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $114 = __ZNK8JSScript8functionEv($script);
    var $115 = $114 | 0;
    var $116 = __ZNK8JSObject11hasLazyTypeEv($115);
    if ($116) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $118 = __ZNK8JSObject4typeEv($115);
    __ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb($cx, $118, 0, 1);
    __label__ = 29;
    break;
   case 29:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE["X"] = 1;

function __ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_($this, $p1, $p2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p2;
  $p2 = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p2 >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 12);
    if (($2 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $7 = HEAP32[$p2 >> 2];
    HEAP32[$1 >> 2] = $7;
    __ZN2js5types10TypeResultC1EjNS0_4TypeE($5, $p1, $1);
    var $10 = $5;
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $untrap = __stackBase__;
    var $enter = __stackBase__ + 8;
    var $type = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 24;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $script, $pc);
    if ((HEAP32[_js_CodeSpec + ((HEAPU8[$pc] & 255) << 3) + 4 >> 2] & 67108864 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, 0);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($14, $cx);
    __label__ = 6;
    break;
   case 4:
    __ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE($type, undef, $rval);
    var $16 = __ZN8JSScript8analysisEv($script);
    var $17 = __ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh($16, $pc);
    var $19 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $19;
    var $21 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($17, $1);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$2 >> 2] = $19;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($17, $cx, $2);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 7;
    break;
   case 7:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $script, $scope) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 100 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    if ((HEAP8[$script + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $2 + 8 | 0;
    HEAP32[$10 >> 2] = 0;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 3:
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $4;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $_in = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = $scope;
    var $18 = __ZNK8JSObject9getGlobalEv($17);
    var $_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $_in;
    var $21 = $2 + 8 | 0;
    HEAP32[$21 >> 2] = $_in;
    var $22 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 7:
    var $25 = HEAP8[$script + 37 | 0];
    if (($25 & 32) << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZNK10JSFunction13isNullClosureEv($4);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $scope;
    var $31 = __ZNK8JSObject6isCallEv($30);
    if ($31) {
      var $_01_lcssa = $scope;
      var $_lcssa = $30;
      __label__ = 14;
      break;
    } else {
      var $_013 = $scope;
      __label__ = 13;
      break;
    }
   case 10:
    if (($25 & 16) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($cx);
    var $38 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$38 >> 2] = $36;
    if ((HEAP32[HEAP32[$1 >> 2] + 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = 1;
    __label__ = 22;
    break;
   case 13:
    var $_013;
    var $44 = __ZNK8JSObject9getParentEv($_013);
    var $45 = $44;
    var $46 = __ZNK8JSObject6isCallEv($45);
    if ($46) {
      var $_01_lcssa = $44;
      var $_lcssa = $45;
      __label__ = 14;
      break;
    } else {
      var $_013 = $44;
      __label__ = 13;
      break;
    }
   case 14:
    var $_lcssa;
    var $_01_lcssa;
    var $47 = __ZN8JSObject6asCallEv($_01_lcssa);
    var $48 = $47;
    var $49 = __ZNK2js10CallObject17getCalleeFunctionEv($48);
    if (($49 | 0) == 0) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $52 = __ZNK10JSFunction13isHeavyweightEv($49);
    if ($52) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 16:
    var $54 = __ZNK10JSFunction6scriptEv($49);
    var $55 = __ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction($54, $cx, $49);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 17:
    var $58 = HEAP32[$54 + 100 >> 2];
    var $59 = __ZN2js5types10TypeScript8hasScopeEv($58);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $61 = __ZNK8JSObject9getParentEv($_01_lcssa);
    var $62 = __ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject($cx, $54, $61);
    if ($62) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $64 = $54;
    var $65 = __ZNK8JSScript7nestingEv($64);
    HEAP32[$65 + 12 >> 2] = $_lcssa;
    var $67 = __ZN2js10CallObject8argArrayEv($48);
    var $68 = __ZNK8JSScript7nestingEv($64);
    HEAP32[$68 + 16 >> 2] = $67;
    var $70 = __ZN2js10CallObject8varArrayEv($48);
    var $71 = __ZNK8JSScript7nestingEv($64);
    HEAP32[$71 + 20 >> 2] = $70;
    __label__ = 20;
    break;
   case 20:
    var $74 = __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($cx);
    var $76 = HEAP32[$1 >> 2] + 12 | 0;
    HEAP32[$76 >> 2] = $74;
    if ((HEAP32[HEAP32[$1 >> 2] + 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $82 = $script;
    var $83 = __ZNK8JSScript7nestingEv($82);
    var $_c = $54;
    HEAP32[$83 >> 2] = $_c;
    var $85 = __ZNK8JSScript7nestingEv($_c);
    var $87 = HEAP32[$85 + 4 >> 2];
    var $88 = __ZNK8JSScript7nestingEv($82);
    HEAP32[$88 + 8 >> 2] = $87;
    var $90 = __ZNK8JSScript7nestingEv($_c);
    HEAP32[$90 + 4 >> 2] = $82;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject["X"] = 1;

function __ZNK10JSFunction13isNullClosureEv($this) {
  var $1 = __ZNK10JSFunction4kindEv($this);
  return $1 << 16 >> 16 == -16384;
}

function __ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 28);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js5types17TypeScriptNestingC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17TypeScriptNestingD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = __ZNK8JSScript7nestingEv($5);
    var $7 = $6 + 4 | 0;
    var $pscript_023 = HEAP32[$7 >> 2];
    var $8 = __ZNK8JSScript7nestingEv($pscript_023);
    if (($8 | 0) == ($this | 0)) {
      var $pscript_0_in_lcssa = $7;
      __label__ = 4;
      break;
    } else {
      var $11 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $11;
    var $12 = $11 + 8 | 0;
    var $pscript_02 = HEAP32[$12 >> 2];
    var $13 = __ZNK8JSScript7nestingEv($pscript_02);
    if (($13 | 0) == ($this | 0)) {
      var $pscript_0_in_lcssa = $12;
      __label__ = 4;
      break;
    } else {
      var $11 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    var $pscript_0_in_lcssa;
    var $_c = HEAP32[$this + 8 >> 2];
    HEAP32[$pscript_0_in_lcssa >> 2] = $_c;
    __label__ = 5;
    break;
   case 5:
    var $18 = $this + 4 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $19;
      __label__ = 6;
      break;
    }
   case 6:
    var $21;
    var $23 = __ZNK8JSScript7nestingEv($21);
    var $24 = $23 + 8 | 0;
    var $26 = HEAP32[$24 >> 2];
    HEAP32[$18 >> 2] = $26;
    HEAP32[$23 >> 2] = 0;
    HEAP32[$24 >> 2] = 0;
    var $28 = HEAP32[$18 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $28;
      __label__ = 6;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types18ClearActiveNestingEP8JSScript($start) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $traverseChildren_0_ph = 0;
    var $script_0_ph = $start;
    __label__ = 2;
    break;
   case 2:
    var $script_0_ph;
    var $traverseChildren_0_ph;
    var $script_0 = $script_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $script_0;
    var $3 = __ZNK8JSScript7nestingEv($script_0);
    var $5 = HEAP32[$3 + 4 >> 2];
    var $6 = $5;
    if (($5 | 0) == 0 | $traverseChildren_0_ph) {
      __label__ = 4;
      break;
    } else {
      var $script_0 = $6;
      __label__ = 3;
      break;
    }
   case 4:
    if ((HEAP32[$3 + 24 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    if ((HEAP8[$script_0 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$3 + 12 >> 2] = 0;
    HEAP32[$3 + 16 >> 2] = 0;
    HEAP32[$3 + 20 >> 2] = 0;
    __label__ = 7;
    break;
   case 7:
    if (($script_0 | 0) == ($start | 0)) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAP32[$3 + 8 >> 2];
    if (($25 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $traverseChildren_0_ph = 0;
    var $script_0_ph = $25;
    __label__ = 2;
    break;
   case 10:
    var $traverseChildren_0_ph = 1;
    var $script_0_ph = HEAP32[$3 >> 2];
    __label__ = 2;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($fp);
    var $2 = __ZNK10JSFunction6scriptEv($1);
    var $3 = $2;
    var $4 = __ZNK8JSScript7nestingEv($3);
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript($cx, $9, $2);
    __label__ = 3;
    break;
   case 3:
    if ((HEAP8[$2 + 37 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js5types18ClearActiveNestingEP8JSScript($2);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $2 + 38 | 0;
    var $20 = HEAP8[$18] | 8;
    HEAP8[$18] = $20;
    var $21 = __ZNK2js10StackFrame3funEv($fp);
    var $22 = $21 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $22, 8388608);
    __label__ = 6;
    break;
   case 6:
    var $24 = $fp;
    var $25 = __ZNK2js10StackFrame7callObjEv($24);
    HEAP32[$4 + 12 >> 2] = $25 | 0;
    var $27 = __ZNK2js10StackFrame10formalArgsEv($fp);
    HEAP32[$4 + 16 >> 2] = $27;
    var $29 = __ZNK2js10StackFrame5slotsEv($24);
    HEAP32[$4 + 20 >> 2] = $29;
    __label__ = 7;
    break;
   case 7:
    var $32 = $4 + 24 | 0;
    var $34 = HEAP32[$32 >> 2] + 1 | 0;
    HEAP32[$32 >> 2] = $34;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript($cx, $scope, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $script;
    var $_01 = $scope;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_0;
    var $3 = __ZNK8JSScript7nestingEv($_0);
    var $5 = HEAP32[$3 >> 2];
    var $_1 = $_01;
    __label__ = 3;
    break;
   case 3:
    var $_1;
    var $8 = __ZNK8JSObject6isCallEv($_1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject6asCallEv($_1);
    var $11 = $10;
    var $12 = __ZNK2js10CallObject17getCalleeFunctionEv($11);
    var $13 = __ZNK10JSFunction6scriptEv($12);
    if (($13 | 0) == ($5 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK8JSObject9getParentEv($_1);
    var $_1 = $15;
    __label__ = 3;
    break;
   case 6:
    var $17 = $5;
    var $18 = __ZNK8JSScript7nestingEv($17);
    if (($_1 | 0) == (HEAP32[$18 + 12 >> 2] | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $5 + 38 | 0;
    var $26 = HEAP8[$24] | 8;
    HEAP8[$24] = $26;
    var $27 = __ZNK8JSScript8functionEv($5);
    var $28 = $27 | 0;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($cx, $28, 8388608);
    var $29 = __ZNK8JSScript7nestingEv($17);
    if ((HEAP32[$29 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZNK8JSObject9getParentEv($_1);
    var $_0 = $5;
    var $_01 = $34;
    __label__ = 2;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15NestingEpilogueEPNS_10StackFrameE($fp) {
  var $1 = __ZNK2js10StackFrame3funEv($fp);
  var $2 = __ZNK10JSFunction6scriptEv($1);
  var $3 = $2;
  var $4 = __ZNK8JSScript7nestingEv($3);
  var $5 = $4 + 24 | 0;
  var $7 = HEAP32[$5 >> 2] - 1 | 0;
  HEAP32[$5 >> 2] = $7;
  return;
}

function __ZN2js2gc12EmptyArenaOpEPNS0_5ArenaE($arena) {
  return;
}

function _JSID_IS_STRING1730($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING1731($iden) {
  return $iden;
}

function __ZNK8JSObject18hasSpecialEqualityEv($this) {
  return (HEAP32[$this + 8 >> 2] & 2048 | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN8JSScript9makeTypesEP9JSContextP10JSFunction($this, $cx, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN9JSContext7calloc_Ej($cx, 20);
    var $4 = $3;
    HEAP32[$this + 100 >> 2] = $4;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types10TypeScriptC1EP10JSFunction($4, $fun);
    var $_1 = 1;
    __label__ = 10;
    break;
   case 4:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    if (($fun | 0) == 0) {
      var $15 = 2;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = (HEAPU16[$fun + 56 >> 1] & 65535) + 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $25 = ((HEAPU16[$this + 14 >> 1] & 65535) + $15 + (HEAPU16[$this + 22 >> 1] & 65535)) * 12 + 20 | 0;
    var $26 = __ZN9JSContext7calloc_Ej($cx, $25);
    var $27 = $26;
    HEAP32[$this + 100 >> 2] = $27;
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($33, $cx);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js5types10TypeScriptC1EP10JSFunction($27, $fun);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = $_0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScriptC1EP10JSFunction($this, $fun) {
  __ZN2js5types10TypeScriptC2EP10JSFunction($this, $fun);
  return;
}

function __ZN8JSScript12makeAnalysisEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext($enter, $cx);
    var $4 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    HEAP32[$1 >> 2] = $this;
    var $5 = __ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_($4, $1);
    var $6 = $this + 100 | 0;
    var $8 = HEAP32[$6 >> 2] | 0;
    HEAP32[$8 >> 2] = $5;
    var $11 = HEAP32[HEAP32[$6 >> 2] >> 2];
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext($11, $cx);
    var $15 = HEAP32[$6 >> 2] | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = __ZN2js7analyze14ScriptAnalysis3OOMEv($16);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$15 >> 2] = 0;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js7analyze17AutoEnterAnalysisD1Ev($enter);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 40 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN2js7analyze14ScriptAnalysisC1EP8JSScript($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($this, $cx, $fun, $singleton) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 37 | 0;
    var $2 = HEAP8[$1];
    var $3 = $2 | 4;
    HEAP8[$1] = $3;
    var $4 = __ZNK10JSFunction13isHeavyweightEv($fun);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $2 | 12;
    HEAP8[$1] = $6;
    __label__ = 3;
    break;
   case 3:
    var $8 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    if ($singleton) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = $fun;
    var $12 = $cx;
    var $13 = __ZN8JSObject16setSingletonTypeEP9JSContext($11, $12);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $15 = $fun | 0;
    var $16 = __ZNK8JSObject8getProtoEv($15);
    var $17 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, 2, $16, 0);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($15, $17);
    HEAP32[$17 + 28 >> 2] = $fun;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21shouldSplicePrototypeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8getProtoEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK8JSObject16hasSingletonTypeEv($this);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15splicePrototypeEP9JSContextPS_($this, $cx, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = $this;
    var $2 = $cx;
    var $3 = __ZN8JSObject7getTypeEP9JSContext($1, $2);
    var $4 = $3;
    var $5 = ($proto | 0) != 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $protoType_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $proto;
    var $8 = __ZN8JSObject7getTypeEP9JSContext($7, $2);
    var $9 = $8;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      var $protoType_0 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $protoType_0;
    var $13 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($5) {
      __label__ = 5;
      break;
    } else {
      var $18 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      var $18 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $18;
    HEAP32[$this + 36 >> 2] = $18;
    var $_1 = 1;
    __label__ = 18;
    break;
   case 7:
    HEAP32[$3 >> 2] = $proto;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    if (($protoType_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = __ZN2js5types10TypeObject17unknownPropertiesEv($protoType_0);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = __ZN2js5types10TypeObject17unknownPropertiesEv($4);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($4, $cx);
    __label__ = 17;
    break;
   case 11:
    var $29 = __ZN2js5types10TypeObject17unknownPropertiesEv($4);
    if ($29) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $31 = __ZN2js5types10TypeObject16getPropertyCountEv($4);
    if (($31 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $i_01;
    var $33 = __ZN2js5types10TypeObject11getPropertyEj($4, $i_01);
    if (($33 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = $33 + 4 | 0;
    var $37 = __ZN2js5types7TypeSet21hasPropagatedPropertyEv($36);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $40 = HEAP32[$33 >> 2];
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($4, $cx, $40, $36, 1);
    __label__ = 16;
    break;
   case 16:
    var $42 = $i_01 + 1 | 0;
    if (($42 | 0) == ($31 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $i_01 = $42;
      __label__ = 13;
      break;
    }
   case 17:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    var $_1 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject15splicePrototypeEP9JSContextPS_["X"] = 1;

function __ZN8JSObject12makeLazyTypeEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $1 = __ZNK8JSObject8getProtoEv($this);
    var $2 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, 1, $1, 0);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($7, $cx);
    __label__ = 22;
    break;
   case 3:
    HEAP32[$2 + 4 >> 2] = $this;
    var $10 = __ZNK8JSObject10isFunctionEv($this);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($this);
    if (($12 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK10JSFunction13isInterpretedEv($12);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    HEAP32[$2 + 28 >> 2] = $12;
    var $18 = __ZNK10JSFunction6scriptEv($12);
    var $19 = $18 + 38 | 0;
    var $20 = HEAP8[$19];
    if (($20 & 2) << 24 >> 24 == 0) {
      var $28 = $20;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $2 + 12 | 0;
    var $26 = HEAP32[$24 >> 2] | 524288;
    HEAP32[$24 >> 2] = $26;
    var $28 = HEAP8[$19];
    __label__ = 8;
    break;
   case 8:
    var $28;
    if (($28 & 4) << 24 >> 24 == 0) {
      var $36 = $28;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $2 + 12 | 0;
    var $34 = HEAP32[$32 >> 2] | 1048576;
    HEAP32[$32 >> 2] = $34;
    var $36 = HEAP8[$19];
    __label__ = 10;
    break;
   case 10:
    var $36;
    if (($36 & 8) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = $2 + 12 | 0;
    var $42 = HEAP32[$40 >> 2] | 8388608;
    HEAP32[$40 >> 2] = $42;
    __label__ = 12;
    break;
   case 12:
    var $44 = $this + 8 | 0;
    if ((HEAP32[$44 >> 2] & 32768 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = $2 + 12 | 0;
    var $51 = HEAP32[$49 >> 2] | 4194304;
    HEAP32[$49 >> 2] = $51;
    __label__ = 14;
    break;
   case 14:
    var $53 = __ZNK8JSObject5isXMLEv($this);
    if ($53) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $55 = __ZN2js5types10TypeObject17unknownPropertiesEv($2);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js5types10TypeObject11markUnknownEP9JSContext($2, $cx);
    __label__ = 17;
    break;
   case 17:
    if ((HEAP32[HEAP32[$this + 4 >> 2] + 68 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = $2 + 12 | 0;
    var $66 = HEAP32[$64 >> 2] | 2097152;
    HEAP32[$64 >> 2] = $66;
    __label__ = 19;
    break;
   case 19:
    var $68 = __ZN2js5types10TypeObject17unknownPropertiesEv($2);
    if ($68) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$this + 36 >> 2] = $2;
    var $72 = HEAP32[$44 >> 2] & -131073;
    HEAP32[$44 >> 2] = $72;
    __label__ = 22;
    break;
   case 21:
    var $74 = $2 + 12 | 0;
    var $76 = HEAP32[$74 >> 2] | 458752;
    HEAP32[$74 >> 2] = $76;
    HEAP32[$this + 36 >> 2] = $2;
    var $79 = HEAP32[$44 >> 2] & -131073;
    HEAP32[$44 >> 2] = $79;
    __label__ = 22;
    break;
   case 22:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject12makeLazyTypeEP9JSContext["X"] = 1;

function __ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb($this, $cx, $fun, $unknown) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $enter = __stackBase__;
    var $1 = __ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb(undef, $cx, undef, 1, $this, $unknown);
    if (($1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$this + 16 >> 2] = $1;
    __ZN8JSObject11setDelegateEv($this);
    var $5 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $7 = __ZNK8JSObject18hasSpecialEqualityEv($this);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $1 + 12 | 0;
    var $11 = HEAP32[$9 >> 2] | 2097152;
    HEAP32[$9 >> 2] = $11;
    __label__ = 5;
    break;
   case 5:
    if (($fun | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction($cx, $1, $fun);
    __label__ = 7;
    break;
   case 7:
    var $16 = __ZNK8JSObject5isXMLEv($this);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZN2js5types10TypeObject17unknownPropertiesEv($1);
    if ($18) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = $1 + 12 | 0;
    var $22 = HEAP32[$20 >> 2] | 33488904;
    HEAP32[$20 >> 2] = $22;
    __label__ = 10;
    break;
   case 10:
    if ((HEAP32[HEAP32[$this + 4 >> 2] + 68 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $30 = $1 + 12 | 0;
    var $32 = HEAP32[$30 >> 2] | 2097152;
    HEAP32[$30 >> 2] = $32;
    __label__ = 12;
    break;
   case 12:
    var $34 = __ZN2js5types10TypeObject17unknownPropertiesEv($1);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $36 = $1 + 12 | 0;
    var $38 = HEAP32[$36 >> 2] | 8;
    HEAP32[$36 >> 2] = $38;
    __label__ = 14;
    break;
   case 14:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb["X"] = 1;

function __Z16SweepTypeObjectsP9JSContextP13JSCompartment($cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN17SweepTypeObjectOpC1EP9JSContext($1, $cx);
  __ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_($compartment, 15, 138, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN17SweepTypeObjectOpC1EP9JSContext($this, $cx) {
  __ZN17SweepTypeObjectOpC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_($compartment, $thingKind, $arenaOp, $cellOp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $cellOp;
  $cellOp = STACKTOP;
  STACKTOP += 4;
  HEAP32[$cellOp >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $firstSpan = __stackBase__;
    var $1 = __ZN2js2gc5Arena9thingSizeENS0_9AllocKindE($thingKind);
    var $2 = $compartment + 8 | 0;
    var $3 = __ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE($2, $thingKind);
    if (($3 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $aheader_01;
    var $5 = __ZN2js2gc11ArenaHeader8getArenaEv($aheader_01);
    FUNCTION_TABLE[$arenaOp]($5);
    __ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv($firstSpan, $aheader_01);
    var $6 = __ZN2js2gc5Arena11thingsStartENS0_9AllocKindE($5, $thingKind);
    var $thing_0 = $6;
    var $span_0 = $firstSpan;
    __label__ = 3;
    break;
   case 3:
    var $span_0;
    var $thing_0;
    if (($thing_0 | 0) == (HEAP32[$span_0 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZNK2js2gc8FreeSpan7hasNextEv($span_0);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $15 = HEAP32[$span_0 + 4 >> 2];
    var $16 = __ZNK2js2gc8FreeSpan8nextSpanEv($span_0);
    var $thing_1 = $15;
    var $span_1 = $16;
    __label__ = 7;
    break;
   case 6:
    __ZN17SweepTypeObjectOpclEPN2js2gc4CellE($cellOp, $thing_0);
    var $thing_1 = $thing_0;
    var $span_1 = $span_0;
    __label__ = 7;
    break;
   case 7:
    var $span_1;
    var $thing_1;
    var $thing_0 = $thing_1 + $1 | 0;
    var $span_0 = $span_1;
    __label__ = 3;
    break;
   case 8:
    var $23 = HEAP32[$aheader_01 + 4 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $aheader_01 = $23;
      __label__ = 2;
      break;
    }
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15TypeCompartment5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $e1 = __stackBase__ + 16;
    var $e4 = __stackBase__ + 32;
    var $1 = __ZN2js5types15TypeCompartment11compartmentEv($this);
    __Z16SweepTypeObjectsP9JSContextP13JSCompartment($cx, $1);
    var $3 = HEAP32[$this + 32 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($e, $3);
    var $6 = $e | 0;
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e);
    __label__ = 10;
    break;
   case 4:
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($6);
    var $10 = HEAP32[$8 + 8 >> 2];
    var $11 = $8 | 0;
    var $12 = __ZNK2js5types4Type12isTypeObjectEv($11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = __ZNK2js5types4Type10typeObjectEv($11);
    var $15 = $14;
    var $16 = __ZNK2js2gc4Cell8isMarkedEj($15, 0);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $10;
    var $18 = __ZNK2js2gc4Cell8isMarkedEj($17, 0);
    __label__ = 8;
    break;
   case 7:
    var $20 = $10;
    var $21 = __ZNK2js2gc4Cell8isMarkedEj($20, 0);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e);
    __label__ = 9;
    break;
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($6);
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($6);
    if ($24) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 10:
    var $27 = HEAP32[$this + 36 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e1, $27);
    var $30 = $e1 | 0;
    var $31 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($30);
    if ($31) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e1);
    __label__ = 25;
    break;
   case 13:
    var $32 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($30);
    var $35 = HEAP32[$32 + 16 >> 2];
    var $36 = __ZNK2js2gc4Cell8isMarkedEj($35, 0);
    var $38 = $32 + 4 | 0;
    var $39 = $32 | 0;
    var $40 = $32 + 20 | 0;
    var $i_0 = 0;
    var $remove3_1 = $36 & 1 ^ 1;
    __label__ = 14;
    break;
   case 14:
    var $remove3_1;
    var $i_0;
    if (($remove3_1 & 1) << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ($i_0 >>> 0 < HEAPU32[$38 >> 2] >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 16:
    var $50 = HEAPU32[HEAP32[$39 >> 2] + ($i_0 << 2) >> 2];
    var $51 = _JSID_IS_STRING1730($50);
    if (($51 | 0) == 0) {
      var $remove3_2 = $remove3_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = _JSID_TO_STRING1731($50);
    var $55 = $54;
    var $56 = __ZNK2js2gc4Cell8isMarkedEj($55, 0);
    if ($56) {
      var $remove3_2 = $remove3_1;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $remove3_2 = 1;
    __label__ = 19;
    break;
   case 19:
    var $remove3_2;
    var $59 = HEAP32[$40 >> 2] + ($i_0 << 2) | 0;
    var $60 = __ZNK2js5types4Type12isTypeObjectEv($59);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      var $remove3_3 = $remove3_2;
      __label__ = 22;
      break;
    }
   case 20:
    var $62 = __ZNK2js5types4Type10typeObjectEv($59);
    var $63 = $62;
    var $64 = __ZNK2js2gc4Cell8isMarkedEj($63, 0);
    if ($64) {
      var $remove3_3 = $remove3_2;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $remove3_3 = 1;
    __label__ = 22;
    break;
   case 22:
    var $remove3_3;
    var $i_0 = $i_0 + 1 | 0;
    var $remove3_1 = $remove3_3;
    __label__ = 14;
    break;
   case 23:
    var $69 = HEAP32[$39 >> 2];
    __ZN2js10Foreground5free_EPv($69);
    var $71 = HEAP32[$40 >> 2];
    __ZN2js10Foreground5free_EPv($71);
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($e1);
    __label__ = 24;
    break;
   case 24:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($30);
    var $72 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($30);
    if ($72) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 25:
    var $75 = HEAP32[$this + 28 >> 2];
    if (($75 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($e4, $75);
    var $78 = $e4 | 0;
    var $79 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($78);
    if ($79) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($e4);
    __label__ = 32;
    break;
   case 28:
    var $80 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($78);
    var $82 = HEAP32[$80 + 8 >> 2];
    var $85 = HEAP32[$80 >> 2];
    var $86 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $85);
    if ($86) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $88 = $82;
    var $89 = __ZNK2js2gc4Cell8isMarkedEj($88, 0);
    if ($89) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($e4);
    __label__ = 31;
    break;
   case 31:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($78);
    var $92 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($78);
    if ($92) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 32:
    var $94 = $this + 40 | 0;
    var $95 = HEAP32[$94 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $98 = $95;
    __ZN9JSContext5free_EPv(undef, $98);
    __label__ = 34;
    break;
   case 34:
    HEAP32[$94 >> 2] = 0;
    HEAP32[$this + 48 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types15TypeCompartment5sweepEP9JSContext["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 28 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE($this, $cx, $source) {
  return;
}

function __ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb($this, $cx, $object, $force) {
  return;
}

function __ZN2js18ArenaAllocatedSizeERK11JSArenaPool($pool) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pool | 0) == 0) {
      var $res_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $res_01 = 0;
    var $a_02 = $pool | 0;
    __label__ = 3;
    break;
   case 3:
    var $a_02;
    var $res_01;
    var $8 = $res_01 - $a_02 + HEAP32[$a_02 + 8 >> 2] | 0;
    var $10 = HEAP32[$a_02 >> 2];
    if (($10 | 0) == 0) {
      var $res_0_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $res_01 = $8;
      var $a_02 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    var $res_0_lcssa;
    return $res_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13allocatedSizeEv($this) {
  return HEAP32[$this + 4 >> 2] * 28 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv($this) {
  return HEAP32[$this + 4 >> 2] << 4;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv($this) {
  return HEAP32[$this + 4 >> 2] << 4;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$rhs + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js5types15TypeCompartmentD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 40 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js10Foreground5free_EPv($5);
    __label__ = 3;
    break;
   case 3:
    var $8 = HEAP32[$this + 32 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($8);
    __label__ = 5;
    break;
   case 5:
    var $13 = HEAP32[$this + 36 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_($13);
    __label__ = 7;
    break;
   case 7:
    var $18 = HEAP32[$this + 28 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($18);
    __label__ = 9;
    break;
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($script);
    var $4 = $script + 100 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = __ZN2js5types10TypeScript9typeArrayEv($5);
    if (($3 | 0) == 0) {
      var $10 = $5;
      __label__ = 4;
      break;
    } else {
      var $i_02 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_02;
    var $8 = $6 + $i_02 * 12 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($8, $cx, $2);
    var $9 = $i_02 + 1 | 0;
    if (($9 | 0) == ($3 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_02 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    var $10 = HEAP32[$4 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $12 = $type | 0;
    var $presult_0_ph = $10 + 16 | 0;
    __label__ = 5;
    break;
   case 5:
    var $presult_0_ph;
    __label__ = 6;
    break;
   case 6:
    var $14 = HEAP32[$presult_0_ph >> 2];
    if (($14 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[$14 + 4 >> 2];
    HEAP32[$12 >> 2] = $18;
    var $19 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($19) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($21) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = __ZNK2js5types4Type8isObjectEv($type);
    if ($23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $25 = __ZNK2js5types4Type9objectKeyEv($type);
    var $26 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($25);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $29 = HEAP32[$14 + 8 >> 2];
    HEAP32[$presult_0_ph >> 2] = $29;
    __ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_(undef, $14);
    __label__ = 6;
    break;
   case 12:
    var $presult_0_ph = $14 + 8 | 0;
    __label__ = 5;
    break;
   case 13:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($this, $cx, $compartment) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objectCount = __stackBase__;
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    HEAP32[$objectCount >> 2] = $1;
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $5 = $this + 4 | 0;
    var $6 = HEAP32[$5 >> 2];
    __ZN2js5types7TypeSet12clearObjectsEv($this);
    HEAP32[$objectCount >> 2] = 0;
    if (($4 | 0) == 0) {
      var $22 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $compartment + 376 | 0;
    var $i_01 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_01;
    var $11 = HEAP32[$6 + ($i_01 << 2) >> 2];
    if (($11 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($11);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745($compartment, $5, $objectCount, $11);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$16 >> 2] = $11;
    __label__ = 9;
    break;
   case 8:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($8, $cx);
    __label__ = 9;
    break;
   case 9:
    var $21 = $i_01 + 1 | 0;
    if (($21 | 0) == ($4 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i_01 = $21;
      __label__ = 4;
      break;
    }
   case 10:
    var $22 = HEAP32[$objectCount >> 2];
    __label__ = 11;
    break;
   case 11:
    var $22;
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, $22);
    __label__ = 15;
    break;
   case 12:
    if (($1 | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $26 = $this + 4 | 0;
    var $28 = HEAP32[$26 >> 2];
    var $29 = __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($28);
    if ($29) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$26 >> 2] = 0;
    __ZN2js5types7TypeSet18setBaseObjectCountEj($this, 0);
    __label__ = 15;
    break;
   case 15:
    HEAP32[$this + 8 >> 2] = 0;
    var $33 = $this | 0;
    var $35 = HEAP32[$33 >> 2] & -131073;
    HEAP32[$33 >> 2] = $35;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment["X"] = 1;

function __ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE($key) {
  var $3 = $key & -2;
  var $4 = __ZNK2js2gc4Cell8isMarkedEj($3, 0);
  return $4 ^ 1;
}

function __ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7destroyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $6 = HEAP32[$4 + 8 >> 2];
    __ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_($4);
    HEAP32[$1 >> 2] = $6;
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 12 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($9);
    __label__ = 5;
    break;
   case 5:
    var $13 = $this;
    __ZN2js10Foreground5free_EPv($13);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types17TypeScriptNestingD2Ev($p);
    var $3 = $p;
    _js_free1736($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_GetTypeInferenceMemoryStats($cx, $compartment, $stats) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $e = __stackBase__ + 40;
    var $1 = $compartment + 344 | 0;
    var $2 = __ZN2js18ArenaAllocatedSizeERK11JSArenaPool($1);
    var $3$0 = $2;
    var $4 = $stats + 24 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6$0 = (i64Math.add($5$0, $5$1, $3$0, 0), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    HEAP32[$4 >> 2] = $6$0;
    HEAP32[$4 + 4 >> 2] = $6$1;
    var $10$0 = HEAP32[$compartment + 424 >> 2] * 12 | 0;
    var $11$0 = (i64Math.add($10$0, 0, $6$0, $6$1), i64Math.result[0]);
    var $11$1 = i64Math.result[1];
    HEAP32[$4 >> 2] = $11$0;
    HEAP32[$4 + 4 >> 2] = $11$1;
    __ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE($i, undef, $compartment, 13);
    var $12 = $i | 0;
    var $13 = __ZNK2js2gc12CellIterImpl4doneEv($12);
    if ($13) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js2gc8CellIterD1Ev($i);
    var $15 = HEAP32[$compartment + 404 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = __ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v($12);
    __ZL20GetScriptMemoryStatsP8JSScriptP24TypeInferenceMemoryStats($17, $stats);
    __ZN2js2gc12CellIterImpl4nextEv($12);
    var $18 = __ZNK2js2gc12CellIterImpl4doneEv($12);
    if ($18) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 4:
    var $20 = __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($15);
    var $21$0 = $20;
    var $22 = $stats + 16 | 0;
    var $st$4$0 = $22 | 0;
    var $23$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$4$1 >> 2];
    var $24$0 = (i64Math.add($23$0, $23$1, $21$0, 0), i64Math.result[0]);
    var $24$1 = i64Math.result[1];
    var $st$9$0 = $22 | 0;
    HEAP32[$st$9$0 >> 2] = $24$0;
    var $st$9$1 = $22 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $24$1;
    __label__ = 5;
    break;
   case 5:
    var $27 = HEAP32[$compartment + 408 >> 2];
    if (($27 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($27);
    var $31$0 = $30;
    var $32 = $stats + 16 | 0;
    var $st$4$0 = $32 | 0;
    var $33$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $32 + 4 | 0;
    var $33$1 = HEAP32[$st$4$1 >> 2];
    var $34$0 = (i64Math.add($33$0, $33$1, $31$0, 0), i64Math.result[0]);
    var $34$1 = i64Math.result[1];
    var $st$9$0 = $32 | 0;
    HEAP32[$st$9$0 >> 2] = $34$0;
    var $st$9$1 = $32 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $34$1;
    __label__ = 7;
    break;
   case 7:
    var $36 = $compartment + 412 | 0;
    var $37 = HEAP32[$36 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $40 = __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($37);
    var $41$0 = $40;
    var $42 = $stats + 16 | 0;
    var $st$4$0 = $42 | 0;
    var $43$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$4$1 >> 2];
    var $44$0 = (i64Math.add($43$0, $43$1, $41$0, 0), i64Math.result[0]);
    var $44$1 = i64Math.result[1];
    var $st$9$0 = $42 | 0;
    HEAP32[$st$9$0 >> 2] = $44$0;
    var $st$9$1 = $42 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $44$1;
    var $45 = HEAP32[$36 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_($e, $45);
    var $46 = $e | 0;
    var $47 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($46);
    if ($47) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev($e);
    __label__ = 11;
    break;
   case 10:
    var $48 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv($46);
    var $52$0 = HEAP32[$48 + 4 >> 2] << 3;
    var $53$0 = HEAP32[$42 >> 2];
    var $53$1 = HEAP32[$42 + 4 >> 2];
    var $54$0 = (i64Math.add($52$0, 0, $53$0, $53$1), i64Math.result[0]);
    var $54$1 = i64Math.result[1];
    HEAP32[$42 >> 2] = $54$0;
    HEAP32[$42 + 4 >> 2] = $54$1;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv($46);
    var $55 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv($46);
    if ($55) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 11:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetTypeInferenceMemoryStats["X"] = 1;

function __ZL20GetScriptMemoryStatsP8JSScriptP24TypeInferenceMemoryStats($script, $stats) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 100 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = __ZNK2js2gc4Cell11compartmentEv($5);
    if ((HEAP8[$6 + 376 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $stats | 0;
    var $st$1$0 = $12 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14$0 = (i64Math.add($13$0, $13$1, 20, 0), i64Math.result[0]);
    var $14$1 = i64Math.result[1];
    HEAP32[$12 >> 2] = $14$0;
    HEAP32[$12 + 4 >> 2] = $14$1;
    __label__ = 10;
    break;
   case 4:
    var $16 = __ZN2js5types10TypeScript11NumTypeSetsEP8JSScript($script);
    var $19$0 = $16 * 12 + 20 | 0;
    var $20 = $stats | 0;
    var $st$6$0 = $20 | 0;
    var $21$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$6$1 >> 2];
    var $22$0 = (i64Math.add($19$0, 0, $21$0, $21$1), i64Math.result[0]);
    var $22$1 = i64Math.result[1];
    HEAP32[$20 >> 2] = $22$0;
    HEAP32[$20 + 4 >> 2] = $22$1;
    var $23 = HEAP32[$1 >> 2];
    var $result_02 = HEAP32[$23 + 16 >> 2];
    if (($result_02 | 0) == 0) {
      var $31 = $23;
      var $30$1 = $22$1;
      var $30$0 = $22$0;
      __label__ = 7;
      break;
    } else {
      var $result_03 = $result_02;
      var $26$1 = $22$1;
      var $26$0 = $22$0;
      __label__ = 5;
      break;
    }
   case 5:
    var $26$0;
    var $26$1;
    var $result_03;
    var $27$0 = (i64Math.add($26$0, $26$1, 12, 0), i64Math.result[0]);
    var $27$1 = i64Math.result[1];
    var $st$6$0 = $20 | 0;
    HEAP32[$st$6$0 >> 2] = $27$0;
    var $st$6$1 = $20 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $27$1;
    var $result_0 = HEAP32[$result_03 + 8 >> 2];
    if (($result_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $result_03 = $result_0;
      var $26$1 = $27$1;
      var $26$0 = $27$0;
      __label__ = 5;
      break;
    }
   case 6:
    var $31 = HEAP32[$1 >> 2];
    var $30$1 = $27$1;
    var $30$0 = $27$0;
    __label__ = 7;
    break;
   case 7:
    var $30$0;
    var $30$1;
    var $31;
    var $32 = __ZN2js5types10TypeScript9typeArrayEv($31);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $stats + 24 | 0;
    var $st$1$0 = $34 | 0;
    var $st$1$1 = $34 + 4 | 0;
    var $i_01 = 0;
    var $37$1 = $30$1;
    var $37$0 = $30$0;
    var $36$1 = HEAP32[$st$1$1 >> 2];
    var $36$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $36$0;
    var $36$1;
    var $37$0;
    var $37$1;
    var $i_01;
    var $38 = $32 + $i_01 * 12 | 0;
    var $39 = __ZN2js5types7TypeSet11dynamicSizeEv($38);
    var $40$0 = $39;
    var $40$1 = 0;
    var $41$0 = (i64Math.add($37$0, $37$1, $40$0, $40$1), i64Math.result[0]);
    var $41$1 = i64Math.result[1];
    HEAP32[$20 >> 2] = $41$0;
    HEAP32[$20 + 4 >> 2] = $41$1;
    var $42$0 = (i64Math.subtract($36$0, $36$1, $40$0, $40$1), i64Math.result[0]);
    var $42$1 = i64Math.result[1];
    HEAP32[$34 >> 2] = $42$0;
    HEAP32[$34 + 4 >> 2] = $42$1;
    var $43 = $i_01 + 1 | 0;
    if (($43 | 0) == ($16 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i_01 = $43;
      var $37$1 = $41$1;
      var $37$0 = $41$0;
      var $36$1 = $42$1;
      var $36$0 = $42$0;
      __label__ = 9;
      break;
    }
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20GetScriptMemoryStatsP8JSScriptP24TypeInferenceMemoryStats["X"] = 1;

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv($1);
  return $2;
}

function __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv($1);
  return $2;
}

function __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13allocatedSizeEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13allocatedSizeEv($1);
  return $2;
}

function _JS_GetTypeInferenceObjectStats($object_, $stats) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $object_;
    var $2 = $stats + 8 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4$0 = (i64Math.add($3$0, $3$1, 32, 0), i64Math.result[0]);
    var $4$1 = i64Math.result[1];
    var $st$9$0 = $2 | 0;
    HEAP32[$st$9$0 >> 2] = $4$0;
    var $st$9$1 = $2 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $4$1;
    if ((HEAP32[$object_ + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $12 = HEAP32[$object_ + 16 >> 2];
    if (($12 | 0) == 0) {
      var $27$1 = $4$1;
      var $27$0 = $4$0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$12 + 12 >> 2];
    if ((HEAP32[$16 >> 2] | 0) == 3) {
      var $length_0_lcssa$1 = 0;
      var $length_0_lcssa$0 = 24;
      __label__ = 6;
      break;
    } else {
      var $length_01 = 1;
      var $init_02 = $16;
      __label__ = 4;
      break;
    }
   case 4:
    var $init_02;
    var $length_01;
    var $20 = $init_02 + 8 | 0;
    var $phitmp = $length_01 + 1 | 0;
    if ((HEAP32[$20 >> 2] | 0) == 3) {
      __label__ = 5;
      break;
    } else {
      var $length_01 = $phitmp;
      var $init_02 = $20;
      __label__ = 4;
      break;
    }
   case 5:
    var $length_0_lcssa$1 = 0;
    var $length_0_lcssa$0 = ($phitmp << 3) + 16 | 0;
    __label__ = 6;
    break;
   case 6:
    var $length_0_lcssa$0;
    var $length_0_lcssa$1;
    var $25$0 = (i64Math.add($4$0, $4$1, $length_0_lcssa$0, $length_0_lcssa$1), i64Math.result[0]);
    var $25$1 = i64Math.result[1];
    HEAP32[$2 >> 2] = $25$0;
    HEAP32[$2 + 4 >> 2] = $25$1;
    var $27$1 = $25$1;
    var $27$0 = $25$0;
    __label__ = 7;
    break;
   case 7:
    var $27$0;
    var $27$1;
    if ((HEAP32[$object_ + 8 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $33 = $stats + 32 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35$0 = (i64Math.add($34$0, $34$1, 48, 0), i64Math.result[0]);
    var $35$1 = i64Math.result[1];
    HEAP32[$33 >> 2] = $35$0;
    HEAP32[$33 + 4 >> 2] = $35$1;
    __label__ = 9;
    break;
   case 9:
    var $37 = __ZN2js5types10TypeObject11dynamicSizeEv($1);
    var $38$0 = $37;
    var $38$1 = 0;
    var $39$0 = (i64Math.add($27$0, $27$1, $38$0, $38$1), i64Math.result[0]);
    var $39$1 = i64Math.result[1];
    HEAP32[$2 >> 2] = $39$0;
    HEAP32[$2 + 4 >> 2] = $39$1;
    var $40 = $stats + 24 | 0;
    var $st$9$0 = $40 | 0;
    var $41$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$9$1 >> 2];
    var $42$0 = (i64Math.subtract($41$0, $41$1, $38$0, $38$1), i64Math.result[0]);
    var $42$1 = i64Math.result[1];
    HEAP32[$40 >> 2] = $42$0;
    HEAP32[$40 + 4 >> 2] = $42$1;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_GetTypeInferenceObjectStats["X"] = 1;

function __ZN2js5types10TypeObject11dynamicSizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $bytes_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $bytes_0 = $4 << 2;
    __label__ = 3;
    break;
   case 3:
    var $bytes_0;
    var $7 = __ZN2js5types10TypeObject16getPropertyCountEv($this);
    if (($7 | 0) == 0) {
      var $bytes_1_lcssa = $bytes_0;
      __label__ = 7;
      break;
    } else {
      var $bytes_11 = $bytes_0;
      var $i_02 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_02;
    var $bytes_11;
    var $9 = __ZN2js5types10TypeObject11getPropertyEj($this, $i_02);
    if (($9 | 0) == 0) {
      var $bytes_2 = $bytes_11;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9 + 4 | 0;
    var $13 = __ZN2js5types7TypeSet11dynamicSizeEv($12);
    var $bytes_2 = $13 + ($bytes_11 + 16) | 0;
    __label__ = 6;
    break;
   case 6:
    var $bytes_2;
    var $17 = $i_02 + 1 | 0;
    if (($17 | 0) == ($7 | 0)) {
      var $bytes_1_lcssa = $bytes_2;
      __label__ = 7;
      break;
    } else {
      var $bytes_11 = $bytes_2;
      var $i_02 = $17;
      __label__ = 4;
      break;
    }
   case 7:
    var $bytes_1_lcssa;
    return $bytes_1_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free1736($p) {
  _free($p);
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types17AllocationSiteKeyC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$rhs + 8 >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev($1);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv($rhs);
  var $10 = $9 + 8 | 0;
  __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($2, $10);
  var $11 = __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($2);
  var $12 = HEAP32[$11 >> 2];
  HEAP32[$this + 8 >> 2] = $12;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_($this, $rhs) {
  var $1 = $this;
  var $2 = $rhs;
  HEAP32[$1 >> 2] = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[$2 + 4 >> 2];
  HEAP32[$1 + 8 >> 2] = HEAP32[$2 + 8 >> 2];
  HEAP32[$1 + 12 >> 2] = HEAP32[$2 + 12 >> 2];
  var $5 = $rhs + 16 | 0;
  var $6 = $this + 16 | 0;
  var $7$0 = HEAP32[$5 >> 2];
  var $7$1 = HEAP32[$5 + 4 >> 2];
  HEAP32[$6 >> 2] = $7$0;
  HEAP32[$6 + 4 >> 2] = $7$1;
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev($this) {
  var $1 = $this;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$1 + 4 >> 2] = 0;
  HEAP32[$1 + 8 >> 2] = 0;
  HEAP32[$1 + 12 >> 2] = 0;
  HEAP32[$1 + 16 >> 2] = 0;
  HEAP32[$1 + 20 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 28 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 28 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 28 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 28 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 28 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 28 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 28 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_($1, $8);
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_($this, $t);
  return;
}

function __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev($1);
  var $6 = $this;
  var $7 = $5;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  HEAP32[$6 + 12 >> 2] = HEAP32[$7 + 12 >> 2];
  var $8 = $this + 16 | 0;
  var $9 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv($rhs);
  var $10 = $9 + 16 | 0;
  __ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_($2, $10);
  var $11 = __ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev($2);
  var $12 = $11;
  var $13 = $8;
  var $14$0 = HEAP32[$12 >> 2];
  var $14$1 = HEAP32[$12 + 4 >> 2];
  HEAP32[$13 >> 2] = $14$0;
  HEAP32[$13 + 4 >> 2] = $14$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $1);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + HEAP32[$this + 4 >> 2] * 28 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 28 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($1);
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types13ArrayTableKeyC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 4) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 16 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 4;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 4) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 16 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 4) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSObject14revertLazyTypeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] | 131072;
    HEAP32[$1 >> 2] = $3;
    var $4 = $this + 36 | 0;
    var $7 = HEAP32[HEAP32[$4 >> 2] >> 2];
    if (($7 | 0) == 0) {
      var $13 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$7 + 16 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $13;
    HEAP32[$4 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeResultC2EjNS0_4TypeE($this, $offset, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$this >> 2] = $offset;
  var $3 = HEAP32[$type >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  HEAP32[$this + 8 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev($1);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = __ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv($rhs);
  var $10 = $9 + 8 | 0;
  __ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_($2, $10);
  var $11 = __ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev($2);
  var $12 = HEAP32[$11 >> 2];
  HEAP32[$this + 8 >> 2] = $12;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 4) | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 16 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17SweepTypeObjectOpclEPN2js2gc4CellE($this, $cell) {
  var $1 = $cell;
  var $3 = HEAP32[$this >> 2];
  __ZN2js5types10TypeObject5sweepEP9JSContext($1, $3);
  return;
}

function __ZN2js5types10TypeObject5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propertyCount = __stackBase__;
    HEAP32[$this + 20 >> 2] = 0;
    var $2 = $this + 4 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types10TypeObject15clearPropertiesEv($this);
    var $6 = $this;
    var $7 = __ZNK2js2gc4Cell8isMarkedEj($6, 0);
    if ($7) {
      __label__ = 30;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$2 >> 2];
    __ZN8JSObject14revertLazyTypeEv($9);
    __label__ = 30;
    break;
   case 4:
    var $11 = $this;
    var $12 = __ZNK2js2gc4Cell8isMarkedEj($11, 0);
    if ($12) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$this + 8 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $15;
    __ZN2js10Foreground5free_EPv($18);
    __label__ = 7;
    break;
   case 7:
    var $21 = HEAP32[$this + 16 >> 2];
    if (($21 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = $21;
    __ZN2js10Foreground5free_EPv($24);
    __label__ = 30;
    break;
   case 9:
    var $26 = __ZNK2js2gc4Cell11compartmentEv($11);
    var $27 = __ZNK2js5types10TypeObject17basePropertyCountEv($this);
    HEAP32[$propertyCount >> 2] = $27;
    if ($27 >>> 0 > 1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 10:
    var $30 = __ZN2js5typesL15HashSetCapacityEj1739($27);
    var $31 = $this + 24 | 0;
    var $32 = HEAP32[$31 >> 2];
    __ZN2js5types10TypeObject15clearPropertiesEv($this);
    HEAP32[$propertyCount >> 2] = 0;
    if (($30 | 0) == 0) {
      var $57 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $26 + 344 | 0;
    var $35 = $26 + 376 | 0;
    var $i_02 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_02;
    var $38 = HEAP32[$32 + ($i_02 << 2) >> 2];
    if (($38 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = $38 + 4 | 0;
    var $42 = __ZNK2js5types7TypeSet13isOwnPropertyEb($41, 0);
    if ($42) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $44 = __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($34, $38);
    if (($44 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $48 = HEAP32[$38 >> 2];
    var $49 = __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740($26, $31, $propertyCount, $48);
    if (($49 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$49 >> 2] = $44;
    var $52 = $44 + 4 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($52, $cx, $26);
    __label__ = 19;
    break;
   case 17:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($35, $cx);
    __label__ = 19;
    break;
   case 18:
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($35, $cx);
    __label__ = 19;
    break;
   case 19:
    var $56 = $i_02 + 1 | 0;
    if (($56 | 0) == ($30 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $i_02 = $56;
      __label__ = 12;
      break;
    }
   case 20:
    var $57 = HEAP32[$propertyCount >> 2];
    __label__ = 21;
    break;
   case 21:
    var $57;
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, $57);
    __label__ = 28;
    break;
   case 22:
    if (($27 | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 23:
    var $61 = $this + 24 | 0;
    var $62 = HEAP32[$61 >> 2];
    var $64 = $62 + 4 | 0;
    var $65 = __ZNK2js5types7TypeSet13isOwnPropertyEb($64, 0);
    if ($65) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $67 = $62;
    var $68 = $26 + 344 | 0;
    var $69 = __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($68, $67);
    if (($69 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $72 = $69;
    HEAP32[$61 >> 2] = $72;
    var $73 = $69 + 4 | 0;
    __ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment($73, $cx, $26);
    __label__ = 28;
    break;
   case 26:
    var $75 = $26 + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($75, $cx);
    __label__ = 28;
    break;
   case 27:
    HEAP32[$61 >> 2] = 0;
    __ZN2js5types10TypeObject20setBasePropertyCountEj($this, 0);
    __label__ = 28;
    break;
   case 28:
    if ((HEAP32[$this + 16 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $81 = $this + 12 | 0;
    var $83 = HEAP32[$81 >> 2] | 4;
    HEAP32[$81 >> 2] = $83;
    __label__ = 30;
    break;
   case 30:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5types10TypeObject5sweepEP9JSContext["X"] = 1;

function __ZN2js5types10TypeObject15clearPropertiesEv($this) {
  __ZN2js5types10TypeObject20setBasePropertyCountEj($this, 0);
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN2js5typesL15HashSetCapacityEj1739($count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 < 9) {
      var $_0 = 8;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $count | 1;
    var $4 = _llvm_ctlz_i32($3);
    var $_0 = 1 << 33 - $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 16 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $25 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    __ZN2js5types8PropertyC1ERKS1_($23, $a);
    var $25 = $23;
    __label__ = 6;
    break;
   case 6:
    var $25;
    return $25;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types8Property6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types8Property6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740["X"] = 1;

function __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $3 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types8Property6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj1739($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types8Property6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742["X"] = 1;

function __ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743($v) {
  var $1 = __ZN2js5types8Property7keyBitsEi($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types8PropertyC1ERKS1_($this, $o) {
  __ZN2js5types8PropertyC2ERKS1_($this, $o);
  return;
}

function __ZN2js5types8PropertyC2ERKS1_($this, $o) {
  var $3 = HEAP32[$o >> 2];
  HEAP32[$this >> 2] = $3;
  var $6 = $this + 4 | 0;
  var $7 = $o + 4 | 0;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  return;
}

function __ZN2js7analyze14ScriptAnalysisC1EP8JSScript($this, $script) {
  __ZN2js7analyze14ScriptAnalysisC2EP8JSScript($this, $script);
  return;
}

function __ZN2js7analyze14ScriptAnalysisC2EP8JSScript($this, $script) {
  __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_($this);
  HEAP32[$this >> 2] = $script;
  return;
}

function __ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZN2js5types17TypeScriptNestingC1Ev($this) {
  __ZN2js5types17TypeScriptNestingC2Ev($this);
  return;
}

function __ZN2js5types17TypeScriptNestingC2Ev($this) {
  __ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_($this);
  return;
}

function __ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 28, 1);
  return;
}

function __ZN2js5types10TypeResultC1EjNS0_4TypeE($this, $offset, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  __ZN2js5types10TypeResultC2EjNS0_4TypeE($this, $offset, $type);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 >> 2] = $6$0;
    HEAP32[$4 + 4 >> 2] = $6$1;
    __label__ = 3;
    break;
   case 3:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $10;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $dst_01;
    HEAP32[$13 >> 2] = 0;
    HEAP32[$13 + 4 >> 2] = 0;
    __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $14 = __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($1);
    var $15 = $14;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    HEAP32[$13 >> 2] = $16$0;
    HEAP32[$13 + 4 >> 2] = $16$1;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2] | 0;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_02;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $6 = __ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev($1);
    var $7 = $6;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    HEAP32[$5 >> 2] = $8$0;
    HEAP32[$5 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3 | 0;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount) {
  __ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount);
  return;
}

function __ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj($this, $cx, $script, $pc, $isNew, $argumentCount) {
  HEAP32[$this >> 2] = $script;
  HEAP32[$this + 4 >> 2] = $pc;
  HEAP8[$this + 8 | 0] = $isNew & 1;
  HEAP32[$this + 16 >> 2] = $argumentCount;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  var $10 = HEAP32[$cx + 56 >> 2] + 344 | 0;
  var $11 = __ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj($10, $argumentCount);
  HEAP32[$this + 12 >> 2] = $11;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_($this, $k, $v) {
  var $1 = $k;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $5 = HEAP32[$v >> 2];
  HEAP32[$this + 8 >> 2] = $5;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js5types4Type3rawEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type, $singleton, $singletonId) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $target;
  var $4 = HEAP32[$type >> 2];
  HEAP32[$this + 8 >> 2] = $4;
  HEAP32[$this + 12 >> 2] = $singleton;
  HEAP32[$this + 16 >> 2] = $singletonId;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj($pool, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $5 = HEAP32[$pool + 24 >> 2];
    var $8 = $5 + ($count << 2) & ($5 ^ -1);
    var $9 = $2 + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $12 = HEAPU32[$2 + 8 >> 2];
    if ($8 >>> 0 > $12 >>> 0 | $10 >>> 0 > ($12 - $8 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = _JS_ArenaAllocate($pool, $8);
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $20 = $8 + $10 | 0;
    HEAP32[$9 >> 2] = $20;
    var $_p_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    return $_p_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js5types8PropertyC1Ei($this, $id) {
  __ZN2js5types8PropertyC2Ei($this, $id);
  return;
}

function __ZN2js5types8PropertyC2Ei($this, $id) {
  HEAP32[$this >> 2] = $id;
  var $2 = $this + 4 | 0;
  __ZN2js5types7TypeSetC1Ev($2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN2js5types14ObjectTableKey4hashEP8JSObject($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 28 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 28 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE($1);
  var $3 = HEAP32[$l >> 2];
  var $4 = __ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject($2, $3);
  return $4;
}

function __ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject($v, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8slotSpanEv($obj);
    if (($1 | 0) == (HEAP32[$v + 4 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13numFixedSlotsEv($obj);
    if (($6 | 0) == (HEAP32[$v + 8 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZNK8JSObject8getProtoEv($obj);
    if (($11 | 0) == (HEAP32[$v + 12 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = __ZNK8JSObject12lastPropertyEv($obj);
    var $17 = $v | 0;
    var $shape_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $shape_0;
    var $20 = HEAP32[$shape_0 + 12 >> 2];
    var $21 = _JSID_IS_EMPTY($20);
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    if (($20 | 0) == (HEAP32[HEAP32[$17 >> 2] + (HEAP32[$shape_0 + 24 >> 2] << 2) >> 2] | 0)) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $31 = __ZNK2js5Shape8previousEv($shape_0);
    var $shape_0 = $31;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types14ObjectTableKey4hashEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12lastPropertyEv($obj);
  var $3 = HEAP32[$1 + 12 >> 2];
  var $4 = __ZNK8JSObject8slotSpanEv($obj);
  var $5 = __ZNK8JSObject13numFixedSlotsEv($obj);
  var $6 = __ZNK8JSObject8getProtoEv($obj);
  return $4 ^ $3 ^ $5 ^ $6 >>> 2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_($this, $p, $l, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$p + 4 >> 2];
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $2, 1);
    var $4 = $p | 0;
    HEAP32[$p >> 2] = $3;
    var $6 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($4);
    if ($6) {
      var $10 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_($this, $p, $t);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_($this, $k, $v) {
  __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_($this, $k, $v);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 4) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 4) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    __ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_($5, $t);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js5types13ArrayTableKey5matchERKS1_S3_($2, $l);
  return $3;
}

function __ZN2js5types13ArrayTableKey5matchERKS1_S3_($v1, $v2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v1 | 0;
    var $4 = HEAP32[$v2 >> 2];
    HEAP32[$1 >> 2] = $4;
    var $6 = __ZNK2js5types4TypeeqES1_($2, $1);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $14 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = (HEAP32[$v1 + 4 >> 2] | 0) == (HEAP32[$v2 + 4 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $14;
    STACKTOP = __stackBase__;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js5types13ArrayTableKey4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js5types13ArrayTableKey4hashERKS1_($v) {
  var $1 = $v | 0;
  var $2 = __ZNK2js5types4Type3rawEv($1);
  return HEAP32[$v + 4 >> 2] >>> 2 ^ $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type, $singleton, $singletonId) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  __ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti($this, $target, $type, $singleton, $singletonId);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN31TypeConstraintFreezeOwnProperty7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN31TypeConstraintFreezeObjectFlags7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types14TypeConstraintC2EPKc($this, $kind) {
  HEAP32[$this >> 2] = __ZTVN2js5types14TypeConstraintE + 8 | 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN20TypeConstraintFreeze7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$1] = 1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN26TypeConstraintFreezeGlobalC1EP8JSScriptP8JSObject($this, $script, $global) {
  __ZN26TypeConstraintFreezeGlobalC2EP8JSScriptP8JSObject($this, $script, $global);
  return;
}

function __ZN26TypeConstraintFreezeGlobalC2EP8JSScriptP8JSObject($this, $script, $global) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV26TypeConstraintFreezeGlobal + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $global;
  return;
}

function __ZN26TypeConstraintFreezeGlobal7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$type >> 2];
    var $7 = __ZL13TypeHasGlobalN2js5types4TypeEP8JSObject($6, $2);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN31TypeConstraintFreezeOwnPropertyC1EP8JSScriptb($this, $script, $configurable) {
  __ZN31TypeConstraintFreezeOwnPropertyC2EP8JSScriptb($this, $script, $configurable);
  return;
}

function __ZN31TypeConstraintFreezeOwnPropertyC2EP8JSScriptb($this, $script, $configurable) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV31TypeConstraintFreezeOwnProperty + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP8[$this + 12 | 0] = 0;
  HEAP8[$this + 13 | 0] = $configurable & 1;
  return;
}

function __ZN31TypeConstraintFreezeOwnProperty16newPropertyStateEP9JSContextPN2js5types7TypeSetE($this, $cx, $source) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    var $10 = __ZNK2js5types7TypeSet13isOwnPropertyEb($source, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$1] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptj($this, $script, $flags) {
  __ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptj($this, $script, $flags);
  return;
}

function __ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptj($this, $script, $flags) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV31TypeConstraintFreezeObjectFlags + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $flags;
  var $6 = $this + 20 | 0;
  HEAP32[$this + 16 >> 2] = $6;
  HEAP8[$6] = 0;
  return;
}

function __ZN31TypeConstraintFreezeObjectFlags14newObjectStateEP9JSContextPN2js5types10TypeObjectEb($this, $cx, $object, $force) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $3 = __ZN2js5types10TypeObject11hasAnyFlagsEj($object, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 16 >> 2];
    if ((HEAP8[$6] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$6] = 1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN34TypeConstraintFreezeObjectFlagsSetC1EP8JSScriptj($this, $script, $flags) {
  __ZN34TypeConstraintFreezeObjectFlagsSetC2EP8JSScriptj($this, $script, $flags);
  return;
}

function __ZN34TypeConstraintFreezeObjectFlagsSetC2EP8JSScriptj($this, $script, $flags) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV34TypeConstraintFreezeObjectFlagsSet + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $flags;
  HEAP8[$this + 16 | 0] = 0;
  return;
}

function __ZN34TypeConstraintFreezeObjectFlagsSet7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 16 | 0;
    if ((HEAP8[$2] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $7 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($7) {
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($9) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2js5types4Type8isObjectEv($type);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $13 = __ZNK2js5types4Type14isSingleObjectEv($type);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = __ZNK2js5types4Type12singleObjectEv($type);
    var $16 = $15;
    var $17 = $cx;
    var $18 = __ZN8JSObject7getTypeEP9JSContext($16, $17);
    var $23 = $18;
    __label__ = 8;
    break;
   case 7:
    var $21 = __ZNK2js5types4Type10typeObjectEv($type);
    var $23 = $21;
    __label__ = 8;
    break;
   case 8:
    var $23;
    var $24 = $this + 12 | 0;
    var $25 = HEAP32[$24 >> 2];
    var $26 = __ZN2js5types10TypeObject11hasAnyFlagsEj($23, $25);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($23, $cx, 4, 0);
    if (($28 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = HEAP32[$cx + 56 >> 2] + 344 | 0;
    var $34 = $this + 8 | 0;
    HEAP32[$1 >> 2] = $2;
    var $35 = __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjPbEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($33, $34, $24, $1);
    var $36 = $35 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($28, $cx, $36, 0);
    __label__ = 12;
    break;
   case 11:
    HEAP8[$2] = 1;
    __label__ = 12;
    break;
   case 12:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjPbEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_($pool, $a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 24 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $28 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    var $25 = HEAP32[$b >> 2];
    var $26 = HEAP32[$c >> 2];
    __ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptjPb($23, $24, $25, $26);
    var $28 = $23;
    __label__ = 6;
    break;
   case 6:
    var $28;
    return $28;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptjPb($this, $script, $flags, $pmarked) {
  __ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptjPb($this, $script, $flags, $pmarked);
  return;
}

function __ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptjPb($this, $script, $flags, $pmarked) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV31TypeConstraintFreezeObjectFlags + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $flags;
  HEAP32[$this + 16 >> 2] = $pmarked;
  HEAP8[$this + 20 | 0] = 0;
  return;
}

function __ZN27TypeConstraintFreezeTypeTagC1EP8JSScript($this, $script) {
  __ZN27TypeConstraintFreezeTypeTagC2EP8JSScript($this, $script);
  return;
}

function __ZN27TypeConstraintFreezeTypeTagC2EP8JSScript($this, $script) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintFreezeTypeTag + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN27TypeConstraintFreezeTypeTag7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js5types4Type11isAnyObjectEv($type);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2js5types4Type8isObjectEv($type);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZN2js5types7TypeSet14getObjectCountEv($source);
    if ($12 >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP8[$1] = 1;
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20TypeConstraintFreezeC1EP8JSScript($this, $script) {
  __ZN20TypeConstraintFreezeC2EP8JSScript($this, $script);
  return;
}

function __ZN20TypeConstraintFreezeC2EP8JSScript($this, $script) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV20TypeConstraintFreeze + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE($this, $target) {
  __ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE($this, $target);
  return;
}

function __ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE($this, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintLazyArguments + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  return;
}

function __ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb($this, $cx, $object, $force) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2js5types10TypeObject11hasAnyFlagsEj($object, 524288);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($5, $cx, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target) {
  __ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target);
  return;
}

function __ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE($this, $script, $pc, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintSubsetBarrier + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP32[$this + 16 >> 2] = $target;
  return;
}

function __ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $5 = HEAP32[$this + 16 >> 2];
    var $7 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $7;
    var $9 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($5, $1);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[$this + 8 >> 2];
    var $13 = __ZN8JSScript8analysisEv($12);
    var $15 = HEAP32[$this + 12 >> 2];
    HEAP32[$2 >> 2] = $7;
    __ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE($13, $cx, $15, $5, $2);
    __label__ = 4;
    break;
   case 3:
    HEAP32[$3 >> 2] = $7;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($5, $cx, $3);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter) {
  __ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter);
  return;
}

function __ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE($this, $target, $filter) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV29TypeConstraintFilterPrimitive + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  HEAP32[$this + 12 >> 2] = $filter;
  return;
}

function __ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $3 = HEAP32[$this + 12 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($3 | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZNK2js5types4Type11isPrimitiveEv($type);
    if ($5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 6);
    if ($7) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 2);
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = __ZNK2js5types4Type11isPrimitiveE11JSValueType($type, 2);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = HEAP32[$this + 8 >> 2];
    var $16 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $16;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($14, $cx, $1);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type, $types) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  __ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type, $types);
  STACKTOP = __stackBase__;
  return;
}

function __ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE($this, $script, $callpc, $type, $types) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintPropagateThis + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $callpc;
  var $6 = HEAP32[$type >> 2];
  HEAP32[$this + 16 >> 2] = $6;
  HEAP32[$this + 20 >> 2] = $types;
  STACKTOP = __stackBase__;
  return;
}

function __ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE($this, $script, $target) {
  __ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE($this, $script, $target);
  return;
}

function __ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE($this, $script, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV27TypeConstraintTransformThis + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $target;
  return;
}

function __ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_($this, $target, $other) {
  __ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_($this, $target, $other);
  return;
}

function __ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_($this, $target, $other) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV19TypeConstraintArith + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  HEAP32[$this + 12 >> 2] = $other;
  return;
}

function __ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE($this, $callsite) {
  __ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE($this, $callsite);
  return;
}

function __ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE($this, $callsite) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV18TypeConstraintCall + 8 | 0;
  HEAP32[$this + 8 >> 2] = $callsite;
  return;
}

function __ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes) {
  __ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes);
  return;
}

function __ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_($this, $script, $pc, $objectTypes, $valueTypes) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV24TypeConstraintSetElement + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP32[$this + 16 >> 2] = $objectTypes;
  HEAP32[$this + 20 >> 2] = $valueTypes;
  return;
}

function __ZN22TypeConstraintCallPropC1EP8JSScriptPhi($this, $script, $callpc, $id) {
  __ZN22TypeConstraintCallPropC2EP8JSScriptPhi($this, $script, $callpc, $id);
  return;
}

function __ZN22TypeConstraintCallPropC2EP8JSScriptPhi($this, $script, $callpc, $id) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV22TypeConstraintCallProp + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $callpc;
  HEAP32[$this + 16 >> 2] = $id;
  return;
}

function __ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign) {
  __ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign);
  return;
}

function __ZN17SweepTypeObjectOpC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  return;
}

function __ZN2js5types10TypeScriptC2EP10JSFunction($this, $fun) {
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = 1;
  return;
}

function __ZN2js7analyze17AutoEnterAnalysis5leaveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 5 | 0;
    if ((HEAP8[$1] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$1] = 1;
    var $8 = HEAP8[$this + 4 | 0] & 1;
    HEAP8[HEAP32[HEAP32[$this >> 2] + 56 >> 2] + 372 | 0] = $8;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $3 = $cx + 56 | 0;
  var $7 = HEAP8[HEAP32[$3 >> 2] + 372 | 0] & 1;
  HEAP8[$this + 4 | 0] = $7;
  HEAP8[$this + 5 | 0] = 0;
  HEAP8[HEAP32[$3 >> 2] + 372 | 0] = 1;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1752($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib($this, $script, $pc, $target, $id, $assign) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV18TypeConstraintProp + 8 | 0;
  HEAP32[$this + 8 >> 2] = $script;
  HEAP32[$this + 12 >> 2] = $pc;
  HEAP8[$this + 16 | 0] = $assign & 1;
  HEAP32[$this + 20 >> 2] = $target;
  HEAP32[$this + 24 >> 2] = $id;
  return;
}

function __ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE($this, $target) {
  __ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE($this, $target);
  return;
}

function __ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE($this, $target) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV20TypeConstraintSubset + 8 | 0;
  HEAP32[$this + 8 >> 2] = $target;
  return;
}

function __ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $3 = HEAP32[$this + 8 >> 2];
  var $5 = HEAP32[$type >> 2];
  HEAP32[$1 >> 2] = $5;
  __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($3, $cx, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js5types7TypeSet11dynamicSizeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5types7TypeSet15baseObjectCountEv($this);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $_0 = $4 << 2;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$count >> 2];
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    HEAP32[$count >> 2] = 1;
    var $_0 = $values;
    __label__ = 15;
    break;
   case 3:
    var $5 = HEAP32[$values >> 2];
    var $6 = $5;
    var $7 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($6);
    if (($7 | 0) == ($key | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $values;
    __label__ = 15;
    break;
   case 5:
    var $12 = $compartment + 344 | 0;
    var $13 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($12, 8);
    HEAP32[$values >> 2] = $13;
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$values >> 2] = $5;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 7:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($13, 8);
    var $18 = HEAP32[$count >> 2] + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = HEAP32[$values >> 2];
    HEAP32[$19 >> 2] = $6;
    var $_0 = HEAP32[$values >> 2] + 4 | 0;
    __label__ = 15;
    break;
   case 8:
    if ($1 >>> 0 < 9) {
      var $i_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = HEAP32[$values >> 2] + ($i_0 << 2) | 0;
    var $28 = HEAP32[$27 >> 2];
    var $29 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($28);
    if (($29 | 0) == ($key | 0)) {
      var $_0 = $27;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 12:
    if ($1 >>> 0 < 8) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$count >> 2] = $1 + 1 | 0;
    var $_0 = HEAP32[$values >> 2] + ($1 << 2) | 0;
    __label__ = 15;
    break;
   case 14:
    var $40 = __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747($compartment, $values, $count, $key);
    var $_0 = $40;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745["X"] = 1;

function __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747($compartment, $values, $count, $key) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$count >> 2];
    var $2 = __ZN2js5typesL15HashSetCapacityEj1739($1);
    var $3 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($key);
    var $4 = $2 - 1 | 0;
    var $5 = $3 & $4;
    if (($1 | 0) == 8) {
      var $insertpos_1 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$values >> 2];
    var $insertpos_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $insertpos_0;
    var $9 = $7 + ($insertpos_0 << 2) | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      var $insertpos_1 = $insertpos_0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($10);
    if (($13 | 0) == ($key | 0)) {
      var $_0 = $9;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $insertpos_0 = $insertpos_0 + 1 & $4;
    __label__ = 3;
    break;
   case 6:
    var $insertpos_1;
    var $18 = $1 + 1 | 0;
    HEAP32[$count >> 2] = $18;
    var $19 = __ZN2js5typesL15HashSetCapacityEj1739($18);
    if (($19 | 0) == ($2 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = HEAP32[$values >> 2] + ($insertpos_1 << 2) | 0;
    __label__ = 17;
    break;
   case 8:
    var $25 = $compartment + 344 | 0;
    var $26 = __ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj($25, $19);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746($26, $19);
    var $_pre = $19 - 1 | 0;
    if (($2 | 0) == 0) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $i_013;
    var $32 = HEAP32[HEAP32[$values >> 2] + ($i_013 << 2) >> 2];
    if (($32 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZN2js5types13TypeObjectKey6getKeyEPS1_($32);
    var $36 = __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($35);
    var $pos_09 = $36 & $_pre;
    var $37 = $26 + ($pos_09 << 2) | 0;
    if ((HEAP32[$37 >> 2] | 0) == 0) {
      var $_lcssa8 = $37;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_09;
      __label__ = 12;
      break;
    }
   case 12:
    var $pos_010;
    var $pos_0 = $pos_010 + 1 & $_pre;
    var $41 = $26 + ($pos_0 << 2) | 0;
    if ((HEAP32[$41 >> 2] | 0) == 0) {
      var $_lcssa8 = $41;
      __label__ = 13;
      break;
    } else {
      var $pos_010 = $pos_0;
      __label__ = 12;
      break;
    }
   case 13:
    var $_lcssa8;
    HEAP32[$_lcssa8 >> 2] = $32;
    __label__ = 14;
    break;
   case 14:
    var $45 = $i_013 + 1 | 0;
    if (($45 | 0) == ($2 | 0)) {
      var $_pre_phi = $_pre;
      __label__ = 15;
      break;
    } else {
      var $i_013 = $45;
      __label__ = 10;
      break;
    }
   case 15:
    var $_pre_phi;
    HEAP32[$values >> 2] = $26;
    var $insertpos_26 = $3 & $_pre_phi;
    var $46 = $26 + ($insertpos_26 << 2) | 0;
    if ((HEAP32[$46 >> 2] | 0) == 0) {
      var $_0 = $46;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_26;
      __label__ = 16;
      break;
    }
   case 16:
    var $insertpos_27;
    var $insertpos_2 = $insertpos_27 + 1 & $_pre_phi;
    var $50 = $26 + ($insertpos_2 << 2) | 0;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      var $_0 = $50;
      __label__ = 17;
      break;
    } else {
      var $insertpos_27 = $insertpos_2;
      __label__ = 16;
      break;
    }
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747["X"] = 1;

function __ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748($v) {
  var $1 = __ZN2js5types13TypeObjectKey7keyBitsEPS1_($v);
  return ((($1 & 255 ^ 84696351) * 16777619 ^ $1 >>> 8 & 255) * 16777619 ^ $1 >>> 16 & 255) * 16777619 ^ $1 >>> 24;
}

function __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($cx, $script, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $enter = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = __ZNK9JSContext12hasRunOptionEj($cx, 65536);
    var $6 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script);
    var $8 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $8;
    var $10 = __ZN2js5types7TypeSet7hasTypeENS0_4TypeE($6, $1);
    if ($5 | $10 ^ 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    __ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb($enter, $cx, undef);
    var $12 = __ZN2js5types10TypeScript9ThisTypesEP8JSScript($script);
    HEAP32[$2 >> 2] = $8;
    __ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE($12, $cx, $2);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = HEAP32[$script + 100 >> 2];
    var $17 = __ZN2js5types10TypeScript8hasScopeEv($16);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script, $cx);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5types22AutoEnterTypeInferenceD1Ev($enter);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze17AutoEnterAnalysisD2Ev($this) {
  __ZN2js7analyze17AutoEnterAnalysis5leaveEv($this);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753($cx, $29, $18);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $type, $fun, $pbaseobj, $initializerList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 76;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $untrap = __stackBase__ + 4;
    var $thisv = __stackBase__ + 12;
    var $untrapUse = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $calleev = __stackBase__ + 44;
    var $untrapCallee = __stackBase__ + 52;
    var $4 = __stackBase__ + 60;
    var $5 = __stackBase__ + 68;
    HEAP32[$1 >> 2] = $type;
    var $6 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv($initializerList);
    if ($6 >>> 0 > 50) {
      var $_5 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK10JSFunction6scriptEv($fun);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($9, $cx, $fun, 0);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN8JSScript18ensureRanInferenceEP9JSContext($9, $cx);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$pbaseobj >> 2] = 0;
    var $16 = HEAP32[$cx + 56 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($16, $cx);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 5:
    var $18 = __ZNK8JSScript16hasClearedGlobalEv($9);
    if ($18) {
      var $_5 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN8JSScript8analysisEv($9);
    var $21 = $9 + 8 | 0;
    var $22 = $9 | 0;
    var $23 = $cx;
    var $24 = $cx + 56 | 0;
    var $25 = $cx;
    var $26 = $calleev;
    var $cx_idx1 = $cx + 52 | 0;
    var $nextOffset_0_ph = 0;
    var $lastThisPopped_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $lastThisPopped_0_ph;
    var $nextOffset_0_ph;
    var $nextOffset_0 = $nextOffset_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $nextOffset_0;
    if ($nextOffset_0 >>> 0 < HEAPU32[$21 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $_5 = 1;
      __label__ = 69;
      break;
    }
   case 9:
    var $32 = HEAP32[$22 >> 2] + $nextOffset_0 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrap, $cx, $9, $32);
    var $33 = __ZN2js7analyzeL17GetBytecodeLengthEPh1712($32);
    var $34 = $33 + $nextOffset_0 | 0;
    var $35 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($20, $32);
    if (($35 | 0) == 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP8[$32];
    if ($38 << 24 >> 24 == -59 || $38 << 24 >> 24 == -101 || $38 << 24 >> 24 == 5) {
      __label__ = 11;
      break;
    } else if ($38 << 24 >> 24 == 123) {
      __label__ = 14;
      break;
    } else if ($38 << 24 >> 24 == 65) {
      __label__ = 16;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 11:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 13:
    var $_4_ph = (HEAP8[$35 | 0] & 32) << 24 >> 24 != 0;
    __label__ = 54;
    break;
   case 14:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    }
   case 15:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 16:
    __ZN2js7analyze8SSAValue11PushedValueEjj($thisv, $nextOffset_0, 0);
    var $51 = __ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE($20, $thisv);
    var $52 = HEAPU32[$51 >> 2];
    if ((HEAP32[$52 + 8 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    }
   case 17:
    if ((HEAP8[$52 | 0] & 1) << 24 >> 24 == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ($nextOffset_0 >>> 0 < $lastThisPopped_0_ph >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$pbaseobj >> 2] = 0;
    var $_4_ph = 0;
    __label__ = 54;
    break;
   case 20:
    var $65 = $52;
    var $67 = HEAPU32[$65 >> 2] >>> 1;
    var $68 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEj($20, $67);
    if (($68 | 0) == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP8[$68 | 0] & 32) << 24 >> 24 == 0) {
      var $_4_ph = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $76 = HEAPU32[$22 >> 2];
    var $77 = $76 + $67 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrapUse, $cx, $9, $77);
    var $78 = HEAP8[$77];
    var $79 = HEAPU32[$pbaseobj >> 2];
    if ($78 << 24 >> 24 == 54) {
      __label__ = 23;
      break;
    } else if ($78 << 24 >> 24 == 108) {
      __label__ = 40;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 23:
    if ((HEAP32[$52 + 4 >> 2] | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 24:
    var $85 = _js_GetIndexFromBytecode($cx, $9, $77, 0);
    var $86 = __ZN8JSScript7getAtomEj($9, $85);
    var $87 = __ZL12ATOM_TO_JSIDP6JSAtom1694($86);
    var $88 = __ZN2js5types10MakeTypeIdEP9JSContexti($cx, $87);
    if (($88 | 0) == ($87 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 25:
    var $cx_idx1_val = HEAP32[$cx_idx1 >> 2];
    var $cx_idx1_val_idx_val = HEAP32[$cx_idx1_val + 210200 >> 2];
    var $91 = __ZL12id_prototypeP9JSContext($cx_idx1_val_idx_val);
    if (($87 | 0) == ($91 | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $cx_idx_val_idx_val = HEAP32[$cx_idx1_val + 210292 >> 2];
    var $94 = __ZL12id___proto__P9JSContext($cx_idx_val_idx_val);
    if (($87 | 0) == ($94 | 0)) {
      __label__ = 59;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $cx_idx2_val_idx_val = HEAP32[$cx_idx1_val + 210204 >> 2];
    var $97 = __ZL14id_constructorP9JSContext($cx_idx2_val_idx_val);
    if (($87 | 0) == ($97 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $100 = __ZNK8JSObject8slotSpanEv($79);
    __ZN2JSL14UndefinedValueEv1713($2);
    var $101 = $79;
    var $102 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($23, $101, $87, $2, 0, 0, 1, 0, 0, 16);
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $105 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($105, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 30:
    var $107 = __ZNK8JSObject16inDictionaryModeEv($79);
    if ($107) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 32:
    var $109 = __ZNK8JSObject8slotSpanEv($79);
    if (($109 | 0) == ($100 | 0)) {
      __label__ = 61;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $113 = HEAPU32[$65 >> 2] >>> 1;
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($3, 0, $113);
    var $114 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $3);
    if ($114) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $116 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($116, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 35:
    var $118 = __ZNK8JSObject8slotSpanEv($79);
    if ($118 >>> 0 > 14) {
      __label__ = 62;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $124 = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $125 = __ZN8JSObject7getTypeEP9JSContext($124, $25);
    var $126 = $125;
    var $127 = __ZN2js5types10TypeObject17unknownPropertiesEv($126);
    if ($127) {
      __label__ = 63;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $129 = __ZN2js5types10TypeObject11getPropertyEP9JSContextib($126, $cx, $87, 0);
    if (($129 | 0) == 0) {
      __label__ = 64;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $132 = __ZNK2js5types7TypeSet7unknownEv($129);
    if ($132) {
      __label__ = 65;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb($126, $cx, $87, $129, 0);
    var $134 = HEAP32[$24 >> 2] + 344 | 0;
    var $135 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($134, $1);
    var $136 = $135 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($129, $cx, $136, 1);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0_ph = $34;
    var $lastThisPopped_0_ph = $67;
    __label__ = 7;
    break;
   case 40:
    var $147 = (HEAPU8[$67 + ($76 + 1) | 0] & 255) << 8 | HEAPU8[$67 + ($76 + 2) | 0] & 255;
    if ((HEAP32[$52 + 4 >> 2] | 0) == ($147 - 1 | 0)) {
      __label__ = 41;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 41:
    var $151 = $147 + 1 | 0;
    var $152 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($20, $77, $151);
    var $153 = $152;
    var $154$0 = HEAP32[$153 >> 2];
    var $154$1 = HEAP32[$153 + 4 >> 2];
    HEAP32[$26 >> 2] = $154$0;
    HEAP32[$26 + 4 >> 2] = $154$1;
    var $155 = __ZNK2js7analyze8SSAValue4kindEv($calleev);
    if (($155 | 0) == 1) {
      __label__ = 42;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 42:
    var $158 = HEAP32[$22 >> 2];
    var $159 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $160 = $158 + $159 | 0;
    __ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh($untrapCallee, $cx, $9, $160);
    if (HEAP8[$160] << 24 >> 24 == -69) {
      __label__ = 43;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 43:
    var $164 = __ZNK2js7analyze8SSAValue11pushedIndexEv($calleev);
    if (($164 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 44:
    var $167 = __ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj($20, $160, 0);
    __ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE($20, $cx, $167);
    var $171 = $160 - HEAP32[$22 >> 2] | 0;
    __ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb($20, $cx, $171, 1);
    var $172 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($20, $160, 0);
    var $173 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj($20, $160, 1);
    var $174 = __ZN2js5types7TypeSet12getSingletonEP9JSContextb($172, $cx, 0);
    var $175 = __ZN2js5types7TypeSet12getSingletonEP9JSContextb($173, $cx, 0);
    if (($174 | 0) == 0 | ($175 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $179 = __ZNK8JSObject10isFunctionEv($175);
    if ($179) {
      __label__ = 46;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 46:
    var $181 = __ZNK8JSObject18getFunctionPrivateEv($175);
    var $182 = __ZNK10JSFunction13isInterpretedEv($181);
    if ($182) {
      __label__ = 47;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 47:
    var $184 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $185 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($20, $184, 0);
    var $187 = HEAP32[$24 >> 2] + 344 | 0;
    var $188 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($187, $1);
    var $189 = $188 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($185, $cx, $189, 1);
    var $190 = __ZNK2js7analyze8SSAValue12pushedOffsetEv($calleev);
    var $191 = __ZN2js7analyze14ScriptAnalysis11pushedTypesEjj($20, $190, 1);
    var $193 = HEAP32[$24 >> 2] + 344 | 0;
    var $194 = __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($193, $1);
    var $195 = $194 | 0;
    __ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb($191, $cx, $195, 1);
    var $197 = HEAPU32[$65 >> 2] >>> 1;
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($4, 1, $197);
    var $198 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $4);
    if ($198) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $201 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($201, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __label__ = 53;
    break;
   case 49:
    var $203 = HEAP32[$1 >> 2];
    var $204 = __ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE($cx, $203, $181, $pbaseobj, $initializerList);
    if ($204) {
      __label__ = 50;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 50:
    __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($5, 2, 0);
    var $206 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($initializerList, $5);
    if ($206) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapCallee);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0_ph = $34;
    var $lastThisPopped_0_ph = $67;
    __label__ = 7;
    break;
   case 52:
    var $209 = HEAP32[$24 >> 2] + 376 | 0;
    __ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext($209, $cx);
    HEAP32[$pbaseobj >> 2] = 0;
    __label__ = 53;
    break;
   case 53:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapCallee);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 54:
    var $_4_ph;
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = $_4_ph;
    __label__ = 69;
    break;
   case 55:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $nextOffset_0 = $34;
    __label__ = 8;
    break;
   case 56:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 57:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 58:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 59:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 60:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 61:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 62:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 63:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 64:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 65:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 66:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 67:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 68:
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrapUse);
    __ZN2js7analyze12UntrapOpcodeD1Ev($untrap);
    var $_5 = 0;
    __label__ = 69;
    break;
   case 69:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE["X"] = 1;

function __ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj($this, $kind, $offset) {
  __ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj($this, $kind, $offset);
  return;
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $t;
    var $11 = $1;
    var $12$0 = HEAP32[$10 >> 2];
    var $12$1 = HEAP32[$10 + 4 >> 2];
    HEAP32[$11 >> 2] = $12$0;
    HEAP32[$11 + 4 >> 2] = $12$1;
    __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 3) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = $_012;
    var $6 = $_03;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    HEAP32[$6 >> 2] = $7$0;
    HEAP32[$6 + 4 >> 2] = $7$1;
    var $8 = $_012 + 8 | 0;
    if (($8 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $8;
      var $_03 = $_03 + 8 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $12 = $dst;
    var $13 = $src;
    var $14 = $nelem << 3;
    _memcpy($12, $13, $14, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj1765($bits) {
  return $bits;
}

function __ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_() {
  HEAP16[__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active >> 1] = 0;
  return;
}

function __ZN2js5types17TypeFlagPrimitiveEj($flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags | 0) == 2) {
      __label__ = 2;
      break;
    } else if (($flags | 0) == 4) {
      __label__ = 3;
      break;
    } else if (($flags | 0) == 8) {
      __label__ = 4;
      break;
    } else if (($flags | 0) == 16) {
      __label__ = 5;
      break;
    } else if (($flags | 0) == 32) {
      __label__ = 6;
      break;
    } else if (($flags | 0) == 64) {
      __label__ = 7;
      break;
    } else if (($flags | 0) == 1) {
      var $_0 = 2;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $_0 = 6;
    __label__ = 9;
    break;
   case 3:
    var $_0 = 3;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 3) | 0;
}

function __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj($this, $kind, $offset) {
  HEAP32[$this >> 2] = $kind;
  HEAP32[$this + 4 >> 2] = $offset;
  return;
}

function __ZL22UsePropertyTypeBarrierPh($pc_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2];
    if (($3 & 67108864 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = ($3 & 2097152 | 0) == 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 8;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $t;
    var $5 = $1;
    var $6$0 = HEAP32[$4 >> 2];
    var $6$1 = HEAP32[$4 + 4 >> 2];
    HEAP32[$5 >> 2] = $6$0;
    HEAP32[$5 + 4 >> 2] = $6$1;
    __label__ = 3;
    break;
   case 3:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] + 1 | 0;
    HEAP32[$8 >> 2] = $10;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 3;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 268435455) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 3;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_($1, $src_02);
    var $13 = __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($1);
    var $14 = $13;
    var $15 = $dst_01;
    var $16$0 = HEAP32[$14 >> 2];
    var $16$1 = HEAP32[$14 + 4 >> 2];
    HEAP32[$15 >> 2] = $16$0;
    HEAP32[$15 + 4 >> 2] = $16$1;
    __label__ = 5;
    break;
   case 5:
    var $18 = $dst_01 + 8 | 0;
    var $19 = $src_02 + 8 | 0;
    var $20 = __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $18;
      var $src_02 = $19;
      __label__ = 3;
      break;
    }
   case 6:
    var $22 = $v + 4 | 0;
    var $24 = HEAP32[$22 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $24);
    HEAP32[$22 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_($1, $p_01);
    var $5 = __ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev($1);
    var $6 = $5;
    var $7 = $_02;
    var $8$0 = HEAP32[$6 >> 2];
    var $8$1 = HEAP32[$6 + 4 >> 2];
    HEAP32[$7 >> 2] = $8$0;
    HEAP32[$7 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    var $10 = $p_01 + 8 | 0;
    if (($10 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $10;
      var $_02 = $_02 + 8 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_($agg_result, $t);
  return;
}

function __ZL14id_constructorP9JSContext($cx_0_11_val_0_70_15_val) {
  var $1 = $cx_0_11_val_0_70_15_val | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1694($1);
  return $2;
}

function __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_($pool, $a) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$pool + 16 >> 2];
    var $4 = HEAP32[$pool + 24 >> 2];
    var $7 = $4 + 12 & ($4 ^ -1);
    var $8 = $2 + 12 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $11 = HEAPU32[$2 + 8 >> 2];
    if ($7 >>> 0 > $11 >>> 0 | $9 >>> 0 > ($11 - $7 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = _JS_ArenaAllocate($pool, $7);
    var $_p_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $19 = $7 + $9 | 0;
    HEAP32[$8 >> 2] = $19;
    var $_p_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      var $26 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $_p_0;
    var $24 = HEAP32[$a >> 2];
    __ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE($23, $24);
    var $26 = $23;
    __label__ = 6;
    break;
   case 6:
    var $26;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE($this, $object) {
  __ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE($this, $object);
  return;
}

function __ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE($this, $object) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV33TypeConstraintClearDefiniteSingle + 8 | 0;
  HEAP32[$this + 8 >> 2] = $object;
  return;
}

function __ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ((HEAP32[$2 + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = __ZNK2js5types7TypeSet9baseFlagsEv($source);
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js5types7TypeSet14getObjectCountEv($source);
    if ($11 >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($2, $cx);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE($this, $object) {
  __ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE($this, $object);
  return;
}

function __ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE($this, $object) {
  var $1 = $this | 0;
  __ZN2js5types14TypeConstraintC2EPKc($1, undef);
  HEAP32[$this >> 2] = __ZTV33TypeConstraintClearDefiniteSetter + 8 | 0;
  HEAP32[$this + 8 >> 2] = $object;
  return;
}

function __ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE($this, $cx, $source, $type) {
  var __stackBase__ = STACKTOP;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 8 >> 2];
    if ((HEAP32[$2 + 16 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 12 >> 2] & 2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = __ZNK2js5types4Type9isUnknownEv($type);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject14clearNewScriptEP9JSContext($2, $cx);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753($cx, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 10);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, 10);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_($2, $1);
  HEAP8[$this + 24 | 0] = 0;
  HEAP8[$this + 25 | 0] = 0;
  HEAP32[$this + 28 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSScript12clearNestingEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSScript7nestingEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_($5);
    var $8 = HEAP32[$this + 100 >> 2] + 12 | 0;
    HEAP32[$8 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5Shape16hasDefaultGetterEv($this);
    if ($1) {
      var $5 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js5Shape8isMethodEv($this);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types13ArrayTableKeyC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js5types4Type13UndefinedTypeEv($1);
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js2gc8CellIterD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 32 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 36 >> 2];
    __ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE($2, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE($this, $cx, $comp, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = $this + 32 | 0;
    var $3 = $comp + 8 | 0;
    HEAP32[$2 >> 2] = $3;
    HEAP32[$this + 36 >> 2] = $kind;
    var $5 = __ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE($3, $kind);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE($3, $kind);
    __label__ = 4;
    break;
   case 4:
    __ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE($1, $comp, $kind);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE($this, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + ($kind << 3) | 0;
    var $2 = __ZNK2js2gc8FreeSpan7isEmptyEv($1);
    if ($2) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2js2gc8FreeSpan11arenaHeaderEv($1);
    var $5 = __ZNK2js2gc11ArenaHeader13hasFreeThingsEv($4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeObjectC2EP8JSObjectbb($this, $proto, $function, $unknown) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_($this);
    HEAP32[$this >> 2] = $proto;
    if ($function) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 12 | 0;
    var $5 = HEAP32[$3 >> 2] | 1;
    HEAP32[$3 >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    if ($unknown) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] | 33488904;
    HEAP32[$8 >> 2] = $10;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function __ZN2js5types10TypeObject9getGlobalEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $_0 = $6;
    __label__ = 6;
    break;
   case 3:
    var $10 = HEAP32[$this + 28 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK10JSFunction6scriptEv($10);
    if ((HEAP8[$13 + 36 | 0] & 16) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $10;
    var $20 = __ZNK8JSObject9getGlobalEv($19);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13GetScopeChainEP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790($cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 132 >> 2];
    HEAP32[$obj >> 2] = $5;
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj);
    var $_0 = HEAP32[$obj >> 2];
    __label__ = 6;
    break;
   case 5:
    var $11 = __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $1);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var $1 = __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp);
  var $2 = __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $1);
  return $2;
}

function __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame13isScriptFrameEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame11hasImacropcEv($fp);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = __ZNK2js10StackFrame8imacropcEv($fp);
    var $12 = $5;
    __label__ = 5;
    break;
   case 4:
    var $8 = $fp;
    var $9 = $cx + 60 | 0;
    var $10 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($8, $9, 0, 0);
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    var $13 = __ZNK2js10StackFrame6scriptEv($fp);
    var $15 = HEAPU32[$13 >> 2];
    var $16 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $12);
    var $target_0 = $12;
    var $op_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $op_0;
    var $target_0;
    if (($op_0 | 0) == 213 || ($op_0 | 0) == 212 || ($op_0 | 0) == 211 || ($op_0 | 0) == 191 || ($op_0 | 0) == 189 || ($op_0 | 0) == 188 || ($op_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($15 >>> 0 < $target_0 >>> 0) {
      var $blockChain_021 = 0;
      var $indexBase_022 = 0;
      var $pc_023 = $15;
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 8:
    var $22 = $target_0 + (HEAP8[_js_CodeSpec + ($op_0 << 3) | 0] << 24 >> 24) | 0;
    var $23 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $22);
    var $target_0 = $22;
    var $op_0 = $23;
    __label__ = 6;
    break;
   case 9:
    var $pc_023;
    var $indexBase_022;
    var $blockChain_021;
    var $24 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($13, $pc_023);
    var $26 = HEAP8[_js_CodeSpec + ($24 << 3) | 0];
    var $27 = $26 << 24 >> 24;
    if ($26 << 24 >> 24 < 0) {
      __label__ = 10;
      break;
    } else {
      var $oplen_0 = $27;
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = __Z28js_GetVariableBytecodeLengthPh($pc_023);
    var $oplen_0 = $30;
    __label__ = 11;
    break;
   case 11:
    var $oplen_0;
    if (($24 | 0) == 191) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $indexBase_1 = (HEAPU8[$pc_023 + 1 | 0] & 255) << 16;
    var $blockChain_1 = $blockChain_021;
    __label__ = 21;
    break;
   case 13:
    if (($24 - 211 | 0) >>> 0 < 3) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $indexBase_1 = ($24 << 16) - 13762560 | 0;
    var $blockChain_1 = $blockChain_021;
    __label__ = 21;
    break;
   case 15:
    if (($24 - 192 | 0) >>> 0 < 2) {
      var $indexBase_1 = 0;
      var $blockChain_1 = $blockChain_021;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($24 | 0) == 201) {
      __label__ = 17;
      break;
    } else if (($24 | 0) == 210 || ($24 | 0) == 202) {
      __label__ = 18;
      break;
    } else if (($24 | 0) == 188) {
      __label__ = 19;
      break;
    } else if (($24 | 0) == 189) {
      __label__ = 20;
      break;
    } else {
      var $indexBase_1 = $indexBase_022;
      var $blockChain_1 = $blockChain_021;
      __label__ = 21;
      break;
    }
   case 17:
    var $55 = ((HEAPU8[$pc_023 + 1 | 0] & 255) << 8 | HEAPU8[$pc_023 + 2 | 0] & 255) + $indexBase_022 | 0;
    var $56 = __ZN8JSScript9getObjectEj($13, $55);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $56;
    __label__ = 21;
    break;
   case 18:
    var $58 = __ZNK8JSObject9getParentEv($blockChain_021);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $58;
    __label__ = 21;
    break;
   case 19:
    var $68 = ((HEAPU8[$pc_023 + 1 | 0] & 255) << 8 | HEAPU8[$pc_023 + 2 | 0] & 255) + $indexBase_022 | 0;
    var $69 = __ZN8JSScript9getObjectEj($13, $68);
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = $69;
    __label__ = 21;
    break;
   case 20:
    var $indexBase_1 = $indexBase_022;
    var $blockChain_1 = 0;
    __label__ = 21;
    break;
   case 21:
    var $blockChain_1;
    var $indexBase_1;
    var $72 = $pc_023 + $oplen_0 | 0;
    if ($72 >>> 0 < $target_0 >>> 0) {
      var $blockChain_021 = $blockChain_1;
      var $indexBase_022 = $indexBase_1;
      var $pc_023 = $72;
      __label__ = 9;
      break;
    } else {
      var $_0 = $blockChain_1;
      __label__ = 22;
      break;
    }
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, $op, $oplen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $fp;
    var $3 = $cx + 60 | 0;
    var $4 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($2, $3, 0, 0);
    var $6 = HEAP8[$4 + $oplen | 0];
    if ($6 << 24 >> 24 == -68) {
      __label__ = 2;
      break;
    } else if ($6 << 24 >> 24 == -67) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZNK2js10StackFrame6scriptEv($fp);
    var $16 = (HEAPU8[$oplen + ($4 + 1) | 0] & 255) << 8 | HEAPU8[$oplen + ($4 + 2) | 0] & 255;
    var $17 = __ZN8JSScript9getObjectEj($8, $16);
    var $_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $19 = __ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE($cx, $fp);
    var $_0 = $19;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $blockChain) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    if (($blockChain | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $_1 = $3;
    __label__ = 17;
    break;
   case 3:
    var $5 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($fp);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2js10StackFrame10hasCallObjEv($fp);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $fp);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      var $limitBlock_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $12 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $13 = __ZNK8JSObject6isWithEv($12);
    if ($13) {
      var $limitClone_03 = $12;
      __label__ = 7;
      break;
    } else {
      var $limitClone_0_lcssa = $12;
      __label__ = 8;
      break;
    }
   case 7:
    var $limitClone_03;
    var $14 = __ZNK8JSObject9getParentEv($limitClone_03);
    var $15 = __ZNK8JSObject6isWithEv($14);
    if ($15) {
      var $limitClone_03 = $14;
      __label__ = 7;
      break;
    } else {
      var $limitClone_0_lcssa = $14;
      __label__ = 8;
      break;
    }
   case 8:
    var $limitClone_0_lcssa;
    var $16 = __ZNK8JSObject8getProtoEv($limitClone_0_lcssa);
    if (($16 | 0) == ($blockChain | 0)) {
      __label__ = 9;
      break;
    } else {
      var $limitBlock_0 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $19 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $_1 = $19;
    __label__ = 17;
    break;
   case 10:
    var $limitBlock_0;
    var $21 = $cx;
    var $22 = $blockChain;
    var $23 = $fp;
    var $24 = __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($21, $22, $23);
    var $25 = $24;
    if (($24 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $cx, $25);
    var $newChild_0 = $25;
    var $sharedBlock_0 = $blockChain;
    __label__ = 12;
    break;
   case 12:
    var $sharedBlock_0;
    var $newChild_0;
    var $29 = __ZNK8JSObject9getParentEv($sharedBlock_0);
    if (($29 | 0) != ($limitBlock_0 | 0) & ($29 | 0) != 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $33 = $29;
    var $34 = __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($21, $33, $23);
    var $35 = $34;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN8JSObject9setParentEPS_($newChild_0, $35);
    var $newChild_0 = $35;
    var $sharedBlock_0 = $29;
    __label__ = 12;
    break;
   case 15:
    var $39 = __ZNK2js10StackFrame10scopeChainEv($fp);
    __ZN8JSObject9setParentEPS_($newChild_0, $39);
    var $40 = $fp;
    var $41 = $24;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($40, $41);
    var $_0 = $25;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject["X"] = 1;

function __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, $op, $oplen) {
  var $1 = __ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $fp, undef, $oplen);
  var $2 = __ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject($cx, $fp, $1);
  return $2;
}

function __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funNameBytes = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = __Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj($cx, $vp, 0);
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $5 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($cx, $2, $funNameBytes);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$clasp >> 2];
    var $10 = __ZN2js21InformalValueTypeNameERKN2JS5ValueE($1);
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $9, HEAP32[tempInt + 4 >> 2] = $5, HEAP32[tempInt + 8 >> 2] = $10, tempInt));
    __label__ = 4;
    break;
   case 4:
    __ZN16JSAutoByteStringD1Ev($funNameBytes);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($cx, $call) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js12CallReceiver5thisvEv($call);
    var $2 = __ZNK2JS5Value17isNullOrUndefinedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK2js12CallReceiver6calleeEv($call);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZN8JSObject10thisObjectEP9JSContext($7, $cx);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js12CallReceiver5thisvEv($call);
    __ZN2JS5Value9setObjectER8JSObject($11, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = __ZNK2JS5Value8isObjectEv($1);
    if ($13) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $cx;
    var $16 = __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($15, $1);
    var $_0 = ($16 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10thisObjectEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject6getOpsEv($this);
    var $3 = HEAP32[$1 + 124 >> 2];
    if (($3 | 0) == 0) {
      var $8 = $this;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = FUNCTION_TABLE[$3]($cx, $this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20no_such_method_traceP8JSTracerP8JSObject($trc, $obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 0);
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $1, undef);
  var $2 = __ZNK8JSObject7getSlotEj($obj, 1);
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($trc, $2, undef);
  return;
}

function __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $tvr = __stackBase__ + 4;
    var $1 = __stackBase__ + 28;
    var $2 = $vp + 8 | 0;
    var $3 = __ZNK2JS5Value8toObjectEv($2);
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210280 >> 2] | 0;
    var $9 = __ZL12ATOM_TO_JSIDP6JSAtom1798($8);
    HEAP32[$id >> 2] = $9;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $10 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $11 = $cx;
    var $12 = $3;
    var $13 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($11, $12, $9, 2, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = __ZNK9JSContext2fpEv($cx);
    var $17 = __ZNK2js10StackFrame6scriptEv($16);
    var $18 = __ZNK9JSContext4regsEv($cx);
    var $20 = HEAP32[$18 + 4 >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $17, $20);
    var $21 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $22 = __ZNK2JS5Value11isPrimitiveEv($21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $24 = $21 | 0;
    var $25$0 = HEAP32[$24 >> 2];
    var $25$1 = HEAP32[$24 + 4 >> 2];
    var $26 = $vp | 0;
    HEAP32[$26 >> 2] = $25$0;
    HEAP32[$26 + 4 >> 2] = $25$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    var $28 = __ZNK2JS5Value8isObjectEv($vp);
    if ($28) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $30 = __ZNK2JS5Value8toObjectEv($vp);
    var $31 = $30;
    var $32 = $cx;
    var $33 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($31, $id, $32);
    if ($33) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $35 = HEAP32[$id >> 2];
    __ZN2jsL9IdToValueEi1799($1, $35);
    var $36 = $1 | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $vp | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    __label__ = 7;
    break;
   case 7:
    var $40 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, 2);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($40, undef, _js_NoSuchMethodClass, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    __ZN8JSObject21setSharedNonNativeMapEv($40);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($40, 0, $21);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($40, 1, $vp);
    __ZN2JS5Value9setObjectER8JSObject($vp, $40);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom1798($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1904($1);
  return $2;
}

function __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type11UnknownTypeEv($1);
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi1799($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1834($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1867($id);
    __ZN2JSL11StringValueEP8JSString1846($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1835($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1836($id);
    __ZN2JSL10Int32ValueEi1832($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1900($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1901($id);
    __ZN2JSL11ObjectValueER8JSObject1804($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1839($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $script, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 36 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame10scopeChainEv($fp);
    var $7 = $6;
    var $8 = __ZNK8JSObject9getGlobalEv($7);
    var $9 = $8;
    var $10 = __ZNK2js12GlobalObject9isClearedEv($9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 269, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE($cx, $fp, 0);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE($cx, $entryFrame, $interpMode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1444;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $switchMask = __stackBase__ + 8;
    var $interruptEnabler = __stackBase__ + 12;
    var $regs = __stackBase__ + 24;
    var $interpGuard = __stackBase__ + 40;
    var $interpreterFrame = __stackBase__ + 52;
    var $stackDummy_ = __stackBase__ + 68;
    var $rval = __stackBase__ + 72;
    var $1 = __stackBase__ + 80;
    var $id = __stackBase__ + 88;
    var $i_ = __stackBase__ + 92;
    var $obj2 = __stackBase__ + 96;
    var $prop = __stackBase__ + 100;
    var $cond15 = __stackBase__ + 104;
    var $id23 = __stackBase__ + 108;
    var $i_25 = __stackBase__ + 112;
    var $obj26 = __stackBase__ + 116;
    var $entry = __stackBase__ + 120;
    var $obj227 = __stackBase__ + 124;
    var $atom28 = __stackBase__ + 128;
    var $i30 = __stackBase__ + 132;
    var $j = __stackBase__ + 136;
    var $i31 = __stackBase__ + 140;
    var $j32 = __stackBase__ + 144;
    var $i33 = __stackBase__ + 148;
    var $j34 = __stackBase__ + 152;
    var $rval35 = __stackBase__ + 156;
    var $lval36 = __stackBase__ + 164;
    var $cond37 = __stackBase__ + 172;
    var $rval39 = __stackBase__ + 176;
    var $lval40 = __stackBase__ + 184;
    var $cond41 = __stackBase__ + 192;
    var $equal = __stackBase__ + 196;
    var $equal49 = __stackBase__ + 200;
    var $equal53 = __stackBase__ + 204;
    var $equal57 = __stackBase__ + 208;
    var $result = __stackBase__ + 212;
    var $l61 = __stackBase__ + 216;
    var $r62 = __stackBase__ + 224;
    var $result69 = __stackBase__ + 232;
    var $l70 = __stackBase__ + 236;
    var $r71 = __stackBase__ + 244;
    var $result78 = __stackBase__ + 252;
    var $l79 = __stackBase__ + 256;
    var $r80 = __stackBase__ + 264;
    var $result87 = __stackBase__ + 272;
    var $l88 = __stackBase__ + 276;
    var $r89 = __stackBase__ + 284;
    var $i91 = __stackBase__ + 292;
    var $j92 = __stackBase__ + 296;
    var $i93 = __stackBase__ + 300;
    var $j94 = __stackBase__ + 304;
    var $u = __stackBase__ + 308;
    var $j95 = __stackBase__ + 312;
    var $rval96 = __stackBase__ + 316;
    var $lval97 = __stackBase__ + 324;
    var $l100 = __stackBase__ + 332;
    var $r101 = __stackBase__ + 340;
    var $rval102 = __stackBase__ + 348;
    var $lval103 = __stackBase__ + 356;
    var $d1 = __stackBase__ + 364;
    var $d2 = __stackBase__ + 372;
    var $rval104 = __stackBase__ + 380;
    var $lval105 = __stackBase__ + 388;
    var $d1106 = __stackBase__ + 396;
    var $d2107 = __stackBase__ + 404;
    var $rval109 = __stackBase__ + 412;
    var $lval110 = __stackBase__ + 420;
    var $d1111 = __stackBase__ + 428;
    var $d2112 = __stackBase__ + 436;
    var $d1117 = __stackBase__ + 444;
    var $d2118 = __stackBase__ + 452;
    var $i121 = __stackBase__ + 460;
    var $ref122 = __stackBase__ + 464;
    var $d124 = __stackBase__ + 472;
    var $obj127 = __stackBase__ + 480;
    var $obj2128 = __stackBase__ + 484;
    var $prop129 = __stackBase__ + 488;
    var $rval134 = __stackBase__ + 492;
    var $id137 = __stackBase__ + 500;
    var $i_139 = __stackBase__ + 504;
    var $id142 = __stackBase__ + 508;
    var $i_144 = __stackBase__ + 512;
    var $2 = __stackBase__ + 516;
    var $obj147 = __stackBase__ + 524;
    var $atom148 = __stackBase__ + 528;
    var $id149 = __stackBase__ + 532;
    var $i_153 = __stackBase__ + 536;
    var $obj2154 = __stackBase__ + 540;
    var $entry155 = __stackBase__ + 544;
    var $3 = __stackBase__ + 548;
    var $prop157 = __stackBase__ + 556;
    var $rf160 = __stackBase__ + 560;
    var $rf161 = __stackBase__ + 568;
    var $rval168 = __stackBase__ + 576;
    var $4 = __stackBase__ + 584;
    var $5 = __stackBase__ + 592;
    var $6 = __stackBase__ + 600;
    var $7 = __stackBase__ + 608;
    var $8 = __stackBase__ + 616;
    var $aobj = __stackBase__ + 624;
    var $entry173 = __stackBase__ + 628;
    var $obj2174 = __stackBase__ + 632;
    var $atom175 = __stackBase__ + 636;
    var $lval178 = __stackBase__ + 640;
    var $objv = __stackBase__ + 648;
    var $pobj = __stackBase__ + 656;
    var $aobj179 = __stackBase__ + 660;
    var $rval180 = __stackBase__ + 664;
    var $entry181 = __stackBase__ + 672;
    var $obj2182 = __stackBase__ + 676;
    var $atom183 = __stackBase__ + 680;
    var $rval187 = __stackBase__ + 684;
    var $entry190 = __stackBase__ + 692;
    var $obj2191 = __stackBase__ + 696;
    var $atom192 = __stackBase__ + 700;
    var $slot194 = __stackBase__ + 704;
    var $rval201 = __stackBase__ + 708;
    var $id202 = __stackBase__ + 716;
    var $i205 = __stackBase__ + 720;
    var $thisv206 = __stackBase__ + 724;
    var $id207 = __stackBase__ + 732;
    var $i_209 = __stackBase__ + 736;
    var $id212 = __stackBase__ + 740;
    var $i_214 = __stackBase__ + 744;
    var $rval215 = __stackBase__ + 748;
    var $id221 = __stackBase__ + 756;
    var $i_223 = __stackBase__ + 760;
    var $rval224 = __stackBase__ + 764;
    var $args = __stackBase__ + 772;
    var $args225 = __stackBase__ + 780;
    var $callee = __stackBase__ + 788;
    var $fun = __stackBase__ + 792;
    var $obj226 = __stackBase__ + 796;
    var $rval229 = __stackBase__ + 800;
    var $entry230 = __stackBase__ + 808;
    var $obj2231 = __stackBase__ + 812;
    var $atom232 = __stackBase__ + 816;
    var $v = __stackBase__ + 820;
    var $prop235 = __stackBase__ + 828;
    var $v236 = __stackBase__ + 832;
    var $proto = __stackBase__ + 840;
    var $lval251 = __stackBase__ + 844;
    var $rval253 = __stackBase__ + 852;
    var $rval254 = __stackBase__ + 860;
    var $rval255 = __stackBase__ + 868;
    var $rval256 = __stackBase__ + 876;
    var $9 = __stackBase__ + 884;
    var $rval258 = __stackBase__ + 892;
    var $10 = __stackBase__ + 900;
    var $rval260 = __stackBase__ + 908;
    var $rval262 = __stackBase__ + 916;
    var $prop274 = __stackBase__ + 924;
    var $obj2275 = __stackBase__ + 928;
    var $11 = __stackBase__ + 932;
    var $prop281 = __stackBase__ + 940;
    var $pobj282 = __stackBase__ + 944;
    var $rval283 = __stackBase__ + 948;
    var $bytes = __stackBase__ + 956;
    var $12 = __stackBase__ + 960;
    var $rval287 = __stackBase__ + 968;
    var $callee304 = __stackBase__ + 976;
    var $id308 = __stackBase__ + 980;
    var $rval309 = __stackBase__ + 984;
    var $i_317 = __stackBase__ + 992;
    var $rtmp = __stackBase__ + 996;
    var $attrs318 = __stackBase__ + 1004;
    var $13 = __stackBase__ + 1008;
    var $rval326 = __stackBase__ + 1016;
    var $entry328 = __stackBase__ + 1024;
    var $shape329 = __stackBase__ + 1028;
    var $slot330 = __stackBase__ + 1032;
    var $id337 = __stackBase__ + 1036;
    var $i_339 = __stackBase__ + 1040;
    var $numBuf = __stackBase__ + 1044;
    var $rval349 = __stackBase__ + 1056;
    var $numBuf352 = __stackBase__ + 1064;
    var $rval355 = __stackBase__ + 1076;
    var $rval358 = __stackBase__ + 1084;
    var $lval359 = __stackBase__ + 1092;
    var $14 = __stackBase__ + 1100;
    var $15 = __stackBase__ + 1108;
    var $16 = __stackBase__ + 1116;
    var $17 = __stackBase__ + 1124;
    var $cond367 = __stackBase__ + 1132;
    var $rval368 = __stackBase__ + 1136;
    var $18 = __stackBase__ + 1144;
    var $id369 = __stackBase__ + 1152;
    var $19 = __stackBase__ + 1156;
    var $rval372 = __stackBase__ + 1164;
    var $lval373 = __stackBase__ + 1172;
    var $rval375 = __stackBase__ + 1180;
    var $lval376 = __stackBase__ + 1188;
    var $rval378 = __stackBase__ + 1196;
    var $rval379 = __stackBase__ + 1204;
    var $rval381 = __stackBase__ + 1212;
    var $lval382 = __stackBase__ + 1220;
    var $lval385 = __stackBase__ + 1228;
    var $obj386 = __stackBase__ + 1236;
    var $id387 = __stackBase__ + 1240;
    var $20 = __stackBase__ + 1244;
    var $rval389 = __stackBase__ + 1252;
    var $id390 = __stackBase__ + 1260;
    var $i_392 = __stackBase__ + 1264;
    var $lval393 = __stackBase__ + 1268;
    var $obj394 = __stackBase__ + 1276;
    var $id395 = __stackBase__ + 1280;
    var $rval396 = __stackBase__ + 1284;
    var $v397 = __stackBase__ + 1292;
    var $rval400 = __stackBase__ + 1300;
    var $21 = __stackBase__ + 1308;
    var $rval402 = __stackBase__ + 1316;
    var $rval404 = __stackBase__ + 1324;
    var $rval406 = __stackBase__ + 1332;
    var $rval408 = __stackBase__ + 1340;
    var $rval418 = __stackBase__ + 1348;
    var $rval421 = __stackBase__ + 1356;
    var $22 = __stackBase__ + 1364;
    var $numBuf429 = __stackBase__ + 1372;
    var $rval432 = __stackBase__ + 1384;
    var $23 = __stackBase__ + 1392;
    var $24 = __stackBase__ + 1400;
    var $25 = __stackBase__ + 1408;
    var $v435 = __stackBase__ + 1416;
    var $26 = __stackBase__ + 1424;
    var $27 = __stackBase__ + 1432;
    var $printable = __stackBase__ + 1440;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $cx, 65535);
    HEAP32[$switchMask >> 2] = 0;
    __ZN23GenericInterruptEnablerIiEC1EPii($interruptEnabler, $switchMask, -1);
    var $28 = __ZNK9JSContext4regsEv($cx);
    var $29 = $regs;
    var $30 = $28;
    HEAP32[$29 >> 2] = HEAP32[$30 >> 2];
    HEAP32[$29 + 4 >> 2] = HEAP32[$30 + 4 >> 2];
    HEAP32[$29 + 8 >> 2] = HEAP32[$30 + 8 >> 2];
    HEAP32[$29 + 12 >> 2] = HEAP32[$30 + 12 >> 2];
    __ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE($interpGuard, $cx, $regs);
    var $31 = $interruptEnabler | 0;
    __ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($interpreterFrame, $cx, $regs, $31);
    var $32 = $cx + 52 | 0;
    var $33 = HEAPU32[$32 >> 2];
    var $34 = __ZNK2js9FrameRegs2fpEv($regs);
    var $35 = __ZNK2js10StackFrame6scriptEv($34);
    var $36 = __ZN8JSScript15stepModeEnabledEv($35);
    if ($36) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 3;
    break;
   case 3:
    var $39 = $35 + 92 | 0;
    var $40 = __ZN12JSPCCounters3getEi($39, 0);
    if (($40 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 5;
    break;
   case 5:
    var $44 = __ZNK2js9FrameRegs2fpEv($regs);
    var $45 = __ZNK2js10StackFrame15maybeFormalArgsEv($44);
    var $46 = $cx + 200 | 0;
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 7;
    break;
   case 7:
    if (($entryFrame | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_08 = $entryFrame;
      __label__ = 9;
      break;
    }
   case 8:
    var $55 = __ZNK2js9FrameRegs2fpEv($regs);
    var $_08 = $55;
    __label__ = 9;
    break;
   case 9:
    var $_08;
    var $58 = HEAP32[$35 + 56 >> 2];
    var $59 = __ZNK2js9FrameRegs2fpEv($regs);
    var $60 = __ZNK2js10StackFrame16isGeneratorFrameEv($59);
    if ($60) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $62 = __ZN9JSContext18isExceptionPendingEv($cx);
    if ($62) {
      var $_4_ph1348 = $interpMode;
      var $script_2_ph1347 = $35;
      var $pcCounts_2_ph1346 = $40;
      var $argv_2_ph1345 = $45;
      __label__ = 1016;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($interpMode | 0) == 0) {
      __label__ = 12;
      break;
    } else if (($interpMode | 0) == 4) {
      __label__ = 13;
      break;
    } else {
      var $_09 = $interpMode;
      __label__ = 14;
      break;
    }
   case 12:
    var $65 = __ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE($cx, $59);
    var $66 = __ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb($cx, $59, $65);
    if ($66) {
      var $_09 = 0;
      __label__ = 14;
      break;
    } else {
      var $_4_ph1348 = 0;
      var $script_2_ph1347 = $35;
      var $pcCounts_2_ph1346 = $40;
      var $argv_2_ph1345 = $45;
      __label__ = 1016;
      break;
    }
   case 13:
    var $_09 = 0;
    __label__ = 14;
    break;
   case 14:
    var $_09;
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 16;
    break;
   case 16:
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $_1_ph = $_09;
    var $script_0_ph = $35;
    var $pcCounts_0_ph = $40;
    var $argv_0_ph = $45;
    var $atoms_0_ph = $58;
    var $len_0_ph1296 = 0;
    var $_pre_phi = $regs + 4 | 0;
    var $_pre_phi80 = $regs | 0;
    __label__ = 1036;
    break;
   case 18:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_4_ph1348 = $_09;
    var $script_2_ph1347 = $35;
    var $pcCounts_2_ph1346 = $40;
    var $argv_2_ph1345 = $45;
    __label__ = 1016;
    break;
   case 19:
    var $len_0;
    var $atoms_0;
    var $argv_0;
    var $pcCounts_0;
    var $script_0;
    var $_1;
    var $80 = HEAP32[$_pre_phi >> 2] + $len_0 | 0;
    HEAP32[$_pre_phi >> 2] = $80;
    var $_2 = $_1;
    var $script_1 = $script_0;
    var $pcCounts_1 = $pcCounts_0;
    var $argv_1 = $argv_0;
    var $atoms_1 = $atoms_0;
    var $op_0 = HEAPU8[$80] & 255;
    __label__ = 20;
    break;
   case 20:
    var $op_0;
    var $atoms_1;
    var $argv_1;
    var $pcCounts_1;
    var $script_1;
    var $_2;
    var $85 = ($pcCounts_1 | 0) == 0;
    var $86 = $script_1 | 0;
    var $switchOp_0 = HEAP32[$switchMask >> 2] | $op_0;
    __label__ = 21;
    break;
   case 21:
    var $switchOp_0;
    if (($switchOp_0 | 0) == 0 || ($switchOp_0 | 0) == 120 || ($switchOp_0 | 0) == 134 || ($switchOp_0 | 0) == 194 || ($switchOp_0 | 0) == 195 || ($switchOp_0 | 0) == 189 || ($switchOp_0 | 0) == 92) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else if (($switchOp_0 | 0) == -1) {
      __label__ = 22;
      break;
    } else if (($switchOp_0 | 0) == 109 || ($switchOp_0 | 0) == 182) {
      __label__ = 34;
      break;
    } else if (($switchOp_0 | 0) == 119) {
      __label__ = 37;
      break;
    } else if (($switchOp_0 | 0) == 188) {
      __label__ = 38;
      break;
    } else if (($switchOp_0 | 0) == 1) {
      __label__ = 39;
      break;
    } else if (($switchOp_0 | 0) == 81) {
      __label__ = 40;
      break;
    } else if (($switchOp_0 | 0) == 11) {
      __label__ = 41;
      break;
    } else if (($switchOp_0 | 0) == 154 || ($switchOp_0 | 0) == 2) {
      __label__ = 42;
      break;
    } else if (($switchOp_0 | 0) == 3) {
      __label__ = 43;
      break;
    } else if (($switchOp_0 | 0) == 4) {
      __label__ = 45;
      break;
    } else if (($switchOp_0 | 0) == 5) {
      __label__ = 46;
      break;
    } else if (($switchOp_0 | 0) == 155 || ($switchOp_0 | 0) == 197) {
      __label__ = 47;
      break;
    } else if (($switchOp_0 | 0) == 122) {
      __label__ = 58;
      break;
    } else if (($switchOp_0 | 0) == 6) {
      __label__ = 59;
      break;
    } else if (($switchOp_0 | 0) == 7) {
      __label__ = 60;
      break;
    } else if (($switchOp_0 | 0) == 8) {
      __label__ = 67;
      break;
    } else if (($switchOp_0 | 0) == 68) {
      __label__ = 74;
      break;
    } else if (($switchOp_0 | 0) == 69) {
      __label__ = 81;
      break;
    } else if (($switchOp_0 | 0) == 148) {
      __label__ = 88;
      break;
    } else if (($switchOp_0 | 0) == 141) {
      __label__ = 89;
      break;
    } else if (($switchOp_0 | 0) == 142) {
      __label__ = 90;
      break;
    } else if (($switchOp_0 | 0) == 143) {
      __label__ = 97;
      break;
    } else if (($switchOp_0 | 0) == 144) {
      __label__ = 104;
      break;
    } else if (($switchOp_0 | 0) == 145) {
      __label__ = 111;
      break;
    } else if (($switchOp_0 | 0) == 113) {
      __label__ = 118;
      break;
    } else if (($switchOp_0 | 0) == 75) {
      __label__ = 130;
      break;
    } else if (($switchOp_0 | 0) == 76) {
      __label__ = 133;
      break;
    } else if (($switchOp_0 | 0) == 77) {
      __label__ = 137;
      break;
    } else if (($switchOp_0 | 0) == 78) {
      __label__ = 138;
      break;
    } else if (($switchOp_0 | 0) == 12) {
      __label__ = 139;
      break;
    } else if (($switchOp_0 | 0) == 13) {
      __label__ = 140;
      break;
    } else if (($switchOp_0 | 0) == 10) {
      __label__ = 141;
      break;
    } else if (($switchOp_0 | 0) == 133) {
      __label__ = 142;
      break;
    } else if (($switchOp_0 | 0) == 14) {
      __label__ = 143;
      break;
    } else if (($switchOp_0 | 0) == 209) {
      __label__ = 146;
      break;
    } else if (($switchOp_0 | 0) == 217) {
      __label__ = 157;
      break;
    } else if (($switchOp_0 | 0) == 110) {
      __label__ = 158;
      break;
    } else if (($switchOp_0 | 0) == 105) {
      __label__ = 163;
      break;
    } else if (($switchOp_0 | 0) == 15) {
      __label__ = 164;
      break;
    } else if (($switchOp_0 | 0) == 16) {
      __label__ = 167;
      break;
    } else if (($switchOp_0 | 0) == 17) {
      __label__ = 170;
      break;
    } else if (($switchOp_0 | 0) == 18) {
      __label__ = 173;
      break;
    } else if (($switchOp_0 | 0) == 19) {
      __label__ = 178;
      break;
    } else if (($switchOp_0 | 0) == 72) {
      __label__ = 183;
      break;
    } else if (($switchOp_0 | 0) == 73) {
      __label__ = 185;
      break;
    } else if (($switchOp_0 | 0) == 121) {
      __label__ = 187;
      break;
    } else if (($switchOp_0 | 0) == 147) {
      __label__ = 190;
      break;
    } else if (($switchOp_0 | 0) == 20) {
      __label__ = 193;
      break;
    } else if (($switchOp_0 | 0) == 21) {
      __label__ = 209;
      break;
    } else if (($switchOp_0 | 0) == 22) {
      __label__ = 225;
      break;
    } else if (($switchOp_0 | 0) == 23) {
      __label__ = 241;
      break;
    } else if (($switchOp_0 | 0) == 24) {
      __label__ = 257;
      break;
    } else if (($switchOp_0 | 0) == 25) {
      __label__ = 260;
      break;
    } else if (($switchOp_0 | 0) == 26) {
      __label__ = 263;
      break;
    } else if (($switchOp_0 | 0) == 27) {
      __label__ = 267;
      break;
    } else if (($switchOp_0 | 0) == 28) {
      __label__ = 300;
      break;
    } else if (($switchOp_0 | 0) == 29) {
      __label__ = 306;
      break;
    } else if (($switchOp_0 | 0) == 30) {
      __label__ = 312;
      break;
    } else if (($switchOp_0 | 0) == 31) {
      __label__ = 319;
      break;
    } else if (($switchOp_0 | 0) == 32) {
      __label__ = 330;
      break;
    } else if (($switchOp_0 | 0) == 33) {
      __label__ = 335;
      break;
    } else if (($switchOp_0 | 0) == 34) {
      __label__ = 337;
      break;
    } else if (($switchOp_0 | 0) == 35) {
      __label__ = 344;
      break;
    } else if (($switchOp_0 | 0) == 36) {
      __label__ = 347;
      break;
    } else if (($switchOp_0 | 0) == 37) {
      __label__ = 350;
      break;
    } else if (($switchOp_0 | 0) == 38) {
      __label__ = 356;
      break;
    } else if (($switchOp_0 | 0) == 231) {
      __label__ = 367;
      break;
    } else if (($switchOp_0 | 0) == 200 || ($switchOp_0 | 0) == 39) {
      __label__ = 377;
      break;
    } else if (($switchOp_0 | 0) == 40) {
      __label__ = 378;
      break;
    } else if (($switchOp_0 | 0) == 43 || ($switchOp_0 | 0) == 46 || ($switchOp_0 | 0) == 49 || ($switchOp_0 | 0) == 52) {
      __label__ = 379;
      break;
    } else if (($switchOp_0 | 0) == 42 || ($switchOp_0 | 0) == 45 || ($switchOp_0 | 0) == 48 || ($switchOp_0 | 0) == 51) {
      __label__ = 380;
      break;
    } else if (($switchOp_0 | 0) == 41 || ($switchOp_0 | 0) == 44 || ($switchOp_0 | 0) == 47 || ($switchOp_0 | 0) == 50 || ($switchOp_0 | 0) == 158 || ($switchOp_0 | 0) == 159 || ($switchOp_0 | 0) == 160 || ($switchOp_0 | 0) == 161) {
      __label__ = 392;
      break;
    } else if (($switchOp_0 | 0) == 99) {
      __label__ = 416;
      break;
    } else if (($switchOp_0 | 0) == 98) {
      __label__ = 417;
      break;
    } else if (($switchOp_0 | 0) == 100) {
      __label__ = 418;
      break;
    } else if (($switchOp_0 | 0) == 97) {
      var $incr2_0 = 1;
      var $incr163_0 = 1;
      __label__ = 419;
      break;
    } else if (($switchOp_0 | 0) == 103) {
      __label__ = 420;
      break;
    } else if (($switchOp_0 | 0) == 102) {
      __label__ = 421;
      break;
    } else if (($switchOp_0 | 0) == 104) {
      __label__ = 422;
      break;
    } else if (($switchOp_0 | 0) == 101) {
      var $incr2_1 = 1;
      var $incr163_1 = 1;
      __label__ = 423;
      break;
    } else if (($switchOp_0 | 0) == 65) {
      __label__ = 431;
      break;
    } else if (($switchOp_0 | 0) == 229) {
      __label__ = 433;
      break;
    } else if (($switchOp_0 | 0) == 53 || ($switchOp_0 | 0) == 198 || ($switchOp_0 | 0) == 220) {
      __label__ = 437;
      break;
    } else if (($switchOp_0 | 0) == 187) {
      __label__ = 471;
      break;
    } else if (($switchOp_0 | 0) == 228) {
      __label__ = 500;
      break;
    } else if (($switchOp_0 | 0) == 157 || ($switchOp_0 | 0) == 111 || ($switchOp_0 | 0) == 54 || ($switchOp_0 | 0) == 226) {
      __label__ = 501;
      break;
    } else if (($switchOp_0 | 0) == 55) {
      __label__ = 536;
      break;
    } else if (($switchOp_0 | 0) == 196) {
      __label__ = 572;
      break;
    } else if (($switchOp_0 | 0) == 56) {
      __label__ = 584;
      break;
    } else if (($switchOp_0 | 0) == 124) {
      __label__ = 608;
      break;
    } else if (($switchOp_0 | 0) == 123) {
      __label__ = 619;
      break;
    } else if (($switchOp_0 | 0) == 82 || ($switchOp_0 | 0) == 58 || ($switchOp_0 | 0) == 108 || ($switchOp_0 | 0) == 79) {
      __label__ = 625;
      break;
    } else if (($switchOp_0 | 0) == 74) {
      __label__ = 644;
      break;
    } else if (($switchOp_0 | 0) == 156 || ($switchOp_0 | 0) == 214 || ($switchOp_0 | 0) == 59 || ($switchOp_0 | 0) == 57) {
      __label__ = 645;
      break;
    } else if (($switchOp_0 | 0) == 88) {
      __label__ = 681;
      break;
    } else if (($switchOp_0 | 0) == 190) {
      __label__ = 682;
      break;
    } else if (($switchOp_0 | 0) == 218) {
      __label__ = 683;
      break;
    } else if (($switchOp_0 | 0) == 219) {
      __label__ = 684;
      break;
    } else if (($switchOp_0 | 0) == 191) {
      __label__ = 685;
      break;
    } else if (($switchOp_0 | 0) == 211 || ($switchOp_0 | 0) == 212 || ($switchOp_0 | 0) == 213) {
      __label__ = 686;
      break;
    } else if (($switchOp_0 | 0) == 193 || ($switchOp_0 | 0) == 192) {
      __label__ = 687;
      break;
    } else if (($switchOp_0 | 0) == 60) {
      __label__ = 688;
      break;
    } else if (($switchOp_0 | 0) == 61) {
      __label__ = 689;
      break;
    } else if (($switchOp_0 | 0) == 80) {
      __label__ = 690;
      break;
    } else if (($switchOp_0 | 0) == 162) {
      __label__ = 691;
      break;
    } else if (($switchOp_0 | 0) == 62) {
      __label__ = 694;
      break;
    } else if (($switchOp_0 | 0) == 63) {
      __label__ = 695;
      break;
    } else if (($switchOp_0 | 0) == 64) {
      __label__ = 696;
      break;
    } else if (($switchOp_0 | 0) == 66) {
      __label__ = 697;
      break;
    } else if (($switchOp_0 | 0) == 67) {
      __label__ = 698;
      break;
    } else if (($switchOp_0 | 0) == 70) {
      __label__ = 699;
      break;
    } else if (($switchOp_0 | 0) == 149) {
      __label__ = 706;
      break;
    } else if (($switchOp_0 | 0) == 71) {
      __label__ = 713;
      break;
    } else if (($switchOp_0 | 0) == 150) {
      var $off249_0 = 4;
      __label__ = 714;
      break;
    } else if (($switchOp_0 | 0) == 83) {
      __label__ = 732;
      break;
    } else if (($switchOp_0 | 0) == 9) {
      __label__ = 740;
      break;
    } else if (($switchOp_0 | 0) == 138) {
      __label__ = 748;
      break;
    } else if (($switchOp_0 | 0) == 139) {
      __label__ = 750;
      break;
    } else if (($switchOp_0 | 0) == 84 || ($switchOp_0 | 0) == 216) {
      __label__ = 752;
      break;
    } else if (($switchOp_0 | 0) == 85) {
      __label__ = 754;
      break;
    } else if (($switchOp_0 | 0) == 86) {
      __label__ = 756;
      break;
    } else if (($switchOp_0 | 0) == 215) {
      __label__ = 757;
      break;
    } else if (($switchOp_0 | 0) == 87) {
      __label__ = 758;
      break;
    } else if (($switchOp_0 | 0) == 136 || ($switchOp_0 | 0) == 137) {
      __label__ = 760;
      break;
    } else if (($switchOp_0 | 0) == 106 || ($switchOp_0 | 0) == 107 || ($switchOp_0 | 0) == 128 || ($switchOp_0 | 0) == 129) {
      __label__ = 762;
      break;
    } else if (($switchOp_0 | 0) == 127) {
      __label__ = 768;
      break;
    } else if (($switchOp_0 | 0) == 222) {
      __label__ = 787;
      break;
    } else if (($switchOp_0 | 0) == 140) {
      __label__ = 792;
      break;
    } else if (($switchOp_0 | 0) == 223) {
      __label__ = 798;
      break;
    } else if (($switchOp_0 | 0) == 130) {
      __label__ = 800;
      break;
    } else if (($switchOp_0 | 0) == 224) {
      __label__ = 816;
      break;
    } else if (($switchOp_0 | 0) == 131) {
      __label__ = 818;
      break;
    } else if (($switchOp_0 | 0) == 125 || ($switchOp_0 | 0) == 126) {
      var $atoms_2 = $atoms_1;
      __label__ = 819;
      break;
    } else if (($switchOp_0 | 0) == 221) {
      __label__ = 848;
      break;
    } else if (($switchOp_0 | 0) == 89) {
      __label__ = 849;
      break;
    } else if (($switchOp_0 | 0) == 90) {
      __label__ = 856;
      break;
    } else if (($switchOp_0 | 0) == 91) {
      __label__ = 860;
      break;
    } else if (($switchOp_0 | 0) == 93 || ($switchOp_0 | 0) == 227) {
      __label__ = 864;
      break;
    } else if (($switchOp_0 | 0) == 94) {
      __label__ = 874;
      break;
    } else if (($switchOp_0 | 0) == 95) {
      __label__ = 883;
      break;
    } else if (($switchOp_0 | 0) == 96) {
      __label__ = 890;
      break;
    } else if (($switchOp_0 | 0) == 230) {
      __label__ = 896;
      break;
    } else if (($switchOp_0 | 0) == 116) {
      __label__ = 903;
      break;
    } else if (($switchOp_0 | 0) == 146) {
      __label__ = 904;
      break;
    } else if (($switchOp_0 | 0) == 117) {
      __label__ = 905;
      break;
    } else if (($switchOp_0 | 0) == 118) {
      __label__ = 908;
      break;
    } else if (($switchOp_0 | 0) == 135) {
      __label__ = 910;
      break;
    } else if (($switchOp_0 | 0) == 153) {
      __label__ = 912;
      break;
    } else if (($switchOp_0 | 0) == 112) {
      __label__ = 913;
      break;
    } else if (($switchOp_0 | 0) == 132) {
      __label__ = 916;
      break;
    } else if (($switchOp_0 | 0) == 203) {
      __label__ = 917;
      break;
    } else if (($switchOp_0 | 0) == 204) {
      __label__ = 919;
      break;
    } else if (($switchOp_0 | 0) == 225) {
      __label__ = 923;
      break;
    } else if (($switchOp_0 | 0) == 114) {
      __label__ = 925;
      break;
    } else if (($switchOp_0 | 0) == 115) {
      __label__ = 929;
      break;
    } else if (($switchOp_0 | 0) == 163) {
      __label__ = 937;
      break;
    } else if (($switchOp_0 | 0) == 164) {
      __label__ = 939;
      break;
    } else if (($switchOp_0 | 0) == 165) {
      __label__ = 941;
      break;
    } else if (($switchOp_0 | 0) == 166) {
      __label__ = 942;
      break;
    } else if (($switchOp_0 | 0) == 167) {
      __label__ = 944;
      break;
    } else if (($switchOp_0 | 0) == 168) {
      __label__ = 946;
      break;
    } else if (($switchOp_0 | 0) == 169) {
      __label__ = 948;
      break;
    } else if (($switchOp_0 | 0) == 170 || ($switchOp_0 | 0) == 171) {
      __label__ = 950;
      break;
    } else if (($switchOp_0 | 0) == 172) {
      __label__ = 952;
      break;
    } else if (($switchOp_0 | 0) == 173) {
      __label__ = 954;
      break;
    } else if (($switchOp_0 | 0) == 199 || ($switchOp_0 | 0) == 174) {
      __label__ = 961;
      break;
    } else if (($switchOp_0 | 0) == 175 || ($switchOp_0 | 0) == 186) {
      __label__ = 966;
      break;
    } else if (($switchOp_0 | 0) == 176) {
      __label__ = 975;
      break;
    } else if (($switchOp_0 | 0) == 177) {
      __label__ = 976;
      break;
    } else if (($switchOp_0 | 0) == 178) {
      __label__ = 983;
      break;
    } else if (($switchOp_0 | 0) == 179) {
      __label__ = 985;
      break;
    } else if (($switchOp_0 | 0) == 180) {
      __label__ = 987;
      break;
    } else if (($switchOp_0 | 0) == 181) {
      __label__ = 989;
      break;
    } else if (($switchOp_0 | 0) == 183) {
      __label__ = 995;
      break;
    } else if (($switchOp_0 | 0) == 184) {
      __label__ = 997;
      break;
    } else if (($switchOp_0 | 0) == 185) {
      __label__ = 999;
      break;
    } else if (($switchOp_0 | 0) == 208) {
      __label__ = 1001;
      break;
    } else if (($switchOp_0 | 0) == 201) {
      __label__ = 1003;
      break;
    } else if (($switchOp_0 | 0) == 210 || ($switchOp_0 | 0) == 202) {
      __label__ = 1004;
      break;
    } else if (($switchOp_0 | 0) == 205) {
      __label__ = 1008;
      break;
    } else if (($switchOp_0 | 0) == 206) {
      __label__ = 1010;
      break;
    } else if (($switchOp_0 | 0) == 207) {
      __label__ = 1013;
      break;
    } else {
      __label__ = 1015;
      break;
    }
   case 22:
    if ($85) {
      var $moreInterrupts_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $90 = __ZNK2js9FrameRegs2fpEv($regs);
    var $91 = __ZNK2js10StackFrame11hasImacropcEv($90);
    if ($91) {
      var $moreInterrupts_0 = -128;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $98 = $pcCounts_1 + (HEAP32[$_pre_phi >> 2] - HEAP32[$86 >> 2] << 3) | 0;
    var $99 = (tempDoubleI32[0] = HEAP32[$98 >> 2], tempDoubleI32[1] = HEAP32[$98 + 4 >> 2], tempDoubleF64[0]);
    var $100 = $99 + 1;
    tempDoubleF64[0] = $100, HEAP32[$98 >> 2] = tempDoubleI32[0], HEAP32[$98 + 4 >> 2] = tempDoubleI32[1];
    var $moreInterrupts_0 = -128;
    __label__ = 25;
    break;
   case 25:
    var $moreInterrupts_0;
    var $102 = HEAP32[$46 >> 2];
    var $104 = HEAP32[$102 >> 2];
    if (($104 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $107 = __ZN8JSScript15stepModeEnabledEv($script_1);
    if ($107) {
      __label__ = 28;
      break;
    } else {
      var $moreInterrupts_1 = $moreInterrupts_0;
      __label__ = 33;
      break;
    }
   case 27:
    var $109 = HEAP32[$_pre_phi >> 2];
    var $111 = HEAP32[$102 + 4 >> 2];
    var $112 = FUNCTION_TABLE[$104]($cx, $script_1, $109, $rval, $111);
    if (($112 | 0) == 1) {
      __label__ = 28;
      break;
    } else {
      var $status_1 = $112;
      __label__ = 30;
      break;
    }
   case 28:
    var $114 = __ZN8JSScript15stepModeEnabledEv($script_1);
    if ($114) {
      __label__ = 29;
      break;
    } else {
      var $moreInterrupts_1 = -128;
      __label__ = 33;
      break;
    }
   case 29:
    var $116 = __ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE($cx, $rval);
    var $status_1 = $116;
    __label__ = 30;
    break;
   case 30:
    var $status_1;
    if (($status_1 | 0) == 2) {
      __label__ = 31;
      break;
    } else if (($status_1 | 0) == 3) {
      __label__ = 32;
      break;
    } else if (($status_1 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $moreInterrupts_1 = -128;
      __label__ = 33;
      break;
    }
   case 31:
    var $119 = __ZNK2js9FrameRegs2fpEv($regs);
    var $120 = $119;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($120, $rval);
    var $_5 = $_2;
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 32:
    var $122 = $rval | 0;
    var $st$1$0 = $122 | 0;
    var $123$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $122 + 4 | 0;
    var $123$1 = HEAP32[$st$1$1 >> 2];
    var $124 = $1 | 0;
    var $st$6$0 = $124 | 0;
    HEAP32[$st$6$0 >> 2] = $123$0;
    var $st$6$1 = $124 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $123$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $1);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 33:
    var $moreInterrupts_1;
    HEAP32[$switchMask >> 2] = $moreInterrupts_1 << 24 >> 24 >> 7 << 24 >> 24;
    var $switchOp_0 = $op_0;
    __label__ = 21;
    break;
   case 34:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 35:
    var $op_1;
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $op_1;
      __label__ = 20;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $133 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($133 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $op_1;
      __label__ = 20;
      break;
    }
   case 37:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 38:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 39:
    var $138 = HEAP32[$_pre_phi80 >> 2];
    var $139 = $138 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $139;
    __ZN2JS5Value12setUndefinedEv($138);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 40:
    var $142 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $142;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 41:
    var $144 = HEAPU32[$_pre_phi >> 2];
    var $155 = HEAP32[$_pre_phi80 >> 2] + (-((HEAPU8[$144 + 1 | 0] & 255) << 8 | HEAPU8[$144 + 2 | 0] & 255) << 3) | 0;
    HEAP32[$_pre_phi80 >> 2] = $155;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 42:
    var $157 = __ZNK2js9FrameRegs2fpEv($regs);
    var $159 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $159;
    var $160 = $157;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($160, $159);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 43:
    var $162 = __ZL9EnterWithP9JSContexti4JSOpj($cx, -1, 1);
    if ($162) {
      __label__ = 44;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 44:
    var $165 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $166 = __ZNK2js9FrameRegs2fpEv($regs);
    var $167 = __ZNK2js10StackFrame10scopeChainEv($166);
    __ZN2JS5Value9setObjectER8JSObject($165, $167);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 45:
    var $170 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $170;
    __ZL9LeaveWithP9JSContext($cx);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 46:
    var $172 = __ZNK2js9FrameRegs2fpEv($regs);
    var $174 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $174;
    var $175 = $172;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($175, $174);
    __label__ = 47;
    break;
   case 47:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $181 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($181 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $184 = __ZNK2js9FrameRegs2fpEv($regs);
    if (($_08 | 0) == ($184 | 0)) {
      var $interpReturnOK_2 = 1;
      __label__ = 1047;
      break;
    } else {
      var $_3 = $_2;
      var $interpReturnOK_0 = 1;
      __label__ = 50;
      break;
    }
   case 50:
    var $interpReturnOK_0;
    var $_3;
    var $187 = __ZNK2js9FrameRegs2fpEv($regs);
    var $189 = __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $187, ($interpReturnOK_0 | 0) != 0);
    var $190 = __ZNK2js9FrameRegs2fpEv($regs);
    var $191 = __ZNK2js10StackFrame18loweredCallOrApplyEv($190);
    __ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE(undef, $regs);
    var $192 = __ZNK2js9FrameRegs2fpEv($regs);
    var $193 = __ZNK2js10StackFrame6scriptEv($192);
    var $194 = __ZN8JSScript15stepModeEnabledEv($193);
    if ($194) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 52;
    break;
   case 52:
    var $197 = $193 + 92 | 0;
    var $198 = __ZN12JSPCCounters3getEi($197, 0);
    if (($198 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 54;
    break;
   case 54:
    var $202 = __ZNK2js9FrameRegs2fpEv($regs);
    var $203 = __ZNK2js10StackFrame15maybeFormalArgsEv($202);
    var $204 = __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $202);
    var $205 = $regs + 4 | 0;
    var $206 = HEAP32[$205 >> 2];
    if ($189) {
      __label__ = 55;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 55:
    var $208 = $regs | 0;
    var $210 = HEAP32[$208 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $193, $206, $210);
    if ($191) {
      __label__ = 56;
      break;
    } else {
      var $_1_ph = $_3;
      var $script_0_ph = $193;
      var $pcCounts_0_ph = $198;
      var $argv_0_ph = $203;
      var $atoms_0_ph = $204;
      var $len_0_ph1296 = 3;
      var $_pre_phi = $205;
      var $_pre_phi80 = $208;
      __label__ = 1036;
      break;
    }
   case 56:
    var $212 = HEAP32[$208 >> 2];
    var $213 = $212 - 8 | 0;
    var $st$2$0 = $213 | 0;
    var $214$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $213 + 4 | 0;
    var $214$1 = HEAP32[$st$2$1 >> 2];
    var $215 = $212 - 16 | 0;
    var $st$7$0 = $215 | 0;
    HEAP32[$st$7$0 >> 2] = $214$0;
    var $st$7$1 = $215 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $214$1;
    var $217 = HEAP32[$208 >> 2] - 8 | 0;
    HEAP32[$208 >> 2] = $217;
    var $_1_ph = $_3;
    var $script_0_ph = $193;
    var $pcCounts_0_ph = $198;
    var $argv_0_ph = $203;
    var $atoms_0_ph = $204;
    var $len_0_ph1296 = 3;
    var $_pre_phi = $205;
    var $_pre_phi80 = $208;
    __label__ = 1036;
    break;
   case 57:
    var $219 = $206 + 3 | 0;
    HEAP32[$205 >> 2] = $219;
    var $_4_ph1348 = $_3;
    var $script_2_ph1347 = $193;
    var $pcCounts_2_ph1346 = $198;
    var $argv_2_ph1345 = $203;
    __label__ = 1016;
    break;
   case 58:
    var $222 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $222;
    __label__ = 59;
    break;
   case 59:
    var $223 = HEAPU32[$_pre_phi >> 2];
    var $231 = (HEAPU8[$223 + 1 | 0] & 255) << 8 | HEAPU8[$223 + 2 | 0] & 255;
    var $233 = $223 + ($231 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $233;
    var $235 = HEAPU8[$233] & 255;
    if ($231 << 16 >> 16 < 1) {
      var $op_1 = $235;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $235;
      __label__ = 20;
      break;
    }
   case 60:
    var $239 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $240 = __ZNK2JS5Value6isNullEv($239);
    if ($240) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    HEAP32[$_pre_phi80 >> 2] = $239;
    __label__ = 66;
    break;
   case 62:
    var $242 = __ZNK2JS5Value9isBooleanEv($239);
    if ($242) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $244 = __ZNK2JS5Value9toBooleanEv($239);
    var $cond_0 = $244 & 1;
    __label__ = 65;
    break;
   case 64:
    var $247 = __Z17js_ValueToBooleanRKN2JS5ValueE($239);
    var $cond_0 = ($247 | 0) != 0 & 1;
    __label__ = 65;
    break;
   case 65:
    var $cond_0;
    HEAP32[$_pre_phi80 >> 2] = $239;
    if (($cond_0 | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 66:
    var $252 = HEAPU32[$_pre_phi >> 2];
    var $260 = (HEAPU8[$252 + 1 | 0] & 255) << 8 | HEAPU8[$252 + 2 | 0] & 255;
    var $262 = $252 + ($260 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $262;
    var $264 = HEAPU8[$262] & 255;
    if ($260 << 16 >> 16 < 1) {
      var $op_1 = $264;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $264;
      __label__ = 20;
      break;
    }
   case 67:
    var $268 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $269 = __ZNK2JS5Value6isNullEv($268);
    if ($269) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    HEAP32[$_pre_phi80 >> 2] = $268;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 69:
    var $271 = __ZNK2JS5Value9isBooleanEv($268);
    if ($271) {
      __label__ = 70;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 70:
    var $273 = __ZNK2JS5Value9toBooleanEv($268);
    var $cond1_0 = $273 & 1;
    __label__ = 72;
    break;
   case 71:
    var $276 = __Z17js_ValueToBooleanRKN2JS5ValueE($268);
    var $cond1_0 = ($276 | 0) != 0 & 1;
    __label__ = 72;
    break;
   case 72:
    var $cond1_0;
    HEAP32[$_pre_phi80 >> 2] = $268;
    if ($cond1_0 << 24 >> 24 == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $282 = HEAPU32[$_pre_phi >> 2];
    var $290 = (HEAPU8[$282 + 1 | 0] & 255) << 8 | HEAPU8[$282 + 2 | 0] & 255;
    var $292 = $282 + ($290 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $292;
    var $294 = HEAPU8[$292] & 255;
    if ($290 << 16 >> 16 < 1) {
      var $op_1 = $294;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $294;
      __label__ = 20;
      break;
    }
   case 74:
    var $297 = HEAPU32[$_pre_phi80 >> 2];
    var $298 = $297 - 8 | 0;
    var $299 = __ZNK2JS5Value6isNullEv($298);
    if ($299) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    HEAP32[$_pre_phi80 >> 2] = $298;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 76:
    var $301 = __ZNK2JS5Value9isBooleanEv($298);
    if ($301) {
      __label__ = 77;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 77:
    var $303 = __ZNK2JS5Value9toBooleanEv($298);
    var $cond3_0 = $303 & 1;
    __label__ = 79;
    break;
   case 78:
    var $306 = __Z17js_ValueToBooleanRKN2JS5ValueE($298);
    var $cond3_0 = ($306 | 0) != 0 & 1;
    __label__ = 79;
    break;
   case 79:
    var $cond3_0;
    HEAP32[$_pre_phi80 >> 2] = $298;
    if ($cond3_0 << 24 >> 24 == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $312 = HEAPU32[$_pre_phi >> 2];
    var $321 = ((HEAPU8[$312 + 1 | 0] & 255) << 8 | HEAPU8[$312 + 2 | 0] & 255) << 16 >> 16;
    HEAP32[$_pre_phi80 >> 2] = $297;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $321;
    __label__ = 19;
    break;
   case 81:
    var $323 = HEAPU32[$_pre_phi80 >> 2];
    var $324 = $323 - 8 | 0;
    var $325 = __ZNK2JS5Value6isNullEv($324);
    if ($325) {
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    HEAP32[$_pre_phi80 >> 2] = $324;
    __label__ = 87;
    break;
   case 83:
    var $327 = __ZNK2JS5Value9isBooleanEv($324);
    if ($327) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    var $329 = __ZNK2JS5Value9toBooleanEv($324);
    var $cond4_0 = $329 & 1;
    __label__ = 86;
    break;
   case 85:
    var $332 = __Z17js_ValueToBooleanRKN2JS5ValueE($324);
    var $cond4_0 = ($332 | 0) != 0 & 1;
    __label__ = 86;
    break;
   case 86:
    var $cond4_0;
    HEAP32[$_pre_phi80 >> 2] = $324;
    if (($cond4_0 | 0) == 0) {
      __label__ = 87;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 87:
    var $337 = HEAPU32[$_pre_phi >> 2];
    var $346 = ((HEAPU8[$337 + 1 | 0] & 255) << 8 | HEAPU8[$337 + 2 | 0] & 255) << 16 >> 16;
    HEAP32[$_pre_phi80 >> 2] = $323;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $346;
    __label__ = 19;
    break;
   case 88:
    var $349 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $349;
    __label__ = 89;
    break;
   case 89:
    var $350 = HEAPU32[$_pre_phi >> 2];
    var $368 = (HEAPU8[$350 + 2 | 0] & 255) << 16 | (HEAPU8[$350 + 1 | 0] & 255) << 24 | HEAPU8[$350 + 4 | 0] & 255 | (HEAPU8[$350 + 3 | 0] & 255) << 8;
    var $369 = $350 + $368 | 0;
    HEAP32[$_pre_phi >> 2] = $369;
    var $371 = HEAPU8[$369] & 255;
    if (($368 | 0) < 1) {
      var $op_1 = $371;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $371;
      __label__ = 20;
      break;
    }
   case 90:
    var $375 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $376 = __ZNK2JS5Value6isNullEv($375);
    if ($376) {
      __label__ = 91;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 91:
    HEAP32[$_pre_phi80 >> 2] = $375;
    __label__ = 96;
    break;
   case 92:
    var $378 = __ZNK2JS5Value9isBooleanEv($375);
    if ($378) {
      __label__ = 93;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 93:
    var $380 = __ZNK2JS5Value9toBooleanEv($375);
    var $cond6_0 = $380 & 1;
    __label__ = 95;
    break;
   case 94:
    var $383 = __Z17js_ValueToBooleanRKN2JS5ValueE($375);
    var $cond6_0 = ($383 | 0) != 0 & 1;
    __label__ = 95;
    break;
   case 95:
    var $cond6_0;
    HEAP32[$_pre_phi80 >> 2] = $375;
    if (($cond6_0 | 0) == 0) {
      __label__ = 96;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    }
   case 96:
    var $388 = HEAPU32[$_pre_phi >> 2];
    var $406 = (HEAPU8[$388 + 2 | 0] & 255) << 16 | (HEAPU8[$388 + 1 | 0] & 255) << 24 | HEAPU8[$388 + 4 | 0] & 255 | (HEAPU8[$388 + 3 | 0] & 255) << 8;
    var $407 = $388 + $406 | 0;
    HEAP32[$_pre_phi >> 2] = $407;
    var $409 = HEAPU8[$407] & 255;
    if (($406 | 0) < 1) {
      var $op_1 = $409;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $409;
      __label__ = 20;
      break;
    }
   case 97:
    var $413 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $414 = __ZNK2JS5Value6isNullEv($413);
    if ($414) {
      __label__ = 98;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 98:
    HEAP32[$_pre_phi80 >> 2] = $413;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 99:
    var $416 = __ZNK2JS5Value9isBooleanEv($413);
    if ($416) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    var $418 = __ZNK2JS5Value9toBooleanEv($413);
    var $cond8_0 = $418 & 1;
    __label__ = 102;
    break;
   case 101:
    var $421 = __Z17js_ValueToBooleanRKN2JS5ValueE($413);
    var $cond8_0 = ($421 | 0) != 0 & 1;
    __label__ = 102;
    break;
   case 102:
    var $cond8_0;
    HEAP32[$_pre_phi80 >> 2] = $413;
    if ($cond8_0 << 24 >> 24 == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    var $427 = HEAPU32[$_pre_phi >> 2];
    var $445 = (HEAPU8[$427 + 2 | 0] & 255) << 16 | (HEAPU8[$427 + 1 | 0] & 255) << 24 | HEAPU8[$427 + 4 | 0] & 255 | (HEAPU8[$427 + 3 | 0] & 255) << 8;
    var $446 = $427 + $445 | 0;
    HEAP32[$_pre_phi >> 2] = $446;
    var $448 = HEAPU8[$446] & 255;
    if (($445 | 0) < 1) {
      var $op_1 = $448;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $448;
      __label__ = 20;
      break;
    }
   case 104:
    var $451 = HEAPU32[$_pre_phi80 >> 2];
    var $452 = $451 - 8 | 0;
    var $453 = __ZNK2JS5Value6isNullEv($452);
    if ($453) {
      __label__ = 105;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 105:
    HEAP32[$_pre_phi80 >> 2] = $452;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 106:
    var $455 = __ZNK2JS5Value9isBooleanEv($452);
    if ($455) {
      __label__ = 107;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 107:
    var $457 = __ZNK2JS5Value9toBooleanEv($452);
    var $cond10_0 = $457 & 1;
    __label__ = 109;
    break;
   case 108:
    var $460 = __Z17js_ValueToBooleanRKN2JS5ValueE($452);
    var $cond10_0 = ($460 | 0) != 0 & 1;
    __label__ = 109;
    break;
   case 109:
    var $cond10_0;
    HEAP32[$_pre_phi80 >> 2] = $452;
    if ($cond10_0 << 24 >> 24 == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $466 = HEAPU32[$_pre_phi >> 2];
    var $484 = (HEAPU8[$466 + 2 | 0] & 255) << 16 | (HEAPU8[$466 + 1 | 0] & 255) << 24 | HEAPU8[$466 + 4 | 0] & 255 | (HEAPU8[$466 + 3 | 0] & 255) << 8;
    HEAP32[$_pre_phi80 >> 2] = $451;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $484;
    __label__ = 19;
    break;
   case 111:
    var $486 = HEAPU32[$_pre_phi80 >> 2];
    var $487 = $486 - 8 | 0;
    var $488 = __ZNK2JS5Value6isNullEv($487);
    if ($488) {
      __label__ = 112;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 112:
    HEAP32[$_pre_phi80 >> 2] = $487;
    __label__ = 117;
    break;
   case 113:
    var $490 = __ZNK2JS5Value9isBooleanEv($487);
    if ($490) {
      __label__ = 114;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 114:
    var $492 = __ZNK2JS5Value9toBooleanEv($487);
    var $cond12_0 = $492 & 1;
    __label__ = 116;
    break;
   case 115:
    var $495 = __Z17js_ValueToBooleanRKN2JS5ValueE($487);
    var $cond12_0 = ($495 | 0) != 0 & 1;
    __label__ = 116;
    break;
   case 116:
    var $cond12_0;
    HEAP32[$_pre_phi80 >> 2] = $487;
    if (($cond12_0 | 0) == 0) {
      __label__ = 117;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    }
   case 117:
    var $500 = HEAPU32[$_pre_phi >> 2];
    var $518 = (HEAPU8[$500 + 2 | 0] & 255) << 16 | (HEAPU8[$500 + 1 | 0] & 255) << 24 | HEAPU8[$500 + 4 | 0] & 255 | (HEAPU8[$500 + 3 | 0] & 255) << 8;
    HEAP32[$_pre_phi80 >> 2] = $486;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $518;
    __label__ = 19;
    break;
   case 118:
    var $520 = HEAPU32[$_pre_phi80 >> 2];
    var $521 = $520 - 8 | 0;
    var $522 = __ZNK2JS5Value8isObjectEv($521);
    if ($522) {
      __label__ = 120;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 119:
    var $524 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 27, -1, $521, 0, 0, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 120:
    var $526 = __ZNK2JS5Value8toObjectEv($521);
    var $527 = $520 - 16 | 0;
    var $528 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($527, $i_);
    if ($528) {
      __label__ = 121;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 121:
    var $530 = HEAP32[$i_ >> 2];
    var $531 = _INT_FITS_IN_JSID1825($530);
    if (($531 | 0) == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $534 = _INT_TO_JSID1826($530);
    HEAP32[$id >> 2] = $534;
    var $540 = $534;
    __label__ = 125;
    break;
   case 123:
    var $537 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $538 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $526, $527, $id, $537);
    if ($538) {
      __label__ = 124;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 124:
    var $540 = HEAP32[$id >> 2];
    __label__ = 125;
    break;
   case 125:
    var $540;
    var $541 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($526, $cx, $540, $obj2, $prop);
    if (($541 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $545 = (HEAP32[$prop >> 2] | 0) != 0;
    var $546 = HEAPU32[$_pre_phi >> 2];
    var $547 = $546 + 1 | 0;
    var $550 = (HEAPU8[$547] & 255) - 7 | 0;
    var $552 = HEAPU32[$_pre_phi80 >> 2];
    if ($550 >>> 0 < 2) {
      __label__ = 127;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 127:
    HEAP32[$_pre_phi80 >> 2] = $552 - 16 | 0;
    if ($545 ^ ($550 | 0) != 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    HEAP32[$_pre_phi >> 2] = $547;
    var $564 = (HEAPU8[$546 + 2 | 0] & 255) << 8 | HEAPU8[$546 + 3 | 0] & 255;
    var $566 = $546 + (($564 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $566;
    var $568 = HEAPU8[$566] & 255;
    if ($564 << 16 >> 16 < 1) {
      var $op_1 = $568;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $568;
      __label__ = 20;
      break;
    }
   case 129:
    HEAP32[$_pre_phi80 >> 2] = $552 - 8 | 0;
    var $572 = $552 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($572, $545);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 130:
    var $577 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255;
    var $579 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $580 = __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($5178, $577, $579);
    if (($580 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 19;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 132:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 19;
    break;
   case 133:
    var $589 = HEAP32[$_pre_phi80 >> 2];
    var $590 = $589 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $590;
    __ZN2JS5Value7setNullEv($589);
    var $591 = HEAP32[$_pre_phi80 >> 2];
    var $592 = $591 - 16 | 0;
    var $593 = __ZNK2JS5Value8toObjectEv($592);
    var $594 = $591 - 8 | 0;
    var $595 = __ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE($cx, $593, $cond15, $594);
    if ($595) {
      __label__ = 134;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 134:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 136;
    break;
   case 136:
    var $604 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $607 = (HEAP8[$cond15] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($604, $607);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 137:
    var $609 = HEAP32[$_pre_phi80 >> 2];
    var $615 = $609 + (-(HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0] << 24 >> 24) << 3) | 0;
    var $616 = $609 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $616;
    __ZN2JS5Value7setNullEv($609);
    var $617 = __ZNK2JS5Value8toObjectEv($615);
    var $619 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $620 = __ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $617, $619);
    if ($620) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 19;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 138:
    var $623 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $624 = __ZNK2JS5Value8toObjectEv($623);
    var $625 = $624;
    var $626 = __Z16js_CloseIteratorP9JSContextP8JSObject($5178, $625);
    var $627 = ($626 | 0) == 0;
    var $629 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $629;
    if ($627) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 139:
    var $631 = HEAP32[$_pre_phi80 >> 2];
    var $632 = $631 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $632;
    var $633 = $631 - 8 | 0;
    var $st$4$0 = $633 | 0;
    var $634$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $633 + 4 | 0;
    var $634$1 = HEAP32[$st$4$1 >> 2];
    var $635 = $631 | 0;
    var $st$9$0 = $635 | 0;
    HEAP32[$st$9$0 >> 2] = $634$0;
    var $st$9$1 = $635 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $634$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 140:
    var $637 = HEAP32[$_pre_phi80 >> 2];
    var $638 = $637 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $638;
    var $639 = $637 - 16 | 0;
    var $st$4$0 = $639 | 0;
    var $640$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $639 + 4 | 0;
    var $640$1 = HEAP32[$st$4$1 >> 2];
    var $641 = $637 | 0;
    var $st$9$0 = $641 | 0;
    HEAP32[$st$9$0 >> 2] = $640$0;
    var $st$9$1 = $641 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $640$1;
    var $642 = HEAP32[$_pre_phi80 >> 2];
    var $643 = $642 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $643;
    var $644 = $637 - 8 | 0;
    var $645$0 = HEAP32[$644 >> 2];
    var $645$1 = HEAP32[$644 + 4 >> 2];
    var $646 = $642 | 0;
    var $st$22$0 = $646 | 0;
    HEAP32[$st$22$0 >> 2] = $645$0;
    var $st$22$1 = $646 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $645$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 141:
    var $648 = HEAP32[$_pre_phi80 >> 2];
    var $649 = $648 - 16 | 0;
    var $650 = $648 - 8 | 0;
    __ZN2JS5Value4swapERS0_($649, $650);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 142:
    var $655 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255;
    var $656 = $655 ^ -1;
    var $657 = HEAPU32[$_pre_phi80 >> 2];
    var $_025 = $657 + ($656 << 3) | 0;
    var $st$7$0 = $_025 | 0;
    var $tmp26$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_025 + 4 | 0;
    var $tmp26$1 = HEAP32[$st$7$1 >> 2];
    var $659 = $657 + ($656 << 3) | 0;
    var $662 = $657 + (-$655 << 3) | 0;
    var $663 = $655 << 3;
    _llvm_memmove_p0i8_p0i8_i32($659, $662, $663, 1, 0);
    var $_027 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$20$0 = $_027 | 0;
    HEAP32[$st$20$0 >> 2] = $tmp26$0;
    var $st$20$1 = $_027 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $tmp26$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 19;
    break;
   case 143:
    var $666 = HEAPU32[$_pre_phi >> 2];
    var $676 = HEAP32[$atoms_1 + (((HEAPU8[$666 + 1 | 0] & 255) << 8 | HEAPU8[$666 + 2 | 0] & 255) << 2) >> 2];
    var $677 = __ZNK2js9FrameRegs2fpEv($regs);
    var $678 = __ZN2js10StackFrame6varObjEv($677);
    var $680 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $681 = __ZL12ATOM_TO_JSIDP6JSAtom1798($676);
    var $682 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($678, $cx, $681, $680, 10, 12, 7);
    if (($682 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $685 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$685 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 145;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 145:
    var $691 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $691;
    var $692 = $685 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $692;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$692] & 255;
    __label__ = 20;
    break;
   case 146:
    var $696 = HEAPU32[$_pre_phi80 >> 2];
    var $697 = $696 - 24 | 0;
    var $698 = $696 - 16 | 0;
    var $699 = __ZNK2JS5Value8isObjectEv($698);
    if ($699) {
      __label__ = 147;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 147:
    var $701 = __ZNK2JS5Value8toObjectEv($698);
    var $obj22_0 = $701;
    var $708 = $696;
    __label__ = 150;
    break;
   case 148:
    var $703 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $698);
    var $704 = $703;
    if (($703 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    __ZN2JS5Value9setObjectER8JSObject($698, $704);
    var $obj22_0 = $704;
    var $708 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 150;
    break;
   case 150:
    var $708;
    var $obj22_0;
    var $709 = $708 - 8 | 0;
    var $710 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($709, $i_25);
    if ($710) {
      __label__ = 151;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 151:
    var $712 = HEAP32[$i_25 >> 2];
    var $713 = _INT_FITS_IN_JSID1825($712);
    if (($713 | 0) == 0) {
      __label__ = 153;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 152:
    var $716 = _INT_TO_JSID1826($712);
    HEAP32[$id23 >> 2] = $716;
    var $722 = $716;
    __label__ = 155;
    break;
   case 153:
    var $719 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $720 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj22_0, $709, $id23, $719);
    if ($720) {
      __label__ = 154;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 154:
    var $722 = HEAP32[$id23 >> 2];
    __label__ = 155;
    break;
   case 155:
    var $722;
    var $723 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj22_0, $cx, $722, $697, 10, 12, 7);
    if (($723 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    var $727 = HEAP32[$_pre_phi80 >> 2] - 24 | 0;
    HEAP32[$_pre_phi80 >> 2] = $727;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 157:
    var $729 = HEAP32[$_pre_phi80 >> 2];
    var $730 = $729 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $730;
    var $731 = __ZNK2js9FrameRegs2fpEv($regs);
    var $732 = __ZNK2js10StackFrame10scopeChainEv($731);
    var $733 = $732;
    var $734 = __ZNK8JSObject9getGlobalEv($733);
    var $735 = $734;
    __ZN2JS5Value9setObjectER8JSObject($729, $735);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 158:
    var $737 = __ZNK2js9FrameRegs2fpEv($regs);
    var $738 = __ZNK2js10StackFrame10scopeChainEv($737);
    HEAP32[$obj26 >> 2] = $738;
    var $739 = __ZNK8JSObject9getParentEv($738);
    if (($739 | 0) == 0) {
      var $756 = $738;
      __label__ = 162;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    var $743 = HEAP32[$32 >> 2] + 144336 | 0;
    var $744 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($743, $cx, $744, $obj26, $obj227, $entry, $atom28);
    var $745 = HEAP32[$atom28 >> 2];
    if (($745 | 0) == 0) {
      __label__ = 160;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 160:
    var $756 = HEAP32[$obj26 >> 2];
    __label__ = 162;
    break;
   case 161:
    var $748 = __ZL12ATOM_TO_JSIDP6JSAtom1798($745);
    var $749 = __ZNK2js9FrameRegs2fpEv($regs);
    var $750 = __ZNK2js10StackFrame10scopeChainEv($749);
    var $751 = $750;
    var $752 = __Z21js_FindIdentifierBaseP9JSContextP8JSObjecti($5173, $751, $748);
    var $753 = $752;
    HEAP32[$obj26 >> 2] = $753;
    if (($752 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $756 = $753;
      __label__ = 162;
      break;
    }
   case 162:
    var $756;
    var $757 = HEAP32[$_pre_phi80 >> 2];
    var $758 = $757 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $758;
    __ZN2JS5Value9setObjectER8JSObject($757, $756);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 163:
    var $760 = __ZNK2js9FrameRegs2fpEv($regs);
    var $761 = __ZNK2js10StackFrame8imacropcEv($760);
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$761] & 255;
    __label__ = 20;
    break;
   case 164:
    var $766 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $767 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $766, $i30);
    if ($767) {
      __label__ = 165;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 165:
    var $770 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $771 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $770, $j);
    if ($771) {
      __label__ = 166;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 166:
    var $775 = HEAP32[$j >> 2] | HEAP32[$i30 >> 2];
    HEAP32[$i30 >> 2] = $775;
    var $776 = HEAP32[$_pre_phi80 >> 2];
    var $777 = $776 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $777;
    var $778 = $776 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($778, $775);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 167:
    var $781 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $782 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $781, $i31);
    if ($782) {
      __label__ = 168;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 168:
    var $785 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $786 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $785, $j32);
    if ($786) {
      __label__ = 169;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 169:
    var $790 = HEAP32[$j32 >> 2] ^ HEAP32[$i31 >> 2];
    HEAP32[$i31 >> 2] = $790;
    var $791 = HEAP32[$_pre_phi80 >> 2];
    var $792 = $791 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $792;
    var $793 = $791 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($793, $790);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 170:
    var $796 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $797 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $796, $i33);
    if ($797) {
      __label__ = 171;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 171:
    var $800 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $801 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $800, $j34);
    if ($801) {
      __label__ = 172;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 172:
    var $805 = HEAP32[$j34 >> 2] & HEAP32[$i33 >> 2];
    HEAP32[$i33 >> 2] = $805;
    var $806 = HEAP32[$_pre_phi80 >> 2];
    var $807 = $806 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $807;
    var $808 = $806 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($808, $805);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 173:
    var $810 = HEAP32[$_pre_phi80 >> 2];
    var $811 = $810 - 8 | 0;
    var $st$2$0 = $811 | 0;
    var $812$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $811 + 4 | 0;
    var $812$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5166 | 0;
    HEAP32[$st$6$0 >> 2] = $812$0;
    var $st$6$1 = $5166 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $812$1;
    var $813 = $810 - 16 | 0;
    var $st$11$0 = $813 | 0;
    var $814$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $813 + 4 | 0;
    var $814$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5167 | 0;
    HEAP32[$st$15$0 >> 2] = $814$0;
    var $st$15$1 = $5167 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $814$1;
    var $815 = __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval36, $rval35, $cond37);
    if ($815) {
      __label__ = 174;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 174:
    var $818 = (HEAP32[$cond37 >> 2] | 0) == 1;
    var $819 = $818 & 1;
    HEAP32[$cond37 >> 2] = $819;
    var $820 = HEAPU32[$_pre_phi >> 2];
    var $821 = $820 + 1 | 0;
    var $824 = (HEAPU8[$821] & 255) - 7 | 0;
    var $826 = HEAPU32[$_pre_phi80 >> 2];
    if ($824 >>> 0 < 2) {
      __label__ = 175;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 175:
    HEAP32[$_pre_phi80 >> 2] = $826 - 16 | 0;
    if ($818 ^ ($824 | 0) != 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 176:
    HEAP32[$_pre_phi >> 2] = $821;
    var $838 = (HEAPU8[$820 + 2 | 0] & 255) << 8 | HEAPU8[$820 + 3 | 0] & 255;
    var $840 = $820 + (($838 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $840;
    var $842 = HEAPU8[$840] & 255;
    if ($838 << 16 >> 16 < 1) {
      var $op_1 = $842;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $842;
      __label__ = 20;
      break;
    }
   case 177:
    HEAP32[$_pre_phi80 >> 2] = $826 - 8 | 0;
    var $846 = $826 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($846, $818);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 178:
    var $848 = HEAPU32[$_pre_phi80 >> 2];
    var $849 = $848 - 8 | 0;
    var $st$2$0 = $849 | 0;
    var $850$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $849 + 4 | 0;
    var $850$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5168 | 0;
    HEAP32[$st$6$0 >> 2] = $850$0;
    var $st$6$1 = $5168 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $850$1;
    var $851 = $848 - 16 | 0;
    var $st$11$0 = $851 | 0;
    var $852$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $851 + 4 | 0;
    var $852$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5169 | 0;
    HEAP32[$st$15$0 >> 2] = $852$0;
    var $st$15$1 = $5169 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $852$1;
    var $853 = __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval40, $rval39, $cond41);
    if ($853) {
      __label__ = 179;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 179:
    var $856 = (HEAP32[$cond41 >> 2] | 0) != 1;
    var $857 = $856 & 1;
    HEAP32[$cond41 >> 2] = $857;
    var $858 = HEAPU32[$_pre_phi >> 2];
    var $859 = $858 + 1 | 0;
    var $862 = (HEAPU8[$859] & 255) - 7 | 0;
    var $864 = HEAPU32[$_pre_phi80 >> 2];
    if ($862 >>> 0 < 2) {
      __label__ = 180;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 180:
    HEAP32[$_pre_phi80 >> 2] = $864 - 16 | 0;
    if ($856 ^ ($862 | 0) != 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 181:
    HEAP32[$_pre_phi >> 2] = $859;
    var $876 = (HEAPU8[$858 + 2 | 0] & 255) << 8 | HEAPU8[$858 + 3 | 0] & 255;
    var $878 = $858 + (($876 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $878;
    var $880 = HEAPU8[$878] & 255;
    if ($876 << 16 >> 16 < 1) {
      var $op_1 = $880;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $880;
      __label__ = 20;
      break;
    }
   case 182:
    HEAP32[$_pre_phi80 >> 2] = $864 - 8 | 0;
    var $884 = $864 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($884, $856);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 183:
    var $886 = HEAP32[$_pre_phi80 >> 2];
    var $887 = $886 - 8 | 0;
    var $888 = $886 - 16 | 0;
    var $889 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $888, $887, $equal);
    if ($889) {
      __label__ = 184;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 184:
    var $892 = (HEAP32[$equal >> 2] | 0) == 1;
    var $893 = HEAP32[$_pre_phi80 >> 2];
    var $894 = $893 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $894;
    var $895 = $893 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($895, $892);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 185:
    var $897 = HEAP32[$_pre_phi80 >> 2];
    var $898 = $897 - 8 | 0;
    var $899 = $897 - 16 | 0;
    var $900 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $899, $898, $equal49);
    if ($900) {
      __label__ = 186;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 186:
    var $903 = (HEAP32[$equal49 >> 2] | 0) != 1;
    var $904 = HEAP32[$_pre_phi80 >> 2];
    var $905 = $904 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $905;
    var $906 = $904 - 16 | 0;
    __ZN2JS5Value10setBooleanEb($906, $903);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 187:
    var $908 = HEAP32[$_pre_phi80 >> 2];
    var $909 = $908 - 8 | 0;
    var $910 = $908 - 16 | 0;
    var $911 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $910, $909, $equal53);
    if ($911) {
      __label__ = 188;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 188:
    var $914 = (HEAP32[$equal53 >> 2] | 0) == 1;
    var $915 = HEAP32[$_pre_phi80 >> 2];
    var $916 = $915 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $916;
    if ($914) {
      __label__ = 189;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 189:
    var $918 = $915 - 16 | 0;
    HEAP32[$_pre_phi80 >> 2] = $918;
    var $919 = HEAPU32[$_pre_phi >> 2];
    var $927 = (HEAPU8[$919 + 1 | 0] & 255) << 8 | HEAPU8[$919 + 2 | 0] & 255;
    var $929 = $919 + ($927 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $929;
    var $931 = HEAPU8[$929] & 255;
    if ($927 << 16 >> 16 < 1) {
      var $op_1 = $931;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $931;
      __label__ = 20;
      break;
    }
   case 190:
    var $934 = HEAP32[$_pre_phi80 >> 2];
    var $935 = $934 - 8 | 0;
    var $936 = $934 - 16 | 0;
    var $937 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $936, $935, $equal57);
    if ($937) {
      __label__ = 191;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 191:
    var $940 = (HEAP32[$equal57 >> 2] | 0) == 1;
    var $941 = HEAP32[$_pre_phi80 >> 2];
    var $942 = $941 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $942;
    if ($940) {
      __label__ = 192;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    }
   case 192:
    var $944 = $941 - 16 | 0;
    HEAP32[$_pre_phi80 >> 2] = $944;
    var $945 = HEAPU32[$_pre_phi >> 2];
    var $963 = (HEAPU8[$945 + 2 | 0] & 255) << 16 | (HEAPU8[$945 + 1 | 0] & 255) << 24 | HEAPU8[$945 + 4 | 0] & 255 | (HEAPU8[$945 + 3 | 0] & 255) << 8;
    var $964 = $945 + $963 | 0;
    HEAP32[$_pre_phi >> 2] = $964;
    var $966 = HEAPU8[$964] & 255;
    if (($963 | 0) < 1) {
      var $op_1 = $966;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $966;
      __label__ = 20;
      break;
    }
   case 193:
    var $969 = HEAP32[$_pre_phi80 >> 2];
    var $970 = $969 - 8 | 0;
    var $971 = $969 - 16 | 0;
    var $972 = __ZNK2JS5Value7isInt32Ev($971);
    if ($972) {
      __label__ = 194;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 194:
    var $974 = __ZNK2JS5Value7isInt32Ev($970);
    if ($974) {
      __label__ = 195;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 195:
    var $976 = __ZNK2JS5Value7toInt32Ev($971);
    var $977 = __ZNK2JS5Value7toInt32Ev($970);
    var $cond60_0 = ($976 | 0) < ($977 | 0) & 1;
    __label__ = 205;
    break;
   case 196:
    var $981 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $971);
    if ($981) {
      __label__ = 197;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 197:
    var $983 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $970);
    if ($983) {
      __label__ = 198;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 198:
    var $985 = __ZNK2JS5Value8isStringEv($971);
    if ($985) {
      __label__ = 199;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 199:
    var $987 = __ZNK2JS5Value8isStringEv($970);
    if ($987) {
      __label__ = 200;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 200:
    var $989 = __ZNK2JS5Value8toStringEv($971);
    var $990 = __ZNK2JS5Value8toStringEv($970);
    var $991 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5170, $989, $990, $result);
    if ($991) {
      __label__ = 201;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 201:
    var $cond60_0 = HEAPU32[$result >> 2] >>> 31 & 255;
    __label__ = 205;
    break;
   case 202:
    var $996 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $971, $l61);
    if ($996) {
      __label__ = 203;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 203:
    var $998 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $970, $r62);
    if ($998) {
      __label__ = 204;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 204:
    var $1000 = (tempDoubleI32[0] = HEAP32[$l61 >> 2], tempDoubleI32[1] = HEAP32[$l61 + 4 >> 2], tempDoubleF64[0]);
    var $1001 = (tempDoubleI32[0] = HEAP32[$r62 >> 2], tempDoubleI32[1] = HEAP32[$r62 + 4 >> 2], tempDoubleF64[0]);
    var $cond60_0 = $1000 < $1001 & 1;
    __label__ = 205;
    break;
   case 205:
    var $cond60_0;
    var $1005 = HEAPU32[$_pre_phi >> 2];
    var $1006 = $1005 + 1 | 0;
    var $1009 = (HEAPU8[$1006] & 255) - 7 | 0;
    var $1012 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    if ($1009 >>> 0 < 2) {
      __label__ = 206;
      break;
    } else {
      __label__ = 208;
      break;
    }
   case 206:
    HEAP32[$_pre_phi80 >> 2] = $1012;
    if (($cond60_0 & 255 | 0) == (($1009 | 0) != 0 & 1 | 0)) {
      __label__ = 207;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    }
   case 207:
    HEAP32[$_pre_phi >> 2] = $1006;
    var $1026 = (HEAPU8[$1005 + 2 | 0] & 255) << 8 | HEAPU8[$1005 + 3 | 0] & 255;
    var $1028 = $1005 + (($1026 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1028;
    var $1030 = HEAPU8[$1028] & 255;
    if ($1026 << 16 >> 16 < 1) {
      var $op_1 = $1030;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1030;
      __label__ = 20;
      break;
    }
   case 208:
    __ZN2JS5Value10setBooleanEb($1012, $cond60_0 << 24 >> 24 != 0);
    var $1035 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1035;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 209:
    var $1037 = HEAP32[$_pre_phi80 >> 2];
    var $1038 = $1037 - 8 | 0;
    var $1039 = $1037 - 16 | 0;
    var $1040 = __ZNK2JS5Value7isInt32Ev($1039);
    if ($1040) {
      __label__ = 210;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 210:
    var $1042 = __ZNK2JS5Value7isInt32Ev($1038);
    if ($1042) {
      __label__ = 211;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 211:
    var $1044 = __ZNK2JS5Value7toInt32Ev($1039);
    var $1045 = __ZNK2JS5Value7toInt32Ev($1038);
    var $cond66_0 = ($1044 | 0) <= ($1045 | 0) & 1;
    __label__ = 221;
    break;
   case 212:
    var $1049 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1039);
    if ($1049) {
      __label__ = 213;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 213:
    var $1051 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1038);
    if ($1051) {
      __label__ = 214;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 214:
    var $1053 = __ZNK2JS5Value8isStringEv($1039);
    if ($1053) {
      __label__ = 215;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 215:
    var $1055 = __ZNK2JS5Value8isStringEv($1038);
    if ($1055) {
      __label__ = 216;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 216:
    var $1057 = __ZNK2JS5Value8toStringEv($1039);
    var $1058 = __ZNK2JS5Value8toStringEv($1038);
    var $1059 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5170, $1057, $1058, $result69);
    if ($1059) {
      __label__ = 217;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 217:
    var $cond66_0 = (HEAP32[$result69 >> 2] | 0) < 1 & 1;
    __label__ = 221;
    break;
   case 218:
    var $1065 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1039, $l70);
    if ($1065) {
      __label__ = 219;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 219:
    var $1067 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1038, $r71);
    if ($1067) {
      __label__ = 220;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 220:
    var $1069 = (tempDoubleI32[0] = HEAP32[$l70 >> 2], tempDoubleI32[1] = HEAP32[$l70 + 4 >> 2], tempDoubleF64[0]);
    var $1070 = (tempDoubleI32[0] = HEAP32[$r71 >> 2], tempDoubleI32[1] = HEAP32[$r71 + 4 >> 2], tempDoubleF64[0]);
    var $cond66_0 = $1069 <= $1070 & 1;
    __label__ = 221;
    break;
   case 221:
    var $cond66_0;
    var $1074 = HEAPU32[$_pre_phi >> 2];
    var $1075 = $1074 + 1 | 0;
    var $1078 = (HEAPU8[$1075] & 255) - 7 | 0;
    var $1081 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    if ($1078 >>> 0 < 2) {
      __label__ = 222;
      break;
    } else {
      __label__ = 224;
      break;
    }
   case 222:
    HEAP32[$_pre_phi80 >> 2] = $1081;
    if (($cond66_0 & 255 | 0) == (($1078 | 0) != 0 & 1 | 0)) {
      __label__ = 223;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    }
   case 223:
    HEAP32[$_pre_phi >> 2] = $1075;
    var $1095 = (HEAPU8[$1074 + 2 | 0] & 255) << 8 | HEAPU8[$1074 + 3 | 0] & 255;
    var $1097 = $1074 + (($1095 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1097;
    var $1099 = HEAPU8[$1097] & 255;
    if ($1095 << 16 >> 16 < 1) {
      var $op_1 = $1099;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1099;
      __label__ = 20;
      break;
    }
   case 224:
    __ZN2JS5Value10setBooleanEb($1081, $cond66_0 << 24 >> 24 != 0);
    var $1104 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1104;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 225:
    var $1106 = HEAP32[$_pre_phi80 >> 2];
    var $1107 = $1106 - 8 | 0;
    var $1108 = $1106 - 16 | 0;
    var $1109 = __ZNK2JS5Value7isInt32Ev($1108);
    if ($1109) {
      __label__ = 226;
      break;
    } else {
      __label__ = 228;
      break;
    }
   case 226:
    var $1111 = __ZNK2JS5Value7isInt32Ev($1107);
    if ($1111) {
      __label__ = 227;
      break;
    } else {
      __label__ = 228;
      break;
    }
   case 227:
    var $1113 = __ZNK2JS5Value7toInt32Ev($1108);
    var $1114 = __ZNK2JS5Value7toInt32Ev($1107);
    var $cond75_0 = ($1113 | 0) > ($1114 | 0) & 1;
    __label__ = 237;
    break;
   case 228:
    var $1118 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1108);
    if ($1118) {
      __label__ = 229;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 229:
    var $1120 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1107);
    if ($1120) {
      __label__ = 230;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 230:
    var $1122 = __ZNK2JS5Value8isStringEv($1108);
    if ($1122) {
      __label__ = 231;
      break;
    } else {
      __label__ = 234;
      break;
    }
   case 231:
    var $1124 = __ZNK2JS5Value8isStringEv($1107);
    if ($1124) {
      __label__ = 232;
      break;
    } else {
      __label__ = 234;
      break;
    }
   case 232:
    var $1126 = __ZNK2JS5Value8toStringEv($1108);
    var $1127 = __ZNK2JS5Value8toStringEv($1107);
    var $1128 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5170, $1126, $1127, $result78);
    if ($1128) {
      __label__ = 233;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 233:
    var $cond75_0 = (HEAP32[$result78 >> 2] | 0) > 0 & 1;
    __label__ = 237;
    break;
   case 234:
    var $1134 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1108, $l79);
    if ($1134) {
      __label__ = 235;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 235:
    var $1136 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1107, $r80);
    if ($1136) {
      __label__ = 236;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 236:
    var $1138 = (tempDoubleI32[0] = HEAP32[$l79 >> 2], tempDoubleI32[1] = HEAP32[$l79 + 4 >> 2], tempDoubleF64[0]);
    var $1139 = (tempDoubleI32[0] = HEAP32[$r80 >> 2], tempDoubleI32[1] = HEAP32[$r80 + 4 >> 2], tempDoubleF64[0]);
    var $cond75_0 = $1138 > $1139 & 1;
    __label__ = 237;
    break;
   case 237:
    var $cond75_0;
    var $1143 = HEAPU32[$_pre_phi >> 2];
    var $1144 = $1143 + 1 | 0;
    var $1147 = (HEAPU8[$1144] & 255) - 7 | 0;
    var $1150 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    if ($1147 >>> 0 < 2) {
      __label__ = 238;
      break;
    } else {
      __label__ = 240;
      break;
    }
   case 238:
    HEAP32[$_pre_phi80 >> 2] = $1150;
    if (($cond75_0 & 255 | 0) == (($1147 | 0) != 0 & 1 | 0)) {
      __label__ = 239;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    }
   case 239:
    HEAP32[$_pre_phi >> 2] = $1144;
    var $1164 = (HEAPU8[$1143 + 2 | 0] & 255) << 8 | HEAPU8[$1143 + 3 | 0] & 255;
    var $1166 = $1143 + (($1164 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1166;
    var $1168 = HEAPU8[$1166] & 255;
    if ($1164 << 16 >> 16 < 1) {
      var $op_1 = $1168;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1168;
      __label__ = 20;
      break;
    }
   case 240:
    __ZN2JS5Value10setBooleanEb($1150, $cond75_0 << 24 >> 24 != 0);
    var $1173 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1173;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 241:
    var $1175 = HEAP32[$_pre_phi80 >> 2];
    var $1176 = $1175 - 8 | 0;
    var $1177 = $1175 - 16 | 0;
    var $1178 = __ZNK2JS5Value7isInt32Ev($1177);
    if ($1178) {
      __label__ = 242;
      break;
    } else {
      __label__ = 244;
      break;
    }
   case 242:
    var $1180 = __ZNK2JS5Value7isInt32Ev($1176);
    if ($1180) {
      __label__ = 243;
      break;
    } else {
      __label__ = 244;
      break;
    }
   case 243:
    var $1182 = __ZNK2JS5Value7toInt32Ev($1177);
    var $1183 = __ZNK2JS5Value7toInt32Ev($1176);
    var $cond84_0 = ($1182 | 0) >= ($1183 | 0) & 1;
    __label__ = 253;
    break;
   case 244:
    var $1187 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1177);
    if ($1187) {
      __label__ = 245;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 245:
    var $1189 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $1176);
    if ($1189) {
      __label__ = 246;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 246:
    var $1191 = __ZNK2JS5Value8isStringEv($1177);
    if ($1191) {
      __label__ = 247;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 247:
    var $1193 = __ZNK2JS5Value8isStringEv($1176);
    if ($1193) {
      __label__ = 248;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 248:
    var $1195 = __ZNK2JS5Value8toStringEv($1177);
    var $1196 = __ZNK2JS5Value8toStringEv($1176);
    var $1197 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($5170, $1195, $1196, $result87);
    if ($1197) {
      __label__ = 249;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 249:
    var $cond84_0 = HEAPU32[$result87 >> 2] >>> 31 & 255 ^ 1;
    __label__ = 253;
    break;
   case 250:
    var $1202 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1177, $l88);
    if ($1202) {
      __label__ = 251;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 251:
    var $1204 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1176, $r89);
    if ($1204) {
      __label__ = 252;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 252:
    var $1206 = (tempDoubleI32[0] = HEAP32[$l88 >> 2], tempDoubleI32[1] = HEAP32[$l88 + 4 >> 2], tempDoubleF64[0]);
    var $1207 = (tempDoubleI32[0] = HEAP32[$r89 >> 2], tempDoubleI32[1] = HEAP32[$r89 + 4 >> 2], tempDoubleF64[0]);
    var $cond84_0 = $1206 >= $1207 & 1;
    __label__ = 253;
    break;
   case 253:
    var $cond84_0;
    var $1211 = HEAPU32[$_pre_phi >> 2];
    var $1212 = $1211 + 1 | 0;
    var $1215 = (HEAPU8[$1212] & 255) - 7 | 0;
    var $1218 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    if ($1215 >>> 0 < 2) {
      __label__ = 254;
      break;
    } else {
      __label__ = 256;
      break;
    }
   case 254:
    HEAP32[$_pre_phi80 >> 2] = $1218;
    if (($cond84_0 & 255 | 0) == (($1215 | 0) != 0 & 1 | 0)) {
      __label__ = 255;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    }
   case 255:
    HEAP32[$_pre_phi >> 2] = $1212;
    var $1232 = (HEAPU8[$1211 + 2 | 0] & 255) << 8 | HEAPU8[$1211 + 3 | 0] & 255;
    var $1234 = $1211 + (($1232 << 16 >> 16) + 1) | 0;
    HEAP32[$_pre_phi >> 2] = $1234;
    var $1236 = HEAPU8[$1234] & 255;
    if ($1232 << 16 >> 16 < 1) {
      var $op_1 = $1236;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $1236;
      __label__ = 20;
      break;
    }
   case 256:
    __ZN2JS5Value10setBooleanEb($1218, $cond84_0 << 24 >> 24 != 0);
    var $1241 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1241;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 257:
    var $1244 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $1245 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1244, $i91);
    if ($1245) {
      __label__ = 258;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 258:
    var $1248 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1249 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1248, $j92);
    if ($1249) {
      __label__ = 259;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 259:
    var $1254 = HEAP32[$i91 >> 2] << (HEAP32[$j92 >> 2] & 31);
    HEAP32[$i91 >> 2] = $1254;
    var $1255 = HEAP32[$_pre_phi80 >> 2];
    var $1256 = $1255 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1256;
    var $1257 = $1255 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($1257, $1254);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 260:
    var $1260 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $1261 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1260, $i93);
    if ($1261) {
      __label__ = 261;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 261:
    var $1264 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1265 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1264, $j94);
    if ($1265) {
      __label__ = 262;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 262:
    var $1270 = HEAP32[$i93 >> 2] >> (HEAP32[$j94 >> 2] & 31);
    HEAP32[$i93 >> 2] = $1270;
    var $1271 = HEAP32[$_pre_phi80 >> 2];
    var $1272 = $1271 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1272;
    var $1273 = $1271 - 16 | 0;
    __ZN2JS5Value8setInt32Ei($1273, $1270);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 263:
    var $1276 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $1277 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $1276, $u);
    if ($1277) {
      __label__ = 264;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 264:
    var $1280 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1281 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1280, $j95);
    if ($1281) {
      __label__ = 265;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 265:
    var $1286 = HEAPU32[$u >> 2] >>> ((HEAP32[$j95 >> 2] & 31) >>> 0);
    HEAP32[$u >> 2] = $1286;
    var $1287 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $1287 - 8 | 0;
    var $1289 = $1287 - 16 | 0;
    var $1290 = __ZN2JS5Value9setNumberEj($1289, $1286);
    if ($1290) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 266;
      break;
    }
   case 266:
    var $1292 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1292);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 267:
    var $1294 = HEAPU32[$_pre_phi80 >> 2];
    var $1295 = $1294 - 8 | 0;
    var $st$2$0 = $1295 | 0;
    var $1296$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1295 + 4 | 0;
    var $1296$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5179 | 0;
    HEAP32[$st$6$0 >> 2] = $1296$0;
    var $st$6$1 = $5179 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1296$1;
    var $1297 = $1294 - 16 | 0;
    var $st$11$0 = $1297 | 0;
    var $1298$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1297 + 4 | 0;
    var $1298$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5180 | 0;
    HEAP32[$st$15$0 >> 2] = $1298$0;
    var $st$15$1 = $5180 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1298$1;
    var $1299 = __ZNK2JS5Value7isInt32Ev($lval97);
    if ($1299) {
      __label__ = 268;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 268:
    var $1301 = __ZNK2JS5Value7isInt32Ev($rval96);
    if ($1301) {
      __label__ = 269;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 269:
    var $1303 = __ZNK2JS5Value7toInt32Ev($lval97);
    var $1304 = __ZNK2JS5Value7toInt32Ev($rval96);
    var $1305 = $1304 + $1303 | 0;
    var $1310 = $1294 - 16 | 0;
    if ((($1305 ^ $1303) & ($1305 ^ $1304) | 0) < 0) {
      __label__ = 270;
      break;
    } else {
      __label__ = 271;
      break;
    }
   case 270:
    var $1314 = ($1303 | 0) + ($1304 | 0);
    __ZN2JS5Value9setDoubleEd($1310, $1314);
    var $1315 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1315);
    __label__ = 272;
    break;
   case 271:
    __ZN2JS5Value8setInt32Ei($1310, $1305);
    __label__ = 272;
    break;
   case 272:
    var $1319 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1319;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 273:
    var $1321 = __ZL5IsXMLRKN2JS5ValueE($lval97);
    if ($1321) {
      __label__ = 274;
      break;
    } else {
      __label__ = 277;
      break;
    }
   case 274:
    var $1323 = __ZL5IsXMLRKN2JS5ValueE($rval96);
    if ($1323) {
      __label__ = 275;
      break;
    } else {
      __label__ = 277;
      break;
    }
   case 275:
    var $1325 = __ZNK2JS5Value8toObjectEv($lval97);
    var $1326 = __ZNK2JS5Value8toObjectEv($rval96);
    var $1327 = $1325;
    var $1328 = $1326;
    var $1329 = __Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE($5177, $1327, $1328, $rval96);
    if (($1329 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 276;
      break;
    }
   case 276:
    var $st$1$0 = $5179 | 0;
    var $1333$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5179 + 4 | 0;
    var $1333$1 = HEAP32[$st$1$1 >> 2];
    var $1334 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $st$6$0 = $1334 | 0;
    HEAP32[$st$6$0 >> 2] = $1333$0;
    var $st$6$1 = $1334 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1333$1;
    var $1336 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1336;
    var $1337 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script_1, $1337);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 277:
    var $1339 = __ZNK2JS5Value8isObjectEv($lval97);
    var $1340 = __ZNK2JS5Value8isObjectEv($rval96);
    var $1341 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $lval97);
    if ($1341) {
      __label__ = 278;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 278:
    var $1343 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $rval96);
    if ($1343) {
      __label__ = 279;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 279:
    var $1345 = __ZNK2JS5Value8isStringEv($lval97);
    var $1346 = __ZNK2JS5Value8isStringEv($rval96);
    if ($1345 | $1346) {
      __label__ = 280;
      break;
    } else {
      __label__ = 292;
      break;
    }
   case 280:
    if ($1345) {
      __label__ = 281;
      break;
    } else {
      __label__ = 282;
      break;
    }
   case 281:
    var $1350 = __ZNK2JS5Value8toStringEv($lval97);
    var $lstr_0 = $1350;
    __label__ = 284;
    break;
   case 282:
    var $1352 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5170, $lval97);
    if (($1352 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 283;
      break;
    }
   case 283:
    var $1356 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($1356, $1352);
    var $lstr_0 = $1352;
    __label__ = 284;
    break;
   case 284:
    var $lstr_0;
    if ($1346) {
      __label__ = 285;
      break;
    } else {
      __label__ = 286;
      break;
    }
   case 285:
    var $1359 = __ZNK2JS5Value8toStringEv($rval96);
    var $rstr_0 = $1359;
    __label__ = 288;
    break;
   case 286:
    var $1361 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5170, $rval96);
    if (($1361 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 287;
      break;
    }
   case 287:
    var $1365 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($1365, $1361);
    var $rstr_0 = $1361;
    __label__ = 288;
    break;
   case 288:
    var $rstr_0;
    var $1367 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $lstr_0, $rstr_0);
    if (($1367 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 289;
      break;
    }
   case 289:
    if ($1339 | $1340) {
      __label__ = 290;
      break;
    } else {
      __label__ = 291;
      break;
    }
   case 290:
    var $1371 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh($cx, $script_1, $1371);
    __label__ = 291;
    break;
   case 291:
    var $1374 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($1374, $1367);
    var $1376 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1376;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 292:
    var $1378 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval97, $l100);
    if ($1378) {
      __label__ = 293;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 293:
    var $1380 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval96, $r101);
    if ($1380) {
      __label__ = 294;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 294:
    var $1382 = (tempDoubleI32[0] = HEAP32[$r101 >> 2], tempDoubleI32[1] = HEAP32[$r101 + 4 >> 2], tempDoubleF64[0]);
    var $1383 = (tempDoubleI32[0] = HEAP32[$l100 >> 2], tempDoubleI32[1] = HEAP32[$l100 + 4 >> 2], tempDoubleF64[0]);
    var $1384 = $1383 + $1382;
    tempDoubleF64[0] = $1384, HEAP32[$l100 >> 2] = tempDoubleI32[0], HEAP32[$l100 + 4 >> 2] = tempDoubleI32[1];
    var $1386 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $1387 = __ZN2JS5Value9setNumberEd($1386, $1384);
    if ($1387) {
      __label__ = 299;
      break;
    } else {
      __label__ = 295;
      break;
    }
   case 295:
    if ($1339 | $1340) {
      __label__ = 298;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $1390 = __ZNK2JS5Value8isDoubleEv($lval97);
    if ($1390) {
      __label__ = 299;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    var $1392 = __ZNK2JS5Value8isDoubleEv($rval96);
    if ($1392) {
      __label__ = 299;
      break;
    } else {
      __label__ = 298;
      break;
    }
   case 298:
    var $1394 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1394);
    __label__ = 299;
    break;
   case 299:
    var $1397 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1397;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 300:
    var $1399 = HEAP32[$_pre_phi80 >> 2];
    var $1400 = $1399 - 8 | 0;
    var $st$2$0 = $1400 | 0;
    var $1401$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1400 + 4 | 0;
    var $1401$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5181 | 0;
    HEAP32[$st$6$0 >> 2] = $1401$0;
    var $st$6$1 = $5181 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1401$1;
    var $1402 = $1399 - 16 | 0;
    var $st$11$0 = $1402 | 0;
    var $1403$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1402 + 4 | 0;
    var $1403$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5182 | 0;
    HEAP32[$st$15$0 >> 2] = $1403$0;
    var $st$15$1 = $5182 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1403$1;
    var $1404 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval103, $d1);
    if ($1404) {
      __label__ = 301;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 301:
    var $1406 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval102, $d2);
    if ($1406) {
      __label__ = 302;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 302:
    var $1408 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $1409 = (tempDoubleI32[0] = HEAP32[$d2 >> 2], tempDoubleI32[1] = HEAP32[$d2 + 4 >> 2], tempDoubleF64[0]);
    var $1410 = $1408 - $1409;
    var $1411 = HEAP32[$_pre_phi80 >> 2];
    var $1412 = $1411 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1412;
    var $1413 = $1411 - 16 | 0;
    var $1414 = __ZN2JS5Value9setNumberEd($1413, $1410);
    if ($1414) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 303:
    var $1416 = __ZNK2JS5Value8isDoubleEv($lval103);
    if ($1416) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 304;
      break;
    }
   case 304:
    var $1418 = __ZNK2JS5Value8isDoubleEv($rval102);
    if ($1418) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 305;
      break;
    }
   case 305:
    var $1420 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1420);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 306:
    var $1422 = HEAP32[$_pre_phi80 >> 2];
    var $1423 = $1422 - 8 | 0;
    var $st$2$0 = $1423 | 0;
    var $1424$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1423 + 4 | 0;
    var $1424$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5183 | 0;
    HEAP32[$st$6$0 >> 2] = $1424$0;
    var $st$6$1 = $5183 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1424$1;
    var $1425 = $1422 - 16 | 0;
    var $st$11$0 = $1425 | 0;
    var $1426$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1425 + 4 | 0;
    var $1426$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5184 | 0;
    HEAP32[$st$15$0 >> 2] = $1426$0;
    var $st$15$1 = $5184 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1426$1;
    var $1427 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval105, $d1106);
    if ($1427) {
      __label__ = 307;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 307:
    var $1429 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval104, $d2107);
    if ($1429) {
      __label__ = 308;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 308:
    var $1431 = (tempDoubleI32[0] = HEAP32[$d1106 >> 2], tempDoubleI32[1] = HEAP32[$d1106 + 4 >> 2], tempDoubleF64[0]);
    var $1432 = (tempDoubleI32[0] = HEAP32[$d2107 >> 2], tempDoubleI32[1] = HEAP32[$d2107 + 4 >> 2], tempDoubleF64[0]);
    var $1433 = $1431 * $1432;
    var $1434 = HEAP32[$_pre_phi80 >> 2];
    var $1435 = $1434 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1435;
    var $1436 = $1434 - 16 | 0;
    var $1437 = __ZN2JS5Value9setNumberEd($1436, $1433);
    if ($1437) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 309;
      break;
    }
   case 309:
    var $1439 = __ZNK2JS5Value8isDoubleEv($lval105);
    if ($1439) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 310;
      break;
    }
   case 310:
    var $1441 = __ZNK2JS5Value8isDoubleEv($rval104);
    if ($1441) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 311;
      break;
    }
   case 311:
    var $1443 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1443);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 312:
    var $1445 = HEAP32[$_pre_phi80 >> 2];
    var $1446 = $1445 - 8 | 0;
    var $st$2$0 = $1446 | 0;
    var $1447$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1446 + 4 | 0;
    var $1447$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5185 | 0;
    HEAP32[$st$6$0 >> 2] = $1447$0;
    var $st$6$1 = $5185 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1447$1;
    var $1448 = $1445 - 16 | 0;
    var $st$11$0 = $1448 | 0;
    var $1449$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $1448 + 4 | 0;
    var $1449$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5186 | 0;
    HEAP32[$st$15$0 >> 2] = $1449$0;
    var $st$15$1 = $5186 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $1449$1;
    var $1450 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lval110, $d1111);
    if ($1450) {
      __label__ = 313;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 313:
    var $1452 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rval109, $d2112);
    if ($1452) {
      __label__ = 314;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 314:
    var $1454 = HEAP32[$_pre_phi80 >> 2];
    var $1455 = $1454 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1455;
    var $1456 = $1454 - 16 | 0;
    var $1457 = (tempDoubleI32[0] = HEAP32[$d1111 >> 2], tempDoubleI32[1] = HEAP32[$d1111 + 4 >> 2], tempDoubleF64[0]);
    var $1458 = (tempDoubleI32[0] = HEAP32[$d2112 >> 2], tempDoubleI32[1] = HEAP32[$d2112 + 4 >> 2], tempDoubleF64[0]);
    var $1459 = __ZN2js9NumberDivEdd($1457, $1458);
    var $1460 = __ZN2JS5Value9setNumberEd($1456, $1459);
    if ($1458 == 0) {
      __label__ = 318;
      break;
    } else {
      __label__ = 315;
      break;
    }
   case 315:
    var $1464 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1465 = __ZNK2JS5Value8isDoubleEv($1464);
    if ($1465) {
      __label__ = 316;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 316:
    var $1467 = __ZNK2JS5Value8isDoubleEv($lval110);
    if ($1467) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1469 = __ZNK2JS5Value8isDoubleEv($rval109);
    if ($1469) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 318;
      break;
    }
   case 318:
    var $1471 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1471);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 319:
    var $1473 = HEAP32[$_pre_phi80 >> 2];
    var $1474 = $1473 - 16 | 0;
    var $1475 = $1473 - 8 | 0;
    var $1476 = __ZNK2JS5Value7isInt32Ev($1474);
    if ($1476) {
      __label__ = 320;
      break;
    } else {
      __label__ = 324;
      break;
    }
   case 320:
    var $1478 = __ZNK2JS5Value7isInt32Ev($1475);
    if ($1478) {
      __label__ = 321;
      break;
    } else {
      __label__ = 324;
      break;
    }
   case 321:
    var $1480 = __ZNK2JS5Value7toInt32Ev($1474);
    if (($1480 | 0) > -1) {
      __label__ = 322;
      break;
    } else {
      __label__ = 324;
      break;
    }
   case 322:
    var $1483 = __ZNK2JS5Value7toInt32Ev($1475);
    if (($1483 | 0) > 0) {
      __label__ = 323;
      break;
    } else {
      __label__ = 324;
      break;
    }
   case 323:
    var $1486 = ($1480 | 0) % ($1483 | 0);
    HEAP32[$_pre_phi80 >> 2] = $1475;
    __ZN2JS5Value8setInt32Ei($1474, $1486);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 324:
    var $1488 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1474, $d1117);
    if ($1488) {
      __label__ = 325;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 325:
    var $1491 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1492 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1491, $d2118);
    if ($1492) {
      __label__ = 326;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 326:
    var $1494 = HEAP32[$_pre_phi80 >> 2];
    var $1495 = $1494 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1495;
    var $1496 = (tempDoubleI32[0] = HEAP32[$d2118 >> 2], tempDoubleI32[1] = HEAP32[$d2118 + 4 >> 2], tempDoubleF64[0]);
    if ($1496 == 0) {
      __label__ = 327;
      break;
    } else {
      __label__ = 328;
      break;
    }
   case 327:
    var $1499 = $1494 - 16 | 0;
    var $1500 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($1499, $1500);
    __label__ = 329;
    break;
   case 328:
    var $1502 = (tempDoubleI32[0] = HEAP32[$d1117 >> 2], tempDoubleI32[1] = HEAP32[$d1117 + 4 >> 2], tempDoubleF64[0]);
    var $1503 = __ZL7js_fmoddd($1502, $1496);
    tempDoubleF64[0] = $1503, HEAP32[$d1117 >> 2] = tempDoubleI32[0], HEAP32[$d1117 + 4 >> 2] = tempDoubleI32[1];
    var $1505 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setDoubleEd($1505, $1503);
    __label__ = 329;
    break;
   case 329:
    var $1507 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1507);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 330:
    var $1510 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1511 = __ZNK2JS5Value6isNullEv($1510);
    if ($1511) {
      var $cond120_0 = 0;
      __label__ = 334;
      break;
    } else {
      __label__ = 331;
      break;
    }
   case 331:
    var $1513 = __ZNK2JS5Value9isBooleanEv($1510);
    if ($1513) {
      __label__ = 332;
      break;
    } else {
      __label__ = 333;
      break;
    }
   case 332:
    var $1515 = __ZNK2JS5Value9toBooleanEv($1510);
    var $cond120_0 = $1515 & 1;
    __label__ = 334;
    break;
   case 333:
    var $1518 = __Z17js_ValueToBooleanRKN2JS5ValueE($1510);
    var $cond120_0 = ($1518 | 0) != 0 & 1;
    __label__ = 334;
    break;
   case 334:
    var $cond120_0;
    __ZN2JS5Value10setBooleanEb($1510, $cond120_0 << 24 >> 24 == 0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 335:
    var $1525 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1526 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $1525, $i121);
    if ($1526) {
      __label__ = 336;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 336:
    var $1529 = HEAP32[$i121 >> 2] ^ -1;
    HEAP32[$i121 >> 2] = $1529;
    var $1531 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value8setInt32Ei($1531, $1529);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 337:
    var $1533 = HEAPU32[$_pre_phi80 >> 2];
    var $1534 = $1533 - 8 | 0;
    var $st$2$0 = $1534 | 0;
    var $1535$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1534 + 4 | 0;
    var $1535$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5187 | 0;
    HEAP32[$st$6$0 >> 2] = $1535$0;
    var $st$6$1 = $5187 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1535$1;
    var $1536 = __ZNK2JS5Value7isInt32Ev($ref122);
    if ($1536) {
      __label__ = 338;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 338:
    var $1538 = __ZNK2JS5Value7toInt32Ev($ref122);
    if (($1538 | 0) == 0 || ($1538 | 0) == -2147483648) {
      __label__ = 340;
      break;
    } else {
      __label__ = 339;
      break;
    }
   case 339:
    var $1540 = -$1538 | 0;
    var $1541 = $1533 - 8 | 0;
    __ZN2JS5Value8setInt32Ei($1541, $1540);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 340:
    var $1543 = $1533 - 8 | 0;
    var $1544 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1543, $d124);
    if ($1544) {
      __label__ = 341;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 341:
    var $1546 = (tempDoubleI32[0] = HEAP32[$d124 >> 2], tempDoubleI32[1] = HEAP32[$d124 + 4 >> 2], tempDoubleF64[0]);
    var $1547 = -$1546;
    tempDoubleF64[0] = $1547, HEAP32[$d124 >> 2] = tempDoubleI32[0], HEAP32[$d124 + 4 >> 2] = tempDoubleI32[1];
    var $1549 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1550 = __ZN2JS5Value9setNumberEd($1549, $1547);
    if ($1550) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 342;
      break;
    }
   case 342:
    var $1552 = __ZNK2JS5Value8isDoubleEv($ref122);
    if ($1552) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 343;
      break;
    }
   case 343:
    var $1554 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1554);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 344:
    var $1557 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1558 = __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $1557);
    if ($1558) {
      __label__ = 345;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 345:
    var $1561 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1562 = __ZNK2JS5Value7isInt32Ev($1561);
    if ($1562) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 346:
    var $1564 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1564);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 347:
    var $1566 = HEAPU32[$_pre_phi >> 2];
    var $1576 = HEAP32[$atoms_1 + (((HEAPU8[$1566 + 1 | 0] & 255) << 8 | HEAPU8[$1566 + 2 | 0] & 255) << 2) >> 2];
    var $1577 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1576);
    var $1578 = __Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty($5173, $1577, 0, $5188, $obj2128, $5189);
    if (($1578 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1581 = HEAP32[$_pre_phi80 >> 2];
    var $1582 = $1581 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1582;
    __ZN2JS5Value10setBooleanEb($1581, 1);
    if ((HEAP32[$prop129 >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 349;
      break;
    }
   case 349:
    var $1586 = HEAP32[$obj127 >> 2];
    var $1588 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1589 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($1586, $cx, $1577, $1588, 0);
    if (($1589 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 350:
    var $1592 = HEAPU32[$_pre_phi >> 2];
    var $1602 = HEAP32[$atoms_1 + (((HEAPU8[$1592 + 1 | 0] & 255) << 8 | HEAPU8[$1592 + 2 | 0] & 255) << 2) >> 2];
    var $1603 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1602);
    var $1605 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1606 = __ZNK2JS5Value8isObjectEv($1605);
    if ($1606) {
      __label__ = 351;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 351:
    var $1608 = __ZNK2JS5Value8toObjectEv($1605);
    var $obj132_0 = $1608;
    __label__ = 354;
    break;
   case 352:
    var $1610 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $1605);
    var $1611 = $1610;
    if (($1610 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 353;
      break;
    }
   case 353:
    __ZN2JS5Value9setObjectER8JSObject($1605, $1611);
    var $obj132_0 = $1611;
    __label__ = 354;
    break;
   case 354:
    var $obj132_0;
    var $1619 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1620 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj132_0, $cx, $1603, $rval134, $1619);
    if (($1620 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 355;
      break;
    }
   case 355:
    var $st$1$0 = $5190 | 0;
    var $1624$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5190 + 4 | 0;
    var $1624$1 = HEAP32[$st$1$1 >> 2];
    var $1625 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $1625 | 0;
    HEAP32[$st$6$0 >> 2] = $1624$0;
    var $st$6$1 = $1625 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1624$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 356:
    var $1627 = HEAP32[$_pre_phi80 >> 2];
    var $1628 = $1627 - 16 | 0;
    var $1629 = __ZNK2JS5Value8isObjectEv($1628);
    if ($1629) {
      __label__ = 357;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 357:
    var $1631 = __ZNK2JS5Value8toObjectEv($1628);
    var $obj135_0 = $1631;
    var $1638 = $1627;
    __label__ = 360;
    break;
   case 358:
    var $1633 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $1628);
    var $1634 = $1633;
    if (($1633 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 359;
      break;
    }
   case 359:
    __ZN2JS5Value9setObjectER8JSObject($1628, $1634);
    var $obj135_0 = $1634;
    var $1638 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 360;
    break;
   case 360:
    var $1638;
    var $obj135_0;
    var $1639 = $1638 - 8 | 0;
    var $1640 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1639, $i_139);
    if ($1640) {
      __label__ = 361;
      break;
    } else {
      __label__ = 363;
      break;
    }
   case 361:
    var $1642 = HEAP32[$i_139 >> 2];
    var $1643 = _INT_FITS_IN_JSID1825($1642);
    if (($1643 | 0) == 0) {
      __label__ = 363;
      break;
    } else {
      __label__ = 362;
      break;
    }
   case 362:
    var $1646 = _INT_TO_JSID1826($1642);
    HEAP32[$id137 >> 2] = $1646;
    var $1652 = $1646;
    __label__ = 365;
    break;
   case 363:
    var $1649 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1650 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj135_0, $1639, $id137, $1649);
    if ($1650) {
      __label__ = 364;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 364:
    var $1652 = HEAP32[$id137 >> 2];
    __label__ = 365;
    break;
   case 365:
    var $1652;
    var $1654 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $1659 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1660 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($obj135_0, $cx, $1652, $1654, $1659);
    if (($1660 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 366;
      break;
    }
   case 366:
    var $1664 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1664;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 367:
    var $1666 = HEAPU32[$_pre_phi80 >> 2];
    var $1667 = $1666 - 16 | 0;
    var $1668 = __ZNK2JS5Value8isObjectEv($1667);
    if ($1668) {
      __label__ = 368;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 368:
    var $1670 = __ZNK2JS5Value8toObjectEv($1667);
    var $obj140_0 = $1670;
    var $1677 = $1666;
    __label__ = 371;
    break;
   case 369:
    var $1672 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $1667);
    var $1673 = $1672;
    if (($1672 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 370;
      break;
    }
   case 370:
    __ZN2JS5Value9setObjectER8JSObject($1667, $1673);
    var $obj140_0 = $1673;
    var $1677 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 371;
    break;
   case 371:
    var $1677;
    var $obj140_0;
    var $1678 = $1677 - 8 | 0;
    var $1679 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1678, $i_144);
    if ($1679) {
      __label__ = 372;
      break;
    } else {
      __label__ = 374;
      break;
    }
   case 372:
    var $1681 = HEAP32[$i_144 >> 2];
    var $1682 = _INT_FITS_IN_JSID1825($1681);
    if (($1682 | 0) == 0) {
      __label__ = 374;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 373:
    var $1685 = _INT_TO_JSID1826($1681);
    HEAP32[$id142 >> 2] = $1685;
    __label__ = 375;
    break;
   case 374:
    var $1688 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1689 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj140_0, $1678, $id142, $1688);
    if ($1689) {
      __label__ = 375;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 375:
    var $1692 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1693 = __ZNK2JS5Value7isInt32Ev($1692);
    if ($1693) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 376;
      break;
    }
   case 376:
    var $1695 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh($cx, $script_1, $1695);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 377:
    var $1698 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $1698 | 0;
    var $1699$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $1698 + 4 | 0;
    var $1699$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5191 | 0;
    HEAP32[$st$6$0 >> 2] = $1699$0;
    var $st$6$1 = $5191 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $1699$1;
    var $1700 = _JS_TypeOfValue($cx, $2);
    var $1704 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1705 = HEAP32[$33 + 209984 + ($1700 << 2) >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($1704, $1705);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 378:
    var $1708 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value12setUndefinedEv($1708);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 379:
    var $1710 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1710) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 19;
      break;
    } else {
      var $i150_0 = -2;
      var $1727 = 2;
      __label__ = 382;
      break;
    }
   case 380:
    var $1712 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1712) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 381;
      break;
    }
   case 381:
    var $1714 = HEAPU32[$_pre_phi >> 2];
    var $1724 = HEAP32[$atoms_1 + (((HEAPU8[$1714 + 1 | 0] & 255) << 8 | HEAPU8[$1714 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom148 >> 2] = $1724;
    var $1725 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1724);
    var $i150_0 = -1;
    var $1727 = $1725;
    __label__ = 382;
    break;
   case 382:
    var $1727;
    var $i150_0;
    HEAP32[$id149 >> 2] = $1727;
    var $1729 = HEAP32[$_pre_phi80 >> 2] + ($i150_0 << 3) | 0;
    var $1730 = __ZNK2JS5Value8isObjectEv($1729);
    if ($1730) {
      __label__ = 383;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 383:
    var $1732 = __ZNK2JS5Value8toObjectEv($1729);
    HEAP32[$obj147 >> 2] = $1732;
    var $1739 = $1732;
    __label__ = 386;
    break;
   case 384:
    var $1734 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $1729);
    var $1735 = $1734;
    HEAP32[$obj147 >> 2] = $1735;
    if (($1734 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 385;
      break;
    }
   case 385:
    __ZN2JS5Value9setObjectER8JSObject($1729, $1735);
    var $1739 = $1735;
    __label__ = 386;
    break;
   case 386:
    var $1739;
    var $1740 = _JSID_IS_VOID1831($1727);
    if (($1740 | 0) == 0) {
      var $1823 = $1739;
      var $1822 = $1727;
      __label__ = 405;
      break;
    } else {
      __label__ = 387;
      break;
    }
   case 387:
    var $1744 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1745 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($1744, $i_153);
    if ($1745) {
      __label__ = 388;
      break;
    } else {
      __label__ = 390;
      break;
    }
   case 388:
    var $1747 = HEAP32[$i_153 >> 2];
    var $1748 = _INT_FITS_IN_JSID1825($1747);
    if (($1748 | 0) == 0) {
      __label__ = 390;
      break;
    } else {
      __label__ = 389;
      break;
    }
   case 389:
    var $1751 = _INT_TO_JSID1826($1747);
    HEAP32[$id149 >> 2] = $1751;
    var $1823 = $1739;
    var $1822 = $1751;
    __label__ = 405;
    break;
   case 390:
    var $1754 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1755 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $1739, $1744, $id149, $1754);
    if ($1755) {
      __label__ = 391;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 391:
    var $1823 = $1739;
    var $1822 = HEAP32[$id149 >> 2];
    __label__ = 405;
    break;
   case 392:
    var $1757 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1757) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 393;
      break;
    }
   case 393:
    var $1759 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1760 = __ZNK2js10StackFrame10scopeChainEv($1759);
    HEAP32[$obj147 >> 2] = $1760;
    var $1762 = HEAPU32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2];
    var $1764 = ($1762 & 33554432 | 0) != 0;
    if ($1764) {
      __label__ = 394;
      break;
    } else {
      __label__ = 395;
      break;
    }
   case 394:
    var $1766 = $1760;
    var $1767 = __ZNK8JSObject9getGlobalEv($1766);
    HEAP32[$obj147 >> 2] = $1767;
    __label__ = 395;
    break;
   case 395:
    var $1771 = HEAP32[$32 >> 2] + 144336 | 0;
    var $1772 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($1771, $cx, $1772, $obj147, $obj2154, $entry155, $atom148);
    var $1773 = HEAPU32[$atom148 >> 2];
    if (($1773 | 0) == 0) {
      __label__ = 396;
      break;
    } else {
      var $1815 = $1773;
      __label__ = 402;
      break;
    }
   case 396:
    var $1776 = HEAPU32[$obj147 >> 2];
    if (($1776 | 0) == (HEAP32[$obj2154 >> 2] | 0)) {
      __label__ = 397;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 397:
    var $1781 = HEAP32[$entry155 >> 2] + 12 | 0;
    var $1782 = __ZNK2js5PCVal6isSlotEv($1781);
    if ($1782) {
      __label__ = 398;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 398:
    var $1784 = __ZNK2js5PCVal6toSlotEv($1781);
    var $1785 = __ZNK8JSObject13nativeGetSlotEj($1776, $1784);
    var $1786 = __ZNK2JS5Value7isInt32Ev($1785);
    if ($1786) {
      __label__ = 399;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 399:
    var $1788 = __ZNK2JS5Value7toInt32Ev($1785);
    var $1789 = __ZL24CanIncDecWithoutOverflowi($1788);
    if ($1789) {
      __label__ = 400;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 400:
    var $1794 = $1788 - 1 + ($1762 >>> 10 & 2) | 0;
    var $tmp_0 = ($1762 & 4096 | 0) == 0 ? $1794 : $1788;
    __ZN2JSL10Int32ValueEi1832($3, $1794);
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($1776, $1784, $3);
    var $1797 = HEAP32[$_pre_phi80 >> 2];
    var $1798 = $1797 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1798;
    __ZN2JS5Value8setInt32Ei($1797, $tmp_0);
    var $1799 = HEAP32[$_pre_phi >> 2];
    var $1800 = __ZN2jsL18GetDecomposeLengthEPhj($1799, 4);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $1800 + 4 | 0;
    __label__ = 19;
    break;
   case 401:
    var $1803 = HEAPU32[$_pre_phi >> 2];
    var $1813 = HEAPU32[$atoms_1 + (((HEAPU8[$1803 + 1 | 0] & 255) << 8 | HEAPU8[$1803 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom148 >> 2] = $1813;
    var $1815 = $1813;
    __label__ = 402;
    break;
   case 402:
    var $1815;
    var $1816 = __ZL12ATOM_TO_JSIDP6JSAtom1798($1815);
    HEAP32[$id149 >> 2] = $1816;
    var $1817 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($5173, $1816, 1, $1764, $5192, $5193, $5194);
    if (($1817 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 403;
      break;
    }
   case 403:
    if ((HEAP32[$prop157 >> 2] | 0) == 0) {
      var $atomNotDefined_0 = $1815;
      __label__ = 1048;
      break;
    } else {
      __label__ = 404;
      break;
    }
   case 404:
    var $1823 = HEAP32[$obj147 >> 2];
    var $1822 = $1816;
    __label__ = 405;
    break;
   case 405:
    var $1822;
    var $1823;
    var $1824 = HEAP32[$_pre_phi80 >> 2];
    var $1825 = $1824 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1825;
    __ZN2JS5Value7setNullEv($1824);
    var $1827 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1828 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1823, $cx, $1822, $1827);
    if (($1828 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 406;
      break;
    }
   case 406:
    var $1831 = _js_CodeSpec + ($op_0 << 3) | 0;
    var $1833 = HEAPU32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2];
    var $1836 = ($1833 & 224 | 0) == 32 ? 2 : 3;
    var $1837 = HEAPU32[$_pre_phi80 >> 2];
    var $1838 = $1837 - 8 | 0;
    var $1839 = __ZNK2JS5Value7isInt32Ev($1838);
    if ($1839) {
      __label__ = 407;
      break;
    } else {
      __label__ = 410;
      break;
    }
   case 407:
    var $1841 = __ZNK2JS5Value7toInt32Ev($1838);
    var $1842 = __ZL24CanIncDecWithoutOverflowi($1841);
    if ($1842) {
      __label__ = 408;
      break;
    } else {
      __label__ = 410;
      break;
    }
   case 408:
    var $1847 = ($1833 >>> 10 & 2) - 1 + $1841 | 0;
    var $1848 = __ZN2JS5Value11getInt32RefEv($1838);
    HEAP32[$1848 >> 2] = $1847;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf160, $cx, $1836);
    var $1853 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1854 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($1823, $cx, $1822, $1838, $1853);
    var $1855 = ($1854 | 0) == 0;
    __ZN18JSAutoResolveFlagsD1Ev($rf160);
    if ($1855) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 409;
      break;
    }
   case 409:
    var $_64 = ($1833 & 4096 | 0) == 0 ? $1847 : $1841;
    __ZN2JS5Value8setInt32Ei($1838, $_64);
    __label__ = 413;
    break;
   case 410:
    HEAP32[$_pre_phi80 >> 2] = $1837 + 8 | 0;
    __ZN2JS5Value7setNullEv($1837);
    var $1861 = HEAP32[$_pre_phi80 >> 2];
    var $1862 = $1861 - 16 | 0;
    var $1863 = $1861 - 8 | 0;
    var $1864 = __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $1831, $1862, $1863);
    if ($1864) {
      __label__ = 411;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 411:
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf161, $cx, $1836);
    var $1867 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1872 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $1873 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($1823, $cx, $1822, $1867, $1872);
    var $1874 = ($1873 | 0) == 0;
    __ZN18JSAutoResolveFlagsD1Ev($rf161);
    if ($1874) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 412;
      break;
    }
   case 412:
    var $1877 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1877;
    __label__ = 413;
    break;
   case 413:
    var $1880 = HEAP8[_js_CodeSpec + ($op_0 << 3) + 1 | 0];
    if ($1880 << 24 >> 24 == 0) {
      __label__ = 415;
      break;
    } else {
      __label__ = 414;
      break;
    }
   case 414:
    var $1883 = $1880 << 24 >> 24;
    var $1885 = HEAP32[$_pre_phi80 >> 2];
    var $1886 = $1885 - 8 | 0;
    var $st$4$0 = $1886 | 0;
    var $1887$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $1886 + 4 | 0;
    var $1887$1 = HEAP32[$st$4$1 >> 2];
    var $1888 = $1885 + (($1883 ^ -1) << 3) | 0;
    var $st$9$0 = $1888 | 0;
    HEAP32[$st$9$0 >> 2] = $1887$0;
    var $st$9$1 = $1888 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $1887$1;
    var $1891 = HEAP32[$_pre_phi80 >> 2] + (-$1883 << 3) | 0;
    HEAP32[$_pre_phi80 >> 2] = $1891;
    __label__ = 415;
    break;
   case 415:
    var $1895 = HEAP8[$1831 | 0] << 24 >> 24;
    var $1896 = HEAP32[$_pre_phi >> 2];
    var $1897 = __ZN2jsL18GetDecomposeLengthEPhj($1896, $1895);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $1897 + $1895 | 0;
    __label__ = 19;
    break;
   case 416:
    var $incr2_0 = 0;
    var $incr163_0 = 1;
    __label__ = 419;
    break;
   case 417:
    var $incr2_0 = -1;
    var $incr163_0 = -1;
    __label__ = 419;
    break;
   case 418:
    var $incr2_0 = 0;
    var $incr163_0 = -1;
    __label__ = 419;
    break;
   case 419:
    var $incr163_0;
    var $incr2_0;
    var $1901 = HEAPU32[$_pre_phi >> 2];
    var $vp165_0 = $argv_1 + (((HEAPU8[$1901 + 1 | 0] & 255) << 8 | HEAPU8[$1901 + 2 | 0] & 255) << 3) | 0;
    var $incr2_2 = $incr2_0;
    var $incr163_2 = $incr163_0;
    __label__ = 424;
    break;
   case 420:
    var $incr2_1 = 0;
    var $incr163_1 = 1;
    __label__ = 423;
    break;
   case 421:
    var $incr2_1 = -1;
    var $incr163_1 = -1;
    __label__ = 423;
    break;
   case 422:
    var $incr2_1 = 0;
    var $incr163_1 = -1;
    __label__ = 423;
    break;
   case 423:
    var $incr163_1;
    var $incr2_1;
    var $1913 = HEAPU32[$_pre_phi >> 2];
    var $1921 = (HEAPU8[$1913 + 1 | 0] & 255) << 8 | HEAPU8[$1913 + 2 | 0] & 255;
    var $1922 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1923 = $1922;
    var $1924 = __ZNK2js10StackFrame5slotsEv($1923);
    var $vp165_0 = $1924 + ($1921 << 3) | 0;
    var $incr2_2 = $incr2_1;
    var $incr163_2 = $incr163_1;
    __label__ = 424;
    break;
   case 424:
    var $incr163_2;
    var $incr2_2;
    var $vp165_0;
    var $1927 = __ZNK2JS5Value7isInt32Ev($vp165_0);
    if ($1927) {
      __label__ = 425;
      break;
    } else {
      __label__ = 429;
      break;
    }
   case 425:
    var $1929 = __ZNK2JS5Value7toInt32Ev($vp165_0);
    var $1930 = __ZL24CanIncDecWithoutOverflowi($1929);
    if ($1930) {
      __label__ = 426;
      break;
    } else {
      __label__ = 429;
      break;
    }
   case 426:
    var $1932 = $1929 + $incr163_2 | 0;
    var $1933 = __ZN2JS5Value11getInt32RefEv($vp165_0);
    HEAP32[$1933 >> 2] = $1932;
    var $1934 = HEAP32[$_pre_phi >> 2];
    var $1938 = HEAPU32[$_pre_phi80 >> 2];
    if (HEAP8[$1934 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 427;
      break;
    } else {
      __label__ = 428;
      break;
    }
   case 427:
    HEAP32[$_pre_phi80 >> 2] = $1938;
    var $1940 = $1934 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $1940;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$1940] & 255;
    __label__ = 20;
    break;
   case 428:
    HEAP32[$_pre_phi80 >> 2] = $1938 + 8 | 0;
    var $1945 = $1929 + $incr2_2 | 0;
    __ZN2JS5Value8setInt32Ei($1938, $1945);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 429:
    var $1947 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $1947 + 8 | 0;
    var $1949 = $vp165_0 | 0;
    var $st$4$0 = $1949 | 0;
    var $1950$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $1949 + 4 | 0;
    var $1950$1 = HEAP32[$st$4$1 >> 2];
    var $1951 = $1947 | 0;
    var $st$9$0 = $1951 | 0;
    HEAP32[$st$9$0 >> 2] = $1950$0;
    var $st$9$1 = $1951 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $1950$1;
    var $1952 = _js_CodeSpec + ($op_0 << 3) | 0;
    var $1954 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $1955 = __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $1952, $1954, $vp165_0);
    if ($1955) {
      __label__ = 430;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 430:
    var $1957 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script_1, $1957);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 431:
    var $1959 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1960 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $1959);
    if ($1960) {
      __label__ = 432;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 432:
    var $1962 = HEAP32[$_pre_phi80 >> 2];
    var $1963 = $1962 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $1963;
    var $1964 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1965 = __ZNK2js10StackFrame9thisValueEv($1964);
    var $1966 = $1965 | 0;
    var $st$6$0 = $1966 | 0;
    var $1967$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $1966 + 4 | 0;
    var $1967$1 = HEAP32[$st$6$1 >> 2];
    var $1968 = $1962 | 0;
    var $st$11$0 = $1968 | 0;
    HEAP32[$st$11$0 >> 2] = $1967$0;
    var $st$11$1 = $1968 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $1967$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 433:
    var $1970 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1971 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($cx, $1970);
    if ($1971) {
      __label__ = 434;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 434:
    var $1973 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1974 = __ZNK2js10StackFrame9thisValueEv($1973);
    var $1975 = __ZNK2JS5Value8isObjectEv($1974);
    if ($1975) {
      __label__ = 435;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 435:
    var $1977 = __ZNK2JS5Value8toObjectEv($1974);
    var $1978 = __ZNK8JSObject8isNativeEv($1977);
    if ($1978) {
      __label__ = 436;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 436:
    var $1980 = $1977;
    var $1981 = __ZN8JSObject7unbrandEP9JSContext($1980, $5195);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 437:
    var $1984 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    if (($op_0 | 0) == 220) {
      __label__ = 438;
      break;
    } else {
      __label__ = 450;
      break;
    }
   case 438:
    var $1987 = __ZNK2JS5Value8isStringEv($1984);
    if ($1987) {
      __label__ = 439;
      break;
    } else {
      __label__ = 440;
      break;
    }
   case 439:
    var $1989 = __ZNK2JS5Value8toStringEv($1984);
    var $1990 = __ZNK8JSString6lengthEv($1989);
    __ZN2JSL10Int32ValueEi1832($4, $1990);
    var $st$3$0 = $5196 | 0;
    var $1991$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5196 + 4 | 0;
    var $1991$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5197 | 0;
    HEAP32[$st$7$0 >> 2] = $1991$0;
    var $st$7$1 = $5197 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $1991$1;
    __label__ = 470;
    break;
   case 440:
    var $1993 = __ZNK2JS5Value7isMagicE10JSWhyMagic($1984, undef);
    if ($1993) {
      __label__ = 441;
      break;
    } else {
      __label__ = 442;
      break;
    }
   case 441:
    var $1995 = __ZNK2js9FrameRegs2fpEv($regs);
    var $1996 = __ZNK2js10StackFrame13numActualArgsEv($1995);
    __ZN2JSL10Int32ValueEi1832($5, $1996);
    var $st$3$0 = $5198 | 0;
    var $1997$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5198 + 4 | 0;
    var $1997$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5197 | 0;
    HEAP32[$st$7$0 >> 2] = $1997$0;
    var $st$7$1 = $5197 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $1997$1;
    __label__ = 470;
    break;
   case 442:
    var $1999 = __ZNK2JS5Value8isObjectEv($1984);
    if ($1999) {
      __label__ = 443;
      break;
    } else {
      __label__ = 450;
      break;
    }
   case 443:
    var $2001 = __ZNK2JS5Value8toObjectEv($1984);
    var $2002 = __ZNK8JSObject7isArrayEv($2001);
    if ($2002) {
      __label__ = 444;
      break;
    } else {
      __label__ = 445;
      break;
    }
   case 444:
    var $2004 = __ZNK8JSObject14getArrayLengthEv($2001);
    var $2005 = $2004 >>> 0;
    __ZN2JSL11NumberValueEd1833($6, $2005);
    var $st$3$0 = $5199 | 0;
    var $2006$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5199 + 4 | 0;
    var $2006$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5197 | 0;
    HEAP32[$st$7$0 >> 2] = $2006$0;
    var $st$7$1 = $5197 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2006$1;
    __label__ = 470;
    break;
   case 445:
    var $2008 = __ZNK8JSObject11isArgumentsEv($2001);
    if ($2008) {
      __label__ = 446;
      break;
    } else {
      __label__ = 448;
      break;
    }
   case 446:
    var $2010 = __ZN8JSObject11asArgumentsEv($2001);
    var $2011 = __ZNK2js15ArgumentsObject19hasOverriddenLengthEv($2010);
    if ($2011) {
      __label__ = 448;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 447:
    var $2013 = __ZNK2js15ArgumentsObject13initialLengthEv($2010);
    __ZN2JSL10Int32ValueEi1832($7, $2013);
    var $st$2$0 = $5200 | 0;
    var $2014$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5200 + 4 | 0;
    var $2014$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5197 | 0;
    HEAP32[$st$6$0 >> 2] = $2014$0;
    var $st$6$1 = $5197 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2014$1;
    __label__ = 470;
    break;
   case 448:
    var $2016 = __Z15js_IsTypedArrayP8JSObject($2001);
    if (($2016 | 0) == 0) {
      __label__ = 450;
      break;
    } else {
      __label__ = 449;
      break;
    }
   case 449:
    var $2019 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2001);
    var $2020 = __ZN2js10TypedArray9getLengthEP8JSObject($2019);
    __ZN2JSL10Int32ValueEi1832($8, $2020);
    var $st$3$0 = $5201 | 0;
    var $2021$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5201 + 4 | 0;
    var $2021$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5197 | 0;
    HEAP32[$st$7$0 >> 2] = $2021$0;
    var $st$7$1 = $5197 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2021$1;
    __label__ = 470;
    break;
   case 450:
    var $2023 = __ZNK2JS5Value8isObjectEv($1984);
    if ($2023) {
      __label__ = 451;
      break;
    } else {
      __label__ = 452;
      break;
    }
   case 451:
    var $2025 = __ZNK2JS5Value8toObjectEv($1984);
    var $obj172_0 = $2025;
    __label__ = 454;
    break;
   case 452:
    var $2027 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $1984);
    var $2028 = $2027;
    if (($2027 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 453:
    __ZN2JS5Value9setObjectER8JSObject($1984, $2028);
    var $obj172_0 = $2028;
    __label__ = 454;
    break;
   case 454:
    var $obj172_0;
    var $2032 = __Z23js_GetProtoIfDenseArrayP8JSObject($obj172_0);
    HEAP32[$aobj >> 2] = $2032;
    var $2034 = HEAP32[$32 >> 2] + 144336 | 0;
    var $2035 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($2034, $cx, $2035, $aobj, $obj2174, $entry173, $atom175);
    var $2036 = HEAP32[$atom175 >> 2];
    if (($2036 | 0) == 0) {
      __label__ = 455;
      break;
    } else {
      __label__ = 465;
      break;
    }
   case 455:
    var $2040 = HEAP32[$entry173 >> 2] + 12 | 0;
    var $2041 = __ZNK2js5PCVal8isFunObjEv($2040);
    if ($2041) {
      __label__ = 456;
      break;
    } else {
      __label__ = 457;
      break;
    }
   case 456:
    var $2043 = __ZNK2js5PCVal8toFunObjEv($2040);
    __ZN2JS5Value9setObjectER8JSObject($rval168, $2043);
    __label__ = 470;
    break;
   case 457:
    var $2045 = __ZNK2js5PCVal6isSlotEv($2040);
    if ($2045) {
      __label__ = 458;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 458:
    var $2047 = __ZNK2js5PCVal6toSlotEv($2040);
    var $2048 = HEAP32[$obj2174 >> 2];
    var $2049 = __ZNK8JSObject13nativeGetSlotEj($2048, $2047);
    var $2050 = $2049 | 0;
    var $st$4$0 = $2050 | 0;
    var $2051$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $2050 + 4 | 0;
    var $2051$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5197 | 0;
    HEAP32[$st$8$0 >> 2] = $2051$0;
    var $st$8$1 = $5197 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2051$1;
    __label__ = 470;
    break;
   case 459:
    var $2053 = __ZNK2js5PCVal7toShapeEv($2040);
    var $2054 = __ZNK2js5Shape16isDataDescriptorEv($2053);
    if ($2054) {
      __label__ = 460;
      break;
    } else {
      __label__ = 464;
      break;
    }
   case 460:
    var $2056 = __ZNK2js5Shape16hasDefaultGetterEv($2053);
    if ($2056) {
      __label__ = 461;
      break;
    } else {
      __label__ = 464;
      break;
    }
   case 461:
    var $2059 = HEAP32[$2053 + 24 >> 2];
    if (($2059 | 0) == -1) {
      __label__ = 463;
      break;
    } else {
      __label__ = 462;
      break;
    }
   case 462:
    var $2062 = HEAP32[$obj2174 >> 2];
    var $2063 = __ZNK8JSObject13nativeGetSlotEj($2062, $2059);
    var $2064 = $2063 | 0;
    var $st$3$0 = $2064 | 0;
    var $2065$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2064 + 4 | 0;
    var $2065$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5197 | 0;
    HEAP32[$st$7$0 >> 2] = $2065$0;
    var $st$7$1 = $5197 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2065$1;
    __label__ = 470;
    break;
   case 463:
    __ZN2JS5Value12setUndefinedEv($rval168);
    __label__ = 470;
    break;
   case 464:
    var $2068 = HEAP32[$obj2174 >> 2];
    var $2069 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2070 = __ZNK2js10StackFrame11hasImacropcEv($2069);
    var $2071 = $2070 ? 2 : 0;
    var $2073 = $2068;
    var $2074 = $2053;
    var $2075 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5173, $obj172_0, $2073, $2074, $2071, $rval168);
    if (($2075 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 470;
      break;
    }
   case 465:
    var $2078 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2036);
    var $2079 = HEAP32[$aobj >> 2];
    var $2080 = __ZNK8JSObject6getOpsEv($2079);
    if ((HEAP32[$2080 + 36 >> 2] | 0) == 0) {
      __label__ = 466;
      break;
    } else {
      __label__ = 469;
      break;
    }
   case 466:
    var $2085 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2086 = __ZNK2js10StackFrame11hasImacropcEv($2085);
    if ($2086) {
      var $2093 = 3;
      __label__ = 468;
      break;
    } else {
      __label__ = 467;
      break;
    }
   case 467:
    var $phitmp = HEAP8[HEAP32[$_pre_phi >> 2] + 3 | 0] << 24 >> 24 == 7 ? 3 : 1;
    var $2093 = $phitmp;
    __label__ = 468;
    break;
   case 468:
    var $2093;
    var $2095 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($5173, $obj172_0, $2078, $2093, $rval168);
    if (($2095 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 470;
      break;
    }
   case 469:
    var $2098 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj172_0, $cx, $2078, $rval168);
    if (($2098 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 470;
      break;
    }
   case 470:
    var $2101 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2101, $rval168);
    var $st$3$0 = $5197 | 0;
    var $2103$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5197 + 4 | 0;
    var $2103$1 = HEAP32[$st$3$1 >> 2];
    var $2104 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$8$0 = $2104 | 0;
    HEAP32[$st$8$0 >> 2] = $2103$0;
    var $st$8$1 = $2104 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2103$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 471:
    var $2107 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $2107 | 0;
    var $2108$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $2107 + 4 | 0;
    var $2108$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5202 | 0;
    HEAP32[$st$6$0 >> 2] = $2108$0;
    var $st$6$1 = $5202 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2108$1;
    var $2109 = __ZNK2JS5Value8isObjectEv($lval178);
    if ($2109) {
      __label__ = 472;
      break;
    } else {
      __label__ = 473;
      break;
    }
   case 472:
    var $st$0$0 = $5203 | 0;
    HEAP32[$st$0$0 >> 2] = $2108$0;
    var $st$0$1 = $5203 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $2108$1;
    __label__ = 479;
    break;
   case 473:
    var $2112 = __ZNK2JS5Value8isStringEv($lval178);
    if ($2112) {
      var $protoKey_0 = 9;
      __label__ = 477;
      break;
    } else {
      __label__ = 474;
      break;
    }
   case 474:
    var $2114 = __ZNK2JS5Value8isNumberEv($lval178);
    if ($2114) {
      var $protoKey_0 = 8;
      __label__ = 477;
      break;
    } else {
      __label__ = 475;
      break;
    }
   case 475:
    var $2116 = __ZNK2JS5Value9isBooleanEv($lval178);
    if ($2116) {
      var $protoKey_0 = 4;
      __label__ = 477;
      break;
    } else {
      __label__ = 476;
      break;
    }
   case 476:
    var $2118 = __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, -1, $lval178, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 477:
    var $protoKey_0;
    var $2120 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($5173, 0, $protoKey_0, $5205, 0);
    if (($2120 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 478;
      break;
    }
   case 478:
    var $2123 = HEAP32[$pobj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($objv, $2123);
    __label__ = 479;
    break;
   case 479:
    var $2125 = __ZNK2JS5Value8toObjectEv($objv);
    var $2126 = __Z23js_GetProtoIfDenseArrayP8JSObject($2125);
    HEAP32[$aobj179 >> 2] = $2126;
    var $2128 = HEAP32[$32 >> 2] + 144336 | 0;
    var $2129 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($2128, $cx, $2129, $aobj179, $obj2182, $entry181, $atom183);
    var $2130 = HEAP32[$atom183 >> 2];
    if (($2130 | 0) == 0) {
      __label__ = 480;
      break;
    } else {
      __label__ = 491;
      break;
    }
   case 480:
    var $2134 = HEAP32[$entry181 >> 2] + 12 | 0;
    var $2135 = __ZNK2js5PCVal8isFunObjEv($2134);
    if ($2135) {
      __label__ = 481;
      break;
    } else {
      __label__ = 482;
      break;
    }
   case 481:
    var $2137 = __ZNK2js5PCVal8toFunObjEv($2134);
    __ZN2JS5Value9setObjectER8JSObject($rval180, $2137);
    __label__ = 490;
    break;
   case 482:
    var $2139 = __ZNK2js5PCVal6isSlotEv($2134);
    if ($2139) {
      __label__ = 483;
      break;
    } else {
      __label__ = 484;
      break;
    }
   case 483:
    var $2141 = __ZNK2js5PCVal6toSlotEv($2134);
    var $2142 = HEAP32[$obj2182 >> 2];
    var $2143 = __ZNK8JSObject13nativeGetSlotEj($2142, $2141);
    var $2144 = $2143 | 0;
    var $st$4$0 = $2144 | 0;
    var $2145$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $2144 + 4 | 0;
    var $2145$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5204 | 0;
    HEAP32[$st$8$0 >> 2] = $2145$0;
    var $st$8$1 = $5204 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2145$1;
    __label__ = 490;
    break;
   case 484:
    var $2147 = __ZNK2js5PCVal7toShapeEv($2134);
    var $2148 = __ZNK2js5Shape16isDataDescriptorEv($2147);
    if ($2148) {
      __label__ = 485;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 485:
    var $2150 = __ZNK2js5Shape16hasDefaultGetterEv($2147);
    if ($2150) {
      __label__ = 486;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 486:
    var $2153 = HEAP32[$2147 + 24 >> 2];
    if (($2153 | 0) == -1) {
      __label__ = 488;
      break;
    } else {
      __label__ = 487;
      break;
    }
   case 487:
    var $2156 = HEAP32[$obj2182 >> 2];
    var $2157 = __ZNK8JSObject13nativeGetSlotEj($2156, $2153);
    var $2158 = $2157 | 0;
    var $st$3$0 = $2158 | 0;
    var $2159$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2158 + 4 | 0;
    var $2159$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5204 | 0;
    HEAP32[$st$7$0 >> 2] = $2159$0;
    var $st$7$1 = $5204 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2159$1;
    __label__ = 490;
    break;
   case 488:
    __ZN2JS5Value12setUndefinedEv($rval180);
    __label__ = 490;
    break;
   case 489:
    var $2162 = __ZNK2JS5Value8toObjectEv($objv);
    var $2164 = $2162;
    var $2165 = HEAP32[$obj2182 >> 2];
    var $2166 = $2147;
    var $2167 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5173, $2164, $2165, $2166, 2, $rval180);
    if (($2167 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 490;
      break;
    }
   case 490:
    var $st$1$0 = $5204 | 0;
    var $2170$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5204 + 4 | 0;
    var $2170$1 = HEAP32[$st$1$1 >> 2];
    var $2171 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $2171 | 0;
    HEAP32[$st$6$0 >> 2] = $2170$0;
    var $st$6$1 = $2171 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2170$1;
    var $2172 = HEAP32[$_pre_phi80 >> 2];
    var $2173 = $2172 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2173;
    var $2174 = $2172 | 0;
    var $st$14$0 = $2174 | 0;
    HEAP32[$st$14$0 >> 2] = $2108$0;
    var $st$14$1 = $2174 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $2108$1;
    __label__ = 496;
    break;
   case 491:
    var $2176 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2130);
    var $2177 = HEAP32[$_pre_phi80 >> 2];
    var $2178 = $2177 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2178;
    __ZN2JS5Value7setNullEv($2177);
    var $2179 = __ZNK2JS5Value8isObjectEv($lval178);
    var $2180 = __ZNK2JS5Value8toObjectEv($objv);
    if ($2179) {
      __label__ = 492;
      break;
    } else {
      __label__ = 494;
      break;
    }
   case 492:
    var $2182 = HEAP32[$aobj179 >> 2];
    var $2183 = __ZNK8JSObject6getOpsEv($2182);
    var $2187 = (HEAP32[$2183 + 36 >> 2] | 0) == 0 ? 3 : 2;
    var $2188 = $2180;
    var $2189 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($5173, $2188, $2176, $2187, $rval180);
    if (($2189 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 493:
    var $st$1$0 = $5203 | 0;
    var $2193$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5203 + 4 | 0;
    var $2193$1 = HEAP32[$st$1$1 >> 2];
    var $2194 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $2194 | 0;
    HEAP32[$st$6$0 >> 2] = $2193$0;
    var $st$6$1 = $2194 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2193$1;
    var $st$11$0 = $5204 | 0;
    var $2196$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $5204 + 4 | 0;
    var $2196$1 = HEAP32[$st$11$1 >> 2];
    var $2197 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $st$16$0 = $2197 | 0;
    HEAP32[$st$16$0 >> 2] = $2196$0;
    var $st$16$1 = $2197 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $2196$1;
    __label__ = 496;
    break;
   case 494:
    var $2199 = $2180;
    var $2200 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($5173, $2199, $2176, 3, $rval180);
    if (($2200 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 495;
      break;
    }
   case 495:
    var $2204 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $2204 | 0;
    HEAP32[$st$2$0 >> 2] = $2108$0;
    var $st$2$1 = $2204 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $2108$1;
    var $st$7$0 = $5204 | 0;
    var $2206$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $5204 + 4 | 0;
    var $2206$1 = HEAP32[$st$7$1 >> 2];
    var $2207 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $st$12$0 = $2207 | 0;
    HEAP32[$st$12$0 >> 2] = $2206$0;
    var $st$12$1 = $2207 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $2206$1;
    __label__ = 496;
    break;
   case 496:
    var $2209 = __ZNK2JS5Value11isPrimitiveEv($rval180);
    if ($2209) {
      __label__ = 497;
      break;
    } else {
      __label__ = 499;
      break;
    }
   case 497:
    var $2211 = HEAPU32[$_pre_phi80 >> 2];
    var $2212 = $2211 - 8 | 0;
    var $2213 = __ZNK2JS5Value8isObjectEv($2212);
    if ($2213) {
      __label__ = 498;
      break;
    } else {
      __label__ = 499;
      break;
    }
   case 498:
    var $2215 = HEAPU32[$_pre_phi >> 2];
    var $2225 = HEAPU32[$atoms_1 + (((HEAPU8[$2215 + 1 | 0] & 255) << 8 | HEAPU8[$2215 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom183 >> 2] = $2225;
    var $2226 = $2211 - 16 | 0;
    var $2227 = $2225 | 0;
    __ZN2JS5Value9setStringEP8JSString($2226, $2227);
    var $2229 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $2230 = __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $2229);
    if ($2230) {
      __label__ = 499;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 499:
    var $2232 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2232, $rval180);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 500:
    var $2235 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $2236 = __ZNK2JS5Value8toObjectEv($2235);
    var $2237 = $2236;
    var $2238 = __ZN8JSObject7unbrandEP9JSContext($2237, $5195);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 501:
    var $2240 = HEAP32[$_pre_phi80 >> 2];
    var $2241 = $2240 - 8 | 0;
    var $st$2$0 = $2241 | 0;
    var $2242$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2241 + 4 | 0;
    var $2242$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5171 | 0;
    HEAP32[$st$6$0 >> 2] = $2242$0;
    var $st$6$1 = $5171 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2242$1;
    var $2243 = $2240 - 16 | 0;
    var $2244 = __ZNK2JS5Value8isObjectEv($2243);
    if ($2244) {
      __label__ = 502;
      break;
    } else {
      __label__ = 503;
      break;
    }
   case 502:
    var $2246 = __ZNK2JS5Value8toObjectEv($2243);
    var $obj189_0 = $2246;
    __label__ = 505;
    break;
   case 503:
    var $2248 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $2243);
    var $2249 = $2248;
    if (($2248 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 504;
      break;
    }
   case 504:
    __ZN2JS5Value9setObjectER8JSObject($2243, $2249);
    var $obj189_0 = $2249;
    __label__ = 505;
    break;
   case 505:
    var $obj189_0;
    var $2254 = HEAP32[$32 >> 2] + 144336 | 0;
    var $2255 = HEAP32[$_pre_phi >> 2];
    var $2256 = __ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom($2254, $cx, $2255, $obj189_0, $entry190, $obj2191, $atom192);
    if ($2256) {
      __label__ = 507;
      break;
    } else {
      __label__ = 506;
      break;
    }
   case 506:
    var $2334 = HEAP32[$atom192 >> 2];
    var $2333 = HEAP32[$entry190 >> 2];
    __label__ = 526;
    break;
   case 507:
    var $2258 = HEAPU32[$entry190 >> 2];
    var $2259 = $2258 + 12 | 0;
    var $2260 = __ZNK2js5PCVal7toShapeEv($2259);
    var $2261 = __ZNK2js18PropertyCacheEntry6addingEv($2258);
    if ($2261) {
      __label__ = 516;
      break;
    } else {
      __label__ = 508;
      break;
    }
   case 508:
    var $2263 = __ZNK2js18PropertyCacheEntry7vcapTagEv($2258);
    if (($2263 | 0) == 0) {
      __label__ = 511;
      break;
    } else {
      __label__ = 509;
      break;
    }
   case 509:
    var $2266 = __ZNK8JSObject8getProtoEv($obj189_0);
    HEAP32[$obj2191 >> 2] = $2266;
    if (($2266 | 0) == 0) {
      __label__ = 525;
      break;
    } else {
      __label__ = 510;
      break;
    }
   case 510:
    var $2269 = __ZNK8JSObject5shapeEv($2266);
    var $2270 = __ZNK2js18PropertyCacheEntry6vshapeEv($2258);
    if (($2269 | 0) == ($2270 | 0)) {
      __label__ = 511;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 511:
    var $2273 = __ZNK2js5Shape16hasDefaultSetterEv($2260);
    if ($2273) {
      __label__ = 512;
      break;
    } else {
      __label__ = 515;
      break;
    }
   case 512:
    if ((HEAP32[$2260 + 24 >> 2] | 0) == -1) {
      __label__ = 515;
      break;
    } else {
      __label__ = 513;
      break;
    }
   case 513:
    var $2279 = __ZN8JSObject25brandedOrHasMethodBarrierEv($obj189_0);
    if ($2279) {
      __label__ = 515;
      break;
    } else {
      __label__ = 514;
      break;
    }
   case 514:
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($obj189_0, $cx, $2260, $rval187);
    __label__ = 533;
    break;
   case 515:
    var $2285 = (HEAP8[$script_1 + 36 | 0] & 8) << 24 >> 24 != 0;
    var $2287 = $2260;
    var $2288 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($5173, $obj189_0, $2287, 0, $2285, $rval187);
    if (($2288 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 516:
    var $2291 = __ZNK8JSObject11nativeEmptyEv($obj189_0);
    if ($2291) {
      __label__ = 517;
      break;
    } else {
      __label__ = 518;
      break;
    }
   case 517:
    var $2293 = __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($obj189_0, $cx);
    if ($2293) {
      __label__ = 518;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 518:
    var $2295 = __ZNK2js5Shape8previousEv($2260);
    var $2296 = __ZNK8JSObject12lastPropertyEv($obj189_0);
    if (($2295 | 0) == ($2296 | 0)) {
      __label__ = 519;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 519:
    var $2299 = __ZNK2js18PropertyCacheEntry6vshapeEv($2258);
    if (($2299 | 0) == (HEAP32[$5172 >> 2] | 0)) {
      __label__ = 520;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 520:
    var $2303 = __ZNK2js5Shape16hasDefaultSetterEv($2260);
    if ($2303) {
      __label__ = 521;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 521:
    var $2305 = __ZNK8JSObject8getClassEv($obj189_0);
    if ((HEAP32[$2305 + 8 >> 2] | 0) == 10) {
      __label__ = 522;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 522:
    var $2311 = HEAPU32[$2260 + 24 >> 2];
    HEAP32[$slot194 >> 2] = $2311;
    var $2312 = __ZNK8JSObject8numSlotsEv($obj189_0);
    if ($2311 >>> 0 < $2312 >>> 0) {
      __label__ = 524;
      break;
    } else {
      __label__ = 523;
      break;
    }
   case 523:
    var $2316 = __ZN8JSObject9allocSlotEP9JSContextPj($obj189_0, $5173, $slot194);
    if ($2316) {
      __label__ = 524;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 524:
    __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($obj189_0, $cx, $2260, 0);
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($obj189_0, $cx, $2260, $rval187);
    var $2319 = HEAP32[$2260 + 12 >> 2];
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($cx, $obj189_0, $2319);
    __label__ = 533;
    break;
   case 525:
    var $2321 = HEAPU32[$_pre_phi >> 2];
    var $2331 = HEAPU32[$atoms_1 + (((HEAPU8[$2321 + 1 | 0] & 255) << 8 | HEAPU8[$2321 + 2 | 0] & 255) << 2) >> 2];
    HEAP32[$atom192 >> 2] = $2331;
    var $2334 = $2331;
    var $2333 = $2258;
    __label__ = 526;
    break;
   case 526:
    var $2333;
    var $2334;
    var $2335 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2334);
    if (($2333 | 0) == 0) {
      __label__ = 532;
      break;
    } else {
      __label__ = 527;
      break;
    }
   case 527:
    var $2338 = __ZNK8JSObject6getOpsEv($obj189_0);
    if ((HEAP32[$2338 + 52 >> 2] | 0) == 0) {
      __label__ = 528;
      break;
    } else {
      __label__ = 532;
      break;
    }
   case 528:
    if (($op_0 | 0) == 111) {
      __label__ = 529;
      break;
    } else if (($op_0 | 0) == 226) {
      var $defineHow_0 = 5;
      __label__ = 531;
      break;
    } else {
      __label__ = 530;
      break;
    }
   case 529:
    var $defineHow_0 = 9;
    __label__ = 531;
    break;
   case 530:
    var $defineHow_0 = 1;
    __label__ = 531;
    break;
   case 531:
    var $defineHow_0;
    var $2350 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2352 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($5173, $obj189_0, $2335, $defineHow_0, $rval187, $2350);
    if (($2352 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 532:
    var $2359 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2360 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj189_0, $cx, $2335, $rval187, $2359);
    if (($2360 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 533;
      break;
    }
   case 533:
    var $2363 = HEAPU32[$_pre_phi >> 2];
    var $2367 = HEAPU32[$_pre_phi80 >> 2];
    if (HEAP8[$2363 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 534;
      break;
    } else {
      __label__ = 535;
      break;
    }
   case 534:
    HEAP32[$_pre_phi80 >> 2] = $2367 - 16 | 0;
    var $2370 = $2363 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $2370;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$2370] & 255;
    __label__ = 20;
    break;
   case 535:
    var $2374 = $2367 - 8 | 0;
    var $2375 = $2374 | 0;
    var $st$2$0 = $2375 | 0;
    var $2376$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2375 + 4 | 0;
    var $2376$1 = HEAP32[$st$2$1 >> 2];
    var $2377 = $2367 - 16 | 0;
    var $st$7$0 = $2377 | 0;
    HEAP32[$st$7$0 >> 2] = $2376$0;
    var $st$7$1 = $2377 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2376$1;
    HEAP32[$_pre_phi80 >> 2] = $2374;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 536:
    var $2379 = HEAPU32[$_pre_phi80 >> 2];
    var $2380 = $2379 - 16 | 0;
    var $2381 = $2379 - 8 | 0;
    var $2382 = __ZNK2JS5Value8isStringEv($2380);
    if ($2382) {
      __label__ = 537;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 537:
    var $2384 = __ZNK2JS5Value7isInt32Ev($2381);
    if ($2384) {
      __label__ = 538;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 538:
    var $2386 = __ZNK2JS5Value8toStringEv($2380);
    var $2387 = __ZNK2JS5Value7toInt32Ev($2381);
    var $2388 = __ZNK8JSString6lengthEv($2386);
    if ($2387 >>> 0 < $2388 >>> 0) {
      __label__ = 539;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 539:
    var $2392 = HEAP32[$32 >> 2] + 210584 | 0;
    var $2393 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($2392, $cx, $2386, $2387);
    if (($2393 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 540;
      break;
    }
   case 540:
    var $2396 = $2393 | 0;
    var $2397 = HEAP32[$_pre_phi80 >> 2];
    var $2398 = $2397 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2398;
    var $2399 = $2397 - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($2399, $2396);
    var $2400 = HEAP32[$_pre_phi >> 2];
    var $2402 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2400, $2402);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 541:
    var $2404 = __ZNK2JS5Value7isMagicE10JSWhyMagic($2380, undef);
    if ($2404) {
      __label__ = 542;
      break;
    } else {
      __label__ = 546;
      break;
    }
   case 542:
    var $2406 = __ZNK2JS5Value7isInt32Ev($2381);
    if ($2406) {
      __label__ = 543;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 543:
    var $2408 = __ZNK2JS5Value7toInt32Ev($2381);
    var $2409 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2410 = __ZNK2js10StackFrame13numActualArgsEv($2409);
    if ($2408 >>> 0 < $2410 >>> 0) {
      __label__ = 544;
      break;
    } else {
      __label__ = 545;
      break;
    }
   case 544:
    HEAP32[$_pre_phi80 >> 2] = $2381;
    var $2413 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2414 = __ZNK2JS5Value7toInt32Ev($2381);
    var $2415 = __ZNK2js10StackFrame18canonicalActualArgEj($2413, $2414);
    var $2416 = $2415 | 0;
    var $st$5$0 = $2416 | 0;
    var $2417$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $2416 + 4 | 0;
    var $2417$1 = HEAP32[$st$5$1 >> 2];
    var $2418 = $2379 - 16 | 0;
    var $st$10$0 = $2418 | 0;
    HEAP32[$st$10$0 >> 2] = $2417$0;
    var $st$10$1 = $2418 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $2417$1;
    var $2419 = HEAP32[$_pre_phi >> 2];
    var $2421 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2419, $2421);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 545:
    __ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript($cx, $script_1);
    __label__ = 546;
    break;
   case 546:
    var $2424 = __ZNK2JS5Value8isObjectEv($2380);
    if ($2424) {
      __label__ = 547;
      break;
    } else {
      __label__ = 548;
      break;
    }
   case 547:
    var $2426 = __ZNK2JS5Value8toObjectEv($2380);
    var $obj200_0 = $2426;
    __label__ = 550;
    break;
   case 548:
    var $2428 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $2380);
    var $2429 = $2428;
    if (($2428 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 549;
      break;
    }
   case 549:
    __ZN2JS5Value9setObjectER8JSObject($2380, $2429);
    var $obj200_0 = $2429;
    __label__ = 550;
    break;
   case 550:
    var $obj200_0;
    var $2433 = __ZNK2JS5Value7isInt32Ev($2381);
    if ($2433) {
      __label__ = 551;
      break;
    } else {
      __label__ = 561;
      break;
    }
   case 551:
    var $2435 = __ZNK2JS5Value7toInt32Ev($2381);
    var $2436 = __ZNK8JSObject12isDenseArrayEv($obj200_0);
    if ($2436) {
      __label__ = 552;
      break;
    } else {
      __label__ = 554;
      break;
    }
   case 552:
    var $2438 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj200_0);
    if ($2435 >>> 0 < $2438 >>> 0) {
      __label__ = 553;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 553:
    var $2441 = __ZN8JSObject20getDenseArrayElementEj($obj200_0, $2435);
    var $2442 = __ZNK2JS5Value7isMagicEv($2441);
    if ($2442) {
      __label__ = 559;
      break;
    } else {
      var $copyFrom_0 = $2441;
      __label__ = 571;
      break;
    }
   case 554:
    var $2444 = __ZNK8JSObject11isArgumentsEv($obj200_0);
    if ($2444) {
      __label__ = 555;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 555:
    var $2446 = __ZN8JSObject11asArgumentsEv($obj200_0);
    var $2447 = __ZNK2js15ArgumentsObject13initialLengthEv($2446);
    if ($2435 >>> 0 < $2447 >>> 0) {
      __label__ = 556;
      break;
    } else {
      __label__ = 559;
      break;
    }
   case 556:
    var $2450 = __ZNK2js15ArgumentsObject7elementEj($2446, $2435);
    var $2451 = __ZNK2JS5Value7isMagicE10JSWhyMagic($2450, undef);
    if ($2451) {
      __label__ = 559;
      break;
    } else {
      __label__ = 557;
      break;
    }
   case 557:
    var $2453 = __ZNK2js15ArgumentsObject15maybeStackFrameEv($2446);
    if (($2453 | 0) == 0) {
      var $copyFrom_0 = $2450;
      __label__ = 571;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2456 = __ZNK2js10StackFrame18canonicalActualArgEj($2453, $2435);
    var $copyFrom_0 = $2456;
    __label__ = 571;
    break;
   case 559:
    var $2458 = _INT_FITS_IN_JSID1825($2435);
    if (($2458 | 0) == 0) {
      __label__ = 564;
      break;
    } else {
      __label__ = 560;
      break;
    }
   case 560:
    var $2461 = _INT_TO_JSID1826($2435);
    HEAP32[$id202 >> 2] = $2461;
    var $2473 = $2461;
    __label__ = 566;
    break;
   case 561:
    var $2463 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2381, $i205);
    if ($2463) {
      __label__ = 562;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 562:
    var $2465 = HEAP32[$i205 >> 2];
    var $2466 = _INT_FITS_IN_JSID1825($2465);
    if (($2466 | 0) == 0) {
      __label__ = 564;
      break;
    } else {
      __label__ = 563;
      break;
    }
   case 563:
    var $2469 = _INT_TO_JSID1826($2465);
    HEAP32[$id202 >> 2] = $2469;
    var $2473 = $2469;
    __label__ = 566;
    break;
   case 564:
    var $2471 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi($cx, $obj200_0, $2381, $id202);
    if ($2471) {
      __label__ = 565;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 565:
    var $2473 = HEAP32[$id202 >> 2];
    __label__ = 566;
    break;
   case 566:
    var $2473;
    var $2474 = _JSID_IS_STRING1834($2473);
    if (($2474 | 0) == 0) {
      __label__ = 570;
      break;
    } else {
      __label__ = 567;
      break;
    }
   case 567:
    var $2477 = __ZN8JSScript11hasAnalysisEv($script_1);
    if ($2477) {
      __label__ = 568;
      break;
    } else {
      __label__ = 570;
      break;
    }
   case 568:
    var $2479 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2480 = __ZNK2js10StackFrame11hasImacropcEv($2479);
    if ($2480) {
      __label__ = 570;
      break;
    } else {
      __label__ = 569;
      break;
    }
   case 569:
    var $2482 = __ZN8JSScript8analysisEv($script_1);
    var $2483 = HEAP32[$_pre_phi >> 2];
    var $2484 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($2482, $2483);
    var $2486 = $2484 + 1 | 0;
    var $2488 = HEAP8[$2486] | 32;
    HEAP8[$2486] = $2488;
    __label__ = 570;
    break;
   case 570:
    var $2490 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj200_0, $cx, $2473, $rval201);
    if (($2490 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $copyFrom_0 = $rval201;
      __label__ = 571;
      break;
    }
   case 571:
    var $copyFrom_0;
    var $2492 = HEAP32[$_pre_phi80 >> 2];
    var $2493 = $2492 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2493;
    var $2494 = $copyFrom_0 | 0;
    var $st$5$0 = $2494 | 0;
    var $2495$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $2494 + 4 | 0;
    var $2495$1 = HEAP32[$st$5$1 >> 2];
    var $2496 = $2492 - 16 | 0;
    var $st$10$0 = $2496 | 0;
    HEAP32[$st$10$0 >> 2] = $2495$0;
    var $st$10$1 = $2496 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $2495$1;
    var $2497 = HEAP32[$_pre_phi >> 2];
    var $2499 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2497, $2499);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 572:
    var $2502 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $st$2$0 = $2502 | 0;
    var $2503$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2502 + 4 | 0;
    var $2503$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5206 | 0;
    HEAP32[$st$6$0 >> 2] = $2503$0;
    var $st$6$1 = $5206 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2503$1;
    var $2504 = __ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi($cx, $thisv206, -2);
    if (($2504 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 573;
      break;
    }
   case 573:
    var $2508 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $2509 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2508, $i_209);
    if ($2509) {
      __label__ = 574;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 574:
    var $2511 = HEAP32[$i_209 >> 2];
    var $2512 = _INT_FITS_IN_JSID1825($2511);
    if (($2512 | 0) == 0) {
      __label__ = 576;
      break;
    } else {
      __label__ = 575;
      break;
    }
   case 575:
    var $2515 = _INT_TO_JSID1826($2511);
    HEAP32[$id207 >> 2] = $2515;
    var $2521 = $2515;
    __label__ = 578;
    break;
   case 576:
    var $2518 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $2519 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $2504, $2508, $id207, $2518);
    if ($2519) {
      __label__ = 577;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 577:
    var $2521 = HEAP32[$id207 >> 2];
    __label__ = 578;
    break;
   case 578:
    var $2521;
    var $2523 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $2524 = $2504;
    var $2525 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($5173, $2524, $2521, 2, $2523);
    if (($2525 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 579;
      break;
    }
   case 579:
    var $2528 = HEAP32[$_pre_phi80 >> 2];
    var $2529 = $2528 - 16 | 0;
    var $2530 = __ZNK2JS5Value11isPrimitiveEv($2529);
    if ($2530) {
      __label__ = 580;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 580:
    var $2532 = __ZNK2JS5Value8isObjectEv($thisv206);
    if ($2532) {
      __label__ = 581;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 581:
    var $2534 = $2528 - 8 | 0;
    var $st$1$0 = $2534 | 0;
    var $2535$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $2534 + 4 | 0;
    var $2535$1 = HEAP32[$st$1$1 >> 2];
    var $2536 = $2528 - 16 | 0;
    var $st$6$0 = $2536 | 0;
    HEAP32[$st$6$0 >> 2] = $2535$0;
    var $st$6$1 = $2536 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2535$1;
    var $2538 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($2538, $2504);
    var $2540 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $2541 = __ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE($cx, $2540);
    if ($2541) {
      __label__ = 583;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 582:
    var $st$0$0 = $5206 | 0;
    var $2543$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5206 + 4 | 0;
    var $2543$1 = HEAP32[$st$0$1 >> 2];
    var $2544 = $2528 - 8 | 0;
    var $st$5$0 = $2544 | 0;
    HEAP32[$st$5$0 >> 2] = $2543$0;
    var $st$5$1 = $2544 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $2543$1;
    __label__ = 583;
    break;
   case 583:
    var $2546 = HEAP32[$_pre_phi >> 2];
    var $2548 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2546, $2548);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 584:
    var $2550 = HEAP32[$_pre_phi80 >> 2];
    var $2551 = $2550 - 24 | 0;
    var $2552 = __ZNK2JS5Value8isObjectEv($2551);
    if ($2552) {
      __label__ = 585;
      break;
    } else {
      __label__ = 586;
      break;
    }
   case 585:
    var $2554 = __ZNK2JS5Value8toObjectEv($2551);
    var $obj210_0 = $2554;
    var $2561 = $2550;
    __label__ = 588;
    break;
   case 586:
    var $2556 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $2551);
    var $2557 = $2556;
    if (($2556 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 587;
      break;
    }
   case 587:
    __ZN2JS5Value9setObjectER8JSObject($2551, $2557);
    var $obj210_0 = $2557;
    var $2561 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 588;
    break;
   case 588:
    var $2561;
    var $obj210_0;
    var $2562 = $2561 - 16 | 0;
    var $2563 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2562, $i_214);
    if ($2563) {
      __label__ = 589;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 589:
    var $2565 = HEAP32[$i_214 >> 2];
    var $2566 = _INT_FITS_IN_JSID1825($2565);
    if (($2566 | 0) == 0) {
      __label__ = 591;
      break;
    } else {
      __label__ = 590;
      break;
    }
   case 590:
    var $2569 = _INT_TO_JSID1826($2565);
    HEAP32[$id212 >> 2] = $2569;
    var $2575 = $2569;
    __label__ = 593;
    break;
   case 591:
    var $2572 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $2573 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj210_0, $2562, $id212, $2572);
    if ($2573) {
      __label__ = 592;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 592:
    var $2575 = HEAP32[$id212 >> 2];
    __label__ = 593;
    break;
   case 593:
    var $2575;
    __ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE($cx, undef, undef, $obj210_0, $2575, undef);
    var $2576 = __ZNK8JSObject12isDenseArrayEv($obj210_0);
    if ($2576) {
      __label__ = 594;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 594:
    var $2578 = _JSID_IS_INT1835($2575);
    if (($2578 | 0) == 0) {
      __label__ = 604;
      break;
    } else {
      __label__ = 595;
      break;
    }
   case 595:
    var $2581 = __ZN8JSObject30getDenseArrayInitializedLengthEv($obj210_0);
    var $2582 = _JSID_TO_INT1836($2575);
    if ($2582 >>> 0 < $2581 >>> 0) {
      __label__ = 596;
      break;
    } else {
      __label__ = 601;
      break;
    }
   case 596:
    var $2585 = __ZN8JSObject20getDenseArrayElementEj($obj210_0, $2582);
    var $2586 = __ZNK2JS5Value7isMagicE10JSWhyMagic($2585, undef);
    if ($2586) {
      __label__ = 597;
      break;
    } else {
      __label__ = 600;
      break;
    }
   case 597:
    var $2588 = __Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject(undef, $obj210_0);
    if (($2588 | 0) == 0) {
      __label__ = 598;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 598:
    var $2591 = __ZNK8JSObject14getArrayLengthEv($obj210_0);
    if ($2582 >>> 0 < $2591 >>> 0) {
      __label__ = 600;
      break;
    } else {
      __label__ = 599;
      break;
    }
   case 599:
    var $2594 = $2582 + 1 | 0;
    __ZN8JSObject14setArrayLengthEP9JSContextj($obj210_0, $cx, $2594);
    __label__ = 600;
    break;
   case 600:
    var $2597 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE($obj210_0, $cx, $2582, $2597);
    __label__ = 605;
    break;
   case 601:
    var $2599 = __ZN8JSScript11hasAnalysisEv($script_1);
    if ($2599) {
      __label__ = 602;
      break;
    } else {
      __label__ = 604;
      break;
    }
   case 602:
    var $2601 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2602 = __ZNK2js10StackFrame11hasImacropcEv($2601);
    if ($2602) {
      __label__ = 604;
      break;
    } else {
      __label__ = 603;
      break;
    }
   case 603:
    var $2604 = __ZN8JSScript8analysisEv($script_1);
    var $2605 = HEAP32[$_pre_phi >> 2];
    var $2606 = __ZN2js7analyze14ScriptAnalysis7getCodeEPKh($2604, $2605);
    var $2608 = $2606 + 1 | 0;
    var $2610 = HEAP8[$2608] | 16;
    HEAP8[$2608] = $2610;
    __label__ = 604;
    break;
   case 604:
    var $2613 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $2613 | 0;
    var $2614$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2613 + 4 | 0;
    var $2614$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5174 | 0;
    HEAP32[$st$6$0 >> 2] = $2614$0;
    var $st$6$1 = $5174 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2614$1;
    var $2619 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2620 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj210_0, $cx, $2575, $rval215, $2619);
    if (($2620 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 605;
      break;
    }
   case 605:
    var $2623 = HEAPU32[$_pre_phi >> 2];
    var $2627 = HEAPU32[$_pre_phi80 >> 2];
    if (HEAP8[$2623 + 1 | 0] << 24 >> 24 == 81) {
      __label__ = 606;
      break;
    } else {
      __label__ = 607;
      break;
    }
   case 606:
    HEAP32[$_pre_phi80 >> 2] = $2627 - 24 | 0;
    var $2630 = $2623 + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $2630;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$2630] & 255;
    __label__ = 20;
    break;
   case 607:
    var $2634 = $2627 - 16 | 0;
    var $2635 = $2627 - 8 | 0;
    var $st$2$0 = $2635 | 0;
    var $2636$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2635 + 4 | 0;
    var $2636$1 = HEAP32[$st$2$1 >> 2];
    var $2637 = $2627 - 24 | 0;
    var $st$7$0 = $2637 | 0;
    HEAP32[$st$7$0 >> 2] = $2636$0;
    var $st$7$1 = $2637 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2636$1;
    HEAP32[$_pre_phi80 >> 2] = $2634;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 608:
    var $2639 = HEAP32[$_pre_phi80 >> 2];
    var $2640 = $2639 - 16 | 0;
    var $2641 = __ZNK2JS5Value8isObjectEv($2640);
    if ($2641) {
      __label__ = 609;
      break;
    } else {
      __label__ = 610;
      break;
    }
   case 609:
    var $2643 = __ZNK2JS5Value8toObjectEv($2640);
    var $obj219_0 = $2643;
    var $2650 = $2639;
    __label__ = 612;
    break;
   case 610:
    var $2645 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $2640);
    var $2646 = $2645;
    if (($2645 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 611;
      break;
    }
   case 611:
    __ZN2JS5Value9setObjectER8JSObject($2640, $2646);
    var $obj219_0 = $2646;
    var $2650 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 612;
    break;
   case 612:
    var $2650;
    var $obj219_0;
    var $2651 = $2650 - 8 | 0;
    var $2652 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($2651, $i_223);
    if ($2652) {
      __label__ = 613;
      break;
    } else {
      __label__ = 615;
      break;
    }
   case 613:
    var $2654 = HEAP32[$i_223 >> 2];
    var $2655 = _INT_FITS_IN_JSID1825($2654);
    if (($2655 | 0) == 0) {
      __label__ = 615;
      break;
    } else {
      __label__ = 614;
      break;
    }
   case 614:
    var $2658 = _INT_TO_JSID1826($2654);
    HEAP32[$id221 >> 2] = $2658;
    var $2664 = $2658;
    __label__ = 617;
    break;
   case 615:
    var $2661 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $2662 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj219_0, $2651, $id221, $2661);
    if ($2662) {
      __label__ = 616;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 616:
    var $2664 = HEAP32[$id221 >> 2];
    __label__ = 617;
    break;
   case 617:
    var $2664;
    var $2666 = HEAP32[$_pre_phi80 >> 2] - 24 | 0;
    var $st$3$0 = $2666 | 0;
    var $2667$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2666 + 4 | 0;
    var $2667$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5207 | 0;
    HEAP32[$st$7$0 >> 2] = $2667$0;
    var $st$7$1 = $5207 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2667$1;
    var $2672 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2673 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($obj219_0, $cx, $2664, $rval224, $2672);
    if (($2673 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 618;
      break;
    }
   case 618:
    var $2677 = HEAP32[$_pre_phi80 >> 2] - 24 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2677;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 619:
    var $2679 = HEAPU32[$_pre_phi >> 2];
    var $2687 = (HEAPU8[$2679 + 1 | 0] & 255) << 8 | HEAPU8[$2679 + 2 | 0] & 255;
    var $2688 = HEAP32[$_pre_phi80 >> 2];
    __ZN2js14CallArgsFromSpEjPN2JS5ValueE($args, $2687, $2688);
    var $2689 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2690 = __ZNK2js10StackFrame10scopeChainEv($2689);
    var $2691 = __ZNK2js12CallReceiver7calleevEv($5208);
    var $2692 = $2690;
    var $2693 = __ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE($2692, $2691);
    if ($2693) {
      __label__ = 620;
      break;
    } else {
      __label__ = 621;
      break;
    }
   case 620:
    var $2695 = __ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE($5173, $args);
    if ($2695) {
      __label__ = 622;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 621:
    var $2697 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args, 0);
    if ($2697) {
      __label__ = 622;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 622:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 624;
      break;
    } else {
      __label__ = 623;
      break;
    }
   case 623:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 624;
    break;
   case 624:
    var $2705 = __ZNK2js12CallReceiver11spAfterCallEv($5208);
    HEAP32[$_pre_phi80 >> 2] = $2705;
    var $2706 = HEAP32[$_pre_phi >> 2];
    var $2707 = $2705 - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2706, $2707);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 625:
    var $2708 = HEAPU32[$_pre_phi >> 2];
    var $2716 = (HEAPU8[$2708 + 1 | 0] & 255) << 8 | HEAPU8[$2708 + 2 | 0] & 255;
    var $2717 = HEAP32[$_pre_phi80 >> 2];
    __ZN2js14CallArgsFromSpEjPN2JS5ValueE($args225, $2716, $2717);
    var $2720 = HEAP8[HEAP32[$_pre_phi >> 2]] << 24 >> 24 == 82;
    var $2721 = __ZNK2js12CallReceiver7calleevEv($5175);
    var $2722 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837($2721, $callee, $fun);
    if ($2722) {
      __label__ = 626;
      break;
    } else {
      __label__ = 627;
      break;
    }
   case 626:
    var $2724 = HEAPU32[$fun >> 2];
    var $2725 = __ZNK10JSFunction24isInterpretedConstructorEv($2724);
    if ($2725) {
      __label__ = 632;
      break;
    } else {
      __label__ = 627;
      break;
    }
   case 627:
    if ($2720) {
      __label__ = 628;
      break;
    } else {
      __label__ = 629;
      break;
    }
   case 628:
    var $2728 = __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $args225);
    if ($2728) {
      __label__ = 630;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 629:
    var $2730 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args225, 0);
    if ($2730) {
      __label__ = 630;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 630:
    var $2732 = __ZNK2js12CallReceiver11spAfterCallEv($5175);
    HEAP32[$_pre_phi80 >> 2] = $2732;
    var $2733 = HEAP32[$_pre_phi >> 2];
    var $2734 = $2732 - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2733, $2734);
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 631;
      break;
    }
   case 631:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 632:
    __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args225, $2720);
    var $2741 = $2720 ? 128 : 0;
    var $2742 = __ZNK10JSFunction6scriptEv($2724);
    var $2743 = HEAP32[$callee >> 2];
    var $2744 = __ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE($5176, $cx, $regs, $args225, $2743, $2724, $2742, $2741);
    if ($2744) {
      __label__ = 633;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 633:
    var $2746 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2747 = __ZNK2js10StackFrame6scriptEv($2746);
    var $2748 = __ZN8JSScript15stepModeEnabledEv($2747);
    if ($2748) {
      __label__ = 634;
      break;
    } else {
      __label__ = 635;
      break;
    }
   case 634:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 635;
    break;
   case 635:
    var $2751 = $2747 + 92 | 0;
    var $2752 = __ZN12JSPCCounters3getEi($2751, 0);
    if (($2752 | 0) == 0) {
      __label__ = 637;
      break;
    } else {
      __label__ = 636;
      break;
    }
   case 636:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 637;
    break;
   case 637:
    var $2756 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2757 = __ZNK2js10StackFrame15maybeFormalArgsEv($2756);
    var $2758 = __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $2756);
    var $2759 = __ZN2js10StackFrame16functionPrologueEP9JSContext($2756, $cx);
    if ($2759) {
      __label__ = 638;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $2747;
      var $pcCounts_2_ph1346 = $2752;
      var $argv_2_ph1345 = $2757;
      __label__ = 1016;
      break;
    }
   case 638:
    var $2761 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2761) {
      __label__ = 639;
      break;
    } else {
      var $2766 = 0;
      __label__ = 640;
      break;
    }
   case 639:
    var $2763 = HEAP32[$_pre_phi >> 2];
    var $2764 = __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $2747, $2763);
    var $2766 = $2764;
    __label__ = 640;
    break;
   case 640:
    var $2766;
    var $2767 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2768 = __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $2767, $2766);
    if ($2768) {
      __label__ = 641;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $2747;
      var $pcCounts_2_ph1346 = $2752;
      var $argv_2_ph1345 = $2757;
      __label__ = 1016;
      break;
    }
   case 641:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 643;
      break;
    } else {
      __label__ = 642;
      break;
    }
   case 642:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 643;
    break;
   case 643:
    var $_2 = $_2;
    var $script_1 = $2747;
    var $pcCounts_1 = $2752;
    var $argv_1 = $2757;
    var $atoms_1 = $2758;
    var $op_0 = HEAPU8[HEAP32[$_pre_phi >> 2]] & 255;
    __label__ = 20;
    break;
   case 644:
    _JS_ReportErrorNumber($cx, 2, 0, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 645:
    var $2781 = __ZNK2js9FrameRegs2fpEv($regs);
    var $2782 = __ZNK2js10StackFrame10scopeChainEv($2781);
    HEAP32[$obj226 >> 2] = $2782;
    var $2786 = (HEAP32[_js_CodeSpec + ($op_0 << 3) + 4 >> 2] & 33554432 | 0) != 0;
    if ($2786) {
      __label__ = 646;
      break;
    } else {
      __label__ = 647;
      break;
    }
   case 646:
    var $2788 = $2782;
    var $2789 = __ZNK8JSObject9getGlobalEv($2788);
    HEAP32[$obj226 >> 2] = $2789;
    __label__ = 647;
    break;
   case 647:
    var $2793 = HEAP32[$32 >> 2] + 144336 | 0;
    var $2794 = HEAP32[$_pre_phi >> 2];
    __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($2793, $cx, $2794, $obj226, $obj2231, $entry230, $atom232);
    var $2795 = HEAPU32[$atom232 >> 2];
    if (($2795 | 0) == 0) {
      __label__ = 648;
      break;
    } else {
      __label__ = 662;
      break;
    }
   case 648:
    var $2799 = HEAP32[$entry230 >> 2] + 12 | 0;
    var $2800 = __ZNK2js5PCVal8isFunObjEv($2799);
    if ($2800) {
      __label__ = 649;
      break;
    } else {
      __label__ = 650;
      break;
    }
   case 649:
    var $2802 = HEAP32[$_pre_phi80 >> 2];
    var $2803 = $2802 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2803;
    var $2804 = __ZNK2js5PCVal8toFunObjEv($2799);
    __ZN2JS5Value9setObjectER8JSObject($2802, $2804);
    __label__ = 659;
    break;
   case 650:
    var $2806 = __ZNK2js5PCVal6isSlotEv($2799);
    if ($2806) {
      __label__ = 651;
      break;
    } else {
      __label__ = 652;
      break;
    }
   case 651:
    var $2808 = __ZNK2js5PCVal6toSlotEv($2799);
    var $2809 = HEAP32[$_pre_phi80 >> 2];
    var $2810 = $2809 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2810;
    var $2811 = HEAP32[$obj2231 >> 2];
    var $2812 = __ZNK8JSObject13nativeGetSlotEj($2811, $2808);
    var $2813 = $2812 | 0;
    var $st$7$0 = $2813 | 0;
    var $2814$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $2813 + 4 | 0;
    var $2814$1 = HEAP32[$st$7$1 >> 2];
    var $2815 = $2809 | 0;
    var $st$12$0 = $2815 | 0;
    HEAP32[$st$12$0 >> 2] = $2814$0;
    var $st$12$1 = $2815 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $2814$1;
    __label__ = 659;
    break;
   case 652:
    var $2817 = __ZNK2js5PCVal7toShapeEv($2799);
    var $2818 = __ZNK2js5Shape16isDataDescriptorEv($2817);
    if ($2818) {
      __label__ = 653;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 653:
    var $2820 = __ZNK2js5Shape16hasDefaultGetterEv($2817);
    if ($2820) {
      __label__ = 654;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 654:
    var $2823 = HEAP32[$2817 + 24 >> 2];
    if (($2823 | 0) == -1) {
      __label__ = 656;
      break;
    } else {
      __label__ = 655;
      break;
    }
   case 655:
    var $2826 = HEAP32[$obj2231 >> 2];
    var $2827 = __ZNK8JSObject13nativeGetSlotEj($2826, $2823);
    var $2828 = $2827 | 0;
    var $st$3$0 = $2828 | 0;
    var $2829$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $2828 + 4 | 0;
    var $2829$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5210 | 0;
    HEAP32[$st$7$0 >> 2] = $2829$0;
    var $st$7$1 = $5210 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $2829$1;
    __label__ = 658;
    break;
   case 656:
    __ZN2JS5Value12setUndefinedEv($rval229);
    __label__ = 658;
    break;
   case 657:
    var $2834 = HEAP32[$obj226 >> 2];
    var $2835 = HEAP32[$obj2231 >> 2];
    var $2836 = $2817;
    var $2837 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5173, $2834, $2835, $2836, 0, $rval229);
    if (($2837 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 658;
      break;
    }
   case 658:
    var $2839 = HEAP32[$_pre_phi80 >> 2];
    var $2840 = $2839 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2840;
    var $st$3$0 = $5210 | 0;
    var $2841$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5210 + 4 | 0;
    var $2841$1 = HEAP32[$st$3$1 >> 2];
    var $2842 = $2839 | 0;
    var $st$8$0 = $2842 | 0;
    HEAP32[$st$8$0 >> 2] = $2841$0;
    var $st$8$1 = $2842 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2841$1;
    __label__ = 659;
    break;
   case 659:
    var $2844 = HEAP32[$_pre_phi >> 2];
    var $2846 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2844, $2846);
    if (($op_0 | 0) == 214 || ($op_0 | 0) == 57) {
      __label__ = 660;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 660:
    var $2847 = HEAP32[$obj226 >> 2];
    var $2849 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $2850 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $2847, $2849, $v);
    if ($2850) {
      __label__ = 661;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 661:
    var $2852 = HEAP32[$_pre_phi80 >> 2];
    var $2853 = $2852 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2853;
    var $st$3$0 = $5209 | 0;
    var $2854$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5209 + 4 | 0;
    var $2854$1 = HEAP32[$st$3$1 >> 2];
    var $2855 = $2852 | 0;
    var $st$8$0 = $2855 | 0;
    HEAP32[$st$8$0 >> 2] = $2854$0;
    var $st$8$1 = $2855 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2854$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 662:
    var $2857 = __ZL12ATOM_TO_JSIDP6JSAtom1798($2795);
    var $2858 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($5173, $2857, 1, $2786, $5211, $5212, $5213);
    if (($2858 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 663;
      break;
    }
   case 663:
    var $2861 = HEAP32[$prop235 >> 2];
    if (($2861 | 0) == 0) {
      __label__ = 664;
      break;
    } else {
      __label__ = 666;
      break;
    }
   case 664:
    var $2865 = HEAP32[$_pre_phi >> 2] + 3 | 0;
    var $2866 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $2865);
    if (($2866 | 0) == 39) {
      __label__ = 665;
      break;
    } else {
      var $atomNotDefined_0 = $2795;
      __label__ = 1048;
      break;
    }
   case 665:
    var $2869 = HEAP32[$_pre_phi80 >> 2];
    var $2870 = $2869 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2870;
    __ZN2JS5Value12setUndefinedEv($2869);
    var $2871 = HEAP32[$_pre_phi >> 2];
    var $2873 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2871, $2873);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 666:
    var $2875 = HEAP32[$obj226 >> 2];
    var $2876 = __ZNK8JSObject8isNativeEv($2875);
    if ($2876) {
      __label__ = 667;
      break;
    } else {
      __label__ = 668;
      break;
    }
   case 667:
    var $2878 = HEAP32[$obj2231 >> 2];
    var $2879 = __ZNK8JSObject8isNativeEv($2878);
    if ($2879) {
      __label__ = 669;
      break;
    } else {
      __label__ = 668;
      break;
    }
   case 668:
    var $2881 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2875, $cx, $2857, $rval229);
    if (($2881 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 678;
      break;
    }
   case 669:
    var $2884 = $2861;
    var $2885 = __ZNK8JSObject8getClassEv($2875);
    if (($2885 | 0) == (__ZN2js9WithClassE | 0)) {
      __label__ = 670;
      break;
    } else {
      var $normalized_0 = $2875;
      __label__ = 672;
      break;
    }
   case 670:
    var $2888 = __ZNK2js5Shape16hasDefaultGetterEv($2884);
    if ($2888) {
      var $normalized_0 = $2875;
      __label__ = 672;
      break;
    } else {
      __label__ = 671;
      break;
    }
   case 671:
    var $2890 = __Z19js_UnwrapWithObjectP9JSContextP8JSObject(undef, $2875);
    var $normalized_0 = $2890;
    __label__ = 672;
    break;
   case 672:
    var $normalized_0;
    var $2892 = __ZNK2js5Shape16isDataDescriptorEv($2884);
    if ($2892) {
      __label__ = 673;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 673:
    var $2894 = __ZNK2js5Shape16hasDefaultGetterEv($2884);
    if ($2894) {
      __label__ = 674;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 674:
    var $2897 = HEAP32[$2884 + 24 >> 2];
    if (($2897 | 0) == -1) {
      __label__ = 676;
      break;
    } else {
      __label__ = 675;
      break;
    }
   case 675:
    var $2900 = __ZNK8JSObject13nativeGetSlotEj($2878, $2897);
    var $2901 = $2900 | 0;
    var $st$2$0 = $2901 | 0;
    var $2902$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $2901 + 4 | 0;
    var $2902$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5210 | 0;
    HEAP32[$st$6$0 >> 2] = $2902$0;
    var $st$6$1 = $5210 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $2902$1;
    __label__ = 678;
    break;
   case 676:
    __ZN2JS5Value12setUndefinedEv($rval229);
    __label__ = 678;
    break;
   case 677:
    var $2906 = $2878;
    var $2907 = $2861;
    var $2908 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($5173, $normalized_0, $2906, $2907, 0, $rval229);
    if (($2908 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 678;
      break;
    }
   case 678:
    var $2910 = HEAP32[$_pre_phi80 >> 2];
    var $2911 = $2910 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2911;
    var $st$3$0 = $5210 | 0;
    var $2912$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5210 + 4 | 0;
    var $2912$1 = HEAP32[$st$3$1 >> 2];
    var $2913 = $2910 | 0;
    var $st$8$0 = $2913 | 0;
    HEAP32[$st$8$0 >> 2] = $2912$0;
    var $st$8$1 = $2913 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2912$1;
    var $2914 = HEAP32[$_pre_phi >> 2];
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $2914, $rval229);
    if (($op_0 | 0) == 214 || ($op_0 | 0) == 57) {
      __label__ = 679;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 679:
    var $2916 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $2875, $rval229, $v236);
    if ($2916) {
      __label__ = 680;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 680:
    var $2918 = HEAP32[$_pre_phi80 >> 2];
    var $2919 = $2918 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $2919;
    var $st$3$0 = $5214 | 0;
    var $2920$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5214 + 4 | 0;
    var $2920$1 = HEAP32[$st$3$1 >> 2];
    var $2921 = $2918 | 0;
    var $st$8$0 = $2921 | 0;
    HEAP32[$st$8$0 >> 2] = $2920$0;
    var $st$8$1 = $2921 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2920$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 681:
    var $2923 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $2923 + 8 | 0;
    var $2925 = HEAPU32[$_pre_phi >> 2];
    var $2933 = (HEAPU8[$2925 + 1 | 0] & 255) << 8 | HEAPU8[$2925 + 2 | 0] & 255;
    __ZN2JS5Value8setInt32Ei($2923, $2933);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 682:
    var $2935 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $2935 + 8 | 0;
    var $2937 = HEAPU32[$_pre_phi >> 2];
    var $2950 = HEAPU8[$2937 + 3 | 0] & 255 | (HEAPU8[$2937 + 1 | 0] & 255) << 16 | (HEAPU8[$2937 + 2 | 0] & 255) << 8;
    __ZN2JS5Value8setInt32Ei($2935, $2950);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 4;
    __label__ = 19;
    break;
   case 683:
    var $2952 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $2952 + 8 | 0;
    var $2957 = HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0] << 24 >> 24;
    __ZN2JS5Value8setInt32Ei($2952, $2957);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 2;
    __label__ = 19;
    break;
   case 684:
    var $2959 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $2959 + 8 | 0;
    var $2961 = HEAPU32[$_pre_phi >> 2];
    var $2979 = (HEAPU8[$2961 + 2 | 0] & 255) << 16 | (HEAPU8[$2961 + 1 | 0] & 255) << 24 | HEAPU8[$2961 + 4 | 0] & 255 | (HEAPU8[$2961 + 3 | 0] & 255) << 8;
    __ZN2JS5Value8setInt32Ei($2959, $2979);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 685:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1 + ((HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0] & 255) << 16 << 2) | 0;
    var $len_0 = 2;
    __label__ = 19;
    break;
   case 686:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1 + (($op_0 << 16) - 13762560 << 2) | 0;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 687:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = HEAP32[$script_1 + 56 >> 2];
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 688:
    var $3001 = HEAPU32[$_pre_phi >> 2];
    var $3010 = ((HEAPU8[$3001 + 1 | 0] & 255) << 8 | HEAPU8[$3001 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3011 = __ZN8JSScript8getConstEj($script_1, $3010);
    var $3012 = __ZNK2JS5Value8toDoubleEv($3011);
    var $3013 = HEAP32[$_pre_phi80 >> 2];
    var $3014 = $3013 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3014;
    __ZN2JS5Value9setDoubleEd($3013, $3012);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 689:
    var $3016 = HEAPU32[$_pre_phi >> 2];
    var $3026 = HEAP32[$atoms_1 + (((HEAPU8[$3016 + 1 | 0] & 255) << 8 | HEAPU8[$3016 + 2 | 0] & 255) << 2) >> 2];
    var $3027 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3027 + 8 | 0;
    var $3029 = $3026 | 0;
    __ZN2JS5Value9setStringEP8JSString($3027, $3029);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 690:
    var $3037 = HEAPU32[$_pre_phi >> 2];
    var $3046 = ((HEAPU8[$3037 + 1 | 0] & 255) << 8 | HEAPU8[$3037 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3047 = __ZN8JSScript9getObjectEj($script_1, $3046);
    var $3048 = HEAP32[$_pre_phi80 >> 2];
    var $3049 = $3048 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3049;
    __ZN2JS5Value9setObjectER8JSObject($3048, $3047);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 691:
    var $3052 = HEAP32[$script_1 + 56 >> 2];
    var $3053 = HEAP32[$_pre_phi >> 2];
    var $3055 = HEAPU8[$3053 + 1 | 0];
    var $3057 = HEAPU8[$3053 + 2 | 0];
    var $3058 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3059 = __ZNK2js10StackFrame10scopeChainEv($3058);
    var $3060 = $3059;
    var $3061 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($5173, $3060, 10, $5215, 0);
    if (($3061 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 692;
      break;
    }
   case 692:
    var $3072 = (($3055 & 255) << 8 | $3057 & 255) + ($atoms_1 - $3052 >> 2) | 0;
    var $3073 = __ZN8JSScript9getRegExpEj($script_1, $3072);
    var $3075 = $3073;
    var $3076 = HEAP32[$proto >> 2];
    var $3077 = __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($5177, $3075, $3076);
    if (($3077 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 693;
      break;
    }
   case 693:
    var $3080 = $3077;
    var $3081 = HEAP32[$_pre_phi80 >> 2];
    var $3082 = $3081 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3082;
    __ZN2JS5Value9setObjectER8JSObject($3081, $3080);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 694:
    var $3084 = HEAP32[$_pre_phi80 >> 2];
    var $3085 = $3084 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3085;
    __ZN2JS5Value8setInt32Ei($3084, 0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 695:
    var $3087 = HEAP32[$_pre_phi80 >> 2];
    var $3088 = $3087 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3088;
    __ZN2JS5Value8setInt32Ei($3087, 1);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 696:
    var $3090 = HEAP32[$_pre_phi80 >> 2];
    var $3091 = $3090 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3091;
    __ZN2JS5Value7setNullEv($3090);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 697:
    var $3093 = HEAP32[$_pre_phi80 >> 2];
    var $3094 = $3093 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3094;
    __ZN2JS5Value10setBooleanEb($3093, 0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 698:
    var $3096 = HEAP32[$_pre_phi80 >> 2];
    var $3097 = $3096 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3097;
    __ZN2JS5Value10setBooleanEb($3096, 1);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 699:
    var $3099 = HEAPU32[$_pre_phi >> 2];
    var $3108 = ((HEAPU8[$3099 + 1 | 0] & 255) << 8 | HEAPU8[$3099 + 2 | 0] & 255) << 16 >> 16;
    var $3110 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3110;
    var $3111 = __ZNK2JS5Value7isInt32Ev($3110);
    if ($3111) {
      __label__ = 700;
      break;
    } else {
      __label__ = 701;
      break;
    }
   case 700:
    var $3113 = __ZNK2JS5Value7toInt32Ev($3110);
    var $i241_0 = $3113;
    __label__ = 703;
    break;
   case 701:
    var $3115 = __ZNK2JS5Value8isDoubleEv($3110);
    if ($3115) {
      __label__ = 702;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3108;
      __label__ = 19;
      break;
    }
   case 702:
    var $3117 = __ZNK2JS5Value8toDoubleEv($3110);
    var $3118 = $3117 & -1;
    if ($3117 != ($3118 | 0)) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3108;
      __label__ = 19;
      break;
    } else {
      var $i241_0 = $3118;
      __label__ = 703;
      break;
    }
   case 703:
    var $i241_0;
    var $3130 = ((HEAPU8[$3099 + 3 | 0] & 255) << 8 | HEAPU8[$3099 + 4 | 0] & 255) << 16 >> 16;
    var $3140 = $i241_0 - $3130 | 0;
    if ($3140 >>> 0 < (1 - $3130 + (((HEAPU8[$3099 + 5 | 0] & 255) << 8 | HEAPU8[$3099 + 6 | 0] & 255) << 16 >> 16) | 0) >>> 0) {
      __label__ = 704;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3108;
      __label__ = 19;
      break;
    }
   case 704:
    var $3145 = $3140 << 1;
    var $3153 = (HEAPU8[$3145 + ($3099 + 7) | 0] & 255) << 8 | HEAPU8[$3145 + ($3099 + 8) | 0] & 255;
    if ($3153 << 16 >> 16 == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3108;
      __label__ = 19;
      break;
    } else {
      __label__ = 705;
      break;
    }
   case 705:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $3153 << 16 >> 16;
    __label__ = 19;
    break;
   case 706:
    var $3158 = HEAPU32[$_pre_phi >> 2];
    var $3176 = (HEAPU8[$3158 + 2 | 0] & 255) << 16 | (HEAPU8[$3158 + 1 | 0] & 255) << 24 | HEAPU8[$3158 + 4 | 0] & 255 | (HEAPU8[$3158 + 3 | 0] & 255) << 8;
    var $3178 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3178;
    var $3179 = __ZNK2JS5Value7isInt32Ev($3178);
    if ($3179) {
      __label__ = 707;
      break;
    } else {
      __label__ = 708;
      break;
    }
   case 707:
    var $3181 = __ZNK2JS5Value7toInt32Ev($3178);
    var $i245_0 = $3181;
    __label__ = 710;
    break;
   case 708:
    var $3183 = __ZNK2JS5Value8isDoubleEv($3178);
    if ($3183) {
      __label__ = 709;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3176;
      __label__ = 19;
      break;
    }
   case 709:
    var $3185 = __ZNK2JS5Value8toDoubleEv($3178);
    if ($3185 == 0) {
      var $i245_0 = 0;
      __label__ = 710;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3176;
      __label__ = 19;
      break;
    }
   case 710:
    var $i245_0;
    var $3196 = ((HEAPU8[$3158 + 5 | 0] & 255) << 8 | HEAPU8[$3158 + 6 | 0] & 255) << 16 >> 16;
    var $3206 = $i245_0 - $3196 | 0;
    if ($3206 >>> 0 < (1 - $3196 + (((HEAPU8[$3158 + 7 | 0] & 255) << 8 | HEAPU8[$3158 + 8 | 0] & 255) << 16 >> 16) | 0) >>> 0) {
      __label__ = 711;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3176;
      __label__ = 19;
      break;
    }
   case 711:
    var $3212 = $3206 << 2 | 2;
    var $3230 = (HEAPU8[$3212 + ($3158 + 8) | 0] & 255) << 16 | (HEAPU8[$3212 + ($3158 + 7) | 0] & 255) << 24 | HEAPU8[$3212 + ($3158 + 10) | 0] & 255 | (HEAPU8[$3212 + ($3158 + 9) | 0] & 255) << 8;
    if (($3230 | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = $3176;
      __label__ = 19;
      break;
    } else {
      __label__ = 712;
      break;
    }
   case 712:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $3230;
    __label__ = 19;
    break;
   case 713:
    var $off249_0 = 2;
    __label__ = 714;
    break;
   case 714:
    var $off249_0;
    var $3233 = HEAPU32[$_pre_phi >> 2];
    var $3234 = HEAPU32[$_pre_phi80 >> 2];
    var $3235 = $3234 - 8 | 0;
    var $st$4$0 = $3235 | 0;
    var $3236$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $3235 + 4 | 0;
    var $3236$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5216 | 0;
    HEAP32[$st$8$0 >> 2] = $3236$0;
    var $st$8$1 = $5216 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3236$1;
    HEAP32[$_pre_phi80 >> 2] = $3234 - 8 | 0;
    var $3238 = __ZNK2JS5Value11isPrimitiveEv($lval251);
    if ($3238) {
      __label__ = 715;
      break;
    } else {
      var $pc2250_3 = $3233;
      __label__ = 729;
      break;
    }
   case 715:
    var $_sum39 = $off249_0 + 2 | 0;
    var $3244 = $3233 + $_sum39 | 0;
    var $3247 = (HEAPU8[$3233 + ($off249_0 | 1) | 0] & 255) << 8 | HEAPU8[$3244] & 255;
    var $3248 = __ZNK2JS5Value8isStringEv($lval251);
    if ($3248) {
      __label__ = 716;
      break;
    } else {
      __label__ = 722;
      break;
    }
   case 716:
    var $3250 = __ZNK2JS5Value8toStringEv($lval251);
    var $3251 = __ZN8JSString12ensureLinearEP9JSContext($3250, $cx);
    if (($3251 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $npairs_0 = $3247;
      var $pc2250_0 = $3244;
      __label__ = 717;
      break;
    }
   case 717:
    var $pc2250_0;
    var $npairs_0;
    var $3257 = $pc2250_0 + 2 | 0;
    var $3260 = (HEAPU8[$pc2250_0 + 1 | 0] & 255) << 8 | HEAPU8[$3257] & 255;
    var $3261 = __ZN8JSScript8getConstEj($script_1, $3260);
    var $3262 = $3261 | 0;
    var $st$12$0 = $3262 | 0;
    var $3263$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $3262 + 4 | 0;
    var $3263$1 = HEAP32[$st$12$1 >> 2];
    var $st$16$0 = $5217 | 0;
    HEAP32[$st$16$0 >> 2] = $3263$0;
    var $st$16$1 = $5217 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $3263$1;
    var $3264 = __ZNK2JS5Value8isStringEv($rval253);
    if ($3264) {
      __label__ = 718;
      break;
    } else {
      __label__ = 720;
      break;
    }
   case 718:
    var $3266 = __ZNK2JS5Value8toStringEv($rval253);
    var $3267 = __ZN8JSString8asLinearEv($3266);
    if (($3267 | 0) == ($3251 | 0)) {
      var $pc2250_3 = $3257;
      __label__ = 729;
      break;
    } else {
      __label__ = 719;
      break;
    }
   case 719:
    var $3270 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3267, $3251);
    if ($3270) {
      var $pc2250_3 = $3257;
      __label__ = 729;
      break;
    } else {
      __label__ = 720;
      break;
    }
   case 720:
    var $3272 = $npairs_0 - 1 | 0;
    if (($3272 | 0) == 0) {
      __label__ = 721;
      break;
    } else {
      var $npairs_0 = $3272;
      var $pc2250_0 = $pc2250_0 + $_sum39 | 0;
      __label__ = 717;
      break;
    }
   case 721:
    var $pc2250_3 = HEAP32[$_pre_phi >> 2];
    __label__ = 729;
    break;
   case 722:
    var $3277 = __ZNK2JS5Value8isNumberEv($lval251);
    if ($3277) {
      __label__ = 723;
      break;
    } else {
      var $npairs_2 = $3247;
      var $pc2250_2 = $3244;
      __label__ = 727;
      break;
    }
   case 723:
    var $3279 = __ZNK2JS5Value8toNumberEv($lval251);
    var $npairs_1 = $3247;
    var $pc2250_1 = $3244;
    __label__ = 724;
    break;
   case 724:
    var $pc2250_1;
    var $npairs_1;
    var $3285 = $pc2250_1 + 2 | 0;
    var $3288 = (HEAPU8[$pc2250_1 + 1 | 0] & 255) << 8 | HEAPU8[$3285] & 255;
    var $3289 = __ZN8JSScript8getConstEj($script_1, $3288);
    var $3290 = $3289 | 0;
    var $st$12$0 = $3290 | 0;
    var $3291$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $3290 + 4 | 0;
    var $3291$1 = HEAP32[$st$12$1 >> 2];
    var $st$16$0 = $5218 | 0;
    HEAP32[$st$16$0 >> 2] = $3291$0;
    var $st$16$1 = $5218 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $3291$1;
    var $3292 = __ZNK2JS5Value8isNumberEv($rval254);
    if ($3292) {
      __label__ = 725;
      break;
    } else {
      __label__ = 726;
      break;
    }
   case 725:
    var $3294 = __ZNK2JS5Value8toNumberEv($rval254);
    if ($3279 == $3294) {
      var $pc2250_3 = $3285;
      __label__ = 729;
      break;
    } else {
      __label__ = 726;
      break;
    }
   case 726:
    var $3297 = $npairs_1 - 1 | 0;
    if (($3297 | 0) == 0) {
      var $pc2250_3 = $3233;
      __label__ = 729;
      break;
    } else {
      var $npairs_1 = $3297;
      var $pc2250_1 = $pc2250_1 + $_sum39 | 0;
      __label__ = 724;
      break;
    }
   case 727:
    var $pc2250_2;
    var $npairs_2;
    var $3303 = $pc2250_2 + 2 | 0;
    var $3306 = (HEAPU8[$pc2250_2 + 1 | 0] & 255) << 8 | HEAPU8[$3303] & 255;
    var $3307 = __ZN8JSScript8getConstEj($script_1, $3306);
    var $3308 = $3307 | 0;
    var $st$12$0 = $3308 | 0;
    var $3309$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $3308 + 4 | 0;
    var $3309$1 = HEAP32[$st$12$1 >> 2];
    var $st$16$0 = $5219 | 0;
    HEAP32[$st$16$0 >> 2] = $3309$0;
    var $st$16$1 = $5219 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $3309$1;
    var $3310 = __ZNK2JS5ValueeqERKS0_($lval251, $rval255);
    if ($3310) {
      var $pc2250_3 = $3303;
      __label__ = 729;
      break;
    } else {
      __label__ = 728;
      break;
    }
   case 728:
    var $3313 = $npairs_2 - 1 | 0;
    if (($3313 | 0) == 0) {
      var $pc2250_3 = $3233;
      __label__ = 729;
      break;
    } else {
      var $npairs_2 = $3313;
      var $pc2250_2 = $pc2250_2 + $_sum39 | 0;
      __label__ = 727;
      break;
    }
   case 729:
    var $pc2250_3;
    var $3318 = HEAPU8[$pc2250_3 + 1 | 0] & 255;
    if (($op_0 | 0) == 71) {
      __label__ = 730;
      break;
    } else {
      __label__ = 731;
      break;
    }
   case 730:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = (HEAPU8[$pc2250_3 + 2 | 0] & 255 | $3318 << 8) << 16 >> 16;
    __label__ = 19;
    break;
   case 731:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = (HEAPU8[$pc2250_3 + 2 | 0] & 255) << 16 | $3318 << 24 | HEAPU8[$pc2250_3 + 4 | 0] & 255 | (HEAPU8[$pc2250_3 + 3 | 0] & 255) << 8;
    __label__ = 19;
    break;
   case 732:
    if (($_2 | 0) == 5) {
      __label__ = 733;
      break;
    } else {
      __label__ = 734;
      break;
    }
   case 733:
    var $3345 = HEAP32[$_pre_phi >> 2];
    var $3347 = _JS_GetTrapOpcode(undef, $script_1, $3345);
    var $_2 = 0;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = $3347;
    __label__ = 20;
    break;
   case 734:
    var $3349 = __ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE($cx, $rval256);
    if (($3349 | 0) == 2) {
      __label__ = 735;
      break;
    } else if (($3349 | 0) == 3) {
      __label__ = 736;
      break;
    } else if (($3349 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 737;
      break;
    }
   case 735:
    var $3351 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3352 = $3351;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($3352, $rval256);
    var $_5 = $_2;
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 736:
    var $3354 = $rval256 | 0;
    var $st$1$0 = $3354 | 0;
    var $3355$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $3354 + 4 | 0;
    var $3355$1 = HEAP32[$st$1$1 >> 2];
    var $3356 = $9 | 0;
    var $st$6$0 = $3356 | 0;
    HEAP32[$st$6$0 >> 2] = $3355$0;
    var $st$6$1 = $3356 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $3355$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $9);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 737:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 739;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 738:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 739;
    break;
   case 739:
    var $3364 = __ZNK2JS5Value7toInt32Ev($rval256);
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = $3364;
    __label__ = 20;
    break;
   case 740:
    var $3366 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($3366) {
      __label__ = 741;
      break;
    } else {
      __label__ = 746;
      break;
    }
   case 741:
    if ((HEAP8[$script_1 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 742;
      break;
    } else {
      __label__ = 746;
      break;
    }
   case 742:
    var $3373 = __ZN8JSScript18ensureRanInferenceEP9JSContext($script_1, $cx);
    if ($3373) {
      __label__ = 743;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 743:
    if ((HEAP8[$script_1 + 38 | 0] & 2) << 24 >> 24 == 0) {
      __label__ = 745;
      break;
    } else {
      __label__ = 744;
      break;
    }
   case 744:
    var $3380 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3381 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $3380, $rval258);
    if (($3381 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 747;
      break;
    }
   case 745:
    __ZN2JSL10MagicValueE10JSWhyMagic1838($10);
    var $st$1$0 = $5220 | 0;
    var $3384$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5220 + 4 | 0;
    var $3384$1 = HEAP32[$st$1$1 >> 2];
    var $st$5$0 = $5221 | 0;
    HEAP32[$st$5$0 >> 2] = $3384$0;
    var $st$5$1 = $5221 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $3384$1;
    __label__ = 747;
    break;
   case 746:
    var $3386 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3387 = __Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE($cx, $3386, $rval258);
    if (($3387 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 747;
      break;
    }
   case 747:
    var $3389 = HEAP32[$_pre_phi80 >> 2];
    var $3390 = $3389 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3390;
    var $st$3$0 = $5221 | 0;
    var $3391$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5221 + 4 | 0;
    var $3391$1 = HEAP32[$st$3$1 >> 2];
    var $3392 = $3389 | 0;
    var $st$8$0 = $3392 | 0;
    HEAP32[$st$8$0 >> 2] = $3391$0;
    var $st$8$1 = $3392 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3391$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 748:
    var $3394 = HEAPU32[$_pre_phi >> 2];
    var $3402 = (HEAPU8[$3394 + 1 | 0] & 255) << 8 | HEAPU8[$3394 + 2 | 0] & 255;
    var $3403 = _INT_TO_JSID1826($3402);
    var $3404 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3405 = __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $3404, $3403, $rval260);
    if (($3405 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 749;
      break;
    }
   case 749:
    var $3408 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3408 + 8 | 0;
    var $st$3$0 = $5222 | 0;
    var $3410$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5222 + 4 | 0;
    var $3410$1 = HEAP32[$st$3$1 >> 2];
    var $3411 = $3408 | 0;
    var $st$8$0 = $3411 | 0;
    HEAP32[$st$8$0 >> 2] = $3410$0;
    var $st$8$1 = $3411 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3410$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 750:
    var $3414 = HEAP32[$5223 >> 2] | 0;
    var $3415 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3414);
    var $3416 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3417 = __Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE($cx, $3416, $3415, $rval262);
    if (($3417 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 751;
      break;
    }
   case 751:
    var $3420 = HEAP32[$_pre_phi80 >> 2];
    var $3421 = $3420 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3421;
    var $st$3$0 = $5224 | 0;
    var $3422$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5224 + 4 | 0;
    var $3422$1 = HEAP32[$st$3$1 >> 2];
    var $3423 = $3420 | 0;
    var $st$8$0 = $3423 | 0;
    HEAP32[$st$8$0 >> 2] = $3422$0;
    var $st$8$1 = $3423 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $3422$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 752:
    var $3424 = HEAPU32[$_pre_phi >> 2];
    var $3432 = (HEAPU8[$3424 + 1 | 0] & 255) << 8 | HEAPU8[$3424 + 2 | 0] & 255;
    var $3433 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3433 + 8 | 0;
    var $3435 = $argv_1 + ($3432 << 3) | 0;
    var $st$13$0 = $3435 | 0;
    var $3436$0 = HEAP32[$st$13$0 >> 2];
    var $st$13$1 = $3435 + 4 | 0;
    var $3436$1 = HEAP32[$st$13$1 >> 2];
    var $3437 = $3433 | 0;
    var $st$18$0 = $3437 | 0;
    HEAP32[$st$18$0 >> 2] = $3436$0;
    var $st$18$1 = $3437 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $3436$1;
    if (($op_0 | 0) == 216) {
      __label__ = 753;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 753:
    var $3440 = HEAP32[$_pre_phi80 >> 2];
    var $3441 = $3440 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3441;
    __ZN2JS5Value12setUndefinedEv($3440);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 754:
    var $3443 = HEAPU32[$_pre_phi >> 2];
    var $3453 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$11$0 = $3453 | 0;
    var $3454$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $3453 + 4 | 0;
    var $3454$1 = HEAP32[$st$11$1 >> 2];
    var $3455 = $argv_1 + (((HEAPU8[$3443 + 1 | 0] & 255) << 8 | HEAPU8[$3443 + 2 | 0] & 255) << 3) | 0;
    var $st$16$0 = $3455 | 0;
    HEAP32[$st$16$0 >> 2] = $3454$0;
    var $st$16$1 = $3455 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $3454$1;
    var $3456 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$3456 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 755;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 755:
    var $3462 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3462;
    var $3463 = $3456 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $3463;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$3463] & 255;
    __label__ = 20;
    break;
   case 756:
    var $3467 = HEAPU32[$_pre_phi >> 2];
    var $3475 = (HEAPU8[$3467 + 1 | 0] & 255) << 8 | HEAPU8[$3467 + 2 | 0] & 255;
    var $3476 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3476 + 8 | 0;
    var $3478 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3479 = $3478;
    var $3480 = __ZNK2js10StackFrame5slotsEv($3479);
    var $3481 = $3480 + ($3475 << 3) | 0;
    var $st$16$0 = $3481 | 0;
    var $3482$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $3481 + 4 | 0;
    var $3482$1 = HEAP32[$st$16$1 >> 2];
    var $3483 = $3476 | 0;
    var $st$21$0 = $3483 | 0;
    HEAP32[$st$21$0 >> 2] = $3482$0;
    var $st$21$1 = $3483 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $3482$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 757:
    var $3485 = HEAPU32[$_pre_phi >> 2];
    var $3493 = (HEAPU8[$3485 + 1 | 0] & 255) << 8 | HEAPU8[$3485 + 2 | 0] & 255;
    var $3494 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3494 + 8 | 0;
    var $3496 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3497 = $3496;
    var $3498 = __ZNK2js10StackFrame5slotsEv($3497);
    var $3499 = $3498 + ($3493 << 3) | 0;
    var $st$16$0 = $3499 | 0;
    var $3500$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $3499 + 4 | 0;
    var $3500$1 = HEAP32[$st$16$1 >> 2];
    var $3501 = $3494 | 0;
    var $st$21$0 = $3501 | 0;
    HEAP32[$st$21$0 >> 2] = $3500$0;
    var $st$21$1 = $3501 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $3500$1;
    var $3502 = HEAP32[$_pre_phi80 >> 2];
    var $3503 = $3502 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3503;
    __ZN2JS5Value12setUndefinedEv($3502);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 758:
    var $3505 = HEAPU32[$_pre_phi >> 2];
    var $3513 = (HEAPU8[$3505 + 1 | 0] & 255) << 8 | HEAPU8[$3505 + 2 | 0] & 255;
    var $3514 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3515 = $3514;
    var $3516 = __ZNK2js10StackFrame5slotsEv($3515);
    var $3518 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$14$0 = $3518 | 0;
    var $3519$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $3518 + 4 | 0;
    var $3519$1 = HEAP32[$st$14$1 >> 2];
    var $3520 = $3516 + ($3513 << 3) | 0;
    var $st$19$0 = $3520 | 0;
    HEAP32[$st$19$0 >> 2] = $3519$0;
    var $st$19$1 = $3520 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $3519$1;
    var $3521 = HEAP32[$_pre_phi >> 2];
    if (HEAP8[$3521 + 3 | 0] << 24 >> 24 == 81) {
      __label__ = 759;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 759:
    var $3527 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3527;
    var $3528 = $3521 + 4 | 0;
    HEAP32[$_pre_phi >> 2] = $3528;
    var $_2 = $_2;
    var $script_1 = $script_1;
    var $pcCounts_1 = $pcCounts_1;
    var $argv_1 = $argv_1;
    var $atoms_1 = $atoms_1;
    var $op_0 = HEAPU8[$3528] & 255;
    __label__ = 20;
    break;
   case 760:
    var $3531 = HEAPU32[$_pre_phi >> 2];
    var $3539 = (HEAPU8[$3531 + 1 | 0] & 255) << 8 | HEAPU8[$3531 + 2 | 0] & 255;
    var $3541 = __ZNK2JS5Value8toObjectEv($argv_1 - 16 | 0);
    var $3542 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $3542 + 8 | 0;
    var $3544 = __ZN8JSObject19getFlatClosureUpvarEj($3541, $3539);
    var $3545 = $3544 | 0;
    var $st$16$0 = $3545 | 0;
    var $3546$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $3545 + 4 | 0;
    var $3546$1 = HEAP32[$st$16$1 >> 2];
    var $3547 = $3542 | 0;
    var $st$21$0 = $3547 | 0;
    HEAP32[$st$21$0 >> 2] = $3546$0;
    var $st$21$1 = $3547 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $3546$1;
    var $3548 = HEAP32[$_pre_phi >> 2];
    var $3550 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script_1, $3548, $3550);
    if (($op_0 | 0) == 137) {
      __label__ = 761;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 761:
    var $3553 = HEAP32[$_pre_phi80 >> 2];
    var $3554 = $3553 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3554;
    __ZN2JS5Value12setUndefinedEv($3553);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 762:
    var $3555 = HEAPU32[$_pre_phi >> 2];
    var $3565 = HEAP32[$atoms_1 + (((HEAPU8[$3555 + 1 | 0] & 255) << 8 | HEAPU8[$3555 + 2 | 0] & 255) << 2) >> 2];
    var $3566 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3567 = __ZN2js10StackFrame6varObjEv($3566);
    var $3568 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3569 = __ZNK2js10StackFrame11isEvalFrameEv($3568);
    var $attrs_0 = $3569 ? 1 : 5;
    var $3570 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3565);
    if (($op_0 | 0) == 129) {
      __label__ = 763;
      break;
    } else {
      __label__ = 765;
      break;
    }
   case 763:
    var $3573 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($3567, $cx, $3570, $obj2275, $prop274);
    if (($3573 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 764;
      break;
    }
   case 764:
    if ((HEAP32[$prop274 >> 2] | 0) == 0) {
      var $attrs_181 = $attrs_0;
      __label__ = 767;
      break;
    } else {
      __label__ = 766;
      break;
    }
   case 765:
    var $3579 = $attrs_0 | 2;
    var $3580 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $3567, $3570, $3579);
    if ($3580) {
      var $attrs_181 = $3579;
      __label__ = 767;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 766:
    if ((HEAP32[$obj2275 >> 2] | 0) == ($3567 | 0)) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      var $attrs_181 = $attrs_0;
      __label__ = 767;
      break;
    }
   case 767:
    var $attrs_181;
    __ZN2JSL14UndefinedValueEv1839($11);
    var $3584 = $3567;
    var $3585 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5173, $3584, $3570, $11, 10, 12, $attrs_181, 0, 0, 0);
    if (($3585 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 768:
    var $3594 = HEAPU32[$_pre_phi >> 2];
    var $3603 = ((HEAPU8[$3594 + 1 | 0] & 255) << 8 | HEAPU8[$3594 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3604 = __ZN8JSScript11getFunctionEj($script_1, $3603);
    var $3605 = $3604 | 0;
    var $3606 = __ZNK10JSFunction13isNullClosureEv($3604);
    var $3607 = __ZNK2js9FrameRegs2fpEv($regs);
    if ($3606) {
      __label__ = 769;
      break;
    } else {
      __label__ = 770;
      break;
    }
   case 769:
    var $3609 = __ZNK2js10StackFrame10scopeChainEv($3607);
    var $obj2278_0 = $3609;
    __label__ = 771;
    break;
   case 770:
    var $3611 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3607, undef, 3);
    if (($3611 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj2278_0 = $3611;
      __label__ = 771;
      break;
    }
   case 771:
    var $obj2278_0;
    var $3614 = __ZNK8JSObject9getParentEv($3605);
    if (($3614 | 0) == ($obj2278_0 | 0)) {
      var $obj277_0 = $3605;
      __label__ = 773;
      break;
    } else {
      __label__ = 772;
      break;
    }
   case 772:
    var $3617 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3604, $obj2278_0, 1);
    if (($3617 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj277_0 = $3617;
      __label__ = 773;
      break;
    }
   case 773:
    var $obj277_0;
    var $3620 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3621 = __ZNK2js10StackFrame11isEvalFrameEv($3620);
    var $3622 = $3621 ? 1 : 5;
    var $3623 = __ZN2js10StackFrame6varObjEv($3620);
    var $3625 = HEAP32[$3604 + 72 >> 2];
    var $3626 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3625);
    HEAP32[$prop281 >> 2] = 0;
    var $3627 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($3623, $cx, $3626, $pobj282, $prop281);
    if (($3627 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 774;
      break;
    }
   case 774:
    __ZN2JSL11ObjectValueER8JSObject1804($rval283, $obj277_0);
    var $3630 = HEAP32[$prop281 >> 2];
    if (($3630 | 0) == 0) {
      __label__ = 776;
      break;
    } else {
      __label__ = 775;
      break;
    }
   case 775:
    if ((HEAP32[$pobj282 >> 2] | 0) == ($3623 | 0)) {
      __label__ = 777;
      break;
    } else {
      __label__ = 776;
      break;
    }
   case 776:
    var $3636 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3623, $cx, $3626, $rval283, 10, 12, $3622);
    if (($3636 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 777:
    var $3639 = $3630;
    var $3640 = __ZNK8JSObject8isGlobalEv($3623);
    if ($3640) {
      __label__ = 778;
      break;
    } else {
      __label__ = 786;
      break;
    }
   case 778:
    var $3642 = $3630;
    var $3643 = __ZNK2js5Shape12configurableEv($3642);
    if ($3643) {
      __label__ = 779;
      break;
    } else {
      __label__ = 780;
      break;
    }
   case 779:
    var $3645 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3623, $cx, $3626, $rval283, 10, 12, $3622);
    if (($3645 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 780:
    var $3648 = __ZNK2js5Shape20isAccessorDescriptorEv($3639);
    if ($3648) {
      __label__ = 783;
      break;
    } else {
      __label__ = 781;
      break;
    }
   case 781:
    var $3650 = __ZNK2js5Shape8writableEv($3642);
    if ($3650) {
      __label__ = 782;
      break;
    } else {
      __label__ = 783;
      break;
    }
   case 782:
    var $3652 = __ZNK2js5Shape10enumerableEv($3639);
    if ($3652) {
      __label__ = 786;
      break;
    } else {
      __label__ = 783;
      break;
    }
   case 783:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi1799($12, $3626);
    var $3654 = $bytes;
    var $3655 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($5170, $12, $3654, 0);
    if (($3655 | 0) == 0) {
      __label__ = 785;
      break;
    } else {
      __label__ = 784;
      break;
    }
   case 784:
    _JS_ReportErrorNumber($cx, 2, 0, 240, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3655, tempInt));
    __label__ = 785;
    break;
   case 785:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 786:
    var $3664 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $3665 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3623, $cx, $3626, $rval283, $3664);
    if (($3665 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 787:
    var $3674 = HEAPU32[$_pre_phi >> 2];
    var $3683 = ((HEAPU8[$3674 + 1 | 0] & 255) << 8 | HEAPU8[$3674 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3684 = __ZN8JSScript11getFunctionEj($script_1, $3683);
    var $3685 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3684, undef, undef);
    if (($3685 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 788;
      break;
    }
   case 788:
    __ZN2JSL11ObjectValueER8JSObject1804($rval287, $3685);
    var $3688 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3689 = __ZNK2js10StackFrame11isEvalFrameEv($3688);
    var $3690 = $3689 ? 1 : 5;
    var $3691 = __ZN2js10StackFrame6varObjEv($3688);
    var $3693 = HEAP32[$3684 + 72 >> 2];
    var $3694 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3693);
    var $3695 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $3691, $3694, $3690);
    if ($3695) {
      __label__ = 789;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 789:
    if ($3689) {
      __label__ = 790;
      break;
    } else {
      __label__ = 791;
      break;
    }
   case 790:
    var $3702 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $3703 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3691, $cx, $3694, $rval287, $3702);
    if (($3703 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 791:
    var $3706 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($3691, $cx, $3694, $rval287, 10, 12, $3690);
    if (($3706 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 792:
    var $3715 = HEAPU32[$_pre_phi >> 2];
    var $3724 = ((HEAPU8[$3715 + 3 | 0] & 255) << 8 | HEAPU8[$3715 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3725 = __ZN8JSScript11getFunctionEj($script_1, $3724);
    var $3726 = $3725 | 0;
    var $3727 = __ZNK10JSFunction13isNullClosureEv($3725);
    var $3728 = __ZNK2js9FrameRegs2fpEv($regs);
    if ($3727) {
      __label__ = 793;
      break;
    } else {
      __label__ = 794;
      break;
    }
   case 793:
    var $3730 = __ZNK2js10StackFrame10scopeChainEv($3728);
    var $3731 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3725, $3730, 1);
    if (($3731 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj292_0 = $3731;
      __label__ = 797;
      break;
    }
   case 794:
    var $3734 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3728, undef, 5);
    if (($3734 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 795;
      break;
    }
   case 795:
    var $3737 = __ZNK8JSObject9getParentEv($3726);
    if (($3737 | 0) == ($3734 | 0)) {
      var $obj292_0 = $3726;
      __label__ = 797;
      break;
    } else {
      __label__ = 796;
      break;
    }
   case 796:
    var $3740 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3725, $3734, 1);
    if (($3740 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj292_0 = $3740;
      __label__ = 797;
      break;
    }
   case 797:
    var $obj292_0;
    var $3743 = HEAPU32[$_pre_phi >> 2];
    var $3751 = (HEAPU8[$3743 + 1 | 0] & 255) << 8 | HEAPU8[$3743 + 2 | 0] & 255;
    var $3752 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3753 = $3752;
    var $3754 = __ZNK2js10StackFrame5slotsEv($3753);
    var $3755 = $3754 + ($3751 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($3755, $obj292_0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 798:
    var $3763 = HEAPU32[$_pre_phi >> 2];
    var $3772 = ((HEAPU8[$3763 + 3 | 0] & 255) << 8 | HEAPU8[$3763 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3773 = __ZN8JSScript11getFunctionEj($script_1, $3772);
    var $3774 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3773, undef, undef);
    if (($3774 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 799;
      break;
    }
   case 799:
    var $3777 = HEAPU32[$_pre_phi >> 2];
    var $3785 = (HEAPU8[$3777 + 1 | 0] & 255) << 8 | HEAPU8[$3777 + 2 | 0] & 255;
    var $3786 = __ZNK2js9FrameRegs2fpEv($regs);
    var $3787 = $3786;
    var $3788 = __ZNK2js10StackFrame5slotsEv($3787);
    var $3789 = $3788 + ($3785 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($3789, $3774);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 800:
    var $3791 = $script_1 + 56 | 0;
    var $3793 = $atoms_1;
    var $3797 = HEAPU32[$_pre_phi >> 2];
    var $3806 = ((HEAPU8[$3797 + 1 | 0] & 255) << 8 | HEAPU8[$3797 + 2 | 0] & 255) + ($3793 - HEAP32[$3791 >> 2] >> 2) | 0;
    var $3807 = __ZN8JSScript11getFunctionEj($script_1, $3806);
    var $3808 = $3807 | 0;
    var $3809 = __ZNK10JSFunction13isNullClosureEv($3807);
    var $3810 = __ZNK2js9FrameRegs2fpEv($regs);
    if ($3809) {
      __label__ = 801;
      break;
    } else {
      __label__ = 813;
      break;
    }
   case 801:
    var $3812 = __ZNK2js10StackFrame10scopeChainEv($3810);
    var $3813 = __ZNK10JSFunction8joinableEv($3807);
    if ($3813) {
      __label__ = 802;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 802:
    var $3815 = HEAPU32[$_pre_phi >> 2];
    var $3816 = $3815 + 3 | 0;
    var $3817 = __ZN2js23AdvanceOverBlockchainOpEPh($3816);
    var $3818 = HEAP8[$3817];
    if ($3818 << 24 >> 24 == -29) {
      __label__ = 803;
      break;
    } else if ($3818 << 24 >> 24 == -30) {
      __label__ = 804;
      break;
    } else if ($3818 << 24 >> 24 == 58) {
      __label__ = 807;
      break;
    } else if ($3818 << 24 >> 24 == 64) {
      __label__ = 811;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 803:
    var $3826 = $3817 - $3815 | 0;
    var $3835 = ((HEAPU8[$3826 + ($3815 + 1) | 0] & 255) << 8 | HEAPU8[$3826 + ($3815 + 2) | 0] & 255) + ($3793 - HEAP32[$3791 >> 2] >> 2) | 0;
    var $3836 = __ZN8JSScript7getAtomEj($script_1, $3835);
    __ZN10JSFunction13setMethodAtomEP6JSAtom($3807, $3836);
    var $obj299_0 = $3808;
    __label__ = 815;
    break;
   case 804:
    var $3839 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $3840 = __ZNK2JS5Value8isObjectEv($3839);
    if ($3840) {
      __label__ = 805;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 805:
    var $3842 = __ZNK2JS5Value8toObjectEv($3839);
    var $3843 = __ZNK8JSObject20canHaveMethodBarrierEv($3842);
    if ($3843) {
      __label__ = 806;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 806:
    var $3851 = $3817 - $3815 | 0;
    var $3860 = ((HEAPU8[$3851 + ($3815 + 1) | 0] & 255) << 8 | HEAPU8[$3851 + ($3815 + 2) | 0] & 255) + ($3793 - HEAP32[$3791 >> 2] >> 2) | 0;
    var $3861 = __ZN8JSScript7getAtomEj($script_1, $3860);
    __ZN10JSFunction13setMethodAtomEP6JSAtom($3807, $3861);
    var $obj299_0 = $3808;
    __label__ = 815;
    break;
   case 807:
    var $3870 = (HEAPU8[$3817 + 1 | 0] & 255) << 8 | HEAPU8[$3817 + 2 | 0] & 255;
    var $3873 = HEAP32[$_pre_phi80 >> 2] + (($3870 ^ -1) << 3) | 0;
    var $3874 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($3873, $callee304);
    if ($3874) {
      __label__ = 808;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 808:
    var $3876 = HEAP32[$callee304 >> 2];
    var $3877 = __ZNK8JSObject18getFunctionPrivateEv($3876);
    var $3878 = $3877;
    var $3879 = __ZNK10JSFunction11maybeNativeEv($3878);
    if (($3879 | 0) == 0) {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    } else {
      __label__ = 809;
      break;
    }
   case 809:
    if (($3870 | 0) == 1 & ($3879 | 0) == 140) {
      var $obj299_0 = $3808;
      __label__ = 815;
      break;
    } else {
      __label__ = 810;
      break;
    }
   case 810:
    if (($3870 | 0) == 2 & ($3879 | 0) == 142) {
      var $obj299_0 = $3808;
      __label__ = 815;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 811:
    if (HEAP8[$3817 + 1 | 0] << 24 >> 24 == 58) {
      __label__ = 812;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 812:
    if (((HEAPU8[$3817 + 2 | 0] & 255) << 8 | HEAPU8[$3817 + 3 | 0] & 255 | 0) == 0) {
      var $obj299_0 = $3808;
      __label__ = 815;
      break;
    } else {
      var $parent300_0 = $3812;
      __label__ = 814;
      break;
    }
   case 813:
    var $3902 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $3810, undef, 3);
    if (($3902 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $parent300_0 = $3902;
      __label__ = 814;
      break;
    }
   case 814:
    var $parent300_0;
    var $3905 = __Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb($cx, $3807, $parent300_0, 1);
    if (($3905 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $obj299_0 = $3905;
      __label__ = 815;
      break;
    }
   case 815:
    var $obj299_0;
    var $3908 = HEAP32[$_pre_phi80 >> 2];
    var $3909 = $3908 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3909;
    __ZN2JS5Value9setObjectER8JSObject($3908, $obj299_0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 816:
    var $3917 = HEAPU32[$_pre_phi >> 2];
    var $3926 = ((HEAPU8[$3917 + 1 | 0] & 255) << 8 | HEAPU8[$3917 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $3927 = __ZN8JSScript11getFunctionEj($script_1, $3926);
    var $3928 = __Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj($cx, $3927, undef, undef);
    if (($3928 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 817;
      break;
    }
   case 817:
    var $3931 = HEAP32[$_pre_phi80 >> 2];
    var $3932 = $3931 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3932;
    __ZN2JS5Value9setObjectER8JSObject($3931, $3928);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 818:
    var $3934 = HEAP32[$_pre_phi80 >> 2];
    var $3935 = $3934 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $3935;
    var $3936 = $argv_1 - 16 | 0;
    var $st$4$0 = $3936 | 0;
    var $3937$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $3936 + 4 | 0;
    var $3937$1 = HEAP32[$st$4$1 >> 2];
    var $3938 = $3934 | 0;
    var $st$9$0 = $3938 | 0;
    HEAP32[$st$9$0 >> 2] = $3937$0;
    var $st$9$1 = $3938 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $3937$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 819:
    var $atoms_2;
    var $3940 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $3940;
    var $3941 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $3940);
    if (($3941 | 0) == 191) {
      __label__ = 820;
      break;
    } else if (($3941 | 0) == 211 || ($3941 | 0) == 212 || ($3941 | 0) == 213) {
      __label__ = 822;
      break;
    } else if (($3941 | 0) == 111 || ($3941 | 0) == 54) {
      __label__ = 823;
      break;
    } else if (($3941 | 0) == 56) {
      __label__ = 824;
      break;
    } else if (($3941 | 0) == 93) {
      __label__ = 829;
      break;
    } else {
      __label__ = 830;
      break;
    }
   case 820:
    var $3944 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    var $3947 = (HEAPU8[$3944] & 255) << 16;
    HEAP32[$_pre_phi >> 2] = $3944;
    var $_pn = $3947;
    __label__ = 821;
    break;
   case 821:
    var $_pn;
    var $atoms_2 = $atoms_2 + ($_pn << 2) | 0;
    __label__ = 819;
    break;
   case 822:
    var $_pn = ($3941 << 16) - 13762560 | 0;
    __label__ = 821;
    break;
   case 823:
    var $3952 = HEAPU32[$_pre_phi >> 2];
    var $3962 = HEAP32[$atoms_2 + (((HEAPU8[$3952 + 1 | 0] & 255) << 8 | HEAPU8[$3952 + 2 | 0] & 255) << 2) >> 2];
    var $3963 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3962);
    HEAP32[$id308 >> 2] = $3963;
    var $3964 = HEAPU32[$_pre_phi80 >> 2];
    var $3965 = $3964 - 8 | 0;
    var $st$15$0 = $3965 | 0;
    var $3966$0 = HEAPU32[$st$15$0 >> 2];
    var $st$15$1 = $3965 + 4 | 0;
    var $3966$1 = HEAPU32[$st$15$1 >> 2];
    var $st$19$0 = $5255 | 0;
    HEAP32[$st$19$0 >> 2] = $3966$0;
    var $st$19$1 = $5255 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $3966$1;
    var $i310_0 = -1;
    var $3974 = $3963;
    var $3973$1 = $3966$1;
    var $3973$0 = $3966$0;
    var $3972 = $3964;
    __label__ = 825;
    break;
   case 824:
    var $3968 = HEAP32[$_pre_phi80 >> 2];
    var $3969 = $3968 - 8 | 0;
    var $st$2$0 = $3969 | 0;
    var $3970$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $3969 + 4 | 0;
    var $3970$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5255 | 0;
    HEAP32[$st$6$0 >> 2] = $3970$0;
    var $st$6$1 = $5255 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $3970$1;
    HEAP32[$id308 >> 2] = 2;
    var $i310_0 = -2;
    var $3974 = 2;
    var $3973$1 = $3970$1;
    var $3973$0 = $3970$0;
    var $3972 = $3968;
    __label__ = 825;
    break;
   case 825:
    var $3972;
    var $3973$0;
    var $3973$1;
    var $3974;
    var $i310_0;
    var $3976 = $3972 + ($i310_0 - 1 << 3) | 0;
    var $3977 = __ZNK2JS5Value8isObjectEv($3976);
    if ($3977) {
      __label__ = 826;
      break;
    } else {
      __label__ = 827;
      break;
    }
   case 826:
    var $3979 = __ZNK2JS5Value8toObjectEv($3976);
    var $obj311_0 = $3979;
    var $i310_2 = $i310_0;
    var $4013 = $3974;
    var $4012$1 = $3973$1;
    var $4012$0 = $3973$0;
    __label__ = 832;
    break;
   case 827:
    var $3981 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $3976);
    var $3982 = $3981;
    if (($3981 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 828;
      break;
    }
   case 828:
    __ZN2JS5Value9setObjectER8JSObject($3976, $3982);
    var $obj311_0 = $3982;
    var $i310_2 = $i310_0;
    var $4013 = $3974;
    var $4012$1 = $3973$1;
    var $4012$0 = $3973$0;
    __label__ = 832;
    break;
   case 829:
    var $3986 = HEAPU32[$_pre_phi80 >> 2];
    var $3987 = $3986 - 8 | 0;
    var $st$2$0 = $3987 | 0;
    var $3988$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $3987 + 4 | 0;
    var $3988$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $5255 | 0;
    HEAP32[$st$6$0 >> 2] = $3988$0;
    var $st$6$1 = $5255 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $3988$1;
    var $3989 = HEAPU32[$_pre_phi >> 2];
    var $3999 = HEAP32[$atoms_2 + (((HEAPU8[$3989 + 1 | 0] & 255) << 8 | HEAPU8[$3989 + 2 | 0] & 255) << 2) >> 2];
    var $4000 = __ZL12ATOM_TO_JSIDP6JSAtom1798($3999);
    var $i310_1 = -1;
    var $storemerge = $4000;
    var $4007 = $3986;
    var $4006$1 = $3988$1;
    var $4006$0 = $3988$0;
    __label__ = 831;
    break;
   case 830:
    var $4002 = HEAPU32[$_pre_phi80 >> 2];
    var $4003 = $4002 - 8 | 0;
    var $st$2$0 = $4003 | 0;
    var $4004$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4003 + 4 | 0;
    var $4004$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5255 | 0;
    HEAP32[$st$6$0 >> 2] = $4004$0;
    var $st$6$1 = $5255 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4004$1;
    var $i310_1 = -2;
    var $storemerge = 2;
    var $4007 = $4002;
    var $4006$1 = $4004$1;
    var $4006$0 = $4004$0;
    __label__ = 831;
    break;
   case 831:
    var $4006$0;
    var $4006$1;
    var $4007;
    var $storemerge;
    var $i310_1;
    HEAP32[$id308 >> 2] = $storemerge;
    var $4010 = __ZNK2JS5Value8toObjectEv($4007 + ($i310_1 - 1 << 3) | 0);
    var $obj311_0 = $4010;
    var $i310_2 = $i310_1;
    var $4013 = $storemerge;
    var $4012$1 = $4006$1;
    var $4012$0 = $4006$0;
    __label__ = 832;
    break;
   case 832:
    var $4012$0;
    var $4012$1;
    var $4013;
    var $i310_2;
    var $obj311_0;
    var $4014 = _JSID_IS_VOID1831($4013);
    if (($4014 | 0) == 0) {
      __label__ = 837;
      break;
    } else {
      __label__ = 833;
      break;
    }
   case 833:
    var $4018 = HEAP32[$_pre_phi80 >> 2] + ($i310_2 << 3) | 0;
    var $4019 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($4018, $i_317);
    if ($4019) {
      __label__ = 834;
      break;
    } else {
      __label__ = 836;
      break;
    }
   case 834:
    var $4021 = HEAP32[$i_317 >> 2];
    var $4022 = _INT_FITS_IN_JSID1825($4021);
    if (($4022 | 0) == 0) {
      __label__ = 836;
      break;
    } else {
      __label__ = 835;
      break;
    }
   case 835:
    var $4025 = _INT_TO_JSID1826($4021);
    HEAP32[$id308 >> 2] = $4025;
    __label__ = 837;
    break;
   case 836:
    var $4028 = HEAP32[$_pre_phi80 >> 2] + ($i310_2 << 3) | 0;
    var $4029 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj311_0, $4018, $id308, $4028);
    if ($4029) {
      __label__ = 837;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 837:
    var $4031 = __ZL13js_IsCallableRKN2JS5ValueE1841($rval309);
    if ($4031) {
      __label__ = 839;
      break;
    } else {
      __label__ = 838;
      break;
    }
   case 838:
    var $_ = ($op_0 | 0) == 125 ? STRING_TABLE._js_getter_str : STRING_TABLE._js_setter_str;
    var $4034 = $_ | 0;
    _JS_ReportErrorNumber($cx, 2, 0, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4034, tempInt));
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 839:
    var $4036 = HEAP32[$id308 >> 2];
    var $4038 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($5173, $obj311_0, $4036, 3, $rtmp, $attrs318);
    if (($4038 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 840;
      break;
    }
   case 840:
    var $4041 = ($op_0 | 0) == 125;
    var $4042 = __ZNK2JS5Value8toObjectEv($rval309);
    if ($4041) {
      __label__ = 841;
      break;
    } else {
      __label__ = 842;
      break;
    }
   case 841:
    var $4044 = __ZN2jsL16CastAsPropertyOpEP8JSObject1842($4042);
    var $setter_0 = 12;
    var $getter_0 = $4044;
    var $4048 = 81;
    __label__ = 843;
    break;
   case 842:
    var $4046 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843($4042);
    var $setter_0 = $4046;
    var $getter_0 = 10;
    var $4048 = 97;
    __label__ = 843;
    break;
   case 843:
    var $4048;
    var $getter_0;
    var $setter_0;
    HEAP32[$attrs318 >> 2] = $4048;
    var $4049 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $obj311_0, $4036, $4048);
    if ($4049) {
      __label__ = 844;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 844:
    __ZN2JSL14UndefinedValueEv1839($13);
    var $4051 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj311_0, $cx, $4036, $13, $getter_0, $setter_0, $4048);
    if (($4051 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 845;
      break;
    }
   case 845:
    var $4054 = HEAP32[$_pre_phi80 >> 2];
    var $4055 = $4054 + ($i310_2 << 3) | 0;
    HEAP32[$_pre_phi80 >> 2] = $4055;
    if (HEAP8[_js_CodeSpec + ($3941 << 3) + 2 | 0] << 24 >> 24 > HEAP8[_js_CodeSpec + ($3941 << 3) + 1 | 0] << 24 >> 24) {
      __label__ = 846;
      break;
    } else {
      __label__ = 847;
      break;
    }
   case 846:
    var $4062 = $4054 + ($i310_2 - 1 << 3) | 0;
    var $st$2$0 = $4062 | 0;
    HEAP32[$st$2$0 >> 2] = $4012$0;
    var $st$2$1 = $4062 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $4012$1;
    __label__ = 847;
    break;
   case 847:
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_2;
    var $len_0 = HEAP8[_js_CodeSpec + ($3941 << 3) | 0] << 24 >> 24;
    __label__ = 19;
    break;
   case 848:
    var $4068 = HEAP32[$_pre_phi80 >> 2];
    var $4069 = $4068 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4069;
    __ZN2JS5Value8setMagicE10JSWhyMagic($4068, 0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 849:
    var $4073 = HEAPU8[HEAP32[$_pre_phi >> 2] + 1 | 0];
    var $4074 = $4073 & 255;
    if ($4073 << 24 >> 24 == 3) {
      __label__ = 850;
      break;
    } else {
      __label__ = 851;
      break;
    }
   case 850:
    var $4077 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    var $obj320_0 = $4077;
    __label__ = 852;
    break;
   case 851:
    var $4079 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, 4);
    var $obj320_0 = $4079;
    __label__ = 852;
    break;
   case 852:
    var $obj320_0;
    if (($obj320_0 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 853;
      break;
    }
   case 853:
    var $4083 = HEAP32[$_pre_phi >> 2];
    var $4084 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4083, $4074);
    if (($4084 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 854;
      break;
    }
   case 854:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($obj320_0, $4084);
    var $4087 = HEAP32[$_pre_phi80 >> 2];
    var $4088 = $4087 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4088;
    __ZN2JS5Value9setObjectER8JSObject($4087, $obj320_0);
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 855;
      break;
    }
   case 855:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 856:
    var $4095 = HEAPU32[$_pre_phi >> 2];
    var $4108 = HEAPU8[$4095 + 3 | 0] & 255 | (HEAPU8[$4095 + 1 | 0] & 255) << 16 | (HEAPU8[$4095 + 2 | 0] & 255) << 8;
    var $4109 = __ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject($cx, $4108, 0);
    if (($4109 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 857;
      break;
    }
   case 857:
    var $4112 = HEAP32[$_pre_phi >> 2];
    var $4113 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4112, 3);
    if (($4113 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 858;
      break;
    }
   case 858:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($4109, $4113);
    var $4116 = HEAP32[$_pre_phi80 >> 2];
    var $4117 = $4116 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4117;
    __ZN2JS5Value9setObjectER8JSObject($4116, $4109);
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 4;
      __label__ = 19;
      break;
    } else {
      __label__ = 859;
      break;
    }
   case 859:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 4;
    __label__ = 19;
    break;
   case 860:
    var $4130 = HEAPU32[$_pre_phi >> 2];
    var $4139 = ((HEAPU8[$4130 + 1 | 0] & 255) << 8 | HEAPU8[$4130 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $4140 = __ZN8JSScript9getObjectEj($script_1, $4139);
    var $4141 = __ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey($cx, $script_1, $4130, 1);
    if (($4141 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 861;
      break;
    }
   case 861:
    var $4144 = __ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE($cx, $4140, $4141);
    if (($4144 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 862;
      break;
    }
   case 862:
    var $4147 = HEAP32[$_pre_phi80 >> 2];
    var $4148 = $4147 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4148;
    __ZN2JS5Value9setObjectER8JSObject($4147, $4144);
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 863;
      break;
    }
   case 863:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 864:
    var $4154 = HEAP32[$_pre_phi80 >> 2];
    var $4155 = $4154 - 8 | 0;
    var $st$2$0 = $4155 | 0;
    var $4156$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4155 + 4 | 0;
    var $4156$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5225 | 0;
    HEAP32[$st$6$0 >> 2] = $4156$0;
    var $st$6$1 = $5225 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4156$1;
    var $4157 = $4154 - 16 | 0;
    var $4158 = __ZNK2JS5Value8toObjectEv($4157);
    var $4160 = HEAP32[$32 >> 2] + 144336 | 0;
    var $4161 = HEAP32[$_pre_phi >> 2];
    var $4162 = __ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE($4160, $33, $4161, $4158, $shape329, $entry328);
    if ($4162) {
      __label__ = 865;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 865:
    var $4164 = HEAPU32[$shape329 >> 2];
    var $4165 = __ZNK2js5Shape16hasDefaultSetterEv($4164);
    if ($4165) {
      __label__ = 866;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 866:
    var $4167 = __ZNK2js5Shape8previousEv($4164);
    var $4168 = __ZNK8JSObject12lastPropertyEv($4158);
    if (($4167 | 0) == ($4168 | 0)) {
      __label__ = 867;
      break;
    } else {
      __label__ = 870;
      break;
    }
   case 867:
    var $4172 = HEAPU32[$4164 + 24 >> 2];
    HEAP32[$slot330 >> 2] = $4172;
    var $4173 = __ZNK8JSObject8numSlotsEv($4158);
    if ($4172 >>> 0 < $4173 >>> 0) {
      __label__ = 869;
      break;
    } else {
      __label__ = 868;
      break;
    }
   case 868:
    var $4176 = $4158;
    var $4177 = __ZN8JSObject9allocSlotEP9JSContextPj($4176, $5173, $slot330);
    if ($4177) {
      __label__ = 869;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 869:
    __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($4158, $cx, $4164, 0);
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($4158, $cx, $4164, $rval326);
    __label__ = 873;
    break;
   case 870:
    var $4180 = HEAPU32[$_pre_phi >> 2];
    var $4190 = HEAPU32[$atoms_1 + (((HEAPU8[$4180 + 1 | 0] & 255) << 8 | HEAPU8[$4180 + 2 | 0] & 255) << 2) >> 2];
    var $4191 = __ZL12ATOM_TO_JSIDP6JSAtom1798($4190);
    var $4193 = ($op_0 | 0) == 227 ? 5 : 1;
    if (($4190 | 0) == (HEAP32[HEAP32[$32 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 871;
      break;
    } else {
      __label__ = 872;
      break;
    }
   case 871:
    var $4204 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $4205 = $4158;
    var $4206 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($5173, $4205, $4191, $4193, $rval326, $4204);
    if (($4206 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 873;
      break;
    }
   case 872:
    var $4209 = $4158;
    var $4210 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5173, $4209, $4191, $rval326, 0, 0, 1, 0, 0, $4193);
    if (($4210 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 873;
      break;
    }
   case 873:
    var $4214 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4214;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 874:
    var $4216 = HEAP32[$_pre_phi80 >> 2];
    var $4217 = $4216 - 8 | 0;
    var $4218 = $4216 - 24 | 0;
    var $4219 = __ZNK2JS5Value8toObjectEv($4218);
    var $4220 = $4216 - 16 | 0;
    var $4221 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($4220, $i_339);
    if ($4221) {
      __label__ = 875;
      break;
    } else {
      __label__ = 877;
      break;
    }
   case 875:
    var $4223 = HEAP32[$i_339 >> 2];
    var $4224 = _INT_FITS_IN_JSID1825($4223);
    if (($4224 | 0) == 0) {
      __label__ = 877;
      break;
    } else {
      __label__ = 876;
      break;
    }
   case 876:
    var $4227 = _INT_TO_JSID1826($4223);
    HEAP32[$id337 >> 2] = $4227;
    __label__ = 878;
    break;
   case 877:
    var $4230 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $4231 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $4219, $4220, $id337, $4230);
    if ($4231) {
      __label__ = 878;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 878:
    var $4233 = __ZNK2JS5Value7isMagicE10JSWhyMagic($4217, undef);
    if ($4233) {
      __label__ = 879;
      break;
    } else {
      __label__ = 881;
      break;
    }
   case 879:
    var $4236 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    var $4237 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793($script_1, $4236);
    if (($4237 | 0) == 92) {
      __label__ = 880;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 880:
    var $4240 = HEAP32[$id337 >> 2];
    var $4241 = _JSID_TO_INT1836($4240);
    var $4243 = ($4241 + 1 | 0) >>> 0;
    var $4244 = __Z20js_SetLengthPropertyP9JSContextP8JSObjectd($cx, $4219, $4243);
    if (($4244 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 881:
    var $4247 = HEAP32[$id337 >> 2];
    var $4248 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($4219, $cx, $4247, $4217, 0, 0, 1);
    if (($4248 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 882;
      break;
    }
   case 882:
    var $4252 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4252;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 883:
    var $4254 = HEAPU32[$_pre_phi >> 2];
    var $4262 = (HEAPU8[$4254 + 1 | 0] & 255) << 8 | HEAPU8[$4254 + 2 | 0] & 255;
    var $4263 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4264 = $4263;
    var $4265 = __ZNK2js10StackFrame5slotsEv($4264);
    var $4266 = $4265 + ($4262 << 3) | 0;
    var $4267 = __ZNK2JS5Value8isObjectEv($4266);
    if ($4267) {
      __label__ = 884;
      break;
    } else {
      __label__ = 885;
      break;
    }
   case 884:
    var $4269 = __ZNK2JS5Value8toObjectEv($4266);
    var $obj342_0 = $4269;
    var $4279 = $4254;
    __label__ = 887;
    break;
   case 885:
    var $4271 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($cx, 0);
    if (($4271 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 886;
      break;
    }
   case 886:
    var $4274 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4275 = $4274;
    var $4276 = __ZNK2js10StackFrame5slotsEv($4275);
    var $4277 = $4276 + ($4262 << 3) | 0;
    __ZN2JS5Value9setObjectER8JSObject($4277, $4271);
    var $obj342_0 = $4271;
    var $4279 = HEAP32[$_pre_phi >> 2];
    __label__ = 887;
    break;
   case 887:
    var $4279;
    var $obj342_0;
    var $4287 = (HEAPU8[$4279 + 3 | 0] & 255) << 8 | HEAPU8[$4279 + 4 | 0] & 255;
    var $4289 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4290 = __ZNK2JS5Value11isPrimitiveEv($4289);
    if ($4290) {
      __label__ = 888;
      break;
    } else {
      __label__ = 889;
      break;
    }
   case 888:
    var $4292 = $numBuf | 0;
    var $4293 = _JS_snprintf($4292, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4287, tempInt));
    _JS_ReportErrorNumber($cx, 2, 0, 29, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4292, tempInt));
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 889:
    var $4295 = _INT_TO_JSID1826($4287);
    var $4296 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj342_0, $cx, $4295, $4289, 0, 0, 1);
    if (($4296 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    }
   case 890:
    var $4299 = HEAPU32[$_pre_phi >> 2];
    var $4307 = (HEAPU8[$4299 + 1 | 0] & 255) << 8 | HEAPU8[$4299 + 2 | 0] & 255;
    var $4308 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4309 = $4308;
    var $4310 = __ZNK2js10StackFrame5slotsEv($4309);
    var $4311 = $4310 + ($4307 << 3) | 0;
    var $4319 = (HEAPU8[$4299 + 3 | 0] & 255) << 8 | HEAPU8[$4299 + 4 | 0] & 255;
    var $4320 = __ZNK2JS5Value11isUndefinedEv($4311);
    if ($4320) {
      __label__ = 891;
      break;
    } else {
      __label__ = 892;
      break;
    }
   case 891:
    __ZN2JS5Value12setUndefinedEv($rval349);
    __label__ = 893;
    break;
   case 892:
    var $4323 = __ZNK2JS5Value8toObjectEv($4311);
    var $4324 = _INT_TO_JSID1826($4319);
    var $4325 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($4323, $cx, $4324, $rval349);
    if (($4325 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 893;
      break;
    }
   case 893:
    var $4328 = __ZNK2JS5Value14isObjectOrNullEv($rval349);
    if ($4328) {
      __label__ = 895;
      break;
    } else {
      __label__ = 894;
      break;
    }
   case 894:
    var $4330 = $numBuf352 | 0;
    var $4331 = _JS_snprintf($4330, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4319, tempInt));
    _JS_ReportErrorNumber($cx, 2, 0, 30, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $4330, tempInt));
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 895:
    var $4333 = HEAP32[$_pre_phi80 >> 2];
    var $4334 = $4333 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4334;
    var $st$3$0 = $5226 | 0;
    var $4335$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5226 + 4 | 0;
    var $4335$1 = HEAP32[$st$3$1 >> 2];
    var $4336 = $4333 | 0;
    var $st$8$0 = $4336 | 0;
    HEAP32[$st$8$0 >> 2] = $4335$0;
    var $st$8$1 = $4336 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4335$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 896:
    var $4338 = HEAPU32[$_pre_phi >> 2];
    var $4346 = (HEAPU8[$4338 + 1 | 0] & 255) << 8 | HEAPU8[$4338 + 2 | 0] & 255;
    var $4347 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4348 = $4347;
    var $4349 = __ZNK2js10StackFrame5slotsEv($4348);
    var $4350 = $4349 + ($4346 << 3) | 0;
    var $4351 = $4349 + ($4346 + 1 << 3) | 0;
    var $st$15$0 = $4351 | 0;
    var $4352$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $4351 + 4 | 0;
    var $4352$1 = HEAP32[$st$15$1 >> 2];
    var $st$19$0 = $5227 | 0;
    HEAP32[$st$19$0 >> 2] = $4352$0;
    var $st$19$1 = $5227 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $4352$1;
    if (HEAP8[$4338 + 3 | 0] << 24 >> 24 == 92) {
      __label__ = 900;
      break;
    } else {
      __label__ = 897;
      break;
    }
   case 897:
    var $4357 = __ZNK2JS5Value11isUndefinedEv($rval355);
    if ($4357) {
      var $4362 = 1;
      __label__ = 899;
      break;
    } else {
      __label__ = 898;
      break;
    }
   case 898:
    var $4359 = __ZNK2JS5Value7toInt32Ev($rval355);
    var $4362 = $4359 + 1 | 0;
    __label__ = 899;
    break;
   case 899:
    var $4362;
    __ZN2JS5Value8setInt32Ei($rval355, $4362);
    __label__ = 902;
    break;
   case 900:
    var $4364 = __ZN2JS5Value11getInt32RefEv($rval355);
    var $4366 = HEAP32[$4364 >> 2] - 1 | 0;
    HEAP32[$4364 >> 2] = $4366;
    var $4367 = __ZNK2JS5Value7toInt32Ev($rval355);
    if (($4367 | 0) == 0) {
      __label__ = 901;
      break;
    } else {
      __label__ = 902;
      break;
    }
   case 901:
    __ZN2JS5Value12setUndefinedEv($4350);
    __label__ = 902;
    break;
   case 902:
    var $st$0$0 = $5227 | 0;
    var $4371$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5227 + 4 | 0;
    var $4371$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $4351 | 0;
    HEAP32[$st$4$0 >> 2] = $4371$0;
    var $st$4$1 = $4351 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $4371$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 903:
    var $4373 = HEAP32[$_pre_phi80 >> 2];
    var $4374 = $4373 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4374;
    __ZN2JS5Value10setBooleanEb($4373, 0);
    var $4380 = HEAP32[$_pre_phi >> 2] + 3 - HEAP32[$86 >> 2] | 0;
    var $4381 = HEAP32[$_pre_phi80 >> 2];
    var $4382 = $4381 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4382;
    __ZN2JS5Value8setInt32Ei($4381, $4380);
    var $4383 = HEAPU32[$_pre_phi >> 2];
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = ((HEAPU8[$4383 + 1 | 0] & 255) << 8 | HEAPU8[$4383 + 2 | 0] & 255) << 16 >> 16;
    __label__ = 19;
    break;
   case 904:
    var $4394 = HEAP32[$_pre_phi80 >> 2];
    var $4395 = $4394 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4395;
    __ZN2JS5Value10setBooleanEb($4394, 0);
    var $4396 = HEAPU32[$_pre_phi >> 2];
    var $4401 = $4396 + 5 - HEAP32[$86 >> 2] | 0;
    var $4419 = (HEAPU8[$4396 + 2 | 0] & 255) << 16 | (HEAPU8[$4396 + 1 | 0] & 255) << 24 | HEAPU8[$4396 + 4 | 0] & 255 | (HEAPU8[$4396 + 3 | 0] & 255) << 8;
    var $4420 = HEAP32[$_pre_phi80 >> 2];
    var $4421 = $4420 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4421;
    __ZN2JS5Value8setInt32Ei($4420, $4401);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $4419;
    __label__ = 19;
    break;
   case 905:
    var $4423 = HEAPU32[$_pre_phi80 >> 2];
    var $4424 = $4423 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4424;
    var $4425 = $4424 | 0;
    var $st$4$0 = $4425 | 0;
    var $4426$0 = HEAPU32[$st$4$0 >> 2];
    var $st$4$1 = $4425 + 4 | 0;
    var $4426$1 = HEAPU32[$st$4$1 >> 2];
    var $st$8$0 = $5228 | 0;
    HEAP32[$st$8$0 >> 2] = $4426$0;
    var $st$8$1 = $5228 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4426$1;
    var $4427 = $4423 - 16 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4427;
    var $4428 = $4427 | 0;
    var $st$15$0 = $4428 | 0;
    var $4429$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $4428 + 4 | 0;
    var $4429$1 = HEAP32[$st$15$1 >> 2];
    var $st$19$0 = $5229 | 0;
    HEAP32[$st$19$0 >> 2] = $4429$0;
    var $st$19$1 = $5229 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $4429$1;
    var $4430 = __ZNK2JS5Value9toBooleanEv($lval359);
    if ($4430) {
      __label__ = 906;
      break;
    } else {
      __label__ = 907;
      break;
    }
   case 906:
    var $4432 = $14 | 0;
    var $st$1$0 = $4432 | 0;
    HEAP32[$st$1$0 >> 2] = $4426$0;
    var $st$1$1 = $4432 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $4426$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $14);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 907:
    var $4434 = __ZNK2JS5Value7toInt32Ev($rval358);
    var $4435 = HEAP32[$86 >> 2];
    HEAP32[$_pre_phi >> 2] = $4435;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = $4434;
    __label__ = 19;
    break;
   case 908:
    var $4437 = HEAP32[$_pre_phi80 >> 2];
    var $4438 = $4437 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4438;
    __ZN9JSContext19getPendingExceptionEv($15, $cx);
    var $st$4$0 = $5230 | 0;
    var $4439$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $5230 + 4 | 0;
    var $4439$1 = HEAP32[$st$4$1 >> 2];
    var $4440 = $4437 | 0;
    var $st$9$0 = $4440 | 0;
    HEAP32[$st$9$0 >> 2] = $4439$0;
    var $st$9$1 = $4440 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $4439$1;
    __ZN9JSContext21clearPendingExceptionEv($cx);
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 909;
      break;
    }
   case 909:
    var $4446 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4446 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 910:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 911;
      break;
    }
   case 911:
    var $4454 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4454 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 912:
    var $4458 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4458;
    var $_019 = $4458 | 0;
    var $st$4$0 = $_019 | 0;
    var $tmp20$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_019 + 4 | 0;
    var $tmp20$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $_021 | 0;
    HEAP32[$st$8$0 >> 2] = $tmp20$0;
    var $st$8$1 = $_021 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $tmp20$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $16);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 913:
    if ((HEAP32[HEAP32[$32 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 915;
      break;
    } else {
      __label__ = 914;
      break;
    }
   case 914:
    var $4465 = __Z27js_HandleExecutionInterruptP9JSContext($cx);
    if (($4465 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 915;
      break;
    }
   case 915:
    var $4469 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4469;
    var $_014 = $4469 | 0;
    var $st$4$0 = $_014 | 0;
    var $tmp$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $_014 + 4 | 0;
    var $tmp$1 = HEAP32[$st$4$1 >> 2];
    var $_015 = $17 | 0;
    var $st$9$0 = $_015 | 0;
    HEAP32[$st$9$0 >> 2] = $tmp$0;
    var $st$9$1 = $_015 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $tmp$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $17);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 916:
    var $4471 = HEAPU32[$_pre_phi >> 2];
    var $4479 = (HEAPU8[$4471 + 1 | 0] & 255) << 8 | HEAPU8[$4471 + 2 | 0] & 255;
    var $4480 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4481 = $4480;
    var $4482 = __ZNK2js10StackFrame5slotsEv($4481);
    var $4484 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4484;
    var $4485 = $4484 | 0;
    var $st$16$0 = $4485 | 0;
    var $4486$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $4485 + 4 | 0;
    var $4486$1 = HEAP32[$st$16$1 >> 2];
    var $4487 = $4482 + ($4479 << 3) | 0;
    var $st$21$0 = $4487 | 0;
    HEAP32[$st$21$0 >> 2] = $4486$0;
    var $st$21$1 = $4487 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $4486$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 917:
    var $4490 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4491 = __ZL13js_IsCallableRKN2JS5ValueE1841($4490);
    if ($4491) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    } else {
      __label__ = 918;
      break;
    }
   case 918:
    var $4493 = HEAPU32[$_pre_phi >> 2];
    var $4501 = (HEAPU8[$4493 + 1 | 0] & 255) << 8 | HEAPU8[$4493 + 2 | 0] & 255;
    var $4503 = $4493 + ($4501 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $4503;
    var $4505 = HEAPU8[$4503] & 255;
    if ($4501 << 16 >> 16 < 1) {
      var $op_1 = $4505;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $4505;
      __label__ = 20;
      break;
    }
   case 919:
    var $4508 = HEAPU32[$_pre_phi80 >> 2];
    var $4509 = $4508 - 8 | 0;
    var $4510 = __ZNK2JS5Value8isObjectEv($4509);
    if ($4510) {
      __label__ = 920;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 2;
      __label__ = 19;
      break;
    }
   case 920:
    var $4514 = HEAP8[HEAP32[$_pre_phi >> 2] + 1 | 0];
    var $4515 = $4508 - 16 | 0;
    if ($4514 << 24 >> 24 == 0) {
      var $4523 = STRING_TABLE.__str242227 | 0;
      __label__ = 922;
      break;
    } else {
      __label__ = 921;
      break;
    }
   case 921:
    var $4523 = HEAP32[_js_common_atom_names + (($4514 << 24 >> 24) + 3 << 2) >> 2];
    __label__ = 922;
    break;
   case 922:
    var $4523;
    var $4524 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 38, -2, $4515, 0, $4523, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 923:
    var $4527 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4528 = __ZNK2JS5Value11isPrimitiveEv($4527);
    if ($4528) {
      __label__ = 924;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 3;
      __label__ = 19;
      break;
    }
   case 924:
    var $4530 = HEAPU32[$_pre_phi >> 2];
    var $4538 = (HEAPU8[$4530 + 1 | 0] & 255) << 8 | HEAPU8[$4530 + 2 | 0] & 255;
    var $4539 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, $4538, -1, $4527, 0, 0, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 925:
    var $4541 = HEAPU32[$_pre_phi80 >> 2];
    var $4542 = $4541 - 8 | 0;
    var $4543 = __ZNK2JS5Value11isPrimitiveEv($4542);
    if ($4543) {
      __label__ = 926;
      break;
    } else {
      __label__ = 927;
      break;
    }
   case 926:
    var $4545 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, -1, $4542, 0, 0, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 927:
    var $4547 = __ZNK2JS5Value8toObjectEv($4542);
    var $4548 = $4541 - 16 | 0;
    HEAP32[$cond367 >> 2] = 0;
    var $4549 = __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $4547, $4548, $cond367);
    if (($4549 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 928;
      break;
    }
   case 928:
    var $4552 = HEAP32[$_pre_phi80 >> 2];
    var $4553 = $4552 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4553;
    var $4554 = $4552 - 16 | 0;
    var $4556 = (HEAP32[$cond367 >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($4554, $4556);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 929:
    var $4558 = HEAP32[$46 >> 2];
    var $4560 = HEAP32[$4558 + 24 >> 2];
    if (($4560 | 0) == 0) {
      __label__ = 931;
      break;
    } else {
      __label__ = 930;
      break;
    }
   case 930:
    var $4563 = HEAP32[$_pre_phi >> 2];
    var $4565 = HEAP32[$4558 + 28 >> 2];
    var $4566 = FUNCTION_TABLE[$4560]($cx, $script_1, $4563, $rval368, $4565);
    if (($4566 | 0) == 1) {
      __label__ = 931;
      break;
    } else {
      var $st_1 = $4566;
      __label__ = 932;
      break;
    }
   case 931:
    var $4568 = __ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE($cx, $rval368);
    var $st_1 = $4568;
    __label__ = 932;
    break;
   case 932:
    var $st_1;
    if (($st_1 | 0) == 2) {
      __label__ = 933;
      break;
    } else if (($st_1 | 0) == 3) {
      __label__ = 934;
      break;
    } else if (($st_1 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 935;
      break;
    }
   case 933:
    var $4571 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4572 = $4571;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($4572, $rval368);
    var $_5 = $_2;
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 934:
    var $4574 = $rval368 | 0;
    var $st$1$0 = $4574 | 0;
    var $4575$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $4574 + 4 | 0;
    var $4575$1 = HEAP32[$st$1$1 >> 2];
    var $4576 = $18 | 0;
    var $st$6$0 = $4576 | 0;
    HEAP32[$st$6$0 >> 2] = $4575$0;
    var $st$6$1 = $4576 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4575$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $18);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 935:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 936;
      break;
    }
   case 936:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 937:
    var $4585 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4586 = __Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE($5177, $4585);
    if (($4586 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 938;
      break;
    }
   case 938:
    var $4590 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4590;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 939:
    var $4592 = __Z13js_GetAnyNameP9JSContextPi($5177, $id369);
    if (($4592 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 940;
      break;
    }
   case 940:
    var $4595 = HEAP32[$_pre_phi80 >> 2];
    var $4596 = $4595 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4596;
    var $4597 = HEAP32[$id369 >> 2];
    __ZN2jsL9IdToValueEi1799($19, $4597);
    var $st$5$0 = $5231 | 0;
    var $4598$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $5231 + 4 | 0;
    var $4598$1 = HEAP32[$st$5$1 >> 2];
    var $4599 = $4595 | 0;
    var $st$10$0 = $4599 | 0;
    HEAP32[$st$10$0 >> 2] = $4598$0;
    var $st$10$1 = $4599 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $4598$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 941:
    var $4601 = HEAPU32[$_pre_phi >> 2];
    var $4611 = HEAP32[$atoms_1 + (((HEAPU8[$4601 + 1 | 0] & 255) << 8 | HEAPU8[$4601 + 2 | 0] & 255) << 2) >> 2];
    var $4612 = HEAPU32[$_pre_phi80 >> 2];
    HEAP32[$_pre_phi80 >> 2] = $4612 + 8 | 0;
    var $4614 = $4611 | 0;
    __ZN2JS5Value9setStringEP8JSString($4612, $4614);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 942:
    var $4616 = HEAPU32[$_pre_phi >> 2];
    var $4627 = HEAP32[$atoms_1 + (((HEAPU8[$4616 + 1 | 0] & 255) << 8 | HEAPU8[$4616 + 2 | 0] & 255) << 2) >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString1846($rval372, $4627);
    var $4629 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$15$0 = $4629 | 0;
    var $4630$0 = HEAP32[$st$15$0 >> 2];
    var $st$15$1 = $4629 + 4 | 0;
    var $4630$1 = HEAP32[$st$15$1 >> 2];
    var $st$19$0 = $5232 | 0;
    HEAP32[$st$19$0 >> 2] = $4630$0;
    var $st$19$1 = $5232 + 4 | 0;
    HEAP32[$st$19$1 >> 2] = $4630$1;
    var $4631 = __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($5177, $lval373, $rval372);
    if (($4631 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 943;
      break;
    }
   case 943:
    var $4634 = $4631;
    var $4636 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4636, $4634);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 944:
    var $4638 = HEAP32[$_pre_phi80 >> 2];
    var $4639 = $4638 - 8 | 0;
    var $st$2$0 = $4639 | 0;
    var $4640$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4639 + 4 | 0;
    var $4640$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5233 | 0;
    HEAP32[$st$6$0 >> 2] = $4640$0;
    var $st$6$1 = $5233 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4640$1;
    var $4641 = $4638 - 16 | 0;
    var $st$11$0 = $4641 | 0;
    var $4642$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $4641 + 4 | 0;
    var $4642$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5234 | 0;
    HEAP32[$st$15$0 >> 2] = $4642$0;
    var $st$15$1 = $5234 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $4642$1;
    var $4643 = __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($5177, $lval376, $rval375);
    if (($4643 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 945;
      break;
    }
   case 945:
    var $4646 = $4643;
    var $4647 = HEAP32[$_pre_phi80 >> 2];
    var $4648 = $4647 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4648;
    var $4649 = $4647 - 16 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4649, $4646);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 946:
    var $4652 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4652 | 0;
    var $4653$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4652 + 4 | 0;
    var $4653$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5235 | 0;
    HEAP32[$st$6$0 >> 2] = $4653$0;
    var $st$6$1 = $5235 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4653$1;
    var $4654 = __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($5177, $rval378);
    if (($4654 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 947;
      break;
    }
   case 947:
    var $st$1$0 = $5235 | 0;
    var $4658$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5235 + 4 | 0;
    var $4658$1 = HEAP32[$st$1$1 >> 2];
    var $4659 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $4659 | 0;
    HEAP32[$st$6$0 >> 2] = $4658$0;
    var $st$6$1 = $4659 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4658$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 948:
    var $4662 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4662 | 0;
    var $4663$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4662 + 4 | 0;
    var $4663$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5236 | 0;
    HEAP32[$st$6$0 >> 2] = $4663$0;
    var $st$6$1 = $5236 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4663$1;
    var $4664 = __ZNK2JS5Value8toStringEv($rval379);
    var $4665 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($5177, $4664, 0);
    if (($4665 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 949;
      break;
    }
   case 949:
    var $4668 = $4665 | 0;
    var $4670 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4670, $4668);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 950:
    var $4672 = HEAP32[$_pre_phi80 >> 2];
    var $4673 = $4672 - 8 | 0;
    var $st$2$0 = $4673 | 0;
    var $4674$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4673 + 4 | 0;
    var $4674$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5237 | 0;
    HEAP32[$st$6$0 >> 2] = $4674$0;
    var $st$6$1 = $5237 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4674$1;
    var $4675 = $4672 - 16 | 0;
    var $st$11$0 = $4675 | 0;
    var $4676$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $4675 + 4 | 0;
    var $4676$1 = HEAP32[$st$11$1 >> 2];
    var $st$15$0 = $5238 | 0;
    HEAP32[$st$15$0 >> 2] = $4676$0;
    var $st$15$1 = $5238 + 4 | 0;
    HEAP32[$st$15$1 >> 2] = $4676$1;
    var $4677 = __ZNK2JS5Value8toStringEv($lval382);
    var $4678 = __ZNK2JS5Value8toStringEv($rval381);
    var $4681 = __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($5177, ($op_0 | 0) == 170 & 1, $4677, $4678);
    if (($4681 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 951;
      break;
    }
   case 951:
    var $4684 = HEAP32[$_pre_phi80 >> 2];
    var $4685 = $4684 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4685;
    var $4686 = $4684 - 16 | 0;
    __ZN2JS5Value9setStringEP8JSString($4686, $4681);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 952:
    var $4689 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4689 | 0;
    var $4690$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4689 + 4 | 0;
    var $4690$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5239 | 0;
    HEAP32[$st$6$0 >> 2] = $4690$0;
    var $st$6$1 = $5239 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4690$1;
    var $4691 = __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($5177, $lval385, $5240, $id387);
    if (($4691 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 953;
      break;
    }
   case 953:
    var $4695 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4696 = HEAP32[$obj386 >> 2];
    __ZN2JS5Value15setObjectOrNullEP8JSObject($4695, $4696);
    var $4697 = HEAP32[$_pre_phi80 >> 2];
    var $4698 = $4697 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4698;
    var $4699 = HEAP32[$id387 >> 2];
    __ZN2jsL9IdToValueEi1799($20, $4699);
    var $st$9$0 = $5241 | 0;
    var $4700$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $5241 + 4 | 0;
    var $4700$1 = HEAP32[$st$9$1 >> 2];
    var $4701 = $4697 | 0;
    var $st$14$0 = $4701 | 0;
    HEAP32[$st$14$0 >> 2] = $4700$0;
    var $st$14$1 = $4701 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $4700$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 954:
    var $4703 = HEAP32[$_pre_phi80 >> 2];
    var $4704 = $4703 - 24 | 0;
    var $4705 = __ZNK2JS5Value8toObjectEv($4704);
    var $4706 = $4703 - 8 | 0;
    var $st$4$0 = $4706 | 0;
    var $4707$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $4706 + 4 | 0;
    var $4707$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $5242 | 0;
    HEAP32[$st$8$0 >> 2] = $4707$0;
    var $st$8$1 = $5242 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4707$1;
    var $4708 = $4703 - 16 | 0;
    var $4709 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($4708, $i_392);
    if ($4709) {
      __label__ = 955;
      break;
    } else {
      __label__ = 957;
      break;
    }
   case 955:
    var $4711 = HEAP32[$i_392 >> 2];
    var $4712 = _INT_FITS_IN_JSID1825($4711);
    if (($4712 | 0) == 0) {
      __label__ = 957;
      break;
    } else {
      __label__ = 956;
      break;
    }
   case 956:
    var $4715 = _INT_TO_JSID1826($4711);
    HEAP32[$id390 >> 2] = $4715;
    var $4721 = $4715;
    __label__ = 959;
    break;
   case 957:
    var $4718 = HEAP32[$_pre_phi80 >> 2] - 16 | 0;
    var $4719 = __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $4705, $4708, $id390, $4718);
    if ($4719) {
      __label__ = 958;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 958:
    var $4721 = HEAP32[$id390 >> 2];
    __label__ = 959;
    break;
   case 959:
    var $4721;
    var $4726 = (HEAPU8[$script_1 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $4727 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($4705, $cx, $4721, $rval389, $4726);
    if (($4727 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 960;
      break;
    }
   case 960:
    var $4730 = HEAPU32[$_pre_phi80 >> 2];
    var $4731 = $4730 - 8 | 0;
    var $st$2$0 = $4731 | 0;
    var $4732$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $4731 + 4 | 0;
    var $4732$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $5242 | 0;
    HEAP32[$st$6$0 >> 2] = $4732$0;
    var $st$6$1 = $5242 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4732$1;
    HEAP32[$_pre_phi80 >> 2] = $4730 - 16 | 0;
    var $4734 = $4730 - 24 | 0;
    var $st$13$0 = $4734 | 0;
    HEAP32[$st$13$0 >> 2] = $4732$0;
    var $st$13$1 = $4734 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $4732$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 961:
    var $4737 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4737 | 0;
    var $4738$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4737 + 4 | 0;
    var $4738$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5243 | 0;
    HEAP32[$st$6$0 >> 2] = $4738$0;
    var $st$6$1 = $5243 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4738$1;
    var $4739 = __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($5177, $lval393, $5244, $id395);
    if (($4739 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 962;
      break;
    }
   case 962:
    var $4742 = HEAP32[$obj394 >> 2];
    var $4743 = HEAP32[$id395 >> 2];
    var $4744 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($4742, $cx, $4743, $rval396);
    if (($4744 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 963;
      break;
    }
   case 963:
    var $st$1$0 = $5245 | 0;
    var $4748$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5245 + 4 | 0;
    var $4748$1 = HEAP32[$st$1$1 >> 2];
    var $4749 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $4749 | 0;
    HEAP32[$st$6$0 >> 2] = $4748$0;
    var $st$6$1 = $4749 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4748$1;
    if (($op_0 | 0) == 199) {
      __label__ = 964;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 1;
      __label__ = 19;
      break;
    }
   case 964:
    var $4752 = __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $4742, $rval396, $v397);
    if ($4752) {
      __label__ = 965;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 965:
    var $4754 = HEAP32[$_pre_phi80 >> 2];
    var $4755 = $4754 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4755;
    var $st$3$0 = $5246 | 0;
    var $4756$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5246 + 4 | 0;
    var $4756$1 = HEAP32[$st$3$1 >> 2];
    var $4757 = $4754 | 0;
    var $st$8$0 = $4757 | 0;
    HEAP32[$st$8$0 >> 2] = $4756$0;
    var $st$8$1 = $4757 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4756$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 966:
    var $4759 = HEAP32[$_pre_phi80 >> 2];
    var $4760 = $4759 - 16 | 0;
    var $4761 = __ZNK2JS5Value8isObjectEv($4760);
    if ($4761) {
      __label__ = 967;
      break;
    } else {
      __label__ = 968;
      break;
    }
   case 967:
    var $4763 = __ZNK2JS5Value8toObjectEv($4760);
    var $obj398_0 = $4763;
    var $4770 = $4759;
    __label__ = 970;
    break;
   case 968:
    var $4765 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($5173, $4760);
    var $4766 = $4765;
    if (($4765 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 969;
      break;
    }
   case 969:
    __ZN2JS5Value9setObjectER8JSObject($4760, $4766);
    var $obj398_0 = $4766;
    var $4770 = HEAP32[$_pre_phi80 >> 2];
    __label__ = 970;
    break;
   case 970:
    var $4770;
    var $obj398_0;
    var $4771 = $4770 - 8 | 0;
    var $st$3$0 = $4771 | 0;
    var $4772$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $4771 + 4 | 0;
    var $4772$1 = HEAP32[$st$3$1 >> 2];
    var $st$7$0 = $5247 | 0;
    HEAP32[$st$7$0 >> 2] = $4772$0;
    var $st$7$1 = $5247 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $4772$1;
    var $st$11$0 = $5248 | 0;
    HEAP32[$st$11$0 >> 2] = $4772$0;
    var $st$11$1 = $5248 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $4772$1;
    var $4774 = __Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_($5177, $obj398_0, $21, $rval400);
    if (($4774 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 971;
      break;
    }
   case 971:
    if (($op_0 | 0) == 186) {
      __label__ = 973;
      break;
    } else {
      __label__ = 972;
      break;
    }
   case 972:
    var $st$0$0 = $5247 | 0;
    var $st$0$1 = $5247 + 4 | 0;
    var $4787$1 = HEAP32[$st$0$1 >> 2];
    var $4787$0 = HEAP32[$st$0$0 >> 2];
    __label__ = 974;
    break;
   case 973:
    var $st$1$0 = $5247 | 0;
    var $4780$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5247 + 4 | 0;
    var $4780$1 = HEAP32[$st$1$1 >> 2];
    var $4781 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$6$0 = $4781 | 0;
    HEAP32[$st$6$0 >> 2] = $4780$0;
    var $st$6$1 = $4781 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4780$1;
    var $4782 = _JSVAL_TO_OBJECT1847($4780$0, $4780$1);
    var $4783 = $4782;
    var $4784 = __Z24js_DeleteXMLListElementsP9JSContextP8JSObject(undef, $4783);
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$14$0 = $$emscripten$temp$0 | 0;
    var $4785$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $$emscripten$temp$0 + 4 | 0;
    var $4785$1 = HEAP32[$st$14$1 >> 2];
    var $st$18$0 = $5247 | 0;
    HEAP32[$st$18$0 >> 2] = $4785$0;
    var $st$18$1 = $5247 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $4785$1;
    var $4787$1 = $4785$1;
    var $4787$0 = $4785$0;
    __label__ = 974;
    break;
   case 974:
    var $4787$0;
    var $4787$1;
    var $4788 = HEAP32[$_pre_phi80 >> 2];
    var $4789 = $4788 - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4789;
    var $4790 = $4788 - 16 | 0;
    var $st$6$0 = $4790 | 0;
    HEAP32[$st$6$0 >> 2] = $4787$0;
    var $st$6$1 = $4790 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4787$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 975:
    var $4792 = HEAP32[$_pre_phi80 >> 2];
    var $4793 = $4792 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4793;
    __ZN2JS5Value8setMagicE10JSWhyMagic($4792, 0);
    var $4794 = HEAPU32[$_pre_phi >> 2];
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = ((HEAPU8[$4794 + 1 | 0] & 255) << 8 | HEAPU8[$4794 + 2 | 0] & 255) << 16 >> 16;
    __label__ = 19;
    break;
   case 976:
    var $4806 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4807 = __ZNK2JS5Value7isMagicEv($4806);
    if ($4807) {
      __label__ = 978;
      break;
    } else {
      __label__ = 977;
      break;
    }
   case 977:
    __ZL9LeaveWithP9JSContext($cx);
    __label__ = 978;
    break;
   case 978:
    var $4811 = $4807 & 1 ^ 1;
    var $4812 = __Z20js_StepXMLListFilterP9JSContexti($5177, $4811);
    if (($4812 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 979;
      break;
    }
   case 979:
    var $4816 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $4817 = __ZNK2JS5Value6isNullEv($4816);
    if ($4817) {
      __label__ = 982;
      break;
    } else {
      __label__ = 980;
      break;
    }
   case 980:
    var $4819 = __ZL9EnterWithP9JSContexti4JSOpj($cx, -2, 3);
    if ($4819) {
      __label__ = 981;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 981:
    var $4822 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4822;
    var $4823 = HEAPU32[$_pre_phi >> 2];
    var $4831 = (HEAPU8[$4823 + 1 | 0] & 255) << 8 | HEAPU8[$4823 + 2 | 0] & 255;
    var $4833 = $4823 + ($4831 << 16 >> 16) | 0;
    HEAP32[$_pre_phi >> 2] = $4833;
    var $4835 = HEAPU8[$4833] & 255;
    if ($4831 << 16 >> 16 < 1) {
      var $op_1 = $4835;
      __label__ = 35;
      break;
    } else {
      var $_2 = $_2;
      var $script_1 = $script_1;
      var $pcCounts_1 = $pcCounts_1;
      var $argv_1 = $argv_1;
      var $atoms_1 = $atoms_1;
      var $op_0 = $4835;
      __label__ = 20;
      break;
    }
   case 982:
    HEAP32[$_pre_phi80 >> 2] = $4816;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 983:
    var $4840 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4840 | 0;
    var $4841$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4840 + 4 | 0;
    var $4841$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5249 | 0;
    HEAP32[$st$6$0 >> 2] = $4841$0;
    var $st$6$1 = $5249 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4841$1;
    var $4842 = __Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE($5177, $rval402);
    if (($4842 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 984;
      break;
    }
   case 984:
    var $4845 = $4842;
    var $4847 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4847, $4845);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 985:
    var $4850 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4850 | 0;
    var $4851$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4850 + 4 | 0;
    var $4851$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5250 | 0;
    HEAP32[$st$6$0 >> 2] = $4851$0;
    var $st$6$1 = $5250 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4851$1;
    var $4852 = __Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE($5177, $rval404);
    if (($4852 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 986;
      break;
    }
   case 986:
    var $4855 = $4852;
    var $4857 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4857, $4855);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 987:
    var $4860 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4860 | 0;
    var $4861$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4860 + 4 | 0;
    var $4861$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5251 | 0;
    HEAP32[$st$6$0 >> 2] = $4861$0;
    var $st$6$1 = $5251 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4861$1;
    var $4862 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5170, $rval406);
    if (($4862 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 988;
      break;
    }
   case 988:
    var $4866 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4866, $4862);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 989:
    var $4869 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$2$0 = $4869 | 0;
    var $4870$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $4869 + 4 | 0;
    var $4870$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $5252 | 0;
    HEAP32[$st$6$0 >> 2] = $4870$0;
    var $st$6$1 = $5252 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $4870$1;
    var $4871 = __ZL5IsXMLRKN2JS5ValueE($rval408);
    if ($4871) {
      __label__ = 990;
      break;
    } else {
      __label__ = 991;
      break;
    }
   case 990:
    var $4873 = __Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE($5177, $rval408);
    var $str409_0 = $4873;
    __label__ = 993;
    break;
   case 991:
    var $4875 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($5170, $rval408);
    if (($4875 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 992;
      break;
    }
   case 992:
    var $4878 = __Z21js_EscapeElementValueP9JSContextP8JSString($5177, $4875);
    var $str409_0 = $4878 | 0;
    __label__ = 993;
    break;
   case 993:
    var $str409_0;
    if (($str409_0 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 994;
      break;
    }
   case 994:
    var $4884 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setStringEP8JSString($4884, $str409_0);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 995:
    var $4886 = HEAPU32[$_pre_phi >> 2];
    var $4897 = HEAP32[$atoms_1 + (((HEAPU8[$4886 + 1 | 0] & 255) << 8 | HEAPU8[$4886 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4898 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5177, 4, 0, $4897);
    if (($4898 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 996;
      break;
    }
   case 996:
    var $4901 = $4898;
    var $4902 = HEAP32[$_pre_phi80 >> 2];
    var $4903 = $4902 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4903;
    __ZN2JS5Value9setObjectER8JSObject($4902, $4901);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 997:
    var $4905 = HEAPU32[$_pre_phi >> 2];
    var $4916 = HEAP32[$atoms_1 + (((HEAPU8[$4905 + 1 | 0] & 255) << 8 | HEAPU8[$4905 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4917 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5177, 5, 0, $4916);
    if (($4917 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 998;
      break;
    }
   case 998:
    var $4920 = $4917;
    var $4921 = HEAP32[$_pre_phi80 >> 2];
    var $4922 = $4921 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4922;
    __ZN2JS5Value9setObjectER8JSObject($4921, $4920);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 999:
    var $4924 = HEAPU32[$_pre_phi >> 2];
    var $4935 = HEAP32[$atoms_1 + (((HEAPU8[$4924 + 1 | 0] & 255) << 8 | HEAPU8[$4924 + 2 | 0] & 255) << 2) >> 2] | 0;
    var $4937 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $st$14$0 = $4937 | 0;
    var $4938$0 = HEAP32[$st$14$0 >> 2];
    var $st$14$1 = $4937 + 4 | 0;
    var $4938$1 = HEAP32[$st$14$1 >> 2];
    var $st$18$0 = $5253 | 0;
    HEAP32[$st$18$0 >> 2] = $4938$0;
    var $st$18$1 = $5253 + 4 | 0;
    HEAP32[$st$18$1 >> 2] = $4938$1;
    var $4939 = __ZNK2JS5Value8toStringEv($rval418);
    var $4940 = __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($5177, 3, $4935, $4939);
    if (($4940 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1e3;
      break;
    }
   case 1e3:
    var $4943 = $4940;
    var $4945 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    __ZN2JS5Value9setObjectER8JSObject($4945, $4943);
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 1001:
    var $4947 = __ZNK9JSContext2fpEv($cx);
    var $4948 = __ZNK2js10StackFrame10scopeChainEv($4947);
    var $4949 = $4948;
    var $4950 = __ZNK8JSObject9getGlobalEv($4949);
    var $4951 = $4950;
    var $4952 = __ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE($4951, $5177, $rval421);
    if ($4952) {
      __label__ = 1002;
      break;
    } else {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    }
   case 1002:
    var $4954 = HEAP32[$_pre_phi80 >> 2];
    var $4955 = $4954 + 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $4955;
    var $st$3$0 = $5254 | 0;
    var $4956$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $5254 + 4 | 0;
    var $4956$1 = HEAP32[$st$3$1 >> 2];
    var $4957 = $4954 | 0;
    var $st$8$0 = $4957 | 0;
    HEAP32[$st$8$0 >> 2] = $4956$0;
    var $st$8$1 = $4957 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $4956$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 1;
    __label__ = 19;
    break;
   case 1003:
    var $4965 = HEAPU32[$_pre_phi >> 2];
    var $4974 = ((HEAPU8[$4965 + 1 | 0] & 255) << 8 | HEAPU8[$4965 + 2 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $4975 = __ZN8JSScript9getObjectEj($script_1, $4974);
    var $4976 = HEAP32[$_pre_phi80 >> 2];
    var $4977 = $4975;
    var $4978 = __ZNK8JSObject13propertyCountEv($4977);
    var $4979 = $4976 + ($4978 << 3) | 0;
    var $4980 = HEAP32[$_pre_phi80 >> 2];
    __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848($4980, $4979);
    HEAP32[$_pre_phi80 >> 2] = $4979;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 1004:
    var $4987 = HEAPU32[$_pre_phi >> 2];
    var $4996 = ((HEAPU8[$4987 + 3 | 0] & 255) << 8 | HEAPU8[$4987 + 4 | 0] & 255) + ($atoms_1 - HEAP32[$script_1 + 56 >> 2] >> 2) | 0;
    var $4997 = __ZN8JSScript9getObjectEj($script_1, $4996);
    var $4998 = __ZNK2js9FrameRegs2fpEv($regs);
    var $4999 = __ZNK2js10StackFrame10scopeChainEv($4998);
    var $5000 = __ZNK8JSObject8getProtoEv($4999);
    if (($5000 | 0) == ($4997 | 0)) {
      __label__ = 1005;
      break;
    } else {
      __label__ = 1006;
      break;
    }
   case 1005:
    var $5003 = __Z17js_PutBlockObjectP9JSContexti($5173, 1);
    if (($5003 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1006;
      break;
    }
   case 1006:
    var $5005 = ($op_0 | 0) == 210;
    var $5006 = HEAPU32[$_pre_phi80 >> 2];
    var $vp425_0 = $5005 ? $5006 - 8 | 0 : 0;
    var $5007 = HEAPU32[$_pre_phi >> 2];
    var $5015 = (HEAPU8[$5007 + 1 | 0] & 255) << 8 | HEAPU8[$5007 + 2 | 0] & 255;
    HEAP32[$_pre_phi80 >> 2] = $5006 + (-$5015 << 3) | 0;
    if ($5005) {
      __label__ = 1007;
      break;
    } else {
      var $_1 = $_2;
      var $script_0 = $script_1;
      var $pcCounts_0 = $pcCounts_1;
      var $argv_0 = $argv_1;
      var $atoms_0 = $atoms_1;
      var $len_0 = 5;
      __label__ = 19;
      break;
    }
   case 1007:
    var $st$1$0 = $vp425_0 | 0;
    var $5019$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $vp425_0 + 4 | 0;
    var $5019$1 = HEAP32[$st$1$1 >> 2];
    var $5020 = $5006 + (($5015 ^ -1) << 3) | 0;
    var $st$6$0 = $5020 | 0;
    HEAP32[$st$6$0 >> 2] = $5019$0;
    var $st$6$1 = $5020 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $5019$1;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 5;
    __label__ = 19;
    break;
   case 1008:
    var $5023 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $5023;
    var $5024 = __Z15js_NewGeneratorP9JSContext($5178);
    if (($5024 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1009;
      break;
    }
   case 1009:
    var $5027 = $5024;
    var $5028 = __ZNK2js9FrameRegs2fpEv($regs);
    __ZN2JSL11ObjectValueER8JSObject1804($22, $5027);
    var $5029 = $5028;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($5029, $22);
    var $5030 = __ZNK2js9FrameRegs2fpEv($regs);
    if (($_08 | 0) == ($5030 | 0)) {
      var $interpReturnOK_2 = 1;
      __label__ = 1047;
      break;
    } else {
      var $_3 = $_2;
      var $interpReturnOK_0 = 1;
      __label__ = 50;
      break;
    }
   case 1010:
    var $5033 = __ZNK2js9FrameRegs2fpEv($regs);
    var $5034 = __ZNK9JSContext12generatorForEPN2js10StackFrameE($cx, $5033);
    if ((HEAP32[$5034 + 4 >> 2] | 0) == 3) {
      __label__ = 1011;
      break;
    } else {
      __label__ = 1012;
      break;
    }
   case 1011:
    var $5040 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 214, 1, $argv_1 - 16 | 0, 0, 0, 0);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 1012:
    var $5043 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $5044 = $5033;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($5044, $5043);
    var $5045 = __ZNK2js9FrameRegs2fpEv($regs);
    __ZN2js10StackFrame11setYieldingEv($5045);
    var $5047 = HEAP32[$_pre_phi >> 2] + 1 | 0;
    HEAP32[$_pre_phi >> 2] = $5047;
    var $interpReturnOK_2 = 1;
    __label__ = 1047;
    break;
   case 1013:
    var $5049 = HEAPU32[$_pre_phi >> 2];
    var $5057 = (HEAPU8[$5049 + 1 | 0] & 255) << 8 | HEAPU8[$5049 + 2 | 0] & 255;
    var $5058 = __ZNK2js9FrameRegs2fpEv($regs);
    var $5059 = $5058;
    var $5060 = __ZNK2js10StackFrame5slotsEv($5059);
    var $5061 = $5060 + ($5057 << 3) | 0;
    var $5062 = __ZNK2JS5Value8toObjectEv($5061);
    var $5064 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    var $5065 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($cx, $5062, $5064);
    if (($5065 | 0) == 0) {
      var $_4_ph1348 = $_2;
      var $script_2_ph1347 = $script_1;
      var $pcCounts_2_ph1346 = $pcCounts_1;
      var $argv_2_ph1345 = $argv_1;
      __label__ = 1016;
      break;
    } else {
      __label__ = 1014;
      break;
    }
   case 1014:
    var $5069 = HEAP32[$_pre_phi80 >> 2] - 8 | 0;
    HEAP32[$_pre_phi80 >> 2] = $5069;
    var $_1 = $_2;
    var $script_0 = $script_1;
    var $pcCounts_0 = $pcCounts_1;
    var $argv_0 = $argv_1;
    var $atoms_0 = $atoms_1;
    var $len_0 = 3;
    __label__ = 19;
    break;
   case 1015:
    var $5071 = $numBuf429 | 0;
    var $5072 = _JS_snprintf($5071, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $op_0, tempInt));
    _JS_ReportErrorNumber($cx, 2, 0, 32, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $5071, tempInt));
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   case 1016:
    var $argv_2_ph1345;
    var $pcCounts_2_ph1346;
    var $script_2_ph1347;
    var $_4_ph1348;
    var $5073 = $script_2_ph1347 + 56 | 0;
    var $5074 = $cx + 56 | 0;
    var $5075 = $script_2_ph1347 + 19 | 0;
    var $5076 = $regs + 4 | 0;
    var $5077 = $regs | 0;
    var $5078 = $cx;
    var $5079 = $v435 | 0;
    var $5080 = $26 | 0;
    var $5081 = $rval432 | 0;
    var $5082 = $23 | 0;
    __label__ = 1017;
    break;
   case 1017:
    var $5083 = __ZN9JSContext18isExceptionPendingEv($cx);
    if ($5083) {
      __label__ = 1018;
      break;
    } else {
      var $_5 = $_4_ph1348;
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1018:
    var $5085 = HEAP32[$5073 >> 2];
    if ((HEAP32[HEAP32[$46 >> 2] + 56 >> 2] | 0) == 0) {
      __label__ = 1019;
      break;
    } else {
      __label__ = 1020;
      break;
    }
   case 1019:
    var $5091 = HEAP32[$5074 >> 2];
    var $5092 = __ZN13JSCompartment12getDebuggeesEv($5091);
    var $5093 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($5092);
    if ($5093) {
      __label__ = 1029;
      break;
    } else {
      __label__ = 1020;
      break;
    }
   case 1020:
    var $5095 = __ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE($cx, $rval432);
    if (($5095 | 0) == 1) {
      __label__ = 1021;
      break;
    } else {
      var $st433_0 = $5095;
      __label__ = 1023;
      break;
    }
   case 1021:
    var $5098 = HEAP32[$46 >> 2];
    var $5100 = HEAP32[$5098 + 56 >> 2];
    if (($5100 | 0) == 0) {
      __label__ = 1027;
      break;
    } else {
      __label__ = 1022;
      break;
    }
   case 1022:
    var $5103 = HEAP32[$5076 >> 2];
    var $5105 = HEAP32[$5098 + 60 >> 2];
    var $5106 = FUNCTION_TABLE[$5100]($cx, $script_2_ph1347, $5103, $rval432, $5105);
    var $st433_0 = $5106;
    __label__ = 1023;
    break;
   case 1023:
    var $st433_0;
    if (($st433_0 | 0) == 0) {
      __label__ = 1024;
      break;
    } else if (($st433_0 | 0) == 2) {
      __label__ = 1025;
      break;
    } else if (($st433_0 | 0) == 3) {
      __label__ = 1026;
      break;
    } else {
      __label__ = 1027;
      break;
    }
   case 1024:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    __label__ = 1017;
    break;
   case 1025:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $5110 = __ZNK2js9FrameRegs2fpEv($regs);
    var $5111 = $5110;
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($5111, $rval432);
    var $_5 = $_4_ph1348;
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 1026:
    var $st$0$0 = $5081 | 0;
    var $5113$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5081 + 4 | 0;
    var $5113$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $5082 | 0;
    HEAP32[$st$4$0 >> 2] = $5113$0;
    var $st$4$1 = $5082 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $5113$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $23);
    __label__ = 1027;
    break;
   case 1027:
    if ((HEAP32[HEAP32[$46 >> 2] >> 2] | 0) == 0) {
      __label__ = 1029;
      break;
    } else {
      __label__ = 1028;
      break;
    }
   case 1028:
    __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($interruptEnabler);
    __label__ = 1029;
    break;
   case 1029:
    var $5120 = HEAP8[$5075];
    var $5121 = __ZN8JSScript13isValidOffsetEh($5120);
    if ($5121) {
      __label__ = 1030;
      break;
    } else {
      __label__ = 1041;
      break;
    }
   case 1030:
    var $5123 = HEAP32[$5076 >> 2];
    var $5124 = __ZN8JSScript4mainEv($script_2_ph1347);
    var $5125 = $5123;
    var $5126 = $5124;
    var $5127 = __ZN8JSScript8trynotesEv($script_2_ph1347);
    var $5129 = HEAP32[$5127 >> 2];
    var $5132 = $5129 + HEAP32[$5127 + 4 >> 2] * 12 | 0;
    var $5133 = $5125 - $5126 | 0;
    var $tn_0 = $5129;
    __label__ = 1031;
    break;
   case 1031:
    var $tn_0;
    var $5136 = HEAPU32[$tn_0 + 4 >> 2];
    var $5139 = HEAPU32[$tn_0 + 8 >> 2];
    if (($5133 - $5136 | 0) >>> 0 < $5139 >>> 0) {
      __label__ = 1032;
      break;
    } else {
      __label__ = 1040;
      break;
    }
   case 1032:
    var $5142 = $tn_0 + 2 | 0;
    var $5144 = HEAPU16[$5142 >> 1] & 65535;
    var $5145 = HEAP32[$5077 >> 2];
    var $5146 = __ZNK2js9FrameRegs2fpEv($regs);
    var $5147 = $5146;
    var $5148 = __ZNK2js10StackFrame4baseEv($5147);
    if (($5144 | 0) > ($5145 - $5148 >> 3 | 0)) {
      __label__ = 1040;
      break;
    } else {
      __label__ = 1033;
      break;
    }
   case 1033:
    var $5155 = __ZN8JSScript4mainEv($script_2_ph1347);
    HEAP32[$5076 >> 2] = $5155 + ($5139 + $5136) | 0;
    var $5158 = HEAPU16[$5142 >> 1] & 65535;
    var $5159 = __ZN2js11UnwindScopeEP9JSContextii($cx, $5158, 1);
    if ($5159) {
      __label__ = 1034;
      break;
    } else {
      __label__ = 1017;
      break;
    }
   case 1034:
    var $5163 = HEAPU8[$tn_0 | 0] & 255;
    if (($5163 | 0) == 0) {
      __label__ = 1035;
      break;
    } else if (($5163 | 0) == 1) {
      __label__ = 1037;
      break;
    } else if (($5163 | 0) == 2) {
      __label__ = 1038;
      break;
    } else {
      __label__ = 1040;
      break;
    }
   case 1035:
    __ZN9JSContext19getPendingExceptionEv($24, $cx);
    var $5165 = __ZNK2JS5Value7isMagicE10JSWhyMagic($24, undef);
    if ($5165) {
      __label__ = 1040;
      break;
    } else {
      var $_1_ph = $_4_ph1348;
      var $script_0_ph = $script_2_ph1347;
      var $pcCounts_0_ph = $pcCounts_2_ph1346;
      var $argv_0_ph = $argv_2_ph1345;
      var $atoms_0_ph = $5085;
      var $len_0_ph1296 = 0;
      var $_pre_phi = $5076;
      var $_pre_phi80 = $5077;
      __label__ = 1036;
      break;
    }
   case 1036:
    var $_pre_phi80;
    var $_pre_phi;
    var $len_0_ph1296;
    var $atoms_0_ph;
    var $argv_0_ph;
    var $pcCounts_0_ph;
    var $script_0_ph;
    var $_1_ph;
    var $5166 = $rval35 | 0;
    var $5167 = $lval36 | 0;
    var $5168 = $rval39 | 0;
    var $5169 = $lval40 | 0;
    var $5170 = $cx;
    var $5171 = $rval187 | 0;
    var $5172 = $33 + 44 | 0;
    var $5173 = $cx;
    var $5174 = $rval215 | 0;
    var $5175 = $args225 | 0;
    var $5176 = $cx + 60 | 0;
    var $5177 = $cx;
    var $5178 = $cx;
    var $5179 = $rval96 | 0;
    var $5180 = $lval97 | 0;
    var $5181 = $rval102 | 0;
    var $5182 = $lval103 | 0;
    var $5183 = $rval104 | 0;
    var $5184 = $lval105 | 0;
    var $5185 = $rval109 | 0;
    var $5186 = $lval110 | 0;
    var $5187 = $ref122 | 0;
    var $5188 = $obj127;
    var $5189 = $prop129;
    var $5190 = $rval134 | 0;
    var $5191 = $2 | 0;
    var $5192 = $obj147;
    var $5193 = $obj2154;
    var $5194 = $prop157;
    var $5195 = $cx;
    var $5196 = $4 | 0;
    var $5197 = $rval168 | 0;
    var $5198 = $5 | 0;
    var $5199 = $6 | 0;
    var $5200 = $7 | 0;
    var $5201 = $8 | 0;
    var $5202 = $lval178 | 0;
    var $5203 = $objv | 0;
    var $5204 = $rval180 | 0;
    var $5205 = $pobj;
    var $5206 = $thisv206 | 0;
    var $5207 = $rval224 | 0;
    var $5208 = $args | 0;
    var $5209 = $v | 0;
    var $5210 = $rval229 | 0;
    var $5211 = $obj226;
    var $5212 = $obj2231;
    var $5213 = $prop235;
    var $5214 = $v236 | 0;
    var $5215 = $proto;
    var $5216 = $lval251 | 0;
    var $5217 = $rval253 | 0;
    var $5218 = $rval254 | 0;
    var $5219 = $rval255 | 0;
    var $5220 = $10 | 0;
    var $5221 = $rval258 | 0;
    var $5222 = $rval260 | 0;
    var $5223 = $33 + 210256 | 0;
    var $5224 = $rval262 | 0;
    var $5225 = $rval326 | 0;
    var $5226 = $rval349 | 0;
    var $5227 = $rval355 | 0;
    var $5228 = $rval358 | 0;
    var $5229 = $lval359 | 0;
    var $5230 = $15 | 0;
    var $_021 = $16 | 0;
    var $5231 = $19 | 0;
    var $5232 = $lval373 | 0;
    var $5233 = $rval375 | 0;
    var $5234 = $lval376 | 0;
    var $5235 = $rval378 | 0;
    var $5236 = $rval379 | 0;
    var $5237 = $rval381 | 0;
    var $5238 = $lval382 | 0;
    var $5239 = $lval385 | 0;
    var $5240 = $obj386;
    var $5241 = $20 | 0;
    var $5242 = $rval389 | 0;
    var $5243 = $lval393 | 0;
    var $5244 = $obj394;
    var $5245 = $rval396 | 0;
    var $5246 = $v397 | 0;
    var $5247 = $rval400 | 0;
    var $5248 = $21 | 0;
    var $5249 = $rval402 | 0;
    var $5250 = $rval404 | 0;
    var $5251 = $rval406 | 0;
    var $5252 = $rval408 | 0;
    var $5253 = $rval418 | 0;
    var $5254 = $rval421 | 0;
    var $5255 = $rval309 | 0;
    var $_1 = $_1_ph;
    var $script_0 = $script_0_ph;
    var $pcCounts_0 = $pcCounts_0_ph;
    var $argv_0 = $argv_0_ph;
    var $atoms_0 = $atoms_0_ph;
    var $len_0 = $len_0_ph1296;
    __label__ = 19;
    break;
   case 1037:
    var $5257 = HEAP32[$5077 >> 2];
    var $5258 = $5257 + 8 | 0;
    HEAP32[$5077 >> 2] = $5258;
    __ZN2JS5Value10setBooleanEb($5257, 1);
    var $5259 = HEAP32[$5077 >> 2];
    var $5260 = $5259 + 8 | 0;
    HEAP32[$5077 >> 2] = $5260;
    __ZN9JSContext19getPendingExceptionEv($25, $cx);
    var $5261 = $25 | 0;
    var $st$9$0 = $5261 | 0;
    var $5262$0 = HEAP32[$st$9$0 >> 2];
    var $st$9$1 = $5261 + 4 | 0;
    var $5262$1 = HEAP32[$st$9$1 >> 2];
    var $5263 = $5259 | 0;
    var $st$14$0 = $5263 | 0;
    HEAP32[$st$14$0 >> 2] = $5262$0;
    var $st$14$1 = $5263 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $5262$1;
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $_1_ph = $_4_ph1348;
    var $script_0_ph = $script_2_ph1347;
    var $pcCounts_0_ph = $pcCounts_2_ph1346;
    var $argv_0_ph = $argv_2_ph1345;
    var $atoms_0_ph = $5085;
    var $len_0_ph1296 = 0;
    var $_pre_phi = $5076;
    var $_pre_phi80 = $5077;
    __label__ = 1036;
    break;
   case 1038:
    __ZN9JSContext19getPendingExceptionEv($v435, $cx);
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $5266 = HEAP32[$5077 >> 2] - 8 | 0;
    var $5267 = __ZNK2JS5Value8toObjectEv($5266);
    var $5268 = $5267;
    var $5269 = __Z16js_CloseIteratorP9JSContextP8JSObject($5078, $5268);
    var $5271 = HEAP32[$5077 >> 2] - 8 | 0;
    HEAP32[$5077 >> 2] = $5271;
    if (($5269 | 0) == 0) {
      __label__ = 1017;
      break;
    } else {
      __label__ = 1039;
      break;
    }
   case 1039:
    var $st$0$0 = $5079 | 0;
    var $5274$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5079 + 4 | 0;
    var $5274$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $5080 | 0;
    HEAP32[$st$4$0 >> 2] = $5274$0;
    var $st$4$1 = $5080 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $5274$1;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($cx, $26);
    __label__ = 1040;
    break;
   case 1040:
    var $5276 = $tn_0 + 12 | 0;
    if (($5276 | 0) == ($5132 | 0)) {
      __label__ = 1041;
      break;
    } else {
      var $tn_0 = $5276;
      __label__ = 1031;
      break;
    }
   case 1041:
    var $5278 = __ZN9JSContext18isExceptionPendingEv($cx);
    if ($5278) {
      __label__ = 1042;
      break;
    } else {
      var $_5 = $_4_ph1348;
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1042:
    __ZN9JSContext19getPendingExceptionEv($27, $cx);
    var $5280 = __ZNK2JS5Value7isMagicE10JSWhyMagic($27, undef);
    if ($5280) {
      __label__ = 1043;
      break;
    } else {
      var $_5 = $_4_ph1348;
      var $interpReturnOK_1 = 0;
      __label__ = 1044;
      break;
    }
   case 1043:
    __ZN9JSContext21clearPendingExceptionEv($cx);
    var $5282 = __ZNK2js9FrameRegs2fpEv($regs);
    __ZN2js10StackFrame16clearReturnValueEv($5282);
    var $_5 = $_4_ph1348;
    var $interpReturnOK_1 = 1;
    __label__ = 1044;
    break;
   case 1044:
    var $interpReturnOK_1;
    var $_5;
    if (($interpReturnOK_1 | 0) == 0) {
      __label__ = 1045;
      break;
    } else {
      var $5287 = 1;
      __label__ = 1046;
      break;
    }
   case 1045:
    var $5285 = __ZN9JSContext18isExceptionPendingEv($cx);
    var $5287 = $5285;
    __label__ = 1046;
    break;
   case 1046:
    var $5287;
    var $5289 = __ZN2js11UnwindScopeEP9JSContextii($cx, 0, $5287 & 1);
    var $5291 = $5289 & 1 & $interpReturnOK_1;
    var $5292 = __ZNK2js9FrameRegs2fpEv($regs);
    if (($_08 | 0) == ($5292 | 0)) {
      var $interpReturnOK_2 = $5291;
      __label__ = 1047;
      break;
    } else {
      var $_3 = $_5;
      var $interpReturnOK_0 = $5291;
      __label__ = 50;
      break;
    }
   case 1047:
    var $interpReturnOK_2;
    var $5295 = __ZNK2js9FrameRegs2fpEv($regs);
    var $5297 = __ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb($cx, $5295, ($interpReturnOK_2 | 0) != 0);
    var $5298 = __ZNK2js9FrameRegs2fpEv($regs);
    __ZN2js10StackFrame24setFinishedInInterpreterEv($5298);
    __ZN2js17InterpreterFramesD1Ev($interpreterFrame);
    __ZN2js17PreserveRegsGuardD1Ev($interpGuard);
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $5297;
   case 1048:
    var $atomNotDefined_0;
    __ZN16JSAutoByteStringC1Ev($printable);
    var $5300 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atomNotDefined_0, $printable);
    if (($5300 | 0) == 0) {
      __label__ = 1050;
      break;
    } else {
      __label__ = 1049;
      break;
    }
   case 1049:
    var $5303 = __ZNK16JSAutoByteString3ptrEv($printable);
    __Z21js_ReportIsNotDefinedP9JSContextPKc($cx, $5303);
    __label__ = 1050;
    break;
   case 1050:
    __ZN16JSAutoByteStringD1Ev($printable);
    var $_4_ph1348 = $_2;
    var $script_2_ph1347 = $script_1;
    var $pcCounts_2_ph1346 = $pcCounts_1;
    var $argv_2_ph1345 = $argv_1;
    __label__ = 1016;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE["X"] = 1;

function __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($initial) {
  return $initial & 128;
}

function __ZNK2JS5Value18payloadAsRawUint32Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK8JSScript7isEmptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 > 3) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    if ((HEAP8[$this + 36 | 0] & 1) << 24 >> 24 == 0) {
      var $pc_0 = $6;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP8[$6] << 24 >> 24 == 66) {
      __label__ = 4;
      break;
    } else {
      var $pc_0 = $6;
      __label__ = 5;
      break;
    }
   case 4:
    var $pc_0 = $6 + 1 | 0;
    __label__ = 5;
    break;
   case 5:
    var $pc_0;
    var $_0 = HEAP8[$pc_0] << 24 >> 24 == -59;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $argsRef, $construct) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $ifg = __stackBase__ + 8;
    var $preserve = __stackBase__ + 36;
    var $1 = $argsRef;
    var $2 = $args;
    var $3$0 = HEAP32[$1 >> 2];
    var $3$1 = HEAP32[$1 + 4 >> 2];
    HEAP32[$2 >> 2] = $3$0;
    HEAP32[$2 + 4 >> 2] = $3$1;
    var $4 = $args | 0;
    var $5 = __ZNK2js12CallReceiver7calleevEv($4);
    var $6 = __ZNK2JS5Value11isPrimitiveEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($construct);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $5, $8);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 3:
    var $10 = __ZNK2js12CallReceiver6calleeEv($4);
    var $11 = __ZNK8JSObject8getClassEv($10);
    if (($11 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($11 | 0) == (_js_NoSuchMethodClass | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZNK2js8CallArgs4argcEv($args);
    var $17 = __ZNK2js12CallReceiver4baseEv($4);
    var $18 = __ZL12NoSuchMethodP9JSContextjPN2JS5ValueE($cx, $16, $17);
    var $_1 = ($18 | 0) != 0;
    __label__ = 15;
    break;
   case 6:
    var $22 = HEAP32[$11 + 48 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = __ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE($construct);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $5, $25);
    var $_1 = 0;
    __label__ = 15;
    break;
   case 8:
    var $27 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $22, $args);
    var $_1 = $27;
    __label__ = 15;
    break;
   case 9:
    var $29 = __ZNK8JSObject18getFunctionPrivateEv($10);
    var $30 = $29;
    var $31 = __ZNK10JSFunction8isNativeEv($30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAP32[$29 + 60 >> 2];
    var $35 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $34, $args);
    var $_1 = $35;
    __label__ = 15;
    break;
   case 11:
    var $37 = ($construct | 0) != 0;
    __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args, $37);
    __ZN2js16InvokeFrameGuardC1Ev($ifg);
    var $39 = $cx + 60 | 0;
    var $40 = $cx;
    var $41 = $ifg;
    var $42 = __ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE($39, $40, $args, $construct, $41);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 12:
    var $44 = $ifg | 0;
    var $45 = __ZNK2js10FrameGuard2fpEv($44);
    var $46 = __ZN2js10StackFrame16functionPrologueEP9JSContext($45, $cx);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($preserve, $cx);
    var $48 = __ZNK10JSFunction6scriptEv($29);
    var $49 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $48, $45);
    __ZN2js23AutoPreserveEnumeratorsD1Ev($preserve);
    var $50 = __ZNK2js12CallReceiver4rvalEv($4);
    var $51 = $45;
    var $52 = __ZN2js10StackFrame11returnValueEv($51);
    var $53 = $52 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55 = $50 | 0;
    HEAP32[$55 >> 2] = $54$0;
    HEAP32[$55 + 4 >> 2] = $54$1;
    var $_0 = $49;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js16InvokeFrameGuardD1Ev($ifg);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE["X"] = 1;

function __ZL12NoSuchMethodP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, 2, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZNK2JS5Value8toObjectEv($vp);
    var $8 = $args | 0;
    var $9 = __ZNK2js12CallReceiver7calleevEv($8);
    var $10 = __ZNK8JSObject7getSlotEj($7, 0);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $9 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZNK2js12CallReceiver5thisvEv($8);
    var $15 = $vp + 8 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $14 | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = $args | 0;
    var $19 = __ZNK2js8CallArgsixEj($18, 0);
    var $20 = __ZNK8JSObject7getSlotEj($7, 1);
    var $21 = $20 | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $19 | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $24 = $vp + 16 | 0;
    var $25 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($cx, $argc, $24, 0);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $28 = __ZNK2js8CallArgsixEj($18, 1);
    __ZN2JS5Value9setObjectER8JSObject($28, $25);
    var $29 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    var $30 = $29 & 1;
    var $31 = __ZNK2js12CallReceiver4rvalEv($8);
    var $32 = $31 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = $30;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12NoSuchMethodP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args) {
  var $1 = __ZNK2js8CallArgs4argcEv($args);
  var $2 = $args | 0;
  var $3 = __ZNK2js12CallReceiver4baseEv($2);
  var $4 = FUNCTION_TABLE[$native]($cx, $1, $3);
  return ($4 | 0) != 0;
}

function __ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb($cx, $args, $constructing) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $args | 0;
    var $2 = __ZNK2js12CallReceiver6calleeEv($1);
    var $3 = __ZNK8JSObject10isFunctionEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($2);
    var $6 = __ZNK10JSFunction13isInterpretedEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $8 = __ZNK10JSFunction6scriptEv($5);
    var $9 = __ZNK8JSObject9getParentEv($2);
    var $10 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($8, $cx, $5, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb($cx, $2, $args, $constructing);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16InvokeFrameGuardC1Ev($this) {
  __ZN2js16InvokeFrameGuardC2Ev($this);
  return;
}

function __ZNK2js10FrameGuard2fpEv($this) {
  var $1 = $this + 8 | 0;
  var $2 = __ZNK2js9FrameRegs2fpEv($1);
  return $2;
}

function __ZN2js10StackFrame16functionPrologueEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame3funEv($this);
    var $2 = __ZNK10JSFunction13isHeavyweightEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE($cx, $this);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($this);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js10StackFrame6scriptEv($this);
    var $10 = $9;
    var $11 = __ZNK8JSScript7nestingEv($10);
    if (($11 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE($cx, $this);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($this, $cx) {
  __ZN2js23AutoPreserveEnumeratorsC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js23AutoPreserveEnumeratorsD1Ev($this) {
  __ZN2js23AutoPreserveEnumeratorsD2Ev($this);
  return;
}

function __ZN2js16InvokeFrameGuardD1Ev($this) {
  __ZN2js16InvokeFrameGuardD2Ev($this);
  return;
}

function __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $thisv, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $7 = $args | 0;
    var $8 = __ZNK2js12CallReceiver7calleevEv($7);
    var $9 = $fval | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZNK2js12CallReceiver5thisvEv($7);
    var $13 = $thisv | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $12 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = $args | 0;
    var $17 = __ZNK2js8CallArgs4argvEv($16);
    var $18 = $17;
    var $19 = $argv;
    var $20 = $argc << 3;
    _memcpy($18, $19, $20, 1);
    var $21 = __ZNK2js12CallReceiver5thisvEv($7);
    var $22 = __ZNK2JS5Value8isObjectEv($21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $24 = __ZNK2JS5Value8toObjectEv($21);
    var $25 = __ZN8JSObject10thisObjectEP9JSContext($24, $cx);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $28 = __ZNK2js12CallReceiver5thisvEv($7);
    __ZN2JS5Value9setObjectER8JSObject($28, $25);
    __label__ = 5;
    break;
   case 5:
    var $30 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 0);
    if ($30) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = __ZNK2js12CallReceiver4rvalEv($7);
    var $33 = $32 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $rval | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_["X"] = 1;

function __ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_($cx, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = $args | 0;
    var $8 = __ZNK2js12CallReceiver7calleevEv($7);
    var $9 = $fval | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $8 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZNK2js12CallReceiver5thisvEv($7);
    __ZN2JS5Value8setMagicE10JSWhyMagic($12, 6);
    var $13 = $args | 0;
    var $14 = __ZNK2js8CallArgs4argvEv($13);
    var $15 = $14;
    var $16 = $argv;
    var $17 = $argc << 3;
    _memcpy($15, $16, $17, 1);
    var $18 = __ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE($cx, $args);
    if ($18) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $20 = __ZNK2js12CallReceiver4rvalEv($7);
    var $21 = $20 | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $rval | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $obj, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1804($1, $obj);
    var $8 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject1804($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $script, $scopeChain, $thisv, $type, $evalInFrame, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $efg = __stackBase__;
    var $preserve = __stackBase__ + 28;
    var $1 = __ZNK8JSScript7isEmptyEv($script);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if (($result | 0) == 0) {
      var $_1 = 1;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($result);
    var $_1 = 1;
    __label__ = 16;
    break;
   case 4:
    __ZN2js17ExecuteFrameGuardC1Ev($efg);
    var $7 = $cx + 60 | 0;
    var $8 = $cx;
    var $9 = $script;
    var $10 = $scopeChain;
    var $11 = $evalInFrame;
    var $12 = $efg;
    var $13 = __ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE($7, $8, $9, $thisv, $10, $type, $11, $12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 5:
    var $15 = $efg | 0;
    var $16 = __ZNK2js10FrameGuard2fpEv($15);
    var $17 = __ZNK2js10StackFrame17isStrictEvalFrameEv($16);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE($cx, $16);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP8[$script + 36 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE($cx, $16);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 9:
    var $29 = __ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject($script, $cx, 0, $scopeChain);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 10:
    var $31 = __ZNK2js10StackFrame9thisValueEv($16);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE($cx, $script, $31);
    __ZN2js23AutoPreserveEnumeratorsC1EP9JSContext($preserve, $cx);
    var $32 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($cx, $script, $16);
    if (($result | 0) == 0 | $32 ^ 1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = $16;
    var $36 = __ZN2js10StackFrame11returnValueEv($35);
    var $37 = $36 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $result | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    __label__ = 12;
    break;
   case 12:
    var $41 = __ZNK2js10StackFrame17isStrictEvalFrameEv($16);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __Z16js_PutCallObjectPN2js10StackFrameE($16);
    __label__ = 14;
    break;
   case 14:
    __ZN2js23AutoPreserveEnumeratorsD1Ev($preserve);
    var $_0 = $32;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js17ExecuteFrameGuardD1Ev($efg);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_["X"] = 1;

function __ZN2js17ExecuteFrameGuardC1Ev($this) {
  __ZN2js17ExecuteFrameGuardC2Ev($this);
  return;
}

function __ZNK2js10StackFrame17isStrictEvalFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11isEvalFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6scriptEv($this);
    var $9 = (HEAP8[$3 + 36 | 0] & 8) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame4prevEv($fp);
    var $2 = __ZNK2js10StackFrame6scriptEv($fp);
    var $5 = HEAPU16[$2 + 14 >> 1] & 65535;
    var $6 = $5 - 2 | 0;
    var $7 = $fp;
    var $8 = __ZNK2js10StackFrame5slotsEv($7);
    var $9 = $8 + ($6 << 3) | 0;
    var $10 = __ZNK2js10StackFrame13isGlobalFrameEv($fp);
    if ($10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZNK2js10StackFrame6scriptEv($1);
    if ((HEAP8[$12 + 36 | 0] & 4) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($1);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZNK2js10StackFrame3funEv($1);
    var $21 = __ZNK10JSFunction6scriptEv($20);
    var $23 = $21 + 64 | 0;
    var $24 = $cx;
    var $25 = __ZN2js8Bindings13sharpSlotBaseEP9JSContext($23, $24);
    var $30 = $25;
    __label__ = 6;
    break;
   case 5:
    var $27 = __ZNK2js10StackFrame8numFixedEv($1);
    var $30 = $27 - 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $30;
    if (($30 | 0) < 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = $1;
    var $34 = __ZNK2js10StackFrame5slotsEv($33);
    var $35 = $34 + ($30 << 3) | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $9 | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $39 = $34 + ($30 + 1 << 3) | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $41 = $8 + ($5 - 1 << 3) | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JS5Value12setUndefinedEv($9);
    var $43 = $8 + ($5 - 1 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($43);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE["X"] = 1;

function __ZN2js17ExecuteFrameGuardD1Ev($this) {
  __ZN2js17ExecuteFrameGuardD2Ev($this);
  return;
}

function __ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE($cx, $script, $scopeChainArg, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scopeChain = __stackBase__;
    var $thisv = __stackBase__ + 4;
    HEAP32[$scopeChain >> 2] = $scopeChainArg;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $scopeChain);
    var $1 = HEAP32[$scopeChain >> 2];
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject8isNativeEv($1);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 266, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $7 = __ZNK9JSContext12hasRunOptionEj($cx, 4);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject10makeVarObjEv($1);
    __label__ = 6;
    break;
   case 6:
    var $10 = __ZN8JSObject10thisObjectEP9JSContext($1, $cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL11ObjectValueER8JSObject1804($thisv, $10);
    var $13 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($cx, $script, $1, $thisv, 1, 0, $rval);
    var $_0 = $13;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($cx, $obj, $id, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $oldAttrs = __stackBase__ + 8;
    var $value = __stackBase__ + 12;
    var $bytes = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    var $2 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($obj, $cx, $id, $obj2, $prop);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAPU32[$obj2 >> 2];
    var $9 = __ZNK8JSObject8isNativeEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $5;
    var $12 = __ZNK2js5Shape10attributesEv($11);
    var $13 = $12 & 255;
    HEAP32[$oldAttrs >> 2] = $13;
    var $18 = $13;
    __label__ = 7;
    break;
   case 5:
    var $15 = __ZN8JSObject13getAttributesEP9JSContextiPj($8, $cx, $id, $oldAttrs);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAP32[$oldAttrs >> 2];
    __label__ = 7;
    break;
   case 7:
    var $18;
    if ((($18 | $attrs) & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if (($attrs & 48 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((($18 ^ $attrs) & 48 | 0) == 48 | ($18 & 4 | 0) == 0) {
      var $_1 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = ($18 & 48 | 0) != 0;
    if ($33) {
      var $isFunction_0 = $33 & 1;
      var $42 = $18;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($obj, $cx, $id, $value);
    if (($36 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809($value);
    var $isFunction_0 = $39 & 1;
    var $42 = HEAP32[$oldAttrs >> 2];
    __label__ = 13;
    break;
   case 13:
    var $42;
    var $isFunction_0;
    var $43 = $42 & $attrs;
    if (($43 & 16 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $55 = STRING_TABLE._js_getter_str;
      __label__ = 17;
      break;
    }
   case 14:
    if (($43 & 32 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $55 = STRING_TABLE._js_setter_str;
      __label__ = 17;
      break;
    }
   case 15:
    if (($42 & 2 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $55 = STRING_TABLE._js_const_str;
      __label__ = 17;
      break;
    }
   case 16:
    var $_ = $isFunction_0 << 24 >> 24 != 0 ? STRING_TABLE._js_function_str : STRING_TABLE._js_var_str;
    var $55 = $_;
    __label__ = 17;
    break;
   case 17:
    var $55;
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi1799($1, $id);
    var $56 = $cx;
    var $57 = $bytes;
    var $58 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($56, $1, $57, 0);
    if (($58 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = _JS_ReportErrorFlagsAndNumber($cx, 0, 2, 0, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $55 | 0, HEAP32[tempInt + 4 >> 2] = $58, tempInt));
    __label__ = 19;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij["X"] = 1;

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject8getClassEv($obj);
    var $4 = HEAP32[$2 + 60 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = FUNCTION_TABLE[$4]($cx, $obj, $v, $bp);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1804($1, $obj);
    var $9 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, 1, $1, 0, 0, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lval, $rval, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lvalue = __stackBase__;
    var $rvalue = __stackBase__ + 8;
    var $l7 = __stackBase__ + 16;
    var $r8 = __stackBase__ + 24;
    var $1 = __ZNK2JS5Value8isObjectEv($lval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($lval);
    var $4 = __ZNK8JSObject5isXMLEv($3);
    if ($4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($rval);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($rval);
    var $9 = __ZNK8JSObject5isXMLEv($8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = $cx;
    var $12 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($11, $lval, $rval, $result);
    var $_0 = ($12 | 0) != 0;
    __label__ = 28;
    break;
   case 6:
    var $15 = __ZN2JS8SameTypeERKNS_5ValueES2_($lval, $rval);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value8isStringEv($lval);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = __ZNK2JS5Value8toStringEv($lval);
    var $20 = __ZNK2JS5Value8toStringEv($rval);
    var $21 = $cx;
    var $22 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($21, $19, $20, $result);
    var $_0 = $22;
    __label__ = 28;
    break;
   case 9:
    var $24 = __ZNK2JS5Value8isDoubleEv($lval);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = __ZNK2JS5Value8toDoubleEv($lval);
    var $27 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$result >> 2] = $26 == $27 & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 11:
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $32 = __ZNK2JS5Value8toObjectEv($lval);
    var $33 = __ZNK8JSObject8getClassEv($32);
    var $35 = HEAP32[$33 + 68 >> 2];
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = FUNCTION_TABLE[$35]($cx, $32, $rval, $result);
    var $_0 = ($38 | 0) != 0;
    __label__ = 28;
    break;
   case 14:
    var $41 = __ZNK2JS5Value8toObjectEv($rval);
    HEAP32[$result >> 2] = ($32 | 0) == ($41 | 0) & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 15:
    var $45 = __ZNK2JS5Value18payloadAsRawUint32Ev($lval);
    var $46 = __ZNK2JS5Value18payloadAsRawUint32Ev($rval);
    HEAP32[$result >> 2] = ($45 | 0) == ($46 | 0) & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 16:
    var $50 = __ZNK2JS5Value17isNullOrUndefinedEv($lval);
    var $51 = __ZNK2JS5Value17isNullOrUndefinedEv($rval);
    if ($50) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$result >> 2] = $51 & 1;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 18:
    if ($51) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 20:
    var $57 = $lval | 0;
    var $58$0 = HEAP32[$57 >> 2];
    var $58$1 = HEAP32[$57 + 4 >> 2];
    var $59 = $lvalue | 0;
    HEAP32[$59 >> 2] = $58$0;
    HEAP32[$59 + 4 >> 2] = $58$1;
    var $60 = $rval | 0;
    var $61$0 = HEAP32[$60 >> 2];
    var $61$1 = HEAP32[$60 + 4 >> 2];
    var $62 = $rvalue | 0;
    HEAP32[$62 >> 2] = $61$0;
    HEAP32[$62 + 4 >> 2] = $61$1;
    var $63 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $lvalue);
    if ($63) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 21:
    var $65 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $rvalue);
    if ($65) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 22:
    var $67 = __ZNK2JS5Value8isStringEv($lvalue);
    if ($67) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $69 = __ZNK2JS5Value8isStringEv($rvalue);
    if ($69) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $71 = __ZNK2JS5Value8toStringEv($lvalue);
    var $72 = __ZNK2JS5Value8toStringEv($rvalue);
    var $73 = $cx;
    var $74 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($73, $71, $72, $result);
    var $_0 = $74;
    __label__ = 28;
    break;
   case 25:
    var $76 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $lvalue, $l7);
    if ($76) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 26:
    var $78 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $rvalue, $r8);
    if ($78) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 27:
    var $80 = (tempDoubleI32[0] = HEAP32[$l7 >> 2], tempDoubleI32[1] = HEAP32[$l7 + 4 >> 2], tempDoubleF64[0]);
    var $81 = (tempDoubleI32[0] = HEAP32[$r8 >> 2], tempDoubleI32[1] = HEAP32[$r8 + 4 >> 2], tempDoubleF64[0]);
    var $83 = $80 == $81 & 1;
    HEAP32[$result >> 2] = $83;
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi["X"] = 1;

function __ZN2JS8SameTypeERKNS_5ValueES2_($lhs, $rhs) {
  var $1 = $lhs | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $rhs | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = _JSVAL_SAME_TYPE_IMPL($2$0, $2$1, $4$0, $4$1);
  return ($5 | 0) != 0;
}

function __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 0, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZeqRK8JSObjectS1_1816($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function _INT_FITS_IN_JSID1825($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _INT_TO_JSID1826($i) {
  return $i << 1 | 1;
}

function _OBJECT_TO_JSID1827($obj) {
  return $obj | 4;
}

function __ZNK10JSFunction13isConstructorEv($this) {
  return (HEAP16[$this + 58 >> 1] & 512) << 16 >> 16 != 0;
}

function __ZNK8JSObject7isXMLIdEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == (__ZN2js10QNameClassE | 0) | ($2 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = ($2 | 0) == (__ZN2js12AnyNameClassE | 0);
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject6isWithEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js9WithClassE | 0);
}

function __ZNK8JSObject7isBlockEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js10BlockClassE | 0);
}

function __ZN8JSScript15stepModeEnabledEv($this) {
  return (HEAP32[$this + 24 >> 2] | 0) != 0;
}

function __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this + 4 >> 2];
  HEAP32[$4 >> 2] = $2;
  return;
}

function __ZN12JSPCCounters3getEi($this, $runmode) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 + (HEAP32[$this >> 2] * $runmode << 3) | 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame18loweredCallOrApplyEv($this) {
  return (HEAP32[$this >> 2] & 4194304 | 0) != 0;
}

function __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $lref, $rref, $equal) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $lval = __stackBase__;
    var $rval = __stackBase__ + 8;
    var $1 = $lref | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $lval | 0;
    HEAP32[$3 >> 2] = $2$0;
    HEAP32[$3 + 4 >> 2] = $2$1;
    var $4 = $rref | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $rval | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $7 = __ZN2JS8SameTypeERKNS_5ValueES2_($lval, $rval);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $9 = __ZNK2JS5Value8isStringEv($lval);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5Value8toStringEv($lval);
    var $12 = __ZNK2JS5Value8toStringEv($rval);
    var $13 = $cx;
    var $14 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($13, $11, $12, $equal);
    var $_0 = $14;
    __label__ = 18;
    break;
   case 4:
    var $16 = __ZNK2JS5Value8isDoubleEv($lval);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2JS5Value8toDoubleEv($lval);
    var $19 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$equal >> 2] = $18 == $19 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 6:
    var $23 = __ZNK2JS5Value8isObjectEv($lval);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = __ZNK2JS5Value8toObjectEv($lval);
    var $26 = __ZNK2JS5Value8toObjectEv($rval);
    var $27 = __ZeqRK8JSObjectS1_1816($25, $26);
    HEAP32[$equal >> 2] = $27 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 8:
    var $30 = __ZNK2JS5Value11isUndefinedEv($lval);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$equal >> 2] = 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 10:
    var $33 = __ZNK2JS5Value18payloadAsRawUint32Ev($lval);
    var $34 = __ZNK2JS5Value18payloadAsRawUint32Ev($rval);
    HEAP32[$equal >> 2] = ($33 | 0) == ($34 | 0) & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 11:
    var $38 = __ZNK2JS5Value8isDoubleEv($lval);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $40 = __ZNK2JS5Value7isInt32Ev($rval);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = __ZNK2JS5Value8toDoubleEv($lval);
    var $43 = __ZNK2JS5Value7toInt32Ev($rval);
    HEAP32[$equal >> 2] = $42 == ($43 | 0) & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 14:
    var $48 = __ZNK2JS5Value7isInt32Ev($lval);
    if ($48) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $50 = __ZNK2JS5Value8isDoubleEv($rval);
    if ($50) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $52 = __ZNK2JS5Value7toInt32Ev($lval);
    var $53 = $52 | 0;
    var $54 = __ZNK2JS5Value8toDoubleEv($rval);
    HEAP32[$equal >> 2] = $53 == $54 & 1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 17:
    HEAP32[$equal >> 2] = 0;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi["X"] = 1;

function __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $same) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14IsNegativeZeroRKN2JS5ValueE($v1);
    var $2 = __ZL14IsNegativeZeroRKN2JS5ValueE($v2);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$same >> 2] = $2 & 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    if ($2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$same >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $8 = __ZL5IsNaNRKN2JS5ValueE($v1);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $10 = __ZL5IsNaNRKN2JS5ValueE($v2);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$same >> 2] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $13 = __ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi($cx, $v1, $v2, $same);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14IsNegativeZeroRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isDoubleEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    var $4 = _JSDOUBLE_IS_NEGZERO1872($3);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5IsNaNRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isDoubleEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toDoubleEv($v);
    var $4 = __ZL15JSDOUBLE_IS_NaNd1870($3);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $vref) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $vref | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $v | 0;
    HEAP32[$3 >> 2] = $2$0;
    HEAP32[$3 + 4 >> 2] = $2$1;
    var $4 = __ZNK2JS5Value8isNumberEv($v);
    if ($4) {
      var $_0 = 4;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2JS5Value8isStringEv($v);
    if ($6) {
      var $_0 = 3;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value6isNullEv($v);
    if ($8) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($10) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value8isObjectEv($v);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 5;
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value8toObjectEv($v);
    var $15 = __ZN8JSObject6typeOfEP9JSContext($14, $cx);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject6typeOfEP9JSContext($this, $cx) {
  var $1 = __ZNK8JSObject6getOpsEv($this);
  var $3 = HEAP32[$1 + 116 >> 2];
  var $5 = ($3 | 0) != 0 ? $3 : 144;
  var $6 = FUNCTION_TABLE[$5]($cx, $this);
  return $6;
}

function __ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE($cx, $argsRef) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    var $1 = $argsRef;
    var $2 = $args;
    var $3$0 = HEAP32[$1 >> 2];
    var $3$1 = HEAP32[$1 + 4 >> 2];
    HEAP32[$2 >> 2] = $3$0;
    HEAP32[$2 + 4 >> 2] = $3$1;
    var $4 = $args | 0;
    var $5 = __ZNK2js12CallReceiver7calleevEv($4);
    var $6 = __ZNK2JS5Value8isObjectEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $8 = __ZNK2js12CallReceiver6calleeEv($4);
    var $9 = __ZNK8JSObject8getClassEv($8);
    if (($9 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $12 = __ZNK8JSObject18getFunctionPrivateEv($8);
    var $13 = __ZNK10JSFunction13isConstructorEv($12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js12CallReceiver5thisvEv($4);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($15, 0);
    var $17 = HEAP32[$12 + 60 >> 2];
    var $18 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $17, $args);
    var $_0 = $18;
    __label__ = 10;
    break;
   case 5:
    var $20 = __ZNK10JSFunction24isInterpretedConstructorEv($12);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $22 = __ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE($cx, $args, 128);
    var $_0 = $22;
    __label__ = 10;
    break;
   case 7:
    var $24 = $9 + 52 | 0;
    if ((HEAP32[$24 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZNK2js12CallReceiver5thisvEv($4);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($28, 0);
    var $29 = HEAP32[$24 >> 2];
    var $30 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $29, $args);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 9:
    var $32 = __ZNK2js12CallReceiver7calleevEv($4);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $32, 128);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _MAGIC_OBJ_TO_JSVAL_IMPL($1, $obj);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args) {
  var $1 = __ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $native, $args);
  return $1;
}

function __ZNK10JSFunction24isInterpretedConstructorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK10JSFunction13isInterpretedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK10JSFunction19isFunctionPrototypeEv($this);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $thisobj, $fval, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $args = __stackBase__;
    __ZN2js15InvokeArgsGuardC1Ev($args);
    var $2 = $cx + 60 | 0;
    var $3 = $cx;
    var $4 = $args;
    var $5 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($2, $3, $argc, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = $args | 0;
    var $8 = __ZNK2js12CallReceiver7calleevEv($7);
    var $9 = $fval | 0;
    var $st$3$0 = $9 | 0;
    var $10$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$3$1 >> 2];
    var $11 = $8 | 0;
    var $st$8$0 = $11 | 0;
    HEAP32[$st$8$0 >> 2] = $10$0;
    var $st$8$1 = $11 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $10$1;
    var $12 = $args | 0;
    var $13 = __ZNK2js8CallArgs4argvEv($12);
    var $14 = $13;
    var $15 = $argv;
    var $16 = $argc << 3;
    _memcpy($14, $15, $16, 1);
    var $17 = __ZNK2JS5Value8toObjectEv($fval);
    var $18 = __ZNK8JSObject8getClassEv($17);
    if (($18 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $21 = __ZNK8JSObject18getFunctionPrivateEv($17);
    var $22 = __ZNK10JSFunction13isConstructorEv($21);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $24 = __ZNK2js12CallReceiver5thisvEv($7);
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($24, $thisobj);
    var $26 = HEAP32[$21 + 60 >> 2];
    var $27 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $26, $12);
    var $ok_0 = $27 & 1;
    __label__ = 8;
    break;
   case 5:
    var $30 = $18 + 52 | 0;
    var $32 = (HEAP32[$30 >> 2] | 0) == 0;
    var $33 = __ZNK2js12CallReceiver5thisvEv($7);
    if ($32) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject($33, $thisobj);
    var $35 = HEAP32[$30 >> 2];
    var $36 = __ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE($cx, $35, $12);
    var $ok_0 = $36 & 1;
    __label__ = 8;
    break;
   case 7:
    __ZN2JS5Value15setObjectOrNullEP8JSObject($33, $thisobj);
    var $39 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($cx, $args, 128);
    var $ok_0 = $39 & 1;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $42 = __ZNK2js12CallReceiver4rvalEv($7);
    var $43 = $42 | 0;
    var $st$3$0 = $43 | 0;
    var $44$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $43 + 4 | 0;
    var $44$1 = HEAP32[$st$3$1 >> 2];
    var $45 = $rval | 0;
    var $st$8$0 = $45 | 0;
    HEAP32[$st$8$0 >> 2] = $44$0;
    var $st$8$1 = $45 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $44$1;
    var $_0 = $ok_0 << 24 >> 24 != 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN2js15InvokeArgsGuardD1Ev($args);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_["X"] = 1;

function __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $v, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($v, $i);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = HEAP32[$i >> 2];
    var $4 = _INT_FITS_IN_JSID1825($3);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _INT_TO_JSID1826($3);
    HEAP32[$idp >> 2] = $7;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $9 = __ZNK2JS5Value8isObjectEv($v);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $11 = __ZNK2JS5Value8toObjectEv($v);
    var $12 = __ZNK8JSObject7isXMLIdEv($11);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = _OBJECT_TO_JSID1827($11);
    HEAP32[$idp >> 2] = $14;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $16 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($cx, $v, $idp);
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi($v, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$pi >> 2] = $3;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = _JSDOUBLE_IS_INT321871($7, $pi);
    var $_0 = ($8 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti($cx, $obj, $stackDepth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject6isWithEv($obj);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject7isBlockEv($obj);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject10getPrivateEv($obj);
    var $6 = __ZNK9JSContext2fpEv($cx);
    var $7 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($cx, $6);
    if (($5 | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $15 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK8JSObject12getFixedSlotEj($obj, 0);
    var $12 = __ZNK2JS5Value7toInt32Ev($11);
    var $15 = ($12 | 0) >= ($stackDepth | 0);
    __label__ = 5;
    break;
   case 5:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame16isGeneratorFrameEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext12generatorForEPN2js10StackFrameE($cx, $fp);
    var $4 = $3;
    var $5 = __ZN11JSGenerator13floatingFrameEv($4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11UnwindScopeEP9JSContextii($cx, $stackDepth, $normalUnwind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = $cx;
    var $_0_ph = $normalUnwind;
    __label__ = 2;
    break;
   case 2:
    var $_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $4 = __ZNK2js10StackFrame10scopeChainEv($1);
    var $5 = __ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti($cx, $4, $stackDepth);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject7isBlockEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $9 = __Z17js_PutBlockObjectP9JSContexti($2, $_0_ph);
    var $_0_ph = $9 & $_0_ph;
    __label__ = 2;
    break;
   case 6:
    __ZL9LeaveWithP9JSContext($cx);
    __label__ = 3;
    break;
   case 7:
    var $13 = $1;
    var $14 = __ZNK2js10StackFrame4baseEv($13);
    var $15 = $14 + ($stackDepth << 3) | 0;
    var $16 = __ZNK9JSContext4regsEv($cx);
    HEAP32[$16 >> 2] = $15;
    return ($_0_ph | 0) != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9LeaveWithP9JSContext($cx) {
  var $1 = __ZNK9JSContext2fpEv($cx);
  var $2 = __ZNK2js10StackFrame10scopeChainEv($1);
  __ZN8JSObject10setPrivateEPv($2, 0);
  var $3 = __ZNK9JSContext2fpEv($cx);
  var $4 = __ZNK8JSObject9getParentEv($2);
  var $5 = $3;
  var $6 = $4;
  __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($5, $6);
  return;
}

function __ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE($cx, $closureLevel, $cookie) {
  var __stackBase__ = STACKTOP;
  var tempParam = $cookie;
  $cookie = STACKTOP;
  STACKTOP += 4;
  HEAP32[$cookie >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js11UpvarCookie5levelEv($cookie);
    var $3 = $closureLevel - ($1 & 65535) | 0;
    var $4 = __ZN2js14FindUpvarFrameEP9JSContextj($cx, $3);
    var $5 = __ZNK2js11UpvarCookie4slotEv($cookie);
    var $6 = $5 & 65535;
    var $7 = __ZNK2js10StackFrame15isFunctionFrameEv($4);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js10StackFrame11isEvalFrameEv($4);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $4;
    var $12 = __ZNK2js10StackFrame5slotsEv($11);
    var $13 = __ZNK2js10StackFrame8numFixedEv($4);
    var $vp_0 = $12 + ($13 << 3) | 0;
    var $slot_0 = $6;
    __label__ = 9;
    break;
   case 4:
    var $16 = __ZNK2js10StackFrame13numFormalArgsEv($4);
    if ($6 >>> 0 < $16 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = __ZNK2js10StackFrame10formalArgsEv($4);
    var $vp_0 = $19;
    var $slot_0 = $6;
    __label__ = 9;
    break;
   case 6:
    if ($5 << 16 >> 16 == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = __ZNK2js10StackFrame7calleevEv($4);
    var $vp_0 = $23;
    var $slot_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $25 = $6 - $16 | 0;
    var $26 = $4;
    var $27 = __ZNK2js10StackFrame5slotsEv($26);
    var $vp_0 = $27;
    var $slot_0 = $25;
    __label__ = 9;
    break;
   case 9:
    var $slot_0;
    var $vp_0;
    STACKTOP = __stackBase__;
    return $vp_0 + ($slot_0 << 3) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14FindUpvarFrameEP9JSContextj($cx, $targetLevel) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = __ZNK2js10StackFrame6scriptEv($1);
    if ((HEAPU16[$2 + 46 >> 1] & 65535 | 0) == ($targetLevel | 0)) {
      var $fp_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $fp_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $fp_01;
    var $7 = __ZNK2js10StackFrame4prevEv($fp_01);
    var $8 = __ZNK2js10StackFrame6scriptEv($7);
    if ((HEAPU16[$8 + 46 >> 1] & 65535 | 0) == ($targetLevel | 0)) {
      var $fp_0_lcssa = $7;
      __label__ = 3;
      break;
    } else {
      var $fp_01 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    var $fp_0_lcssa;
    return $fp_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js10StackFrame8numFixedEv($this) {
  var $1 = __ZNK2js10StackFrame6scriptEv($this);
  return HEAPU16[$1 + 14 >> 1] & 65535;
}

function __ZN23GenericInterruptEnablerIiEC1EPii($this, $variable, $value) {
  __ZN23GenericInterruptEnablerIiEC2EPii($this, $variable, $value);
  return;
}

function __ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE($this, $cx, $regs) {
  __ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE($this, $cx, $regs);
  return;
}

function __ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler) {
  __ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler);
  return;
}

function __ZNK2js10StackFrame15maybeFormalArgsEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 10 | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame10formalArgsEv($this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame16isGeneratorFrameEv($fp);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $6 = HEAP32[$cx + 56 >> 2];
    var $7 = __ZNK13JSCompartment9debugModeEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $fp;
    __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($9, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame14isConstructingEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = __ZNK2js10StackFrame4prevEv($fp);
    if (($5 | 0) == 0) {
      var $18 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK2js10StackFrame13isScriptFrameEv($5);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK2js10StackFrame6scriptEv($5);
    var $12 = $5;
    var $13 = $cx + 60 | 0;
    var $14 = $fp;
    var $15 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($12, $13, $14, 0);
    var $16 = __ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh($cx, $10, $15);
    var $18 = $16;
    __label__ = 6;
    break;
   case 6:
    var $18;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9EnterWithP9JSContexti4JSOpj($cx, $stackIndex, $oplen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZNK9JSContext2fpEv($cx);
    var $2 = __ZNK9JSContext4regsEv($cx);
    var $4 = HEAP32[$2 >> 2];
    var $5 = $4 - 8 | 0;
    var $6 = __ZNK2JS5Value8isObjectEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZNK2JS5Value8toObjectEv($5);
    HEAP32[$obj >> 2] = $8;
    __label__ = 5;
    break;
   case 3:
    var $10 = $cx;
    var $11 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($10, $5);
    var $12 = $11;
    HEAP32[$obj >> 2] = $12;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($5, $12);
    __label__ = 5;
    break;
   case 5:
    var $16 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($cx, $1, undef, $oplen);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj);
    var $19 = HEAP32[$obj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = $4 + ($stackIndex << 3) | 0;
    var $23 = $1;
    var $24 = __ZNK2js10StackFrame4baseEv($23);
    var $28 = $22 - $24 >> 3;
    var $29 = $cx;
    var $30 = $19;
    var $31 = $16;
    var $32 = __Z16js_NewWithObjectP9JSContextP8JSObjectS2_i($29, $30, $31, $28);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $32;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($23, $35);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $ok & 1;
    var $3 = $fp;
    var $5 = HEAP32[$cx + 56 >> 2];
    var $6 = __ZNK13JSCompartment9debugModeEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($8, $3, $ok);
    var $_0 = $9 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    var $12 = __ZNK2js10StackFrame14isConstructingEv($fp);
    if ($_0 << 24 >> 24 == 0 | $12 ^ 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZN2js10StackFrame11returnValueEv($3);
    var $16 = __ZNK2JS5Value11isPrimitiveEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = __ZNK2js10StackFrame15constructorThisEv($fp);
    __ZN2JSL11ObjectValueER8JSObject1804($1, $18);
    __ZN2js10StackFrame14setReturnValueERKN2JS5ValueE($3, $1);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $_0 << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE($this, $regs) {
  var $1 = __ZNK2js9FrameRegs2fpEv($regs);
  var $2 = $1;
  __ZN2js10StackFrame16functionEpilogueEv($2);
  var $3 = __ZNK2js10StackFrame10actualArgsEv($1);
  var $4 = $3 - 8 | 0;
  var $5 = $1;
  var $6 = __ZN2js10StackFrame11returnValueEv($5);
  var $7 = $6 | 0;
  var $8$0 = HEAP32[$7 >> 2];
  var $8$1 = HEAP32[$7 + 4 >> 2];
  var $9 = $3 - 16 | 0;
  HEAP32[$9 >> 2] = $8$0;
  HEAP32[$9 + 4 >> 2] = $8$1;
  __ZN2js9FrameRegs8popFrameEPN2JS5ValueE($regs, $4);
  return;
}

function __ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE($cx, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame11hasImacropcEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    var $6 = __ZN11JSAtomState16commonAtomsStartEv($5);
    var $12 = $6;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK2js10StackFrame6scriptEv($fp);
    var $12 = HEAP32[$8 + 56 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE($cx, $script, $pc, $rval);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj, $idval, $idp, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $1 = __ZNK2JS5Value8isObjectEv($idval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_($cx, $obj, $idval, $idp, $vp);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($cx, $idval, $atom);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = HEAP32[$atom >> 2];
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom1798($7);
    HEAP32[$idp >> 2] = $8;
    var $9 = $7 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE($cx, $iterobj, $cond, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10isIteratorEv($iterobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject17getNativeIteratorEv($iterobj);
    var $4 = __ZNK2js14NativeIterator9isKeyIterEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$cond] = HEAPU32[$3 + 8 >> 2] >>> 0 < HEAPU32[$3 + 12 >> 2] >>> 0 & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $13 = $cx;
    var $14 = $iterobj;
    var $15 = __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($13, $14, $rval);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK2JS5Value6isTrueEv($rval);
    HEAP8[$cond] = $18 & 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_VOID1831($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZL24CanIncDecWithoutOverflowi($i) {
  return ($i - 2147483647 | 0) >>> 0 > 1;
}

function _JSID_IS_STRING1834($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT1835($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1836($iden) {
  return $iden >> 1;
}

function __ZN2JS5Value11getInt32RefEv($this) {
  return $this;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject1842($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843($object) {
  return $object;
}

function __ZN2JS5Value4swapERS0_($this, $rhs) {
  var $1 = $rhs | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $this | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$1 >> 2] = $4$0;
  HEAP32[$1 + 4 >> 2] = $4$1;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZNK2js5PCVal6isSlotEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js5PCVal6toSlotEv($this) {
  return HEAPU32[$this >> 2] >>> 1;
}

function __ZN2jsL18GetDecomposeLengthEPhj($pc, $len) {
  return HEAPU8[$pc + ($len - 1) | 0] & 255;
}

function __ZNK2js5PCVal8isFunObjEv($this) {
  return (HEAP32[$this >> 2] & 3 | 0) == 0;
}

function __ZNK2js5PCVal8toFunObjEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js5PCVal7toShapeEv($this) {
  return HEAP32[$this >> 2] & -4;
}

function __ZNK2js18PropertyCacheEntry7vcapTagEv($this) {
  return HEAP32[$this + 8 >> 2] & 255;
}

function __ZNK8JSObject5shapeEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZNK2js18PropertyCacheEntry6vshapeEv($this) {
  return HEAPU32[$this + 8 >> 2] >>> 8;
}

function __ZNK2js5Shape16hasDefaultSetterEv($this) {
  return (HEAP32[$this + 20 >> 2] | 0) == 0;
}

function __ZN8JSObject25brandedOrHasMethodBarrierEv($this) {
  return (HEAP32[$this + 8 >> 2] & 40 | 0) != 0;
}

function __ZNK2js12CallReceiver11spAfterCallEv($this) {
  return HEAP32[$this >> 2] - 8 | 0;
}

function __ZNK2js5Shape20isAccessorDescriptorEv($this) {
  return (HEAP8[$this + 28 | 0] & 48) << 24 >> 24 != 0;
}

function __ZN2js23AdvanceOverBlockchainOpEPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP8[$pc];
    if ($1 << 24 >> 24 == -67) {
      __label__ = 2;
      break;
    } else if ($1 << 24 >> 24 == -68) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $pc;
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = $pc + 1 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $pc + 3 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame11setYieldingEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 256;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10isIteratorEv($iterobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject17getNativeIteratorEv($iterobj);
    var $4 = __ZNK2js14NativeIterator9isKeyIterEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZNK2js14NativeIterator7currentEv($3);
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZL12JSID_IS_ATOMi1876($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _JSID_TO_STRING1867($7);
    __ZN2JS5Value9setStringEP8JSString($rval, $11);
    __ZN2js14NativeIterator9incCursorEv($3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $13 = $cx;
    var $14 = $iterobj;
    var $15 = __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($13, $14, $rval);
    var $_0 = ($15 | 0) != 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame6varObjEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame10scopeChainEv($this);
    var $2 = __ZNK8JSObject8isVarObjEv($1);
    if ($2) {
      var $obj_0_lcssa = $1;
      __label__ = 3;
      break;
    } else {
      var $obj_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $obj_01;
    var $3 = __ZNK8JSObject9getParentEv($obj_01);
    var $4 = __ZNK8JSObject8isVarObjEv($3);
    if ($4) {
      var $obj_0_lcssa = $3;
      __label__ = 3;
      break;
    } else {
      var $obj_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $obj_0_lcssa;
    return $obj_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom($this, $cx, $pc, $obj, $pobj, $entry, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj >> 2];
    var $2 = __ZNK8JSObject5shapeEv($1);
    var $3 = __ZN2js13PropertyCache4hashEPhj($pc, $2);
    var $4 = $this + ($3 << 4) | 0;
    HEAP32[$entry >> 2] = $4;
    if ((HEAP32[$4 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      var $28 = $4;
      __label__ = 8;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($3 << 4) + 4 >> 2] | 0) == ($2 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $28 = $4;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = HEAP32[$obj >> 2];
    HEAP32[$pobj >> 2] = $13;
    var $14 = HEAP32[$entry >> 2];
    var $15 = __ZNK2js18PropertyCacheEntry7vcapTagEv($14);
    if (($15 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $23 = $13;
      var $22 = $14;
      __label__ = 6;
      break;
    }
   case 4:
    var $18 = __ZNK8JSObject8getProtoEv($13);
    if (($18 | 0) == 0) {
      var $23 = $13;
      var $22 = $14;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$pobj >> 2] = $18;
    var $23 = $18;
    var $22 = HEAP32[$entry >> 2];
    __label__ = 6;
    break;
   case 6:
    var $22;
    var $23;
    var $24 = __ZNK2js18PropertyCacheEntry6vshapeEv($22);
    var $25 = __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj(undef, $23, $24);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $28 = $22;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$atom >> 2] = 0;
    return;
   case 8:
    var $28;
    var $29 = __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE(undef, $cx, $pc, $obj, $pobj, $28);
    HEAP32[$atom >> 2] = $29;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 4, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10DoubleTypeEv($1);
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5IsXMLRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject5isXMLEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types4Type10StringTypeEv($1);
    __ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE($cx, $script, $pc, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9NumberDivEdd($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($b == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    if ($a == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZL15JSDOUBLE_IS_NaNd1870($a);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $10 = __ZL15JSDOUBLE_IS_NEGd($a);
    var $11 = __ZL15JSDOUBLE_IS_NEGd($b);
    if ($10 ^ $11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $14 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $14;
    __label__ = 9;
    break;
   case 7:
    var $16 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $16;
    __label__ = 9;
    break;
   case 8:
    var $_0 = $a / $b;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7js_fmoddd($d, $d2) {
  var $1 = _fmod($d, $d2);
  return $1;
}

function __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK2JS5Value8isNumberEv($vp);
    if ($2) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $7 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $d);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $10 = __ZN2JS5Value9setNumberEd($vp, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi1832($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_($cx, $cs, $vp, $vp2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $d1 = __stackBase__ + 8;
    var $1 = $cs + 4 | 0;
    if ((HEAP32[$1 >> 2] & 4096 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $8 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $9 = __ZN2JS5Value9setNumberEd($vp, $8);
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $storemerge1 = $8 + 1;
    __label__ = 6;
    break;
   case 5:
    var $storemerge1 = $8 - 1;
    __label__ = 6;
    break;
   case 6:
    var $storemerge1;
    tempDoubleF64[0] = $storemerge1, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $18 = __ZN2JS5Value9setNumberEd($vp2, $storemerge1);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 7:
    var $20 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d1);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $24 = (HEAP32[$1 >> 2] & 2048 | 0) == 0;
    var $25 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $storemerge = $25 + 1;
    __label__ = 11;
    break;
   case 10:
    var $storemerge = $25 - 1;
    __label__ = 11;
    break;
   case 11:
    var $storemerge;
    tempDoubleF64[0] = $storemerge, HEAP32[$d1 >> 2] = tempDoubleI32[0], HEAP32[$d1 + 4 >> 2] = tempDoubleI32[1];
    var $31 = __ZN2JS5Value9setNumberEd($vp, $storemerge);
    var $32 = $vp | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp2 | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_["X"] = 1;

function __ZN2JSL11NumberValueEd1833($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __Z23js_GetProtoIfDenseArrayP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject12isDenseArrayEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = $obj;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8getProtoEv($obj);
    var $5 = $3;
    __label__ = 3;
    break;
   case 3:
    var $5;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom($this, $cx, $pc, $obj, $entryp, $obj2p, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __ZNK8JSObject5shapeEv($obj);
    var $3 = __ZN2js13PropertyCache4hashEPhj($pc, $2);
    var $4 = $this + ($3 << 4) | 0;
    HEAP32[$entryp >> 2] = $4;
    if ((HEAP32[$4 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($3 << 4) + 4 >> 2] | 0) == ($2 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE(undef, $cx, $pc, $1, $obj2p, $4);
    HEAP32[$atomp >> 2] = $13;
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18PropertyCacheEntry6addingEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js18PropertyCacheEntry7vcapTagEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 4 >> 2];
    var $6 = __ZNK2js18PropertyCacheEntry6vshapeEv($this);
    var $9 = ($5 | 0) != ($6 | 0);
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($this, $cx, $shape, $value) {
  var $2 = HEAP32[$shape + 24 >> 2];
  __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($this, $2, $value);
  var $4 = HEAP32[$shape + 12 >> 2];
  __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $this, $4, $value);
  return;
}

function __ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb($this, $cx, $shape, $isDefinitelyAtom) {
  __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape);
  __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape, $isDefinitelyAtom);
  __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
  return;
}

function __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10isDelegateEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $obj;
    __Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti($3, $4, $id);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($this, $cx, $str, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSString8getCharsEP9JSContext($str, $cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU16[$1 + ($index << 1) >> 1];
    if (($5 & 65535) < 256) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZN2js13StaticStrings7getUnitEt($this, $5);
    var $_0 = $8 | 0;
    __label__ = 5;
    break;
   case 4:
    var $11 = $cx;
    var $12 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($11, $str, $index, 1);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi($cx, $v, $spindex) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isStringEv($v);
    if ($5) {
      var $protoKey_0 = 9;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8isNumberEv($v);
    if ($7) {
      var $protoKey_0 = 8;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK2JS5Value9isBooleanEv($v);
    if ($9) {
      var $protoKey_0 = 4;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($cx, $spindex, $v, 0);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 7:
    var $protoKey_0;
    var $13 = $cx;
    var $14 = $pobj;
    var $15 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($13, 0, $protoKey_0, $14, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = HEAP32[$pobj >> 2];
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE($cx, $script, $pc, $obj, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject16hasSingletonTypeEv($obj);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject4typeEv($obj);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $8, 0);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14CallArgsFromSpEjPN2JS5ValueE($agg_result, $argc, $sp) {
  var $2 = $sp + (-$argc << 3) | 0;
  __ZN2js16CallArgsFromArgvEjPN2JS5ValueE($agg_result, $argc, $2);
  return;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837($v, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($v, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$funobj >> 2];
    var $4 = __ZNK8JSObject18getFunctionPrivateEv($3);
    HEAP32[$fun >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE($this, $cx, $regs, $args, $callee, $fun, $script, $initial) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $1 = __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859($initial);
    HEAP32[$flags >> 2] = $1;
    var $2 = $this;
    var $3 = $cx;
    var $4 = $fun;
    var $5 = $script;
    var $6 = __ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE($2, $3, 1, $args, $4, $5, $flags);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js8CallArgs4argcEv($args);
    var $10 = HEAP32[$flags >> 2];
    var $11 = $callee;
    __ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE($6, $3, $11, $4, $5, $9, $10);
    var $12 = $regs;
    __ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript($12, $6, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb($cx, $fp, $newType) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10StackFrame14isConstructingEv($fp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2js10StackFrame6calleeEv($fp);
    var $4 = $cx;
    var $5 = $3;
    var $6 = __Z24js_CreateThisForFunctionP9JSContextP8JSObjectb($4, $5, $newType);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    var $10 = __ZNK2js10StackFrame12functionThisEv($fp);
    __ZN2JS5Value9setObjectER8JSObject($10, $9);
    __label__ = 4;
    break;
   case 4:
    var $13 = HEAP32[$cx + 56 >> 2];
    var $14 = __ZNK13JSCompartment9debugModeEv($13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $fp;
    var $17 = $cx;
    __ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE($17, $16);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_($cx, $obj, $funval, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $1 = __ZNK2JS5Value8isObjectEv($funval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8isGlobalEv($obj);
    if ($3) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject($obj);
    if ($5) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZN8JSObject10thisObjectEP9JSContext($obj, $cx);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_UnwrapWithObjectP9JSContextP8JSObject($cx, $withobj) {
  var $1 = __ZNK8JSObject8getProtoEv($withobj);
  return $1;
}

function __ZN8JSScript8getConstEj($this, $index) {
  var $1 = __ZN8JSScript6constsEv($this);
  return HEAP32[$1 >> 2] + ($index << 3) | 0;
}

function __ZN8JSScript9getRegExpEj($this, $index) {
  var $1 = $this;
  var $2 = __ZN8JSScript7regexpsEv($1);
  return HEAP32[HEAP32[$2 >> 2] + ($index << 2) >> 2];
}

function __ZN2JSL10MagicValueE10JSWhyMagic1838($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 9);
  return;
}

function __ZN2JSL14UndefinedValueEv1839($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN10JSFunction13setMethodAtomEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $atom | 0;
  __ZN2JSL11StringValueEP8JSString1846($1, $3);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK8JSObject20canHaveMethodBarrierEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8isObjectEv($this);
    if ($1) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject10isFunctionEv($this);
    if ($3) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject11isPrimitiveEv($this);
    if ($5) {
      var $9 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject6isDateEv($this);
    var $9 = $7;
    __label__ = 5;
    break;
   case 5:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE1841($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE($cx, $baseobj, $type) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject13numFixedSlotsEv($baseobj);
    var $2 = __ZN2js2gcL25GetGCObjectFixedSlotsKindEj($1);
    var $3 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject8numSlotsEv($baseobj);
    var $7 = __ZN8JSObject11ensureSlotsEP9JSContextj($3, $cx, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($3, $type);
    var $10 = HEAP32[$baseobj + 8 >> 2];
    HEAP32[$3 + 8 >> 2] = $10;
    var $13 = HEAP32[$baseobj >> 2];
    HEAP32[$3 >> 2] = $13;
    var $16 = HEAP32[$baseobj + 12 >> 2];
    HEAP32[$3 + 12 >> 2] = $16;
    var $_0 = $3;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE($this, $rt, $pc, $obj, $shapep, $entryp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject5shapeEv($obj);
    var $2 = __ZN2js13PropertyCache4hashEPhj($pc, $1);
    var $3 = $this + ($2 << 4) | 0;
    HEAP32[$entryp >> 2] = $3;
    if ((HEAP32[$3 >> 2] | 0) == ($pc | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$this + ($2 << 4) + 4 >> 2] | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = __ZNK2js18PropertyCacheEntry6vshapeEv($3);
    if (($12 | 0) == (HEAP32[$rt + 44 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = $this + ($2 << 4) + 12 | 0;
    var $18 = __ZNK2js5PCVal7toShapeEv($17);
    HEAP32[$shapep >> 2] = $18;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value14isObjectOrNullEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_OBJECT_OR_NULL_IMPL($2$0, $2$1);
  return ($3 | 0) != 0;
}

function __ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, 0);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1846($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function _JSVAL_TO_OBJECT1847($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE1850($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL1849($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $beg;
      __label__ = 2;
      break;
    }
   case 2:
    var $v_01;
    __ZN2JS5Value12setUndefinedEv($v_01);
    var $2 = $v_01 + 8 | 0;
    if (($2 | 0) == ($end | 0)) {
      __label__ = 3;
      break;
    } else {
      var $v_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859($initial) {
  return $initial;
}

function __ZL14JSID_FROM_BITSj1904($bits) {
  return $bits;
}

function __ZL17iterator_iteratorP9JSContextP8JSObjecti($cx, $obj, $keysonly) {
  return $obj;
}

function _JSVAL_TO_OBJECT_IMPL1849($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_OBJECT_OR_NULL_IMPL($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967173 & 1;
}

function __ZN2js13PropertyCache4hashEPhj($pc, $kshape) {
  var $1 = $pc;
  return ($1 >>> 12 ^ $1) + $kshape & 4095;
}

function _JSID_TO_STRING1867($iden) {
  return $iden;
}

function _JSVAL_SAME_TYPE_IMPL($lhs_0$0, $lhs_0$1, $rhs_0$0, $rhs_0$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $lhs_0$1;
    var $4 = $rhs_0$1;
    if (($2 | 0) == ($4 | 0)) {
      var $11 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($2 >>> 0 < 4294967168) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $4 >>> 0 < 4294967168;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_OBJECT1900($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1901($iden) {
  return $iden & -8;
}

function __ZL15JSDOUBLE_IS_NaNd1870($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL15JSDOUBLE_IS_NEGd($d) {
  tempDoubleF64[0] = $d;
  var $1$1 = tempDoubleI32[1];
  var $$emscripten$temp$0$1 = 0;
  return ($1$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && tempDoubleI32[0] >>> 0 < 0 >>> 0;
}

function _JSDOUBLE_IS_NEGZERO1872($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript4mainEv($this) {
  return HEAP32[$this >> 2] + HEAP32[$this + 32 >> 2] | 0;
}

function __ZN2js10StackFrame24setFinishedInInterpreterEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 512;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVN2js17InterpreterFrames20InterruptEnablerBaseE + 8 | 0;
  return;
}

function __ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE($this, $regs) {
  HEAP32[$this + 8 >> 2] = $regs;
  return;
}

function __ZN2js17InterpreterFramesD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  var $7 = HEAP32[HEAP32[$this + 4 >> 2] + 52 >> 2] + 209936 | 0;
  HEAP32[$7 >> 2] = $2;
  return;
}

function __ZN2js10StackFrame10isYieldingEv($this) {
  return (HEAP32[$this >> 2] & 256 | 0) != 0;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE1850($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZN2js2gcL25GetGCObjectFixedSlotsKindEj($numFixedSlots) {
  return HEAP32[__ZN2js2gc16slotsToThingKindE + ($numFixedSlots << 2) >> 2];
}

function __ZNK8JSObject9isDeclEnvEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js12DeclEnvClassE | 0);
}

function __ZN8JSObject10setIndexedEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 64;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSObject16setMethodBarrierEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] | 32;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK8JSObject8isVarObjEv($this) {
  return (HEAP32[$this + 8 >> 2] & 4096 | 0) != 0;
}

function __ZNK8JSObject10isIteratorEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js13IteratorClassE | 0);
}

function __ZNK2js14NativeIterator9isKeyIterEv($this) {
  return (HEAP32[$this + 28 >> 2] & 2 | 0) == 0;
}

function __ZNK2js14NativeIterator7currentEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js14NativeIterator9incCursorEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] + 4 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE($this, $cx, $regs, $enabler) {
  HEAP32[$this + 4 >> 2] = $cx;
  HEAP32[$this + 8 >> 2] = $regs;
  HEAP32[$this + 12 >> 2] = $enabler;
  var $4 = $cx + 52 | 0;
  var $7 = HEAP32[HEAP32[$4 >> 2] + 209936 >> 2];
  HEAP32[$this >> 2] = $7;
  var $10 = HEAP32[$4 >> 2] + 209936 | 0;
  HEAP32[$10 >> 2] = $this;
  return;
}

function _MAGIC_OBJ_TO_JSVAL_IMPL($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -124;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZNK2js10FrameGuard6pushedEv($this) {
  return (HEAP32[$this >> 2] | 0) != 0;
}

function __ZN2js10FrameGuardC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js23AutoPreserveEnumeratorsD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $5 = HEAP32[$this >> 2] + 284 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZN2js23AutoPreserveEnumeratorsC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 284 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZNK2js14NativeIterator5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js14NativeIterator3endEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 56 >> 2];
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE($cx, $vp, 1);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10StackFrame16clearReturnValueEv($this) {
  var $1 = $this + 24 | 0;
  __ZN2JS5Value12setUndefinedEv($1);
  var $2 = $this;
  __ZN2js10StackFrame15markReturnValueEv($2);
  return;
}

function __ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10StackFrame10isYieldingEv($fp);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb($cx, $fp, $ok);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $6 = HEAP32[$cx + 56 >> 2];
    var $7 = __ZNK13JSCompartment9debugModeEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $ok;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = $cx;
    var $10 = $fp;
    var $11 = __ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb($9, $10, $ok);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17InterpreterFramesD1Ev($this) {
  __ZN2js17InterpreterFramesD2Ev($this);
  return;
}

function __ZN2js17PreserveRegsGuardD1Ev($this) {
  __ZN2js17PreserveRegsGuardD2Ev($this);
  return;
}

function __ZN23GenericInterruptEnablerIiEC2EPii($this, $variable, $value) {
  var $1 = $this | 0;
  __ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev($1);
  HEAP32[$this >> 2] = __ZTV23GenericInterruptEnablerIiE + 8 | 0;
  HEAP32[$this + 4 >> 2] = $variable;
  HEAP32[$this + 8 >> 2] = $value;
  return;
}

function __ZN2js17PreserveRegsGuardD2Ev($this) {
  var $1 = $this | 0;
  var $5 = HEAP32[$1 >> 2];
  var $6 = HEAP32[$this + 8 >> 2];
  HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
  HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
  HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
  HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
  var $9 = HEAP32[$this + 4 >> 2] + 60 | 0;
  var $10 = HEAP32[$1 >> 2];
  __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($9, $10);
  return;
}

function __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($this, $regs) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE($2, $regs);
  return;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject11isPrimitiveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8isNumberEv($this);
    if ($1) {
      var $7 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject8isStringEv($this);
    if ($3) {
      var $7 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK8JSObject9isBooleanEv($this);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject6isCallEv($1);
    if ($2) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject7isBlockEv($obj);
    if ($4) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSObject9isDeclEnvEv($obj);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape, $isDefinitelyAtom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    if ($isDefinitelyAtom) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = HEAP32[$shape + 12 >> 2];
    var $4 = __Z12js_IdIsIndexiPj($3, $index);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject10setIndexedEv($this);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZNK2js5Shape8isMethodEv($shape);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN8JSObject16setMethodBarrierEv($this);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11updateShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject11hasOwnShapeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __Z16js_GenerateShapeP9JSContext($cx);
    __ZN8JSObject11setOwnShapeEj($this, $3);
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[HEAP32[$this >> 2] >> 2];
    HEAP32[$this + 12 >> 2] = $8;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT321871($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO1872($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj($cx, $obj, $shape) {
  var $1 = __ZNK8JSObject5shapeEv($obj);
  return ($1 | 0) == ($shape | 0);
}

function __ZNK8JSObject17getNativeIteratorEv($this) {
  var $1 = __ZNK8JSObject10getPrivateEv($this);
  return $1;
}

function __ZL12JSID_IS_ATOMi1876($id) {
  var $1 = _JSID_IS_STRING1834($id);
  return $1;
}

function __ZN2js9FrameRegs8popFrameEPN2JS5ValueE($this, $newsp) {
  var $1 = $this + 12 | 0;
  var $4 = HEAP32[$1 >> 2];
  var $5 = $this + 8 | 0;
  var $6 = __ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE($4, $5);
  HEAP32[$this + 4 >> 2] = $6;
  HEAP32[$this >> 2] = $newsp;
  var $9 = HEAP32[$1 >> 2];
  var $10 = __ZNK2js10StackFrame4prevEv($9);
  HEAP32[$1 >> 2] = $10;
  return;
}

function __ZNK2js10StackFrame15constructorThisEv($this) {
  var $1 = __ZNK2js10StackFrame10formalArgsEv($this);
  var $2 = $1 - 8 | 0;
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  return $3;
}

function __ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE($this, $cx, $regs) {
  var $1 = $this | 0;
  var $2 = $cx;
  var $3 = __ZNK9JSContext9maybeRegsEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = $cx;
  HEAP32[$this + 8 >> 2] = $regs;
  var $7 = $cx + 60 | 0;
  __ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE($7, $regs);
  return;
}

function __ZN2js17ExecuteFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN2js10FrameGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js10FrameGuard6pushedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$this >> 2];
    var $6 = $this;
    __ZN2js12ContextStack8popFrameERKNS_10FrameGuardE($5, $6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ExecuteFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN2js16InvokeFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN2js16InvokeFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZL17iterator_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject17getNativeIteratorEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($obj, 0);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14iterator_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject17getNativeIteratorEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js14NativeIterator4markEP8JSTracer($5, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14NativeIterator4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js14NativeIterator5beginEv($this);
    var $2 = __ZNK2js14NativeIterator3endEv($this);
    var $3 = $trc;
    __ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc($3, $1, $2, undef);
    var $5 = HEAP32[$this >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($3, $8, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray($cx, $props, $idap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props;
    var $2 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $3 = $2 << 2;
    var $4 = $3 + 4 | 0;
    var $5 = $cx;
    var $6 = __ZN9JSContext7malloc_Ej($5, $4);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    HEAP32[$6 >> 2] = $2;
    var $11 = $6 + 4 | 0;
    var $12 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $13 = $12;
    _memcpy($11, $13, $3, 1);
    HEAP32[$idap >> 2] = $9;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($cx, $obj, $flags, $props) {
  var $1 = $flags & 24;
  var $2 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $1, $props);
  return $2;
}

function __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ht = __stackBase__;
    var $1 = __stackBase__ + 28;
    var $proxyProps = __stackBase__ + 32;
    var $state = __stackBase__ + 92;
    var $id = __stackBase__ + 100;
    var $2 = $1;
    var $3 = $cx;
    __ZN2js15TempAllocPolicyC1EP9JSContext($2, $3);
    __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_($ht, $1);
    var $4 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj($ht, 32);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 2:
    var $6 = ($flags & 8 | 0) == 0;
    var $_lobit = $flags >>> 4 & 1;
    var $cx_idx = $cx + 52 | 0;
    var $pobj_0 = $obj;
    __label__ = 3;
    break;
   case 3:
    var $pobj_0;
    var $9 = $pobj_0;
    var $10 = __ZNK8JSObject8getClassEv($9);
    var $11 = __ZNK8JSObject8isNativeEv($9);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject6getOpsEv($9);
    if ((HEAP32[$13 + 112 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ((HEAP32[$10 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $25 = HEAP32[$10 + 24 >> 2];
    var $26 = FUNCTION_TABLE[$25]($cx, $pobj_0);
    if (($26 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $flags, $ht, $props);
    if ($29 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $29;
      __label__ = 34;
      break;
    }
   case 8:
    var $31 = __ZNK8JSObject12isDenseArrayEv($9);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $cx_idx_val_idx_val = HEAP32[HEAP32[$cx_idx >> 2] + 210256 >> 2];
    var $33 = __ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($cx_idx_val_idx_val, $pobj_0, $flags, $ht, $props);
    if ($33 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $33;
      __label__ = 34;
      break;
    }
   case 10:
    var $35 = __ZNK8JSObject7isProxyEv($9);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 11:
    var $37 = $proxyProps;
    __ZN2js12AutoIdVectorC1EP9JSContext($37, $3);
    if ($6) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($flags & 16 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $42 = __ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $9, $37);
    if ($42) {
      __label__ = 16;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 14:
    var $44 = __ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $9, $37);
    if ($44) {
      __label__ = 16;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 15:
    var $46 = __ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE($3, $9, $37);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 16:
    var $48 = $proxyProps;
    var $49 = __ZNK2js16AutoVectorRooterIiE6lengthEv($48);
    var $n_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $n_0;
    if ($n_0 >>> 0 < $49 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    var $53 = __ZN2js16AutoVectorRooterIiEixEj($48, $n_0);
    var $54 = HEAP32[$53 >> 2];
    var $55 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $54, 1, $flags, $ht, $props);
    if ($55) {
      __label__ = 19;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 19:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 17;
    break;
   case 20:
    __ZN2js12AutoIdVectorD1Ev($37);
    var $_1 = 1;
    __label__ = 34;
    break;
   case 21:
    var $60 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($pobj_0, $cx, $_lobit, $state, 0);
    if (($60 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $63 = __ZNK2JS5Value7isMagicE10JSWhyMagic($state, undef);
    if ($63) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $65 = __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $flags, $ht, $props);
    if ($65 & $6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = $65;
      __label__ = 34;
      break;
    }
   case 24:
    var $66 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($pobj_0, $cx, 2, $state, $id);
    if (($66 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $69 = __ZNK2JS5Value6isNullEv($state);
    if ($69) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $71 = HEAP32[$id >> 2];
    var $72 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj_0, $71, 1, $flags, $ht, $props);
    if ($72) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 27:
    if ($6) {
      __label__ = 28;
      break;
    } else {
      var $_1 = 1;
      __label__ = 34;
      break;
    }
   case 28:
    var $74 = __ZNK8JSObject5isXMLEv($9);
    if ($74) {
      var $_1 = 1;
      __label__ = 34;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $76 = __ZNK8JSObject8getProtoEv($9);
    var $77 = $76;
    if (($76 | 0) == 0) {
      var $_1 = 1;
      __label__ = 34;
      break;
    } else {
      var $pobj_0 = $77;
      __label__ = 3;
      break;
    }
   case 30:
    __ZN2js12AutoIdVectorD1Ev($37);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 31:
    __ZN2js12AutoIdVectorD1Ev($37);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 32:
    __ZN2js12AutoIdVectorD1Ev($37);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 33:
    __ZN2js12AutoIdVectorD1Ev($37);
    var $_1 = 0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev($ht);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE["X"] = 1;

function __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, $slength, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $props | 0;
    var $2 = $props;
    var $3 = __ZNK2js16AutoVectorRooterIiE6lengthEv($2);
    var $4 = $3 << 2;
    var $7 = ($slength << 2) + 36 + $4 | 0;
    var $8 = $cx;
    var $9 = __ZN9JSContext7malloc_Ej($8, $7);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $9 + 36 | 0;
    var $14 = $13;
    HEAP32[$9 + 8 >> 2] = $14;
    HEAP32[$9 + 4 >> 2] = $14;
    HEAP32[$9 + 12 >> 2] = $14 + ($3 << 2) | 0;
    if (($3 | 0) == 0) {
      var $_0 = $10;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $24 = __ZNK2js16AutoVectorRooterIiE5beginEv($1);
    var $25 = $24;
    _memcpy($13, $25, $4, 1);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js16AutoVectorRooterIiE5beginEv($this) {
  var $2 = $this + 12 | 0;
  var $3 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($2);
  return $3;
}

function __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp) {
  var $1 = __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $props, 0, 0, $vp);
  return $1;
}

function __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $keys, $slength, $key, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj + 8 | 0;
    var $5 = HEAP32[$3 >> 2] | 32768;
    HEAP32[$3 >> 2] = $5;
    var $6 = $cx;
    var $7 = $obj;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($6, $7, 4194304);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZL17NewIteratorObjectP9JSContextj($cx, $flags);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, $slength, $keys);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js14NativeIterator4initEP8JSObjectjjj($12, $obj, $flags, $slength, $key);
    if (($slength | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $12 + 16 | 0;
    var $ind_0 = 0;
    var $pobj_0 = $obj;
    __label__ = 7;
    break;
   case 7:
    var $pobj_0;
    var $ind_0;
    var $18 = $pobj_0;
    var $19 = __ZNK8JSObject5shapeEv($18);
    var $20 = $ind_0 + 1 | 0;
    var $22 = HEAP32[$16 >> 2] + ($ind_0 << 2) | 0;
    HEAP32[$22 >> 2] = $19;
    var $23 = __ZNK8JSObject8getProtoEv($18);
    var $24 = $23;
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $ind_0 = $20;
      var $pobj_0 = $24;
      __label__ = 7;
      break;
    }
   case 8:
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($9, $12);
    var $26 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $26);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $9, $12);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $keys, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj + 8 | 0;
    var $5 = HEAP32[$3 >> 2] | 32768;
    HEAP32[$3 >> 2] = $5;
    var $6 = $cx;
    var $7 = $obj;
    __ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj($6, $7, 4194304);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZL17NewIteratorObjectP9JSContextj($cx, $flags);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE($cx, 0, $keys);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js14NativeIterator4initEP8JSObjectjjj($12, $obj, $flags, 0, 0);
    __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($9, $12);
    var $15 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $15);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $9, $12);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17NewIteratorObjectP9JSContextj($cx, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags & 1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($4, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($5, undef, __ZN2js13IteratorClassE, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    var $12 = $9;
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $12);
    var $_0 = $6;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991($cx);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14NativeIterator4initEP8JSObjectjjj($this, $obj, $flags, $slength, $key) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 28 >> 2] = $flags;
  var $4 = HEAP32[$this + 12 >> 2];
  HEAP32[$this + 16 >> 2] = $4;
  HEAP32[$this + 20 >> 2] = $slength;
  HEAP32[$this + 24 >> 2] = $key;
  return;
}

function __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $iterobj, $ni) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ni + 28 | 0;
    if ((HEAP32[$1 >> 2] & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx + 284 | 0;
    var $7 = HEAP32[$6 >> 2];
    HEAP32[$ni + 32 >> 2] = $7;
    HEAP32[$6 >> 2] = $iterobj;
    var $10 = HEAP32[$1 >> 2] | 4096;
    HEAP32[$1 >> 2] = $10;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($ni, $obj) {
  HEAP32[$ni >> 2] = $obj;
  return;
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZL7CompareIjEbPT_S1_j($a, $b, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($c + 7 | 0) >>> 3;
    var $3 = $c & 7;
    if (($3 | 0) == 0) {
      var $_01 = $a;
      var $_02 = $b;
      var $n_0 = $2;
      __label__ = 2;
      break;
    } else if (($3 | 0) == 7) {
      var $_1 = $a;
      var $_13 = $b;
      var $n_1 = $2;
      __label__ = 3;
      break;
    } else if (($3 | 0) == 6) {
      var $_2 = $a;
      var $_24 = $b;
      var $n_2 = $2;
      __label__ = 4;
      break;
    } else if (($3 | 0) == 5) {
      var $_3 = $a;
      var $_35 = $b;
      var $n_3 = $2;
      __label__ = 5;
      break;
    } else if (($3 | 0) == 4) {
      var $_4 = $a;
      var $_46 = $b;
      var $n_4 = $2;
      __label__ = 6;
      break;
    } else if (($3 | 0) == 3) {
      var $_5 = $a;
      var $_57 = $b;
      var $n_5 = $2;
      __label__ = 7;
      break;
    } else if (($3 | 0) == 2) {
      var $_6 = $a;
      var $_68 = $b;
      var $n_6 = $2;
      __label__ = 8;
      break;
    } else if (($3 | 0) == 1) {
      var $_7 = $a;
      var $_79 = $b;
      var $n_7 = $2;
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 2:
    var $n_0;
    var $_02;
    var $_01;
    if ((HEAP32[$_01 >> 2] | 0) == (HEAP32[$_02 >> 2] | 0)) {
      var $_1 = $_01 + 4 | 0;
      var $_13 = $_02 + 4 | 0;
      var $n_1 = $n_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $n_1;
    var $_13;
    var $_1;
    if ((HEAP32[$_1 >> 2] | 0) == (HEAP32[$_13 >> 2] | 0)) {
      var $_2 = $_1 + 4 | 0;
      var $_24 = $_13 + 4 | 0;
      var $n_2 = $n_1;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $n_2;
    var $_24;
    var $_2;
    if ((HEAP32[$_2 >> 2] | 0) == (HEAP32[$_24 >> 2] | 0)) {
      var $_3 = $_2 + 4 | 0;
      var $_35 = $_24 + 4 | 0;
      var $n_3 = $n_2;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $n_3;
    var $_35;
    var $_3;
    if ((HEAP32[$_3 >> 2] | 0) == (HEAP32[$_35 >> 2] | 0)) {
      var $_4 = $_3 + 4 | 0;
      var $_46 = $_35 + 4 | 0;
      var $n_4 = $n_3;
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    var $n_4;
    var $_46;
    var $_4;
    if ((HEAP32[$_4 >> 2] | 0) == (HEAP32[$_46 >> 2] | 0)) {
      var $_5 = $_4 + 4 | 0;
      var $_57 = $_46 + 4 | 0;
      var $n_5 = $n_4;
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $n_5;
    var $_57;
    var $_5;
    if ((HEAP32[$_5 >> 2] | 0) == (HEAP32[$_57 >> 2] | 0)) {
      var $_6 = $_5 + 4 | 0;
      var $_68 = $_57 + 4 | 0;
      var $n_6 = $n_5;
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $n_6;
    var $_68;
    var $_6;
    if ((HEAP32[$_6 >> 2] | 0) == (HEAP32[$_68 >> 2] | 0)) {
      var $_7 = $_6 + 4 | 0;
      var $_79 = $_68 + 4 | 0;
      var $n_7 = $n_6;
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $n_7;
    var $_79;
    var $_7;
    if ((HEAP32[$_7 >> 2] | 0) == (HEAP32[$_79 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $53 = $n_7 - 1 | 0;
    if (($53 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $_01 = $_7 + 4 | 0;
      var $_02 = $_79 + 4 | 0;
      var $n_0 = $53;
      __label__ = 2;
      break;
    }
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7CompareIjEbPT_S1_j["X"] = 1;

function __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK8JSObject11isGeneratorEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js14GeneratorClassE | 0);
}

function __ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE($this, $ni) {
  var $1 = $ni;
  var $2 = $this;
  __ZN8JSObject10setPrivateEPv($2, $1);
  return;
}

function __ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($flags & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $props, $vp);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shapes = __stackBase__;
    var $1 = __stackBase__ + 48;
    var $keys = __stackBase__ + 52;
    var $2 = $cx;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $2);
    var $3 = $shapes;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_($3, $1);
    var $4 = ($flags | 0) == 1;
    var $5 = ($obj | 0) != 0;
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $key_2 = 0;
      __label__ = 34;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = __ZNK8JSObject8getClassEv($7);
    var $10 = HEAP32[$8 + 80 >> 2];
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($8 | 0) == (__ZN2js13IteratorClassE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZNK8JSObject17getNativeIteratorEv($7);
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $flags >>> 1 & 1 ^ 1;
    var $21 = FUNCTION_TABLE[$11]($cx, $obj, $20);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 46;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $21;
    __ZN2JS5Value9setObjectER8JSObject($vp, $24);
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $_1 = 1;
    __label__ = 46;
    break;
   case 7:
    if ($4) {
      __label__ = 8;
      break;
    } else {
      var $key_1 = 0;
      __label__ = 29;
      break;
    }
   case 8:
    var $27 = $cx + 56 | 0;
    var $30 = HEAPU32[HEAP32[$27 >> 2] + 1832 >> 2];
    var $31 = __ZNK8JSObject8getProtoEv($7);
    if (($30 | 0) == 0) {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = $30;
    var $35 = __ZNK8JSObject17getNativeIteratorEv($34);
    var $36 = $35;
    if ((HEAP32[$35 + 28 >> 2] & 12288 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $42 = __ZNK8JSObject8isNativeEv($7);
    if ($42) {
      __label__ = 11;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 11:
    var $44 = __ZNK8JSObject5shapeEv($7);
    var $46 = HEAP32[$35 + 16 >> 2];
    if (($44 | 0) != (HEAP32[$46 >> 2] | 0) | ($31 | 0) == 0) {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $51 = __ZNK8JSObject8isNativeEv($31);
    if ($51) {
      __label__ = 13;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    var $53 = __ZNK8JSObject5shapeEv($31);
    if (($53 | 0) == (HEAP32[$46 + 4 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $58 = __ZNK8JSObject8getProtoEv($31);
    if (($58 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $pobj_0 = $obj;
      var $key_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN2JS5Value9setObjectER8JSObject($vp, $34);
    __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($36, $obj);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $30, $36);
    var $_1 = 1;
    __label__ = 46;
    break;
   case 16:
    var $key_0;
    var $pobj_0;
    var $61 = $pobj_0;
    var $62 = __ZNK8JSObject8isNativeEv($61);
    if ($62) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $64 = __ZNK8JSObject6getOpsEv($7);
    if ((HEAP32[$64 + 112 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $69 = __ZNK8JSObject8getClassEv($61);
    if ((HEAP32[$69 + 24 >> 2] | 0) == 146) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv($shapes);
    var $key_1 = $key_0;
    __label__ = 29;
    break;
   case 20:
    var $75 = __ZNK8JSObject5shapeEv($61);
    var $77 = $75 ^ $key_0 * 65537;
    var $78 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_($shapes, $75);
    if ($78) {
      __label__ = 21;
      break;
    } else {
      var $_1 = 0;
      __label__ = 46;
      break;
    }
   case 21:
    var $80 = __ZNK8JSObject8getProtoEv($61);
    var $81 = $80;
    if (($80 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $pobj_0 = $81;
      var $key_0 = $77;
      __label__ = 16;
      break;
    }
   case 22:
    var $85 = HEAP32[$27 >> 2] + 808 | 0;
    var $86 = __ZNK2js15NativeIterCache3getEj($85, $77);
    if (($86 | 0) == 0) {
      var $key_1 = $77;
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $89 = $86;
    var $90 = __ZNK8JSObject17getNativeIteratorEv($89);
    var $91 = $90;
    if ((HEAP32[$90 + 28 >> 2] & 12288 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $key_1 = $77;
      __label__ = 29;
      break;
    }
   case 24:
    if ((HEAP32[$90 + 24 >> 2] | 0) == ($77 | 0)) {
      __label__ = 25;
      break;
    } else {
      var $key_1 = $77;
      __label__ = 29;
      break;
    }
   case 25:
    var $102 = HEAP32[$90 + 20 >> 2];
    var $103 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes);
    if (($102 | 0) == ($103 | 0)) {
      __label__ = 26;
      break;
    } else {
      var $key_1 = $77;
      __label__ = 29;
      break;
    }
   case 26:
    var $107 = HEAP32[$90 + 16 >> 2];
    var $108 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($shapes);
    var $109 = __ZL7CompareIjEbPT_S1_j($107, $108, $102);
    if ($109) {
      __label__ = 27;
      break;
    } else {
      var $key_1 = $77;
      __label__ = 29;
      break;
    }
   case 27:
    __ZN2JS5Value9setObjectER8JSObject($vp, $89);
    __ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject($91, $obj);
    __ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE($cx, $86, $91);
    var $111 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes);
    if (($111 | 0) == 2) {
      __label__ = 28;
      break;
    } else {
      var $_1 = 1;
      __label__ = 46;
      break;
    }
   case 28:
    var $115 = HEAP32[$27 >> 2] + 1832 | 0;
    HEAP32[$115 >> 2] = $86;
    var $_1 = 1;
    __label__ = 46;
    break;
   case 29:
    var $key_1;
    var $117 = __ZNK8JSObject7isProxyEv($7);
    if ($117) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $119 = __ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($2, $7, $flags, $vp);
    var $_1 = $119;
    __label__ = 46;
    break;
   case 31:
    var $121 = __ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp);
    if ($121) {
      __label__ = 32;
      break;
    } else {
      var $_1 = 0;
      __label__ = 46;
      break;
    }
   case 32:
    var $123 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($123) {
      var $key_2 = $key_1;
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx);
    var $_1 = 1;
    __label__ = 46;
    break;
   case 34:
    var $key_2;
    var $126 = $keys;
    __ZN2js12AutoIdVectorC1EP9JSContext($126, $2);
    if (($flags & 2 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if ($5) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $131 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $keys);
    if ($131) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 37:
    var $133 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($cx, $obj, $flags, $keys, $vp);
    if ($133) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 38:
    if ($5) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $136 = __ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE($cx, $obj, $flags, $keys);
    if ($136) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 40:
    var $138 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes);
    var $139 = __ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE($cx, $obj, $flags, $keys, $138, $key_2, $vp);
    if ($139) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 41:
    var $141 = __ZNK2JS5Value8toObjectEv($vp);
    var $142 = $141;
    var $143 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes);
    if (($143 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $148 = HEAP32[$cx + 56 >> 2] + 808 | 0;
    __ZN2js15NativeIterCache3setEjP8JSObject($148, $key_2, $142);
    __label__ = 43;
    break;
   case 43:
    var $150 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($shapes);
    if (($150 | 0) == 2) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 1;
      __label__ = 45;
      break;
    }
   case 44:
    var $155 = HEAP32[$cx + 56 >> 2] + 1832 | 0;
    HEAP32[$155 >> 2] = $142;
    var $_0 = 1;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($126);
    var $_1 = $_0;
    __label__ = 46;
    break;
   case 46:
    var $_1;
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev($3);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE["X"] = 1;

function __ZN2js5types19MarkIteratorUnknownEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5types23MarkIteratorUnknownSlowEP9JSContext($1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj($7, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js15NativeIterCache3getEj($this, $key) {
  var $1 = __ZN2js15NativeIterCache8getIndexEj($key);
  return HEAP32[$this + ($1 << 2) >> 2];
}

function __ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $arg = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $bytes = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 210244 >> 2] | 0;
    var $8 = __ZL12ATOM_TO_JSIDP6JSAtom1935($7);
    var $9 = $cx;
    var $10 = $obj;
    var $11 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($9, $10, $8, 2, $vp);
    if (($11 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = __ZNK2JS5Value8isObjectEv($vp);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_1 = 1;
    __label__ = 11;
    break;
   case 4:
    var $17 = $cx;
    var $18 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = HEAP32[_sCustomIteratorCount >> 2] + 1 | 0;
    HEAP32[_sCustomIteratorCount >> 2] = $21;
    __label__ = 6;
    break;
   case 6:
    var $24 = ($flags & 2 | 0) == 0;
    __ZN2JSL12BooleanValueEb1988($arg, $24);
    __ZN2JSL11ObjectValueER8JSObject1936($1, $obj);
    var $25 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($17, $1, $vp, 1, $arg, $vp);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $27 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_1 = 1;
      __label__ = 11;
      break;
    }
   case 8:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $29 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($17, $7, $bytes);
    if (($29 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL11ObjectValueER8JSObject1936($2, $obj);
    var $32 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $33 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($17, 0, 212, -1, $2, 0, $32, 0);
    __label__ = 10;
    break;
   case 10:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_1 = 0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15NativeIterCache3setEjP8JSObject($this, $key, $iterobj) {
  var $1 = __ZN2js15NativeIterCache8getIndexEj($key);
  HEAP32[$this + ($1 << 2) >> 2] = $iterobj;
  return;
}

function __Z21js_ThrowStopIterationP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $cx;
    var $3 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($2, 0, 23, $v, 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = $cx;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($9, $1);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13iterator_nextP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject10isIteratorEv($3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js13IteratorClassE);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $10 = __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($cx, $4, $vp);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZNK2JS5Value9toBooleanEv($vp);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $17 = __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $4, $vp);
    var $_0 = $17;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($cx, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = $cx + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($1, 3);
    var $2 = __ZNK2JS5Value8isObjectEv($vp);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($vp);
    var $5 = $4;
    HEAP32[$obj >> 2] = $5;
    var $19 = $5;
    __label__ = 7;
    break;
   case 3:
    var $9 = $cx;
    if (($flags & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $obj;
    var $12 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($9, $vp, $11);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = HEAP32[$obj >> 2];
    __label__ = 7;
    break;
   case 6:
    var $15 = __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($9, $vp);
    var $16 = $15;
    HEAP32[$obj >> 2] = $16;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $19 = $16;
      __label__ = 7;
      break;
    }
   case 7:
    var $19;
    var $20 = __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $19, $flags, $vp);
    var $_0 = $20 & 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_CloseIteratorP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 224 | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($1, 3);
    var $2 = $obj;
    var $3 = __ZNK8JSObject10isIteratorEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject17getNativeIteratorEv($2);
    var $6 = $5 + 28 | 0;
    if ((HEAP32[$6 >> 2] & 1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 + 32 >> 2];
    HEAP32[$cx + 284 >> 2] = $13;
    var $16 = HEAP32[$6 >> 2] & -4097;
    HEAP32[$6 >> 2] = $16;
    var $18 = HEAP32[$5 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = $18;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $21 = __ZNK8JSObject11isGeneratorEv($obj);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZL14CloseGeneratorP9JSContextP8JSObject($cx, $obj);
    var $_0 = $23;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14CloseGeneratorP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject10getPrivateEv($2);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] | 0) == 4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL14UndefinedValueEv1961($1);
    var $12 = __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, 3, $obj, $4, $1);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = __Z22js_CheckForStringIndexi($id);
  __ZN17SingleIdPredicateC1Ei($1, $2);
  var $_0_val = HEAP32[$1 >> 2];
  var $3 = __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_0_val);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $predicate_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $predicate = __stackBase__;
    HEAP32[$predicate >> 2] = $predicate_0;
    var $proto = STACKTOP;
    STACKTOP += 16;
    var $obj2 = STACKTOP;
    STACKTOP += 16;
    var $prop = STACKTOP;
    STACKTOP += 4;
    var $attrs = STACKTOP;
    STACKTOP += 4;
    var $2 = $obj;
    var $3 = $proto;
    var $4 = $cx;
    var $5 = $obj2;
    var $6 = $prop;
    var $iterobj_0_in = $cx + 284 | 0;
    __label__ = 2;
    break;
   case 2:
    var $iterobj_0_in;
    var $iterobj_0 = HEAP32[$iterobj_0_in >> 2];
    if (($iterobj_0 | 0) == 0) {
      var $_7 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $iterobj_0;
    __label__ = 4;
    break;
   case 4:
    var $10 = __ZNK8JSObject17getNativeIteratorEv($9);
    var $11 = $10;
    var $12 = __ZNK2js14NativeIterator9isKeyIterEv($10);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 5:
    if ((HEAP32[$10 >> 2] | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 6:
    var $18 = $10 + 8 | 0;
    var $20 = $10 + 12 | 0;
    if (HEAPU32[$18 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 7:
    var $24 = __ZNK2js14NativeIterator7currentEv($10);
    var $25 = __ZNK2js14NativeIterator3endEv($11);
    var $idp_0 = $24;
    __label__ = 8;
    break;
   case 8:
    var $idp_0;
    if ($idp_0 >>> 0 < $25 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 9:
    var $29 = HEAP32[$idp_0 >> 2];
    var $30 = __ZN17SingleIdPredicateclEi($predicate, $29);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 10:
    var $32 = __ZNK8JSObject8getProtoEv($2);
    if (($32 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($3, $4, $32);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($5, $4, 0);
    var $35 = __ZNK2js16AutoObjectRooter6objectEv($proto);
    var $36 = HEAP32[$idp_0 >> 2];
    var $37 = __ZN2js16AutoObjectRooter4addrEv($obj2);
    var $38 = $35;
    var $39 = $37;
    var $40 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($38, $4, $36, $39, $6);
    if (($40 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = HEAP32[$prop >> 2];
    if (($43 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __ZNK2js16AutoObjectRooter6objectEv($obj2);
    var $47 = $46;
    var $48 = __ZNK8JSObject8isNativeEv($47);
    if ($48) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $50 = $43;
    var $51 = __ZNK2js5Shape10attributesEv($50);
    var $52 = $51 & 255;
    HEAP32[$attrs >> 2] = $52;
    var $58 = $52;
    __label__ = 17;
    break;
   case 15:
    var $54 = HEAP32[$idp_0 >> 2];
    var $55 = __ZN8JSObject13getAttributesEP9JSContextiPj($47, $4, $54, $attrs);
    if (($55 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $58 = HEAP32[$attrs >> 2];
    __label__ = 17;
    break;
   case 17:
    var $58;
    if (($58 & 1 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    __label__ = 21;
    break;
   case 19:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    var $_7 = 0;
    __label__ = 29;
    break;
   case 20:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    __label__ = 27;
    break;
   case 21:
    if (($25 | 0) == (HEAP32[$20 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 22:
    if (($24 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 23:
    if (($idp_0 | 0) == ($24 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js14NativeIterator9incCursorEv($10);
    __label__ = 26;
    break;
   case 25:
    var $72 = $idp_0 + 4 | 0;
    var $76 = $25 - $72 | 0;
    _llvm_memmove_p0i8_p0i8_i32($idp_0, $72, $76, 1, 0);
    var $77 = __ZNK2js14NativeIterator3endEv($11);
    var $78 = $77 - 4 | 0;
    HEAP32[$20 >> 2] = $78;
    __label__ = 26;
    break;
   case 26:
    var $80 = $10 + 28 | 0;
    var $82 = HEAP32[$80 >> 2] | 8192;
    HEAP32[$80 >> 2] = $82;
    __label__ = 28;
    break;
   case 27:
    var $idp_0 = $idp_0 + 4 | 0;
    __label__ = 8;
    break;
   case 28:
    var $iterobj_0_in = $10 + 32 | 0;
    __label__ = 2;
    break;
   case 29:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_["X"] = 1;

function __ZN17SingleIdPredicateC1Ei($this, $id) {
  __ZN17SingleIdPredicateC2Ei($this, $id);
  return;
}

function __Z25js_SuppressDeletedElementP9JSContextP8JSObjectj($cx, $obj, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $cx;
    var $3 = __ZN2js9IndexToIdEP9JSContextjPi($2, $index, $id);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$id >> 2];
    __ZN17SingleIdPredicateC1Ei($1, $5);
    var $_01_val = HEAP32[$1 >> 2];
    var $6 = __ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_01_val);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii($cx, $obj, $begin, $end) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN19IndexRangePredicateC1Eii($1, $begin, $end);
  var $_0_val = HEAP32[$1 >> 2];
  var $_1_val = HEAP32[$1 + 4 >> 2];
  var $2 = __ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_($cx, $obj, $_0_val, $_1_val);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js13StaticStrings6hasIntEi($i) {
  return $i >>> 0 < 256;
}

function _JSID_IS_INT1957($iden) {
  return $iden & 1;
}

function _JSID_TO_INT1958($iden) {
  return $iden >> 1;
}

function _JSID_IS_STRING1965($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js10StackFrame21initFloatingGeneratorEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 96;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb1947($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js16AutoObjectRooter6objectEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js16AutoObjectRooter4addrEv($this) {
  return $this + 12 | 0;
}

function __ZN17SingleIdPredicateclEi($this, $id) {
  return (HEAP32[$this >> 2] | 0) == ($id | 0);
}

function __ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_($cx, $obj, $predicate_0, $predicate_1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $predicate = __stackBase__;
    HEAP32[$predicate >> 2] = $predicate_0;
    HEAP32[$predicate + 4 >> 2] = $predicate_1;
    var $proto = STACKTOP;
    STACKTOP += 16;
    var $obj2 = STACKTOP;
    STACKTOP += 16;
    var $prop = STACKTOP;
    STACKTOP += 4;
    var $attrs = STACKTOP;
    STACKTOP += 4;
    var $2 = $obj;
    var $3 = $proto;
    var $4 = $cx;
    var $5 = $obj2;
    var $6 = $prop;
    var $iterobj_0_in = $cx + 284 | 0;
    __label__ = 2;
    break;
   case 2:
    var $iterobj_0_in;
    var $iterobj_0 = HEAP32[$iterobj_0_in >> 2];
    if (($iterobj_0 | 0) == 0) {
      var $_7 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $iterobj_0;
    __label__ = 4;
    break;
   case 4:
    var $10 = __ZNK8JSObject17getNativeIteratorEv($9);
    var $11 = $10;
    var $12 = __ZNK2js14NativeIterator9isKeyIterEv($10);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 5:
    if ((HEAP32[$10 >> 2] | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 6:
    var $18 = $10 + 8 | 0;
    var $20 = $10 + 12 | 0;
    if (HEAPU32[$18 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 7:
    var $24 = __ZNK2js14NativeIterator7currentEv($10);
    var $25 = __ZNK2js14NativeIterator3endEv($11);
    var $26 = $10 + 28 | 0;
    var $27 = $25;
    var $idp_0 = $24;
    __label__ = 8;
    break;
   case 8:
    var $idp_0;
    if ($idp_0 >>> 0 < $25 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 9:
    var $31 = HEAP32[$idp_0 >> 2];
    var $32 = __ZN19IndexRangePredicateclEi($predicate, $31);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 10:
    var $34 = __ZNK8JSObject8getProtoEv($2);
    if (($34 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($3, $4, $34);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($5, $4, 0);
    var $37 = __ZNK2js16AutoObjectRooter6objectEv($proto);
    var $38 = HEAP32[$idp_0 >> 2];
    var $39 = __ZN2js16AutoObjectRooter4addrEv($obj2);
    var $40 = $37;
    var $41 = $39;
    var $42 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($40, $4, $38, $41, $6);
    if (($42 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $45 = HEAP32[$prop >> 2];
    if (($45 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = __ZNK2js16AutoObjectRooter6objectEv($obj2);
    var $49 = $48;
    var $50 = __ZNK8JSObject8isNativeEv($49);
    if ($50) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $52 = $45;
    var $53 = __ZNK2js5Shape10attributesEv($52);
    var $54 = $53 & 255;
    HEAP32[$attrs >> 2] = $54;
    var $60 = $54;
    __label__ = 17;
    break;
   case 15:
    var $56 = HEAP32[$idp_0 >> 2];
    var $57 = __ZN8JSObject13getAttributesEP9JSContextiPj($49, $4, $56, $attrs);
    if (($57 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $60 = HEAP32[$attrs >> 2];
    __label__ = 17;
    break;
   case 17:
    var $60;
    if (($60 & 1 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    __label__ = 21;
    break;
   case 19:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    var $_7 = 0;
    __label__ = 29;
    break;
   case 20:
    __ZN2js16AutoObjectRooterD1Ev($5);
    __ZN2js16AutoObjectRooterD1Ev($3);
    __label__ = 27;
    break;
   case 21:
    if (($25 | 0) == (HEAP32[$20 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 22:
    if (($24 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 23:
    if (($idp_0 | 0) == ($24 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js14NativeIterator9incCursorEv($10);
    __label__ = 26;
    break;
   case 25:
    var $74 = $idp_0 + 4 | 0;
    var $77 = $27 - $74 | 0;
    _llvm_memmove_p0i8_p0i8_i32($idp_0, $74, $77, 1, 0);
    var $78 = __ZNK2js14NativeIterator3endEv($11);
    var $79 = $78 - 4 | 0;
    HEAP32[$20 >> 2] = $79;
    __label__ = 26;
    break;
   case 26:
    var $82 = HEAP32[$26 >> 2] | 8192;
    HEAP32[$26 >> 2] = $82;
    __label__ = 27;
    break;
   case 27:
    var $idp_0 = $idp_0 + 4 | 0;
    __label__ = 8;
    break;
   case 28:
    var $iterobj_0_in = $10 + 32 | 0;
    __label__ = 2;
    break;
   case 29:
    var $_7;
    STACKTOP = __stackBase__;
    return $_7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_["X"] = 1;

function __ZN19IndexRangePredicateC1Eii($this, $begin, $end) {
  __ZN19IndexRangePredicateC2Eii($this, $begin, $end);
  return;
}

function __Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stackDummy_ = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = $iterobj;
    var $4 = __ZNK8JSObject10isIteratorEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $ni_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject17getNativeIteratorEv($3);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $ni_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAPU32[$6 + 8 >> 2] >>> 0 < HEAPU32[$6 + 12 >> 2] >>> 0;
    var $15 = __ZNK2js14NativeIterator9isKeyIterEv($6);
    if ($15 | $14 ^ 1) {
      __label__ = 4;
      break;
    } else {
      var $ni_0 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, $14);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $ni_0;
    var $18 = $cx + 224 | 0;
    var $19 = __ZNK2JS5Value7isMagicE10JSWhyMagic($18, undef);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 7:
    if ($stackDummy_ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($27);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 9:
    if (($ni_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    var $35 = HEAP32[HEAP32[$cx + 52 >> 2] + 210276 >> 2] | 0;
    var $36 = __ZL12ATOM_TO_JSIDP6JSAtom1935($35);
    var $37 = $cx;
    var $38 = $iterobj;
    var $39 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($37, $38, $36, 0, $rval);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL11ObjectValueER8JSObject1936($1, $iterobj);
    var $42 = $cx;
    var $43 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($42, $1, $rval, 0, 0, $rval);
    if ($43) {
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $45 = __ZN9JSContext18isExceptionPendingEv($42);
    if ($45) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    __ZN9JSContext19getPendingExceptionEv($2, $42);
    var $47 = __ZN2jsL15IsStopIterationERKN2JS5ValueE($2);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    __ZN9JSContext21clearPendingExceptionEv($42);
    __ZN2JS5Value8setMagicE10JSWhyMagic($18, 3);
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $50 = $ni_0;
    var $51 = __ZNK2js14NativeIterator7currentEv($50);
    var $52 = HEAP32[$51 >> 2];
    __ZN2js14NativeIterator9incCursorEv($50);
    var $55 = HEAP32[$ni_0 >> 2];
    var $56 = $cx;
    var $57 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($55, $56, $52, $rval);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$ni_0 + 28 >> 2] & 4 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = __ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_($cx, $52, $rval, $rval);
    if ($65) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $67 = $rval | 0;
    var $68$0 = HEAP32[$67 >> 2];
    var $68$1 = HEAP32[$67 + 4 >> 2];
    var $69 = $18 | 0;
    HEAP32[$69 >> 2] = $68$0;
    HEAP32[$69 + 4 >> 2] = $68$1;
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom1935($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj1979($1);
  return $2;
}

function __ZN2JSL11ObjectValueER8JSObject1936($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL15IsStopIterationERKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject15isStopIterationEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_($cx, $id, $val, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vec = __stackBase__;
    var $tvr = __stackBase__ + 16;
    var $1 = $vec | 0;
    __ZN2jsL9IdToValueEi1939($1, $id);
    var $2 = $val | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $vec + 8 | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $5, 2, $1);
    var $6 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($5, 2, $1, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($rval, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE($cx, $iterobj, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $iterobj;
    var $3 = __ZNK8JSObject10isIteratorEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject17getNativeIteratorEv($2);
    if (($5 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js14NativeIterator9isKeyIterEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $10 = __ZNK2js14NativeIterator7currentEv($5);
    var $11 = HEAP32[$10 >> 2];
    __ZN2jsL9IdToValueEi1939($1, $11);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $rval | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    __ZN2js14NativeIterator9incCursorEv($5);
    var $15 = __ZNK2JS5Value8isStringEv($rval);
    if ($15) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK2JS5Value7isInt32Ev($rval);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = __ZNK2JS5Value7toInt32Ev($rval);
    var $20 = __ZN2js13StaticStrings6hasIntEi($19);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $25 = __ZN2js13StaticStrings6getIntEi($24, $19);
    var $str_0 = $25 | 0;
    __label__ = 9;
    break;
   case 8:
    var $28 = $cx;
    var $29 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($28, $rval);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $str_0 = $29;
      __label__ = 9;
      break;
    }
   case 9:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($rval, $str_0);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $33 = $cx + 224 | 0;
    var $34 = $33 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $rval | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    __ZN2JS5Value8setMagicE10JSWhyMagic($33, 3);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZN2jsL9IdToValueEi1939($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING1965($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING1974($id);
    __ZN2JSL11StringValueEP8JSString1973($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT1957($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT1958($id);
    __ZN2JSL10Int32ValueEi1975($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT1976($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT1977($id);
    __ZN2JSL11ObjectValueER8JSObject1936($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv1961($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var $1 = __ZN2jsL15IsStopIterationERKN2JS5ValueE($v);
  HEAP32[$bp >> 2] = $1 & 1;
  return 1;
}

function __ZL18generator_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv(undef, $2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15generator_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 4 >> 2] - 2 | 0) >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $2;
    var $10 = __ZN11JSGenerator13floatingFrameEv($9);
    var $12 = $2 + 32 | 0;
    var $13 = $10;
    var $14 = __ZNK2js10StackFrame13formalArgsEndEv($13);
    var $15 = $trc;
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($15, $12, $14);
    __Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE($15, $13);
    var $16 = __ZNK2js10StackFrame5slotsEv($10);
    var $19 = HEAP32[$2 + 8 >> 2];
    __ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_($15, $16, $19);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_NewGeneratorP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext4regsEv($1);
    var $3 = __ZNK2js9FrameRegs2fpEv($2);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6;
    var $8 = __ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext($7, $1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $8;
    var $12 = $6;
    var $13 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942($cx, $11, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZNK2js10StackFrame10actualArgsEv($3);
    var $17 = $16 - 16 | 0;
    var $18 = __ZNK2js10StackFrame13formalArgsEndEv($3);
    var $22 = $18 - $17 >> 3;
    var $23 = $3;
    var $24 = __ZNK2js10StackFrame8numSlotsEv($23);
    var $28 = ($22 + ($24 + 6) << 3) + 40 | 0;
    var $29 = __ZN9JSContext7malloc_Ej($1, $28);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = $29 + 32 | 0;
    var $34 = $33 + ($22 << 3) | 0;
    var $35 = $34;
    HEAP32[$29 >> 2] = $13;
    HEAP32[$29 + 4 >> 2] = 0;
    HEAP32[$29 + 24 >> 2] = 0;
    HEAP32[$29 + 28 >> 2] = $35;
    var $44 = $29 + 8 | 0;
    var $45 = $2;
    var $46 = $34;
    __ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE($44, $45, $46);
    var $48 = HEAP32[$2 >> 2];
    __ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_($46, $33, $23, $17, $48);
    __ZN2js10StackFrame21initFloatingGeneratorEv($35);
    var $49 = $13;
    __ZN8JSObject10setPrivateEPv($49, $29);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_NewGeneratorP9JSContext["X"] = 1;

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js14GeneratorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1947($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948($cx, $proto, $parent, $4);
  return $5;
}

function __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($fp) {
  var $1 = $fp;
  var $2 = __ZNK2js10StackFrame10actualArgsEv($1);
  return $2 - 48 | 0;
}

function __ZL14generator_nextP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 0, $vp, $argc);
  return $1;
}

function __ZL14generator_sendP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 1, $vp, $argc);
  return $1;
}

function __ZL15generator_throwP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 2, $vp, $argc);
  return $1;
}

function __ZL15generator_closeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, 3, $vp, $argc);
  return $1;
}

function __ZN2js12GlobalObject18initGeneratorClassEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js14GeneratorClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, 0, __ZL17generator_methods);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject1936($1, $5);
    var $10 = $this;
    __ZN8JSObject15setReservedSlotEjRKN2JS5ValueE($10, 112, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_InitIteratorClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $iter;
    var $7 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($4, $5, 22, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$iter >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $10;
      __label__ = 6;
      break;
    }
   case 3:
    var $13 = __ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $15 = __ZN2js12GlobalObject18initGeneratorClassEP9JSContext($3, $cx);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js13IteratorClassE);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 210108 >> 2];
    var $11 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($1, $2, 148, __ZN2js13IteratorClassE, $10, 2);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11 | 0;
    var $15 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($2, $14, $3);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $17 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($2, $3, 0, __ZL16iterator_methods);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $cx;
    var $20 = $global;
    var $21 = $11;
    var $22 = $3;
    var $23 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($19, $20, 22, $21, $22);
    var $_0 = $23;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js18StopIterationClassE);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $3;
    var $8 = $cx;
    var $9 = __ZN8JSObject6freezeEP9JSContext($7, $8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = $global;
    var $12 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($8, $11, 23, $7, $7);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $global;
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($14, __ZN2js18StopIterationClassE);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = $proto;
    var $15 = __ZNK8JSObject9getParentEv($14);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, undef, __ZN2js14GeneratorClassE, $8, $18, 0, (__ZN2js14GeneratorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $21 = __ZNK2js5Class8isNativeEv(__ZN2js14GeneratorClassE);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951($cx, $10, $8, $kind);
    if ($23) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js14GeneratorClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $5 = __ZNK8JSObject8numSlotsEv($4);
    if ($3 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $3);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = $type;
    var $13 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($12, __ZN2js14GeneratorClassE);
    var $14 = $cx;
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($12, $14, __ZN2js14GeneratorClassE, $kind);
    var $empty_0_in = $16;
    __label__ = 6;
    break;
   case 5:
    var $18 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($14, __ZN2js14GeneratorClassE);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19IndexRangePredicateclEi($this, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_INT1957($id);
    if (($1 | 0) == 0) {
      var $13 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this >> 2];
    var $6 = _JSID_TO_INT1958($id);
    if (($5 | 0) > ($6 | 0)) {
      var $13 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = ($6 | 0) < (HEAP32[$this + 4 >> 2] | 0);
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv1961($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL8IteratorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($argc >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $vp + 24 | 0;
    var $4 = __Z17js_ValueToBooleanRKN2JS5ValueE($3);
    var $phitmp2 = ($4 | 0) != 0 ? 8 : 14;
    var $8 = $phitmp2;
    __label__ = 4;
    break;
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $8 = 14;
      __label__ = 4;
      break;
    }
   case 4:
    var $8;
    var $9 = $vp + 16 | 0;
    var $st$2$0 = $9 | 0;
    var $10$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $9 + 4 | 0;
    var $10$1 = HEAPU32[$st$2$1 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $15 = $8;
    var $14$1 = $10$1;
    var $14$0 = $10$0;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv1961($1);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $15 = 14;
    var $14$1 = HEAP32[$st$2$1 >> 2];
    var $14$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $14$0;
    var $14$1;
    var $15;
    var $16 = $vp | 0;
    HEAP32[$16 >> 2] = $14$0;
    HEAP32[$16 + 4 >> 2] = $14$1;
    var $17 = __Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE($cx, $15, $vp);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj1979($bits) {
  return $bits;
}

function _JSID_TO_STRING1974($iden) {
  return $iden;
}

function _JSID_IS_OBJECT1976($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT1977($iden) {
  return $iden & -8;
}

function _INT_TO_JSID1982($i) {
  return $i << 1 | 1;
}

function __ZN2js15NativeIterCache8getIndexEj($key) {
  return $key & 255;
}

function __ZN2js10StackFrame13clearYieldingEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -257;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 4 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19IndexRangePredicateC2Eii($this, $begin, $end) {
  HEAP32[$this >> 2] = $begin;
  HEAP32[$this + 4 >> 2] = $end;
  return;
}

function __ZN17SingleIdPredicateC2Ei($this, $id) {
  HEAP32[$this >> 2] = $id;
  return;
}

function __ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj($cx, $op, $vp, $argc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = $cx;
    var $6 = $vp + 8 | 0;
    var $7 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK8JSObject11isGeneratorEv($8);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js14GeneratorClassE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $14 = __ZNK8JSObject10getPrivateEv($7);
    var $15 = $14;
    if (($14 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $14 + 4 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($20 | 0) == 4) {
      __label__ = 11;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 6:
    if (($op | 0) == 1) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 0 || ($op | 0) == 2) {
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if (($argc | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = $vp + 16 | 0;
    var $26 = __ZNK2JS5Value11isUndefinedEv($25);
    if ($26) {
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($5, 0, 182, 1, $25, 0, 0, 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    HEAP32[$19 >> 2] = 4;
    __ZN2JSL14UndefinedValueEv1961($1);
    var $30 = $1 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 11:
    if (($op | 0) == 0 || ($op | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    var $35 = __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    if (($argc | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $39 = $vp + 16 | 0;
    var $st$1$0 = $39 | 0;
    var $40$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$1$1 >> 2];
    var $41 = $2 | 0;
    var $st$6$0 = $41 | 0;
    HEAP32[$st$6$0 >> 2] = $40$0;
    var $st$6$1 = $41 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $40$1;
    __label__ = 16;
    break;
   case 15:
    __ZN2JSL14UndefinedValueEv1961($2);
    __label__ = 16;
    break;
   case 16:
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($5, $2);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    __ZN2JSL14UndefinedValueEv1961($3);
    var $45 = $3 | 0;
    var $46$0 = HEAP32[$45 >> 2];
    var $46$1 = HEAP32[$45 + 4 >> 2];
    var $47 = $vp | 0;
    HEAP32[$47 >> 2] = $46$0;
    HEAP32[$47 + 4 >> 2] = $46$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 18:
    if (($op - 1 | 0) >>> 0 < 2 & ($argc | 0) != 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $53 = $vp + 16 | 0;
    var $st$1$0 = $53 | 0;
    var $54$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $53 + 4 | 0;
    var $54$1 = HEAP32[$st$1$1 >> 2];
    var $55 = $4 | 0;
    var $st$6$0 = $55 | 0;
    HEAP32[$st$6$0 >> 2] = $54$0;
    var $st$6$1 = $55 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $54$1;
    __label__ = 21;
    break;
   case 20:
    __ZN2JSL14UndefinedValueEv1961($4);
    __label__ = 21;
    break;
   case 21:
    var $57 = __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, $op, $8, $15, $4);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $60 = $14;
    var $61 = __ZN11JSGenerator13floatingFrameEv($60);
    var $62 = $61;
    var $63 = __ZN2js10StackFrame11returnValueEv($62);
    var $64 = $63 | 0;
    var $65$0 = HEAP32[$64 >> 2];
    var $65$1 = HEAP32[$64 + 4 >> 2];
    var $66 = $vp | 0;
    HEAP32[$66 >> 2] = $65$0;
    HEAP32[$66 + 4 >> 2] = $65$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj["X"] = 1;

function __ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE($cx, $op, $obj, $gen, $arg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $gfg = __stackBase__ + 24;
    var $4 = $gen + 4 | 0;
    if ((HEAP32[$4 >> 2] - 2 | 0) >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL17ObjectOrNullValueEP8JSObject1967($1, $obj);
    var $7 = $gen;
    var $8 = __ZN11JSGenerator13floatingFrameEv($7);
    var $9 = $8;
    var $10 = __ZNK2js10StackFrame3funEv($9);
    var $11 = _JS_GetFunctionId($10);
    var $12 = $cx;
    var $13 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($12, 0, 175, 1, $1, $11, 0, 0);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 3:
    var $15 = __ZN9JSContext25ensureGeneratorStackSpaceEv($cx);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 17;
      break;
    }
   case 4:
    if (($op | 0) == 0 || ($op | 0) == 1) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if ((HEAP32[$4 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = $arg | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = HEAP32[$gen + 8 >> 2] - 8 | 0;
    var $st$8$0 = $25 | 0;
    HEAP32[$st$8$0 >> 2] = $24$0;
    var $st$8$1 = $25 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $24$1;
    __label__ = 7;
    break;
   case 7:
    HEAP32[$4 >> 2] = 2;
    __label__ = 10;
    break;
   case 8:
    var $28 = $arg | 0;
    var $29$0 = HEAP32[$28 >> 2];
    var $29$1 = HEAP32[$28 + 4 >> 2];
    var $30 = $2 | 0;
    HEAP32[$30 >> 2] = $29$0;
    HEAP32[$30 + 4 >> 2] = $29$1;
    var $31 = $cx;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($31, $2);
    HEAP32[$4 >> 2] = 2;
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL10MagicValueE10JSWhyMagic1968($3);
    var $33 = $cx;
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($33, $3);
    HEAP32[$4 >> 2] = 3;
    __label__ = 10;
    break;
   case 10:
    var $35 = $gen;
    var $36 = __ZN11JSGenerator13floatingFrameEv($35);
    var $37 = $36;
    __ZN2js19GeneratorFrameGuardC1Ev($gfg);
    var $39 = $cx + 60 | 0;
    var $40 = $cx;
    var $41 = $gfg;
    var $42 = __ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE($39, $40, $35, $41);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$4 >> 2] = 4;
    __ZN2js19GeneratorFrameGuardD1Ev($gfg);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 12:
    var $44 = $gfg;
    var $45 = __ZNK2js10FrameGuard2fpEv($44);
    var $46 = $gen + 8 | 0;
    var $47 = $cx;
    var $48 = __ZNK9JSContext4regsEv($47);
    var $49 = $46;
    var $50 = $48;
    HEAP32[$49 >> 2] = HEAP32[$50 >> 2];
    HEAP32[$49 + 4 >> 2] = HEAP32[$50 + 4 >> 2];
    HEAP32[$49 + 8 >> 2] = HEAP32[$50 + 8 >> 2];
    HEAP32[$49 + 12 >> 2] = HEAP32[$50 + 12 >> 2];
    var $51 = __ZN9JSContext14enterGeneratorEP11JSGenerator($cx, $gen);
    var $52 = $cx + 284 | 0;
    var $53 = HEAP32[$52 >> 2];
    var $54 = $gen + 24 | 0;
    var $55 = HEAP32[$54 >> 2];
    HEAP32[$52 >> 2] = $55;
    var $56 = __ZNK2js10StackFrame6scriptEv($45);
    var $57 = __ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE($47, $56, $45);
    var $58 = HEAP32[$52 >> 2];
    HEAP32[$54 >> 2] = $58;
    HEAP32[$52 >> 2] = $53;
    __ZN9JSContext14leaveGeneratorEP11JSGenerator($cx, undef);
    __ZN2js19GeneratorFrameGuardD1Ev($gfg);
    var $59 = __ZN11JSGenerator13floatingFrameEv($35);
    var $60 = $59;
    var $61 = __ZN2js10StackFrame10isYieldingEv($60);
    if ($61) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    __ZN2js10StackFrame13clearYieldingEv($37);
    HEAP32[$4 >> 2] = 1;
    var $_1 = 1;
    __label__ = 17;
    break;
   case 14:
    var $64 = $36;
    __ZN2js10StackFrame16clearReturnValueEv($64);
    HEAP32[$4 >> 2] = 4;
    if ($57) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 0;
      __label__ = 17;
      break;
    }
   case 15:
    if (($op | 0) == 3) {
      var $_1 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $68 = __Z21js_ThrowStopIterationP9JSContext($cx);
    var $_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE["X"] = 1;

function __ZN2JSL17ObjectOrNullValueEP8JSObject1967($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $1);
  return;
}

function __ZN9JSContext25ensureGeneratorStackSpaceEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 288 | 0;
    var $2 = $1;
    var $3 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv($2);
    var $4 = $3 + 1 | 0;
    var $5 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj($1, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this;
    __Z20js_ReportOutOfMemoryP9JSContext($7);
    __label__ = 3;
    break;
   case 3:
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10MagicValueE10JSWhyMagic1968($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 4);
  return;
}

function __ZN2js19GeneratorFrameGuardC1Ev($this) {
  __ZN2js19GeneratorFrameGuardC2Ev($this);
  return;
}

function __ZN9JSContext14enterGeneratorEP11JSGenerator($this, $gen) {
  var $1 = $this + 288 | 0;
  var $2 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($1, $gen);
  return $2;
}

function __ZN9JSContext14leaveGeneratorEP11JSGenerator($this, $gen) {
  var $1 = $this + 288 | 0;
  __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv($1);
  return;
}

function __ZN2js19GeneratorFrameGuardD1Ev($this) {
  __ZN2js19GeneratorFrameGuardD2Ev($this);
  return;
}

function __ZN2js19GeneratorFrameGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js10FrameGuard6pushedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this;
    __ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE(undef, $4);
    __label__ = 3;
    break;
   case 3:
    __ZN2js10FrameGuardD2Ev($1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 4 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $this;
    var $12 = __ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv($11);
    var $13 = $12;
    var $14 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv($11);
    var $15 = $14;
    __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $13, $15);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js19GeneratorFrameGuardC2Ev($this) {
  var $1 = $this;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString1973($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi1975($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN2JSL12BooleanValueEb1988($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 764 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js13IteratorClassE, $5);
  return $6;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991($cx) {
  var $3 = HEAPU32[__ZN2js13IteratorClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb1947($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js13IteratorClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $22 = __ZNK2JS5Value8isObjectEv($1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js13IteratorClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js13IteratorClassE, $3, $10, 0, (__ZN2js13IteratorClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js13IteratorClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj($1, $len);
  return $2;
}

function __ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $flags, $ht, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $props;
    var $2 = __ZNK2js16AutoVectorRooterIiE6lengthEv($1);
    var $3 = $pobj;
    var $4 = __ZNK8JSObject12lastPropertyEv($3);
    var $5 = $r;
    var $6 = $4;
    __ZNK2js5Shape3allEv($5, $6);
    var $7 = $r;
    __label__ = 2;
    break;
   case 2:
    var $9 = __ZNK2js5Shape5Range5emptyEv($5);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js5Shape5Range5frontEv($7);
    var $13 = HEAP32[$11 + 12 >> 2];
    var $14 = _JSID_IS_DEFAULT_XML_NAMESPACE($13);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = __ZNK2js5Shape10enumerableEv($11);
    var $18 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $13, $17, $flags, $ht, $props);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2js5Shape5Range8popFrontEv($7);
    __label__ = 2;
    break;
   case 6:
    var $21 = __ZN2js16AutoVectorRooterIiE5beginEv($1);
    var $22 = $21 + ($2 << 2) | 0;
    var $23 = __ZN2js16AutoVectorRooterIiE3endEv($1);
    __ZN2jsL7ReverseIiEEvPT_S2_1995($22, $23);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($cx_0_11_val_0_70_28_val, $pobj, $flags, $ht, $props) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx_0_11_val_0_70_28_val | 0;
    var $2 = __ZL12ATOM_TO_JSIDP6JSAtom1935($1);
    var $3 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $2, 0, $flags, $ht, $props);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $5 = $pobj;
    var $6 = __ZNK8JSObject14getArrayLengthEv($5);
    if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN8JSObject30getDenseArrayInitializedLengthEv($5);
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($5);
    var $i_0 = 0;
    var $vp_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $vp_0;
    var $i_0;
    if ($i_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    var $14 = __ZNK2JS5Value7isMagicE10JSWhyMagic($vp_0, undef);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = _INT_TO_JSID1982($i_0);
    var $17 = __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $16, 1, $flags, $ht, $props);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    var $vp_0 = $vp_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE($pobj, $id, $enumerable, $flags, $ht, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $id;
    if (($flags & 8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $pobj;
    var $7 = __ZNK8JSObject7isProxyEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject6getOpsEv($6);
    if ((HEAP32[$9 + 112 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi($p, $ht, $1);
    var $14 = $p | 0;
    __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv($2, $14);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 5:
    var $19 = $pobj;
    var $20 = __ZNK8JSObject8getProtoEv($19);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $23 = __ZNK8JSObject7isProxyEv($19);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZNK8JSObject6getOpsEv($19);
    if ((HEAP32[$25 + 112 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_($ht, $p, $1);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 9:
    if ($enumerable) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($flags & 16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $props | 0;
    var $37 = __ZN2js16AutoVectorRooterIiE6appendERKi($36, $1);
    var $_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($this, $cx, $iterop, $statep, $idp) {
  var $1 = $this;
  var $2 = __ZNK8JSObject6getOpsEv($1);
  var $4 = HEAP32[$2 + 112 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 150;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $iterop, $statep, $idp);
  return $8;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev($this) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($5, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 152,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_($1, $p, $t);
  return $2;
}

function __ZN2js16AutoVectorRooterIiE6appendERKi($this, $v) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$v >> 2];
  var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_($1, $2);
  return $3;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi($t) {
  return $t;
}

function __ZN12IdHashPolicy4hashEi($id) {
  return $id;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN12IdHashPolicy5matchEii($id1, $id2) {
  return ($id1 | 0) == ($id2 | 0);
}

function _JSID_IS_DEFAULT_XML_NAMESPACE($iden) {
  return ($iden | 0) == 6 & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2026($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKiE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIiEcvRiEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIiEC2ERi($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKiEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKiE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2jsL7ReverseIiEEvPT_S2_1995($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $beg;
    var $_01 = $end;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $_0;
    if (($_0 | 0) == ($_01 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $_01 - 4 | 0;
    if (($4 | 0) == ($_0 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = HEAP32[$_0 >> 2];
    var $8 = HEAP32[$4 >> 2];
    HEAP32[$_0 >> 2] = $8;
    HEAP32[$4 >> 2] = $7;
    var $_0 = $_0 + 4 | 0;
    var $_01 = $4;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $this;
    var $13 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv($12);
    var $14 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv($12);
    __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($9, $13, $14);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKiE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($14);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $16 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($12, $10);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $20 = $this + 16 | 0;
    var $22 = HEAP32[$20 >> 2] + 1 | 0;
    HEAP32[$20 >> 2] = $22;
    HEAP32[$2 >> 2] = $16;
    var $23 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $25 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($src_01);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($src_01);
    var $27 = __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($src_01);
    var $28 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $27);
    __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($28, $1);
    __label__ = 7;
    break;
   case 7:
    var $30 = $src_01 + 8 | 0;
    if (($30 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $30;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj($12, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKiEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $12 = $e_01 + 8 | 0;
    if (($12 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $12;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIiEENS_7MoveRefIT_EERS2_($1, $7);
  var $8 = __ZNK2js7MoveRefIiEcvRiEv($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIiEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIiEC1ERi($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIiEC1ERi($this, $t) {
  __ZN2js7MoveRefIiEC2ERi($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKiEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKiEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_($l);
  var $2 = __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN12IdHashPolicy4hashEi($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = HEAP32[$l >> 2];
  var $5 = __ZN12IdHashPolicy5matchEii($3, $4);
  return $5;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function _JS_CeilingLog2($n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($n >>> 0 < 2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $n - 1 | 0;
    var $4 = _llvm_ctlz_i32($3);
    var $7 = 32 - $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_FloorLog2($n) {
  var $1 = $n | 1;
  var $2 = _llvm_ctlz_i32($1);
  return 31 - $2 | 0;
}

function __ZN2js9MathCacheC2Ev($this) {
  var $1 = $this;
  _memset($1, 0, 81920, 1);
  return;
}

function __Z11js_math_absP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = _fabs($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_math_ceil_impld($x) {
  var $1 = _ceil($x);
  return $1;
}

function __Z12js_math_ceilP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = __Z17js_math_ceil_impld($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_math_floor_impld($x) {
  var $1 = _floor($x);
  return $1;
}

function __Z13js_math_floorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = __Z18js_math_floor_impld($9);
    var $11 = __ZN2JS5Value9setNumberEd($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_math_maxP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $1 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $i_0 = 0;
    var $z_0 = $1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($vp, $1);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $z_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $9 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $8, $x);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $11 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $12 = __ZL15JSDOUBLE_IS_NaNd2026($11);
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $15);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 8:
    if ($11 == 0 & $11 == $z_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $20 = _copysign(1, $z_0);
    if ($20 == -1) {
      __label__ = 10;
      break;
    } else {
      var $z_1 = $z_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $z_1 = $11;
    __label__ = 12;
    break;
   case 11:
    var $25 = $11 > $z_0 ? $11 : $z_0;
    var $z_1 = $25;
    __label__ = 12;
    break;
   case 12:
    var $z_1;
    var $i_0 = $i_0 + 1 | 0;
    var $z_0 = $z_1;
    __label__ = 4;
    break;
   case 13:
    var $29 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11js_math_minP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $1 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $cx;
    var $i_0 = 0;
    var $z_0 = $1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value9setDoubleEd($vp, $1);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 4:
    var $z_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $9 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($3, $8, $x);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 6:
    var $11 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $12 = __ZL15JSDOUBLE_IS_NaNd2026($11);
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $15);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 8:
    if ($11 == 0 & $11 == $z_0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $20 = _copysign(1, $11);
    if ($20 == -1) {
      __label__ = 10;
      break;
    } else {
      var $z_1 = $z_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $z_1 = $11;
    __label__ = 12;
    break;
   case 11:
    var $25 = $11 < $z_0 ? $11 : $z_0;
    var $z_1 = $25;
    __label__ = 12;
    break;
   case 12:
    var $z_1;
    var $i_0 = $i_0 + 1 | 0;
    var $z_0 = $z_1;
    __label__ = 4;
    break;
   case 13:
    var $29 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js9MathClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18JSDOUBLE_IS_FINITEd2027($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN2js9MathCache4hashEd($this, $x) {
  tempDoubleF64[0] = $x;
  var $4 = tempDoubleI32[1] ^ tempDoubleI32[0];
  var $6 = $4 & 65535 ^ $4 >>> 16;
  return $6 & 4095 ^ $6 >>> 4;
}

function __ZL20JSDOUBLE_IS_INFINITEd($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & -1) == 0 && (tempDoubleI32[1] & 2147483647) == 2146435072) & 1;
}

function __ZL14random_setSeedP9JSContextx($cx, $seed$0, $seed$1) {
  var $2$1 = $seed$1 & 65535 ^ 5;
  var $3 = $cx + 212 | 0;
  HEAP32[$3 >> 2] = $seed$0 & -1 ^ -554899859;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __Z17js_IsMathFunctionPFiP9JSContextjPN2JS5ValueEE($native) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ((HEAP32[__ZL19math_static_methods + $i_0 * 12 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[__ZL19math_static_methods + $i_0 * 12 + 4 >> 2] | 0) == ($native | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb2034($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2047($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _OBJECT_TO_JSVAL_IMPL2048($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL11random_nextP9JSContexti($cx, $bits) {
  var $1 = $cx + 212 | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3$0 = (i64Math.multiply($2$0, $2$1, -554899859, 5), i64Math.result[0]);
  var $3$1 = i64Math.result[1];
  var $4$0 = (i64Math.add($3$0, $3$1, 11, 0), i64Math.result[0]);
  var $4$1 = i64Math.result[1];
  var $5$0 = $4$0 & -1;
  var $5$1 = $4$1 & 65535;
  HEAP32[$1 >> 2] = $5$0;
  HEAP32[$1 + 4 >> 2] = $5$1;
  var $7$0 = 48 - $bits | 0;
  var $8 = Runtime.bitshift64($5$0, $5$1, "lshr", $7$0);
  return [ $8[0], $8[1] ];
}

function __Z11js_math_powP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $y = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $9, $y);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZL18JSDOUBLE_IS_FINITEd2027($12);
    var $or_cond = ($13 | 0) != 0 & $12 != 0;
    var $16 = (tempDoubleI32[0] = HEAP32[$y >> 2], tempDoubleI32[1] = HEAP32[$y + 4 >> 2], tempDoubleF64[0]);
    if ($or_cond) {
      __label__ = 6;
      break;
    } else {
      var $28 = $16;
      __label__ = 10;
      break;
    }
   case 6:
    if ($16 == .5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = _sqrt($12);
    var $21 = __ZN2JS5Value9setNumberEd($vp, $20);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    if ($16 == -.5) {
      __label__ = 9;
      break;
    } else {
      var $28 = $16;
      __label__ = 10;
      break;
    }
   case 9:
    var $25 = _sqrt($12);
    var $26 = 1 / $25;
    var $27 = __ZN2JS5Value9setNumberEd($vp, $26);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $28;
    var $29 = __ZL18JSDOUBLE_IS_FINITEd2027($28);
    if (($29 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ($12 == 1 | $12 == -1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $35 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $35);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 13:
    if ($28 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN2JS5Value8setInt32Ei($vp, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $39 = __ZNK2JS5Value7isInt32Ev($9);
    if ($39) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $41 = __ZNK2JS5Value7toInt32Ev($9);
    var $42 = __ZL4powidi($12, $41);
    var $z_0 = $42;
    __label__ = 18;
    break;
   case 17:
    var $44 = _llvm_pow_f64($12, $28);
    var $z_0 = $44;
    __label__ = 18;
    break;
   case 18:
    var $z_0;
    var $46 = __ZN2JS5Value9setNumberEd($vp, $z_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z11js_math_powP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL4powidi($x, $y) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($y | 0) < 0;
    var $3 = $1 ? -$y | 0 : $y;
    var $p_0 = 1;
    var $m_0 = $x;
    var $n_0 = $3;
    __label__ = 2;
    break;
   case 2:
    var $n_0;
    var $m_0;
    var $p_0;
    if (($n_0 & 1 | 0) == 0) {
      var $p_1 = $p_0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $p_1 = $p_0 * $m_0;
    __label__ = 4;
    break;
   case 4:
    var $p_1;
    var $10 = $n_0 >>> 1;
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $p_1;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = 1 / $p_1;
    if ($14 == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $14;
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = __ZL20JSDOUBLE_IS_INFINITEd($p_1);
    if (($17 | 0) == 0) {
      var $_0 = $14;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $y | 0;
    var $21 = _llvm_pow_f64($x, $20);
    var $_0 = $21;
    __label__ = 10;
    break;
   case 9:
    var $p_0 = $p_1;
    var $m_0 = $m_0 * $m_0;
    var $n_0 = $10;
    __label__ = 2;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_InitRandomP9JSContext($cx) {
  var $1 = _PRMJ_Now();
  var $1$0 = $1[0];
  var $1$1 = $1[1];
  var $2$0 = (i64Math.divide($1$0, $1$1, 1e3, 0), i64Math.result[0]);
  var $2$1 = i64Math.result[1];
  var $10$0 = $2$0 ^ $cx ^ HEAP32[$cx >> 2];
  var $10$1 = $2$1 ^ 0 ^ 0;
  __ZL14random_setSeedP9JSContextx($cx, $10$0, $10$1);
  return;
}

function __Z18js_math_round_impld($x) {
  var $1 = $x + .5;
  var $2 = _floor($1);
  var $3 = _copysign($2, $x);
  return $3;
}

function __Z13js_math_roundP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $10 = $9 + .5;
    var $11 = _floor($10);
    var $12 = _copysign($11, $9);
    var $13 = __ZN2JS5Value9setNumberEd($vp, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_math_sqrtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 154, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12GetMathCacheEP9JSContext($cx) {
  var $2 = HEAP32[$cx + 56 >> 2];
  var $3 = __ZN13JSCompartment12getMathCacheEP9JSContext($2, $cx);
  return $3;
}

function __ZN2js9MathCache6lookupEPFddEd($this, $f, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9MathCache4hashEd(undef, $x);
    var $2 = $this + $1 * 20 | 0;
    var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
    var $5 = $this + $1 * 20 + 8 | 0;
    if ($3 == $x) {
      __label__ = 2;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[$5 >> 2] | 0) == ($f | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $this + $1 * 20 + 12 | 0;
    var $11 = (tempDoubleI32[0] = HEAP32[$10 >> 2], tempDoubleI32[1] = HEAP32[$10 + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $_pre_phi;
    tempDoubleF64[0] = $x, HEAP32[$2 >> 2] = tempDoubleI32[0], HEAP32[$2 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$_pre_phi >> 2] = $f;
    var $12 = FUNCTION_TABLE[$f]($x);
    var $13 = $this + $1 * 20 + 12 | 0;
    tempDoubleF64[0] = $12, HEAP32[$13 >> 2] = tempDoubleI32[0], HEAP32[$13 + 4 >> 2] = tempDoubleI32[1];
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13math_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210048 >> 2] | 0;
  __ZN2JS5Value9setStringEP8JSString($vp, $5);
  return 1;
}

function __ZL9math_acosP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 156, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9math_asinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 158, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9math_atanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 160, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10math_atan2P9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    var $y = __stackBase__ + 8;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $9, $y);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = (tempDoubleI32[0] = HEAP32[$y >> 2], tempDoubleI32[1] = HEAP32[$y + 4 >> 2], tempDoubleF64[0]);
    var $14 = __ZL17math_atan2_kerneldd($12, $13);
    __ZN2JS5Value9setDoubleEd($vp, $14);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_cosP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 162, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_expP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 164, $12);
    var $14 = __ZN2JS5Value9setNumberEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_logP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 166, $12);
    var $14 = __ZN2JS5Value9setNumberEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11math_randomP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL17random_nextDoubleP9JSContext($cx);
  __ZN2JS5Value9setDoubleEd($vp, $1);
  return 1;
}

function __ZL8math_sinP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 168, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8math_tanP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($6, $5, $x);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2jsL12GetMathCacheEP9JSContext($cx);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $13 = __ZN2js9MathCache6lookupEPFddEd($9, 170, $12);
    __ZN2JS5Value9setDoubleEd($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_InitMathClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    var $7 = __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL2033($1, $2);
    var $8 = $cx;
    var $9 = $obj;
    var $10 = _JS_DefineProperty($8, $9, STRING_TABLE._js_Math_str | 0, $1, 10, 12, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $2;
    var $14 = _JS_DefineFunctions($8, $13, __ZL19math_static_methods);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = _JS_DefineConstDoubles($8, $13, __ZL14math_constants);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $obj;
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($20, __ZN2js9MathClassE);
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032($cx, $parent) {
  var $3 = HEAPU32[__ZN2js9MathClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2034($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL2033($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL2048($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout2047($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $4;
    var $20 = __ZNK8JSObject9getParentEv($19);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, undef, __ZN2js9MathClassE, $12, $23, 0, (__ZN2js9MathClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $26 = __ZNK2js5Class8isNativeEv(__ZN2js9MathClassE);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039($cx, $14, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js9MathClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js9MathClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $5 = __ZNK8JSObject8numSlotsEv($4);
    if ($3 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $3);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = $type;
    var $13 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($12, __ZN2js9MathClassE);
    var $14 = $cx;
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($12, $14, __ZN2js9MathClassE, $kind);
    var $empty_0_in = $16;
    __label__ = 6;
    break;
   case 5:
    var $18 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($14, __ZN2js9MathClassE);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17random_nextDoubleP9JSContext($cx) {
  var $1 = __ZL11random_nextP9JSContexti($cx, 26);
  var $1$0 = $1[0];
  var $2$0 = $1$0 << 27 | 0 >>> 5;
  var $2$1 = $1[1] << 27 | $1$0 >>> 5;
  var $3 = __ZL11random_nextP9JSContexti($cx, 27);
  var $3$0 = $3[0];
  var $3$1 = $3[1];
  var $4$0 = (i64Math.add($2$0, $2$1, $3$0, $3$1), i64Math.result[0]);
  var $4$1 = i64Math.result[1];
  return ($4$0 + $4$1 * 4294967296) * 1.1102230246251565e-16;
}

function __ZL13math_exp_bodyd($d) {
  var $1 = _exp($d);
  return $1;
}

function __ZL17math_atan2_kerneldd($x, $y) {
  var $1 = _atan2($x, $y);
  return $1;
}

function __ZN13JSCompartment12getMathCacheEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 1904 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN13JSCompartment14allocMathCacheEP9JSContext($5, $6);
    var $10 = $7;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22GetNativeStackBaseImplEv() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var $sattr = __stackBase__;
  var $stackBase = __stackBase__ + 32;
  var $stackSize = __stackBase__ + 36;
  var $1 = _pthread_self();
  var $2 = _pthread_attr_init($sattr);
  var $3 = _pthread_getattr_np($1, $sattr);
  HEAP32[$stackBase >> 2] = 0;
  HEAP32[$stackSize >> 2] = 0;
  var $4 = _pthread_attr_getstack($sattr, $stackBase, $stackSize);
  var $5 = _pthread_attr_destroy($sattr);
  var $6 = HEAP32[$stackBase >> 2];
  STACKTOP = __stackBase__;
  return $6;
}

function __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $start, $end, $base, $endp, $dp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $base | 0;
    var $d_0 = 0;
    var $s_0 = $start;
    __label__ = 2;
    break;
   case 2:
    var $s_0;
    var $d_0;
    if ($s_0 >>> 0 < $end >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 3:
    var $5 = HEAPU16[$s_0 >> 1];
    var $6 = $5 & 65535;
    if (($5 - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $digit_0 = $6 - 48 | 0;
    __label__ = 9;
    break;
   case 5:
    if (($5 - 97 & 65535 & 65535) < 26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $digit_0 = $6 - 87 | 0;
    __label__ = 9;
    break;
   case 7:
    if (($5 - 65 & 65535 & 65535) < 26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $digit_0 = $6 - 55 | 0;
    __label__ = 9;
    break;
   case 9:
    var $digit_0;
    if (($digit_0 | 0) < ($base | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $d_0 = $d_0 * $1 + ($digit_0 | 0);
    var $s_0 = $s_0 + 2 | 0;
    __label__ = 2;
    break;
   case 11:
    HEAP32[$endp >> 2] = $s_0;
    tempDoubleF64[0] = $d_0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    if ($d_0 < 9007199254740992) {
      var $_0 = 1;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($base | 0) == 10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $30 = __ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd($cx, $start, $s_0, $dp);
    var $_0 = $30;
    __label__ = 16;
    break;
   case 14:
    if (($base - 1 & $base | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 15:
    var $36 = __ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i($start, $s_0, $base);
    tempDoubleF64[0] = $36, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ToCStringBufC2Ev($this) {
  HEAP32[$this + 36 >> 2] = 0;
  return;
}

function __ZN2js9DtoaCache6lookupEid($this, $base, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    if (($2 | 0) == 0) {
      var $14 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$this + 8 >> 2] | 0) == ($base | 0)) {
      __label__ = 3;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = (tempDoubleI32[0] = HEAP32[$9 >> 2], tempDoubleI32[1] = HEAP32[$9 + 4 >> 2], tempDoubleF64[0]);
    if ($10 == $d) {
      __label__ = 4;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $2;
    __label__ = 5;
    break;
   case 5:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSShortString23inlineStorageBeforeInitEv($this) {
  return $this + 8 | 0;
}

function __ZN2js9DtoaCache5cacheEidP13JSFixedString($this, $base, $d, $s) {
  HEAP32[$this + 8 >> 2] = $base;
  var $2 = $this | 0;
  tempDoubleF64[0] = $d, HEAP32[$2 >> 2] = tempDoubleI32[0], HEAP32[$2 + 4 >> 2] = tempDoubleI32[1];
  HEAP32[$this + 12 >> 2] = $s;
  return;
}

function __ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd($cx, $start, $end, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $estr = __stackBase__;
    var $err = __stackBase__ + 4;
    var $4 = $end - $start >> 1;
    var $5 = $4 + 1 | 0;
    var $6 = __ZN9JSContext7malloc_Ej($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $i_01;
    HEAP8[$6 + $i_01 | 0] = HEAP16[$start + ($i_01 << 1) >> 1] & 255;
    var $13 = $i_01 + 1 | 0;
    if (($13 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    HEAP8[$6 + $4 | 0] = 0;
    HEAP32[$err >> 2] = 0;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $19 = _js_strtod_harder($18, $6, $estr, $err);
    tempDoubleF64[0] = $19, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $20 = HEAP32[$err >> 2];
    if (($20 | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($20 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($cx);
    __ZN9JSContext5free_EPv(undef, $6);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    if ($19 == Infinity) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 8:
    __ZN9JSContext5free_EPv(undef, $6);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i($start, $end, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bdr = __stackBase__;
    __ZN17BinaryDigitReaderC1EiPKtS1_($bdr, $base, $start, $end);
    __label__ = 2;
    break;
   case 2:
    var $2 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $j_0 = 52;
      var $value_0 = 1;
      var $bit_0 = $2;
      __label__ = 3;
      break;
    }
   case 3:
    var $bit_0;
    var $value_0;
    var $j_0;
    var $4 = ($j_0 | 0) > 0;
    var $5 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if (($5 | 0) < 0) {
      var $_0 = $value_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $j_0 = $j_0 - 1 | 0;
    var $value_0 = $value_0 * 2 + ($5 | 0);
    var $bit_0 = $5;
    __label__ = 3;
    break;
   case 6:
    if (($5 | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $value_0;
      __label__ = 10;
      break;
    }
   case 7:
    var $15 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($15 | 0) > -1) {
      var $factor_01 = 2;
      var $sticky_02 = 0;
      var $17 = $15;
      __label__ = 8;
      break;
    } else {
      var $factor_0_lcssa = 2;
      var $sticky_0_lcssa = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $17;
    var $sticky_02;
    var $factor_01;
    var $18 = $17 | $sticky_02;
    var $19 = $factor_01 * 2;
    var $20 = __ZN17BinaryDigitReader9nextDigitEv($bdr);
    if (($20 | 0) > -1) {
      var $factor_01 = $19;
      var $sticky_02 = $18;
      var $17 = $20;
      __label__ = 8;
      break;
    } else {
      var $factor_0_lcssa = $19;
      var $sticky_0_lcssa = $18;
      __label__ = 9;
      break;
    }
   case 9:
    var $sticky_0_lcssa;
    var $factor_0_lcssa;
    var $_0 = ($value_0 + (($sticky_0_lcssa | $bit_0) & $5 | 0)) * $factor_0_lcssa;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9num_isNaNP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($vp, 1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $4, $x);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $8 = __ZL15JSDOUBLE_IS_NaNd2114($7);
    var $9 = ($8 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_isFiniteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $x = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $4, $x);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$x >> 2], tempDoubleI32[1] = HEAP32[$x + 4 >> 2], tempDoubleF64[0]);
    var $8 = __ZL18JSDOUBLE_IS_FINITEd2111($7);
    var $9 = ($8 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $9);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14num_parseFloatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $ep = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $3);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($6, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSString8getCharsEP9JSContext($7, $cx);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZNK8JSString6lengthEv($7);
    var $14 = $10 + ($13 << 1) | 0;
    var $15 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $10, $14, $ep, $d);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$ep >> 2] | 0) == ($10 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $21);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $23 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $24 = __ZN2JS5Value9setNumberEd($vp, $23);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_parseIntP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $radix = __stackBase__;
    var $number = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($argc | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $2);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 3:
    var $4 = $vp + 24 | 0;
    var $5 = __ZNK2JS5Value7isInt32Ev($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value7toInt32Ev($4);
    if (($7 | 0) == 0 || ($7 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $9 = $vp + 16 | 0;
    var $10 = __ZNK2JS5Value7isInt32Ev($9);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = $9 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 7:
    var $16 = __ZNK2JS5Value8isDoubleEv($9);
    if ($16) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $18 = __ZNK2JS5Value8toDoubleEv($9);
    if ($18 > -1e+21 & $18 < 1e+21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $22 = __ZL20ParseIntDoubleHelperd($18);
    var $23 = __ZN2JS5Value9setNumberEd($vp, $22);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 10:
    var $25 = $vp + 16 | 0;
    var $26 = $cx;
    var $27 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($26, $25);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JS5Value9setStringEP8JSString($25, $27);
    HEAP32[$radix >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $stripPrefix_0 = 1;
      var $45 = 0;
      __label__ = 18;
      break;
    }
   case 12:
    var $32 = $vp + 24 | 0;
    var $33 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $32, $radix);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 13:
    var $35 = HEAPU32[$radix >> 2];
    if (($35 | 0) == 0) {
      var $stripPrefix_0 = 1;
      var $45 = $35;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if (($35 - 2 | 0) >>> 0 > 34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $40 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $40);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 16:
    if (($35 | 0) == 16) {
      var $stripPrefix_0 = 1;
      var $45 = $35;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $stripPrefix_0 = 0;
    var $45 = $35;
    __label__ = 18;
    break;
   case 18:
    var $45;
    var $stripPrefix_0;
    var $46 = __ZN8JSString8getCharsEP9JSContext($27, $cx);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = __ZNK8JSString6lengthEv($27);
    var $50 = $46 + ($49 << 1) | 0;
    var $51 = __ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd($cx, $46, $50, $45, $stripPrefix_0, $number);
    if ($51) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $53 = (tempDoubleI32[0] = HEAP32[$number >> 2], tempDoubleI32[1] = HEAP32[$number + 4 >> 2], tempDoubleF64[0]);
    var $54 = __ZN2JS5Value9setNumberEd($vp, $53);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12num_parseIntP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12ToCStringBufD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 36 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js10Foreground5free_EPv($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_IntToStringP9JSContexti($cx, $si) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $start = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    if (($si | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2js13StaticStrings6hasIntEi($si);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $ui_0 = $si;
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $9 = __ZN2js13StaticStrings6getIntEi($8, $si);
    var $_0 = $9 | 0;
    __label__ = 11;
    break;
   case 4:
    var $ui_0 = -$si | 0;
    __label__ = 5;
    break;
   case 5:
    var $ui_0;
    var $16 = HEAP32[$cx + 56 >> 2] + 1888 | 0;
    var $17 = $si | 0;
    var $18 = __ZN2js9DtoaCache6lookupEid($16, 10, $17);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = $18 | 0;
    __label__ = 11;
    break;
   case 7:
    var $23 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZN13JSShortString23inlineStorageBeforeInitEv($23);
    var $27 = $26 + 22 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_j($end, $27, undef, undef);
    var $28 = __ZNK7mozilla9RangedPtrItEdeEv($end);
    HEAP16[$28 >> 1] = 0;
    var $30 = HEAP32[$end >> 2];
    HEAP32[$1 >> 2] = $30;
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $ui_0, $1);
    if (($si | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = __ZN7mozilla9RangedPtrItEmmEv($start);
    var $35 = __ZNK7mozilla9RangedPtrItEdeEv($34);
    HEAP16[$35 >> 1] = 45;
    __label__ = 10;
    break;
   case 10:
    var $37 = __ZNK7mozilla9RangedPtrItE3getEv($start);
    var $38 = __ZNK7mozilla9RangedPtrItEmiERKS1_($end, $start);
    __ZN13JSShortString20initAtOffsetInBufferEPKtj($23, $37, $38);
    var $39 = $23 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($16, 10, $17, $39);
    var $_0 = $23 | 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_IntToStringP9JSContexti["X"] = 1;

function __ZN13JSShortString20initAtOffsetInBufferEPKtj($this, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 4);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  return;
}

function __Z14js_num_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2JS5Value9setNumberEd($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($1);
    tempDoubleF64[0] = $4, HEAP32[$v >> 2] = tempDoubleI32[0], HEAP32[$v + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($1);
    var $9 = __ZNK8JSObject8getClassEv($8);
    if (($9 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $8;
    var $13 = __ZNK8JSObject16getPrimitiveThisEv($12);
    var $14 = __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($13);
    tempDoubleF64[0] = $14, HEAP32[$v >> 2] = tempDoubleI32[0], HEAP32[$v + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js11NumberClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $cbuf = __stackBase__ + 8;
    var $buf = __stackBase__ + 48;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $3 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $4 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $3, 10);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $8 = $buf | 0;
    var $9 = HEAP32[__ZN2js11NumberClassE >> 2];
    var $10 = _JS_snprintf($8, 64, STRING_TABLE.__str122090 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $9, HEAP32[tempInt + 4 >> 2] = $4, tempInt));
    var $11 = $cx;
    var $12 = __Z17js_NewStringCopyZP9JSContextPKc($11, $8);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $12 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $15);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js12ToCStringBufD2Ev($cbuf);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $d2 = __stackBase__ + 8;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $base_0 = 10;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value11isUndefinedEv($5);
    if ($6) {
      var $base_0 = 10;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $5, $d2);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $10 = (tempDoubleI32[0] = HEAP32[$d2 >> 2], tempDoubleI32[1] = HEAP32[$d2 + 4 >> 2], tempDoubleF64[0]);
    if ($10 < 2 | $10 > 36) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 33, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 7:
    var $base_0 = $10 & -1;
    __label__ = 8;
    break;
   case 8:
    var $base_0;
    var $17 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $18 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $17, $base_0);
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBytes = __stackBase__;
    var $1 = __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toStringEv($vp);
    var $5 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($numBytes, $5, $4);
    var $6 = __ZNK16JSAutoByteStringntEv($numBytes);
    if ($6) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK16JSAutoByteString3ptrEv($numBytes);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = HEAP8[$8] << 24 >> 24 == 45;
    var $nint_0_ph = $11 ? $8 + 1 | 0 : $8;
    var $13 = HEAPU8[$nint_0_ph];
    if (($13 - 48 & 255 & 255) < 10) {
      var $nint_017 = $nint_0_ph;
      __label__ = 5;
      break;
    } else {
      var $nint_0_lcssa = $nint_0_ph;
      var $_lcssa15 = $13;
      __label__ = 6;
      break;
    }
   case 5:
    var $nint_017;
    var $15 = $nint_017 + 1 | 0;
    var $16 = HEAPU8[$15];
    if (($16 - 48 & 255 & 255) < 10) {
      var $nint_017 = $15;
      __label__ = 5;
      break;
    } else {
      var $nint_0_lcssa = $15;
      var $_lcssa15 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $_lcssa15;
    var $nint_0_lcssa;
    var $20 = $nint_0_lcssa - $8 | 0;
    var $21 = $8 + $20 | 0;
    if (($nint_0_lcssa | 0) == ($8 | 0)) {
      var $_0 = 1;
      __label__ = 31;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = HEAPU32[$cx + 52 >> 2];
    var $26 = $25 + 144260 | 0;
    var $27 = HEAP32[$26 >> 2];
    var $28 = _strlen($27);
    var $29 = $25 + 144264 | 0;
    var $30 = HEAP32[$29 >> 2];
    var $31 = _strlen($30);
    var $32 = _strlen($8);
    if ($_lcssa15 << 24 >> 24 == 46) {
      __label__ = 8;
      break;
    } else {
      var $buflen_0 = $32;
      __label__ = 9;
      break;
    }
   case 8:
    var $buflen_0 = $31 - 1 + $32 | 0;
    __label__ = 9;
    break;
   case 9:
    var $buflen_0;
    var $39 = HEAP32[$25 + 144268 >> 2];
    var $remainder_0 = ($11 << 31 >> 31) + $20 | 0;
    var $buflen_1 = $buflen_0;
    var $tmpGroup_0 = $39;
    __label__ = 10;
    break;
   case 10:
    var $tmpGroup_0;
    var $buflen_1;
    var $remainder_0;
    var $42 = HEAP8[$tmpGroup_0];
    var $43 = $42 << 24 >> 24;
    if ($42 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else if ($42 << 24 >> 24 == 127) {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($43 | 0) < ($remainder_0 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $remainder_0 = $remainder_0 - $43 | 0;
    var $buflen_1 = $buflen_1 + $28 | 0;
    var $tmpGroup_0 = $tmpGroup_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    if ($42 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    }
   case 14:
    if (HEAP8[$39] << 24 >> 24 == 0) {
      var $nrepeat_0 = 0;
      var $remainder_1 = $remainder_0;
      var $buflen_2 = $buflen_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = HEAP8[$tmpGroup_0 - 1 | 0] << 24 >> 24;
    var $59 = ($remainder_0 - 1 | 0) / ($58 | 0) & -1;
    var $nrepeat_0 = $59;
    var $remainder_1 = $remainder_0 - $59 * $58 | 0;
    var $buflen_2 = $59 * $28 + $buflen_1 | 0;
    __label__ = 16;
    break;
   case 16:
    var $buflen_2;
    var $remainder_1;
    var $nrepeat_0;
    var $66 = __ZN9JSContext7malloc_Ej($cx, $buflen_2 + 1 | 0);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      var $remainder_2 = $remainder_1;
      var $tmpDest_0 = $66;
      var $tmpSrc_0 = $8;
      __label__ = 17;
      break;
    }
   case 17:
    var $tmpSrc_0;
    var $tmpDest_0;
    var $remainder_2;
    var $68 = HEAP8[$tmpSrc_0];
    if ($68 << 24 >> 24 == 45) {
      var $remainder_3 = $remainder_2;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($remainder_2 | 0) == 0) {
      var $nrepeat_1_ph = $nrepeat_0;
      var $tmpDest_1_ph = $tmpDest_0;
      var $tmpGroup_1_ph_pn = $tmpGroup_0;
      var $tmpSrc_1_ph = $tmpSrc_0;
      __label__ = 22;
      break;
    } else {
      var $remainder_3 = $remainder_2 - 1 | 0;
      __label__ = 19;
      break;
    }
   case 19:
    var $remainder_3;
    HEAP8[$tmpDest_0] = $68;
    var $remainder_2 = $remainder_3;
    var $tmpDest_0 = $tmpDest_0 + 1 | 0;
    var $tmpSrc_0 = $tmpSrc_0 + 1 | 0;
    __label__ = 17;
    break;
   case 20:
    var $tmpSrc_1;
    var $tmpDest_1;
    var $nrepeat_1;
    if ($tmpSrc_1 >>> 0 < $21 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $78 = HEAP32[$26 >> 2];
    var $79 = _strcpy($tmpDest_1, $78);
    var $80 = $tmpDest_1 + $28 | 0;
    var $82 = HEAP8[$tmpGroup_1_ph] << 24 >> 24;
    _memcpy($80, $tmpSrc_1, $82, 1);
    var $84 = HEAP8[$tmpGroup_1_ph] << 24 >> 24;
    var $85 = $tmpDest_1 + ($84 + $28) | 0;
    var $86 = $tmpSrc_1 + $84 | 0;
    var $87 = $nrepeat_1 - 1 | 0;
    if (($87 | 0) < 0) {
      var $nrepeat_1_ph = $87;
      var $tmpDest_1_ph = $85;
      var $tmpGroup_1_ph_pn = $tmpGroup_1_ph;
      var $tmpSrc_1_ph = $86;
      __label__ = 22;
      break;
    } else {
      var $nrepeat_1 = $87;
      var $tmpDest_1 = $85;
      var $tmpSrc_1 = $86;
      __label__ = 20;
      break;
    }
   case 22:
    var $tmpSrc_1_ph;
    var $tmpGroup_1_ph_pn;
    var $tmpDest_1_ph;
    var $nrepeat_1_ph;
    var $tmpGroup_1_ph = $tmpGroup_1_ph_pn - 1 | 0;
    var $nrepeat_1 = $nrepeat_1_ph;
    var $tmpDest_1 = $tmpDest_1_ph;
    var $tmpSrc_1 = $tmpSrc_1_ph;
    __label__ = 20;
    break;
   case 23:
    if (HEAP8[$nint_0_lcssa] << 24 >> 24 == 46) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $93 = HEAP32[$29 >> 2];
    var $94 = _strcpy($tmpDest_1, $93);
    var $95 = $tmpDest_1 + $31 | 0;
    var $97 = _strcpy($95, $nint_0_lcssa + 1 | 0);
    __label__ = 26;
    break;
   case 25:
    var $99 = _strcpy($tmpDest_1, $nint_0_lcssa);
    __label__ = 26;
    break;
   case 26:
    var $102 = HEAP32[$cx + 36 >> 2];
    if (($102 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $106 = HEAP32[$102 + 12 >> 2];
    if (($106 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $109 = FUNCTION_TABLE[$106]($cx, $66, $vp);
    __ZN9JSContext5free_EPv(undef, $66);
    var $_0 = $109;
    __label__ = 31;
    break;
   case 29:
    var $111 = $cx;
    var $112 = __Z17js_NewStringCopyNP9JSContextPKcj($111, $66, $buflen_2);
    __ZN9JSContext5free_EPv(undef, $66);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $115 = $112 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $115);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($numBytes);
    var $_1 = $_0;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11num_toFixedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 2, 2, -20, 0, $argc, $vp);
  return $1;
}

function __ZL17num_toExponentialP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 1, 3, 0, 1, $argc, $vp);
  return $1;
}

function __ZL15num_toPrecisionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZNK2JS5Value11isUndefinedEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL12num_toStringP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $6;
    __label__ = 5;
    break;
   case 4:
    var $8 = __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, 0, 4, 1, 0, $argc, $vp);
    var $_0 = $8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22InitRuntimeNumberStateEP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    tempDoubleF64[0] = NaN, HEAP32[_js_NaN >> 2] = tempDoubleI32[0], HEAP32[_js_NaN + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = NaN, HEAP32[__ZL16number_constants >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 4 >> 2] = tempDoubleI32[1];
    var $1 = $rt + 144112 | 0;
    __ZN2JS5Value9setDoubleEd($1, NaN);
    tempDoubleF64[0] = Infinity, HEAP32[_js_PositiveInfinity >> 2] = tempDoubleI32[0], HEAP32[_js_PositiveInfinity + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = Infinity, HEAP32[__ZL16number_constants + 16 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 20 >> 2] = tempDoubleI32[1];
    var $2 = $rt + 144128 | 0;
    __ZN2JS5Value9setDoubleEd($2, Infinity);
    tempDoubleF64[0] = -Infinity, HEAP32[_js_NegativeInfinity >> 2] = tempDoubleI32[0], HEAP32[_js_NegativeInfinity + 4 >> 2] = tempDoubleI32[1];
    tempDoubleF64[0] = -Infinity, HEAP32[__ZL16number_constants + 32 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 36 >> 2] = tempDoubleI32[1];
    var $3 = $rt + 144120 | 0;
    __ZN2JS5Value9setDoubleEd($3, -Infinity);
    tempDoubleF64[0] = 5e-324, HEAP32[__ZL16number_constants + 64 >> 2] = tempDoubleI32[0], HEAP32[__ZL16number_constants + 68 >> 2] = tempDoubleI32[1];
    var $4 = _localeconv();
    var $6 = HEAP32[$4 + 4 >> 2];
    var $8 = HEAP32[$4 >> 2];
    var $10 = HEAP32[$4 + 8 >> 2];
    var $thousandsSeparator_0 = ($6 | 0) == 0 ? STRING_TABLE.__str32081 | 0 : $6;
    var $decimalPoint_0 = ($8 | 0) == 0 ? STRING_TABLE.__str42082 | 0 : $8;
    var $grouping_0 = ($10 | 0) == 0 ? STRING_TABLE.__str52083 | 0 : $10;
    var $14 = _strlen($thousandsSeparator_0);
    var $15 = $14 + 1 | 0;
    var $16 = _strlen($decimalPoint_0);
    var $17 = $16 + 1 | 0;
    var $18 = _strlen($grouping_0);
    var $19 = $18 + 1 | 0;
    var $20 = $17 + $15 | 0;
    var $21 = $20 + $19 | 0;
    var $22 = __ZN2js11OffTheBooks7malloc_Ej($21);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _memcpy($22, $thousandsSeparator_0, $15, 1);
    HEAP32[$rt + 144260 >> 2] = $22;
    var $26 = $22 + $15 | 0;
    _memcpy($26, $decimalPoint_0, $17, 1);
    HEAP32[$rt + 144264 >> 2] = $26;
    var $28 = $22 + $20 | 0;
    _memcpy($28, $grouping_0, $19, 1);
    HEAP32[$rt + 144268 >> 2] = $grouping_0;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js22InitRuntimeNumberStateEP9JSRuntime["X"] = 1;

function __ZN2js24FinishRuntimeNumberStateEP9JSRuntime($rt) {
  var $2 = HEAP32[$rt + 144260 >> 2];
  __ZN2js10Foreground5free_EPv($2);
  return;
}

function __ZN2js13StaticStrings7hasUintEj($u) {
  return $u >>> 0 < 256;
}

function __ZN8JSObject8asNumberEv($this) {
  return $this;
}

function __ZL18JSDOUBLE_IS_FINITEd2111($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2114($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __Z18js_InitNumberClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js11NumberClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject8asNumberEv($6);
    __ZN2js12NumberObject17setPrimitiveValueEd($9, 0);
    var $10 = $cx + 52 | 0;
    var $14 = HEAP32[HEAP32[$10 >> 2] + 210052 >> 2];
    var $15 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 172, __ZN2js11NumberClassE, $14, 1);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $15;
    var $19 = $15 | 0;
    var $20 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $19, $5);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $22 = _JS_DefineConstDoubles($cx, $18, __ZL16number_constants | 0);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL14number_methods);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $27 = $2;
    var $28 = _JS_DefineFunctions($cx, $27, __ZL16number_functions | 0);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = HEAP32[$10 >> 2];
    var $34 = HEAP32[$31 + 210380 >> 2] | 0;
    var $35 = __ZL12ATOM_TO_JSIDP6JSAtom2097($34);
    var $36 = $31 + 144112 | 0;
    var $37 = $cx;
    var $38 = $2;
    var $39 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($37, $38, $35, $36, 10, 12, 6, 0, 0, 0);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $42 = HEAP32[$10 >> 2];
    var $45 = HEAP32[$42 + 210376 >> 2] | 0;
    var $46 = __ZL12ATOM_TO_JSIDP6JSAtom2097($45);
    var $47 = $42 + 144128 | 0;
    var $48 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($37, $38, $46, $47, 10, 12, 6, 0, 0, 0);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $51 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 8, $18, $6);
    var $_ = $51 ? $6 : 0;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitNumberClassP9JSContextP8JSObject["X"] = 1;

function __ZN2js12NumberObject17setPrimitiveValueEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL11NumberValueEd2157($1, $d);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL6NumberP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14IsConstructingEPKN2JS5ValueE2144($vp);
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5 = __ZN2js8ToNumberEP9JSContextPN2JS5ValueE($cx, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = $4 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    __label__ = 5;
    break;
   case 5:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145($cx);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = $13;
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($16, $vp);
    __ZN2JS5Value9setObjectER8JSObject($vp, $13);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom2097($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2143($1);
  return $2;
}

function __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $1 = _JSDOUBLE_IS_INT322100($d, $i);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$i >> 2];
    var $5 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $4, $base);
    var $9 = $5;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base);
    var $9 = $7;
    __label__ = 4;
    break;
   case 4:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_INT322100($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO2132($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $i, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = ($i | 0) < 0;
    var $5 = $3 ? -$i | 0 : $i;
    var $6 = $cbuf + 33 | 0;
    __ZN7mozilla9RangedPtrIcEC1EPcS2_j($cp, $6, undef, undef);
    var $7 = __ZNK7mozilla9RangedPtrIcEdeEv($cp);
    HEAP8[$7] = 0;
    if (($base | 0) == 10) {
      __label__ = 2;
      break;
    } else if (($base | 0) == 16) {
      var $u_0 = $5;
      __label__ = 3;
      break;
    } else {
      var $u_1 = $5;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = HEAP32[$cp >> 2];
    HEAP32[$2 >> 2] = $10;
    __ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_($1, $5, $2);
    var $12 = __ZN7mozilla9RangedPtrIcEaSERKS1_($cp, $1);
    __label__ = 5;
    break;
   case 3:
    var $u_0;
    var $13 = $u_0 >>> 4;
    var $15 = STRING_TABLE.__str62084 + ($u_0 & 15) | 0;
    var $16 = HEAP8[$15];
    var $17 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $18 = __ZNK7mozilla9RangedPtrIcEdeEv($17);
    HEAP8[$18] = $16;
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $u_0 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    var $u_1;
    var $20 = Math.floor(($u_1 >>> 0) / ($base >>> 0));
    var $23 = STRING_TABLE.__str72085 + ($u_1 - $20 * $base) | 0;
    var $24 = HEAP8[$23];
    var $25 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $26 = __ZNK7mozilla9RangedPtrIcEdeEv($25);
    HEAP8[$26] = $24;
    if (($20 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $u_1 = $20;
      __label__ = 4;
      break;
    }
   case 5:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = __ZN7mozilla9RangedPtrIcEmmEv($cp);
    var $30 = __ZNK7mozilla9RangedPtrIcEdeEv($29);
    HEAP8[$30] = 45;
    __label__ = 7;
    break;
   case 7:
    var $32 = __ZNK7mozilla9RangedPtrIcE3getEv($cp);
    STACKTOP = __stackBase__;
    return $32;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($base | 0) == 10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cbuf | 0;
    var $4 = __ZN2v88internal15DoubleToCStringEdPci($d, $3, 34);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $numStr_0 = $4;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $11 = _js_dtostr($10, $3, 34, 0, 0, $d);
    var $numStr_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $17 = _js_dtobasestr($16, $base, $d);
    HEAP32[$cbuf + 36 >> 2] = $17;
    var $numStr_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $numStr_0;
    return $numStr_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NumberToStringP9JSContextd($cx, $d) {
  var $1 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, 10);
  return $1;
}

function __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, $base) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $i = __stackBase__ + 40;
    __ZN2js12ToCStringBufC2Ev($cbuf);
    if (($base - 2 | 0) >>> 0 > 34) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$cx + 56 >> 2];
    var $5 = _JSDOUBLE_IS_INT322100($d, $i);
    if (($5 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAPU32[$i >> 2];
    if (($base | 0) == 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN2js13StaticStrings6hasIntEi($9);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $16 = __ZN2js13StaticStrings6getIntEi($15, $9);
    var $_0 = $16 | 0;
    __label__ = 18;
    break;
   case 6:
    if ($9 >>> 0 < $base >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    if (($9 | 0) < 10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $25 = __ZN2js13StaticStrings6getIntEi($24, $9);
    var $_0 = $25 | 0;
    __label__ = 18;
    break;
   case 9:
    var $29 = $9 + 87 & 65535;
    var $32 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $33 = __ZN2js13StaticStrings7getUnitEt($32, $29);
    var $_0 = $33 | 0;
    __label__ = 18;
    break;
   case 10:
    var $36 = $4 + 1888 | 0;
    var $37 = __ZN2js9DtoaCache6lookupEid($36, $base, $d);
    if (($37 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = $37 | 0;
    __label__ = 18;
    break;
   case 12:
    var $42 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $9, $base);
    var $numStr_0 = $42;
    __label__ = 17;
    break;
   case 13:
    var $44 = $4 + 1888 | 0;
    var $45 = __ZN2js9DtoaCache6lookupEid($44, $base, $d);
    if (($45 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_0 = $45 | 0;
    __label__ = 18;
    break;
   case 15:
    var $50 = __ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $d, $base);
    if (($50 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $numStr_0 = $50;
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $numStr_0;
    var $54 = $cx;
    var $55 = __Z17js_NewStringCopyZP9JSContextPKc($54, $numStr_0);
    var $56 = $4 + 1888 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($56, $base, $d, $55);
    var $_0 = $55 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js12ToCStringBufD2Ev($cbuf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25js_NumberToStringWithBaseP9JSContextdi["X"] = 1;

function __ZN2js14NumberToStringEP9JSContextd($cx, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL25js_NumberToStringWithBaseP9JSContextdi($cx, $d, 10);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSString7asFixedEv($1);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13IndexToStringEP9JSContextj($cx, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $end = __stackBase__;
    var $start = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __ZN2js13StaticStrings7hasUintEj($index);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $7 = __ZN2js13StaticStrings7getUintEj($6, $index);
    var $_0 = $7 | 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = HEAP32[$cx + 56 >> 2] + 1888 | 0;
    var $13 = $index >>> 0;
    var $14 = __ZN2js9DtoaCache6lookupEid($12, 10, $13);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $14;
      __label__ = 6;
      break;
    }
   case 4:
    var $17 = __Z19js_NewGCShortStringP9JSContext($cx);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = __ZN13JSShortString23inlineStorageBeforeInitEv($17);
    var $21 = $20 + 22 | 0;
    __ZN7mozilla9RangedPtrItEC1EPtS2_j($end, $21, undef, undef);
    var $22 = __ZNK7mozilla9RangedPtrItEdeEv($end);
    HEAP16[$22 >> 1] = 0;
    var $24 = HEAP32[$end >> 2];
    HEAP32[$1 >> 2] = $24;
    __ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_($start, $index, $1);
    var $26 = __ZNK7mozilla9RangedPtrItE3getEv($start);
    var $27 = __ZNK7mozilla9RangedPtrItEmiERKS1_($end, $start);
    __ZN13JSShortString20initAtOffsetInBufferEPKtj($17, $26, $27);
    var $28 = $17 | 0;
    __ZN2js9DtoaCache5cacheEidP13JSFixedString($12, 10, $13, $28);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $v, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $4 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $3, 10);
    var $cstr_0 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8toDoubleEv($v);
    var $7 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($cx, $cbuf, $6, 10);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cstr_0 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $cstr_0;
    var $11 = _strlen($cstr_0);
    var $12 = __ZN2js12StringBuffer14appendInflatedEPKcj($sb, $cstr_0, $11);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js12ToCStringBufD2Ev($cbuf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer14appendInflatedEPKcj($this, $cstr, $cstrlen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $cstrlen;
    var $2 = __ZNK2js12StringBuffer6lengthEv($this);
    var $3 = $this | 0;
    var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj($3, $cstrlen);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js12StringBuffer7contextEv($this);
    var $7 = __ZN2js12StringBuffer5beginEv($this);
    var $8 = $7 + ($2 << 1) | 0;
    var $9 = $6;
    var $10 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($9, $cstr, $cstrlen, $8, $1);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $0, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $v | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    __label__ = 3;
    break;
   case 2:
    var $6 = __ZNK2JS5Value8toNumberEv($v);
    tempDoubleF64[0] = $6, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8isStringEv($v);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8toStringEv($v);
    var $11 = __ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_($cx, $10, $out);
    var $_0 = $11;
    __label__ = 16;
    break;
   case 5:
    var $13 = __ZNK2JS5Value9isBooleanEv($v);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $15 = __ZNK2JS5Value9toBooleanEv($v);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    tempDoubleF64[0] = 1, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 8:
    tempDoubleF64[0] = 0, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 9:
    var $19 = __ZNK2JS5Value6isNullEv($v);
    if ($19) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    tempDoubleF64[0] = 0, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 11:
    var $22 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($22) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $24 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103($cx, $v);
    if ($24) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 13:
    var $26 = __ZNK2JS5Value8isObjectEv($v);
    if ($26) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $28 = __ZNK2JS5Value8isNumberEv($v);
    if ($28) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 15:
    var $30 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $30, HEAP32[$out >> 2] = tempDoubleI32[0], HEAP32[$out + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_($cx, $str, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $endptr = __stackBase__;
    var $d = __stackBase__ + 4;
    var $ep = __stackBase__ + 12;
    var $d1 = __stackBase__ + 16;
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = __ZN8JSString8getCharsEP9JSContext($str, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = HEAPU16[$2 >> 1];
    if (($7 - 48 & 65535 & 65535) < 10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = ($7 & 65535) - 48 | 0;
    var $13 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($12);
    tempDoubleF64[0] = $13, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 5:
    var $15 = __ZN2js7unicode7IsSpaceEt($7);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZN2js12NumberTraitsIdE10toSelfTypeEd(0);
    tempDoubleF64[0] = $17, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 7:
    var $19 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $19, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 8:
    var $21 = $2 + ($1 << 1) | 0;
    var $22 = __ZN2jsL9SkipSpaceEPKtS1_($2, $21);
    if (($21 - $22 | 0) > 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if (HEAP16[$22 >> 1] << 16 >> 16 == 48) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 10:
    var $32 = HEAP16[$22 + 2 >> 1];
    if ($32 << 16 >> 16 == 120 || $32 << 16 >> 16 == 88) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $34 = $22 + 4 | 0;
    var $35 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $34, $21, 16, $endptr, $d);
    if ($35) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $37 = HEAP32[$endptr >> 2];
    var $38 = __ZN2jsL9SkipSpaceEPKtS1_($37, $21);
    if (($38 | 0) == ($21 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $41, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 14:
    var $43 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $44 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($43);
    tempDoubleF64[0] = $44, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 15:
    var $46 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $22, $21, $ep, $d1);
    if (($46 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $49 = HEAP32[$ep >> 2];
    var $50 = __ZN2jsL9SkipSpaceEPKtS1_($49, $21);
    if (($50 | 0) == ($21 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = __ZN2js12NumberTraitsIdE3NaNEv();
    tempDoubleF64[0] = $53, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 18:
    var $55 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $56 = __ZN2js12NumberTraitsIdE10toSelfTypeEd($55);
    tempDoubleF64[0] = $56, HEAP32[$result >> 2] = tempDoubleI32[0], HEAP32[$result + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_["X"] = 1;

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 4, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK2JS5Value8isDoubleEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $4, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $11 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $d);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $12 = __ZL20js_DoubleToECMAInt32d2106($11);
    HEAP32[$out >> 2] = $12;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20js_DoubleToECMAInt32d2106($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK2JS5Value8isDoubleEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $4, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $11 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $d);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $12 = __Z21js_DoubleToECMAUint32d($11);
    HEAP32[$out >> 2] = $12;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_DoubleToECMAUint32d($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($d < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _floor($d);
    var $15 = $9;
    __label__ = 6;
    break;
   case 5:
    var $11 = -$d;
    var $12 = _floor($11);
    var $15 = -$12;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $16 = _fmod($15, 4294967296);
    if ($16 < 0) {
      __label__ = 7;
      break;
    } else {
      var $21 = $16;
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $16 + 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $22 = $21 >= 0 ? Math.floor($21) : Math.ceil($21);
    var $_0 = $22;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK2JS5Value8isDoubleEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $4, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $11 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $d);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = $_pre;
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $12 = __ZL15JSDOUBLE_IS_NaNd2114($11);
    if (($12 | 0) != 0 | $11 <= -2147483649 | $11 >= 2147483648) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 35, 1, $v, 0, 0, 0);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $20 = _floor($11 + .5);
    HEAP32[$out >> 2] = $20 & -1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK2JS5Value8isDoubleEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $4, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $11 = $4;
    __label__ = 5;
    break;
   case 3:
    var $6 = $v | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $1 | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $d);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 4:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $11 = $_pr;
    __label__ = 5;
    break;
   case 5:
    var $11;
    if ($11 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZL18JSDOUBLE_IS_FINITEd2111($11);
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP16[$out >> 1] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 8:
    var $18 = $11 >= 0 ? Math.floor($11) : Math.ceil($11);
    if (($18 & 65535) == $11) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP16[$out >> 1] = $18;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 10:
    if ($11 < 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $24 = _floor($11);
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $30 = $24;
    __label__ = 13;
    break;
   case 12:
    var $27 = _floor(-$11);
    tempDoubleF64[0] = $27, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $30 = -$27;
    __label__ = 13;
    break;
   case 13:
    var $30;
    tempDoubleF64[0] = $30, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $31 = _fmod($30, 65536);
    if ($31 < 0) {
      __label__ = 14;
      break;
    } else {
      var $storemerge = $31;
      __label__ = 15;
      break;
    }
   case 14:
    var $storemerge = $31 + 65536;
    __label__ = 15;
    break;
   case 15:
    var $storemerge;
    tempDoubleF64[0] = $storemerge, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $36 = $storemerge >= 0 ? Math.floor($storemerge) : Math.ceil($storemerge);
    HEAP16[$out >> 1] = $36;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt["X"] = 1;

function __ZN2js12NumberTraitsIdE10toSelfTypeEd($d) {
  return $d;
}

function __ZL14JSID_FROM_BITSj2143($bits) {
  return $bits;
}

function __ZN2js12NumberTraitsIdE3NaNEv() {
  var $1 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  return $1;
}

function _JSDOUBLE_IS_NEGZERO2132($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7unicode13CharacterInfo7isSpaceEv($this) {
  return (HEAP8[$this + 4 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK7mozilla9RangedPtrIcEdeEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN7mozilla9RangedPtrIcEaSERKS1_($this, $other) {
  var $2 = HEAP32[$other >> 2];
  HEAP32[$this >> 2] = $2;
  return $this;
}

function __ZNK7mozilla9RangedPtrIcE3getEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE($this, $p) {
  var $2 = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $2;
  return $this;
}

function __ZN7mozilla9RangedPtrIcEC2EPcS2_j($this, $p, $start, $length) {
  HEAP32[$this >> 2] = $p;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb2146($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17BinaryDigitReader9nextDigitEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $33 = $2;
    var $32 = HEAP32[$this + 4 >> 2];
    __label__ = 10;
    break;
   case 3:
    var $5 = $this + 12 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == (HEAP32[$this + 16 >> 2] | 0)) {
      var $_0 = -1;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $6 + 2 | 0;
    HEAP32[$5 >> 2] = $11;
    var $12 = HEAPU16[$6 >> 1];
    var $13 = $12 & 65535;
    if (($12 - 48 & 65535 & 65535) < 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = $13 - 48 | 0;
    HEAP32[$this + 4 >> 2] = $16;
    var $27 = $16;
    __label__ = 9;
    break;
   case 6:
    if (($12 - 97 & 65535 & 65535) < 26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $13 - 87 | 0;
    HEAP32[$this + 4 >> 2] = $21;
    var $27 = $21;
    __label__ = 9;
    break;
   case 8:
    var $24 = $13 - 55 | 0;
    HEAP32[$this + 4 >> 2] = $24;
    var $27 = $24;
    __label__ = 9;
    break;
   case 9:
    var $27;
    var $30 = HEAP32[$this >> 2] >> 1;
    HEAP32[$1 >> 2] = $30;
    var $33 = $30;
    var $32 = $27;
    __label__ = 10;
    break;
   case 10:
    var $32;
    var $33;
    HEAP32[$1 >> 2] = $33 >> 1;
    var $_0 = ($33 & $32 | 0) != 0 & 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN17BinaryDigitReader9nextDigitEv["X"] = 1;

function __ZN17BinaryDigitReaderC2EiPKtS1_($this, $base, $start, $end) {
  HEAP32[$this >> 2] = $base;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = $start;
  HEAP32[$this + 16 >> 2] = $end;
  return;
}

function __Z9js_strtodP9JSContextPKtS2_PS2_Pd($cx, $s, $send, $ep, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $estr = __stackBase__ + 32;
    var $err = __stackBase__ + 36;
    var $1 = __ZN2jsL9SkipSpaceEPKtS1_($s, $send);
    var $5 = $send - $1 >> 1;
    if ($5 >>> 0 > 31) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $5 + 1 | 0;
    var $9 = __ZN9JSContext7malloc_Ej($cx, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $cstr_0 = $9;
      __label__ = 4;
      break;
    }
   case 3:
    var $cstr_0 = $cbuf | 0;
    __label__ = 4;
    break;
   case 4:
    var $cstr_0;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if (($i_0 | 0) == ($5 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAPU16[$1 + ($i_0 << 1) >> 1];
    if (($18 & 65535) > 255) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP8[$cstr_0 + $i_0 | 0] = $18 & 255;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    HEAP8[$cstr_0 + $i_0 | 0] = 0;
    var $26 = HEAP8[$cstr_0];
    var $27 = $26 << 24 >> 24 == 45;
    var $istr_0 = $27 | $26 << 24 >> 24 == 43 ? $cstr_0 + 1 | 0 : $cstr_0;
    if (HEAP8[$istr_0] << 24 >> 24 == 73) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $33 = _strncmp($istr_0, STRING_TABLE._js_Infinity_str | 0, 8);
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $37 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $38 = $27 ? $36 : $37;
    HEAP32[$estr >> 2] = $istr_0 + 8 | 0;
    var $d_0 = $38;
    __label__ = 15;
    break;
   case 11:
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $45 = _js_strtod_harder($44, $cstr_0, $estr, $err);
    if ($45 == Infinity) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $48 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $48;
    __label__ = 15;
    break;
   case 13:
    if ($45 == -Infinity) {
      __label__ = 14;
      break;
    } else {
      var $d_0 = $45;
      __label__ = 15;
      break;
    }
   case 14:
    var $52 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $52;
    __label__ = 15;
    break;
   case 15:
    var $d_0;
    var $53 = HEAP32[$estr >> 2];
    var $56 = $53 - $cstr_0 | 0;
    if (($cstr_0 | 0) == ($cbuf | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN9JSContext5free_EPv(undef, $cstr_0);
    __label__ = 17;
    break;
   case 17:
    if (($53 | 0) == ($cstr_0 | 0)) {
      var $65 = $s;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $65 = $1 + ($56 << 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $65;
    HEAP32[$ep >> 2] = $65;
    tempDoubleF64[0] = $d_0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9js_strtodP9JSContextPKtS2_PS2_Pd["X"] = 1;

function __ZN2jsL9SkipSpaceEPKtS1_($s, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    if ($_0 >>> 0 < $end >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $4 = HEAP16[$_0 >> 1];
    var $5 = __ZN2js7unicode7IsSpaceEt($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $_0 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode7IsSpaceEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isspace + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 5;
    break;
   case 3:
    if ($ch << 16 >> 16 == 160) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN2js7unicode8CharInfoEt($ch);
    var $12 = __ZNK2js7unicode13CharacterInfo7isSpaceEv($11);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value8isNumberEv($v);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value8toNumberEv($v);
  return $1;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIcEC1EPcS2_j($this, $p, $start, $length) {
  __ZN7mozilla9RangedPtrIcEC2EPcS2_j($this, $p, undef, undef);
  return;
}

function __ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_($agg_result, $index, $end) {
  var __stackBase__ = STACKTOP;
  var tempParam = $end;
  $end = STACKTOP;
  STACKTOP += 4;
  HEAP32[$end >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $index;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $2 = Math.floor(($_0 >>> 0) / 10);
    var $5 = (($_0 >>> 0) % 10 | 48) & 255;
    var $6 = __ZN7mozilla9RangedPtrIcEmmEv($end);
    var $7 = __ZNK7mozilla9RangedPtrIcEdeEv($6);
    HEAP8[$7] = $5;
    if ($_0 >>> 0 > 9) {
      var $_0 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAP32[$end >> 2];
    HEAP32[$agg_result >> 2] = $11;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla9RangedPtrIcEmmEv($this) {
  var $1 = __ZN7mozilla9RangedPtrIcEmIEj($this, 1);
  return $1;
}

function __ZN7mozilla9RangedPtrIcEmIEj($this, $dec) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN7mozilla9RangedPtrIcEmiEj($1, $this, $dec);
  var $2 = __ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE($this, $1);
  STACKTOP = __stackBase__;
  return $this;
}

function __ZN7mozilla9RangedPtrIcEmiEj($agg_result, $this, $dec) {
  var $4 = HEAP32[$this >> 2] + -$dec | 0;
  __ZNK7mozilla9RangedPtrIcE6createEPc($agg_result, undef, $4);
  return;
}

function __ZNK7mozilla9RangedPtrIcE6createEPc($agg_result, $this, $ptr) {
  __ZN7mozilla9RangedPtrIcEC1EPcS2_j($agg_result, $ptr, undef, undef);
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE2144($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145($cx) {
  var $3 = HEAPU32[__ZN2js11NumberClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2146($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11NumberClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11NumberClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11NumberClassE, $1, $parent, 0, (__ZN2js11NumberClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11NumberClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd2157($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE($cx, $zeroArgMode, $oneArgMode, $precisionMin, $precisionOffset, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 184;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buf = __stackBase__;
    var $d = __stackBase__ + 128;
    var $precision = __stackBase__ + 136;
    var $cbuf = __stackBase__ + 144;
    var $1 = __ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $d);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    tempDoubleF64[0] = 0, HEAP32[$precision >> 2] = tempDoubleI32[0], HEAP32[$precision + 4 >> 2] = tempDoubleI32[1];
    var $_01 = $zeroArgMode;
    var $17 = 0;
    __label__ = 7;
    break;
   case 4:
    var $6 = $vp + 16 | 0;
    var $7 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $6, $precision);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $9 = (tempDoubleI32[0] = HEAP32[$precision >> 2], tempDoubleI32[1] = HEAP32[$precision + 4 >> 2], tempDoubleF64[0]);
    if ($9 < ($precisionMin | 0) | $9 > 100) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $oneArgMode;
      var $17 = $9;
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $14 = $9 & -1;
    var $15 = __ZL12IntToCStringPN2js12ToCStringBufEii($cbuf, $14, 10);
    _JS_ReportErrorNumber($cx, 2, 0, 150, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $15, tempInt));
    __ZN2js12ToCStringBufD2Ev($cbuf);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 7:
    var $17;
    var $_01;
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 209876 >> 2];
    var $22 = $buf | 0;
    var $24 = ($17 & -1) + $precisionOffset | 0;
    var $25 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $26 = _js_dtostr($21, $22, 125, $_01, $24, $25);
    if (($26 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $30 = $cx;
    var $31 = __Z17js_NewStringCopyZP9JSContextPKc($30, $26);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = $31 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $34);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159($cx, $v, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value7isInt32Ev($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value7toInt32Ev($v);
    tempDoubleF64[0] = $4 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $16 = $9;
    __label__ = 7;
    break;
   case 5:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($cx, $1, $dp);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $16 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $16;
    var $17 = __ZL18js_DoubleToIntegerd2161($16);
    tempDoubleF64[0] = $17, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd2161($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd2111($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd2114($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ParseIntDoubleHelperd($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _floor($d);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    if ($d < 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = -$d;
    var $8 = _floor($7);
    var $_0 = -$8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd($cx, $ws, $end, $maybeRadix, $stripPrefix, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $actualEnd = __stackBase__;
    var $1 = __ZN2jsL9SkipSpaceEPKtS1_($ws, $end);
    if (($1 | 0) == ($end | 0)) {
      var $s_0 = $1;
      var $8 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP16[$1 >> 1];
    var $5 = $4 << 16 >> 16 == 45;
    if ($4 << 16 >> 16 == 45 || $4 << 16 >> 16 == 43) {
      __label__ = 3;
      break;
    } else {
      var $s_0 = $1;
      var $8 = $5;
      __label__ = 4;
      break;
    }
   case 3:
    var $s_0 = $1 + 2 | 0;
    var $8 = $5;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $s_0;
    if (($maybeRadix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $radix_0 = $maybeRadix;
      __label__ = 9;
      break;
    }
   case 5:
    if (($end - $s_0 | 0) > 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (HEAP16[$s_0 >> 1] << 16 >> 16 == 48) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP16[$s_0 + 2 >> 1];
    if ($20 << 16 >> 16 == 120 || $20 << 16 >> 16 == 88) {
      __label__ = 8;
      break;
    } else {
      var $radix_0 = 8;
      __label__ = 9;
      break;
    }
   case 8:
    var $radix_0 = 10;
    __label__ = 9;
    break;
   case 9:
    var $radix_0;
    if ($stripPrefix) {
      __label__ = 10;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 10:
    if (($end - $s_0 | 0) > 2) {
      __label__ = 11;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 11:
    if (HEAP16[$s_0 >> 1] << 16 >> 16 == 48) {
      __label__ = 12;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = HEAP16[$s_0 + 2 >> 1];
    if ($33 << 16 >> 16 == 120 || $33 << 16 >> 16 == 88) {
      __label__ = 13;
      break;
    } else {
      var $radix_1 = $radix_0;
      var $s_1 = $s_0;
      __label__ = 14;
      break;
    }
   case 13:
    var $radix_1 = 16;
    var $s_1 = $s_0 + 4 | 0;
    __label__ = 14;
    break;
   case 14:
    var $s_1;
    var $radix_1;
    var $37 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($cx, $s_1, $end, $radix_1, $actualEnd, $dp);
    if ($37) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 15:
    if (($s_1 | 0) == (HEAP32[$actualEnd >> 2] | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $42 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $42, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 17:
    if ($8) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $45 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $46 = -$45;
    tempDoubleF64[0] = $46, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd["X"] = 1;

function __ZN17BinaryDigitReaderC1EiPKtS1_($this, $base, $start, $end) {
  __ZN17BinaryDigitReaderC2EiPKtS1_($this, $base, $start, $end);
  return;
}

function _js_ObjectToOuterObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $obj;
  __Z19OBJ_TO_OUTER_OBJECTP9JSContextRP8JSObject($cx, $1);
  var $2 = HEAP32[$1 >> 2];
  STACKTOP = __stackBase__;
  return $2;
}

function __Z19OBJ_TO_OUTER_OBJECTP9JSContextRP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$obj >> 2];
    var $2 = $1;
    var $3 = __ZNK8JSObject8getClassEv($2);
    var $5 = HEAP32[$3 + 72 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = FUNCTION_TABLE[$8]($cx, $1);
    HEAP32[$obj >> 2] = $9;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $cx;
    if ((HEAP32[$obj >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($3, 2, 0, 2, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $obj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($3, $6);
    var $_0 = (HEAP32[$obj >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $attrs = __stackBase__;
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom2291($5);
  var $7 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $6, 0, $vp, $attrs);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $attrs = __stackBase__ + 4;
    var $1 = $cx;
    var $2 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[_sSetProtoCalled >> 2] + 1 | 0;
    HEAP32[_sSetProtoCalled >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    var $7 = $obj;
    var $8 = __ZNK8JSObject12isExtensibleEv($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 0);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 5:
    var $12 = __ZNK2JS5Value14isObjectOrNullEv($vp);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value14toObjectOrNullEv($vp);
    var $15 = $14;
    HEAP32[$pobj >> 2] = $15;
    if (($14 | 0) == 0) {
      var $22 = $15;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $pobj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($1, $18);
    var $19 = HEAP32[$pobj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $22 = $19;
      __label__ = 8;
      break;
    }
   case 8:
    var $22;
    var $27 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
    var $28 = __ZL12ATOM_TO_JSIDP6JSAtom2291($27);
    var $29 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $28, 8, $vp, $attrs);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($cx, $obj, $22, 1);
    var $_0 = $32 & 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14js_hash_objectPKv($key) {
  return $key >>> 8;
}

function __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $obj, $idap, $sp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ida = __stackBase__;
    var $hep = __stackBase__ + 4;
    var $buf = __stackBase__ + 8;
    var $len = __stackBase__ + 28;
    var $1 = $cx + 52 | 0;
    if ((HEAP32[HEAP32[$1 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __Z26js_InvokeOperationCallbackP9JSContext($7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$sp >> 2] = 0;
    var $10 = $cx + 144 | 0;
    var $11 = HEAP32[$10 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $table_0 = $11;
      __label__ = 7;
      break;
    }
   case 4:
    var $14 = _JS_NewHashTable(8, 174, 176, 176, 0, 0);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $cx;
    _JS_ReportOutOfMemory($17);
    var $_0 = 0;
    __label__ = 32;
    break;
   case 6:
    HEAP32[$10 >> 2] = $14;
    var $20 = HEAP32[$1 >> 2] + 136 | 0;
    var $22 = HEAP32[$20 >> 2] + 1 | 0;
    HEAP32[$20 >> 2] = $22;
    var $table_0 = $14;
    __label__ = 7;
    break;
   case 7:
    var $table_0;
    HEAP32[$ida >> 2] = 0;
    var $24 = $cx + 136 | 0;
    if ((HEAP32[$24 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    HEAP32[$24 >> 2] = 1;
    var $28 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $obj, $ida);
    var $30 = HEAP32[$24 >> 2] - 1 | 0;
    HEAP32[$24 >> 2] = $30;
    if (($28 | 0) == 0) {
      var $93 = $30;
      __label__ = 30;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($idap | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $he_0 = $28;
      __label__ = 14;
      break;
    }
   case 10:
    var $36 = HEAP32[$ida >> 2];
    _JS_DestroyIdArray(undef, $36);
    HEAP32[$ida >> 2] = 0;
    var $he_0 = $28;
    __label__ = 14;
    break;
   case 11:
    var $38 = $obj;
    var $39 = __ZL14js_hash_objectPKv($38);
    var $40 = _JS_HashTableRawLookup($table_0, $39, $38);
    HEAP32[$hep >> 2] = $40;
    var $41 = HEAP32[$40 >> 2];
    if (($41 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $he_0 = $41;
      __label__ = 14;
      break;
    }
   case 12:
    var $44 = _JS_HashTableRawAdd($table_0, $hep, $39, $38, 0);
    if (($44 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $he_12 = $44;
      __label__ = 21;
      break;
    }
   case 13:
    var $47 = $cx;
    _JS_ReportOutOfMemory($47);
    __label__ = 29;
    break;
   case 14:
    var $he_0;
    var $50 = HEAP32[$he_0 + 12 >> 2];
    var $51 = $50;
    if (($50 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $_pre_phi = $51 & 1;
    __label__ = 19;
    break;
   case 16:
    var $54 = $buf | 0;
    var $55 = $51 >>> 2;
    var $56 = $51 & 1;
    var $58 = ($56 | 0) != 0 ? 35 : 61;
    var $59 = _JS_snprintf($54, 20, STRING_TABLE.__str63591 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $55, HEAP32[tempInt + 4 >> 2] = $58, tempInt));
    HEAP32[$len >> 2] = $59;
    var $60 = $cx;
    var $61 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($60, $54, $len, 0);
    HEAP32[$sp >> 2] = $61;
    if (($61 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_pre_phi = $56;
      __label__ = 19;
      break;
    }
   case 17:
    var $64 = HEAP32[$ida >> 2];
    if (($64 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = $64;
    _JS_DestroyIdArray(undef, $67);
    __label__ = 29;
    break;
   case 19:
    var $_pre_phi;
    if (($_pre_phi | 0) == 0) {
      var $he_12 = $he_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($idap | 0) == 0) {
      var $_0 = $he_0;
      __label__ = 32;
      break;
    } else {
      var $he_116 = $he_0;
      __label__ = 28;
      break;
    }
   case 21:
    var $he_12;
    if (($idap | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if ((HEAP32[$ida >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 23:
    var $75 = $cx;
    var $76 = $obj;
    var $77 = _JS_Enumerate($75, $76);
    HEAP32[$ida >> 2] = $77;
    if (($77 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $81 = HEAP32[$sp >> 2];
    if (($81 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $84 = $81;
    __ZN9JSContext5free_EPv(undef, $84);
    HEAP32[$sp >> 2] = 0;
    __label__ = 29;
    break;
   case 26:
    var $86 = HEAP32[$24 >> 2] + 1 | 0;
    HEAP32[$24 >> 2] = $86;
    var $he_116 = $he_12;
    __label__ = 28;
    break;
   case 27:
    var $89 = HEAP32[$24 >> 2] + 1 | 0;
    HEAP32[$24 >> 2] = $89;
    var $_0 = $he_12;
    __label__ = 32;
    break;
   case 28:
    var $he_116;
    var $91 = HEAP32[$ida >> 2];
    HEAP32[$idap >> 2] = $91;
    var $_0 = $he_116;
    __label__ = 32;
    break;
   case 29:
    var $93 = HEAP32[$24 >> 2];
    __label__ = 30;
    break;
   case 30:
    var $93;
    if (($93 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 31:
    var $97 = HEAP32[$1 >> 2] + 136 | 0;
    var $99 = HEAP32[$97 >> 2] - 1 | 0;
    HEAP32[$97 >> 2] = $99;
    HEAP32[$cx + 140 >> 2] = 0;
    var $101 = HEAP32[$10 >> 2];
    _JS_HashTableDestroy($101);
    HEAP32[$10 >> 2] = 0;
    var $_0 = 0;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt["X"] = 1;

function __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $obj, $idap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hep = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $v = __stackBase__ + 16;
    var $setter = __stackBase__ + 40;
    var $1 = __stackBase__ + 64;
    var $2 = __stackBase__ + 72;
    var $3 = __stackBase__ + 80;
    if (__stackBase__ + 12 >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($9);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 3:
    var $12 = HEAPU32[$cx + 144 >> 2];
    var $13 = $obj;
    var $14 = __ZL14js_hash_objectPKv($13);
    var $15 = _JS_HashTableRawLookup($12, $14, $13);
    HEAP32[$hep >> 2] = $15;
    var $16 = HEAPU32[$15 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 4:
    var $19 = _JS_HashTableRawAdd($12, $hep, $14, $13, 0);
    var $21 = $cx;
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($21);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 6:
    var $24 = $obj;
    var $25 = _JS_Enumerate($21, $24);
    var $26 = $25;
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = HEAP32[$25 >> 2];
    var $31 = $obj2;
    var $32 = $prop;
    var $33 = $v;
    var $34 = $setter;
    var $35 = $v;
    var $36 = $setter;
    var $37 = $3 | 0;
    var $i_0 = 0;
    var $ok_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $i_0;
    if (($i_0 | 0) < ($30 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $ok_5 = $ok_0;
      __label__ = 27;
      break;
    }
   case 9:
    var $42 = HEAPU32[$25 + 4 + ($i_0 << 2) >> 2];
    var $43 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($24, $21, $42, $31, $32);
    if (($43 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    _JS_DestroyIdArray(undef, $25);
    var $_0 = 0;
    __label__ = 34;
    break;
   case 11:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      var $ok_4 = $43;
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js15AutoValueRooterC1EP9JSContext($33, $21);
    __ZN2js15AutoValueRooterC1EP9JSContext($34, $21);
    var $50 = HEAP32[$obj2 >> 2];
    var $51 = __ZNK8JSObject8isNativeEv($50);
    if ($51) {
      __label__ = 13;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 13:
    var $53 = HEAP32[$prop >> 2];
    var $54 = $53;
    var $55 = $53;
    var $56 = __ZNK2js5Shape14hasGetterValueEv($55);
    var $57 = __ZNK2js5Shape14hasSetterValueEv($55);
    if ($56) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZNK2js5Shape11getterValueEv($1, $54);
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($35, $1);
    __label__ = 15;
    break;
   case 15:
    if ($57) {
      __label__ = 16;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 16:
    __ZNK2js5Shape11setterValueEv($2, $54);
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($36, $2);
    if ($56) {
      __label__ = 17;
      break;
    } else {
      var $ok_1 = $43;
      __label__ = 19;
      break;
    }
   case 17:
    var $62 = __ZNK2js15AutoValueRooter5valueEv($33);
    var $63 = __ZNK2JS5Value8isObjectEv($62);
    if ($63) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $43;
      __label__ = 19;
      break;
    }
   case 18:
    var $65 = __ZNK2JS5Value8toObjectEv($62);
    var $66 = $65;
    var $67 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $66, 0);
    var $68 = ($67 | 0) != 0;
    var $69 = $68 & 1;
    if ($68) {
      var $ok_1 = $69;
      __label__ = 19;
      break;
    } else {
      var $_01 = 1;
      var $ok_3 = $69;
      __label__ = 25;
      break;
    }
   case 19:
    var $ok_1;
    var $71 = __ZNK2js15AutoValueRooter5valueEv($34);
    var $72 = $71 | 0;
    var $73$0 = HEAP32[$72 >> 2];
    var $73$1 = HEAP32[$72 + 4 >> 2];
    HEAP32[$37 >> 2] = $73$0;
    HEAP32[$37 + 4 >> 2] = $73$1;
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($35, $3);
    var $ok_2 = $ok_1;
    __label__ = 22;
    break;
   case 20:
    if ($56) {
      var $ok_2 = $43;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $74 = __ZN2js15AutoValueRooter4addrEv($33);
    var $75 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($24, $21, $42, $74);
    if (($75 | 0) == 0) {
      var $_01 = 1;
      var $ok_3 = 0;
      __label__ = 25;
      break;
    } else {
      var $ok_2 = $75;
      __label__ = 22;
      break;
    }
   case 22:
    var $ok_2;
    var $78 = __ZNK2js15AutoValueRooter5valueEv($33);
    var $79 = __ZNK2JS5Value8isObjectEv($78);
    if ($79) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $81 = __ZNK2JS5Value8toObjectEv($78);
    var $82 = $81;
    var $83 = __ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray($cx, $82, 0);
    if (($83 | 0) == 0) {
      var $_01 = 1;
      var $ok_3 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_01 = 0;
    var $ok_3 = $ok_2;
    __label__ = 25;
    break;
   case 25:
    var $ok_3;
    var $_01;
    __ZN2js15AutoValueRooterD1Ev($34);
    __ZN2js15AutoValueRooterD1Ev($33);
    if ($_01) {
      var $ok_5 = $ok_3;
      __label__ = 27;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 26;
      break;
    }
   case 26:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_0 = $ok_4;
    __label__ = 8;
    break;
   case 27:
    var $ok_5;
    var $90 = ($ok_5 | 0) != 0;
    if (($idap | 0) == 0 | $90 ^ 1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    _JS_DestroyIdArray(undef, $25);
    if ($90) {
      var $ida_0 = $26;
      var $he_0 = $19;
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 29:
    if ($90) {
      var $ida_0 = $26;
      var $he_0 = $19;
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 34;
      break;
    }
   case 30:
    var $95 = $16 + 12 | 0;
    if ((HEAP32[$95 >> 2] | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      var $ida_0 = 0;
      var $he_0 = $16;
      __label__ = 32;
      break;
    }
   case 31:
    var $99 = $cx + 140 | 0;
    var $101 = HEAP32[$99 >> 2] + 1 | 0;
    HEAP32[$99 >> 2] = $101;
    var $103 = $101 << 2;
    HEAP32[$95 >> 2] = $103;
    var $ida_0 = 0;
    var $he_0 = $16;
    __label__ = 32;
    break;
   case 32:
    var $he_0;
    var $ida_0;
    if (($idap | 0) == 0) {
      var $_0 = $he_0;
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    HEAP32[$idap >> 2] = $ida_0;
    var $_0 = $he_0;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray["X"] = 1;

function __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, $idap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 136 | 0;
    var $3 = HEAP32[$1 >> 2] - 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 52 >> 2] + 136 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    HEAP32[$cx + 140 >> 2] = 0;
    var $12 = $cx + 144 | 0;
    var $13 = HEAP32[$12 >> 2];
    _JS_HashTableDestroy($13);
    HEAP32[$12 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    if (($idap | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$idap >> 2];
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $17;
    _JS_DestroyIdArray(undef, $20);
    HEAP32[$idap >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap($trc, $map) {
  var $2 = HEAP32[$map + 8 >> 2];
  var $3 = $trc;
  var $4 = _JS_HashTableEnumerateEntries($2, 178, $3);
  return;
}

function __ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv($he, $i, $arg) {
  var $3 = $arg;
  var $4 = HEAP32[$he + 8 >> 2];
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($3, $4, undef);
  return 0;
}

function __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject7isProxyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject($4, $1);
    var $_0 = $5;
    __label__ = 10;
    break;
   case 3:
    var $7 = __ZNK8JSObject8getClassEv($1);
    var $9 = HEAP32[$7 >> 2];
    var $10 = _strlen($9);
    var $12 = ($10 << 1) + 20 | 0;
    var $13 = $cx;
    var $14 = __ZN9JSContext7malloc_Ej($13, $12);
    var $15 = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP16[$15 >> 1] = 91;
    var $nchars_05 = 0;
    var $prefix_06 = STRING_TABLE.__str12178 | 0;
    __label__ = 6;
    break;
   case 5:
    var $17 = HEAP8[$9];
    HEAP16[$26 >> 1] = $17 << 24 >> 24;
    var $20 = $nchars_05 + 2 | 0;
    if ($17 << 24 >> 24 == 0) {
      var $_lcssa = $26;
      var $_lcssa1 = $20;
      __label__ = 8;
      break;
    } else {
      var $clazz_02 = $9;
      var $28 = $20;
      __label__ = 7;
      break;
    }
   case 6:
    var $prefix_06;
    var $nchars_05;
    var $22 = $nchars_05 + 1 | 0;
    var $23 = $prefix_06 + 1 | 0;
    var $24 = HEAP8[$23];
    var $26 = $15 + ($22 << 1) | 0;
    HEAP16[$26 >> 1] = $24 << 24 >> 24;
    if ($24 << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      var $nchars_05 = $22;
      var $prefix_06 = $23;
      __label__ = 6;
      break;
    }
   case 7:
    var $28;
    var $clazz_02;
    var $29 = $clazz_02 + 1 | 0;
    var $30 = HEAP8[$29];
    var $32 = $15 + ($28 << 1) | 0;
    HEAP16[$32 >> 1] = $30 << 24 >> 24;
    var $34 = $28 + 1 | 0;
    if ($30 << 24 >> 24 == 0) {
      var $_lcssa = $32;
      var $_lcssa1 = $34;
      __label__ = 8;
      break;
    } else {
      var $clazz_02 = $29;
      var $28 = $34;
      __label__ = 7;
      break;
    }
   case 8:
    var $_lcssa1;
    var $_lcssa;
    HEAP16[$_lcssa >> 1] = 93;
    HEAP16[$15 + ($_lcssa1 << 1) >> 1] = 0;
    var $36 = $cx;
    var $37 = __Z12js_NewStringP9JSContextPtj($36, $15, $_lcssa1);
    var $38 = $37 | 0;
    if (($37 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $38;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN9JSContext5free_EPv(undef, $14);
    var $_0 = $38;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js18obj_toStringHelperEP9JSContextP8JSObject["X"] = 1;

function __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 2, 0, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8toObjectEv($v);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21InformalValueTypeNameERKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject8getClassEv($3);
    var $_0 = HEAP32[$4 >> 2];
    __label__ = 8;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8isStringEv($v);
    if ($8) {
      var $_0 = STRING_TABLE.__str22179 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK2JS5Value8isNumberEv($v);
    if ($10) {
      var $_0 = STRING_TABLE.__str32180 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value9isBooleanEv($v);
    if ($12) {
      var $_0 = STRING_TABLE.__str42181 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZNK2JS5Value6isNullEv($v);
    if ($14) {
      var $_0 = STRING_TABLE._js_null_str | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK2JS5Value11isUndefinedEv($v);
    var $_ = $16 ? STRING_TABLE._js_undefined_str | 0 : STRING_TABLE._js_value_str | 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4evalEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $1 = __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $call | 0;
    var $4 = __ZNK2js12CallReceiver6calleeEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $7 = $6 | 0;
    var $8 = __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, 9, 0, $7);
    var $10 = $8;
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8CallArgs4argcEv($call);
    if ($1 >>> 0 > 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $cx + 60 | 0;
    var $6 = __ZNK2js12ContextStack13currentScriptEPPh($5, 0);
    if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6 + 36 | 0;
    if (HEAP8[$9] << 24 >> 24 < 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = _JS_ReportWarning($13, STRING_TABLE.__ZZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsEE20TWO_ARGUMENT_WARNING | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAP8[$9] | -128;
    HEAP8[$9] = $18;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, $evalType, $caller, $scopeobj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $thisv = __stackBase__;
    var $parser = __stackBase__ + 8;
    var $tmp = __stackBase__ + 40;
    var $esg = __stackBase__ + 48;
    var $lineno = __stackBase__ + 64;
    var $1 = __ZNK8JSObject9getGlobalEv($scopeobj);
    var $2 = $1;
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext($2, $3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    _JS_ReportError($6, STRING_TABLE.__str472250 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 34;
    break;
   case 3:
    var $8 = __ZNK2js8CallArgs4argcEv($call);
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $call | 0;
    var $12 = __ZNK2js12CallReceiver4rvalEv($11);
    __ZN2JS5Value12setUndefinedEv($12);
    var $_1 = 1;
    __label__ = 34;
    break;
   case 5:
    var $14 = __ZNK2js8CallArgsixEj($call, 0);
    var $15 = __ZNK2JS5Value8isStringEv($14);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $call | 0;
    var $18 = __ZNK2js12CallReceiver4rvalEv($17);
    var $19 = $14 | 0;
    var $st$3$0 = $19 | 0;
    var $20$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$3$1 >> 2];
    var $21 = $18 | 0;
    var $st$8$0 = $21 | 0;
    HEAP32[$st$8$0 >> 2] = $20$0;
    var $st$8$1 = $21 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $20$1;
    var $_1 = 1;
    __label__ = 34;
    break;
   case 7:
    var $23 = __ZNK2JS5Value8toStringEv($14);
    var $24 = ($evalType | 0) == 8;
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = $caller;
    var $27 = __ZNK2js10StackFrame6scriptEv($26);
    var $29 = HEAPU16[$27 + 46 >> 1];
    var $30 = $cx;
    var $31 = __ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE($30, $26);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 9:
    var $34 = ($29 & 65535) + 1 | 0;
    var $35 = __ZNK2js10StackFrame9thisValueEv($26);
    var $36 = $35 | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $thisv | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    var $staticLevel_0 = $34;
    __label__ = 12;
    break;
   case 10:
    var $40 = $scopeobj;
    var $41 = $cx;
    var $42 = __ZN8JSObject10thisObjectEP9JSContext($40, $41);
    if (($42 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = $42;
    __ZN2JSL11ObjectValueER8JSObject2354($thisv, $45);
    var $staticLevel_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $staticLevel_0;
    var $47 = $cx;
    var $48 = __ZN8JSString12ensureLinearEP9JSContext($23, $47);
    if (($48 | 0) == 0) {
      var $_1 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZNK14JSLinearString5charsEv($48);
    var $52 = $48 | 0;
    var $53 = __ZNK8JSString6lengthEv($52);
    if ($53 >>> 0 > 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 14:
    if (HEAP16[$51 >> 1] << 16 >> 16 == 40) {
      __label__ = 15;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 15:
    if (HEAP16[$51 + ($53 - 1 << 1) >> 1] << 16 >> 16 == 41) {
      __label__ = 16;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 16:
    if (($caller | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $66 = $caller;
    var $67 = __ZNK2js10StackFrame6scriptEv($66);
    if ((HEAP8[$67 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $73 = $51 + 2 | 0;
    var $74 = $53 - 2 | 0;
    var $75 = $51 + ($74 << 1) | 0;
    var $cp_0 = $73;
    __label__ = 19;
    break;
   case 19:
    var $cp_0;
    if ((HEAP16[$cp_0 >> 1] - 8232 & 65535 & 65535) < 2) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($cp_0 | 0) == ($75 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($parser, $cx, $73, $74, 0, 1);
    var $81 = $parser;
    var $82 = __ZN10JSONParser5parseEPN2JS5ValueE($81, $tmp);
    if ($82) {
      __label__ = 22;
      break;
    } else {
      var $_1 = 0;
      __label__ = 34;
      break;
    }
   case 22:
    var $84 = __ZNK2JS5Value11isUndefinedEv($tmp);
    if ($84) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $86 = $call | 0;
    var $87 = __ZNK2js12CallReceiver4rvalEv($86);
    var $88 = $tmp | 0;
    var $st$3$0 = $88 | 0;
    var $89$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $88 + 4 | 0;
    var $89$1 = HEAP32[$st$3$1 >> 2];
    var $90 = $87 | 0;
    var $st$8$0 = $90 | 0;
    HEAP32[$st$8$0 >> 2] = $89$0;
    var $st$8$1 = $90 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $89$1;
    var $_1 = 1;
    __label__ = 34;
    break;
   case 24:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 19;
    break;
   case 25:
    __ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString($esg, $cx, $48);
    var $93 = __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $cx);
    if ($24) {
      __label__ = 26;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $95 = $caller;
    var $96 = __ZNK2js10StackFrame22isNonEvalFunctionFrameEv($95);
    if ($96) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    __ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject($esg, $caller, $staticLevel_0, $93, $scopeobj);
    __label__ = 28;
    break;
   case 28:
    var $99 = __ZN15EvalScriptGuard11foundScriptEv($esg);
    if ($99) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $_pre_phi = $scopeobj;
    __label__ = 32;
    break;
   case 30:
    var $102 = $24 & 1 ^ 1;
    var $103 = __ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE($47, $lineno, $102);
    var $104 = HEAP32[$lineno >> 2];
    var $105 = __ZNK9JSContext11findVersionEv($47);
    var $106 = $scopeobj;
    var $107 = $caller;
    var $108 = $93;
    var $109 = __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($47, $106, $107, $108, 33693696, $51, $53, $103, $104, $105, $52, $staticLevel_0);
    if (($109 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $112 = $109;
    __ZN15EvalScriptGuard12setNewScriptEP8JSScript($esg, $112);
    var $_pre_phi = $106;
    __label__ = 32;
    break;
   case 32:
    var $_pre_phi;
    var $114 = __ZNK15EvalScriptGuard6scriptEv($esg);
    var $115 = $call | 0;
    var $116 = __ZNK2js12CallReceiver4rvalEv($115);
    var $117 = $114;
    var $118 = __ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_($47, $117, $_pre_phi, $thisv, $evalType, 0, $116);
    var $_0 = $118;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    __ZN15EvalScriptGuardD1Ev($esg);
    var $_1 = $_0;
    __label__ = 34;
    break;
   case 34:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject["X"] = 1;

function __ZNK8JSObject9getGlobalEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject9getParentEv($1);
    if (($2 | 0) == 0) {
      var $obj_0_lcssa = $this;
      __label__ = 4;
      break;
    } else {
      var $4 = $2;
      __label__ = 2;
      break;
    }
   case 2:
    var $4;
    var $5 = __ZNK8JSObject9getParentEv($4);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $obj_0_lcssa = $4;
    __label__ = 4;
    break;
   case 4:
    var $obj_0_lcssa;
    var $10 = __ZN8JSObject8asGlobalEv($obj_0_lcssa);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE($cx, $call) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $callProbe = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext2fpEv($1);
    var $3 = $2;
    var $4 = $call | 0;
    var $5 = __ZNK2js12CallReceiver6calleeEv($4);
    var $6 = __ZNK8JSObject18getFunctionPrivateEv($5);
    var $7 = $6;
    var $8 = __ZNK2js10StackFrame6scriptEv($2);
    var $9 = $8;
    __ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript($callProbe, $cx, $7, $9);
    var $10 = __ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj($1, $2, undef, 6);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $18 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = __ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE($cx, $call);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $18 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = __ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject($cx, $call, 8, $3, $11);
    var $18 = $16;
    __label__ = 4;
    break;
   case 4:
    var $18;
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script) {
  __ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script);
  return;
}

function __ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE($scopeChain, $v) {
  var $1 = __ZNK8JSObject9getGlobalEv($scopeChain);
  var $2 = __ZNK2js12GlobalObject15getOriginalEvalEv($1);
  var $3 = __ZNK2JS5ValueeqERKS0_($2, $v);
  return $3;
}

function __ZNK2js12GlobalObject15getOriginalEvalEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 116);
  return $2;
}

function __ZN2js16IsAnyBuiltinEvalEP10JSFunction($fun) {
  var $1 = $fun;
  var $2 = __ZNK10JSFunction11maybeNativeEv($1);
  return ($2 | 0) == 36;
}

function __ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext($call, $cx) {
  var $1 = $call | 0;
  var $2 = __ZNK2js12CallReceiver6calleeEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject10principalsEP9JSContext($2, $3);
  return $4;
}

function __ZN2jsL16CastAsPropertyOpEP8JSObject2286($object) {
  return $object;
}

function __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($object) {
  return $object;
}

function __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($cx, $lookup, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $obj2 = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $has = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $cx;
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($9, $1, $id);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK8JSObject7isProxyEv($13);
    var $18 = HEAP32[$id >> 2];
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = __ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb($9, $13, $18, $has);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = (HEAP8[$has] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $24);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $26 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $lookup, $14, $18, $obj2, $prop);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = (HEAP32[$prop >> 2] | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $30);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv2280($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $lookup, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $1 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $1, 5);
    var $3 = ($lookup | 0) != 0 ? $lookup : 46;
    var $4 = FUNCTION_TABLE[$3]($cx, $obj, $id, $objp, $propp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$objp >> 2];
    if (($10 | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    var $14 = __ZNK8JSObject8getClassEv($13);
    var $16 = HEAP32[$14 + 72 >> 2];
    if (($16 | 0) == 0) {
      var $outer_0 = 0;
      var $23 = $10;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    var $20 = FUNCTION_TABLE[$19]($cx, $10);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $outer_0 = $20;
    var $23 = HEAP32[$objp >> 2];
    __label__ = 7;
    break;
   case 7:
    var $23;
    var $outer_0;
    if (($outer_0 | 0) == ($23 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $3 = HEAP32[$cx + 208 >> 2];
  var $4 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $1, $3, $objp, $propp);
  return $4 & 1;
}

function __Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $attrs = __stackBase__ + 8;
    var $1 = $obj;
    var $2 = $cx;
    var $3 = $pobj;
    var $4 = $prop;
    var $5 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($1, $2, $id, $3, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $12 = HEAP32[$pobj >> 2];
    if (($12 | 0) == ($obj | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 6:
    var $16 = $12;
    var $17 = __ZN8JSObject13getAttributesEP9JSContextiPj($16, $2, $id, $attrs);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = (HEAP32[$attrs >> 2] & 1 | 0) != 0;
    __ZN2JS5Value10setBooleanEb($vp, $22);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $id = __stackBase__ + 8;
    var $junk = __stackBase__ + 12;
    var $attrs = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $2 = $call | 0;
    var $3 = $cx;
    var $4 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $6 = __ZNK2js12CallReceiver5thisvEv($2);
    var $7 = __ZNK2JS5Value8toObjectEv($6);
    var $8 = $7;
    if ($argc >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js8CallArgsixEj($call, 1);
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE2285($11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($3, 2, 0, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_getter_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $15 = __ZNK2JS5Value8toObjectEv($11);
    var $16 = $15;
    var $17 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($16);
    var $18 = __ZNK2js8CallArgsixEj($call, 0);
    var $19 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($3, $18, $id);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = HEAP32[$id >> 2];
    var $22 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($3, $7, $21, 16);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $24 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $8, $21, 3, $junk, $attrs);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js12CallReceiver4rvalEv($2);
    __ZN2JS5Value12setUndefinedEv($27);
    __ZN2JSL14UndefinedValueEv2280($1);
    var $28 = $17;
    var $29 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $3, $21, $1, $28, 12, 81);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE2285($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $id, $mode, $vp, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $obj;
    var $2 = __ZNK8JSObject6isWithEv($1);
    if ($2) {
      var $3 = $1;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $obj;
      var $_lcssa = $1;
      __label__ = 4;
      break;
    }
   case 2:
    var $3;
    var $4 = __ZNK8JSObject8getProtoEv($3);
    var $5 = __ZNK8JSObject6isWithEv($4);
    if ($5) {
      var $3 = $4;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa = $4;
    var $_lcssa = $4;
    __label__ = 4;
    break;
   case 4:
    var $_lcssa;
    var $_01_lcssa;
    var $9 = ($mode & 8 | 0) != 0;
    var $10 = $mode & 7;
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($10 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$pobj >> 2] = $_01_lcssa;
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = __ZNK8JSObject8getProtoEv($_lcssa);
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $13);
    __label__ = 7;
    break;
   case 7:
    HEAP32[$attrsp >> 2] = 4;
    __label__ = 21;
    break;
   case 8:
    HEAP32[$pobj >> 2] = $_01_lcssa;
    var $16 = __ZNK8JSObject9getParentEv($_lcssa);
    __ZN2JS5Value9setObjectER8JSObject($vp, $16);
    HEAP32[$attrsp >> 2] = 6;
    __label__ = 21;
    break;
   case 9:
    var $18 = $cx;
    var $19 = $pobj;
    var $20 = $prop;
    var $21 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($_lcssa, $18, $id, $19, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = HEAPU32[$prop >> 2];
    if (($24 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    if ($9) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 13;
    break;
   case 13:
    HEAP32[$attrsp >> 2] = 0;
    HEAP32[$pobj >> 2] = $_01_lcssa;
    __label__ = 21;
    break;
   case 14:
    var $31 = HEAP32[$pobj >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if ($9) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JS5Value12setUndefinedEv($vp);
    HEAP32[$attrsp >> 2] = 0;
    __label__ = 21;
    break;
   case 17:
    var $36 = $24;
    var $37 = __ZNK2js5Shape10attributesEv($36);
    HEAP32[$attrsp >> 2] = $37 & 255;
    if ($9) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $42 = HEAP32[$24 + 24 >> 2];
    var $43 = __ZNK8JSObject12containsSlotEj($31, $42);
    if ($43) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $45 = __ZNK8JSObject13nativeGetSlotEj($31, $42);
    var $46 = $45 | 0;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = $vp | 0;
    HEAP32[$48 >> 2] = $47$0;
    HEAP32[$48 + 4 >> 2] = $47$1;
    __label__ = 21;
    break;
   case 20:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 21;
    break;
   case 21:
    var $51 = HEAP32[$pobj >> 2];
    var $52 = $51;
    var $53 = __ZNK8JSObject8getClassEv($52);
    var $55 = HEAP32[$53 + 44 >> 2];
    var $56 = $55;
    if (($55 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $check_0 = $56;
      __label__ = 24;
      break;
    }
   case 22:
    var $59 = $cx;
    var $60 = _JS_GetSecurityCallbacks($59);
    if (($60 | 0) == 0) {
      var $70 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $check_0 = HEAP32[$60 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $check_0;
    if (($check_0 | 0) == 0) {
      var $70 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $68 = FUNCTION_TABLE[$check_0]($cx, $51, $id, $mode, $vp);
    var $70 = ($68 | 0) != 0;
    __label__ = 26;
    break;
   case 26:
    var $70;
    var $_0 = $70 & 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj["X"] = 1;

function __Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $id = __stackBase__ + 8;
    var $junk = __stackBase__ + 12;
    var $attrs = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    __ZN2js14CallArgsFromVpEjPN2JS5ValueE($call, $argc, $vp);
    var $2 = $call | 0;
    var $3 = $cx;
    var $4 = __ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $6 = __ZNK2js12CallReceiver5thisvEv($2);
    var $7 = __ZNK2JS5Value8toObjectEv($6);
    var $8 = $7;
    if ($argc >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js8CallArgsixEj($call, 1);
    var $12 = __ZL13js_IsCallableRKN2JS5ValueE2285($11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($3, 2, 0, 151, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_setter_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 5:
    var $15 = __ZNK2JS5Value8toObjectEv($11);
    var $16 = $15;
    var $17 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($16);
    var $18 = __ZNK2js8CallArgsixEj($call, 0);
    var $19 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($3, $18, $id);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $21 = HEAP32[$id >> 2];
    var $22 = __ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij($3, $7, $21, 32);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $24 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $8, $21, 3, $junk, $attrs);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZNK2js12CallReceiver4rvalEv($2);
    __ZN2JS5Value12setUndefinedEv($27);
    __ZN2JSL14UndefinedValueEv2280($1);
    var $28 = $17;
    var $29 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($7, $3, $21, $1, 10, $28, 97);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $attrs = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($3, $vp, 0);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value11isPrimitiveEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx_val$0, $_idx_val$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cx;
    _JS_ReportErrorNumber($11, 2, 0, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str2433396 | 0, tempInt));
    _JS_free(undef, $8);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $13 = __ZNK2JS5Value8toObjectEv($5);
    var $14 = $13;
    var $19 = HEAP32[HEAP32[$cx + 52 >> 2] + 210292 >> 2] | 0;
    var $20 = __ZL12ATOM_TO_JSIDP6JSAtom2291($19);
    var $21 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $14, $20, 0, $vp, $attrs);
    var $_0 = $21;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $v_0_0_0_val$0, $v_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $1 | 0;
  HEAP32[$2 >> 2] = $v_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $v_0_0_0_val$1;
  var $3 = $cx;
  var $4 = _js_DecompileValueGenerator($3, 1, $1, 0);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2291($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2517($1);
  return $2;
}

function __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($cx, $desc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    if ((HEAP32[$desc >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    __ZN2js8PropDescC2Ev($d);
    __ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor($d, $desc);
    var $6 = __ZN2js8PropDesc10makeObjectEP9JSContext($d, $cx);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $d | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor($this, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this | 0;
    __ZN2JS5Value12setUndefinedEv($3);
    var $4 = $desc + 4 | 0;
    HEAP8[$this + 32 | 0] = HEAP32[$4 >> 2] & 255;
    var $11 = $this + 33 | 0;
    var $12 = HEAP8[$11];
    if ((HEAP32[$4 >> 2] & 48 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $12 | 1;
    HEAP8[$11] = $14;
    if ((HEAP32[$4 >> 2] & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$desc + 8 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = $20;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($1, $23);
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 6;
    break;
   case 6:
    var $26 = $1 | 0;
    var $st$1$0 = $26 | 0;
    var $27$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$1$1 >> 2];
    var $28 = $this + 16 | 0;
    var $st$6$0 = $28 | 0;
    HEAP32[$st$6$0 >> 2] = $27$0;
    var $st$6$1 = $28 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $27$1;
    var $30 = HEAP8[$11] | 2;
    HEAP8[$11] = $30;
    if ((HEAP32[$4 >> 2] & 32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $36 = HEAP32[$desc + 12 >> 2];
    if (($36 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $39 = $36;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($2, $39);
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL14UndefinedValueEv2280($2);
    __label__ = 10;
    break;
   case 10:
    var $42 = $2 | 0;
    var $st$1$0 = $42 | 0;
    var $43$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $42 + 4 | 0;
    var $43$1 = HEAP32[$st$1$1 >> 2];
    var $44 = $this + 24 | 0;
    var $st$6$0 = $44 | 0;
    HEAP32[$st$6$0 >> 2] = $43$0;
    var $st$6$1 = $44 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $43$1;
    var $46 = HEAP8[$11] & -5;
    HEAP8[$11] = $46;
    var $47 = $this + 8 | 0;
    __ZN2JS5Value12setUndefinedEv($47);
    var $storemerge = HEAP8[$11] & -9;
    __label__ = 12;
    break;
   case 11:
    var $51 = $12 & -2;
    HEAP8[$11] = $51;
    var $52 = $this + 16 | 0;
    __ZN2JS5Value12setUndefinedEv($52);
    var $54 = HEAP8[$11] & -3;
    HEAP8[$11] = $54;
    var $55 = $this + 24 | 0;
    __ZN2JS5Value12setUndefinedEv($55);
    var $56 = HEAP8[$11];
    var $57 = $56 | 4;
    HEAP8[$11] = $57;
    var $58 = $desc + 16 | 0;
    var $59$0 = HEAP32[$58 >> 2];
    var $59$1 = HEAP32[$58 + 4 >> 2];
    var $60 = $this + 8 | 0;
    HEAP32[$60 >> 2] = $59$0;
    HEAP32[$60 + 4 >> 2] = $59$1;
    var $storemerge = $56 | 12;
    __label__ = 12;
    break;
   case 12:
    var $storemerge;
    HEAP8[$11] = $storemerge | 48;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor["X"] = 1;

function __ZN2js8PropDesc10makeObjectEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11ObjectClassE);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 52 >> 2];
    var $9 = $this + 33 | 0;
    var $10 = HEAP8[$9];
    if (($10 & 32) << 24 >> 24 == 0) {
      var $27 = $10;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$8 + 210348 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom2291($16);
    var $21 = (HEAP8[$this + 32 | 0] & 4) << 24 >> 24 == 0;
    __ZN2JSL12BooleanValueEb2297($1, $21);
    var $22 = $4;
    var $23 = $cx;
    var $24 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($22, $23, $17, $1, 10, 12, 1);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = HEAP8[$9];
    __label__ = 5;
    break;
   case 5:
    var $27;
    if (($27 & 16) << 24 >> 24 == 0) {
      var $44 = $27;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = HEAP32[$8 + 210344 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom2291($33);
    var $38 = (HEAP8[$this + 32 | 0] & 1) << 24 >> 24 != 0;
    __ZN2JSL12BooleanValueEb2297($2, $38);
    var $39 = $4;
    var $40 = $cx;
    var $41 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($39, $40, $34, $2, 10, 12, 1);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $44 = HEAP8[$9];
    __label__ = 8;
    break;
   case 8:
    var $44;
    if (($44 & 1) << 24 >> 24 == 0) {
      var $58 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $50 = HEAP32[$8 + 210220 >> 2] | 0;
    var $51 = __ZL12ATOM_TO_JSIDP6JSAtom2291($50);
    var $52 = $this + 16 | 0;
    var $53 = $4;
    var $54 = $cx;
    var $55 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($53, $54, $51, $52, 10, 12, 1);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $58 = HEAP8[$9];
    __label__ = 11;
    break;
   case 11:
    var $58;
    if (($58 & 2) << 24 >> 24 == 0) {
      var $72 = $58;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $64 = HEAP32[$8 + 210296 >> 2] | 0;
    var $65 = __ZL12ATOM_TO_JSIDP6JSAtom2291($64);
    var $66 = $this + 24 | 0;
    var $67 = $4;
    var $68 = $cx;
    var $69 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($67, $68, $65, $66, 10, 12, 1);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $72 = HEAP8[$9];
    __label__ = 14;
    break;
   case 14:
    var $72;
    if (($72 & 4) << 24 >> 24 == 0) {
      var $86 = $72;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $78 = HEAP32[$8 + 210356 >> 2] | 0;
    var $79 = __ZL12ATOM_TO_JSIDP6JSAtom2291($78);
    var $80 = $this + 8 | 0;
    var $81 = $4;
    var $82 = $cx;
    var $83 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($81, $82, $79, $80, 10, 12, 1);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $86 = HEAP8[$9];
    __label__ = 17;
    break;
   case 17:
    var $86;
    if (($86 & 8) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $_pre_phi = $4;
    __label__ = 20;
    break;
   case 19:
    var $92 = HEAP32[$8 + 210352 >> 2] | 0;
    var $93 = __ZL12ATOM_TO_JSIDP6JSAtom2291($92);
    var $97 = (HEAP8[$this + 32 | 0] & 2) << 24 >> 24 == 0;
    __ZN2JSL12BooleanValueEb2297($3, $97);
    var $98 = $4;
    var $99 = $cx;
    var $100 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($98, $99, $93, $3, 10, 12, 1);
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $_pre_phi = $98;
      __label__ = 20;
      break;
    }
   case 20:
    var $_pre_phi;
    var $103 = $this | 0;
    __ZN2JS5Value9setObjectER8JSObject($103, $_pre_phi);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc10makeObjectEP9JSContext["X"] = 1;

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb2335($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, $clasp, $5);
  return $6;
}

function __ZN2JSL12BooleanValueEb2297($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $obj;
    var $2 = __ZNK8JSObject7isProxyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $desc;
    var $6 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($4, $1, $id, 0, $5);
    var $_0 = $6;
    __label__ = 16;
    break;
   case 3:
    var $8 = __ZNK8JSObject6getOpsEv($1);
    var $11 = HEAP32[$8 + 4 >> 2];
    var $12 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, $11, $obj, $id, $pobj, $prop);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$prop >> 2];
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$desc >> 2] = 0;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 6:
    var $21 = HEAP32[$pobj >> 2];
    var $22 = __ZNK8JSObject8isNativeEv($21);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $24 = $15;
    var $25 = __ZNK2js5Shape10attributesEv($24);
    var $26 = $25 & 255;
    HEAP32[$desc + 4 >> 2] = $26;
    if (($26 & 48 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_pre_phi = $cx;
    __label__ = 14;
    break;
   case 9:
    if (($26 & 16 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZNK2js5Shape12getterObjectEv($24);
    var $35 = $34;
    var $36 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($35);
    HEAP32[$desc + 8 >> 2] = $36;
    __label__ = 11;
    break;
   case 11:
    if (($26 & 32 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZNK2js5Shape12setterObjectEv($24);
    var $42 = $41;
    var $43 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($42);
    HEAP32[$desc + 12 >> 2] = $43;
    __label__ = 15;
    break;
   case 13:
    var $46 = $desc + 4 | 0;
    var $47 = $cx;
    var $48 = __ZN8JSObject13getAttributesEP9JSContextiPj($21, $47, $id, $46);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      var $_pre_phi = $47;
      __label__ = 14;
      break;
    }
   case 14:
    var $_pre_phi;
    var $51 = $desc + 16 | 0;
    var $52 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1, $_pre_phi, $id, $51);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$desc >> 2] = $obj;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor["X"] = 1;

function __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = $desc;
    var $2 = $cx;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($1, $2);
    var $3 = $desc + 16 | 0;
    var $4 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $id, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($cx, $3, $vp);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($1);
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8PropDescC2Ev($this) {
  var $1 = $this | 0;
  __ZN2JSL14UndefinedValueEv2280($1);
  var $2 = $this + 8 | 0;
  __ZN2JSL14UndefinedValueEv2280($2);
  var $3 = $this + 16 | 0;
  __ZN2JSL14UndefinedValueEv2280($3);
  var $4 = $this + 24 | 0;
  __ZN2JSL14UndefinedValueEv2280($4);
  HEAP8[$this + 32 | 0] = 0;
  var $6 = $this + 33 | 0;
  var $8 = HEAP8[$6] & -64;
  HEAP8[$6] = $8;
  return;
}

function __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($this, $cx, $origval, $checkAccessors) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $found = __stackBase__ + 8;
    var $1 = $origval | 0;
    var $st$3$0 = $1 | 0;
    var $2$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $1 + 4 | 0;
    var $2$1 = HEAP32[$st$3$1 >> 2];
    var $3 = $v | 0;
    var $st$8$0 = $3 | 0;
    HEAP32[$st$8$0 >> 2] = $2$0;
    var $st$8$1 = $3 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2$1;
    var $4 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $cx;
    _JS_ReportErrorNumber($6, 2, 0, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8toObjectEv($v);
    var $9 = $8;
    var $10 = $this | 0;
    var $st$3$0 = $10 | 0;
    HEAP32[$st$3$0 >> 2] = $2$0;
    var $st$3$1 = $10 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $2$1;
    var $11 = $this + 32 | 0;
    HEAP8[$11] = 6;
    HEAP8[$found] = 0;
    var $12 = $cx + 52 | 0;
    var $16 = HEAP32[HEAP32[$12 >> 2] + 210344 >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom2291($16);
    var $18 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $17, $v, $found);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 4:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $this + 33 | 0;
    var $26 = HEAP8[$24] | 16;
    HEAP8[$24] = $26;
    var $27 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($27 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $31 = HEAP8[$11] | 1;
    HEAP8[$11] = $31;
    __label__ = 7;
    break;
   case 7:
    var $36 = HEAP32[HEAP32[$12 >> 2] + 210348 >> 2] | 0;
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom2291($36);
    var $38 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $37, $v, $found);
    if ($38) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 8:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $44 = $this + 33 | 0;
    var $46 = HEAP8[$44] | 32;
    HEAP8[$44] = $46;
    var $47 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($47 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $51 = HEAP8[$11] & -5;
    HEAP8[$11] = $51;
    __label__ = 11;
    break;
   case 11:
    var $56 = HEAP32[HEAP32[$12 >> 2] + 210356 >> 2] | 0;
    var $57 = __ZL12ATOM_TO_JSIDP6JSAtom2291($56);
    var $58 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $57, $v, $found);
    if ($58) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 12:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $64 = $this + 33 | 0;
    var $66 = HEAP8[$64] | 4;
    HEAP8[$64] = $66;
    var $st$4$0 = $3 | 0;
    var $67$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $3 + 4 | 0;
    var $67$1 = HEAP32[$st$4$1 >> 2];
    var $68 = $this + 8 | 0;
    var $st$9$0 = $68 | 0;
    HEAP32[$st$9$0 >> 2] = $67$0;
    var $st$9$1 = $68 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $67$1;
    __label__ = 14;
    break;
   case 14:
    var $73 = HEAP32[HEAP32[$12 >> 2] + 210352 >> 2] | 0;
    var $74 = __ZL12ATOM_TO_JSIDP6JSAtom2291($73);
    var $75 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $74, $v, $found);
    if ($75) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 15:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $81 = $this + 33 | 0;
    var $83 = HEAP8[$81] | 8;
    HEAP8[$81] = $83;
    var $84 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
    if (($84 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $88 = HEAP8[$11] & -3;
    HEAP8[$11] = $88;
    __label__ = 18;
    break;
   case 18:
    var $93 = HEAP32[HEAP32[$12 >> 2] + 210220 >> 2] | 0;
    var $94 = __ZL12ATOM_TO_JSIDP6JSAtom2291($93);
    var $95 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $94, $v, $found);
    if ($95) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 19:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $101 = $this + 33 | 0;
    var $103 = HEAP8[$101] | 1;
    HEAP8[$101] = $103;
    var $st$4$0 = $3 | 0;
    var $104$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $3 + 4 | 0;
    var $104$1 = HEAP32[$st$4$1 >> 2];
    var $105 = $this + 16 | 0;
    var $st$9$0 = $105 | 0;
    HEAP32[$st$9$0 >> 2] = $104$0;
    var $st$9$1 = $105 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $104$1;
    var $107 = HEAP8[$11] | 80;
    HEAP8[$11] = $107;
    if ($checkAccessors) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $109 = $cx;
    var $110 = __ZN2js8PropDesc11checkGetterEP9JSContext($this, $109);
    if ($110) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 22:
    var $115 = HEAP32[HEAP32[$12 >> 2] + 210296 >> 2] | 0;
    var $116 = __ZL12ATOM_TO_JSIDP6JSAtom2291($115);
    var $117 = __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $9, $116, $v, $found);
    if ($117) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 23:
    var $_pre = $this + 33 | 0;
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $124 = HEAP8[$_pre] | 2;
    HEAP8[$_pre] = $124;
    var $st$3$0 = $3 | 0;
    var $125$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $3 + 4 | 0;
    var $125$1 = HEAP32[$st$3$1 >> 2];
    var $126 = $this + 24 | 0;
    var $st$8$0 = $126 | 0;
    HEAP32[$st$8$0 >> 2] = $125$0;
    var $st$8$1 = $126 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $125$1;
    var $128 = HEAP8[$11] | 96;
    HEAP8[$11] = $128;
    if ($checkAccessors) {
      __label__ = 25;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    }
   case 25:
    var $130 = $cx;
    var $131 = __ZN2js8PropDesc11checkSetterEP9JSContext($this, $130);
    if ($131) {
      var $_pre_phi = $_pre;
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 26:
    var $_pre_phi;
    var $132 = HEAP8[$_pre_phi];
    if (($132 & 3) << 24 >> 24 == 0 | ($132 & 12) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $138 = $cx;
    _JS_ReportErrorNumber($138, 2, 0, 238, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb["X"] = 1;

function __ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb($cx, $obj, $id, $vp, $foundp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject11hasPropertyEP9JSContextiPbj($1, $2, $id, $foundp, 5);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP8[$foundp] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $10 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($1, $2, $id, $vp);
    var $_0 = ($10 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject7isArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval);
    var $_0 = ($4 | 0) != 0;
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK8JSObject6getOpsEv($1);
    if ((HEAP32[$7 + 4 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject7isProxyEv($1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = HEAP32[$id >> 2];
    var $15 = $desc | 0;
    var $16 = $cx;
    var $17 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE($16, $1, $14, $15);
    var $_0 = $17;
    __label__ = 8;
    break;
   case 6:
    var $19 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 239, $throwError, $rval);
    var $_0 = ($19 | 0) != 0;
    __label__ = 8;
    break;
   case 7:
    var $22 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval);
    var $_0 = ($22 | 0) != 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = $obj;
    var $2 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($1, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject14getArrayLengthEv($1);
    var $9 = HEAP32[$id >> 2];
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $15 = __ZL12JSID_IS_ATOMiP6JSAtom2491($9, $14);
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = $cx;
    _JS_ReportErrorNumber($18, 2, 0, 242, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 5:
    var $20 = __Z12js_IdIsIndexiPj($9, $index);
    if (($20 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, 0, $rval);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP8[$rval] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $30 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 243, $throwError, $rval);
    var $_0 = $30;
    __label__ = 13;
    break;
   case 9:
    var $32 = HEAPU32[$index >> 2];
    if ($32 >>> 0 < $8 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $32 + 1 | 0;
    var $36 = $cx;
    __ZN8JSObject14setArrayLengthEP9JSContextj($1, $36, $35);
    __label__ = 11;
    break;
   case 11:
    HEAP8[$rval] = 1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $39 = __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval);
    var $_0 = $39;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, $errorNumber, $throwError, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ($throwError) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    if (HEAP16[_js_ErrorFormatString + ($errorNumber << 3) + 4 >> 1] << 16 >> 16 == 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $7 = $cx;
    var $8 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($7, 0, $errorNumber, 0, $1, 0, 0, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 2, 0, $errorNumber, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    HEAP8[$rval] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb($cx, $obj, $id, $desc, $throwError, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $current = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $dummy = __stackBase__ + 8;
    var $dummyAttrs = __stackBase__ + 16;
    var $tmp = __stackBase__ + 20;
    var $v = __stackBase__ + 28;
    var $same = __stackBase__ + 36;
    var $1 = __stackBase__ + 40;
    var $same1 = __stackBase__ + 48;
    var $2 = __stackBase__ + 52;
    var $same2 = __stackBase__ + 60;
    var $same3 = __stackBase__ + 64;
    var $same4 = __stackBase__ + 68;
    var $3 = __stackBase__ + 72;
    var $same5 = __stackBase__ + 80;
    var $4 = __stackBase__ + 84;
    var $attrs = __stackBase__ + 92;
    var $dummy6 = __stackBase__ + 96;
    var $dummy8 = __stackBase__ + 104;
    var $5 = HEAP32[$id >> 2];
    var $6 = __Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_($cx, 0, $obj, $5, $obj2, $current);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 100;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$current >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $12 = $obj;
    var $13 = __ZNK8JSObject12isExtensibleEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZL6RejectP9JSContextP8JSObjectjbPb($cx, $obj, 239, $throwError, $rval);
    var $_0 = $15;
    __label__ = 100;
    break;
   case 5:
    HEAP8[$rval] = 1;
    var $17 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK2js8PropDesc16isDataDescriptorEv($desc);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = HEAP32[$id >> 2];
    var $22 = $desc + 8 | 0;
    var $25 = HEAPU8[$desc + 32 | 0] & 255;
    var $26 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $21, $22, 10, 12, $25);
    var $_0 = $26;
    __label__ = 100;
    break;
   case 8:
    var $28 = HEAP32[$id >> 2];
    var $29 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $obj, $28, 3, $dummy, $dummyAttrs);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 100;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL14UndefinedValueEv2280($tmp);
    var $32 = HEAP32[$id >> 2];
    var $33 = __ZNK2js8PropDesc6getterEv($desc);
    var $34 = __ZNK2js8PropDesc6setterEv($desc);
    var $37 = HEAPU8[$desc + 32 | 0] & 255;
    var $38 = $33;
    var $39 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $32, $tmp, $38, $34, $37);
    var $_0 = $39;
    __label__ = 100;
    break;
   case 10:
    __ZN2JSL14UndefinedValueEv2280($v);
    var $41 = HEAPU32[$current >> 2];
    var $42 = $41;
    var $43 = __ZNK2js8PropDesc20isAccessorDescriptorEv($desc);
    var $44 = $41;
    if ($43) {
      __label__ = 11;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 11:
    var $46 = __ZNK2js5Shape20isAccessorDescriptorEv($44);
    if ($46) {
      __label__ = 12;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 12:
    var $48 = $desc + 33 | 0;
    var $49 = HEAPU8[$48];
    if (($49 & 1) << 24 >> 24 == 0) {
      var $60 = $49;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = __ZNK2js8PropDesc11getterValueEv($desc);
    __ZNK2js5Shape17getterOrUndefinedEv($1, $42);
    var $54 = $cx;
    var $55 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($54, $53, $1, $same);
    if ($55) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 14:
    if ((HEAP32[$same >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $60 = HEAP8[$48];
    __label__ = 16;
    break;
   case 16:
    var $60;
    if (($60 & 2) << 24 >> 24 == 0) {
      var $_pre_phi = $48;
      __label__ = 42;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = __ZNK2js8PropDesc11setterValueEv($desc);
    __ZNK2js5Shape17setterOrUndefinedEv($2, $42);
    var $65 = $cx;
    var $66 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($65, $64, $2, $same1);
    if ($66) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 18:
    if ((HEAP32[$same1 >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      var $_pre_phi = $48;
      __label__ = 42;
      break;
    }
   case 19:
    var $71 = __ZNK2js5Shape16isDataDescriptorEv($44);
    if ($71) {
      __label__ = 20;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 20:
    var $73 = $41;
    var $74 = __ZNK2js5Shape12configurableEv($73);
    if ($74) {
      __label__ = 28;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $76 = __ZNK2js5Shape16hasDefaultGetterEv($44);
    if ($76) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $78 = __ZNK2js5Shape16hasDefaultSetterEv($44);
    if ($78) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $80 = __ZNK2js8PropDesc16isDataDescriptorEv($desc);
    if ($80) {
      __label__ = 24;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 24:
    if ((HEAP8[$desc + 33 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $87 = __ZNK2js8PropDesc8writableEv($desc);
    if ($87) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 26:
    var $89 = __ZNK2js5Shape8writableEv($73);
    if ($89) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    var $91 = HEAP32[$id >> 2];
    var $92 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $91, $rval);
    var $_0 = $92;
    __label__ = 100;
    break;
   case 28:
    var $94 = HEAP32[$obj2 >> 2];
    var $95 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $94, $42, 2, $v);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 100;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $98 = __ZNK2js8PropDesc16isDataDescriptorEv($desc);
    if ($98) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $_pre_phi = $desc + 33 | 0;
    __label__ = 42;
    break;
   case 31:
    var $100 = __ZNK2js5Shape16isDataDescriptorEv($44);
    if ($100) {
      __label__ = 32;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 32:
    var $102 = $desc + 33 | 0;
    var $103 = HEAP8[$102];
    if (($103 & 4) << 24 >> 24 == 0) {
      var $124 = $103;
      __label__ = 40;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $107 = $desc + 8 | 0;
    var $108 = $cx;
    var $109 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($108, $107, $v, $same2);
    if ($109) {
      __label__ = 34;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 34:
    if ((HEAP32[$same2 >> 2] | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $124 = HEAP8[$102];
    __label__ = 40;
    break;
   case 36:
    var $114 = $41;
    var $115 = __ZNK2js5Shape12configurableEv($114);
    if ($115) {
      __label__ = 47;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $117 = __ZNK2js5Shape16hasDefaultGetterEv($44);
    if ($117) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $119 = __ZNK2js5Shape16hasDefaultSetterEv($44);
    if ($119) {
      __label__ = 47;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $121 = HEAP32[$id >> 2];
    var $122 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $121, $rval);
    var $_0 = $122;
    __label__ = 100;
    break;
   case 40:
    var $124;
    if (($124 & 8) << 24 >> 24 == 0) {
      var $_pre_phi = $102;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $128 = __ZNK2js8PropDesc8writableEv($desc);
    var $129 = $41;
    var $130 = __ZNK2js5Shape8writableEv($129);
    if ($128 ^ $130) {
      __label__ = 47;
      break;
    } else {
      var $_pre_phi = $102;
      __label__ = 42;
      break;
    }
   case 42:
    var $_pre_phi;
    var $132 = HEAP8[$_pre_phi];
    if (($132 & 32) << 24 >> 24 == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $136 = __ZNK2js8PropDesc12configurableEv($desc);
    var $137 = $41;
    var $138 = __ZNK2js5Shape12configurableEv($137);
    if ($136 ^ $138) {
      __label__ = 47;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if (($132 & 16) << 24 >> 24 == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $144 = __ZNK2js8PropDesc10enumerableEv($desc);
    var $145 = __ZNK2js5Shape10enumerableEv($44);
    if ($144 ^ $145) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    HEAP8[$rval] = 1;
    var $_0 = 1;
    __label__ = 100;
    break;
   case 47:
    var $149 = $41;
    var $150 = __ZNK2js5Shape12configurableEv($149);
    if ($150) {
      __label__ = 52;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $152 = __ZNK2js8PropDesc12configurableEv($desc);
    if ($152) {
      __label__ = 51;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    if ((HEAP8[$desc + 33 | 0] & 16) << 24 >> 24 == 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $159 = __ZNK2js8PropDesc10enumerableEv($desc);
    var $160 = __ZNK2js5Shape10enumerableEv($44);
    if ($159 ^ $160) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $163 = HEAP32[$id >> 2];
    var $164 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $163, $rval);
    var $_0 = $164;
    __label__ = 100;
    break;
   case 52:
    var $166 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc);
    if ($166) {
      var $callDelProperty_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $168 = __ZNK2js8PropDesc16isDataDescriptorEv($desc);
    var $169 = __ZNK2js5Shape16isDataDescriptorEv($44);
    var $170 = $168 ^ $169;
    var $171 = __ZNK2js5Shape12configurableEv($149);
    if ($170) {
      __label__ = 54;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 54:
    if ($171) {
      var $callDelProperty_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $174 = HEAP32[$id >> 2];
    var $175 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $174, $rval);
    var $_0 = $175;
    __label__ = 100;
    break;
   case 56:
    if ($168) {
      __label__ = 57;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 57:
    if ($171) {
      __label__ = 66;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $179 = __ZNK2js5Shape8writableEv($149);
    if ($179) {
      __label__ = 66;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $182 = HEAP8[$desc + 33 | 0];
    if (($182 & 8) << 24 >> 24 == 0) {
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $186 = __ZNK2js8PropDesc8writableEv($desc);
    if ($186) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $188 = HEAP32[$id >> 2];
    var $189 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $188, $rval);
    var $_0 = $189;
    __label__ = 100;
    break;
   case 62:
    if (($182 & 4) << 24 >> 24 == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $194 = $desc + 8 | 0;
    var $195 = $cx;
    var $196 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($195, $194, $v, $same3);
    if ($196) {
      __label__ = 64;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 64:
    if ((HEAP32[$same3 >> 2] | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $201 = HEAP32[$id >> 2];
    var $202 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $201, $rval);
    var $_0 = $202;
    __label__ = 100;
    break;
   case 66:
    var $204 = __ZNK2js5Shape16hasDefaultGetterEv($44);
    if ($204) {
      __label__ = 67;
      break;
    } else {
      var $callDelProperty_0 = 1;
      __label__ = 78;
      break;
    }
   case 67:
    var $206 = __ZNK2js5Shape16hasDefaultSetterEv($44);
    var $callDelProperty_0 = $206 ^ 1;
    __label__ = 78;
    break;
   case 68:
    if ($171) {
      var $callDelProperty_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $210 = $desc + 33 | 0;
    var $211 = HEAP8[$210];
    if (($211 & 2) << 24 >> 24 == 0) {
      var $225 = $211;
      __label__ = 74;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $215 = __ZNK2js8PropDesc11setterValueEv($desc);
    __ZNK2js5Shape17setterOrUndefinedEv($3, $42);
    var $216 = $cx;
    var $217 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($216, $215, $3, $same4);
    if ($217) {
      __label__ = 71;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 71:
    if ((HEAP32[$same4 >> 2] | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $225 = HEAP8[$210];
    __label__ = 74;
    break;
   case 73:
    var $222 = HEAP32[$id >> 2];
    var $223 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $222, $rval);
    var $_0 = $223;
    __label__ = 100;
    break;
   case 74:
    var $225;
    if (($225 & 1) << 24 >> 24 == 0) {
      var $callDelProperty_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $229 = __ZNK2js8PropDesc11getterValueEv($desc);
    __ZNK2js5Shape17getterOrUndefinedEv($4, $42);
    var $230 = $cx;
    var $231 = __ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi($230, $229, $4, $same5);
    if ($231) {
      __label__ = 76;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 76:
    if ((HEAP32[$same5 >> 2] | 0) == 0) {
      __label__ = 77;
      break;
    } else {
      var $callDelProperty_0 = 0;
      __label__ = 78;
      break;
    }
   case 77:
    var $236 = HEAP32[$id >> 2];
    var $237 = __ZL6RejectP9JSContextjbiPb($cx, $throwError, $236, $rval);
    var $_0 = $237;
    __label__ = 100;
    break;
   case 78:
    var $callDelProperty_0;
    var $239 = __ZNK2js8PropDesc19isGenericDescriptorEv($desc);
    if ($239) {
      __label__ = 79;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 79:
    var $242 = HEAPU8[$desc + 33 | 0];
    var $changed_0 = ($242 & 32) << 24 >> 24 == 0 ? 0 : 4;
    var $changed_0_ = $changed_0 | ($242 & 255) >>> 4 & 1 & 255;
    var $247 = __ZNK2js5Shape10attributesEv($44);
    var $255 = $247 & 255 & ($changed_0_ ^ -1) | $changed_0_ & (HEAPU8[$desc + 32 | 0] & 255);
    HEAP32[$attrs >> 2] = $255;
    var $256 = __ZNK2js5Shape8isMethodEv($44);
    if ($256) {
      var $setter_0 = 12;
      var $getter_1 = 10;
      var $340 = $255;
      __label__ = 97;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $258 = __ZNK2js5Shape6getterEv($44);
    var $259 = $258;
    var $260 = __ZNK2js5Shape6setterEv($44);
    var $setter_0 = $260;
    var $getter_1 = $259;
    var $340 = $255;
    __label__ = 97;
    break;
   case 81:
    var $263 = __ZNK2js8PropDesc16isDataDescriptorEv($desc);
    if ($263) {
      __label__ = 82;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 82:
    var $266 = HEAPU8[$desc + 33 | 0];
    var $unchanged_0 = ($266 & 32) << 24 >> 24 == 0 ? 4 : 0;
    var $_unchanged_0 = (($266 & 255) >>> 4 & 1 ^ 1) & 255 | $unchanged_0;
    var $unchanged_2 = ($266 & 8) << 24 >> 24 == 0 ? $_unchanged_0 | 2 : $_unchanged_0;
    if (($266 & 4) << 24 >> 24 == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $278 = $desc + 8 | 0;
    var $279$0 = HEAP32[$278 >> 2];
    var $279$1 = HEAP32[$278 + 4 >> 2];
    var $280 = $v | 0;
    HEAP32[$280 >> 2] = $279$0;
    HEAP32[$280 + 4 >> 2] = $279$1;
    __label__ = 84;
    break;
   case 84:
    var $286 = HEAPU8[$desc + 32 | 0] & 255 & ($unchanged_2 ^ -1);
    var $287 = __ZNK2js5Shape10attributesEv($44);
    var $290 = $287 & 255 & $unchanged_2 | $286;
    HEAP32[$attrs >> 2] = $290;
    var $setter_0 = 12;
    var $getter_1 = 10;
    var $340 = $290;
    __label__ = 97;
    break;
   case 85:
    var $292 = HEAP32[$obj2 >> 2];
    var $293 = HEAP32[$id >> 2];
    var $294 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $292, $293, 3, $dummy6, $attrs);
    if (($294 | 0) == 0) {
      var $_0 = 0;
      __label__ = 100;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $298 = HEAPU8[$desc + 33 | 0];
    var $changed7_0 = ($298 & 32) << 24 >> 24 == 0 ? 0 : 4;
    var $changed7_0_ = $changed7_0 | ($298 & 255) >>> 4 & 1 & 255;
    var $304 = ($298 & 1) << 24 >> 24 == 0;
    var $changed7_2 = $304 ? $changed7_0_ : $changed7_0_ | 80;
    var $308 = ($298 & 2) << 24 >> 24 == 0;
    var $changed7_2_ = $308 ? $changed7_2 : $changed7_2 | 96;
    var $312 = $changed7_2_ & (HEAPU8[$desc + 32 | 0] & 255);
    var $313 = __ZNK2js5Shape10attributesEv($44);
    var $317 = $312 | $313 & 255 & ($changed7_2_ ^ -1);
    HEAP32[$attrs >> 2] = $317;
    if ($304) {
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $319 = __ZNK2js8PropDesc6getterEv($desc);
    var $getter_0 = $319;
    __label__ = 92;
    break;
   case 88:
    var $321 = __ZNK2js5Shape8isMethodEv($44);
    if ($321) {
      var $getter_0 = 10;
      __label__ = 92;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $323 = __ZNK2js5Shape16hasDefaultGetterEv($44);
    if ($323) {
      __label__ = 90;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 90:
    var $325 = __ZNK2js5Shape14hasGetterValueEv($44);
    if ($325) {
      __label__ = 91;
      break;
    } else {
      var $getter_0 = 10;
      __label__ = 92;
      break;
    }
   case 91:
    var $327 = __ZNK2js5Shape6getterEv($44);
    var $getter_0 = $327;
    __label__ = 92;
    break;
   case 92:
    var $getter_0;
    if ($308) {
      __label__ = 94;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $331 = __ZNK2js8PropDesc6setterEv($desc);
    var $setter_0 = $331;
    var $getter_1 = $getter_0;
    var $340 = $317;
    __label__ = 97;
    break;
   case 94:
    var $333 = __ZNK2js5Shape16hasDefaultSetterEv($44);
    if ($333) {
      __label__ = 95;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 95:
    var $335 = __ZNK2js5Shape14hasSetterValueEv($44);
    if ($335) {
      __label__ = 96;
      break;
    } else {
      var $setter_0 = 12;
      var $getter_1 = $getter_0;
      var $340 = $317;
      __label__ = 97;
      break;
    }
   case 96:
    var $337 = __ZNK2js5Shape6setterEv($44);
    var $setter_0 = $337;
    var $getter_1 = $getter_0;
    var $340 = $317;
    __label__ = 97;
    break;
   case 97:
    var $340;
    var $getter_1;
    var $setter_0;
    HEAP8[$rval] = 1;
    if ($callDelProperty_0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 98:
    __ZN2JSL14UndefinedValueEv2280($dummy8);
    var $342 = HEAP32[$obj2 >> 2];
    var $343 = $342;
    var $344 = __ZNK8JSObject8getClassEv($343);
    var $347 = HEAP32[$344 + 12 >> 2];
    var $348 = HEAP32[$id >> 2];
    var $349 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $347, $342, $348, $dummy8);
    if ($349) {
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 100;
      break;
    }
   case 99:
    var $351 = HEAP32[$id >> 2];
    var $353 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $351, $v, $getter_1, $setter_0, $340);
    var $_0 = $353;
    __label__ = 100;
    break;
   case 100:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb["X"] = 1;

function __Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi($cx, $obj, $id, $descriptor, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 76;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $descs = __stackBase__ + 4;
    var $rval = __stackBase__ + 72;
    HEAP32[$1 >> 2] = $id;
    var $2 = $cx;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $2);
    var $3 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($3, $cx, $descriptor, 1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $1, $3, 1, $rval);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$bp >> 2] = HEAP8[$rval] & 1 & 255;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($cx, $props, $checkAccessors, $ids, $descs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $props;
    var $3 = $ids;
    var $4 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($1, $2, 8, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = $ids;
    var $7 = __ZNK2js16AutoVectorRooterIiE6lengthEv($6);
    var $8 = $props;
    var $9 = $cx;
    var $10 = $descs;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    var $14 = __ZN2js16AutoVectorRooterIiEixEj($6, $i_0);
    var $15 = HEAP32[$14 >> 2];
    var $16 = __ZN2js23AutoPropDescArrayRooter6appendEv($10);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($8, $9, $15, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($16, $cx, $v, $checkAccessors);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PopulateObjectP9JSContextP8JSObjectS2_($cx, $newborn, $props) {
  var $1 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $newborn, $props);
  return $1 & 1;
}

function __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $obj, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    var $descs = __stackBase__ + 60;
    var $dummy = __stackBase__ + 128;
    var $1 = $ids;
    var $2 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($1, $2);
    var $3 = $descs;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($3, $2);
    var $4 = __ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE($cx, $props, 1, $ids, $descs);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $ids;
    var $7 = __ZNK2js16AutoVectorRooterIiE6lengthEv($6);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = __ZN2js16AutoVectorRooterIiEixEj($6, $i_0);
    var $12 = __ZN2js23AutoPropDescArrayRooterixEj($3, $i_0);
    var $13 = __ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb($cx, $obj, $11, $12, 1, $dummy);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($3);
    __ZN2js12AutoIdVectorD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16sizeOfSlotsArrayEPFjPvE($this, $usf) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject13hasSlotsArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 32 >> 2];
    var $7 = FUNCTION_TABLE[$usf]($6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject8numSlotsEv($1);
    var $_0 = $10 << 3;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE($this, $cx, $it) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $attrs = __stackBase__ + 60;
    var $1 = $cx;
    var $2 = $this;
    var $3 = $props;
    __ZN2js12AutoIdVectorC1EP9JSContext($3, $1);
    var $4 = __ZNK8JSObject12isExtensibleEv($2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($2, $1, $3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = $this;
    var $10 = $props;
    var $11 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($8, $9, 24, $10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $13 = $props;
    var $14 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $15 = ($it | 0) == 1;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 6:
    var $19 = __ZN2js16AutoVectorRooterIiEixEj($13, $i_0);
    var $20 = HEAPU32[$19 >> 2];
    var $21 = __ZN8JSObject13getAttributesEP9JSContextiPj($2, $1, $20, $attrs);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = HEAPU32[$attrs >> 2];
    if ($15) {
      __label__ = 8;
      break;
    } else {
      var $_pre = $24;
      __label__ = 9;
      break;
    }
   case 8:
    if (($24 & 48 | 0) == 0) {
      var $new_attrs_0 = 6;
      var $29 = $24;
      __label__ = 10;
      break;
    } else {
      var $_pre = $24;
      __label__ = 9;
      break;
    }
   case 9:
    var $_pre;
    var $new_attrs_0 = 4;
    var $29 = $_pre;
    __label__ = 10;
    break;
   case 10:
    var $29;
    var $new_attrs_0;
    var $30 = $29 | $new_attrs_0;
    if (($30 | 0) == ($29 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$attrs >> 2] = $30;
    var $33 = __ZN8JSObject13setAttributesEP9JSContextiPj($2, $1, $20, $attrs);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 13:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($3);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb($this, $cx, $it, $resultp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    var $attrs = __stackBase__ + 60;
    var $1 = $this;
    var $2 = __ZNK8JSObject12isExtensibleEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$resultp] = 0;
    var $_1 = 1;
    __label__ = 14;
    break;
   case 3:
    var $5 = $props;
    var $6 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($5, $6);
    var $7 = $cx;
    var $8 = $this;
    var $9 = $props;
    var $10 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($7, $8, 24, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $12 = $props;
    var $13 = __ZNK2js16AutoVectorRooterIiE6lengthEv($12);
    var $14 = ($it | 0) == 1;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $18 = __ZN2js16AutoVectorRooterIiEixEj($12, $i_0);
    var $19 = HEAP32[$18 >> 2];
    var $20 = __ZN8JSObject13getAttributesEP9JSContextiPj($1, $6, $19, $attrs);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$attrs >> 2];
    if (($23 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($23 & 50 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP8[$resultp] = 0;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 12:
    HEAP8[$resultp] = 1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($5);
    var $_1 = $_0;
    __label__ = 14;
    break;
   case 14:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ida = __stackBase__;
    var $chars = __stackBase__ + 4;
    var $vsharp = __stackBase__ + 8;
    var $obj2 = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $gsop = __stackBase__ + 20;
    var $localroot = __stackBase__ + 32;
    var $tvr = __stackBase__ + 64;
    var $1 = __stackBase__ + 80;
    var $2 = __stackBase__ + 88;
    var $3 = __stackBase__ + 96;
    if (__stackBase__ + 28 >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($9);
    var $_1 = 0;
    __label__ = 91;
    break;
   case 3:
    __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515($localroot);
    var $11 = $localroot | 0;
    var $12 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $12, 4, $11);
    var $15 = (HEAP32[$cx + 136 >> 2] | 0) == 0;
    var $16 = $15 & 1;
    var $17 = $vp + 8 | 0;
    var $18 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($12, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = $18;
    var $22 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $21, $ida, $chars);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAPU32[$chars >> 2];
    if ((HEAP32[$ida >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = __Z9js_strlenPKt($27);
    var $nchars_9 = $29;
    var $330 = $27;
    __label__ = 86;
    break;
   case 7:
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $33 = $15 ? 10 : 6;
    var $34 = __ZN9JSContext7malloc_Ej($12, $33);
    var $35 = $34;
    HEAP32[$chars >> 2] = $35;
    if (($34 | 0) == 0) {
      var $ok_2 = 1;
      var $nchars_8 = 0;
      __label__ = 81;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($15) {
      __label__ = 10;
      break;
    } else {
      var $nchars_0 = 0;
      var $outermost_0 = $16;
      var $57 = $35;
      __label__ = 15;
      break;
    }
   case 10:
    HEAP16[$35 >> 1] = 40;
    var $nchars_0 = 1;
    var $outermost_0 = $16;
    var $57 = HEAP32[$chars >> 2];
    __label__ = 15;
    break;
   case 11:
    var $40 = $22 + 12 | 0;
    var $44 = HEAP32[$40 >> 2] | 1;
    HEAP32[$40 >> 2] = $44;
    var $45 = HEAP32[$chars >> 2];
    var $46 = __Z9js_strlenPKt($45);
    var $47 = $45;
    var $49 = ($46 << 1) + 6 | 0;
    var $50 = __ZN9JSContext8realloc_EPvj($12, $47, $49);
    var $51 = $50;
    HEAP32[$chars >> 2] = $51;
    if (($50 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js10Foreground5free_EPv($47);
    var $ok_2 = 1;
    var $nchars_8 = $46;
    __label__ = 81;
    break;
   case 13:
    if ($15) {
      __label__ = 14;
      break;
    } else {
      var $nchars_0 = $46;
      var $outermost_0 = $16;
      var $57 = $51;
      __label__ = 15;
      break;
    }
   case 14:
    var $nchars_0 = $46;
    var $outermost_0 = 0;
    var $57 = $51;
    __label__ = 15;
    break;
   case 15:
    var $57;
    var $outermost_0;
    var $nchars_0;
    HEAP16[$57 + ($nchars_0 << 1) >> 1] = 123;
    var $60 = $localroot + 16 | 0;
    var $63 = HEAP32[HEAP32[$ida >> 2] >> 2];
    var $64 = $obj2;
    var $65 = $prop;
    var $66 = $cx;
    var $68 = ($outermost_0 | 0) != 0 ? 3 : 2;
    var $69 = $3 | 0;
    var $70 = $cx + 52 | 0;
    var $71 = $2 | 0;
    var $72 = $60 | 0;
    var $73 = $gsop | 0;
    var $ok_0 = 1;
    var $nchars_1 = $nchars_0 + 1 | 0;
    var $i_0 = 0;
    var $comma_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $comma_0;
    var $i_0;
    var $nchars_1;
    var $ok_0;
    if (($i_0 | 0) < ($63 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 17:
    var $79 = HEAPU32[HEAP32[$ida >> 2] + 4 + ($i_0 << 2) >> 2];
    var $80 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($18, $12, $79, $64, $65);
    if (($80 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2jsL9IdToValueEi2416($1, $79);
    var $83 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($66, $1);
    if (($83 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $86 = __ZN8JSString12ensureLinearEP9JSContext($83, $12);
    if (($86 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $89 = $86 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $89);
    var $90 = HEAP32[$prop >> 2];
    if (($90 | 0) == 0) {
      var $ok_1 = $80;
      var $valcnt_2 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $94 = HEAP32[$obj2 >> 2];
    var $95 = __ZNK8JSObject8isNativeEv($94);
    if ($95) {
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 22:
    var $97 = $90;
    var $98 = $90;
    var $99 = __ZNK2js5Shape10attributesEv($98);
    var $100 = $99 & 255;
    if (($100 & 16 | 0) == 0) {
      var $doGet_0 = 1;
      var $valcnt_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZNK2js5Shape11getterValueEv($2, $97);
    var $104$0 = HEAP32[$71 >> 2];
    var $104$1 = HEAP32[$71 + 4 >> 2];
    HEAP32[$72 >> 2] = $104$0;
    HEAP32[$72 + 4 >> 2] = $104$1;
    var $108 = HEAP32[HEAP32[$70 >> 2] + 210220 >> 2] | 0;
    HEAP32[$73 >> 2] = $108;
    var $doGet_0 = 0;
    var $valcnt_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $valcnt_0;
    var $doGet_0;
    if (($100 & 32 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_sum78 = $valcnt_0 | 2;
    __ZNK2js5Shape11setterValueEv($3, $97);
    var $112$0 = HEAP32[$69 >> 2];
    var $112$1 = HEAP32[$69 + 4 >> 2];
    var $113 = $localroot + ($_sum78 << 3) | 0;
    HEAP32[$113 >> 2] = $112$0;
    HEAP32[$113 + 4 >> 2] = $112$1;
    var $117 = HEAP32[HEAP32[$70 >> 2] + 210296 >> 2] | 0;
    HEAP32[$gsop + ($valcnt_0 << 2) >> 2] = $117;
    var $ok_1 = $80;
    var $valcnt_2 = $valcnt_0 + 1 | 0;
    __label__ = 28;
    break;
   case 26:
    if ($doGet_0 << 24 >> 24 == 0) {
      var $ok_1 = $80;
      var $valcnt_2 = $valcnt_0;
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    HEAP32[$73 >> 2] = 0;
    var $122 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($18, $12, $79, $60);
    if (($122 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      var $ok_1 = $122;
      var $valcnt_2 = 1;
      __label__ = 28;
      break;
    }
   case 28:
    var $valcnt_2;
    var $ok_1;
    var $125 = __ZL12JSID_IS_ATOMi2511($79);
    if (($125 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $128 = __Z15js_IsIdentifierP14JSLinearString($86);
    if (($128 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $idstr_0 = $86;
      __label__ = 35;
      break;
    }
   case 30:
    var $131 = _JSID_IS_INT2487($79);
    if (($131 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $134 = _JSID_TO_INT2488($79);
    if (($134 | 0) < 0) {
      __label__ = 32;
      break;
    } else {
      var $idstr_0 = $86;
      __label__ = 35;
      break;
    }
   case 32:
    var $137 = _js_QuoteString($12, $89, 39);
    if (($137 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $140 = __ZN8JSString12ensureLinearEP9JSContext($137, $12);
    if (($140 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $143 = $140 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $143);
    var $idstr_0 = $140;
    __label__ = 35;
    break;
   case 35:
    var $idstr_0;
    var $145 = $idstr_0 | 0;
    var $146 = __ZNK8JSString6lengthEv($145);
    var $147 = __ZN8JSString8getCharsEP9JSContext($145, $12);
    if (($147 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_1;
      __label__ = 81;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $149 = $146 + 1 | 0;
    var $150 = $147;
    var $151 = $146 << 1;
    var $j_0 = 0;
    var $nchars_2 = $nchars_1;
    var $comma_1 = $comma_0;
    __label__ = 37;
    break;
   case 37:
    var $comma_1;
    var $nchars_2;
    var $j_0;
    if (($j_0 | 0) < ($valcnt_2 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 38:
    var $155 = $gsop + ($j_0 << 2) | 0;
    var $156 = HEAPU32[$155 >> 2];
    var $157 = ($156 | 0) == 0;
    var $_pre3 = $localroot + ($j_0 + 2 << 3) | 0;
    if ($157) {
      var $_pre_phi = $_pre3;
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $159 = __ZNK2JS5Value11isUndefinedEv($_pre3);
    if ($159) {
      var $nchars_6 = $nchars_2;
      var $comma_2 = $comma_1;
      __label__ = 76;
      break;
    } else {
      var $_pre_phi = $_pre3;
      __label__ = 40;
      break;
    }
   case 40:
    var $_pre_phi;
    var $160 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($66, $_pre_phi);
    if (($160 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $163 = $localroot + ($j_0 << 3) | 0;
    __ZN2JS5Value9setStringEP8JSString($163, $160);
    var $164 = __ZN8JSString8getCharsEP9JSContext($160, $12);
    if (($164 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $167 = __ZNK8JSString6lengthEv($160);
    HEAP32[$vsharp >> 2] = 0;
    if ($157) {
      __label__ = 43;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 43:
    var $169 = __ZNK2JS5Value8isObjectEv($_pre_phi);
    if ($169) {
      __label__ = 44;
      break;
    } else {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $156;
      __label__ = 57;
      break;
    }
   case 44:
    if (HEAP16[$164 >> 1] << 16 >> 16 == 35) {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $156;
      __label__ = 57;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $174 = __ZNK2JS5Value8toObjectEv($_pre_phi);
    var $175 = $174;
    var $176 = __Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt($cx, $175, 0, $vsharp);
    if (($176 | 0) == 0) {
      var $ok_2 = 0;
      var $nchars_8 = $nchars_2;
      __label__ = 81;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $179 = $176 + 12 | 0;
    var $181 = HEAP32[$179 >> 2];
    var $184 = HEAPU32[$vsharp >> 2];
    if (($181 & 1 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $186 = __Z9js_strlenPKt($184);
    var $vchars_5 = $184;
    var $vlength_1 = $186;
    var $vsharplength_112 = 0;
    var $218 = $184;
    var $217 = $156;
    __label__ = 57;
    break;
   case 48:
    if (($184 | 0) == 0) {
      var $vsharplength_0 = 0;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $190 = __Z9js_strlenPKt($184);
    var $192 = $181 | 1;
    HEAP32[$179 >> 2] = $192;
    var $vsharplength_0 = $190;
    __label__ = 50;
    break;
   case 50:
    var $vsharplength_0;
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, 0);
    var $vchars_5 = $164;
    var $vlength_1 = $167;
    var $vsharplength_112 = $vsharplength_0;
    var $218 = $184;
    var $217 = $156;
    __label__ = 57;
    break;
   case 51:
    var $194 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($_pre_phi);
    if ($194) {
      __label__ = 52;
      break;
    } else {
      var $vchars_5 = $164;
      var $vlength_1 = $167;
      var $vsharplength_112 = 0;
      var $218 = 0;
      var $217 = $156;
      __label__ = 57;
      break;
    }
   case 52:
    var $196 = $164 + ($167 << 1) | 0;
    var $198 = HEAP16[$164 >> 1] << 16 >> 16 == 40;
    var $vchars_1 = $198 ? $164 + 2 | 0 : $164;
    var $parenChomp_0 = $198 & 1;
    if (($vchars_1 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $202 = __Z15js_strchr_limitPKttS0_($vchars_1, 32, $196);
    if (($202 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $205 = __Z15js_strchr_limitPKttS0_($202, 40, $196);
    if (($205 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $vchars_4 = HEAP16[$205 >> 1] << 16 >> 16 == 32 ? $205 + 2 | 0 : $205;
    var $vchars_5 = $vchars_4;
    var $vlength_1 = ($196 - $vchars_4 >> 1) - $parenChomp_0 | 0;
    var $vsharplength_112 = 0;
    var $218 = 0;
    var $217 = $156;
    __label__ = 57;
    break;
   case 56:
    HEAP32[$155 >> 2] = 0;
    var $vchars_5 = $164;
    var $vlength_1 = $167;
    var $vsharplength_112 = 0;
    var $218 = 0;
    var $217 = 0;
    __label__ = 57;
    break;
   case 57:
    var $217;
    var $218;
    var $vsharplength_112;
    var $vlength_1;
    var $vchars_5;
    var $219 = ($comma_1 | 0) != 0;
    if ($219) {
      __label__ = 58;
      break;
    } else {
      var $curlen_0 = $nchars_2;
      __label__ = 59;
      break;
    }
   case 58:
    if ($nchars_2 >>> 0 > 4294967293) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      var $curlen_0 = $nchars_2 + 2 | 0;
      __label__ = 59;
      break;
    }
   case 59:
    var $curlen_0;
    var $uadd = _llvm_uadd_with_overflow_i32($curlen_0, $149);
    var $224 = $uadd.f0;
    var $225 = $uadd.f1;
    if ($225) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $227 = ($217 | 0) == 0;
    if ($227) {
      var $curlen_1 = $224;
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $229 = __ZNK8JSString6lengthEv($217);
    var $230 = $229 + 1 | 0;
    var $uadd5 = _llvm_uadd_with_overflow_i32($224, $230);
    var $231 = $uadd5.f0;
    var $232 = $uadd5.f1;
    if ($232) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      var $curlen_1 = $231;
      __label__ = 62;
      break;
    }
   case 62:
    var $curlen_1;
    var $uadd2 = _llvm_uadd_with_overflow_i32($curlen_1, $vsharplength_112);
    var $234 = $uadd2.f1;
    if ($234) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $236 = $uadd2.f0;
    var $uadd3 = _llvm_uadd_with_overflow_i32($236, $vlength_1);
    var $237 = $uadd3.f1;
    if ($237) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $239 = $uadd3.f0;
    var $uadd4 = _llvm_uadd_with_overflow_i32($239, $68);
    var $240 = $uadd4.f0;
    var $241 = $uadd4.f1;
    if ($241 | ($240 | 0) < 0) {
      var $nchars_10 = $nchars_2;
      __label__ = 89;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $244 = HEAP32[$chars >> 2];
    var $245 = $244;
    var $246 = $240 << 1;
    var $247 = __ZN9JSContext8realloc_EPvj($12, $245, $246);
    var $248 = $247;
    HEAP32[$chars >> 2] = $248;
    if (($247 | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    HEAP32[$chars >> 2] = $244;
    var $nchars_10 = $nchars_2;
    __label__ = 89;
    break;
   case 67:
    if ($219) {
      __label__ = 68;
      break;
    } else {
      var $nchars_3 = $nchars_2;
      __label__ = 69;
      break;
    }
   case 68:
    HEAP16[$248 + ($nchars_2 << 1) >> 1] = HEAP8[$comma_1] << 24 >> 24;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_2 + 1 << 1) >> 1] = HEAP8[$comma_1 + 1 | 0] << 24 >> 24;
    var $nchars_3 = $nchars_2 + 2 | 0;
    __label__ = 69;
    break;
   case 69:
    var $nchars_3;
    if ($227) {
      var $nchars_4 = $nchars_3;
      __label__ = 72;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $265 = __ZNK8JSString6lengthEv($217);
    var $266 = __ZN8JSString8getCharsEP9JSContext($217, $12);
    if (($266 | 0) == 0) {
      var $nchars_10 = $nchars_3;
      __label__ = 89;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $271 = HEAP32[$chars >> 2] + ($nchars_3 << 1) | 0;
    var $272 = $266;
    var $273 = $265 << 1;
    _memcpy($271, $272, $273, 1);
    var $274 = $265 + $nchars_3 | 0;
    var $275 = $274 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($274 << 1) >> 1] = 32;
    var $nchars_4 = $275;
    __label__ = 72;
    break;
   case 72:
    var $nchars_4;
    var $280 = HEAP32[$chars >> 2] + ($nchars_4 << 1) | 0;
    _memcpy($280, $150, $151, 1);
    var $281 = $nchars_4 + $146 | 0;
    var $283 = ($217 | 0) != 0 ? 32 : 58;
    var $284 = $281 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($281 << 1) >> 1] = $283;
    if (($vsharplength_112 | 0) == 0) {
      var $nchars_5 = $284;
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $291 = HEAP32[$chars >> 2] + ($284 << 1) | 0;
    _memcpy($291, $218, $vsharplength_112 << 1, 1);
    var $nchars_5 = $284 + $vsharplength_112 | 0;
    __label__ = 74;
    break;
   case 74:
    var $nchars_5;
    var $298 = HEAP32[$chars >> 2] + ($nchars_5 << 1) | 0;
    _memcpy($298, $vchars_5, $vlength_1 << 1, 1);
    var $301 = $nchars_5 + $vlength_1 | 0;
    if (($218 | 0) == 0) {
      var $nchars_6 = $301;
      var $comma_2 = STRING_TABLE.__str332706 | 0;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    __ZN9JSContext5free_EPv(undef, $218);
    var $nchars_6 = $301;
    var $comma_2 = STRING_TABLE.__str332706 | 0;
    __label__ = 76;
    break;
   case 76:
    var $comma_2;
    var $nchars_6;
    var $j_0 = $j_0 + 1 | 0;
    var $nchars_2 = $nchars_6;
    var $comma_1 = $comma_2;
    __label__ = 37;
    break;
   case 77:
    var $ok_0 = $ok_1;
    var $nchars_1 = $nchars_2;
    var $i_0 = $i_0 + 1 | 0;
    var $comma_0 = $comma_1;
    __label__ = 16;
    break;
   case 78:
    var $310 = $nchars_1 + 1 | 0;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_1 << 1) >> 1] = 125;
    if (($outermost_0 | 0) == 0) {
      var $nchars_7 = $310;
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    HEAP16[HEAP32[$chars >> 2] + ($310 << 1) >> 1] = 41;
    var $nchars_7 = $nchars_1 + 2 | 0;
    __label__ = 80;
    break;
   case 80:
    var $nchars_7;
    HEAP16[HEAP32[$chars >> 2] + ($nchars_7 << 1) >> 1] = 0;
    var $ok_2 = $ok_0;
    var $nchars_8 = $nchars_7;
    __label__ = 81;
    break;
   case 81:
    var $nchars_8;
    var $ok_2;
    __Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray($cx, $ida);
    var $322 = HEAP32[$chars >> 2];
    var $323 = ($322 | 0) != 0;
    if (($ok_2 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 82:
    if ($323) {
      __label__ = 83;
      break;
    } else {
      var $_0 = 0;
      __label__ = 90;
      break;
    }
   case 83:
    var $326 = $322;
    __ZN2js10Foreground5free_EPv($326);
    var $_0 = $ok_2;
    __label__ = 90;
    break;
   case 84:
    if ($323) {
      var $nchars_9 = $nchars_8;
      var $330 = $322;
      __label__ = 86;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    _JS_ReportOutOfMemory($12);
    var $_0 = 0;
    __label__ = 90;
    break;
   case 86:
    var $330;
    var $nchars_9;
    var $331 = $cx;
    var $332 = __Z12js_NewStringP9JSContextPtj($331, $330, $nchars_9);
    if (($332 | 0) == 0) {
      __label__ = 87;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 87:
    var $336 = HEAP32[$chars >> 2];
    __ZN9JSContext5free_EPv(undef, $336);
    var $_0 = 0;
    __label__ = 90;
    break;
   case 88:
    var $338 = $332 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $338);
    var $_0 = 1;
    __label__ = 90;
    break;
   case 89:
    var $nchars_10;
    __ZN9JSContext5free_EPv(undef, $218);
    var $341 = HEAP32[$chars >> 2];
    __ZN9JSContext5free_EPv(undef, $341);
    HEAP32[$chars >> 2] = 0;
    var $ok_2 = $ok_1;
    var $nchars_8 = $nchars_10;
    __label__ = 81;
    break;
   case 90:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 91;
    break;
   case 91:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12obj_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12obj_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210288 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $8);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $10 = __ZNK2JS5Value6isNullEv($1);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 210284 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $16);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $18 = $cx;
    var $19 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($18, $1);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $19;
    var $23 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($cx, $22);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $23);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $9 = $cx;
    var $10 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $8);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210324 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom2291($18);
    var $20 = __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($13, $cx, $19, 0, 0, $vp);
    var $_0 = $20 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11obj_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9obj_watchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $propid = __stackBase__;
    var $tmp = __stackBase__ + 4;
    var $attrs = __stackBase__ + 12;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($3, $vp, 1);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $5 = $vp + 24 | 0;
    var $6 = $cx;
    var $7 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($6, $5, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $vp + 16 | 0;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($6, $10, $propid);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($6, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $14;
    var $18 = HEAP32[$propid >> 2];
    var $19 = __ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj($cx, $17, $18, 3, $tmp, $attrs);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    if ((HEAP32[$attrs >> 2] & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 8:
    var $26 = __ZNK8JSObject12isDenseArrayEv($14);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($14, $6);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = $cx;
    var $32 = $14;
    var $33 = $7;
    var $34 = _JS_SetWatchPoint($31, $32, $18, 180, $33);
    var $_0 = $34;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11obj_unwatchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $vp + 16 | 0;
    var $9 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($2, $8, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = HEAP32[$id >> 2];
    __label__ = 6;
    break;
   case 5:
    HEAP32[$id >> 2] = 2;
    var $12 = 2;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = $cx;
    var $14 = $3;
    var $15 = _JS_ClearWatchPoint($13, $14, $12, 0, 0);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject6getOpsEv($3);
    var $9 = HEAP32[$6 + 4 >> 2];
    var $10 = __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($cx, $9, $argc, $vp);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZNK2JS5Value8isObjectEv($3);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 4:
    var $7 = $vp + 8 | 0;
    var $8 = $cx;
    var $9 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($8, $7);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE(undef, $12, $3);
    __ZN2JS5Value10setBooleanEb($vp, $13);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $cx;
    var $10 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($9, $1, $id);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($9, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13;
    var $17 = HEAP32[$id >> 2];
    var $18 = __Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE($cx, $16, $17, $vp);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $pobj = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $10 = $cx;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($10, $1, $id);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$id >> 2];
    var $18 = $pobj;
    var $19 = $prop;
    var $20 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($14, $10, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $23 = HEAP32[$prop >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAP32[$pobj >> 2];
    var $28 = __ZNK8JSObject8isNativeEv($27);
    if ($28) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $30 = $23;
    var $31 = __ZNK2js5Shape14hasGetterValueEv($30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = $23;
    __ZNK2js5Shape11getterValueEv($2, $33);
    var $34 = $2 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $vp | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE($clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js10ArrayClassE | 0) | ($clasp | 0) == (__ZN2js14SlowArrayClassE | 0)) {
      var $_0 = 6;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_ = ($clasp | 0) == (__ZN2js13FunctionClassE | 0) ? 2 : 4;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_EMPTY2321($iden) {
  return ($iden | 0) == 4 & 1;
}

function __ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $pobj = __stackBase__ + 12;
    var $prop = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 4;
    break;
   case 4:
    var $10 = $cx;
    var $11 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($10, $1, $id);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $13 = $vp + 8 | 0;
    var $14 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$id >> 2];
    var $18 = $pobj;
    var $19 = $prop;
    var $20 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($14, $10, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $23 = HEAP32[$prop >> 2];
    if (($23 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAP32[$pobj >> 2];
    var $28 = __ZNK8JSObject8isNativeEv($27);
    if ($28) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $30 = $23;
    var $31 = __ZNK2js5Shape14hasSetterValueEv($30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = $23;
    __ZNK2js5Shape11setterValueEv($2, $33);
    var $34 = $2 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $vp | 0;
    HEAP32[$36 >> 2] = $35$0;
    HEAP32[$36 + 4 >> 2] = $35$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $nameidr = __stackBase__ + 4;
    var $1 = __stackBase__ + 20;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str452248 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = _INT_TO_JSID2431(0);
    var $5 = $cx;
    __ZN2js12AutoIdRooterC1EP9JSContexti($nameidr, $5, $4);
    if ($argc >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $vp + 24 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $1 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 5;
    break;
   case 5:
    var $13 = __ZN2js12AutoIdRooter4addrEv($nameidr);
    var $14 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($5, $1, $13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = HEAP32[$obj >> 2];
    var $17 = __ZN2js12AutoIdRooter2idEv($nameidr);
    var $18 = __ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $16, $17, $vp);
    var $_0 = $18 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($nameidr);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8obj_keysP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 172;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $props = __stackBase__ + 4;
    var $vals = __stackBase__ + 64;
    var $1 = __stackBase__ + 156;
    var $2 = __stackBase__ + 164;
    var $3 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str442247 | 0, $obj);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    var $5 = $props;
    var $6 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($5, $6);
    var $8 = $cx;
    var $9 = HEAP32[$obj >> 2];
    var $10 = $props;
    var $11 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($8, $9, 8, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    var $13 = $vals;
    __ZN2js15AutoValueVectorC1EP9JSContext($13, $6);
    var $14 = $props;
    var $15 = __ZNK2js16AutoVectorRooterIiE6lengthEv($14);
    var $16 = $vals;
    var $17 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($16, $15);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $19 = __ZNK2js16AutoVectorRooterIiE6lengthEv($14);
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $19 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 6:
    var $23 = __ZN2js16AutoVectorRooterIiEixEj($14, $i_0);
    var $24 = HEAPU32[$23 >> 2];
    var $25 = _JSID_IS_STRING2486($24);
    if (($25 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = _JSID_TO_STRING2421($24);
    __ZN2JSL11StringValueEP8JSString2480($1, $28);
    var $29 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($16, $1);
    __label__ = 11;
    break;
   case 8:
    var $31 = _JSID_IS_INT2487($24);
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = _JSID_TO_INT2488($24);
    var $35 = __Z14js_IntToStringP9JSContexti($6, $34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2JSL11StringValueEP8JSString2480($2, $35);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($16, $2);
    __label__ = 11;
    break;
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 12:
    var $41 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($16);
    var $42 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($16);
    var $43 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($6, $41, $42, 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN2JS5Value9setObjectER8JSObject($vp, $43);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($13);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    __ZN2js12AutoIdVectorD1Ev($5);
    var $_2 = $_1;
    __label__ = 16;
    break;
   case 16:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8obj_keysP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18obj_definePropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $id = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $descval = __stackBase__ + 16;
    var $junk = __stackBase__ + 24;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str432246 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    if ($argc >>> 0 > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $vp + 24 | 0;
    var $st$1$0 = $6 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $6 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $1 | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($1);
    __label__ = 5;
    break;
   case 5:
    var $11 = $cx;
    var $12 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($11, $1, $id);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = $vp + 32 | 0;
    var $st$1$0 = $16 | 0;
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $18 = $descval | 0;
    var $st$6$0 = $18 | 0;
    HEAP32[$st$6$0 >> 2] = $17$0;
    var $st$6$1 = $18 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $17$1;
    __label__ = 9;
    break;
   case 8:
    __ZN2JSL14UndefinedValueEv2280($descval);
    __label__ = 9;
    break;
   case 9:
    var $21 = HEAP32[$obj >> 2];
    var $22 = HEAP32[$id >> 2];
    var $23 = __Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi($cx, $21, $22, $descval, $junk);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = $21;
    __ZN2JS5Value9setObjectER8JSObject($vp, $26);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18obj_definePropertyP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str422245 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = HEAPU32[$obj >> 2];
    var $4 = $3;
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    if ($argc >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    _JS_ReportErrorNumber($7, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str422245 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $9 = $vp + 24 | 0;
    var $10 = $cx;
    var $11 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $9);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11;
    var $15 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $3, $14);
    var $_0 = $15 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10obj_createP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str402243 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value14isObjectOrNullEv($5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx_val$0, $_idx_val$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cx;
    _JS_ReportErrorNumber($11, 2, 0, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str412244 | 0, tempInt));
    _JS_free(undef, $8);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 6:
    var $13 = __ZNK2JS5Value14toObjectOrNullEv($5);
    var $14 = $13;
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZNK8JSObject5isXMLEv($13);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $19 = $cx;
    _JS_ReportErrorNumber($19, 2, 0, 272, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 9:
    var $21 = __ZNK2JS5Value8toObjectEv($vp);
    var $22 = $21;
    var $23 = __ZNK8JSObject9getGlobalEv($22);
    var $24 = $23 | 0;
    var $25 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514($cx, $14, $24);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = $25;
    __ZN2JS5Value9setObjectER8JSObject($vp, $28);
    var $29 = __ZNK8JSObject4typeEv($28);
    var $30 = $cx;
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($30, $29, 0);
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $33 = $vp + 24 | 0;
    var $34 = __ZNK2JS5Value11isUndefinedEv($33);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = __ZNK2JS5Value11isPrimitiveEv($33);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    _JS_ReportErrorNumber($30, 2, 0, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 14:
    var $39 = __ZNK2JS5Value8toObjectEv($33);
    var $40 = $39;
    var $41 = __ZL16DefinePropertiesP9JSContextP8JSObjectS2_($cx, $25, $40);
    if ($41) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10obj_createP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 164;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $keys = __stackBase__ + 4;
    var $vals = __stackBase__ + 64;
    var $1 = __stackBase__ + 156;
    var $2 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str392242 | 0, $obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 17;
      break;
    }
   case 2:
    var $4 = $keys;
    var $5 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($4, $5);
    var $7 = $cx;
    var $8 = HEAP32[$obj >> 2];
    var $9 = $keys;
    var $10 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($7, $8, 24, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $12 = $vals;
    __ZN2js15AutoValueVectorC1EP9JSContext($12, $5);
    var $13 = $keys;
    var $14 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $15 = $vals;
    var $16 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj($15, $14);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 4:
    var $18 = __ZNK2js16AutoVectorRooterIiE6lengthEv($13);
    var $19 = $cx;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $18 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $23 = __ZN2js16AutoVectorRooterIiEixEj($13, $i_0);
    var $24 = HEAPU32[$23 >> 2];
    var $25 = _JSID_IS_INT2487($24);
    if (($25 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = _JSID_TO_INT2488($24);
    __ZN2JSL10Int32ValueEi2332($1, $28);
    var $29 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($19, $1);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($15, $i_0);
    __ZN2JS5Value9setStringEP8JSString($32, $29);
    __label__ = 12;
    break;
   case 9:
    var $34 = __ZL12JSID_IS_ATOMi2511($24);
    var $35 = ($34 | 0) == 0;
    var $36 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($15, $i_0);
    if ($35) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = _JSID_TO_STRING2421($24);
    __ZN2JS5Value9setStringEP8JSString($36, $38);
    __label__ = 12;
    break;
   case 11:
    var $40 = _JSID_TO_OBJECT2490($24);
    var $41 = $40;
    __ZN2JS5Value9setObjectER8JSObject($36, $41);
    __label__ = 12;
    break;
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 13:
    var $45 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($15);
    var $46 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($15);
    var $47 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($5, $45, $46, 0);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2JS5Value9setObjectER8JSObject($vp, $47);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($12);
    var $_1 = $_0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    __ZN2js12AutoIdVectorD1Ev($4);
    var $_2 = $_1;
    __label__ = 17;
    break;
   case 17:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str382241 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    var $5 = __ZNK8JSObject12isExtensibleEv($4);
    __ZN2JS5Value10setBooleanEb($vp, $5);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $props = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str362239 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $5 = __ZNK8JSObject12isExtensibleEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $7);
    var $8 = __ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE($4, $7, $props);
    var $9 = $8 & 1;
    __ZN2js12AutoIdVectorD1Ev($props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10obj_freezeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str372240 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $5 = $cx;
    var $6 = __ZN8JSObject6freezeEP9JSContext($4, $5);
    var $_0 = $6 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_isFrozenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $frozen = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str362239 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    var $5 = $cx;
    var $6 = __ZN8JSObject8isFrozenEP9JSContextPb($4, $5, $frozen);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$frozen] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8obj_sealP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str352238 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $5 = $cx;
    var $6 = __ZN8JSObject4sealEP9JSContext($4, $5);
    var $_0 = $6 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12obj_isSealedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $sealed = __stackBase__ + 4;
    var $1 = __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, STRING_TABLE.__str322235 | 0, $obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    var $5 = $cx;
    var $6 = __ZN8JSObject8isSealedEP9JSContextPb($4, $5, $sealed);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$sealed] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($vp, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_ObjectP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$obj >> 2] = 0;
    __label__ = 5;
    break;
   case 3:
    var $3 = $vp + 16 | 0;
    var $4 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $3, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_pr = HEAP32[$obj >> 2];
    if (($_pr | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $19 = $_pr;
      __label__ = 8;
      break;
    }
   case 5:
    var $9 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $10 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, __ZN2js11ObjectClassE, $9);
    HEAP32[$obj >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = $cx;
    var $14 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($13, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = $10;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($17, $14);
    var $19 = $10;
    __label__ = 8;
    break;
   case 8:
    var $19;
    __ZN2JS5Value9setObjectER8JSObject($vp, $19);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $v, $objp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value14isObjectOrNullEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value14toObjectOrNullEv($v);
    var $obj_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $6 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($6) {
      var $obj_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $v);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $obj_0 = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $obj_0;
    HEAP32[$objp >> 2] = $obj_0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext5hasfpEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $9;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($cx, $global);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($5);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15 | 0;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $21 = __ZNK2JS5Value8isObjectEv($1);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = __ZNK2JS5Value8toObjectEv($1);
    var $24 = $23;
    HEAP32[$proto >> 2] = $24;
    var $28 = $24;
    __label__ = 9;
    break;
   case 7:
    var $26 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $18, $4, $proto, $clasp);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $28 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $28;
    var $29 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510($cx, $clasp, $28, $18, $kind);
    var $_0 = $29;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($cx, $type, $parent, $kind, $shape) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ids = __stackBase__;
    var $1 = __stackBase__ + 60;
    var $2 = __stackBase__ + 64;
    var $3 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $kind);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $shape + 12 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = _JSID_IS_EMPTY2321($7);
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $3;
      __label__ = 15;
      break;
    }
   case 3:
    var $11 = $ids;
    var $12 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($11, $12);
    var $13 = $shape + 24 | 0;
    var $14 = $ids;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    var $16 = HEAPU32[$13 >> 2];
    if ($i_0 >>> 0 > $16 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAPU32[$6 >> 2];
    var $19 = _JSID_IS_EMPTY2321($18);
    var $21 = $ids;
    if (($19 | 0) == 0) {
      var $nshape_02 = $shape;
      var $27 = $18;
      var $26 = $16;
      __label__ = 9;
      break;
    } else {
      var $_pre_phi = $21;
      __label__ = 8;
      break;
    }
   case 6:
    HEAP32[$1 >> 2] = 2;
    var $23 = __ZN2js16AutoVectorRooterIiE6appendERKi($14, $1);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $_pre_phi;
    var $i1_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $26;
    var $27;
    var $nshape_02;
    var $28 = __ZN2js16AutoVectorRooterIiEixEj($21, $26);
    HEAP32[$28 >> 2] = $27;
    var $30 = __ZNK2js5Shape8previousEv($nshape_02);
    var $32 = HEAP32[$30 + 12 >> 2];
    var $33 = _JSID_IS_EMPTY2321($32);
    if (($33 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_pre_phi = $21;
      __label__ = 8;
      break;
    }
   case 10:
    var $_pre = HEAP32[$30 + 24 >> 2];
    var $nshape_02 = $30;
    var $27 = $32;
    var $26 = $_pre;
    __label__ = 9;
    break;
   case 11:
    var $i1_0;
    var $38 = __ZNK2js16AutoVectorRooterIiE6lengthEv($_pre_phi);
    if ($i1_0 >>> 0 < $38 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = $3;
      __label__ = 14;
      break;
    }
   case 12:
    var $41 = __ZN2js16AutoVectorRooterIiEixEj($_pre_phi, $i1_0);
    var $42 = HEAP32[$41 >> 2];
    __ZN2JSL14UndefinedValueEv2280($2);
    var $43 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $3, $42, $2, 0, 0, 1, 0, 0, 16);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 11;
    break;
   case 14:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($11);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE["X"] = 1;

function __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, $kind);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $obj_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($parent | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $16 = $parent;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$type >> 2];
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = __ZNK8JSObject9getParentEv($12);
    var $16 = $13;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $17 = $type;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, undef, __ZN2js11ObjectClassE, $17, $16, 0, 0);
    var $19 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $3, __ZN2js11ObjectClassE, $type, $kind);
    if ($19) {
      var $obj_0 = $3;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $obj_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $obj_0;
    return $obj_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11with_TypeOfP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $id, $value, $getter, $setter, $attrs, $flags, $shortid, $defineHow) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $valueCopy = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __Z22js_CheckForStringIndexi($id);
    if (($attrs & 48 | 0) == 0) {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js5types4Type11UnknownTypeEv($1);
    var $7 = $cx;
    var $8 = $obj;
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($7, $8, $3, $1);
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($7, $8, $3);
    var $9 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $3, $pobj, $prop);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$prop >> 2];
    if (($12 | 0) == 0) {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$pobj >> 2] | 0) == ($obj | 0)) {
      __label__ = 5;
      break;
    } else {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $18 = $12;
    var $19 = __ZNK2js5Shape20isAccessorDescriptorEv($18);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $shape_0 = 0;
      __label__ = 11;
      break;
    }
   case 6:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $27 = $getter;
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = __ZNK2js5Shape6getterEv($18);
    var $27 = $24;
    __label__ = 8;
    break;
   case 8:
    var $27;
    if (($attrs & 32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $34 = $setter;
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = __ZNK2js5Shape6setterEv($18);
    var $34 = $31;
    __label__ = 10;
    break;
   case 10:
    var $34;
    var $37 = __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($8, $7, $18, $attrs, 48, $27, $34);
    var $38 = $37;
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $shape_0 = $38;
      __label__ = 11;
      break;
    }
   case 11:
    var $shape_0;
    if (($defineHow & 2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_pre_phi = $obj;
    __label__ = 14;
    break;
   case 13:
    var $44 = $cx;
    var $45 = $obj;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($44, $45, $3);
    var $_pre_phi = $45;
    __label__ = 14;
    break;
   case 14:
    var $_pre_phi;
    var $47 = __ZNK8JSObject10isDelegateEv($_pre_phi);
    if ($47) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if (($attrs & 34 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = $cx;
    var $53 = __Z16js_GenerateShapeP9JSContext($52);
    var $56 = HEAP32[$cx + 52 >> 2] + 44 | 0;
    HEAP32[$56 >> 2] = $53;
    __label__ = 17;
    break;
   case 17:
    var $58 = __ZNK8JSObject8getClassEv($_pre_phi);
    var $60 = ($defineHow & 4 | 0) != 0;
    if ($60) {
      var $_1 = $getter;
      var $_03 = $setter;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($getter | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      var $_02 = $getter;
      __label__ = 21;
      break;
    }
   case 19:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $_02 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $_02 = HEAP32[$58 + 16 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $_02;
    if (($setter | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $_1 = $_02;
      var $_03 = $setter;
      __label__ = 24;
      break;
    }
   case 22:
    if (($attrs & 32 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $_1 = $_02;
      var $_03 = 0;
      __label__ = 24;
      break;
    }
   case 23:
    var $_1 = $_02;
    var $_03 = HEAP32[$58 + 20 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $_03;
    var $_1;
    var $83 = $cx;
    if (($60 | ($_1 | 0) == 10) & ($defineHow & 16 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      var $_pre_phi3 = $83;
      __label__ = 27;
      break;
    }
   case 25:
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($83, $_pre_phi, $3, $value);
    if (($attrs & 2 | 0) == 0) {
      var $_pre_phi3 = $83;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($83, $_pre_phi, $3);
    var $_pre_phi3 = $83;
    __label__ = 27;
    break;
   case 27:
    var $_pre_phi3;
    var $88 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($_pre_phi, $_pre_phi3);
    if ($88) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 28:
    var $90 = $value | 0;
    var $91$0 = HEAP32[$90 >> 2];
    var $91$1 = HEAP32[$90 + 4 >> 2];
    var $92 = $valueCopy | 0;
    HEAP32[$92 >> 2] = $91$0;
    HEAP32[$92 + 4 >> 2] = $91$1;
    if (($shape_0 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $adding_1 = 0;
      var $shape_1 = $shape_0;
      __label__ = 41;
      break;
    }
   case 29:
    if ($60) {
      __label__ = 30;
      break;
    } else {
      var $_01 = $flags;
      var $_2 = $_1;
      __label__ = 32;
      break;
    }
   case 30:
    var $96 = __ZNK2JS5Value8toObjectEv($value);
    var $97 = __ZNK8JSObject18getFunctionPrivateEv($96);
    if (($97 | 0) == ($96 | 0)) {
      __label__ = 31;
      break;
    } else {
      var $_01 = $flags;
      var $_2 = $_1;
      __label__ = 32;
      break;
    }
   case 31:
    var $101 = $96;
    var $102 = $flags | 128;
    var $103 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($101);
    var $_01 = $102;
    var $_2 = $103;
    __label__ = 32;
    break;
   case 32:
    var $_2;
    var $_01;
    var $105 = __ZN8JSObject12nativeLookupEP9JSContexti($_pre_phi, $_pre_phi3, $3);
    if (($105 | 0) == 0) {
      var $adding_0 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $108 = __ZNK2js5Shape8isMethodEv($105);
    if ($108) {
      __label__ = 34;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 34:
    var $110 = __ZNK2js5Shape12methodObjectEv($105);
    var $111 = $110;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $111);
    var $112 = __ZNK2JS5ValueeqERKS0_($2, $valueCopy);
    if ($112) {
      __label__ = 35;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 35:
    var $114 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($_pre_phi, $_pre_phi3, $105, $valueCopy);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $adding_0 = 0;
      __label__ = 36;
      break;
    }
   case 36:
    var $adding_0;
    var $117 = __ZNK8JSObject5shapeEv($_pre_phi);
    var $120 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($_pre_phi, $_pre_phi3, $3, $_2, $_03, -1, $attrs, $_01, $shortid);
    var $121 = $120;
    if (($120 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $124 = __ZNK8JSObject5shapeEv($_pre_phi);
    if (($124 | 0) == ($117 | 0)) {
      __label__ = 38;
      break;
    } else {
      var $adding_1 = $adding_0;
      var $shape_1 = $121;
      __label__ = 41;
      break;
    }
   case 38:
    var $127 = $obj;
    var $128 = __ZN8JSObject7brandedEv($127);
    if ($128) {
      __label__ = 39;
      break;
    } else {
      var $adding_1 = $adding_0;
      var $shape_1 = $121;
      __label__ = 41;
      break;
    }
   case 39:
    if ((HEAP32[$120 + 24 >> 2] | 0) == -1) {
      var $adding_1 = $adding_0;
      var $shape_1 = $121;
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $134 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($obj, $cx, $121, $valueCopy);
    var $adding_1 = $adding_0;
    var $shape_1 = $121;
    __label__ = 41;
    break;
   case 41:
    var $shape_1;
    var $adding_1;
    var $137 = HEAP32[$shape_1 + 24 >> 2];
    var $138 = __ZNK8JSObject12containsSlotEj($_pre_phi, $137);
    if ($138) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($_pre_phi, $137, $valueCopy);
    __label__ = 43;
    break;
   case 43:
    var $_idx_val = HEAP32[$58 + 8 >> 2];
    var $142 = __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $_idx_val, $obj, $shape_1, $valueCopy);
    if ($142) {
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $144 = __ZN8JSObject14removePropertyEP9JSContexti($_pre_phi, $_pre_phi3, $3);
    var $_0 = 0;
    __label__ = 48;
    break;
   case 45:
    if (($defineHow & 1 | 0) == 0) {
      var $_0 = $shape_1;
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if (($adding_1 & 1) << 24 >> 24 == 0) {
      var $_0 = $shape_1;
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $155 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $157 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($155, $_pre_phi3, $_pre_phi, 0, $_pre_phi, $shape_1, 1);
    var $_0 = $shape_1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij["X"] = 1;

function __Z13js_CreateThisP9JSContextP8JSObject($cx, $callee) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $protov = __stackBase__;
    var $1 = $callee;
    var $2 = __ZNK8JSObject8getClassEv($1);
    if (($2 | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($1);
    var $6 = $5;
    var $7 = __ZNK10JSFunction8isNativeEv($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$5 + 64 >> 2];
    if (($10 | 0) == 0) {
      var $newclasp_0 = __ZN2js11ObjectClassE;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $newclasp_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $newclasp_0;
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $19 = $cx;
    var $20 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($1, $19, $18, $protov);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZNK2JS5Value14isObjectOrNullEv($protov);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $28 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $25 = __ZNK2JS5Value14toObjectOrNullEv($protov);
    var $28 = $25;
    __label__ = 8;
    break;
   case 8:
    var $28;
    var $29 = __ZNK8JSObject9getParentEv($1);
    var $30 = $29;
    var $31 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE($newclasp_0);
    var $32 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $newclasp_0, $28, $30, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = $32;
    __ZN8JSObject19syncSpecialEqualityEv($35);
    var $_0 = $32;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_($cx, $callee, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($proto | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $callee;
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($4);
    var $6 = $proto;
    var $7 = $cx;
    var $8 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($6, $7, $5, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8;
    var $12 = __ZNK8JSObject9getParentEv($4);
    var $13 = $12;
    var $14 = __ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject($cx, $11, $13);
    var $res_0 = $14;
    __label__ = 5;
    break;
   case 4:
    var $16 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $17 = $callee;
    var $18 = __ZNK8JSObject9getParentEv($17);
    var $19 = $18;
    var $20 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, 0, $19, $16);
    var $res_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $res_0;
    if (($res_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $cx;
    var $25 = __ZN9JSContext20typeInferenceEnabledEv($24);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $res_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $27 = $callee;
    var $28 = __ZNK8JSObject18getFunctionPrivateEv($27);
    var $29 = __ZNK10JSFunction6scriptEv($28);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($1, $res_0);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($24, $29, $1);
    var $_0 = $res_0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject($cx, $type, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $type + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 4 >> 2];
    var $7 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $7;
    var $14 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    __ZN8JSObject6setMapEPN2js5ShapeE($13, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $16 = __ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE(__ZN2js11ObjectClassE);
    var $17 = __ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE($cx, $type, $parent, $16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $proto, $parent, $kind) {
  var $1 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, __ZN2js11ObjectClassE, $proto, $parent, $kind);
  return $1;
}

function __Z24js_CreateThisForFunctionP9JSContextP8JSObjectb($cx, $callee, $newType) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $protov = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $6 = $callee;
    var $7 = $cx;
    var $8 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($6, $7, $5, $protov);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK2JS5Value8isObjectEv($protov);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $proto_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = __ZNK2JS5Value8toObjectEv($protov);
    var $proto_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $proto_0;
    var $16 = __Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_($cx, $callee, $proto_0);
    if (($16 | 0) == 0 | $newType ^ 1) {
      var $_0 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    __ZN8JSObject5clearEP9JSContext($19, $7);
    var $20 = $16;
    var $21 = $cx;
    var $22 = __ZN8JSObject16setSingletonTypeEP9JSContext($20, $21);
    var $23 = __ZNK8JSObject18getFunctionPrivateEv($6);
    var $24 = __ZNK10JSFunction6scriptEv($23);
    __ZN2js5types4Type10ObjectTypeEP8JSObject($1, $19);
    __ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE($7, $24, $1);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9DetectingP9JSContextPh($cx, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $cx + 60 | 0;
    var $3 = __ZNK2js12ContextStack13currentScriptEPPh($2, 0);
    var $4 = $3;
    var $5 = $3 | 0;
    var $7 = $3 + 8 | 0;
    var $9 = HEAP32[$5 >> 2] + HEAP32[$7 >> 2] | 0;
    var $_04 = $pc;
    __label__ = 2;
    break;
   case 2:
    var $_04;
    var $11 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $_04);
    var $12 = _js_CodeSpec + ($11 << 3) | 0;
    var $14 = HEAPU32[_js_CodeSpec + ($11 << 3) + 4 >> 2];
    if (($14 & 16384 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 3:
    if (($11 | 0) == 64) {
      __label__ = 4;
      break;
    } else if (($11 | 0) == 156 || ($11 | 0) == 59) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $19 = $_04 + 1 | 0;
    if ($19 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    var $22 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $19);
    var $_0 = (HEAP8[$19] - 18 & 255 & 255) < 2 & 1;
    __label__ = 17;
    break;
   case 6:
    var $27 = $cx;
    var $28 = _js_GetIndexFromBytecode($27, $3, $_04, 0);
    var $29 = HEAPU32[$5 >> 2];
    if ($_04 >>> 0 < $29 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($29 + HEAP32[$7 >> 2] | 0) >>> 0 > $_04 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = HEAPU32[$cx + 52 >> 2];
    var $38 = $37 + 209948 | 0;
    var $39 = __ZN11JSAtomState16commonAtomsStartEv($38);
    var $atom_0 = HEAP32[$39 + ($28 << 2) >> 2];
    var $45 = $37;
    __label__ = 10;
    break;
   case 9:
    var $43 = __ZN8JSScript7getAtomEj($3, $28);
    var $atom_0 = $43;
    var $45 = HEAP32[$cx + 52 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $45;
    var $atom_0;
    if (($atom_0 | 0) == (HEAP32[$45 + 209984 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 11:
    var $54 = $_04 + (HEAP8[$12 | 0] << 24 >> 24) | 0;
    if ($54 >>> 0 < $9 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $57 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $54);
    if (($57 - 18 | 0) >>> 0 < 2 | ($57 | 0) == 72) {
      var $63 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $63 = ($57 | 0) == 73;
    __label__ = 14;
    break;
   case 14:
    var $63;
    var $_0 = $63 & 1;
    __label__ = 17;
    break;
   case 15:
    if (($14 & 262144 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $_04 = $_04 + (HEAP8[$12 | 0] << 24 >> 24) | 0;
    __label__ = 2;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z9DetectingP9JSContextPh["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_InferFlagsP9JSContextj($cx, $defaultFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $2 = $cx + 60 | 0;
    var $3 = __ZNK2js12ContextStack13currentScriptEPPh($2, $pc);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = $defaultFlags;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$pc >> 2];
    if (($7 | 0) == 0) {
      var $_0 = $defaultFlags;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329($4, $7);
    var $12 = HEAPU32[_js_CodeSpec + ($10 << 3) + 4 >> 2];
    var $flags_0 = ($12 & 224 | 0) != 32 & 1;
    if (($12 & 8448 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $flags_1 = $flags_0 | 2;
    __label__ = 8;
    break;
   case 5:
    var $20 = HEAP8[_js_CodeSpec + ($10 << 3) | 0];
    if ($20 << 24 >> 24 > -1) {
      __label__ = 6;
      break;
    } else {
      var $flags_1 = $flags_0;
      __label__ = 8;
      break;
    }
   case 6:
    var $25 = HEAP32[$pc >> 2] + ($20 << 24 >> 24) | 0;
    HEAP32[$pc >> 2] = $25;
    if ($25 >>> 0 < (HEAP32[$3 >> 2] + HEAP32[$3 + 8 >> 2] | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $flags_1 = $flags_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = __Z9DetectingP9JSContextPh($cx, $25);
    var $flags_0_ = ($33 | 0) == 0 ? $flags_0 : $flags_0 | 4;
    var $flags_1 = $flags_0_;
    __label__ = 8;
    break;
   case 8:
    var $flags_1;
    var $flags_2 = ($12 & 131072 | 0) == 0 ? $flags_1 : $flags_1 | 8;
    var $_0 = $flags_2;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $2 = HEAP32[$cx + 208 >> 2];
    if (($2 | 0) == 65535) {
      __label__ = 2;
      break;
    } else {
      var $flags_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __Z13js_InferFlagsP9JSContextj($cx, 65535);
    var $flags_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $flags_0;
    var $8 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $8, $flags_0 | 32);
    var $9 = $obj;
    var $10 = __ZNK8JSObject8getProtoEv($9);
    var $11 = $objp;
    var $12 = $propp;
    var $13 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($10, $8, $id, $11, $12);
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $4, $objp, $propp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2, $3, $id, $vp);
  return $4;
}

function __ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom2291($1);
  var $3 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($2, $3, $id, $vp, $strict);
  return $4;
}

function __ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject13getAttributesEP9JSContextiPj($2, $3, $id, $attrsp);
  return $4;
}

function __ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL18with_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject13setAttributesEP9JSContextiPj($2, $3, $id, $attrsp);
  return $4;
}

function __ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL18with_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $cx;
  var $4 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($2, $3, $id, $rval, $strict);
  return $4;
}

function __ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $rval, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_idx_val);
  var $2 = __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8getProtoEv($1);
  var $3 = $2;
  var $4 = $cx;
  var $5 = __ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi($3, $4, $enum_op, $statep, $idp);
  return $5;
}

function __ZL15with_ThisObjectP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZNK8JSObject11getWithThisEv($obj);
  return $1;
}

function __Z16js_NewWithObjectP9JSContextP8JSObjectS2_i($cx, $proto, $parent, $depth) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = $proto;
    var $3 = $cx;
    var $4 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($2, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($3, 2);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK9JSContext2fpEv($3);
    var $12 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($3, $11);
    var $13 = $12;
    var $14 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($7, undef, __ZN2js9WithClassE, $4, $14, $13, 0);
    var $15 = __ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext($cx);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = $15;
    __ZN8JSObject6setMapEPN2js5ShapeE($7, $18);
    __ZN2JSL10Int32ValueEi2332($1, $depth);
    __ZN8JSObject12setFixedSlotEjRKN2JS5ValueE($7, 0, $1);
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $3, $7);
    var $19 = __ZN8JSObject10thisObjectEP9JSContext($2, $3);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $19;
    __ZN8JSObject11setWithThisEPS_($8, $22);
    var $_0 = $8;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 768 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js9WithClassE, $5);
  return $6;
}

function __ZN2JSL10Int32ValueEi2332($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZN8JSObject11setWithThisEPS_($this, $thisp) {
  var $1 = __ZN8JSObject15getFixedSlotRefEj($this, 1);
  var $2 = $thisp;
  __ZN2JS5Value9setObjectER8JSObject($1, $2);
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb2335($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject7watchedEv($this) {
  return (HEAP32[$this + 8 >> 2] & 8192 | 0) != 0;
}

function __ZN8JSObject16updateFixedSlotsEj($this, $fixed) {
  var $1 = $this + 8 | 0;
  var $5 = HEAP32[$1 >> 2] & 134217727 | $fixed << 27;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __Z17js_NewBlockObjectP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, 2);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext($cx);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, undef, __ZN2js10BlockClassE, __ZN2js5types15emptyTypeObjectE, 0, 0, 0);
    var $9 = $6;
    __ZN8JSObject6setMapEPN2js5ShapeE($2, $9);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 752 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js10BlockClassE, $5);
  return $6;
}

function __Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE($cx, $proto, $fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = __ZNK8JSObject13propertyCountEv($1);
    var $3 = $2 + 1 | 0;
    var $4 = __ZN2js2gcL15GetGCObjectKindEjb2335($3);
    var $5 = $proto;
    var $6 = $cx;
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($5, $6, 0, 0);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($6, $4);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $fp;
    var $16 = __Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE($6, $15);
    var $17 = $16;
    __ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE($12, $cx, $8, $17);
    var $18 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($12, $cx, $3);
    if ($18) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $20 = __ZNK8JSObject7getSlotEj($5, 0);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($11, 0, $20);
    var $_0 = $12;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE($this, $cx, $type, $frame) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $frame;
    var $2 = $this;
    var $3 = $type;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, undef, __ZN2js10BlockClassE, $3, 0, $1, 0);
    var $4 = __ZNK8JSObject8getProtoEv($2);
    var $6 = HEAP32[$4 >> 2];
    HEAP32[$this >> 2] = $6;
    var $8 = __ZNK8JSObject8getProtoEv($2);
    var $9 = __ZNK8JSObject11hasOwnShapeEv($8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $cx;
    var $12 = __Z16js_GenerateShapeP9JSContext($11);
    __ZN8JSObject11setOwnShapeEj($2, $12);
    __label__ = 4;
    break;
   case 3:
    var $15 = HEAP32[$6 >> 2];
    HEAP32[$this + 12 >> 2] = $15;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($this, $cx, $nreserved) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject8getClassEv($1);
    var $7 = (HEAPU32[$2 + 4 >> 2] >>> 8 & 255) + $nreserved | 0;
    var $8 = __ZNK8JSObject8numSlotsEv($1);
    if ($7 >>> 0 > $8 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $13 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $7);
    var $13 = $11;
    __label__ = 3;
    break;
   case 3:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PutBlockObjectP9JSContexti($cx, $normalUnwind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext2fpEv($1);
    var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
    var $4 = $3;
    var $5 = __ZNK8JSObject13propertyCountEv($4);
    if (($normalUnwind | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $2;
    __label__ = 4;
    break;
   case 3:
    var $8 = __ZNK8JSObject12getFixedSlotEj($3, 0);
    var $9 = __ZNK2JS5Value7toInt32Ev($8);
    var $10 = $3;
    var $11 = __ZNK2js10StackFrame8numFixedEv($2);
    var $12 = $11 + $9 | 0;
    var $13 = $2;
    var $14 = __ZNK2js10StackFrame5slotsEv($13);
    var $15 = $14 + ($12 << 3) | 0;
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($10, 1, $15, $5);
    var $_pre_phi = $13;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    __ZN8JSObject10setPrivateEPv($3, 0);
    var $17 = __ZNK8JSObject9getParentEv($3);
    var $18 = $17;
    __ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject($_pre_phi, $18);
    return $normalUnwind;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($this, $start, $vector, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 32 >> 2] + ($start << 3) | 0;
    var $8 = $vector;
    var $9 = $length << 3;
    _memcpy($7, $8, $9, 1);
    __label__ = 8;
    break;
   case 3:
    var $11 = __ZNK8JSObject13numFixedSlotsEv($1);
    if ($11 >>> 0 > $start >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($length + $start | 0) >>> 0 < $11 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZNK8JSObject10fixedSlotsEv($1);
    var $19 = $17 + ($start << 3) | 0;
    var $20 = $vector;
    var $21 = $length << 3;
    _memcpy($19, $20, $21, 1);
    __label__ = 8;
    break;
   case 6:
    var $23 = $11 - $start | 0;
    var $24 = __ZNK8JSObject10fixedSlotsEv($1);
    var $26 = $24 + ($start << 3) | 0;
    var $27 = $vector;
    var $28 = $23 << 3;
    _memcpy($26, $27, $28, 1);
    var $31 = HEAP32[$this + 32 >> 2];
    var $33 = $vector + ($23 << 3) | 0;
    var $35 = $length - $23 << 3;
    _memcpy($31, $33, $35, 1);
    __label__ = 8;
    break;
   case 7:
    var $40 = HEAP32[$this + 32 >> 2] + ($start - $11 << 3) | 0;
    var $41 = $vector;
    var $42 = $length << 3;
    _memcpy($40, $41, $42, 1);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj["X"] = 1;

function __ZN8JSObject19defineBlockVariableEP9JSContextii($this, $cx, $id, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = (HEAPU32[__ZN2js10BlockClassE + 4 >> 2] >>> 8 & 255) + $index | 0;
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($5, $6, $id, 182, 184, $4, 5, 64, $index);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK8JSObject8numSlotsEv($5);
    if ($4 >>> 0 < $11 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $4 + 1 | 0;
    var $15 = __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $8;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT2488($id);
    var $6 = $2;
    var $7 = __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($6);
    var $8 = $7;
    var $9 = __ZNK2js10StackFrame8numFixedEv($8);
    var $10 = __ZNK8JSObject12getFixedSlotEj($1, 0);
    var $11 = __ZNK2JS5Value7toInt32Ev($10);
    var $13 = $9 + $5 + $11 | 0;
    var $14 = $7;
    var $15 = __ZNK2js10StackFrame5slotsEv($14);
    var $16 = $15 + ($13 << 3) | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_INT2488($id);
    var $6 = $2;
    var $7 = __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($6);
    var $8 = $7;
    var $9 = __ZNK2js10StackFrame8numFixedEv($8);
    var $10 = __ZNK8JSObject12getFixedSlotEj($1, 0);
    var $11 = __ZNK2JS5Value7toInt32Ev($10);
    var $13 = $9 + $5 + $11 | 0;
    var $14 = $7;
    var $15 = __ZNK2js10StackFrame5slotsEv($14);
    var $16 = $vp | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $15 + ($13 << 3) | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    __label__ = 3;
    break;
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject8numSlotsEv($1);
    if ($2 >>> 0 < 1048577) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $2 << 1;
    __label__ = 4;
    break;
   case 3:
    var $10 = ($2 >>> 3) + $2 | 0;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $12 = $10 >>> 0 < $newcap >>> 0 ? $newcap : $10;
    if ($12 >>> 0 > 131071) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($12 >>> 0 < 8) {
      __label__ = 6;
      break;
    } else {
      var $actualCapacity_01 = $12;
      __label__ = 9;
      break;
    }
   case 6:
    var $actualCapacity_01 = 8;
    __label__ = 9;
    break;
   case 7:
    var $19 = $12 + 131071 & -131072;
    if ($19 >>> 0 > 536870911) {
      __label__ = 8;
      break;
    } else {
      var $actualCapacity_01 = $19;
      __label__ = 9;
      break;
    }
   case 8:
    var $22 = $cx;
    _JS_ReportOutOfMemory($22);
    var $_0 = 0;
    __label__ = 19;
    break;
   case 9:
    var $actualCapacity_01;
    var $23 = __ZNK8JSObject13hasSlotsArrayEv($1);
    if ($23) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $actualCapacity_01);
    var $_0 = $25;
    __label__ = 19;
    break;
   case 11:
    var $27 = __ZNK8JSObject15numDynamicSlotsEj($1, $2);
    var $28 = __ZNK8JSObject15numDynamicSlotsEj($1, $actualCapacity_01);
    var $29 = $this + 32 | 0;
    var $31 = HEAP32[$29 >> 2];
    var $32 = $27 << 3;
    var $33 = $28 << 3;
    var $34 = $cx;
    var $35 = __ZN9JSContext8realloc_EPvjj($34, $31, $32, $33);
    var $36 = $35;
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = (HEAP32[$29 >> 2] | 0) == ($36 | 0);
    HEAP32[$29 >> 2] = $36;
    HEAP32[$this + 28 >> 2] = $actualCapacity_01;
    var $42 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($42) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $44 = __ZN9JSContext20typeInferenceEnabledEv($34);
    if ($44) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($1, $34);
    __label__ = 16;
    break;
   case 15:
    var $47 = $36 + ($27 << 3) | 0;
    var $48 = $28 - $27 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($47, $48, 0);
    __label__ = 16;
    break;
   case 16:
    if ($40) {
      var $_0 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $51 = __ZNK8JSObject8isGlobalEv($1);
    if ($51) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $this);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject9growSlotsEP9JSContextj["X"] = 1;

function __ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi($this, $cx, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7watchedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_01 = $id;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __Z22js_CheckForStringIndexi($id);
    var $7 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($7 | 0) == 0) {
      var $_01 = $3;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $7;
    var $11 = $cx;
    var $12 = $this;
    var $13 = __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($10, $11, $12, $3, $vp);
    if ($13) {
      var $_01 = $3;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01;
    var $15 = $this;
    var $16 = __ZNK8JSObject6getOpsEv($15);
    var $19 = HEAP32[$16 + 52 >> 2];
    var $20 = FUNCTION_TABLE[$19]($cx, $this, $_01, $vp, $strict);
    var $_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19nonNativeSetElementEP9JSContextjPN2JS5ValueEi($this, $cx, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZNK8JSObject7watchedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __ZN2js9IndexToIdEP9JSContextjPi($3, $index, $id);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$id >> 2];
    var $13 = $9;
    var $14 = $this;
    var $15 = __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($13, $3, $14, $12, $vp);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $this;
    var $18 = __ZNK8JSObject6getOpsEv($17);
    var $21 = HEAP32[$18 + 56 >> 2];
    var $22 = FUNCTION_TABLE[$21]($cx, $this, $index, $vp, $strict);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($this, $cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shapes = __stackBase__;
    var $r = __stackBase__ + 60;
    var $1 = __stackBase__ + 68;
    var $getter = __stackBase__ + 72;
    var $setter = __stackBase__ + 76;
    var $v = __stackBase__ + 80;
    var $2 = $this;
    var $3 = __ZNK8JSObject8isNativeEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 18;
      break;
    }
   case 2:
    __ZN2js15AutoShapeVectorC1EP9JSContext($shapes, $cx);
    var $5 = $obj;
    var $6 = __ZNK8JSObject12lastPropertyEv($5);
    var $7 = $r;
    __ZN2js5Shape5RangeC1EPKS0_($7, $6);
    var $8 = $r;
    var $9 = $shapes | 0;
    __label__ = 3;
    break;
   case 3:
    var $11 = __ZNK2js5Shape5Range5emptyEv($8);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK2js5Shape5Range5frontEv($7);
    HEAP32[$1 >> 2] = $13;
    var $15 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_($9, $1);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    __ZN2js5Shape5Range8popFrontEv($7);
    __label__ = 3;
    break;
   case 6:
    var $18 = __ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv($9);
    var $19 = $v | 0;
    var $20 = $cx + 56 | 0;
    var $21 = $cx;
    var $22 = $setter;
    var $23 = $getter;
    var $n_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $n_0;
    if (($n_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = $n_0 - 1 | 0;
    var $28 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($9, $27);
    var $29 = HEAPU32[$28 >> 2];
    var $30 = $29;
    var $31 = __ZNK2js5Shape10attributesEv($30);
    var $32 = $31 & 255;
    var $33 = __ZNK2js5Shape6getterEv($30);
    HEAP32[$getter >> 2] = $33;
    if (($32 & 16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = HEAP32[$20 >> 2];
    var $40 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE($39, $21, $23);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 10:
    var $42 = __ZNK2js5Shape6setterEv($30);
    HEAP32[$setter >> 2] = $42;
    if (($32 & 32 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $48 = HEAP32[$20 >> 2];
    var $49 = __ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE($48, $21, $22);
    if ($49) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $51 = __ZNK2js5Shape7hasSlotEv($30);
    if ($51) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $54 = HEAP32[$29 + 24 >> 2];
    var $55 = __ZNK8JSObject7getSlotEj($5, $54);
    var $56 = $55 | 0;
    var $57$0 = HEAP32[$56 >> 2];
    var $57$1 = HEAP32[$56 + 4 >> 2];
    HEAP32[$19 >> 2] = $57$0;
    HEAP32[$19 + 4 >> 2] = $57$1;
    __label__ = 15;
    break;
   case 14:
    __ZN2JSL14UndefinedValueEv2280($v);
    __label__ = 15;
    break;
   case 15:
    var $61 = HEAP32[$20 >> 2];
    var $62 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($61, $21, $v);
    if ($62) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $65 = HEAP32[$29 + 12 >> 2];
    var $68 = HEAP32[$getter >> 2];
    var $69 = HEAP32[$setter >> 2];
    var $70 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($2, $21, $65, $v, $68, $69, $32);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      var $n_0 = $27;
      __label__ = 7;
      break;
    }
   case 17:
    var $_0;
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = $_0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject18copyPropertiesFromEP9JSContextPS_["X"] = 1;

function __ZN2js15AutoShapeVectorC1EP9JSContext($this, $cx) {
  __ZN2js15AutoShapeVectorC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_($this, $v) {
  var $1 = $this + 12 | 0;
  var $2 = HEAP32[$v >> 2];
  var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_($1, $2);
  return $3;
}

function __ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv($this) {
  var $2 = $this + 12 | 0;
  var $3 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($2);
  return $3;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZN2js15AutoShapeVectorD1Ev($this) {
  __ZN2js15AutoShapeVectorD2Ev($this);
  return;
}

function __ZN8JSObject5cloneEP9JSContextPS_S2_($this, $cx, $proto, $parent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject8isNativeEv($1);
    if ($2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $cx;
    var $7 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($1, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject7isProxyEv($1);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $cx;
    _JS_ReportErrorNumber($12, 2, 0, 265, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $14 = __ZNK8JSObject8getClassEv($1);
    var $15 = $14;
    var $16 = $this;
    var $17 = __ZNK2js2gc4Cell12getAllocKindEv($16);
    var $18 = __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346($cx, $15, $proto, $parent, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = __ZNK8JSObject8isNativeEv($1);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $23 = $18;
    var $24 = __ZNK8JSObject10isFunctionEv($23);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = __ZNK2js2gc4Cell11compartmentEv($16);
    var $27 = $18;
    var $28 = __ZNK2js2gc4Cell11compartmentEv($27);
    if (($26 | 0) == ($28 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = $cx;
    _JS_ReportErrorNumber($31, 2, 0, 265, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 11:
    var $33 = __ZNK8JSObject8getClassEv($1);
    if ((HEAP32[$33 + 4 >> 2] & 1 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = __ZNK8JSObject10getPrivateEv($1);
    __ZN8JSObject10setPrivateEPv($23, $39);
    __label__ = 14;
    break;
   case 13:
    var $41 = __ZL9CopySlotsP9JSContextP8JSObjectS2_($cx, $this, $18);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $_0 = $18;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($clasp | 0) == (__ZN2js13FunctionClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464($cx, __ZN2js13FunctionClassE, $proto, $parent, $kind);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, $clasp, $proto, $parent, $kind);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9CopySlotsP9JSContextP8JSObjectS2_($cx, $from, $to) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $from;
    var $2 = __ZNK8JSObject8numSlotsEv($1);
    var $3 = $to;
    var $4 = $cx;
    var $5 = __ZN8JSObject11ensureSlotsEP9JSContextj($3, $4, $2);
    if ($5) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject9isWrapperEv($1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $n_0_ph = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZN9JSWrapper14wrapperHandlerEPK8JSObject($1);
    var $10 = $9;
    var $11 = __ZNK9JSWrapper5flagsEv($10);
    if (($11 & 1 | 0) == 0) {
      var $n_0_ph = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK8JSObject7getSlotEj($1, 0);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 0, $15);
    var $16 = __ZNK8JSObject7getSlotEj($1, 1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 1, $16);
    var $n_0_ph = 2;
    __label__ = 5;
    break;
   case 5:
    var $n_0_ph;
    var $17 = $v | 0;
    var $18 = $cx + 56 | 0;
    var $n_0 = $n_0_ph;
    __label__ = 6;
    break;
   case 6:
    var $n_0;
    if ($n_0 >>> 0 < $2 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $22 = __ZNK8JSObject7getSlotEj($1, $n_0);
    var $23 = $22 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    HEAP32[$17 >> 2] = $24$0;
    HEAP32[$17 + 4 >> 2] = $24$1;
    var $26 = HEAP32[$18 >> 2];
    var $27 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($26, $4, $v);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $n_0, $v);
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $a, $b, $reserved) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = __ZNK8JSObject10structSizeEv($1);
    var $3 = $b;
    var $4 = __ZNK8JSObject10structSizeEv($3);
    if (($2 | 0) == ($4 | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $a;
    var $8 = __ZNK8JSObject8numSlotsEv($7);
    var $9 = $b;
    var $10 = __ZNK8JSObject8numSlotsEv($9);
    var $11 = $reserved + 4 | 0;
    var $12 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($11, $8);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $14 = $reserved + 28 | 0;
    var $15 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($14, $10);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $17 = __ZNK8JSObject13numFixedSlotsEv($7);
    var $18 = __ZNK8JSObject13numFixedSlotsEv($9);
    if ($17 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $22 = $10 - $17 << 3;
    var $23 = $cx;
    var $24 = __ZN9JSContext7malloc_Ej($23, $22);
    HEAP32[$reserved + 52 >> 2] = $24;
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($18 >>> 0 < $8 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $32 = $8 - $18 << 3;
    var $33 = $cx;
    var $34 = __ZN9JSContext7malloc_Ej($33, $32);
    HEAP32[$reserved + 56 >> 2] = $34;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    var $8 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $9 = __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj($5, $8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL3MaxIjEET_S1_S1_2347($t1, $t2) {
  var $2 = $t1 >>> 0 > $t2 >>> 0 ? $t1 : $t2;
  return $2;
}

function __Z15FindObjectIndexP13JSObjectArrayP8JSObject($array, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($array | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$array >> 2];
    var $i_0 = HEAP32[$array + 4 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    var $8 = $i_0 - 1 | 0;
    if ((HEAP32[$6 + ($8 << 2) >> 2] | 0) == ($obj | 0)) {
      var $_0 = $8;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      var $i_0 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5ValueneERKS0_($this, $rhs) {
  var $1 = $this | 0;
  var $3 = $rhs | 0;
  return HEAP32[$1 >> 2] != HEAP32[$3 >> 2] || HEAP32[$1 + 4 >> 2] != HEAP32[$3 + 4 >> 2];
}

function __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $a, $b, $reserved) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 168;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = $a + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $b + 16 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $a;
    var $6 = __ZNK8JSObject10structSizeEv($5);
    var $7 = $b;
    var $8 = __ZNK8JSObject10structSizeEv($7);
    if (($6 | 0) == ($8 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $tmp | 0;
    var $12 = $a;
    _memcpy($11, $12, $6, 1);
    var $13 = $b;
    _memcpy($12, $13, $6, 1);
    _memcpy($13, $11, $6, 1);
    __label__ = 18;
    break;
   case 3:
    var $15 = $a;
    var $16 = __ZNK8JSObject8isNativeEv($15);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = $cx;
    __ZN8JSObject16generateOwnShapeEP9JSContext($15, $18);
    __label__ = 5;
    break;
   case 5:
    var $20 = $b;
    var $21 = __ZNK8JSObject8isNativeEv($20);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = $cx;
    __ZN8JSObject16generateOwnShapeEP9JSContext($20, $23);
    __label__ = 7;
    break;
   case 7:
    var $25 = __ZNK8JSObject8numSlotsEv($15);
    var $26 = __ZNK8JSObject8numSlotsEv($20);
    if (($25 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $reserved + 4 | 0;
    var $i_023 = 0;
    __label__ = 11;
    break;
   case 9:
    if (($26 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = $reserved + 28 | 0;
    var $i1_022 = 0;
    __label__ = 12;
    break;
   case 11:
    var $i_023;
    var $32 = __ZNK8JSObject7getSlotEj($15, $i_023);
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($28, $32);
    var $33 = $i_023 + 1 | 0;
    if (($33 | 0) == ($25 | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i_023 = $33;
      __label__ = 11;
      break;
    }
   case 12:
    var $i1_022;
    var $35 = __ZNK8JSObject7getSlotEj($20, $i1_022);
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($30, $35);
    var $36 = $i1_022 + 1 | 0;
    if (($36 | 0) == ($26 | 0)) {
      __label__ = 13;
      break;
    } else {
      var $i1_022 = $36;
      __label__ = 12;
      break;
    }
   case 13:
    var $37 = __ZNK8JSObject13hasSlotsArrayEv($15);
    if ($37) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $41 = HEAP32[$a + 32 >> 2];
    __ZN9JSContext5free_EPv(undef, $41);
    __label__ = 15;
    break;
   case 15:
    var $43 = __ZNK8JSObject13hasSlotsArrayEv($20);
    var $44 = $b + 32 | 0;
    if ($43) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $47 = HEAP32[$44 >> 2];
    __ZN9JSContext5free_EPv(undef, $47);
    __label__ = 17;
    break;
   case 17:
    var $48 = __ZNK8JSObject13numFixedSlotsEv($15);
    var $49 = __ZNK8JSObject13numFixedSlotsEv($20);
    var $a_0 = $a | 0;
    var $tmp11 = HEAPU8[$a_0] | HEAPU8[$a_0 + 1] << 8 | HEAPU8[$a_0 + 2] << 16 | HEAPU8[$a_0 + 3] << 24 | 0;
    var $a_1 = $a + 4 | 0;
    var $tmp12 = HEAPU8[$a_1] | HEAPU8[$a_1 + 1] << 8 | HEAPU8[$a_1 + 2] << 16 | HEAPU8[$a_1 + 3] << 24 | 0;
    var $a_2 = $a + 8 | 0;
    var $tmp13 = HEAPU8[$a_2] | HEAPU8[$a_2 + 1] << 8 | HEAPU8[$a_2 + 2] << 16 | HEAPU8[$a_2 + 3] << 24 | 0;
    var $a_3 = $a + 12 | 0;
    var $tmp14 = HEAPU8[$a_3] | HEAPU8[$a_3 + 1] << 8 | HEAPU8[$a_3 + 2] << 16 | HEAPU8[$a_3 + 3] << 24 | 0;
    var $tmp20 = HEAPU8[$1] | HEAPU8[$1 + 1] << 8 | HEAPU8[$1 + 2] << 16 | HEAPU8[$1 + 3] << 24 | 0;
    var $a_5 = $a + 20 | 0;
    var $tmp15 = HEAPU8[$a_5] | HEAPU8[$a_5 + 1] << 8 | HEAPU8[$a_5 + 2] << 16 | HEAPU8[$a_5 + 3] << 24 | 0;
    var $a_6 = $a + 24 | 0;
    var $tmp16 = HEAPU8[$a_6] | HEAPU8[$a_6 + 1] << 8 | HEAPU8[$a_6 + 2] << 16 | HEAPU8[$a_6 + 3] << 24 | 0;
    var $a_7 = $a + 28 | 0;
    var $tmp17 = HEAPU8[$a_7] | HEAPU8[$a_7 + 1] << 8 | HEAPU8[$a_7 + 2] << 16 | HEAPU8[$a_7 + 3] << 24 | 0;
    var $a_8 = $a + 32 | 0;
    var $tmp18 = HEAPU8[$a_8] | HEAPU8[$a_8 + 1] << 8 | HEAPU8[$a_8 + 2] << 16 | HEAPU8[$a_8 + 3] << 24 | 0;
    var $a_9 = $a + 36 | 0;
    var $tmp19 = HEAPU8[$a_9] | HEAPU8[$a_9 + 1] << 8 | HEAPU8[$a_9 + 2] << 16 | HEAPU8[$a_9 + 3] << 24 | 0;
    var $50 = $a;
    var $51 = $b;
    _memcpy($50, $51, 40, 1);
    var $b_0 = $b | 0;
    tempBigInt = $tmp11;
    HEAP8[$b_0] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_0 + 3] = tempBigInt & 255;
    var $b_1 = $b + 4 | 0;
    tempBigInt = $tmp12;
    HEAP8[$b_1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_1 + 3] = tempBigInt & 255;
    var $b_2 = $b + 8 | 0;
    tempBigInt = $tmp13;
    HEAP8[$b_2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_2 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_2 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_2 + 3] = tempBigInt & 255;
    var $b_3 = $b + 12 | 0;
    tempBigInt = $tmp14;
    HEAP8[$b_3] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_3 + 3] = tempBigInt & 255;
    tempBigInt = $tmp20;
    HEAP8[$3] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$3 + 3] = tempBigInt & 255;
    var $b_5 = $b + 20 | 0;
    tempBigInt = $tmp15;
    HEAP8[$b_5] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_5 + 3] = tempBigInt & 255;
    var $b_6 = $b + 24 | 0;
    tempBigInt = $tmp16;
    HEAP8[$b_6] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_6 + 3] = tempBigInt & 255;
    var $b_7 = $b + 28 | 0;
    tempBigInt = $tmp17;
    HEAP8[$b_7] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_7 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_7 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_7 + 3] = tempBigInt & 255;
    tempBigInt = $tmp18;
    HEAP8[$44] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$44 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$44 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$44 + 3] = tempBigInt & 255;
    var $b_9 = $b + 36 | 0;
    tempBigInt = $tmp19;
    HEAP8[$b_9] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 1] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 2] = tempBigInt & 255;
    tempBigInt >>= 8;
    HEAP8[$b_9 + 3] = tempBigInt & 255;
    __ZN8JSObject16updateFixedSlotsEj($a, $48);
    var $52 = $reserved + 52 | 0;
    var $53 = HEAP32[$52 >> 2];
    HEAP32[$a_8 >> 2] = $53;
    var $54 = __ZN2jsL3MaxIjEET_S1_S1_2347($48, $26);
    HEAP32[$a_7 >> 2] = $54;
    var $56 = $reserved + 28 | 0;
    var $57 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($56);
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($a, 0, $57, $26);
    var $58 = $54 - $26 | 0;
    __ZN8JSObject14clearSlotRangeEjj($a, $26, $58);
    __ZN8JSObject16updateFixedSlotsEj($b, $49);
    var $59 = $reserved + 56 | 0;
    var $60 = HEAP32[$59 >> 2];
    HEAP32[$44 >> 2] = $60;
    var $61 = __ZN2jsL3MaxIjEET_S1_S1_2347($49, $25);
    HEAP32[$b_7 >> 2] = $61;
    var $63 = $reserved + 4 | 0;
    var $64 = __ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv($63);
    __ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj($b, 0, $64, $25);
    var $65 = $61 - $25 | 0;
    __ZN8JSObject14clearSlotRangeEjj($b, $25, $65);
    HEAP32[$52 >> 2] = 0;
    HEAP32[$59 >> 2] = 0;
    __label__ = 18;
    break;
   case 18:
    HEAP32[$1 >> 2] = $2;
    HEAP32[$3 >> 2] = $4;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE["X"] = 1;

function __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $t | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $1 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $this;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($5, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN8JSObject14clearSlotRangeEjj($this, $start, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 32 >> 2] + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($6, $length, 1);
    __label__ = 8;
    break;
   case 3:
    var $8 = __ZNK8JSObject13numFixedSlotsEv($1);
    if ($8 >>> 0 > $start >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($length + $start | 0) >>> 0 < $8 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZNK8JSObject10fixedSlotsEv($1);
    var $15 = $14 + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($15, $length, 0);
    __label__ = 8;
    break;
   case 6:
    var $17 = $8 - $start | 0;
    var $18 = __ZNK8JSObject10fixedSlotsEv($1);
    var $19 = $18 + ($start << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($19, $17, 0);
    var $21 = HEAP32[$this + 32 >> 2];
    var $22 = $length - $17 | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($21, $22, 0);
    __label__ = 8;
    break;
   case 7:
    var $26 = HEAP32[$this + 32 >> 2] + ($start - $8 << 3) | 0;
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($26, $length, 0);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject4swapEP9JSContextPS_($this, $cx, $other) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 284;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $reserved = __stackBase__;
    var $ac = __stackBase__ + 60;
    var $ac1 = __stackBase__ + 112;
    var $reservedThis = __stackBase__ + 164;
    var $reservedOther = __stackBase__ + 224;
    var $1 = $this;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = $other;
    var $4 = __ZNK2js2gc4Cell11compartmentEv($3);
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reserved, $cx);
    var $7 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $other, $reserved);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $other, $reserved);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN8JSObject17TradeGutsReservedD1Ev($reserved);
    var $_4 = $_0;
    __label__ = 17;
    break;
   case 5:
    var $11 = $cx;
    var $12 = $other;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac, $11, $12);
    var $13 = __ZN2js15AutoCompartment5enterEv($ac);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $15 = __ZNK8JSObject8getProtoEv($12);
    var $16 = $15;
    var $17 = __ZNK8JSObject9getParentEv($12);
    var $18 = $17;
    var $19 = __ZN8JSObject5cloneEP9JSContextPS_S2_($this, $cx, $16, $18);
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($19, $cx, $this);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $_4 = 0;
    __label__ = 17;
    break;
   case 9:
    __ZN2js15AutoCompartmentD2Ev($ac);
    var $24 = $this;
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($ac1, $11, $24);
    var $25 = __ZN2js15AutoCompartment5enterEv($ac1);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $27 = __ZNK8JSObject8getProtoEv($12);
    var $28 = $27;
    var $29 = __ZNK8JSObject9getParentEv($12);
    var $30 = $29;
    var $31 = __ZN8JSObject5cloneEP9JSContextPS_S2_($other, $cx, $28, $30);
    if (($31 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = __ZN8JSObject18copyPropertiesFromEP9JSContextPS_($31, $cx, $other);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2js15AutoCompartmentD2Ev($ac1);
    var $_4 = 0;
    __label__ = 17;
    break;
   case 13:
    __ZN2js15AutoCompartmentD2Ev($ac1);
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reservedThis, $cx);
    __ZN8JSObject17TradeGutsReservedC1EP9JSContext($reservedOther, $cx);
    var $36 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $31, $reservedThis);
    if ($36) {
      __label__ = 14;
      break;
    } else {
      var $_3 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $38 = __ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $other, $19, $reservedOther);
    if ($38) {
      __label__ = 15;
      break;
    } else {
      var $_3 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $this, $31, $reservedThis);
    __ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE($cx, $other, $19, $reservedOther);
    var $_3 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_3;
    __ZN8JSObject17TradeGutsReservedD1Ev($reservedOther);
    __ZN8JSObject17TradeGutsReservedD1Ev($reservedThis);
    var $_4 = $_3;
    __label__ = 17;
    break;
   case 17:
    var $_4;
    STACKTOP = __stackBase__;
    return $_4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject4swapEP9JSContextPS_["X"] = 1;

function __ZN8JSObject17TradeGutsReservedC1EP9JSContext($this, $cx) {
  __ZN8JSObject17TradeGutsReservedC2EP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject17TradeGutsReservedD1Ev($this) {
  __ZN8JSObject17TradeGutsReservedD2Ev($this);
  return;
}

function __Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parentId = __stackBase__;
    var $depthAndCount = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $1 = __stackBase__ + 24;
    var $atom = __stackBase__ + 32;
    var $shapes = __stackBase__ + 36;
    var $r = __stackBase__ + 96;
    var $atom2 = __stackBase__ + 104;
    var $3 = HEAPU32[$xdr + 8 >> 2];
    var $4 = $xdr | 0;
    if ((HEAP32[$4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $obj_0 = 0;
      var $count_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$objp >> 2];
    var $9 = $8;
    var $11 = HEAP32[$xdr + 32 >> 2];
    var $13 = HEAP8[$11 + 16 | 0];
    var $14 = __ZN8JSScript13isValidOffsetEh($13);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $23 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = __ZNK8JSObject9getParentEv($9);
    var $17 = $16;
    var $18 = $11;
    var $19 = __ZN8JSScript7objectsEv($18);
    var $20 = $19;
    var $21 = __Z15FindObjectIndexP13JSObjectArrayP8JSObject($20, $17);
    var $23 = $21;
    __label__ = 4;
    break;
   case 4:
    var $23;
    HEAP32[$parentId >> 2] = $23;
    var $24 = __ZNK8JSObject12getFixedSlotEj($9, 0);
    var $25 = __ZNK2JS5Value7toInt32Ev($24);
    var $26 = $8;
    var $27 = __ZNK8JSObject13propertyCountEv($26);
    var $28 = $27 & 65535;
    var $30 = $28 | $25 << 16;
    HEAP32[$depthAndCount >> 2] = $30;
    var $obj_0 = $8;
    var $count_0 = $28;
    __label__ = 5;
    break;
   case 5:
    var $count_0;
    var $obj_0;
    var $32 = $xdr;
    var $33 = _JS_XDRUint32($32, $parentId);
    if (($33 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$4 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $obj_1 = $obj_0;
      __label__ = 11;
      break;
    }
   case 7:
    var $39 = __Z17js_NewBlockObjectP9JSContext($3);
    if (($39 | 0) == 0) {
      var $_2 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$objp >> 2] = $39;
    var $42 = HEAP32[$parentId >> 2];
    if (($42 | 0) == -1) {
      var $parent_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = HEAP32[$xdr + 32 >> 2];
    var $48 = __ZN8JSScript9getObjectEj($47, $42);
    var $parent_0 = $48;
    __label__ = 10;
    break;
   case 10:
    var $parent_0;
    var $50 = $39;
    __ZN8JSObject9setParentEPS_($50, $parent_0);
    var $obj_1 = $39;
    __label__ = 11;
    break;
   case 11:
    var $obj_1;
    var $52 = $3;
    var $53 = $obj_1;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $52, $53);
    var $54 = _JS_XDRUint32($32, $depthAndCount);
    if (($54 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$4 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 13:
    var $60 = HEAPU32[$depthAndCount >> 2];
    var $61 = $60 >>> 16;
    var $62 = $60 & 65535;
    __ZN2JSL10Int32ValueEi2332($1, $61);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($53, 0, $1);
    var $63 = $atom;
    var $i_0 = 0;
    __label__ = 14;
    break;
   case 14:
    var $i_0;
    if ($i_0 >>> 0 < $62 >>> 0) {
      __label__ = 15;
      break;
    } else {
      var $_1 = 1;
      __label__ = 26;
      break;
    }
   case 15:
    var $67 = _js_XDRAtom($32, $63);
    if (($67 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $70 = HEAP32[$atom >> 2];
    var $71 = __ZL12ATOM_TO_JSIDP6JSAtom2291($70);
    var $72 = __ZN8JSObject19defineBlockVariableEP9JSContextii($obj_1, $3, $71, $i_0);
    if (($72 | 0) == 0) {
      var $_1 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 14;
    break;
   case 18:
    __ZN2js15AutoShapeVectorC1EP9JSContext($shapes, $3);
    var $77 = $shapes | 0;
    var $78 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj($77, $count_0);
    var $79 = __ZNK8JSObject12lastPropertyEv($53);
    var $80 = $r;
    __ZN2js5Shape5RangeC1EPKS0_($80, $79);
    var $81 = $r;
    var $82 = __ZNK2js5Shape5Range5emptyEv($81);
    if ($82) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $83 = $atom2;
    var $i1_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $84 = __ZNK2js5Shape5Range5frontEv($80);
    var $85 = $84;
    var $88 = HEAP16[$84 + 30 >> 1] << 16 >> 16;
    var $89 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($77, $88);
    HEAP32[$89 >> 2] = $85;
    __ZN2js5Shape5Range8popFrontEv($80);
    var $90 = __ZNK2js5Shape5Range5emptyEv($81);
    if ($90) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 21:
    var $i1_0;
    if ($i1_0 >>> 0 < $count_0 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $94 = __ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj($77, $i1_0);
    var $97 = HEAP32[HEAP32[$94 >> 2] + 12 >> 2];
    var $98 = __ZL12JSID_TO_ATOMi2352($97);
    HEAP32[$atom2 >> 2] = $98;
    var $99 = _js_XDRAtom($32, $83);
    if (($99 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 21;
    break;
   case 24:
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = 1;
    __label__ = 26;
    break;
   case 25:
    __ZN2js15AutoShapeVectorD1Ev($shapes);
    var $_1 = 0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_2 = $_1;
    __label__ = 27;
    break;
   case 27:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj($this, $inc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = $1;
    var $3 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv($2);
    var $4 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $inc);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($2);
    var $8 = $6 + ($3 << 2) | 0;
    var $9 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv($1);
    __ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_($8, $9);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_TO_ATOMi2352($id) {
  var $1 = _JSID_TO_STRING2421($id);
  return $1;
}

function __ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_($cx, $obj, $key, $atom, $protoProto, $clasp, $constructor, $nargs, $ps, $fs, $static_ps, $static_fs, $ctorp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $named = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $tvr2 = __stackBase__ + 12;
    var $2 = __stackBase__ + 36;
    var $rval = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    var $rval1 = __stackBase__ + 60;
    var $4 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $protoProto, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject16setSingletonTypeEP9JSContext($7, $8);
    var $11 = $4;
    var $12 = $cx;
    if (($clasp | 0) == (__ZN2js10ArrayClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $11;
      var $_pre_phi8 = $12;
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = __ZN8JSObject18makeDenseArraySlowEP9JSContext($11, $12);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      var $_pre_phi = $11;
      var $_pre_phi8 = $12;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi8;
    var $_pre_phi;
    var $16 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($_pre_phi, $_pre_phi8, 0, 0);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZNK8JSObject8getClassEv($_pre_phi);
    var $20 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($16, $_pre_phi8, $19, 0);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN8JSObject19syncSpecialEqualityEv($7);
    HEAP8[$named] = 0;
    if (($constructor | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $27 = HEAP32[$clasp + 4 >> 2] & 131072;
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $obj;
    var $31 = __ZNK8JSObject8isGlobalEv($30);
    if (($key | 0) == 0 | $31 ^ 1) {
      __label__ = 9;
      break;
    } else {
      var $cached_1 = 0;
      var $ctor_1 = $4;
      var $proto_2 = $4;
      __label__ = 25;
      break;
    }
   case 9:
    var $35 = ($27 | 0) != 0 ? 6 : 0;
    __ZN2JSL11ObjectValueER8JSObject2354($1, $4);
    var $36 = __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $1, $35, $named);
    if ($36) {
      var $cached_1 = 0;
      var $ctor_1 = $4;
      var $proto_2 = $4;
      __label__ = 25;
      break;
    } else {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    }
   case 10:
    var $38 = $constructor;
    var $39 = $obj;
    var $40 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($_pre_phi8, 0, $38, $nargs, 512, $39, $atom);
    if (($40 | 0) == 0) {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = $40;
    var $44 = $clasp;
    __ZN10JSFunction19setConstructorClassEPN2js5ClassE($43, $44);
    if (($key | 0) == 0) {
      var $cached_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$clasp + 4 >> 2] & 64 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $cached_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = $40;
    var $53 = __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $52, $4);
    if ($53) {
      var $cached_0 = 1;
      __label__ = 14;
      break;
    } else {
      var $cached_2 = 0;
      __label__ = 39;
      break;
    }
   case 14:
    var $cached_0;
    var $55 = $40;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $55);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr2, $_pre_phi8, $2);
    var $56 = __ZNK2js15AutoValueRooter5valueEv($tvr2);
    var $57 = __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $56, 0, $named);
    if ($57) {
      __label__ = 15;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 15:
    if ((HEAP32[$clasp + 4 >> 2] & 64 | 0) == 0) {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($3, $55);
    var $64 = __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($_pre_phi8, $_pre_phi, $3, 0, 0, $rval);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 17:
    var $66 = __ZNK2JS5Value8isObjectEv($rval);
    if ($66) {
      __label__ = 18;
      break;
    } else {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    }
   case 18:
    var $68 = __ZNK2JS5Value8toObjectEv($rval);
    var $69 = $68;
    if (($69 | 0) == ($4 | 0)) {
      var $proto_0 = $4;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $proto_0 = $69;
    __label__ = 20;
    break;
   case 20:
    var $proto_0;
    var $73 = $40;
    var $75 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($8, $73, $proto_0);
    if ($75) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $77 = $40 | 0;
    var $78 = __ZNK8JSObject8getClassEv($77);
    if (($78 | 0) == ($clasp | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $83 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($77, $_pre_phi8, $proto_0);
    if ($83) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2js15AutoValueRooterD1Ev($tvr2);
    var $cached_2 = $cached_0;
    __label__ = 39;
    break;
   case 24:
    __ZN2js15AutoValueRooterD1Ev($tvr2);
    var $cached_1 = $cached_0;
    var $ctor_1 = $55;
    var $proto_2 = $proto_0;
    __label__ = 25;
    break;
   case 25:
    var $proto_2;
    var $ctor_1;
    var $cached_1;
    var $87 = $ps;
    var $88 = $fs;
    var $89 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($8, $proto_2, $87, $88);
    if ($89) {
      __label__ = 26;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 26:
    if (($ctor_1 | 0) == ($proto_2 | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $94 = $static_ps;
    var $95 = $static_fs;
    var $96 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($8, $ctor_1, $94, $95);
    if ($96) {
      __label__ = 28;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 28:
    var $98 = $clasp + 4 | 0;
    var $99 = HEAP32[$98 >> 2];
    if (($99 & 6291456 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if (($proto_2 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    if (($99 & 2097152 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $109 = __ZN8JSObject6freezeEP9JSContext($proto_2, $_pre_phi8);
    if ($109) {
      __label__ = 32;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 32:
    if (($ctor_1 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    if ((HEAP32[$98 >> 2] & 4194304 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $118 = __ZN8JSObject6freezeEP9JSContext($ctor_1, $_pre_phi8);
    if ($118) {
      __label__ = 35;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 35:
    if (($cached_1 & 1) << 24 >> 24 != 0 | ($key | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $124 = __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $ctor_1, $proto_2);
    if ($124) {
      __label__ = 37;
      break;
    } else {
      var $cached_2 = $cached_1;
      __label__ = 39;
      break;
    }
   case 37:
    if (($ctorp | 0) == 0) {
      var $_0 = $proto_2;
      __label__ = 43;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP32[$ctorp >> 2] = $ctor_1;
    var $_0 = $proto_2;
    __label__ = 43;
    break;
   case 39:
    var $cached_2;
    if ((HEAP8[$named] & 1) << 24 >> 24 == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $132 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
    var $133 = $obj;
    var $134 = __ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi($133, $_pre_phi8, $132, $rval1, 0);
    __label__ = 41;
    break;
   case 41:
    if (($cached_2 & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey($obj, $key);
    var $_0 = 0;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_["X"] = 1;

function __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb2335($4);
  var $6 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb($cx, $obj, $key, $atom, $v, $attrs, $named) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
    var $_pre = $obj;
    var $_pre1 = $cx;
    if (($key | 0) == 0) {
      var $_pre_phi = $_pre;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($_pre, $_pre1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $6 = __ZN8JSObject12nativeLookupEP9JSContexti($_pre, $_pre1, $1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_pre_phi = $_pre;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = $key + 74 | 0;
    var $10 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $9, $v);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($_pre, $_pre1, $1, 10, 12, $9, $attrs, 0, 0);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($_pre1, $_pre, $1, $v);
    HEAP8[$named] = 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $_pre_phi2;
    var $_pre_phi;
    var $15 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($_pre_phi, $_pre_phi2, $1, $v, 10, 12, $attrs);
    var $16 = ($15 | 0) != 0;
    HEAP8[$named] = $16 & 1;
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_($cx, $obj, $key, $cobj, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $4 = __ZNK8JSObject8isGlobalEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($1, $cobj);
    var $6 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $key, $1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $key + 37 | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($2, $proto);
    var $9 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $8, $2);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject2355($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $1);
  return;
}

function __ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey($obj, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $4 = __ZNK8JSObject8isGlobalEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv2280($1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $key, $1);
    var $6 = $key + 37 | 0;
    __ZN2JSL14UndefinedValueEv2280($2);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $6, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE($obj, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  var $5 = HEAPU32[$clasp + 4 >> 2] >>> 24;
  var $6 = $obj;
  __ZNK8JSObject15getReservedSlotEj($1, $6, $5);
  __ZN2JSL14UndefinedValueEv2280($2);
  var $7 = __ZNK2JS5ValueneERKS0_($1, $2);
  STACKTOP = __stackBase__;
  return $7;
}

function __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($obj, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $6 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $7 = $obj;
    __ZNK8JSObject15getReservedSlotEj($1, $7, $6);
    __ZN2JSL14UndefinedValueEv2280($2);
    var $8 = __ZNK2JS5ValueeqERKS0_($1, $2);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL12BooleanValueEb2297($3, 1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, $6, $3);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367($thingKind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($thingKind | 0) == 2 || ($thingKind | 0) == 3) {
      __label__ = 2;
      break;
    } else if (($thingKind | 0) == 4 || ($thingKind | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($thingKind | 0) == 6 || ($thingKind | 0) == 7) {
      __label__ = 4;
      break;
    } else if (($thingKind | 0) == 8 || ($thingKind | 0) == 9) {
      __label__ = 5;
      break;
    } else if (($thingKind | 0) == 11 || ($thingKind | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $_0 = 2;
    __label__ = 7;
    break;
   case 3:
    var $_0 = 4;
    __label__ = 7;
    break;
   case 4:
    var $_0 = 8;
    __label__ = 7;
    break;
   case 5:
    var $_0 = 12;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE($kindp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$kindp >> 2] + 2 | 0;
    if ($2 >>> 0 > 11) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$kindp >> 2] = $2;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $clasp_0_1_val >>> 24;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $clasp_0_1_val >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_($cx, $obj, $protoProto, $clasp, $constructor, $nargs, $ps, $fs, $static_ps, $static_fs, $ctorp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $protoProto;
    var $3 = HEAP32[$clasp >> 2];
    var $4 = _strlen($3);
    var $5 = $cx;
    var $6 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($5, $3, $4, 0, 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    if (($11 | 0) != 0 & ($protoProto | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $18 = $protoProto;
      __label__ = 5;
      break;
    }
   case 3:
    var $15 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $obj, 1, $1, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = HEAP32[$1 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_($cx, $obj, $11, $6, $18, $clasp, $constructor, $nargs, $ps, $fs, $static_ps, $static_fs, $ctorp);
    var $_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $scopeobj, $protoKey, $protop, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($protoKey | 0) == 0) {
      var $_2 = $scopeobj;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($scopeobj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $scopeobj;
      __label__ = 7;
      break;
    }
   case 3:
    var $6 = $cx;
    var $7 = __ZNK9JSContext5hasfpEv($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK9JSContext2fpEv($6);
    var $10 = __ZNK2js10StackFrame10scopeChainEv($9);
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $11;
      __label__ = 7;
      break;
    }
   case 5:
    var $14 = HEAP32[$cx + 132 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_1 = $14;
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$protop >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $_1;
    var $18 = __ZNK8JSObject9getGlobalEv($_1);
    var $19 = $18 | 0;
    var $20 = $18;
    var $21 = __ZNK8JSObject8isGlobalEv($20);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_2 = $19;
      __label__ = 10;
      break;
    }
   case 8:
    var $23 = $protoKey + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $20, $23);
    var $24 = __ZNK2JS5Value8isObjectEv($1);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_2 = $19;
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$protop >> 2] = $26;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $_2;
    var $29 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $_2, $protoKey, $protop, $clasp);
    var $_0 = $29 & 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($vec, $len, $useHoles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($len | 0) == 0;
    if ($useHoles) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    if ($1) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $i_04;
    var $2 = $vec + ($i_04 << 3) | 0;
    __ZN2JS5Value8setMagicE10JSWhyMagic($2, 0);
    var $3 = $i_04 + 1 | 0;
    if (($3 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_04 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $i1_01;
    var $4 = $vec + ($i1_01 << 3) | 0;
    __ZN2JS5Value12setUndefinedEv($4);
    var $5 = $i1_01 + 1 | 0;
    if (($5 | 0) == ($len | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i1_01 = $5;
      __label__ = 5;
      break;
    }
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10allocSlotsEP9JSContextj($this, $cx, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $1 = $this;
    var $2 = __ZNK8JSObject11hasLazyTypeEv($1);
    if ($2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject4typeEv($1);
    var $6 = HEAP32[$4 + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 + 4 >> 2];
    HEAP32[$kind >> 2] = $10;
    var $11 = __ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367($10);
    var $12 = __ZNK8JSObject13numFixedSlotsEv($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $15 = __ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE($kind);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = __ZNK8JSObject4typeEv($1);
    var $18 = $17;
    var $19 = __ZNK8JSObject9getParentEv($1);
    var $20 = $19;
    var $21 = HEAP32[$kind >> 2];
    var $26 = HEAP32[HEAP32[$17 + 16 >> 2] + 8 >> 2];
    var $27 = __ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE($cx, $18, $20, $21, $26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = __ZNK8JSObject4typeEv($1);
    var $33 = HEAP32[$30 + 16 >> 2] + 4 | 0;
    HEAP32[$33 >> 2] = $21;
    var $34 = $27;
    var $35 = __ZNK8JSObject12lastPropertyEv($34);
    var $36 = __ZNK8JSObject4typeEv($1);
    var $39 = HEAP32[$36 + 16 >> 2] + 8 | 0;
    HEAP32[$39 >> 2] = $35;
    var $40 = __ZNK8JSObject4typeEv($1);
    var $41 = $cx;
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($40, $41);
    __label__ = 7;
    break;
   case 7:
    if ($newcap >>> 0 > 536870912) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $45 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($45);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 9:
    var $47 = __ZNK8JSObject15numDynamicSlotsEj($1, $newcap);
    var $48 = $47 << 3;
    var $49 = $cx;
    var $50 = __ZN9JSContext7malloc_Ej($49, $48);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $53 = $50;
    HEAP32[$this + 32 >> 2] = $53;
    HEAP32[$this + 28 >> 2] = $newcap;
    var $56 = __ZNK8JSObject12isDenseArrayEv($1);
    if ($56) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $58 = __ZNK8JSObject10fixedSlotsEv($1);
    var $59 = $58;
    var $60 = __ZN8JSObject30getDenseArrayInitializedLengthEv($1);
    var $61 = $60 << 3;
    _memcpy($50, $59, $61, 1);
    var $62 = __ZN9JSContext20typeInferenceEnabledEv($49);
    if ($62) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN8JSObject23backfillDenseArrayHolesEP9JSContext($1, $49);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364($53, $47, 0);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject10allocSlotsEP9JSContextj["X"] = 1;

function __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = __ZNK8JSObject11hasLazyTypeEv($4);
    if ($5) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject4typeEv($4);
    var $8 = __ZN2js5types10TypeObject17unknownPropertiesEv($7);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js5types10TypeObject15markStateChangeEP9JSContext($7, $1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11shrinkSlotsEP9JSContextj($this, $cx, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject6isCallEv($1);
    if ($2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this;
    var $5 = __ZNK8JSObject8numSlotsEv($4);
    if ($5 >>> 0 < 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject13hasSlotsArrayEv($4);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject12isDenseArrayEv($4);
    if ($10) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $5 - $newcap | 0;
    __ZN8JSObject14clearSlotRangeEjj($this, $newcap, $12);
    __label__ = 13;
    break;
   case 6:
    var $14 = __ZN2jsL3MaxIjEET_S1_S1_2347($newcap, 8);
    var $15 = __ZNK8JSObject13numFixedSlotsEv($4);
    var $16 = __ZN2jsL3MaxIjEET_S1_S1_2347($14, $15);
    var $17 = $this + 32 | 0;
    var $19 = HEAP32[$17 >> 2];
    var $20 = $16 << 3;
    var $21 = $cx;
    var $22 = __ZN9JSContext8realloc_EPvj($21, $19, $20);
    var $23 = $22;
    if (($22 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = (HEAP32[$17 >> 2] | 0) == ($23 | 0);
    HEAP32[$17 >> 2] = $23;
    HEAP32[$this + 28 >> 2] = $16;
    if ($16 >>> 0 > $newcap >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $31 = __ZNK8JSObject12isDenseArrayEv($4);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = $16 - $newcap | 0;
    __ZN8JSObject14clearSlotRangeEjj($this, $newcap, $33);
    __label__ = 10;
    break;
   case 10:
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZNK8JSObject8isGlobalEv($4);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject($cx, $this);
    __label__ = 13;
    break;
   case 13:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($cx, $obj, $proto, $checkForCycles) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject8isNativeEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($1, $4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 3:
    var $7 = ($proto | 0) != 0;
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $cx;
    var $oldproto_0 = $obj;
    __label__ = 7;
    break;
   case 5:
    var $10 = $proto;
    var $11 = __ZNK8JSObject5isXMLEv($10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 6:
    var $13 = $cx;
    _JS_ReportErrorNumber($13, 2, 0, 272, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 7:
    var $oldproto_0;
    if (($oldproto_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = $oldproto_0;
    var $18 = __ZNK8JSObject8isNativeEv($17);
    if ($18) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN8JSObject16protoShapeChangeEP9JSContext($17, $8);
    var $20 = __ZNK8JSObject8getProtoEv($17);
    var $oldproto_0 = $20;
    __label__ = 7;
    break;
   case 10:
    if ($checkForCycles) {
      var $obj2_0 = $proto;
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $obj2_0;
    if (($obj2_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($obj2_0 | 0) == ($obj | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    _JS_ReportErrorNumber($8, 2, 0, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_proto_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 14:
    var $28 = __ZNK8JSObject8getProtoEv($obj2_0);
    var $obj2_0 = $28;
    __label__ = 11;
    break;
   case 15:
    var $30 = __ZNK8JSObject16hasSingletonTypeEv($1);
    if ($30) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $32 = $proto;
    var $33 = __ZN8JSObject15splicePrototypeEP9JSContextPS_($1, $8, $32);
    if ($33) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 17:
    var $35 = __ZNK8JSObject4typeEv($1);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($8, $35, 0);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 18:
    if ($7) {
      __label__ = 19;
      break;
    } else {
      var $42 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 20;
      break;
    }
   case 19:
    var $38 = $proto;
    var $39 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($38, $8, 0, 1);
    var $40 = $39;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $42 = $40;
      __label__ = 20;
      break;
    }
   case 20:
    var $42;
    var $43 = __ZNK8JSObject4typeEv($1);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($8, $43, 1);
    var $44 = $42;
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($8, $44, 1);
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($1, $44);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8SetProtoEP9JSContextP8JSObjectS3_b["X"] = 1;

function __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($cx, $obj, $key, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $resolving = __stackBase__ + 8;
    var $1 = __ZNK8JSObject9getGlobalEv($obj);
    var $2 = $1 | 0;
    var $3 = $1;
    var $4 = __ZNK8JSObject8isGlobalEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$objp >> 2] = 0;
    var $_1 = 1;
    __label__ = 12;
    break;
   case 3:
    __ZNK8JSObject15getReservedSlotEj($v, $3, $key);
    var $7 = __ZNK2JS5Value8isObjectEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$objp >> 2] = $9;
    var $_1 = 1;
    __label__ = 12;
    break;
   case 5:
    var $16 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($key << 2) >> 2] | 0;
    var $17 = __ZL12ATOM_TO_JSIDP6JSAtom2291($16);
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $2, $17, 0);
    var $18 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[$objp >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $22 = HEAP32[__ZL19lazy_prototype_init + ($key << 2) >> 2];
    var $23 = FUNCTION_TABLE[$22]($cx, $2);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZNK8JSObject15getReservedSlotEj($v, $3, $key);
    var $26 = __ZNK2JS5Value8isObjectEv($v);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $cobj_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZNK2JS5Value8toObjectEv($v);
    var $cobj_0 = $28;
    __label__ = 10;
    break;
   case 10:
    var $cobj_0;
    HEAP32[$objp >> 2] = $cobj_0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js13AutoResolvingD1Ev($resolving);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind) {
  __ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind);
  return;
}

function __ZNK2js13AutoResolving14alreadyStartedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 16 >> 2] | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = __ZNK2js13AutoResolving18alreadyStartedSlowEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoResolvingD1Ev($this) {
  __ZN2js13AutoResolvingD2Ev($this);
  return;
}

function __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $start, $protoKey, $vp, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $cobj = __stackBase__ + 4;
    var $pobj = __stackBase__ + 8;
    var $prop = __stackBase__ + 12;
    var $v = __stackBase__ + 16;
    if (($start | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $start;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = __ZNK9JSContext7maybefpEv($3);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $8 = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_1 = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $_1;
    HEAP32[$obj >> 2] = $_1;
    var $11 = __ZNK8JSObject9getParentEv($_1);
    var $12 = $11;
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $12;
      __label__ = 4;
      break;
    }
   case 5:
    var $15 = HEAP32[$cx + 132 >> 2];
    HEAP32[$obj >> 2] = $15;
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_pre_phi = $3;
      __label__ = 8;
      break;
    }
   case 6:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 7:
    var $_pre_phi = $cx;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $18 = $obj;
    __Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($_pre_phi, $18);
    var $19 = HEAP32[$obj >> 2];
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($protoKey | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($cx, $19, $protoKey, $cobj);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = HEAP32[$cobj >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $30 = $27;
    __ZN2JS5Value9setObjectER8JSObject($vp, $30);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 13:
    var $36 = HEAP32[HEAP32[$cx + 52 >> 2] + 210020 + ($protoKey << 2) >> 2] | 0;
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom2291($36);
    var $id_0 = $37;
    __label__ = 16;
    break;
   case 14:
    var $40 = HEAP32[$clasp >> 2];
    var $41 = _strlen($40);
    var $42 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($_pre_phi, $40, $41, 0, 0);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom2291($42);
    var $id_0 = $45;
    __label__ = 16;
    break;
   case 16:
    var $id_0;
    var $47 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $19, $id_0, 16, $pobj, $prop);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    __ZN2JSL14UndefinedValueEv2280($v);
    var $49 = HEAP32[$prop >> 2];
    if (($49 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $53 = HEAP32[$pobj >> 2];
    var $54 = __ZNK8JSObject8isNativeEv($53);
    if ($54) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $58 = HEAP32[$49 + 24 >> 2];
    var $59 = __ZNK8JSObject12containsSlotEj($53, $58);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $61 = __ZNK8JSObject13nativeGetSlotEj($53, $58);
    var $62 = $61 | 0;
    var $63$0 = HEAP32[$62 >> 2];
    var $63$1 = HEAP32[$62 + 4 >> 2];
    var $64 = $v | 0;
    HEAP32[$64 >> 2] = $63$0;
    HEAP32[$64 + 4 >> 2] = $63$1;
    var $65 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($65) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN2JS5Value12setUndefinedEv($v);
    __label__ = 22;
    break;
   case 22:
    var $67 = $v | 0;
    var $68$0 = HEAP32[$67 >> 2];
    var $68$1 = HEAP32[$67 + 4 >> 2];
    var $69 = $vp | 0;
    HEAP32[$69 >> 2] = $68$0;
    HEAP32[$69 + 4 >> 2] = $68$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE["X"] = 1;

function __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $1, $flags, $objp, $propp);
  return $2;
}

function __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($cx, $clasp, $proto, $parent, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argtvr = __stackBase__;
    var $tvr = __stackBase__ + 16;
    var $rval = __stackBase__ + 40;
    var $rval1 = __stackBase__ + 48;
    var $1 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($argtvr, $1, $argc, $argv);
    var $clasp_idx = $clasp + 4 | 0;
    var $clasp_idx_val = HEAP32[$clasp_idx >> 2];
    var $2 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_idx_val);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $1);
    var $3 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $4 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $parent, $2, $3, $clasp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $8 = __ZNK2JS5Value11isPrimitiveEv($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($1, $3, 65664);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 4:
    var $11 = __ZNK2JS5Value8toObjectEv($7);
    if (($parent | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_02 = $parent;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZNK8JSObject9getParentEv($11);
    var $_02 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_02;
    if (($proto | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_01 = $proto;
      __label__ = 10;
      break;
    }
   case 7:
    var $22 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $23 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($11, $1, $22, $rval);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = __ZNK2JS5Value14isObjectOrNullEv($rval);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_01 = $proto;
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZNK2JS5Value14toObjectOrNullEv($rval);
    var $_01 = $28;
    __label__ = 10;
    break;
   case 10:
    var $_01;
    var $31 = __ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353($cx, $clasp, $_01, $_02);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $31;
    __ZN8JSObject19syncSpecialEqualityEv($34);
    var $35 = $31;
    var $36 = __ZNK8JSObject4typeEv($35);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($1, $36, 0);
    var $37 = __ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($1, $35, $7, $argc, $argv, $rval1);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 12:
    var $39 = __ZNK2JS5Value11isPrimitiveEv($rval1);
    if ($39) {
      var $_0 = $31;
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = __ZNK2JS5Value8toObjectEv($rval1);
    var $42 = $41;
    var $43 = __ZNK8JSObject8getClassEv($41);
    if (($43 | 0) == ($clasp | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    if ((HEAP32[$clasp_idx >> 2] & 65 | 0) == 65) {
      __label__ = 15;
      break;
    } else {
      var $_0 = $42;
      __label__ = 17;
      break;
    }
   case 15:
    var $51 = __ZNK8JSObject10getPrivateEv($41);
    if (($51 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $_0 = $42;
      __label__ = 17;
      break;
    }
   case 16:
    var $55 = HEAP32[$clasp >> 2];
    _JS_ReportErrorNumber($1, 2, 0, 207, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $55, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    __ZN2js15AutoArrayRooterD1Ev($argtvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE["X"] = 1;

function __ZN8JSObject9allocSlotEP9JSContextPj($this, $cx, $slotp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZNK8JSObject8slotSpanEv($2);
    var $4 = __ZNK8JSObject16inDictionaryModeEv($2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[$this >> 2];
    var $9 = __ZNK2js5Shape8hasTableEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = __ZNK2js5Shape8getTableEv($8);
    var $12 = $11 + 12 | 0;
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) == -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$slotp >> 2] = $13;
    var $16 = __ZNK8JSObject7getSlotEj($2, $13);
    var $17 = __ZNK2JS5Value15toPrivateUint32Ev($16);
    HEAP32[$12 >> 2] = $17;
    __ZN2JSL14UndefinedValueEv2280($1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $13, $1);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $19 = __ZNK8JSObject8numSlotsEv($2);
    if ($3 >>> 0 < $19 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $3 + 1 | 0;
    var $23 = __ZN8JSObject9growSlotsEP9JSContextj($this, $cx, $22);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$slotp >> 2] = $3;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8freeSlotEP9JSContextj($this, $cx, $slot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $this;
    var $4 = __ZNK8JSObject8slotSpanEv($3);
    var $5 = __ZNK8JSObject16inDictionaryModeEv($3);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = HEAP32[$this >> 2];
    var $10 = __ZNK2js5Shape8hasTableEv($9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = __ZNK2js5Shape8getTableEv($9);
    var $13 = $12 + 12 | 0;
    var $14 = __ZNK8JSObject8getClassEv($3);
    if ((HEAPU32[$14 + 4 >> 2] >>> 8 & 255) >>> 0 <= $slot >>> 0 & ($slot + 1 | 0) >>> 0 < $4 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = HEAP32[$13 >> 2];
    __ZN2JSL18PrivateUint32ValueEj2384($1, $23);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $slot, $1);
    HEAP32[$13 >> 2] = $slot;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JSL14UndefinedValueEv2280($2);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, $slot, $2);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL18PrivateUint32ValueEj2384($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject8getProtoEv($1);
    var $3 = $2;
    var $4 = __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $3, $id);
    var $5 = $obj;
    var $6 = __ZNK8JSObject6isCallEv($5);
    if ($6) {
      var $_0 = $obj;
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0;
    var $8 = __ZNK8JSObject9getParentEv($_0);
    var $9 = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $9, $id);
    if (($12 | 0) == 0) {
      var $_0 = $9;
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15PurgeProtoChainP9JSContextP8JSObjecti($cx, $obj, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if (($_01 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $_01;
    var $6 = __ZNK8JSObject8isNativeEv($5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject8getProtoEv($5);
    var $_01_be_in = $8;
    __label__ = 5;
    break;
   case 5:
    var $_01_be_in;
    var $_01 = $_01_be_in;
    __label__ = 2;
    break;
   case 6:
    var $10 = __ZN8JSObject12nativeLookupEP9JSContexti($5, $1, $id);
    if (($10 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE($5, $1, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $14 = __ZNK8JSObject8getProtoEv($5);
    var $_01_be_in = $14;
    __label__ = 5;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($cx, $obj, $id, $getter, $setter, $slot, $attrs, $flags, $shortid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = $cx;
    var $3 = $obj;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($2, $3, $1);
    var $4 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($3, $2);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $getter;
    var $7 = $setter;
    var $8 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($3, $2, $1, $6, $7, $slot, $attrs, $flags, $shortid);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E($cx, $obj, $shape, $attrs, $mask, $getter, $setter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($attrs & 2 | 0) == 0) {
      var $_01 = $getter;
      var $_02 = $shape;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $shape;
    var $9 = __ZNK2js5Shape8isMethodEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $getter;
      var $_02 = $shape;
      __label__ = 7;
      break;
    }
   case 4:
    var $11 = __ZNK2js5Shape12methodObjectEv($8);
    var $12 = $11;
    __ZN2JSL11ObjectValueER8JSObject2354($v, $12);
    var $13 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($1, $2, $8, $v);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $getter;
    var $18 = __ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($17);
    if (($18 | 0) == ($11 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $getter;
      var $_02 = $14;
      __label__ = 7;
      break;
    }
   case 6:
    var $_01 = 0;
    var $_02 = $14;
    __label__ = 7;
    break;
   case 7:
    var $_02;
    var $_01;
    var $24 = $setter;
    var $25 = __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($1, $2, $_02, $attrs, $mask, $_01, $24);
    var $_0 = $25;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $value, $getter_coerce, $setter, $attrs) {
  var $1 = $getter_coerce;
  var $2 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $id, $value, $1, $setter, $attrs, 0, 0, 0);
  return ($2 | 0) != 0 & 1;
}

function __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $value, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $getter_coerce;
    var $5 = HEAP32[$id >> 2];
    var $6 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($cx, $obj, $5, $value, $4, $setter, $attrs, 0, 0, 0);
    var $_0 = ($6 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($this, $cx, $shape, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN8JSObject25brandedOrHasMethodBarrierEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $shape;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$shape + 24 >> 2];
    if (($5 | 0) == -1) {
      var $_0 = $shape;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject13nativeGetSlotEj($1, $5);
    var $9 = __ZL18ChangesMethodValueRKN2JS5ValueES2_($8, $v);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $shape;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $cx;
    var $12 = $shape;
    var $13 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($1, $11, $12);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $clasp_0_2_val, $obj, $shape, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nominal = __stackBase__;
    if (($clasp_0_2_val | 0) == 10) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $nominal | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    var $6 = $clasp_0_2_val;
    var $8 = HEAP32[$shape + 12 >> 2];
    var $9 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $6, $obj, $8, $vp);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $11 = __ZNK2JS5ValueneERKS0_($vp, $nominal);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[$shape + 24 >> 2];
    var $15 = $obj;
    var $16 = __ZNK8JSObject12containsSlotEj($15, $14);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = $shape;
    __ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE($15, $18, $19, $vp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $id, $flags, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $recursed = __stackBase__;
    var $1 = $cx;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = $_01;
    var $4 = __ZN8JSObject12nativeLookupEP9JSContexti($3, $1, $id);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$objp >> 2] = $_01;
    HEAP32[$propp >> 2] = $4;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 4:
    var $9 = __ZNK8JSObject8getClassEv($3);
    if ((HEAP32[$9 + 28 >> 2] | 0) == 186) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb($cx, $obj, $_01, $id, $flags, $objp, $propp, $recursed);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP8[$recursed] & 1) << 24 >> 24 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 8:
    var $24 = __ZNK8JSObject8getProtoEv($3);
    if (($24 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = $24;
    var $28 = __ZNK8JSObject8isNativeEv($24);
    if ($28) {
      var $_01 = $27;
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = $objp;
    var $31 = $propp;
    var $32 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($24, $1, $id, $30, $31);
    var $_0 = ($32 | 0) != 0;
    __label__ = 12;
    break;
   case 11:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $6 = HEAP32[$cx + 208 >> 2];
    var $7 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $obj, $4, $6, $objp, $propp);
    var $_0 = $7 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($cx, $id, $cacheResult, $global, $objp, $pobjp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = $cx + 60 | 0;
    var $2 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($1);
    if ($global) {
      __label__ = 2;
      break;
    } else {
      var $scopeChain_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject9getGlobalEv($2);
    var $scopeChain_0 = $4 | 0;
    __label__ = 3;
    break;
   case 3:
    var $scopeChain_0;
    var $7 = $scopeChain_0;
    var $8 = __ZNK8JSObject9getParentEv($7);
    var $9 = $cx + 208 | 0;
    var $scopeIndex_0 = 0;
    var $parent_0_in = $8;
    var $obj_0 = $scopeChain_0;
    __label__ = 4;
    break;
   case 4:
    var $obj_0;
    var $parent_0_in;
    var $scopeIndex_0;
    var $parent_0 = $parent_0_in;
    var $11 = ($parent_0_in | 0) != 0;
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj_0);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = $cx;
    var $15 = $pobj;
    var $16 = $prop;
    var $obj_1 = $obj_0;
    __label__ = 16;
    break;
   case 7:
    var $19 = __ZNK8JSObject6getOpsEv($obj_0);
    if ((HEAP32[$19 + 4 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 8:
    var $24 = HEAP32[$9 >> 2];
    var $25 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj_0, $id, $24, $pobj, $prop);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 9:
    var $27 = HEAP32[$prop >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($cacheResult) {
      __label__ = 11;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_0;
      var $61 = $27;
      __label__ = 21;
      break;
    }
   case 11:
    var $32 = HEAP32[$pobj >> 2];
    var $33 = __ZNK8JSObject8isNativeEv($32);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_0;
      var $61 = $27;
      __label__ = 21;
      break;
    }
   case 12:
    var $38 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $39 = $cx;
    var $40 = $27;
    var $41 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($38, $39, $7, $scopeIndex_0, $32, $40, 0);
    var $entry_0 = $41;
    var $obj_2 = $obj_0;
    var $61 = HEAP32[$prop >> 2];
    __label__ = 21;
    break;
   case 13:
    if ($11) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$pobj >> 2] = 0;
    var $entry_0 = 16;
    var $obj_2 = $obj_0;
    var $61 = $27;
    __label__ = 21;
    break;
   case 15:
    var $46 = __ZNK8JSObject9getParentEv($parent_0_in);
    var $scopeIndex_0 = $scopeIndex_0 + 1 | 0;
    var $parent_0_in = $46;
    var $obj_0 = $parent_0;
    __label__ = 4;
    break;
   case 16:
    var $obj_1;
    var $49 = $obj_1;
    var $50 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($49, $14, $id, $15, $16);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = HEAP32[$prop >> 2];
    if (($53 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $entry_0 = 16;
      var $obj_2 = $obj_1;
      var $61 = $53;
      __label__ = 21;
      break;
    }
   case 18:
    var $56 = __ZNK8JSObject9getParentEv($49);
    if (($56 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    HEAP32[$pobj >> 2] = 0;
    var $entry_0 = 16;
    var $obj_2 = $obj_1;
    var $61 = $53;
    __label__ = 21;
    break;
   case 20:
    var $obj_1 = $56;
    __label__ = 16;
    break;
   case 21:
    var $61;
    var $obj_2;
    var $entry_0;
    HEAP32[$objp >> 2] = $obj_2;
    var $62 = HEAP32[$pobj >> 2];
    HEAP32[$pobjp >> 2] = $62;
    HEAP32[$propp >> 2] = $61;
    var $_0 = $entry_0;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty["X"] = 1;

function __ZNK2js12ContextStack25currentScriptedScopeChainEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js12ContextStack2fpEv($1);
  var $3 = __ZNK2js10StackFrame10scopeChainEv($2);
  return $3;
}

function __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject6isCallEv($1);
    if ($2) {
      var $9 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = __ZNK8JSObject7isBlockEv($4);
    if ($5) {
      var $9 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject9isDeclEnvEv($4);
    var $9 = $7;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty($cx, $id, $global, $objp, $pobjp, $propp) {
  var $1 = __Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty($cx, $id, 0, $global, $objp, $pobjp, $propp);
  return ($1 | 0) != 0 & 1;
}

function __Z21js_FindIdentifierBaseP9JSContextP8JSObjecti($cx, $scopeChain, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $pobj1 = __stackBase__ + 8;
    var $prop2 = __stackBase__ + 12;
    var $1 = $cx + 208 | 0;
    var $scopeIndex_0 = 0;
    var $obj_0 = $scopeChain;
    __label__ = 2;
    break;
   case 2:
    var $obj_0;
    var $scopeIndex_0;
    var $3 = $obj_0;
    var $4 = __ZNK8JSObject9getParentEv($3);
    if (($4 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396($obj_0);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $cx;
    var $9 = $prop2;
    var $obj_1 = $obj_0;
    __label__ = 11;
    break;
   case 5:
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj_0, $id, $10, $pobj, $prop);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 6:
    var $13 = HEAP32[$prop >> 2];
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = HEAP32[$pobj >> 2];
    var $18 = __ZNK8JSObject8isNativeEv($17);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $obj_0;
      __label__ = 15;
      break;
    }
   case 8:
    var $23 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $24 = $cx;
    var $25 = $scopeChain;
    var $26 = $13;
    var $27 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($23, $24, $25, $scopeIndex_0, $17, $26, 0);
    var $_0 = $obj_0;
    __label__ = 15;
    break;
   case 9:
    var $29 = __ZNK8JSObject9getParentEv($3);
    if (($29 | 0) == 0) {
      var $_0 = $obj_0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $scopeIndex_0 = $scopeIndex_0 + 1 | 0;
    var $obj_0 = $29;
    __label__ = 2;
    break;
   case 11:
    var $obj_1;
    var $35 = $obj_1;
    var $36 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($35, $8, $id, $pobj1, $9);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$prop2 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = $obj_1;
      __label__ = 15;
      break;
    }
   case 13:
    var $42 = __ZNK8JSObject9getParentEv($35);
    var $43 = $42;
    if (($42 | 0) == 0) {
      var $_0 = $obj_1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $46 = __ZNK8JSObject9getParentEv($42);
    if (($46 | 0) == 0) {
      var $_0 = $43;
      __label__ = 15;
      break;
    } else {
      var $obj_1 = $43;
      __label__ = 11;
      break;
    }
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_FindIdentifierBaseP9JSContextP8JSObjecti["X"] = 1;

function __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $pobj, $shape, $getHow, $vp) {
  var $1 = __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $obj, $pobj, $shape, $getHow, $vp);
  return $1;
}

function __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $receiver, $pobj, $shape, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $2 = HEAP32[$shape + 24 >> 2];
    if (($2 | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $pobj;
    var $6 = __ZNK8JSObject13nativeGetSlotEj($5, $2);
    var $7 = $6 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 4:
    var $12 = $shape;
    var $13 = __ZNK2js5Shape16hasDefaultGetterEv($12);
    if ($13) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK2js5Shape8isMethodEv($12);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    if (($getHow & 2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 7:
    var $21 = $cx + 60 | 0;
    var $22 = __ZNK2js12ContextStack13currentScriptEPPh($21, $pc);
    if (($22 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZN8JSScript11hasAnalysisEv($22);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $27 = $cx;
    var $28 = __ZNK9JSContext2fpEv($27);
    var $29 = __ZNK2js10StackFrame11hasImacropcEv($28);
    if ($29) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = __ZN8JSScript8analysisEv($22);
    var $32 = HEAP32[$pc >> 2];
    var $33 = __ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh($31, $32);
    if (($33 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $33 + 1 | 0;
    var $39 = HEAP8[$37] | 64;
    HEAP8[$37] = $39;
    __label__ = 12;
    break;
   case 12:
    var $41 = $cx + 52 | 0;
    var $44 = HEAP32[HEAP32[$41 >> 2] + 144252 >> 2];
    var $45 = __ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE($shape, $cx, $receiver, undef, $pobj, $vp);
    if ($45) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $47 = $pobj;
    var $48 = __ZNK8JSObject12containsSlotEj($47, $2);
    if ($48) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 14:
    if ((HEAP32[HEAP32[$41 >> 2] + 144252 >> 2] | 0) == ($44 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($pobj, $cx, $shape);
    if ($55) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 16:
    var $57 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($pobj, $cx, $shape, $vp);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($47, $2, $vp);
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE["X"] = 1;

function __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $shape, $added, $strict, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$shape + 12 >> 2];
    var $3 = $cx;
    var $4 = $obj;
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($3, $4, $2, $vp);
    var $5 = $shape + 24 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $8 = $shape;
    if (($6 | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK2js5Shape16hasDefaultSetterEv($8);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    if ($added) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE($obj, $cx, $6, $vp);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 5:
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($4, $6, $vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 6:
    var $16 = __ZNK2js5Shape14hasGetterValueEv($8);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZNK2js5Shape16hasDefaultSetterEv($8);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $20 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = $20;
    __label__ = 16;
    break;
   case 9:
    var $22 = $cx + 52 | 0;
    var $25 = HEAP32[HEAP32[$22 >> 2] + 144252 >> 2];
    var $26 = __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($shape, $cx, $obj, $strict, $vp);
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $28 = HEAP32[$5 >> 2];
    var $29 = __ZNK8JSObject12containsSlotEj($4, $28);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 11:
    if ((HEAP32[HEAP32[$22 >> 2] + 144252 >> 2] | 0) == ($25 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($obj, $cx, $shape);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 13:
    if ($added) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $39 = __ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE($obj, $cx, $shape, $vp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($4, $28, $vp);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE($this, $cx, $slot, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN8JSObject25brandedOrHasMethodBarrierEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject13nativeGetSlotEj($1, $slot);
    var $5 = __ZL18ChangesMethodValueRKN2JS5ValueES2_($4, $v);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = __ZN8JSObject17methodShapeChangeEP9JSContextj($1, $7, $slot);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx) {
  var __stackBase__ = STACKTOP;
  var $1 = $cx;
  var $2 = _JS_ReportErrorFlagsAndNumber($1, 13, 2, 0, 160, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($this, $cx, $obj, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $3 = HEAPU8[$this + 28 | 0] & 255;
    if (($3 & 32 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZNK2js5Shape11setterValueEv($fval, $this);
    var $7 = $cx;
    var $8 = $obj;
    var $9 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($7, $8, $fval, 1, $vp, $vp);
    var $_0 = $9;
    __label__ = 11;
    break;
   case 3:
    if (($3 & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = ($14 | 0) != 0;
    __label__ = 11;
    break;
   case 5:
    var $17 = $obj;
    var $18 = __ZNK8JSObject6isWithEv($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $obj;
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __Z19js_UnwrapWithObjectP9JSContextP8JSObject(undef, $17);
    var $_01 = $20;
    __label__ = 7;
    break;
   case 7:
    var $_01;
    var $23 = __ZNK2js5Shape8setterOpEv($this);
    var $24 = __ZNK2js5Shape10hasShortIDEv($this);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $28 = HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $29 = _INT_TO_JSID2431($28);
    var $34 = $29;
    __label__ = 10;
    break;
   case 9:
    var $34 = HEAP32[$this + 12 >> 2];
    __label__ = 10;
    break;
   case 10:
    var $34;
    var $35 = $strict & 1;
    var $36 = __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $23, $_01, $34, $35, $vp);
    var $_0 = $36;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  var $2 = HEAP32[$shape + 12 >> 2];
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN8JSObject12nativeLookupEP9JSContexti($3, $4, $2);
  return ($5 | 0) == ($shape | 0);
}

function __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp) {
  var $1 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $obj, $id, $getHow, $vp);
  return $1;
}

function __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $id, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj2 = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __Z22js_CheckForStringIndexi($id);
    var $3 = $obj;
    var $4 = __Z23js_GetProtoIfDenseArrayP8JSObject($3);
    var $5 = $4;
    var $6 = $cx + 208 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty($cx, $5, $2, $7, $obj2, $prop);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 2:
    var $10 = HEAPU32[$prop >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $13 = __ZNK8JSObject8getClassEv($3);
    var $16 = HEAP32[$13 + 16 >> 2];
    var $17 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $16, $obj, $2, $vp);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 4:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $cx;
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($21, $3, $2, $vp);
    __label__ = 6;
    break;
   case 6:
    var $23 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 7:
    var $25 = $cx;
    var $26 = __Z23js_GetCurrentBytecodePCP9JSContext($25);
    if (($26 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = HEAPU8[$26];
    var $30 = $29 & 255;
    if ($29 << 24 >> 24 == 83) {
      __label__ = 9;
      break;
    } else {
      var $op_0 = $30;
      __label__ = 10;
      break;
    }
   case 9:
    var $33 = __ZNK9JSContext2fpEv($25);
    var $34 = __ZNK2js10StackFrame6scriptEv($33);
    var $35 = $34;
    var $36 = _JS_GetTrapOpcode(undef, $35, $26);
    var $op_0 = $36;
    __label__ = 10;
    break;
   case 10:
    var $op_0;
    if (($op_0 | 0) == 198) {
      var $flags_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = __ZNK9JSContext15hasStrictOptionEv($25);
    if ($40) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 12:
    var $43 = $cx + 60 | 0;
    var $44 = __ZNK2js12ContextStack13currentScriptEPPh($43, 0);
    if ((HEAP8[$44 + 37 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 13:
    if (($op_0 | 0) == 55 || ($op_0 | 0) == 53) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 14:
    var $55 = HEAP32[HEAP32[$cx + 52 >> 2] + 210244 >> 2] | 0;
    var $56 = __ZL12JSID_IS_ATOMiP6JSAtom2491($2, $55);
    if (($56 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 15:
    var $59 = HEAP32[$6 >> 2];
    if (($59 | 0) == 65535) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $65 = $26 + (HEAP8[_js_CodeSpec + ($op_0 << 3) | 0] << 24 >> 24) | 0;
    var $66 = __Z9DetectingP9JSContextPh($cx, $65);
    if (($66 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 17:
    if (($59 & 4 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 18:
    var $72 = __ZNK2js12ContextStack13currentScriptEPPh($43, 0);
    var $73 = $72 + 37 | 0;
    var $75 = HEAP8[$73] | 1;
    HEAP8[$73] = $75;
    var $flags_0 = 5;
    __label__ = 19;
    break;
   case 19:
    var $flags_0;
    __ZN2jsL9IdToValueEi2416($1, $2);
    var $77 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($25, $flags_0, 162, 0, $1, 0, 0, 0);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $_0 = 1;
    __label__ = 28;
    break;
   case 21:
    var $81 = HEAPU32[$obj2 >> 2];
    var $82 = $81;
    var $83 = __ZNK8JSObject8isNativeEv($82);
    if ($83) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $85 = __ZNK8JSObject7isProxyEv($82);
    var $86 = $cx;
    if ($85) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $88 = $receiver;
    var $89 = __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($86, $82, $88, $2, $vp);
    var $_0 = $89 & 1;
    __label__ = 28;
    break;
   case 24:
    var $92 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($82, $86, $2, $vp);
    var $_0 = $92;
    __label__ = 28;
    break;
   case 25:
    var $94 = $10;
    if (($getHow & 1 | 0) == 0) {
      var $106 = $81;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $101 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $102 = $cx;
    var $103 = $10;
    var $104 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($101, $102, $4, 0, $82, $103, 0);
    var $106 = HEAP32[$obj2 >> 2];
    __label__ = 27;
    break;
   case 27:
    var $106;
    var $107 = __ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE($cx, $receiver, $106, $94, $getHow, $vp);
    var $_0 = ($107 | 0) != 0 & 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE["X"] = 1;

function __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $1 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $id, 0, $vp);
  return $1;
}

function __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE($cx, $obj, $receiver, $4, 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_TO_STRING2421($iden) {
  return $iden;
}

function __ZeqRK8JSObjectS1_2422($lhs, $rhs) {
  return ($lhs | 0) == ($rhs | 0);
}

function __ZNK2js5Shape10hasShortIDEv($this) {
  return (HEAP8[$this + 29 | 0] & 64) << 24 >> 24 != 0;
}

function __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($cx, $obj, $id, $def, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $prop = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $1 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $id, 1, $obj2, $prop);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $def | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $11 = $cx;
    var $12 = HEAP32[$obj2 >> 2];
    var $13 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($11, $12, $id, $vp);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rf = __stackBase__;
    var $1 = $cx;
    __ZN18JSAutoResolveFlagsC1EP9JSContextj($rf, $1, 1);
    var $2 = $obj;
    var $3 = __ZNK8JSObject6getOpsEv($2);
    var $5 = HEAP32[$3 + 32 >> 2];
    var $6 = $5;
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, $getHow, $vp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZNK8JSObject5isXMLEv($2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $obj;
    var $15 = __Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE($13, $14, $id, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = FUNCTION_TABLE[$6]($cx, $obj, $obj, $id, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN18JSAutoResolveFlagsD1Ev($rf);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString($cx, $propname) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415($cx);
    if (($1 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZNK2js10StackFrame13isScriptFrameEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK2js10StackFrame6scriptEv($4);
    if ((HEAP8[$7 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = __ZNK9JSContext15hasStrictOptionEv($13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $16, $propname);
    var $17 = __ZNK16JSAutoByteStringntEv($bytes);
    if ($17) {
      var $24 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $20 = $cx;
    var $21 = _JS_ReportErrorFlagsAndNumber($20, 13, 2, 0, 156, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $19, tempInt));
    var $24 = ($21 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $24;
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = $24;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415($cx) {
  var $1 = $cx;
  var $2 = __ZNK9JSContext7maybefpEv($1);
  return $2;
}

function __ZN8JSObject14reportReadOnlyEP9JSContextij($this, $cx, $id, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2jsL9IdToValueEi2416($1, $id);
  var $2 = $cx;
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, $report, 19, 0, $1, 0, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN2jsL9IdToValueEi2416($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING2486($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING2421($id);
    __ZN2JSL11StringValueEP8JSString2480($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT2487($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT2488($id);
    __ZN2JSL10Int32ValueEi2332($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT2489($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT2490($id);
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject21reportNotConfigurableEP9JSContextij($this, $cx, $id, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2jsL9IdToValueEi2416($1, $id);
  var $2 = $cx;
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, $report, 21, 0, $1, 0, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN8JSObject19reportNotExtensibleEP9JSContextj($this, $cx, $report) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject2354($1, $this);
  var $2 = $cx;
  var $3 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($2, $report, 239, 0, $1, 0, 0, 0);
  var $4 = ($3 | 0) != 0;
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_($this, $cx, $id, $argc, $argv, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $this, $id, 2, $fval);
    if (($2 | 0) == 0) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $this);
    var $5 = $cx;
    var $6 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($5, $1, $fval, $argc, $argv, $vp);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($cx, $obj, $id, $defineHow, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $pd = __stackBase__ + 8;
    var $1 = __stackBase__ + 56;
    var $2 = __Z22js_CheckForStringIndexi($id);
    var $3 = __ZNK8JSObject7watchedEv($obj);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_02 = $defineHow;
      __label__ = 5;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 56 >> 2] + 1984 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $8;
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($11, $12, $13, $2, $vp);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 4:
    var $_02 = $defineHow & -5;
    __label__ = 5;
    break;
   case 5:
    var $_02;
    var $19 = HEAP32[$cx + 208 >> 2];
    var $20 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($cx, $obj, $2, $19, $pobj, $prop);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 6:
    var $22 = HEAPU32[$prop >> 2];
    if (($22 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$pobj >> 2];
    var $27 = __ZNK8JSObject8isNativeEv($26);
    if ($27) {
      var $78 = $22;
      __label__ = 26;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZNK8JSObject7isProxyEv($26);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $31 = $pd;
    var $32 = $cx;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($31, $32);
    var $phitmp = $pd + 16 | 0;
    var $35 = HEAP32[$pobj >> 2];
    var $36 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($32, $35, $2, 1, $phitmp);
    if ($36) {
      __label__ = 10;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $39 = HEAPU32[$pd + 20 >> 2];
    if (($39 & 192 | 0) == 64) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $44 = HEAP32[$pd + 28 >> 2];
    if (($44 | 0) == 0) {
      var $51 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = HEAP32[$pd + 40 >> 2];
    var $49 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($cx, $obj, $2, $44, $39, $48, $strict, $vp);
    var $51 = $49;
    __label__ = 13;
    break;
   case 13:
    var $51;
    var $_0_ph = $51 & 1;
    __label__ = 19;
    break;
   case 14:
    if (($39 & 2 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($strict | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = __ZN8JSObject14reportReadOnlyEP9JSContextij(undef, $cx, $2, 0);
    var $_0_ph = $59 & 1;
    __label__ = 19;
    break;
   case 17:
    var $62 = __ZNK9JSContext15hasStrictOptionEv($32);
    if ($62) {
      __label__ = 18;
      break;
    } else {
      var $_0_ph = 1;
      __label__ = 19;
      break;
    }
   case 18:
    var $64 = __ZN8JSObject14reportReadOnlyEP9JSContextij(undef, $cx, $2, 5);
    var $_0_ph = $64 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_0_ph;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($31);
    var $_1 = $_0_ph;
    __label__ = 73;
    break;
   case 20:
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($31);
    __label__ = 21;
    break;
   case 21:
    HEAP32[$prop >> 2] = 0;
    var $78 = 0;
    __label__ = 26;
    break;
   case 22:
    var $69 = $obj;
    var $70 = __ZNK8JSObject9getParentEv($69);
    if (($70 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $78 = $22;
      __label__ = 26;
      break;
    }
   case 23:
    if (($_02 & 8 | 0) == 0) {
      var $78 = $22;
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = _JSID_TO_STRING2421($2);
    var $77 = __Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString($cx, $76);
    if ($77) {
      __label__ = 25;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 25:
    var $78 = HEAP32[$prop >> 2];
    __label__ = 26;
    break;
   case 26:
    var $78;
    var $79 = $78;
    var $80 = $obj;
    var $81 = __ZNK8JSObject8getClassEv($80);
    var $84 = HEAP32[$81 + 16 >> 2];
    var $87 = HEAP32[$81 + 20 >> 2];
    if (($78 | 0) == 0) {
      var $shortid_310 = 0;
      var $flags_311 = 0;
      var $attrs_212 = 1;
      var $getter_213 = $84;
      var $setter_214 = $87;
      var $_316 = $_02;
      __label__ = 55;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $90 = $78;
    var $91 = __ZNK2js5Shape20isAccessorDescriptorEv($90);
    if ($91) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $93 = __ZNK2js5Shape16hasDefaultSetterEv($90);
    if ($93) {
      __label__ = 29;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $95 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_1 = $95;
    __label__ = 73;
    break;
   case 30:
    var $98 = __ZNK2js5Shape8writableEv($78);
    if ($98) {
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (($strict | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $102 = __ZN8JSObject14reportReadOnlyEP9JSContextij(undef, $cx, $2, 0);
    var $_1 = $102 & 1;
    __label__ = 73;
    break;
   case 33:
    var $105 = $cx;
    var $106 = __ZNK9JSContext15hasStrictOptionEv($105);
    if ($106) {
      __label__ = 34;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 34:
    var $108 = __ZN8JSObject14reportReadOnlyEP9JSContextij(undef, $cx, $2, 5);
    var $_1 = $108 & 1;
    __label__ = 73;
    break;
   case 35:
    var $110 = __ZNK2js5Shape10attributesEv($90);
    var $111 = $110 & 255;
    if ((HEAP32[$pobj >> 2] | 0) == ($obj | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $115 = __ZNK2js5Shape10shadowableEv($79);
    if ($115) {
      __label__ = 44;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    if (($_02 & 4 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $120 = __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp);
    if ($120) {
      __label__ = 39;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 39:
    if (($_02 & 1 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $129 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $130 = $cx;
    var $131 = HEAP32[$pobj >> 2];
    var $132 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($129, $130, $80, 0, $131, $90, 0);
    __label__ = 41;
    break;
   case 41:
    var $134 = __ZNK2js5Shape16hasDefaultSetterEv($90);
    if ($134) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $136 = __ZNK2js5Shape14hasGetterValueEv($90);
    if ($136) {
      __label__ = 43;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 43:
    var $138 = ($strict | 0) != 0;
    var $139 = __ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE($79, $cx, $obj, $138, $vp);
    var $_1 = $139 & 1;
    __label__ = 73;
    break;
   case 44:
    var $142 = __ZNK2js5Shape7hasSlotEv($90);
    if ($142) {
      var $shortid_310 = 0;
      var $flags_311 = 0;
      var $attrs_212 = 1;
      var $getter_213 = $84;
      var $setter_214 = $87;
      var $_316 = $_02;
      __label__ = 55;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $144 = $_02 & -5;
    var $145 = __ZNK2js5Shape10hasShortIDEv($79);
    if ($145) {
      __label__ = 46;
      break;
    } else {
      var $flags_0 = 0;
      var $shortid_0 = 0;
      __label__ = 47;
      break;
    }
   case 46:
    var $flags_0 = 64;
    var $shortid_0 = HEAP16[$79 + 30 >> 1] << 16 >> 16;
    __label__ = 47;
    break;
   case 47:
    var $shortid_0;
    var $flags_0;
    var $151 = $111 & 191;
    var $152 = __ZNK2js5Shape6getterEv($90);
    var $153 = $152;
    var $154 = __ZNK2js5Shape6setterEv($90);
    var $shortid_310 = $shortid_0;
    var $flags_311 = $flags_0;
    var $attrs_212 = $151;
    var $getter_213 = $153;
    var $setter_214 = $154;
    var $_316 = $144;
    __label__ = 55;
    break;
   case 48:
    if (($_02 & 4 | 0) == 0) {
      var $added_0 = 0;
      var $shape_3 = $79;
      var $_315 = $_02;
      __label__ = 70;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $160 = __ZNK2js5Shape8isMethodEv($90);
    if ($160) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $162 = __ZNK2js5Shape12methodObjectEv($90);
    var $163 = $162;
    var $164 = __ZNK2JS5Value8toObjectEv($vp);
    var $165 = $164;
    var $166 = __ZeqRK8JSObjectS1_2422($163, $165);
    if ($166) {
      var $177 = 1;
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $167 = $cx;
    var $168 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($80, $167, $90);
    if (($168 | 0) == 0) {
      var $_1 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $171 = __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp);
    if ($171) {
      __label__ = 53;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 53:
    var $173 = $168;
    var $174 = ($strict | 0) != 0;
    var $175 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $173, 0, $174, $vp);
    var $177 = ($175 | 0) != 0;
    __label__ = 54;
    break;
   case 54:
    var $177;
    var $_1 = $177 & 1;
    __label__ = 73;
    break;
   case 55:
    var $_316;
    var $setter_214;
    var $getter_213;
    var $attrs_212;
    var $flags_311;
    var $shortid_310;
    var $179 = __ZNK8JSObject12isExtensibleEv($80);
    if ($179) {
      __label__ = 60;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (($strict | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $183 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 0);
    var $_1 = $183 & 1;
    __label__ = 73;
    break;
   case 58:
    var $186 = $cx;
    var $187 = __ZNK9JSContext15hasStrictOptionEv($186);
    if ($187) {
      __label__ = 59;
      break;
    } else {
      var $_1 = 1;
      __label__ = 73;
      break;
    }
   case 59:
    var $189 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($obj, $cx, 5);
    var $_1 = $189 & 1;
    __label__ = 73;
    break;
   case 60:
    var $192 = $cx;
    __Z18js_PurgeScopeChainP9JSContextP8JSObjecti($192, $80, $2);
    var $193 = __ZN8JSObject24ensureClassReservedSlotsEP9JSContext($80, $192);
    if ($193) {
      __label__ = 61;
      break;
    } else {
      var $_1 = 0;
      __label__ = 73;
      break;
    }
   case 61:
    if (($_316 & 4 | 0) == 0) {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $198 = __ZNK8JSObject20canHaveMethodBarrierEv($80);
    if ($198) {
      __label__ = 63;
      break;
    } else {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    }
   case 63:
    var $200 = __ZNK2JS5Value8toObjectEv($vp);
    var $201 = __ZNK8JSObject18getFunctionPrivateEv($200);
    if (($201 | 0) == ($200 | 0)) {
      __label__ = 64;
      break;
    } else {
      var $getter_3 = $getter_213;
      var $flags_4 = $flags_311;
      __label__ = 65;
      break;
    }
   case 64:
    var $205 = $200;
    var $206 = $flags_311 | 128;
    var $207 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($205);
    var $getter_3 = $207;
    var $flags_4 = $206;
    __label__ = 65;
    break;
   case 65:
    var $flags_4;
    var $getter_3;
    var $211 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($80, $192, $2, $getter_3, $setter_214, -1, $attrs_212, $flags_4, $shortid_310);
    var $212 = $211;
    if (($211 | 0) == 0) {
      var $_1 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $216 = HEAP32[$211 + 24 >> 2];
    var $217 = __ZNK8JSObject12containsSlotEj($80, $216);
    if ($217) {
      __label__ = 67;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 67:
    __ZN2JSL14UndefinedValueEv2280($1);
    __ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE($80, $216, $1);
    __label__ = 68;
    break;
   case 68:
    var $_idx_val = HEAP32[$81 + 8 >> 2];
    var $221 = __ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE($cx, $_idx_val, $obj, $212, $vp);
    if ($221) {
      var $added_0 = 1;
      var $shape_3 = $212;
      var $_315 = $_316;
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $223 = __ZN8JSObject14removePropertyEP9JSContexti($80, $192, $2);
    var $_1 = 0;
    __label__ = 73;
    break;
   case 70:
    var $_315;
    var $shape_3;
    var $added_0;
    if (($_315 & 1 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $231 = HEAP32[$cx + 52 >> 2] + 144336 | 0;
    var $232 = $cx;
    var $234 = __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($231, $232, $80, 0, $80, $shape_3, $added_0 & 1);
    __label__ = 72;
    break;
   case 72:
    var $236 = ($strict | 0) != 0;
    var $237 = __Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE($cx, $obj, $shape_3, $added_0, $236, $vp);
    var $_1 = $237;
    __label__ = 73;
    break;
   case 73:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi["X"] = 1;

function __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($cx, $obj, $id, $op, $attrs, $shortid, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($attrs & 32 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $op;
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE($1, $5);
    var $6 = $cx;
    var $7 = $obj;
    var $8 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($6, $7, $1, 1, $vp, $vp);
    var $_0 = $8;
    __label__ = 8;
    break;
   case 3:
    if (($attrs & 16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __Z29js_ReportGetterOnlyAssignmentP9JSContext($cx);
    var $_0 = ($13 | 0) != 0;
    __label__ = 8;
    break;
   case 5:
    if (($attrs & 256 | 0) == 0) {
      var $_01 = $id;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = _INT_TO_JSID2431($shortid);
    var $_01 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_01;
    var $21 = __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $op, $obj, $_01, $strict, $vp);
    var $_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape10shadowableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape7hasSlotEv($1);
    if ($2) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP8[$this + 28 | 0] << 24 >> 24 < 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8toObjectEv($vp);
    var $2 = __ZNK8JSObject18getFunctionPrivateEv($1);
    if (($2 | 0) == ($1 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $cx;
    var $7 = __Z19CloneFunctionObjectP9JSContextP10JSFunction($6, $2);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi($cx, $obj, $index, $defineHow, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($cx, $obj, $4, $defineHow, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$attrsp >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 4:
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZNK8JSObject8isNativeEv($10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $cx;
    var $14 = __ZN8JSObject13getAttributesEP9JSContextiPj($10, $13, $id, $attrsp);
    var $_0 = $14;
    __label__ = 7;
    break;
   case 6:
    var $16 = $5;
    var $17 = __ZNK2js5Shape10attributesEv($16);
    var $18 = $17 & 255;
    HEAP32[$attrsp >> 2] = $18;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$attrsp >> 2] = 0;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 4:
    var $9 = HEAP32[$1 >> 2];
    var $10 = $9;
    var $11 = __ZNK8JSObject8isNativeEv($10);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZN8JSObject20getElementAttributesEP9JSContextjPj($9, $cx, $index, $attrsp);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 6:
    var $15 = $5;
    var $16 = __ZNK2js5Shape10attributesEv($15);
    var $17 = $16 & 255;
    HEAP32[$attrsp >> 2] = $17;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20getElementAttributesEP9JSContextjPj($this, $cx, $index, $attrsp) {
  var $1 = $this;
  var $2 = __ZNK8JSObject6getOpsEv($1);
  var $4 = HEAP32[$2 + 72 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 188;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $attrsp);
  return $8;
}

function __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $obj, $shape, $attrs) {
  var $1 = $shape;
  var $2 = __ZNK2js5Shape6getterEv($1);
  var $3 = $2;
  var $4 = __ZNK2js5Shape6setterEv($1);
  var $5 = $4;
  var $6 = __Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E($cx, $obj, $shape, $attrs, 0, $3, $5);
  return ($6 | 0) != 0 & 1;
}

function __Z16js_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$1 >> 2];
    var $9 = $8;
    var $10 = __ZNK8JSObject8isNativeEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $5;
    var $13 = HEAP32[$attrsp >> 2];
    var $14 = __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $8, $12, $13);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = $cx;
    var $17 = __ZN8JSObject13setAttributesEP9JSContextiPj($9, $16, $id, $attrsp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $prop = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $obj;
    var $2 = __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $1, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$prop >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAP32[$1 >> 2];
    var $9 = $8;
    var $10 = __ZNK8JSObject8isNativeEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $5;
    var $13 = HEAP32[$attrsp >> 2];
    var $14 = __Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj($cx, $8, $12, $13);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN8JSObject20setElementAttributesEP9JSContextjPj($8, $cx, $index, $attrsp);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject20setElementAttributesEP9JSContextjPj($this, $cx, $index, $attrsp) {
  var $1 = $this;
  var $2 = __ZNK8JSObject6getOpsEv($1);
  var $4 = HEAP32[$2 + 88 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 190;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $attrsp);
  return $8;
}

function _INT_TO_JSID2431($i) {
  return $i << 1 | 1;
}

function __ZN2jsL8JsvalifyEPNS_5ClassE2452($c) {
  return $c;
}

function __ZN2jsL8ValueifyEP7JSClass2453($c) {
  return $c;
}

function __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_0_11_val) {
  HEAP8[$cx_0_11_val + 144088 | 0] = 1;
  return;
}

function __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $funobj = __stackBase__ + 8;
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $proto, $prop);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$prop >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$proto >> 2] | 0) == ($obj | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $obj;
    var $12 = __ZNK8JSObject8getClassEv($11);
    var $15 = HEAP32[$12 + 12 >> 2];
    var $16 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $15, $obj, $1, $rval);
    var $_0 = $16 & 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = $5;
    var $20 = $5;
    var $21 = __ZNK2js5Shape12configurableEv($20);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($strict | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZN8JSObject21reportNotConfigurableEP9JSContextij(undef, $cx, $1, 0);
    var $_0 = $25 & 1;
    __label__ = 30;
    break;
   case 8:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 9:
    var $29 = $obj;
    var $30 = __ZNK8JSObject8getClassEv($29);
    var $33 = HEAP32[$30 + 12 >> 2];
    var $34 = __ZNK2js5Shape10hasShortIDEv($19);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $38 = HEAP16[$19 + 30 >> 1] << 16 >> 16;
    var $39 = _INT_TO_JSID2431($38);
    var $44 = $39;
    __label__ = 12;
    break;
   case 11:
    var $44 = HEAP32[$19 + 12 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $44;
    var $45 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $33, $obj, $44, $rval);
    if ($45) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 13:
    var $47 = __ZNK2JS5Value7isFalseEv($rval);
    if ($47) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = HEAP32[$19 + 24 >> 2];
    var $51 = __ZNK8JSObject12containsSlotEj($29, $50);
    if ($51) {
      __label__ = 15;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $53 = __ZNK8JSObject13nativeGetSlotEj($29, $50);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_idx_val);
    var $54 = __ZN8JSObject16hasMethodBarrierEv($29);
    if ($54) {
      __label__ = 16;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 16:
    var $56 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($53, $funobj);
    if ($56) {
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 17:
    var $58 = HEAP32[$funobj >> 2];
    var $59 = $58;
    var $60 = __ZNK8JSObject18getFunctionPrivateEv($59);
    if (($60 | 0) == ($58 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = $cx;
    var $65 = __ZNK9JSContext7maybefpEv($64);
    if (($65 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $fp_0_in2 = $65;
      __label__ = 19;
      break;
    }
   case 19:
    var $fp_0_in2;
    var $67 = __ZNK2js10StackFrame15isFunctionFrameEv($fp_0_in2);
    if ($67) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    var $69 = __ZNK2js10StackFrame6calleeEv($fp_0_in2);
    var $70 = $69;
    var $71 = __ZN10JSFunction14compiledFunObjEv($60);
    var $72 = $71;
    var $73 = __ZeqRK8JSObjectS1_2422($70, $72);
    if ($73) {
      __label__ = 21;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 21:
    var $75 = __ZNK2js10StackFrame9thisValueEv($fp_0_in2);
    var $76 = __ZNK2JS5Value8isObjectEv($75);
    if ($76) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    var $78 = __ZNK2JS5Value8toObjectEv($75);
    var $tmp_0_in = $78;
    __label__ = 23;
    break;
   case 23:
    var $tmp_0_in;
    if (($tmp_0_in | 0) == ($obj | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    __ZN2js10StackFrame15overwriteCalleeER8JSObject($fp_0_in2, $59);
    __label__ = 26;
    break;
   case 25:
    var $83 = __ZNK8JSObject8getProtoEv($tmp_0_in);
    if (($83 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $tmp_0_in = $83;
      __label__ = 23;
      break;
    }
   case 26:
    var $85 = __ZNK2js10StackFrame4prevEv($fp_0_in2);
    if (($85 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $fp_0_in2 = $85;
      __label__ = 19;
      break;
    }
   case 27:
    var $87 = $cx;
    var $88 = __ZN8JSObject14removePropertyEP9JSContexti($29, $87, $1);
    if ($88) {
      __label__ = 28;
      break;
    } else {
      var $94 = 0;
      __label__ = 29;
      break;
    }
   case 28:
    var $90 = $cx;
    var $91 = $obj;
    var $92 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($90, $91, $1);
    var $94 = $92;
    __label__ = 29;
    break;
   case 29:
    var $94;
    var $_0 = $94 & 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi["X"] = 1;

function __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $op, $receiver, $id, $vp) {
  var $1 = FUNCTION_TABLE[$op]($cx, $receiver, $id, $vp);
  return ($1 | 0) != 0;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $5 = __ZNK8JSObject10isFunctionEv($3);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $rval, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $methodid, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = $cx;
    var $3 = __ZN8JSObject12nativeLookupEP9JSContexti($1, $2, $methodid);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($3);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$3 + 24 >> 2];
    var $10 = __ZNK8JSObject12containsSlotEj($1, $9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject13nativeGetSlotEj($1, $9);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8getClassEv($2);
    var $4 = ($hint | 0) == 3;
    var $5 = ($3 | 0) == (__ZN2js11StringClassE | 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $7 = $cx + 52 | 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$7 >> 2] + 210324 >> 2] | 0;
    var $13 = __ZL12ATOM_TO_JSIDP6JSAtom2291($12);
    var $14 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11StringClassE, $13, 192);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $obj;
    var $17 = __ZNK8JSObject16getPrimitiveThisEv($16);
    var $18 = $17 | 0;
    var $st$3$0 = $18 | 0;
    var $19$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$3$1 >> 2];
    var $20 = $vp | 0;
    var $st$8$0 = $20 | 0;
    HEAP32[$st$8$0 >> 2] = $19$0;
    var $st$8$1 = $20 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 5:
    var $_pre_phi;
    var $24 = HEAP32[HEAP32[$_pre_phi >> 2] + 210324 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom2291($24);
    var $26 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $25, $vp);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 6:
    var $28 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($28) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $33 = HEAP32[HEAP32[$_pre_phi >> 2] + 210332 >> 2] | 0;
    var $34 = __ZL12ATOM_TO_JSIDP6JSAtom2291($33);
    var $35 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $34, $vp);
    if ($35) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 8:
    var $37 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($37) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 9:
    if ($5) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $44 = HEAP32[HEAP32[$cx + 52 >> 2] + 210332 >> 2] | 0;
    var $45 = __ZL12ATOM_TO_JSIDP6JSAtom2291($44);
    var $46 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11StringClassE, $45, 192);
    if ($46) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $49 = $cx + 52 | 0;
    if (($3 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_pre_phi3 = $49;
      __label__ = 14;
      break;
    }
   case 12:
    var $54 = HEAP32[HEAP32[$49 >> 2] + 210332 >> 2] | 0;
    var $55 = __ZL12ATOM_TO_JSIDP6JSAtom2291($54);
    var $56 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, __ZN2js11NumberClassE, $55, 194);
    if ($56) {
      __label__ = 13;
      break;
    } else {
      var $_pre_phi3 = $49;
      __label__ = 14;
      break;
    }
   case 13:
    var $58 = $obj;
    var $59 = __ZNK8JSObject16getPrimitiveThisEv($58);
    var $60 = $59 | 0;
    var $st$3$0 = $60 | 0;
    var $61$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $60 + 4 | 0;
    var $61$1 = HEAP32[$st$3$1 >> 2];
    var $62 = $vp | 0;
    var $st$8$0 = $62 | 0;
    HEAP32[$st$8$0 >> 2] = $61$0;
    var $st$8$1 = $62 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $61$1;
    var $_0 = 1;
    __label__ = 24;
    break;
   case 14:
    var $_pre_phi3;
    var $66 = HEAP32[HEAP32[$_pre_phi3 >> 2] + 210332 >> 2] | 0;
    var $67 = __ZL12ATOM_TO_JSIDP6JSAtom2291($66);
    var $68 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $67, $vp);
    if ($68) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 15:
    var $70 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($70) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $75 = HEAP32[HEAP32[$_pre_phi3 >> 2] + 210324 >> 2] | 0;
    var $76 = __ZL12ATOM_TO_JSIDP6JSAtom2291($75);
    var $77 = __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $76, $vp);
    if ($77) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 17:
    var $79 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($79) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ($4) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $83 = HEAP32[$3 >> 2];
    var $84 = $cx;
    var $85 = _JS_InternString($84, $83);
    if (($85 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $str_01 = $85;
    __label__ = 22;
    break;
   case 21:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    if (($hint | 0) == 0) {
      var $94 = STRING_TABLE.__str242227 | 0;
      var $str_02 = 0;
      __label__ = 23;
      break;
    } else {
      var $str_01 = 0;
      __label__ = 22;
      break;
    }
   case 22:
    var $str_01;
    var $94 = HEAP32[_js_common_atom_names + ($hint + 3 << 2) >> 2];
    var $str_02 = $str_01;
    __label__ = 23;
    break;
   case 23:
    var $str_02;
    var $94;
    var $95 = $cx;
    var $96 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($95, 0, 38, 1, $1, $str_02, $94, 0);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE["X"] = 1;

function __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE($cx, $obj, $clasp, $methodid, $native) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $methodid, $v);
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $obj;
    var $4 = __ZNK8JSObject8getProtoEv($3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject8getClassEv($4);
    if (($8 | 0) == ($clasp | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $5, $methodid, $v);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E($v, $native);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($cx, $obj, $id, 2, $vp);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL13js_IsCallableRKN2JS5ValueE2285($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($1, $obj);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL11ObjectValueER8JSObject2354($2, $obj);
    var $12 = $cx;
    var $13 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($12, $2, $vp, 0, 0, $vp);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject8getClassEv($1);
    var $4 = HEAP32[$2 + 24 >> 2];
    if ((HEAP32[$2 + 4 >> 2] & 2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $4;
    var $11 = FUNCTION_TABLE[$10]($cx, $obj, $enum_op, $statep, $idp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = $4;
    var $14 = FUNCTION_TABLE[$13]($cx, $obj);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value8setMagicE10JSWhyMagic($statep, 2);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_TypeOfP9JSContextP8JSObject($cx, $obj) {
  var $1 = $obj;
  var $2 = __ZN8JSObject10isCallableEv($1);
  var $3 = $2 ? 2 : 1;
  return $3;
}

function __Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE($cx, $obj, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($1) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $obj2_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $obj2_0;
    var $7 = __ZNK8JSObject8getProtoEv($obj2_0);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $obj2_0 = $8;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($cx, $scopeobj, $protoKey, $protop, $clasp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($cx, $scopeobj, $protoKey, $v, $clasp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($v);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8toObjectEv($v);
    var $10 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $11 = $cx;
    var $12 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($6, $11, $10, $v);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK2JS5Value8isObjectEv($v);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $20 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZNK2JS5Value8toObjectEv($v);
    var $20 = $17;
    __label__ = 6;
    break;
   case 6:
    var $20;
    HEAP32[$protop >> 2] = $20;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v);
    var $4 = __ZN2js12StringObject6createEP9JSContextP8JSString($cx, $3);
    var $_0 = $4 | 0;
    __label__ = 7;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isNumberEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toNumberEv($v);
    var $10 = __ZN2js12NumberObject6createEP9JSContextd($cx, $9);
    var $_0 = $10 | 0;
    __label__ = 7;
    break;
   case 5:
    var $13 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js12BooleanClassE);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = $13;
    __ZN8JSObject16setPrimitiveThisERKN2JS5ValueE($16, $v);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringObject6createEP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11StringClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject8asStringEv($1);
    var $5 = __ZN2js12StringObject4initEP9JSContextP8JSString($4, $cx, $str);
    var $_ = $5 ? $4 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12NumberObject6createEP9JSContextd($cx, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296($cx, __ZN2js11NumberClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZN8JSObject8asNumberEv($4);
    var $6 = $5;
    __ZN2js12NumberObject17setPrimitiveValueEd($5, $d);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value17isNullOrUndefinedEv($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value6isNullEv($vp);
    var $4 = $3 ? STRING_TABLE._js_null_str | 0 : STRING_TABLE._js_undefined_str | 0;
    var $5 = $cx;
    _JS_ReportErrorNumber($5, 2, 0, 38, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $4, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_object_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE($cx, $vp);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    __ZN2JS5Value9setObjectER8JSObject($vp, $10);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject($cx, $v, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$obj >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $cx;
    var $8 = __Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString($7, 1, $v, 0);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_XDRObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $atom = __stackBase__;
    var $classId = __stackBase__ + 4;
    var $classDef = __stackBase__ + 8;
    var $proto = __stackBase__ + 12;
    var $numBuf = __stackBase__ + 16;
    var $2 = HEAPU32[$xdr + 8 >> 2];
    HEAP32[$atom >> 2] = 0;
    var $3 = $xdr | 0;
    if ((HEAP32[$3 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $8 = HEAP32[$objp >> 2];
    var $9 = __ZNK8JSObject8getClassEv($8);
    var $10 = $9;
    var $11 = $9 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $xdr;
    var $14 = _JS_XDRFindClassIdByName($13, $12);
    HEAP32[$classId >> 2] = $14;
    var $15 = ($14 | 0) == 0;
    var $16 = $15 & 1;
    HEAP32[$classDef >> 2] = $16;
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $clasp_0 = $10;
      var $_pre_phi = $13;
      __label__ = 8;
      break;
    }
   case 3:
    var $18 = __ZN2jsL8JsvalifyEPNS_5ClassE2452($10);
    var $19 = $18;
    var $20 = _JS_XDRRegisterClass($13, $19, $classId);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAPU32[$9 + 4 >> 2];
    if ($24 >>> 0 < 16777216) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $30 = HEAP32[$classDef >> 2] | $24 >>> 23 & 510;
    HEAP32[$classDef >> 2] = $30;
    var $clasp_0 = $10;
    var $_pre_phi = $13;
    __label__ = 8;
    break;
   case 6:
    var $32 = HEAP32[$11 >> 2];
    var $33 = _strlen($32);
    var $34 = $2;
    var $35 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($34, $32, $33, 0, 0);
    HEAP32[$atom >> 2] = $35;
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $clasp_0 = $10;
      var $_pre_phi = $13;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$classDef >> 2] = 0;
    var $clasp_0 = 0;
    var $_pre_phi = $xdr;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $clasp_0;
    var $39 = _JS_XDRUint32($_pre_phi, $classDef);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$classDef >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $45 = $atom;
    var $46 = _js_XDRAtom($_pre_phi, $45);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $49 = _JS_XDRUint32($_pre_phi, $classId);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$3 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      var $clasp_1 = $clasp_0;
      __label__ = 18;
      break;
    }
   case 13:
    var $55 = HEAPU32[$classDef >> 2];
    if (($55 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $58 = $55 >>> 1;
    var $59 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, 0, $58, $proto, $clasp_0);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $63 = HEAP32[$proto >> 2];
    var $64 = __ZNK8JSObject8getClassEv($63);
    var $65 = $64;
    var $66 = __ZN2jsL8JsvalifyEPNS_5ClassE2452($65);
    var $67 = $66;
    var $68 = _JS_XDRRegisterClass($_pre_phi, $67, $classId);
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $clasp_1 = $65;
      __label__ = 18;
      break;
    }
   case 16:
    var $71 = HEAP32[$classId >> 2];
    var $72 = _JS_XDRFindClassById($_pre_phi, $71);
    var $73 = $72;
    var $74 = __ZN2jsL8ValueifyEP7JSClass2453($73);
    if (($74 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $clasp_1 = $74;
      __label__ = 18;
      break;
    }
   case 17:
    var $77 = $numBuf | 0;
    var $78 = _JS_snprintf($77, 12, STRING_TABLE.__str262229 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $71, tempInt));
    var $79 = $2;
    _JS_ReportErrorNumber($79, 2, 0, 40, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $77, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 18:
    var $clasp_1;
    var $82 = HEAP32[$clasp_1 + 56 >> 2];
    if (($82 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $86 = HEAP32[$clasp_1 >> 2];
    var $87 = $2;
    _JS_ReportErrorNumber($87, 2, 0, 41, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $86, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 20:
    var $89 = FUNCTION_TABLE[$82]($xdr, $objp);
    var $_0 = $89;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_XDRObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __Z14js_ClearNativeP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $obj;
    var $3 = $cx;
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZL21LastConfigurableShapeP8JSObject($obj);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 + 12 >> 2];
    var $10 = __ZN8JSObject14removePropertyEP9JSContexti($2, $3, $9);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject12lastPropertyEv($2);
    var $13 = $r;
    var $14 = $12;
    __ZNK2js5Shape3allEv($13, $14);
    var $15 = __ZNK2js5Shape5Range5emptyEv($13);
    if ($15) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $r;
    __label__ = 6;
    break;
   case 6:
    var $18 = __ZNK2js5Shape5Range5frontEv($16);
    var $19 = __ZNK2js5Shape16isDataDescriptorEv($18);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $21 = $18;
    var $22 = __ZNK2js5Shape8writableEv($21);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = __ZNK2js5Shape16hasDefaultSetterEv($18);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $27 = HEAP32[$18 + 24 >> 2];
    var $28 = __ZNK8JSObject12containsSlotEj($2, $27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN2JSL14UndefinedValueEv2280($1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $27, $1);
    __label__ = 11;
    break;
   case 11:
    __ZN2js5Shape5Range8popFrontEv($16);
    var $31 = __ZNK2js5Shape5Range5emptyEv($13);
    if ($31) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21LastConfigurableShapeP8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $obj;
    var $2 = __ZNK8JSObject12lastPropertyEv($1);
    var $3 = $r;
    var $4 = $2;
    __ZNK2js5Shape3allEv($3, $4);
    var $5 = $r;
    __label__ = 2;
    break;
   case 2:
    var $7 = __ZNK2js5Shape5Range5emptyEv($3);
    if ($7) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js5Shape5Range5frontEv($5);
    var $10 = $9;
    var $11 = __ZNK2js5Shape12configurableEv($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $9;
    __label__ = 6;
    break;
   case 5:
    __ZN2js5Shape5Range8popFrontEv($5);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE($cx, $obj, $slot, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject8isNativeEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 3:
    var $5 = __ZNK8JSObject8numSlotsEv($1);
    if ($5 >>> 0 > $slot >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK8JSObject7getSlotEj($1, $slot);
    var $9 = $8 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16js_InitNullClassP9JSContextP8JSObject($cx, $obj) {
  return 0;
}

function _JSID_IS_STRING2486($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_IS_INT2487($iden) {
  return $iden & 1;
}

function _JSID_TO_INT2488($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT2489($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT2490($iden) {
  return $iden & -8;
}

function __ZN8JSObject8asStringEv($this) {
  return $this;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape8setterOpEv($this) {
  return HEAP32[$this + 20 >> 2];
}

function __ZNK2js5Shape8getterOpEv($this) {
  return HEAP32[$this + 16 >> 2];
}

function __ZN2js13AutoResolvingD2Ev($this) {
  var $2 = HEAP32[$this + 16 >> 2];
  var $5 = HEAP32[$this >> 2] + 40 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE($this, $cx, $obj, $id, $kind) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  HEAP32[$this + 8 >> 2] = $id;
  HEAP32[$this + 12 >> 2] = $kind;
  var $6 = $cx + 40 | 0;
  var $7 = HEAP32[$6 >> 2];
  HEAP32[$this + 16 >> 2] = $7;
  HEAP32[$6 >> 2] = $this;
  return;
}

function __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($cx, $obj, $slot, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8isNativeEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8numSlotsEv($2);
    if ($5 >>> 0 > $slot >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject8getClassEv($2);
    var $12 = HEAPU32[$8 + 4 >> 2] >>> 8 & 255;
    var $13 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, $slot, $v);
    __ZN2JSL9NullValueEv2460($1);
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    __ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE($cx_idx_val);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv2460($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __Z25js_GetterOnlyPropertyStubP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  var $1 = $cx;
  _JS_ReportErrorNumber($1, 2, 0, 160, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_($beg, $end) {
  var $4 = $end - $beg >> 2;
  __ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j($beg, $4);
  return;
}

function __ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj32EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $8 = $6;
      __label__ = 3;
      break;
    }
   case 3:
    var $8;
    var $9 = $cx;
    var $10 = __Z16js_NewGCFunctionP9JSContext($9);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $19 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = $proto;
    var $16 = __ZNK8JSObject9getParentEv($15);
    var $19 = $16;
    __label__ = 6;
    break;
   case 6:
    var $19;
    var $20 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $21 = $10;
    var $22 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($21, undef, $22, $8, $19, 0, $20);
    var $25 = __ZNK2js5Class8isNativeEv($22);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $27 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $11, $clasp, $8, $kind);
    if ($27) {
      var $_0 = $11;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($21);
    var $_0 = $11;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 4;
    break;
   case 3:
    var $3 = $proto;
    var $4 = $cx;
    var $5 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($3, $4, 0, 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $8 = $6;
      var $_pre_phi = $4;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pre_phi;
    var $8;
    var $9 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $18 = $parent;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = $proto;
    var $15 = __ZNK8JSObject9getParentEv($14);
    var $18 = $15;
    __label__ = 7;
    break;
   case 7:
    var $18;
    var $19 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $20 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($9, undef, $20, $8, $18, 0, $19);
    var $23 = __ZNK2js5Class8isNativeEv($20);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $10, $clasp, $8, $kind);
    if ($25) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($9);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $6 = __ZNK8JSObject8numSlotsEv($5);
    if ($4 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $4);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = $type;
    var $12 = $clasp;
    var $13 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($11, $12);
    var $14 = $cx;
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($11, $14, $12, $kind);
    var $empty_0_in = $16;
    __label__ = 6;
    break;
   case 5:
    var $18 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($14, $12);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = $this;
  var $2 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2 + ($i << 2) | 0;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types15emptyTypeObjectE;
    var $13 = $_pr;
    var $_pre_phi = $cx;
    __label__ = 6;
    break;
   case 5:
    var $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $9, 0, 0);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $14 = $11;
      var $13 = $7;
      var $_pre_phi = $9;
      __label__ = 6;
      break;
    }
   case 6:
    var $_pre_phi;
    var $13;
    var $14;
    var $15 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $16 = $15;
    if (($15 | 0) == 0) {
      var $_0 = $16;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($parent | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $27 = $parent;
      __label__ = 10;
      break;
    }
   case 8:
    if (($13 | 0) == 0) {
      var $27 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __ZNK8JSObject9getParentEv($13);
    var $27 = $24;
    __label__ = 10;
    break;
   case 10:
    var $27;
    var $28 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $29 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($15, undef, $29, $14, $27, 0, $28);
    var $32 = __ZNK2js5Class8isNativeEv($29);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $34 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $16, $clasp, $14, $kind);
    if ($34) {
      var $_0 = $16;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    __ZN8JSObject21setSharedNonNativeMapEv($15);
    var $_0 = $16;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clasp_idx_val = HEAP32[$clasp + 4 >> 2];
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381($clasp_idx_val);
    var $2 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $parent, $1, $proto, $clasp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, $parent, 1, $proto, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471($cx, $clasp, $proto, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $proto;
    if (($proto | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = $proto;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470($cx, $clasp, $parent, $1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 3:
    var $_pr = HEAP32[$1 >> 2];
    if (($_pr | 0) == 0) {
      var $14 = __ZN2js5types15emptyTypeObjectE;
      var $13 = $_pr;
      __label__ = 5;
      break;
    } else {
      var $7 = $_pr;
      __label__ = 4;
      break;
    }
   case 4:
    var $7;
    var $9 = $cx;
    var $10 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $9, 0, 0);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $14 = $11;
      var $13 = $7;
      __label__ = 5;
      break;
    }
   case 5:
    var $13;
    var $14;
    var $15 = $cx;
    var $16 = __Z16js_NewGCFunctionP9JSContext($15);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = $17;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($parent | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $28 = $parent;
      __label__ = 9;
      break;
    }
   case 7:
    if (($13 | 0) == 0) {
      var $28 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = __ZNK8JSObject9getParentEv($13);
    var $28 = $25;
    __label__ = 9;
    break;
   case 9:
    var $28;
    var $29 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $30 = $16;
    var $31 = $clasp;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($30, undef, $31, $14, $28, 0, $29);
    var $34 = __ZNK2js5Class8isNativeEv($31);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $36 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468($cx, $17, $clasp, $14, $kind);
    if ($36) {
      var $_0 = $17;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN8JSObject21setSharedNonNativeMapEv($30);
    var $_0 = $17;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringObject4initEP9JSContextP8JSString($this, $cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$cx + 56 >> 2] + 800 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = $4;
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($7, $8);
    __label__ = 4;
    break;
   case 3:
    var $10 = $this;
    var $11 = $cx;
    var $12 = __ZN2js12StringObject18assignInitialShapeEP9JSContext($10, $11);
    HEAP32[$3 >> 2] = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js12StringObject13setStringThisEP8JSString($this, $str);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringObject13setStringThisEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 8;
  __ZN2JSL11StringValueEP8JSString2480($1, $str);
  var $3 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 0, $1);
  var $4 = __ZNK8JSString6lengthEv($str);
  __ZN2JSL10Int32ValueEi2332($2, $4);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($3, 1, $2);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL11StringValueEP8JSString2480($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E($v, $native) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483($v, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$fun >> 2];
    var $5 = __ZNK10JSFunction11maybeNativeEv($4);
    var $9 = ($5 | 0) == ($native | 0);
    __label__ = 3;
    break;
   case 3:
    var $9;
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483($v, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484($v, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484($v, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432($v, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$funobj >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($4);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_($cx, $op, $obj, $id, $strict, $vp) {
  var $1 = FUNCTION_TABLE[$op]($cx, $obj, $id, $strict, $vp);
  return ($1 | 0) != 0;
}

function __ZL12JSID_IS_ATOMiP6JSAtom2491($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom2291($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZNK2js5Shape11setterValueEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 20 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $3);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18ChangesMethodValueRKN2JS5ValueES2_($prev, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($prev);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($prev);
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $11 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($v);
    var $11 = ($8 | 0) != ($3 | 0);
    __label__ = 5;
    break;
   case 5:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE($this, $cx, $receiver, $obj, $pobj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = $this;
    var $2 = __ZNK2js5Shape14hasGetterValueEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js5Shape11getterValueEv($fval, $this);
    var $4 = $cx;
    var $5 = $receiver;
    var $6 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($4, $5, $fval, 0, 0, $vp);
    var $_0 = $6;
    __label__ = 9;
    break;
   case 3:
    var $8 = __ZNK2js5Shape8isMethodEv($1);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js5Shape12methodObjectEv($1);
    __ZN2JS5Value9setObjectER8JSObject($vp, $10);
    var $11 = $pobj;
    var $12 = $cx;
    var $13 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($11, $12, $1, $vp);
    var $_0 = ($13 | 0) != 0;
    __label__ = 9;
    break;
   case 5:
    var $16 = __ZNK2js5Shape8getterOpEv($this);
    var $17 = __ZNK2js5Shape10hasShortIDEv($this);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $22 = _INT_TO_JSID2431($21);
    var $27 = $22;
    __label__ = 8;
    break;
   case 7:
    var $27 = HEAP32[$this + 12 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $27;
    var $28 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($cx, $16, $receiver, $27, $vp);
    var $_0 = $28;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape11getterValueEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 16 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $3);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb($cx, $start, $obj, $id, $flags, $objp, $propp, $recursedp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $resolving = __stackBase__;
    var $obj2 = __stackBase__ + 20;
    var $1 = $obj;
    var $2 = __ZNK8JSObject8getClassEv($1);
    var $4 = HEAP32[$2 + 28 >> 2];
    var $5 = $4;
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $obj, $id, 0);
    var $6 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$recursedp] = 1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 3:
    HEAP8[$recursedp] = 0;
    HEAP32[$propp >> 2] = 0;
    var $9 = $2 + 4 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $4;
    if (($flags | 0) == 65535) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $flags;
      var $19 = $10;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __Z13js_InferFlagsP9JSContextj($cx, 0);
    var $_01 = $17;
    var $19 = HEAP32[$9 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $19;
    var $_01;
    var $22 = ($19 & 32 | 0) != 0 ? $start : 0;
    HEAP32[$obj2 >> 2] = $22;
    var $23 = FUNCTION_TABLE[$14]($cx, $obj, $id, $_01, $obj2);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$obj2 >> 2];
    if (($26 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = $26;
    var $30 = __ZNK8JSObject8isNativeEv($29);
    if ($30) {
      var $_02 = $26;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = $cx;
    var $33 = $objp;
    var $34 = $propp;
    var $35 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($29, $32, $id, $33, $34);
    var $_0 = $35;
    __label__ = 14;
    break;
   case 10:
    var $37 = FUNCTION_TABLE[$5]($cx, $obj, $id);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $_02 = $obj;
      __label__ = 11;
      break;
    }
   case 11:
    var $_02;
    var $40 = $_02;
    var $41 = __ZNK8JSObject11nativeEmptyEv($40);
    if ($41) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = $cx;
    var $44 = __ZN8JSObject12nativeLookupEP9JSContexti($40, $43, $id);
    if (($44 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$objp >> 2] = $_02;
    HEAP32[$propp >> 2] = $44;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js13AutoResolvingD1Ev($resolving);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb["X"] = 1;

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj2517($bits) {
  return $bits;
}

function __ZNK2js8PropDesc16isDataDescriptorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP8[$this + 33 | 0];
    if (($2 & 4) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = ($2 & 8) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc20isAccessorDescriptorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP8[$this + 33 | 0];
    if (($2 & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = ($2 & 2) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc11getterValueEv($this) {
  return $this + 16 | 0;
}

function __ZNK2js8PropDesc11setterValueEv($this) {
  return $this + 24 | 0;
}

function __ZNK2js8PropDesc8writableEv($this) {
  return (HEAP8[$this + 32 | 0] & 2) << 24 >> 24 == 0;
}

function __ZNK2js8PropDesc12configurableEv($this) {
  return (HEAP8[$this + 32 | 0] & 4) << 24 >> 24 == 0;
}

function __ZNK2js8PropDesc10enumerableEv($this) {
  return (HEAP8[$this + 32 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript($this, $cx, $fun, $script) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $fun;
  HEAP32[$this + 8 >> 2] = $script;
  return;
}

function __ZN15EvalScriptGuard11foundScriptEv($this) {
  return (HEAP32[$this + 12 >> 2] | 0) != 0;
}

function __ZN15EvalScriptGuard12setNewScriptEP8JSScript($this, $script) {
  HEAP32[$this + 12 >> 2] = $script;
  var $2 = $script + 37 | 0;
  var $4 = HEAP8[$2] | 64;
  HEAP8[$2] = $4;
  return;
}

function __ZNK15EvalScriptGuard6scriptEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN8JSObject17TradeGutsReservedD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 52 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    __label__ = 3;
    break;
   case 3:
    var $8 = HEAP32[$this + 56 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    __ZN9JSContext5free_EPv(undef, $11);
    __label__ = 5;
    break;
   case 5:
    var $14 = $this + 28 | 0;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($14);
    var $16 = $this + 4 | 0;
    __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev($16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17TradeGutsReservedC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  HEAP32[$this >> 2] = $cx;
  var $4 = $this + 4 | 0;
  var $5 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $5);
  var $6 = $4;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($6, $1);
  var $7 = $this + 28 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($2, $5);
  var $8 = $7;
  __ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_($8, $2);
  HEAP32[$this + 52 >> 2] = 0;
  HEAP32[$this + 56 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js15AutoShapeVectorD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev($1);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev($1);
  var $2 = $this;
  __ZN2js12AutoGCRooterD2Ev($2);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoShapeVectorC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti($1, $cx, -4);
  return;
}

function __ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti($this, $cx, $tag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this;
  var $3 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($2, $3, $tag);
  var $4 = $this + 12 | 0;
  var $5 = $1;
  __ZN2js15TempAllocPolicyC1EP9JSContext($5, $3);
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_($4, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj32EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 8;
  STACKTOP = __stackBase__;
  return;
}

function __Z23js_LiveFrameIfGeneratorPN2js10StackFrameE($fp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js10StackFrame16isGeneratorFrameEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $10 = $fp;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $fp;
    var $5 = __Z27js_FloatingFrameToGeneratorPN2js10StackFrameE($4);
    var $6 = $5;
    var $7 = __ZN11JSGenerator9liveFrameEv($6);
    var $10 = $7;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject15getFixedSlotRefEj($this, $slot) {
  var $1 = $this;
  var $2 = __ZNK8JSObject10fixedSlotsEv($1);
  return $2 + ($slot << 3) | 0;
}

function __ZNK8JSObject11getWithThisEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject12getFixedSlotEj($1, 1);
  var $3 = __ZNK2JS5Value8toObjectEv($2);
  return $3;
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $11 = $clasp;
    var $12 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, $11, $3, $12, 0, $10);
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, $11, $kind);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $13 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $16);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject($cx, $argc, $vp, $method, $objp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    _JS_ReportErrorNumber($3, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $method, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value8isObjectEv($5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_idx = $5 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $8 = __ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290($cx, $_idx_val$0, $_idx_val$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cx;
    _JS_ReportErrorNumber($11, 2, 0, 222, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str2433396 | 0, tempInt));
    _JS_free(undef, $8);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $13 = __ZNK2JS5Value8toObjectEv($5);
    HEAP32[$objp >> 2] = $13;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMi2511($id) {
  var $1 = _JSID_IS_STRING2486($id);
  return $1;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2335($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465($cx, __ZN2js11ObjectClassE, $proto, $parent, $4);
  return $5;
}

function __ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv($cx, $obj, $id, $0, $nvp, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $resolving = __stackBase__;
    var $argv = __stackBase__ + 20;
    var $2 = __stackBase__ + 44;
    var $3 = __stackBase__ + 52;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $4 = $closure;
    var $5 = $closure;
    var $6 = $cx;
    var $7 = __ZN8JSObject10principalsEP9JSContext($5, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $cx + 60 | 0;
    var $12 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $12;
    var $16 = __ZN8JSObject10principalsEP9JSContext($15, $6);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $16;
    var $22 = HEAP32[$7 + 20 >> 2];
    var $23 = FUNCTION_TABLE[$22]($8, $19);
    if (($23 | 0) == 0) {
      var $_1 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE($resolving, $cx, $obj, $id, 1);
    var $26 = __ZNK2js13AutoResolving14alreadyStartedEv($resolving);
    if ($26) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $argv | 0;
    __ZN2jsL9IdToValueEi2416($28, $id);
    var $_04 = $argv + 8 | 0;
    HEAP32[$_04 >> 2] = $tmp$0;
    HEAP32[$_04 + 4 >> 2] = $tmp$1;
    var $29 = $nvp | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $argv + 16 | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    __ZN2JSL11ObjectValueER8JSObject2354($2, $obj);
    __ZN2JSL17ObjectOrNullValueEP8JSObject2355($3, $4);
    var $32 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($6, $2, $3, 3, $28, $nvp);
    var $_0 = $32 & 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js13AutoResolvingD1Ev($resolving);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv["X"] = 1;

function __ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515($t) {
  var $1 = $t;
  _memset($1, 0, 32, 1);
  return;
}

function __ZNK2js8PropDesc19isGenericDescriptorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8PropDesc20isAccessorDescriptorEv($this);
    if ($1) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js8PropDesc16isDataDescriptorEv($this);
    var $6 = $3 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc6getterEv($this) {
  var $1 = __ZNK2js8PropDesc12getterObjectEv($this);
  var $2 = __ZN2jsL16CastAsPropertyOpEP8JSObject2286($1);
  return $2;
}

function __ZNK2js8PropDesc6setterEv($this) {
  var $1 = __ZNK2js8PropDesc12setterObjectEv($this);
  var $2 = __ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289($1);
  return $2;
}

function __ZNK2js5Shape17getterOrUndefinedEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape14hasGetterValueEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $6);
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape17setterOrUndefinedEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape14hasSetterValueEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 20 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL11ObjectValueER8JSObject2354($agg_result, $6);
    __label__ = 5;
    break;
   case 4:
    __ZN2JSL14UndefinedValueEv2280($agg_result);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6RejectP9JSContextjbiPb($cx, $throwError, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $idstr = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $bytes = __stackBase__ + 12;
    if ($throwError) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZN2jsL9IdToValueEi2416($1, $id);
    var $3 = $cx;
    var $4 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($3, $1, $idstr);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $6 = HEAP32[$idstr >> 2];
    var $7 = _JSID_TO_STRING2421($6);
    var $8 = $cx;
    __ZN16JSAutoByteStringC1EP9JSContextP8JSString($bytes, $8, $7);
    var $9 = __ZNK16JSAutoByteStringntEv($bytes);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($3, 2, 0, 240, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_1 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP8[$rval] = 0;
    var $_1 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc12setterObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($1);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8PropDesc12getterObjectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 16 | 0;
    var $2 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($1);
    var $7 = $4;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling) {
  __ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling);
  return;
}

function __ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString($this, $cx, $str) {
  __ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString($this, $cx, $str);
  return;
}

function __ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject($this, $caller, $staticLevel, $principals, $scopeobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $4 = HEAP32[$this + 4 >> 2];
    var $6 = HEAP32[$this + 8 >> 2];
    var $7 = __ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript($2, $4, $caller, $staticLevel, $principals, $scopeobj, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$1 >> 2];
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($10, $7, 0);
    var $11 = $this + 12 | 0;
    HEAP32[$11 >> 2] = $7;
    var $12 = $7 + 37 | 0;
    var $14 = HEAP8[$12] & 127;
    HEAP8[$12] = $14;
    var $16 = HEAP32[$11 >> 2] + 37 | 0;
    var $18 = HEAP8[$16] | 64;
    HEAP8[$16] = $18;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN15EvalScriptGuardD1Ev($this) {
  __ZN15EvalScriptGuardD2Ev($this);
  return;
}

function __ZN15EvalScriptGuardD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($6, $2);
    var $8 = HEAP32[$1 >> 2] + 37 | 0;
    var $10 = HEAP8[$8] & -65;
    HEAP8[$8] = $10;
    var $12 = HEAP32[$1 >> 2] + 37 | 0;
    var $14 = HEAP8[$12] | -128;
    HEAP8[$12] = $14;
    var $15 = $this + 8 | 0;
    var $19 = HEAP32[$1 >> 2] + 84 | 0;
    var $_c = HEAP32[HEAP32[$15 >> 2] >> 2];
    HEAP32[$19 >> 2] = $_c;
    var $20 = HEAP32[$1 >> 2];
    var $21 = HEAP32[$15 >> 2];
    HEAP32[$21 >> 2] = $20;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript($cx, $str, $caller, $staticLevel, $principals, $scopeobj, $bucket) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext11findVersionEv($1);
    var $3 = $caller;
    var $4 = ($principals | 0) == 0;
    var $5 = $principals + 20 | 0;
    var $scriptp_0 = $bucket;
    var $count_0 = 1;
    __label__ = 2;
    break;
   case 2:
    var $count_0;
    var $scriptp_0;
    var $7 = HEAPU32[$scriptp_0 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAPU16[$7 + 36 >> 1];
    if (($12 & 2) << 16 >> 16 == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAPU16[$7 + 46 >> 1] & 65535 | 0) == ($staticLevel | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 5:
    var $21 = $7;
    var $22 = __ZNK8JSScript10getVersionEv($21);
    if (($22 | 0) == ($2 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    if (($12 & 512) << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 7:
    var $28 = $7 + 76 | 0;
    var $29 = HEAP32[$28 >> 2];
    if (($29 | 0) == ($principals | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 | ($29 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = HEAP32[$5 >> 2];
    var $35 = FUNCTION_TABLE[$34]($principals, $29);
    if (($35 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$28 >> 2];
    var $40 = HEAP32[$38 + 20 >> 2];
    var $41 = FUNCTION_TABLE[$40]($38, $principals);
    if (($41 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZN8JSScript17getCallerFunctionEv($7);
    var $45 = __ZNK2js10StackFrame3funEv($3);
    if (($44 | 0) == ($45 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 12:
    var $52 = HEAP32[HEAP32[$7 + 56 >> 2] >> 2] | 0;
    if (($52 | 0) == ($str | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $55 = __ZN2js12EqualStringsEP14JSLinearStringS1_($52, $str);
    if ($55) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $57 = __ZN8JSScript7objectsEv($21);
    var $58 = $57;
    if ((HEAP32[$57 + 4 >> 2] | 0) == 1) {
      __label__ = 15;
      break;
    } else {
      var $i_0_ph = 1;
      var $objarray_0_ph = $58;
      __label__ = 17;
      break;
    }
   case 15:
    var $64 = HEAP8[$7 + 18 | 0];
    var $65 = __ZN8JSScript13isValidOffsetEh($64);
    if ($65) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $67 = $7;
    var $68 = __ZN8JSScript7regexpsEv($67);
    var $i_0_ph = 0;
    var $objarray_0_ph = $68;
    __label__ = 17;
    break;
   case 17:
    var $objarray_0_ph;
    var $i_0_ph;
    var $75 = HEAP32[HEAP32[$objarray_0_ph >> 2] + ($i_0_ph << 2) >> 2];
    var $76 = __ZNK8JSObject9getParentEv($75);
    if (($76 | 0) == ($scopeobj | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $79 = $7 + 84 | 0;
    var $81 = HEAP32[$79 >> 2];
    HEAP32[$scriptp_0 >> 2] = $81;
    HEAP32[$79 >> 2] = 0;
    var $_0 = $7;
    __label__ = 21;
    break;
   case 19:
    if (($count_0 | 0) == 4) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $scriptp_0 = $7 + 84 | 0;
    var $count_0 = $count_0 + 1 | 0;
    __label__ = 2;
    break;
   case 21:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript["X"] = 1;

function __ZN8JSScript17getCallerFunctionEv($this) {
  var $1 = $this;
  var $2 = __ZN8JSScript11getFunctionEj($1, 0);
  return $2;
}

function __ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString($this, $cx, $str) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $str;
  HEAP32[$this + 12 >> 2] = 0;
  var $4 = __ZL13EvalCacheHashP9JSContextP14JSLinearString($cx, $str);
  HEAP32[$this + 8 >> 2] = $4;
  return;
}

function __ZL13EvalCacheHashP9JSContextP14JSLinearString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $str | 0;
    var $2 = __ZNK8JSString6lengthEv($1);
    var $n_0 = $2 >>> 0 > 100 ? 100 : $2;
    if (($n_0 | 0) == 0) {
      var $h_0_lcssa = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK14JSLinearString5charsEv($str);
    var $s_01 = $5;
    var $n_12 = $n_0;
    var $h_03 = 0;
    __label__ = 3;
    break;
   case 3:
    var $h_03;
    var $n_12;
    var $s_01;
    var $12 = HEAPU16[$s_01 >> 1] & 65535 ^ ($h_03 << 4 | $h_03 >>> 28);
    var $14 = $n_12 - 1 | 0;
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $s_01 = $s_01 + 2 | 0;
      var $n_12 = $14;
      var $h_03 = $12;
      __label__ = 3;
      break;
    }
   case 4:
    var $h_0_lcssa = ($12 * -1640531527 | 0) >>> 26;
    __label__ = 5;
    break;
   case 5:
    var $h_0_lcssa;
    return HEAP32[$cx + 56 >> 2] + 452 + ($h_0_lcssa << 2) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($this, $cx, $data, $length, $parsingMode, $errorHandling) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  __ZN7mozilla9RangedPtrIKtEC1EPS1_j($2, $data, undef);
  var $3 = $this + 8 | 0;
  var $4 = $data + ($length << 1) | 0;
  __ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j($3, $4, undef, undef);
  HEAP32[$this + 24 >> 2] = $parsingMode;
  HEAP32[$this + 28 >> 2] = $errorHandling;
  return;
}

function __Z13js_json_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $reviver = __stackBase__ + 4;
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = $cx;
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = __ZN8JSString12ensureLinearEP9JSContext($5, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2];
    var $15 = $14 | 0;
    var $16 = $14 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $16);
    var $linear_02 = $15;
    var $25 = $16;
    __label__ = 7;
    break;
   case 5:
    var $18 = $9 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $18);
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $linear_02 = $9;
      var $25 = $18;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = $vp + 24 | 0;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $reviver | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $linear_01 = $9;
    var $27 = $18;
    __label__ = 8;
    break;
   case 7:
    var $25;
    var $linear_02;
    __ZN2JSL14UndefinedValueEv2537($reviver);
    var $linear_01 = $linear_02;
    var $27 = $25;
    __label__ = 8;
    break;
   case 8:
    var $27;
    var $linear_01;
    var $28 = __ZNK14JSLinearString5charsEv($linear_01);
    var $29 = __ZNK8JSString6lengthEv($27);
    var $30 = __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($cx, $28, $29, $reviver, $vp, 0);
    var $_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv2537($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode($cx, $chars, $length, $reviver, $vp, $decodingMode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parser = __stackBase__;
    var $1 = ($decodingMode | 0) != 0 & 1;
    var $2 = $parser;
    var $3 = $cx;
    __ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE($2, $3, $chars, $length, $1, 0);
    var $4 = $parser;
    var $5 = __ZN10JSONParser5parseEPN2JS5ValueE($4, $vp);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $7 = __ZL13js_IsCallableRKN2JS5ValueE2550($reviver);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZL6ReviveP9JSContextRKN2JS5ValueEPS2_($cx, $reviver, $vp);
    var $_0 = $9 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_json_stringifyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $space = __stackBase__ + 8;
    var $sb = __stackBase__ + 16;
    var $2 = __stackBase__ + 96;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv2537($1);
    var $4 = $1 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $vp | 0;
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = $5$0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $5$1;
    var $26 = 0;
    __label__ = 8;
    break;
   case 3:
    var $8 = $vp + 16 | 0;
    var $st$1$0 = $8 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $8 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = $1 | 0;
    var $st$6$0 = $10 | 0;
    HEAP32[$st$6$0 >> 2] = $9$0;
    var $st$6$1 = $10 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $9$1;
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $9$0;
    HEAP32[$11 + 4 >> 2] = $9$1;
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $14 = $vp + 24 | 0;
    var $15 = __ZNK2JS5Value8isObjectEv($14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $20 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZNK2JS5Value8toObjectEv($14);
    var $20 = $17;
    __label__ = 6;
    break;
   case 6:
    var $20;
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      var $26 = $20;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $vp + 32 | 0;
    var $st$1$0 = $23 | 0;
    var $24$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $23 + 4 | 0;
    var $24$1 = HEAPU32[$st$1$1 >> 2];
    var $25 = $space | 0;
    var $st$6$0 = $25 | 0;
    HEAP32[$st$6$0 >> 2] = $24$0;
    var $st$6$1 = $25 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $24$1;
    var $29 = $20;
    var $28$1 = $24$1;
    var $28$0 = $24$0;
    __label__ = 9;
    break;
   case 8:
    var $26;
    __ZN2JSL14UndefinedValueEv2537($space);
    var $_phi_trans_insert = $space | 0;
    var $29 = $26;
    var $28$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $28$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 9;
    break;
   case 9:
    var $28$0;
    var $28$1;
    var $29;
    var $30 = $sb;
    var $31 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($30, $31);
    var $32 = $2 | 0;
    var $st$7$0 = $32 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $32 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    var $33 = __Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE($cx, $vp, $29, $2, $sb);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = __ZNK2js12StringBuffer5emptyEv($30);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = $sb;
    var $39 = __ZN2js12StringBuffer12finishStringEv($38);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $42 = $39 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $42);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js12StringBufferD1Ev($30);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_json_stringifyP9JSContextjPN2JS5ValueE["X"] = 1;

function _INT_FITS_IN_JSID2543($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _INT_TO_JSID2544($i) {
  return $i << 1 | 1;
}

function __ZN2js2gcL15GetGCObjectKindEjb2555($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE($cx, $vp, $replacer, $0, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 284;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $space = __stackBase__;
    var $propertyList = __stackBase__ + 8;
    var $len = __stackBase__ + 68;
    var $idSet = __stackBase__ + 72;
    var $2 = __stackBase__ + 100;
    var $v = __stackBase__ + 104;
    var $id = __stackBase__ + 112;
    var $n = __stackBase__ + 116;
    var $p = __stackBase__ + 120;
    var $3 = __stackBase__ + 128;
    var $d = __stackBase__ + 136;
    var $gap = __stackBase__ + 144;
    var $d1 = __stackBase__ + 224;
    var $anchor = __stackBase__ + 232;
    var $scx = __stackBase__ + 236;
    var $4 = $0 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $space | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $7 = $propertyList;
    var $8 = $cx;
    __ZN2js12AutoIdVectorC1EP9JSContext($7, $8);
    if (($replacer | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $replacer;
    var $12 = __ZN8JSObject10isCallableEv($11);
    if ($12) {
      var $_04 = $replacer;
      __label__ = 27;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = _JS_IsArrayObject(undef, $11);
    if (($14 | 0) == 0) {
      var $_04 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($8, $11, $len);
    var $18 = __ZNK8JSObject12isDenseArrayEv($11);
    var $19 = HEAPU32[$len >> 2];
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $24 = $19;
      __label__ = 6;
      break;
    }
   case 5:
    var $21 = __ZN8JSObject21getDenseArrayCapacityEv($11);
    var $23 = $19 >>> 0 < $21 >>> 0 ? $19 : $21;
    HEAP32[$len >> 2] = $23;
    var $24 = $23;
    __label__ = 6;
    break;
   case 6:
    var $24;
    var $25 = $2;
    __ZN2js15TempAllocPolicyC1EP9JSContext($25, $8);
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_($idSet, $2);
    var $26 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj($idSet, $24);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 7:
    var $27 = $p | 0;
    var $28 = $3 | 0;
    var $29 = $propertyList | 0;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 9:
    var $33 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($11, $8, $i_0, $v);
    if (($33 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = __ZNK2JS5Value8isNumberEv($v);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $38 = __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542($v, $n);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $40 = HEAP32[$n >> 2];
    var $41 = _INT_FITS_IN_JSID2543($40);
    if (($41 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = _INT_TO_JSID2544($40);
    HEAP32[$id >> 2] = $44;
    __label__ = 22;
    break;
   case 14:
    var $46 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($8, $v, $id);
    if ($46) {
      __label__ = 15;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 15:
    var $48 = HEAP32[$id >> 2];
    var $49 = __Z22js_CheckForStringIndexi($48);
    HEAP32[$id >> 2] = $49;
    __label__ = 22;
    break;
   case 16:
    var $51 = __ZNK2JS5Value8isStringEv($v);
    if ($51) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $53 = __ZNK2JS5Value8isObjectEv($v);
    if ($53) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $55 = __ZNK2JS5Value8toObjectEv($v);
    var $56 = __ZNK8JSObject8isStringEv($55);
    if ($56) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = __ZNK8JSObject8isNumberEv($55);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $60 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($8, $v, $id);
    if ($60) {
      __label__ = 21;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 21:
    var $62 = HEAP32[$id >> 2];
    var $63 = __Z22js_CheckForStringIndexi($62);
    HEAP32[$id >> 2] = $63;
    __label__ = 22;
    break;
   case 22:
    __ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi($p, $idSet, $id);
    __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv($3, $27);
    if ((HEAP32[$28 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    var $68 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_($idSet, $p, $id);
    if ($68) {
      __label__ = 24;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 24:
    var $70 = __ZN2js16AutoVectorRooterIiE6appendERKi($29, $id);
    if ($70) {
      __label__ = 25;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 25:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 26:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_04 = $replacer;
    __label__ = 27;
    break;
   case 27:
    var $_04;
    var $75 = __ZNK2JS5Value8isObjectEv($space);
    if ($75) {
      __label__ = 28;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 28:
    var $77 = __ZNK2JS5Value8toObjectEv($space);
    var $78 = __ZNK8JSObject8isNumberEv($77);
    if ($78) {
      __label__ = 29;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 29:
    var $80 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($8, $space, $d);
    if ($80) {
      __label__ = 30;
      break;
    } else {
      var $_5 = 0;
      __label__ = 54;
      break;
    }
   case 30:
    var $82 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    __ZN2JSL11NumberValueEd2545($space, $82);
    __label__ = 34;
    break;
   case 31:
    var $84 = __ZNK8JSObject8isStringEv($77);
    if ($84) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $86 = $cx;
    var $87 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($86, $space);
    if (($87 | 0) == 0) {
      var $_5 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    __ZN2JSL11StringValueEP8JSString2546($space, $87);
    __label__ = 34;
    break;
   case 34:
    var $91 = $gap;
    __ZN2js12StringBufferC1EP9JSContext($91, $8);
    var $92 = __ZNK2JS5Value8isNumberEv($space);
    if ($92) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547($cx, $space, $d1);
    var $94 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    var $96 = $94 > 10 ? 10 : $94;
    tempDoubleF64[0] = $96, HEAP32[$d1 >> 2] = tempDoubleI32[0], HEAP32[$d1 + 4 >> 2] = tempDoubleI32[1];
    if ($96 < 1) {
      __label__ = 40;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $99 = $96 >= 0 ? Math.floor($96) : Math.ceil($96);
    var $100 = __ZN2js12StringBuffer7appendNEtj($gap, 32, $99);
    if ($100) {
      __label__ = 40;
      break;
    } else {
      var $_4 = 0;
      __label__ = 47;
      break;
    }
   case 37:
    var $102 = __ZNK2JS5Value8isStringEv($space);
    if ($102) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $104 = __ZNK2JS5Value8toStringEv($space);
    var $105 = __ZN8JSString12ensureLinearEP9JSContext($104, $8);
    if (($105 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $108 = $105 | 0;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $108);
    var $109 = __ZNK2JS5Value8toStringEv($space);
    var $110 = __ZNK8JSString6lengthEv($109);
    var $112 = $110 >>> 0 > 10 ? 10 : $110;
    var $113 = __ZNK14JSLinearString5charsEv($105);
    var $114 = __ZN2js12StringBuffer6appendEPKtj($91, $113, $112);
    if ($114) {
      __label__ = 40;
      break;
    } else {
      var $_4 = 0;
      __label__ = 47;
      break;
    }
   case 40:
    var $116 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx);
    if (($116 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $123 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $124 = __ZL12ATOM_TO_JSIDP6JSAtom2549($123);
    var $125 = $cx;
    var $126 = $116;
    var $127 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($125, $126, $124, $vp, 10, 12, 1, 0, 0, 0);
    if (($127 | 0) == 0) {
      var $_4 = 0;
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    __ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($scx, $cx, $sb, $gap, $_04, $propertyList);
    var $130 = __ZN16StringifyContext4initEv($scx);
    if ($130) {
      __label__ = 43;
      break;
    } else {
      var $_3 = 0;
      __label__ = 46;
      break;
    }
   case 43:
    var $132 = __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $116, $124, $vp, $scx);
    if ($132) {
      __label__ = 44;
      break;
    } else {
      var $_3 = 0;
      __label__ = 46;
      break;
    }
   case 44:
    var $134 = __ZL15IsFilteredValueRKN2JS5ValueE($vp);
    if ($134) {
      var $_3 = 1;
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $136 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $vp, $scx);
    var $_3 = $136;
    __label__ = 46;
    break;
   case 46:
    var $_3;
    __ZN16StringifyContextD1Ev($scx);
    var $_4 = $_3;
    __label__ = 47;
    break;
   case 47:
    var $_4;
    __ZN2js12StringBufferD1Ev($91);
    var $_5 = $_4;
    __label__ = 54;
    break;
   case 48:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 49:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 50:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 51:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 52:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 53:
    __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($idSet);
    var $_5 = 0;
    __label__ = 54;
    break;
   case 54:
    var $_5;
    __ZN2js12AutoIdVectorD1Ev($7);
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE["X"] = 1;

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj($1, $len);
  return $2;
}

function __ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542($v, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$pi >> 2] = $3;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = _JSDOUBLE_IS_INT322570($7, $pi);
    var $_0 = ($8 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 196,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_($1, $p, $t);
  return $2;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2JSL11NumberValueEd2545($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN2JSL11StringValueEP8JSString2546($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547($cx, $v, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value7isInt32Ev($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value7toInt32Ev($v);
    tempDoubleF64[0] = $4 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $17 = $9;
    __label__ = 7;
    break;
   case 5:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = $cx;
    var $15 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($14, $1, $dp);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $17 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $17;
    var $18 = __ZL18js_DoubleToIntegerd2596($17);
    tempDoubleF64[0] = $18, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    __label__ = 8;
    break;
   case 8:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer7appendNEtj($this, $c, $n) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP16[$1 >> 1] = $c;
    var $2 = $this;
    var $3 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($2);
    var $4 = $3 + $n | 0;
    var $5 = $this;
    var $6 = __ZN2js12StringBuffer11checkLengthEj($5, $4);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this | 0;
    var $9 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj($8, $1, $n);
    var $_0 = $9;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2555($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593($cx, $4);
  return $5;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2549($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2592($1);
  return $2;
}

function __ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList) {
  __ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList);
  return;
}

function __ZN16StringifyContext4initEv($this) {
  var $1 = $this + 20 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, 16);
  return $2;
}

function __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $holder, $key, $vp, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toJSON = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $args1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 64;
    var $3 = __stackBase__ + 72;
    var $4 = __stackBase__ + 80;
    var $d = __stackBase__ + 88;
    var $5 = __ZNK2JS5Value8isObjectEv($vp);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210336 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom2549($11);
    var $13 = __ZNK2JS5Value8toObjectEv($vp);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($14, $15, $12, 2, $toJSON);
    if (($16 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = __ZL13js_IsCallableRKN2JS5ValueE2550($toJSON);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $21 = __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $key);
    if (($21 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($24);
    var $26 = $cx + 60 | 0;
    var $27 = $cx;
    var $28 = $args;
    var $29 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($26, $27, 1, $28);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $31 = $args;
    var $32 = __ZNK2js12CallReceiver7calleevEv($31);
    var $33 = $toJSON | 0;
    var $st$3$0 = $33 | 0;
    var $34$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $33 + 4 | 0;
    var $34$1 = HEAP32[$st$3$1 >> 2];
    var $35 = $32 | 0;
    var $st$8$0 = $35 | 0;
    HEAP32[$st$8$0 >> 2] = $34$0;
    var $st$8$1 = $35 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $34$1;
    var $36 = __ZNK2js12CallReceiver5thisvEv($31);
    var $37 = $vp | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $36 | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = $args;
    var $41 = __ZNK2js8CallArgsixEj($40, 0);
    __ZN2JSL11StringValueEP8JSString2546($1, $21);
    var $42 = $1 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $41 | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $45 = $cx;
    var $46 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($45, $24, 0);
    if ($46) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $47 = __ZNK2js12CallReceiver4rvalEv($31);
    var $48 = $47 | 0;
    var $st$2$0 = $48 | 0;
    var $49$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $48 + 4 | 0;
    var $49$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $37 | 0;
    HEAP32[$st$6$0 >> 2] = $49$0;
    var $st$6$1 = $37 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $49$1;
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $keyStr_0 = $21;
    __label__ = 9;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 9:
    var $keyStr_0;
    var $52 = $scx + 8 | 0;
    var $53 = HEAP32[$52 >> 2];
    if (($53 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $56 = $53;
    var $57 = __ZN8JSObject10isCallableEv($56);
    if ($57) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if (($keyStr_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $keyStr_1 = $keyStr_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $61 = __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $key);
    if (($61 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      var $keyStr_1 = $61;
      __label__ = 13;
      break;
    }
   case 13:
    var $keyStr_1;
    var $64 = $args1;
    __ZN2js15InvokeArgsGuardC1Ev($64);
    var $66 = $cx + 60 | 0;
    var $67 = $cx;
    var $68 = $args1;
    var $69 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($66, $67, 2, $68);
    if ($69) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $71 = $cx;
    var $72 = $args1;
    var $73 = __ZNK2js12CallReceiver7calleevEv($72);
    var $74 = HEAP32[$52 >> 2];
    __ZN2JSL11ObjectValueER8JSObject2569($2, $74);
    var $75 = $2 | 0;
    var $st$6$0 = $75 | 0;
    var $76$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $75 + 4 | 0;
    var $76$1 = HEAP32[$st$6$1 >> 2];
    var $77 = $73 | 0;
    HEAP32[$77 >> 2] = $76$0;
    HEAP32[$77 + 4 >> 2] = $76$1;
    var $78 = __ZNK2js12CallReceiver5thisvEv($72);
    __ZN2JSL11ObjectValueER8JSObject2569($3, $holder);
    var $79 = $3 | 0;
    var $80$0 = HEAP32[$79 >> 2];
    var $80$1 = HEAP32[$79 + 4 >> 2];
    var $81 = $78 | 0;
    HEAP32[$81 >> 2] = $80$0;
    HEAP32[$81 + 4 >> 2] = $80$1;
    var $82 = $args1;
    var $83 = __ZNK2js8CallArgsixEj($82, 0);
    __ZN2JSL11StringValueEP8JSString2546($4, $keyStr_1);
    var $84 = $4 | 0;
    var $85$0 = HEAP32[$84 >> 2];
    var $85$1 = HEAP32[$84 + 4 >> 2];
    var $86 = $83 | 0;
    HEAP32[$86 >> 2] = $85$0;
    HEAP32[$86 + 4 >> 2] = $85$1;
    var $87 = __ZNK2js8CallArgsixEj($82, 1);
    var $88 = $vp | 0;
    var $89$0 = HEAP32[$88 >> 2];
    var $89$1 = HEAP32[$88 + 4 >> 2];
    var $90 = $87 | 0;
    HEAP32[$90 >> 2] = $89$0;
    HEAP32[$90 + 4 >> 2] = $89$1;
    var $91 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($71, $64, 0);
    if ($91) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $92 = __ZNK2js12CallReceiver4rvalEv($72);
    var $93 = $92 | 0;
    var $st$2$0 = $93 | 0;
    var $94$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $93 + 4 | 0;
    var $94$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $88 | 0;
    HEAP32[$st$6$0 >> 2] = $94$0;
    var $st$6$1 = $88 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $94$1;
    __ZN2js15InvokeArgsGuardD1Ev($64);
    __label__ = 17;
    break;
   case 16:
    __ZN2js15InvokeArgsGuardD1Ev($64);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 17:
    var $97 = __ZNK2JS5Value8isObjectEv($vp);
    if ($97) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 18:
    var $99 = __ZNK2JS5Value8toObjectEv($vp);
    var $100 = __ZNK8JSObject8getClassEv($99);
    if (($100 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $103 = $cx;
    var $104 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($103, $vp, $d);
    if ($104) {
      __label__ = 20;
      break;
    } else {
      var $_3 = 0;
      __label__ = 26;
      break;
    }
   case 20:
    var $106 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $107 = __ZN2JS5Value9setNumberEd($vp, $106);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 21:
    if (($100 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $111 = $cx;
    var $112 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($111, $vp);
    if (($112 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JS5Value9setStringEP8JSString($vp, $112);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 24:
    if (($100 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 25:
    var $118 = $99;
    var $119 = __ZNK8JSObject16getPrimitiveThisEv($118);
    var $120 = $119 | 0;
    var $st$3$0 = $120 | 0;
    var $121$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $120 + 4 | 0;
    var $121$1 = HEAP32[$st$3$1 >> 2];
    var $122 = $vp | 0;
    var $st$8$0 = $122 | 0;
    HEAP32[$st$8$0 >> 2] = $121$0;
    var $st$8$1 = $122 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $121$1;
    var $_3 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZL15IsFilteredValueRKN2JS5ValueE($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($1) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE2550($v);
    if ($3) {
      var $10 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2JS5Value8isObjectEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $10 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toObjectEv($v);
    var $8 = __ZNK8JSObject5isXMLEv($7);
    var $10 = $8;
    __label__ = 5;
    break;
   case 5:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $v, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 3:
    var $8 = __ZNK2JS5Value8isStringEv($v);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$scx >> 2];
    var $12 = __ZNK2JS5Value8toStringEv($v);
    var $13 = __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($cx, $11, $12);
    var $_1 = $13 & 1;
    __label__ = 20;
    break;
   case 5:
    var $16 = __ZNK2JS5Value6isNullEv($v);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = HEAP32[$scx >> 2];
    var $21 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($20, STRING_TABLE._js_null_str);
    var $_1 = $21 & 1;
    __label__ = 20;
    break;
   case 7:
    var $24 = __ZNK2JS5Value9isBooleanEv($v);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $26 = __ZNK2JS5Value9toBooleanEv($v);
    var $29 = HEAP32[$scx >> 2];
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($29, STRING_TABLE._js_true_str);
    var $35 = $31;
    __label__ = 11;
    break;
   case 10:
    var $33 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($29, STRING_TABLE._js_false_str);
    var $35 = $33;
    __label__ = 11;
    break;
   case 11:
    var $35;
    var $_1 = $35 & 1;
    __label__ = 20;
    break;
   case 12:
    var $38 = __ZNK2JS5Value8isNumberEv($v);
    if ($38) {
      __label__ = 13;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 13:
    var $40 = __ZNK2JS5Value8isDoubleEv($v);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $42 = __ZNK2JS5Value8toDoubleEv($v);
    var $43 = __ZL18JSDOUBLE_IS_FINITEd2585($42);
    if (($43 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$scx >> 2];
    var $49 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($48, STRING_TABLE._js_null_str);
    var $_1 = $49 & 1;
    __label__ = 20;
    break;
   case 16:
    var $52 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($sb, $52);
    var $53 = __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($52, $v, $sb);
    if ($53) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $56 = HEAP32[$scx >> 2];
    var $57 = __ZN2js12StringBuffer5beginEv($sb);
    var $58 = __ZNK2js12StringBuffer6lengthEv($sb);
    var $59 = $56;
    var $60 = __ZN2js12StringBuffer6appendEPKtj($59, $57, $58);
    var $_0 = $60 & 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js12StringBufferD1Ev($sb);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 19:
    var $64 = $scx + 16 | 0;
    var $66 = HEAP32[$64 >> 2] + 1 | 0;
    HEAP32[$64 >> 2] = $66;
    var $67 = __ZNK2JS5Value8toObjectEv($v);
    var $68 = _JS_IsArrayObject(undef, $67);
    var $_ZL2JAP9JSContextP8JSObjectP16StringifyContext__ZL2JOP9JSContextP8JSObjectP16StringifyContext = ($68 | 0) != 0 ? 198 : 200;
    var $70 = __ZNK2JS5Value8toObjectEv($v);
    var $71 = $70;
    var $72 = FUNCTION_TABLE[$_ZL2JAP9JSContextP8JSObjectP16StringifyContext__ZL2JOP9JSContextP8JSObjectP16StringifyContext]($cx, $71, $scx);
    var $74 = HEAP32[$64 >> 2] - 1 | 0;
    HEAP32[$64 >> 2] = $74;
    var $_1 = $72;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZN16StringifyContextD1Ev($this) {
  __ZN16StringifyContextD2Ev($this);
  return;
}

function __ZL13js_IsCallableRKN2JS5ValueE2550($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6ReviveP9JSContextRKN2JS5ValueEPS2_($cx, $reviver, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548($cx);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $4, $5);
    var $6 = $cx + 52 | 0;
    var $10 = HEAP32[HEAP32[$6 >> 2] + 209972 >> 2] | 0;
    var $11 = __ZL12ATOM_TO_JSIDP6JSAtom2549($10);
    var $12 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($5, $4, $11, $vp, 0, 0, 1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = HEAP32[HEAP32[$6 >> 2] + 209972 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom2549($18);
    var $20 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $1, $19, $reviver, $vp);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13json_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210040 >> 2] | 0;
  __ZN2JS5Value9setStringEP8JSString($vp, $5);
  return 1;
}

function __Z16js_InitJSONClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    var $7 = __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL2554($1, $2);
    var $8 = $cx;
    var $9 = $obj;
    var $10 = _JS_DefineProperty($8, $9, STRING_TABLE._js_JSON_str | 0, $1, 10, 12, 0);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $2;
    var $14 = _JS_DefineFunctions($8, $13, __ZL19json_static_methods);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $obj;
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($17, __ZN2js9JSONClassE);
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553($cx, $parent) {
  var $3 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2555($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL2554($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL2574($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout2583($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi($t) {
  return $t;
}

function __ZN2js13DefaultHasherIiE4hashERKi($l) {
  return HEAP32[$l >> 2];
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js13DefaultHasherIiE5matchERKiS3_($id, $l) {
  return (HEAP32[$id >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function _JSID_IS_STRING2575($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING2576($iden) {
  return $iden;
}

function _JSID_IS_INT2577($iden) {
  return $iden & 1;
}

function _JSID_TO_INT2578($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT2581($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT2582($iden) {
  return $iden & -8;
}

function _JSDOUBLE_IS_NEGZERO2573($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function _OBJECT_TO_JSVAL_IMPL2574($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2583($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $4;
    var $20 = __ZNK8JSObject9getParentEv($19);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, undef, __ZN2js9JSONClassE, $12, $23, 0, (__ZN2js9JSONClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $26 = __ZNK2js5Class8isNativeEv(__ZN2js9JSONClassE);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560($cx, $14, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js9JSONClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js9JSONClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $5 = __ZNK8JSObject8numSlotsEv($4);
    if ($3 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $3);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = $type;
    var $13 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($12, __ZN2js9JSONClassE);
    var $14 = $cx;
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($12, $14, __ZN2js9JSONClassE, $kind);
    var $empty_0_in = $16;
    __label__ = 6;
    break;
   case 5:
    var $18 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($14, __ZN2js9JSONClassE);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKiE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($14);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $16 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($12, $10);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $20 = $this + 16 | 0;
    var $22 = HEAP32[$20 >> 2] + 1 | 0;
    HEAP32[$20 >> 2] = $22;
    HEAP32[$2 >> 2] = $16;
    var $23 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $25 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($src_01);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv($src_01);
    var $27 = __ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv($src_01);
    var $28 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $27);
    __ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE($28, $1);
    __label__ = 7;
    break;
   case 7:
    var $30 = $src_01 + 8 | 0;
    if (($30 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $30;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($12, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKiEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $12 = $e_01 + 8 | 0;
    if (($12 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $12;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKiE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_($l);
  var $2 = __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_($l) {
  var $1 = __ZN2js13DefaultHasherIiE4hashERKi($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKiE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKiE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKiE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKiE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi($1);
  var $3 = __ZN2js13DefaultHasherIiE5matchERKiS3_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKiE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN14KeyStringifierIiE8toStringEP9JSContexti($cx, $id) {
  var $1 = __ZN2jsL10IdToStringEP9JSContexti($cx, $id);
  return $1;
}

function __ZN2JSL11ObjectValueER8JSObject2569($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function _JSDOUBLE_IS_INT322570($d, $pi) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSDOUBLE_IS_NEGZERO2573($d);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $d & -1;
    HEAP32[$pi >> 2] = $4;
    var $_0 = ($4 | 0) == $d & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL10IdToStringEP9JSContexti($cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = _JSID_IS_STRING2575($id);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_STRING2576($id);
    var $_0 = $5;
    __label__ = 6;
    break;
   case 3:
    var $7 = _JSID_IS_INT2577($id);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = _JSID_TO_INT2578($id);
    var $11 = $cx;
    var $12 = __Z14js_IntToStringP9JSContexti($11, $10);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 5:
    __ZN2jsL9IdToValueEi2579($1, $id);
    var $14 = $cx;
    var $15 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($14, $1);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToValueEi2579($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING2575($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING2576($id);
    __ZN2JSL11StringValueEP8JSString2546($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT2577($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT2578($id);
    __ZN2JSL10Int32ValueEi2580($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT2581($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT2582($id);
    __ZN2JSL11ObjectValueER8JSObject2569($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv2537($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi2580($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $holder, $name, $reviver, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__ + 4;
    var $id = __stackBase__ + 12;
    var $newElement = __stackBase__ + 16;
    var $keys = __stackBase__ + 24;
    var $newElement2 = __stackBase__ + 84;
    var $args = __stackBase__ + 92;
    var $1 = __stackBase__ + 116;
    var $2 = __stackBase__ + 124;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($8);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 3:
    var $10 = $holder;
    var $11 = $cx;
    var $12 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($10, $11, $name, $val);
    if (($12 | 0) == 0) {
      var $_2 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZNK2JS5Value8isObjectEv($val);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 5:
    var $17 = __ZNK2JS5Value8toObjectEv($val);
    var $18 = $17;
    var $19 = __ZNK8JSObject7isArrayEv($17);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 6:
    var $21 = __ZNK8JSObject14getArrayLengthEv($17);
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $21 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 8:
    var $25 = __ZN2js9IndexToIdEP9JSContextjPi($11, $i_0, $id);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_2 = 0;
      __label__ = 32;
      break;
    }
   case 9:
    var $27 = HEAPU32[$id >> 2];
    var $28 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $18, $27, $reviver, $newElement);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      var $_2 = 0;
      __label__ = 32;
      break;
    }
   case 10:
    var $30 = __ZNK2JS5Value11isUndefinedEv($newElement);
    if ($30) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($11, $17, $27, $newElement, 0);
    __label__ = 13;
    break;
   case 12:
    var $34 = __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej($11, $17, $27, $newElement, 10, 12, 1);
    __label__ = 13;
    break;
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 14:
    var $38 = $keys;
    __ZN2js12AutoIdVectorC1EP9JSContext($38, $11);
    var $39 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($cx, $18, 8, $keys);
    if ($39) {
      __label__ = 15;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 15:
    var $41 = $keys;
    var $42 = __ZNK2js16AutoVectorRooterIiE6lengthEv($41);
    var $43 = $cx;
    var $44 = $17;
    var $i1_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i1_0;
    if ($i1_0 >>> 0 < $42 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    var $48 = __ZN2js16AutoVectorRooterIiEixEj($41, $i1_0);
    var $49 = HEAPU32[$48 >> 2];
    var $50 = __ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_($cx, $18, $49, $reviver, $newElement2);
    if ($50) {
      __label__ = 18;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 18:
    var $52 = __ZNK2JS5Value11isUndefinedEv($newElement2);
    if ($52) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($43, $44, $49, $newElement2, 0);
    if (($54 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $57 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($43, $44, $49, $newElement2, 10, 12, 1, 0, 0, 0);
    if (($57 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 16;
    break;
   case 22:
    __ZN2js12AutoIdVectorD1Ev($38);
    __label__ = 23;
    break;
   case 23:
    var $62 = __ZN2jsL10IdToStringEP9JSContexti($cx, $name);
    if (($62 | 0) == 0) {
      var $_2 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $65 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($65);
    var $67 = $cx + 60 | 0;
    var $68 = $cx;
    var $69 = $args;
    var $70 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($67, $68, 2, $69);
    if ($70) {
      __label__ = 25;
      break;
    } else {
      var $_1 = 0;
      __label__ = 27;
      break;
    }
   case 25:
    var $72 = $args;
    var $73 = __ZNK2js12CallReceiver7calleevEv($72);
    var $74 = $reviver | 0;
    var $75$0 = HEAP32[$74 >> 2];
    var $75$1 = HEAP32[$74 + 4 >> 2];
    var $76 = $73 | 0;
    HEAP32[$76 >> 2] = $75$0;
    HEAP32[$76 + 4 >> 2] = $75$1;
    var $77 = __ZNK2js12CallReceiver5thisvEv($72);
    __ZN2JSL11ObjectValueER8JSObject2569($1, $holder);
    var $78 = $1 | 0;
    var $79$0 = HEAP32[$78 >> 2];
    var $79$1 = HEAP32[$78 + 4 >> 2];
    var $80 = $77 | 0;
    HEAP32[$80 >> 2] = $79$0;
    HEAP32[$80 + 4 >> 2] = $79$1;
    var $81 = $args;
    var $82 = __ZNK2js8CallArgsixEj($81, 0);
    __ZN2JSL11StringValueEP8JSString2546($2, $62);
    var $83 = $2 | 0;
    var $84$0 = HEAP32[$83 >> 2];
    var $84$1 = HEAP32[$83 + 4 >> 2];
    var $85 = $82 | 0;
    HEAP32[$85 >> 2] = $84$0;
    HEAP32[$85 + 4 >> 2] = $84$1;
    var $86 = __ZNK2js8CallArgsixEj($81, 1);
    var $87 = $val | 0;
    var $88$0 = HEAP32[$87 >> 2];
    var $88$1 = HEAP32[$87 + 4 >> 2];
    var $89 = $86 | 0;
    HEAP32[$89 >> 2] = $88$0;
    HEAP32[$89 + 4 >> 2] = $88$1;
    var $90 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($11, $65, 0);
    if ($90) {
      __label__ = 26;
      break;
    } else {
      var $_1 = 0;
      __label__ = 27;
      break;
    }
   case 26:
    var $92 = __ZNK2js12CallReceiver4rvalEv($72);
    var $93 = $92 | 0;
    var $94$0 = HEAP32[$93 >> 2];
    var $94$1 = HEAP32[$93 + 4 >> 2];
    var $95 = $vp | 0;
    HEAP32[$95 >> 2] = $94$0;
    HEAP32[$95 + 4 >> 2] = $94$1;
    var $_1 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_1;
    __ZN2js15InvokeArgsGuardD1Ev($65);
    var $_2 = $_1;
    __label__ = 32;
    break;
   case 28:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 29:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 30:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 31:
    __ZN2js12AutoIdVectorD1Ev($38);
    var $_2 = 0;
    __label__ = 32;
    break;
   case 32:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_["X"] = 1;

function __ZN16StringifyContextD2Ev($this) {
  var $1 = $this + 20 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev($this) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($5, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZL18JSDOUBLE_IS_FINITEd2585($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 1) | 0;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev($this) {
  HEAP8[$this + 60 | 0] = 0;
  return;
}

function __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $str);
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $sb;
    var $7 = __ZN2js12StringBuffer6appendEt($6, 34);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 3:
    var $8 = $sb;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      var $i_1 = $i_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 5:
    var $i_1;
    var $12 = HEAP16[$3 + ($i_1 << 1) >> 1];
    var $13 = __ZL23IsQuoteSpecialCharactert($12);
    if ($13) {
      var $i_2 = $i_1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $i_1 + 1 | 0;
    if ($15 >>> 0 < $1 >>> 0) {
      var $i_1 = $15;
      __label__ = 5;
      break;
    } else {
      var $i_2 = $15;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_2;
    if ($i_2 >>> 0 > $i_0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = $3 + ($i_0 << 1) | 0;
    var $22 = __ZN2js12StringBuffer6appendEPKtj($6, $20, $i_2 - $i_0 | 0);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 9:
    if (($i_2 | 0) == ($1 | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $26 = HEAPU16[$3 + ($i_2 << 1) >> 1];
    if ($26 << 16 >> 16 == 34 || $26 << 16 >> 16 == 92) {
      __label__ = 11;
      break;
    } else if ($26 << 16 >> 16 == 9 || $26 << 16 >> 16 == 10 || $26 << 16 >> 16 == 12 || $26 << 16 >> 16 == 13) {
      __label__ = 13;
      break;
    } else if ($26 << 16 >> 16 == 8) {
      var $38 = 98;
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 11:
    var $28 = __ZN2js12StringBuffer6appendEt($6, 92);
    if ($28) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 12:
    var $30 = __ZN2js12StringBuffer6appendEt($6, $26);
    if ($30) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 13:
    if ($26 << 16 >> 16 == 12) {
      var $38 = 102;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($26 << 16 >> 16 == 10) {
      var $38 = 110;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $phitmp = $26 << 16 >> 16 == 13 ? 114 : 116;
    var $38 = $phitmp;
    __label__ = 16;
    break;
   case 16:
    var $38;
    var $39 = __ZN2js12StringBuffer6appendEt($6, 92);
    if ($39) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    var $41 = __ZN2js12StringBuffer6appendEt($6, $38);
    if ($41) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $43 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE.__str52536);
    if ($43) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 19:
    var $47 = (($26 & 65535) >>> 4 & 255) + 48 & 65535;
    var $48 = __ZN2js12StringBuffer6appendEt($6, $47);
    if ($48) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 20:
    var $50 = $26 & 65535 & 15;
    var $54 = $50 >>> 0 < 10 ? $50 | 48 : $50 + 87 | 0;
    var $55 = $54 & 65535;
    var $56 = __ZN2js12StringBuffer6appendEt($6, $55);
    if ($56) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 21:
    var $i_0 = $i_2 + 1 | 0;
    __label__ = 4;
    break;
   case 22:
    var $60 = __ZN2js12StringBuffer6appendEt($6, 34);
    var $_0 = $60;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString["X"] = 1;

function __ZL2JAP9JSContextP8JSObjectP16StringifyContext($cx, $obj, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $detect = __stackBase__;
    var $length = __stackBase__ + 8;
    var $outputValue = __stackBase__ + 12;
    __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($detect, $scx, $obj);
    var $1 = __ZN13CycleDetector4initEP9JSContext($detect, $cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 2:
    var $3 = $scx | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js12StringBuffer6appendEt($5, 91);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = $obj;
    var $10 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($8, $9, $length);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAPU32[$length >> 2];
    if (($13 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = $scx + 16 | 0;
    var $17 = HEAP32[$16 >> 2];
    var $18 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $13 - 1 | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    var $24 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($9, $8, $i_0, $outputValue);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $obj, $i_0, $outputValue, $scx);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $29 = __ZL15IsFilteredValueRKN2JS5ValueE($outputValue);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = HEAP32[$3 >> 2];
    var $33 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($32, STRING_TABLE._js_null_str);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 12:
    var $35 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($cx, $outputValue, $scx);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($i_0 >>> 0 < $20 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $41 = HEAP32[$3 >> 2];
    var $42 = __ZN2js12StringBuffer6appendEt($41, 44);
    if ($42) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 15:
    var $44 = HEAP32[$16 >> 2];
    var $45 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $44);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 17:
    var $51 = HEAP32[$16 >> 2] - 1 | 0;
    var $52 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $51);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $56 = HEAP32[$3 >> 2];
    var $57 = __ZN2js12StringBuffer6appendEt($56, 93);
    var $_0 = $57 & 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN13CycleDetectorD1Ev($detect);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL2JAP9JSContextP8JSObjectP16StringifyContext["X"] = 1;

function __ZL2JOP9JSContextP8JSObjectP16StringifyContext($cx, $obj, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $detect = __stackBase__ + 4;
    var $ids = __stackBase__ + 12;
    var $outputValue = __stackBase__ + 76;
    HEAP32[$1 >> 2] = $cx;
    __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($detect, $scx, $obj);
    var $2 = __ZN13CycleDetector4initEP9JSContext($detect, $cx);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 2:
    var $4 = $scx | 0;
    var $6 = HEAP32[$4 >> 2];
    var $7 = __ZN2js12StringBuffer6appendEt($6, 123);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 26;
      break;
    }
   case 3:
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev($ids);
    var $10 = HEAP32[$scx + 8 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    var $14 = __ZN8JSObject10isCallableEv($13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $props_0 = HEAP32[$scx + 12 >> 2];
    var $23 = $cx;
    __label__ = 7;
    break;
   case 6:
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_($ids, $1);
    var $19 = HEAP32[$1 >> 2];
    var $20 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv($ids);
    var $21 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($19, $obj, 8, $20);
    if ($21) {
      var $props_0 = $20;
      var $23 = $19;
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 7:
    var $23;
    var $props_0;
    var $24 = $props_0 | 0;
    var $26 = __ZNK2js16AutoVectorRooterIiE6lengthEv($props_0);
    var $27 = $obj;
    var $28 = $23;
    var $29 = $scx + 16 | 0;
    var $30 = $scx + 4 | 0;
    var $i_0 = 0;
    var $wroteMember_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $wroteMember_0;
    var $i_0;
    if ($i_0 >>> 0 < $26 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 9:
    var $34 = __ZNK2js16AutoVectorRooterIiEixEj($24, $i_0);
    var $35 = HEAP32[$34 >> 2];
    var $36 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($27, $28, $35, $outputValue);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = HEAP32[$34 >> 2];
    var $40 = __ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($23, $obj, $39, $outputValue, $scx);
    if ($40) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 11:
    var $42 = __ZL15IsFilteredValueRKN2JS5ValueE($outputValue);
    if ($42) {
      var $wroteMember_1 = $wroteMember_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($wroteMember_0 & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = HEAP32[$4 >> 2];
    var $49 = __ZN2js12StringBuffer6appendEt($48, 44);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 14:
    var $51 = HEAP32[$29 >> 2];
    var $52 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $51);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = HEAP32[$34 >> 2];
    var $56 = __ZN2jsL10IdToStringEP9JSContexti($23, $55);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = HEAP32[$4 >> 2];
    var $60 = __ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString($23, $59, $56);
    if ($60) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 17:
    var $63 = HEAP32[$4 >> 2];
    var $64 = __ZN2js12StringBuffer6appendEt($63, 58);
    if ($64) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 18:
    var $67 = HEAP32[$30 >> 2];
    var $68 = __ZNK2js12StringBuffer5emptyEv($67);
    if ($68) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = HEAP32[$4 >> 2];
    var $72 = __ZN2js12StringBuffer6appendEt($71, 32);
    if ($72) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 20:
    var $74 = __ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext($23, $outputValue, $scx);
    if (($74 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      var $wroteMember_1 = 1;
      __label__ = 21;
      break;
    }
   case 21:
    var $wroteMember_1;
    var $i_0 = $i_0 + 1 | 0;
    var $wroteMember_0 = $wroteMember_1;
    __label__ = 8;
    break;
   case 22:
    if (($wroteMember_0 & 1) << 24 >> 24 == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $83 = HEAP32[$29 >> 2] - 1 | 0;
    var $84 = __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $83);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $88 = HEAP32[$4 >> 2];
    var $89 = __ZN2js12StringBuffer6appendEt($88, 125);
    var $_0 = $89 & 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    __ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev($ids);
    var $_1 = $_0;
    __label__ = 26;
    break;
   case 26:
    var $_1;
    __ZN13CycleDetectorD1Ev($detect);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL2JOP9JSContextP8JSObjectP16StringifyContext["X"] = 1;

function __ZN13CycleDetectorC1EP16StringifyContextP8JSObject($this, $scx, $obj) {
  __ZN13CycleDetectorC2EP16StringifyContextP8JSObject($this, $scx, $obj);
  return;
}

function __ZN13CycleDetector4initEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ptr = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = $this + 4 | 0;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($ptr, $3, $4);
    var $5 = $ptr | 0;
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $5);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $cx;
    _JS_ReportErrorNumber($10, 2, 0, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_object_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $12 = HEAP32[$2 >> 2];
    var $13 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($12, $ptr, $4);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev($this);
  return;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_($this, $t1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2;
    var $7 = HEAP32[$t1 >> 2];
    __ZN2js12AutoIdVectorC1EP9JSContext($6, $7);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 60 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this);
  return $1;
}

function __ZNK2js16AutoVectorRooterIiEixEj($this, $i) {
  var $1 = $this + 12 | 0;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($1, $i);
  return $2;
}

function __ZL11WriteIndentP9JSContextP16StringifyContextj($scx, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $scx + 4 | 0;
    var $3 = HEAP32[$1 >> 2];
    var $4 = __ZNK2js12StringBuffer5emptyEv($3);
    if ($4) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $scx | 0;
    var $8 = HEAP32[$6 >> 2];
    var $9 = __ZN2js12StringBuffer6appendEt($8, 10);
    if ($9) {
      var $i_0 = 0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $limit >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = HEAP32[$6 >> 2];
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZNK2js12StringBuffer5beginEv($13);
    var $15 = __ZNK2js12StringBuffer3endEv($13);
    var $16 = __ZN2js12StringBuffer6appendEPKtS2_($12, $14, $15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev($this);
  return;
}

function __ZN13CycleDetectorD1Ev($this) {
  __ZN13CycleDetectorD2Ev($this);
  return;
}

function __ZN13CycleDetectorD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 4 | 0;
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_($2, $3);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($p, $this, $l);
    __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 202,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $2);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $e;
    var $2 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv($1);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + 1 | 0;
    HEAP32[$4 >> 2] = $6;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = $this + 12 | 0;
    var $11 = HEAP32[$9 >> 2] - 1 | 0;
    HEAP32[$9 >> 2] = $11;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($14);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $16 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($12, $10);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $20 = $this + 16 | 0;
    var $22 = HEAP32[$20 >> 2] + 1 | 0;
    HEAP32[$20 >> 2] = $22;
    HEAP32[$2 >> 2] = $16;
    var $23 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $25 = $src_01;
    var $26 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($25);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv($25);
    var $28 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv($25);
    var $29 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $28);
    __ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_($1, $25);
    var $30 = $29;
    __ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE($30, $1);
    __label__ = 7;
    break;
   case 7:
    var $32 = $src_01 + 8 | 0;
    if (($32 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $32;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj($12, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = $alloc;
    var $3 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + ($capacity << 3) | 0;
    if (($4 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $13 = $e_01 + 8 | 0;
    if (($13 | 0) == ($7 | 0)) {
      var $_0 = $4;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $13;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = $6;
    var $8 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($7);
    if ($8) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = 32 - $2 | 0;
    var $11 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $10, $2);
    var $13 = (1 << $10) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv($entry_0);
    var $17 = $h1_0 - $11 & $13;
    var $19 = HEAP32[$4 >> 2] + ($17 << 3) | 0;
    var $20 = $19;
    var $21 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($20);
    if ($21) {
      var $_0 = $19;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $19;
      var $h1_0 = $17;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv($this) {
  var $3 = HEAP32[$this >> 2];
  var $4 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv($3);
  return $4;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l) {
  var $1 = $l;
  var $2 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = $6;
    var $8 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($7);
    if ($8) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($7, $keyHash);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($6, $l);
    if ($12) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = 32 - $2 | 0;
    var $15 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj($keyHash, $14, $2);
    var $17 = (1 << $14) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $18 = $5;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $19 = $entry_0;
    var $20 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($19);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $26 = $18;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $26 = $18;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj($19, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $26 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $26;
    var $firstRemoved_1;
    var $28 = $h1_0 - $15 & $17;
    var $29 = $26 + ($28 << 3) | 0;
    var $30 = $29;
    var $31 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv($30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $29;
    var $_0 = $34;
    __label__ = 13;
    break;
   case 11:
    var $36 = __ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj($30, $keyHash);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $29;
      var $h1_0 = $28;
      var $18 = $26;
      __label__ = 5;
      break;
    }
   case 12:
    var $38 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($29, $l);
    if ($38) {
      var $_0 = $29;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $29;
      var $h1_0 = $28;
      var $18 = $26;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = $2;
  var $4 = $l;
  var $5 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($3, $4);
  return $5;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj($hash);
  return $1;
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 60 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this);
    var $7 = $6;
    __ZN2js12AutoIdVectorD1Ev($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv($1);
  return $2;
}

function __ZN2js12StringBuffer6appendEPKtS2_($this, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($1);
    var $7 = $2 + ($end - $begin >> 1) | 0;
    var $8 = $this;
    var $9 = __ZN2js12StringBuffer11checkLengthEj($8, $7);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_($1, $begin, $end);
    var $_0 = $11;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js12StringBuffer5beginEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($1);
  return $2;
}

function __ZNK2js12StringBuffer3endEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv($1);
  return $2;
}

function __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = $this;
  var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2 + ($i << 2) | 0;
}

function __ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj2592($bits) {
  return $bits;
}

function __ZN10JSONParser5tokenENS_5TokenE($this, $t) {
  return $t;
}

function __ZL23IsQuoteSpecialCharactert($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($c << 16 >> 16 == 34 || $c << 16 >> 16 == 92) {
      var $4 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ($c & 65535) < 32;
    __label__ = 3;
    break;
   case 3:
    var $4;
    return $4;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd2597($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN13CycleDetectorC2EP16StringifyContextP8JSObject($this, $scx, $obj) {
  HEAP32[$this >> 2] = $scx + 20 | 0;
  HEAP32[$this + 4 >> 2] = $obj;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt($dst, $n, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dst + ($n << 1) | 0;
    if (($n | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $p_01;
    var $3 = HEAP16[$t >> 1];
    HEAP16[$p_01 >> 1] = $3;
    var $4 = $p_01 + 2 | 0;
    if (($4 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $4;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser11errorReturnEv($this) {
  return (HEAP32[$this + 28 >> 2] | 0) == 1;
}

function __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($this, $other) {
  return HEAPU32[$this >> 2] >>> 0 < HEAPU32[$other >> 2] >>> 0;
}

function __ZNK7mozilla9RangedPtrIKtE3getEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $2;
    var $4 = __ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $this + 20 | 0;
    var $8 = HEAP32[$6 >> 2] - 1 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $p + 4 | 0;
    var $11 = HEAP32[$9 >> 2] | 1;
    HEAP32[$9 >> 2] = $11;
    var $27 = HEAP32[$1 >> 2];
    var $_pre_phi = $9;
    __label__ = 7;
    break;
   case 3:
    var $13 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv($this);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $21 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi($this, $_);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $23 = $p + 4 | 0;
    var $24 = HEAP32[$23 >> 2];
    var $25 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj($this, $24);
    HEAP32[$1 >> 2] = $25;
    var $27 = $25;
    var $_pre_phi = $23;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $27;
    var $28 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj($27, $28);
    var $30 = $this + 12 | 0;
    var $32 = HEAP32[$30 >> 2] + 1 | 0;
    HEAP32[$30 >> 2] = $32;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_($l);
  var $2 = __ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext($cx, $holder, $key, $vp, $scx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $toJSON = __stackBase__;
    var $args = __stackBase__ + 8;
    var $1 = __stackBase__ + 32;
    var $args1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 64;
    var $3 = __stackBase__ + 72;
    var $4 = __stackBase__ + 80;
    var $d = __stackBase__ + 88;
    var $5 = __ZNK2JS5Value8isObjectEv($vp);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210336 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom2549($11);
    var $13 = __ZNK2JS5Value8toObjectEv($vp);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($14, $15, $12, 2, $toJSON);
    if (($16 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = __ZL13js_IsCallableRKN2JS5ValueE2550($toJSON);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $keyStr_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $21 = __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $key);
    if (($21 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $args;
    __ZN2js15InvokeArgsGuardC1Ev($24);
    var $26 = $cx + 60 | 0;
    var $27 = $cx;
    var $28 = $args;
    var $29 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($26, $27, 1, $28);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $31 = $args;
    var $32 = __ZNK2js12CallReceiver7calleevEv($31);
    var $33 = $toJSON | 0;
    var $st$3$0 = $33 | 0;
    var $34$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $33 + 4 | 0;
    var $34$1 = HEAP32[$st$3$1 >> 2];
    var $35 = $32 | 0;
    var $st$8$0 = $35 | 0;
    HEAP32[$st$8$0 >> 2] = $34$0;
    var $st$8$1 = $35 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $34$1;
    var $36 = __ZNK2js12CallReceiver5thisvEv($31);
    var $37 = $vp | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $36 | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = $args;
    var $41 = __ZNK2js8CallArgsixEj($40, 0);
    __ZN2JSL11StringValueEP8JSString2546($1, $21);
    var $42 = $1 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $41 | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $45 = $cx;
    var $46 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($45, $24, 0);
    if ($46) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $47 = __ZNK2js12CallReceiver4rvalEv($31);
    var $48 = $47 | 0;
    var $st$2$0 = $48 | 0;
    var $49$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $48 + 4 | 0;
    var $49$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $37 | 0;
    HEAP32[$st$6$0 >> 2] = $49$0;
    var $st$6$1 = $37 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $49$1;
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $keyStr_0 = $21;
    __label__ = 9;
    break;
   case 8:
    __ZN2js15InvokeArgsGuardD1Ev($24);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 9:
    var $keyStr_0;
    var $52 = $scx + 8 | 0;
    var $53 = HEAP32[$52 >> 2];
    if (($53 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $56 = $53;
    var $57 = __ZN8JSObject10isCallableEv($56);
    if ($57) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if (($keyStr_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $keyStr_1 = $keyStr_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $61 = __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $key);
    if (($61 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      var $keyStr_1 = $61;
      __label__ = 13;
      break;
    }
   case 13:
    var $keyStr_1;
    var $64 = $args1;
    __ZN2js15InvokeArgsGuardC1Ev($64);
    var $66 = $cx + 60 | 0;
    var $67 = $cx;
    var $68 = $args1;
    var $69 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($66, $67, 2, $68);
    if ($69) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $71 = $cx;
    var $72 = $args1;
    var $73 = __ZNK2js12CallReceiver7calleevEv($72);
    var $74 = HEAP32[$52 >> 2];
    __ZN2JSL11ObjectValueER8JSObject2569($2, $74);
    var $75 = $2 | 0;
    var $st$6$0 = $75 | 0;
    var $76$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $75 + 4 | 0;
    var $76$1 = HEAP32[$st$6$1 >> 2];
    var $77 = $73 | 0;
    HEAP32[$77 >> 2] = $76$0;
    HEAP32[$77 + 4 >> 2] = $76$1;
    var $78 = __ZNK2js12CallReceiver5thisvEv($72);
    __ZN2JSL11ObjectValueER8JSObject2569($3, $holder);
    var $79 = $3 | 0;
    var $80$0 = HEAP32[$79 >> 2];
    var $80$1 = HEAP32[$79 + 4 >> 2];
    var $81 = $78 | 0;
    HEAP32[$81 >> 2] = $80$0;
    HEAP32[$81 + 4 >> 2] = $80$1;
    var $82 = $args1;
    var $83 = __ZNK2js8CallArgsixEj($82, 0);
    __ZN2JSL11StringValueEP8JSString2546($4, $keyStr_1);
    var $84 = $4 | 0;
    var $85$0 = HEAP32[$84 >> 2];
    var $85$1 = HEAP32[$84 + 4 >> 2];
    var $86 = $83 | 0;
    HEAP32[$86 >> 2] = $85$0;
    HEAP32[$86 + 4 >> 2] = $85$1;
    var $87 = __ZNK2js8CallArgsixEj($82, 1);
    var $88 = $vp | 0;
    var $89$0 = HEAP32[$88 >> 2];
    var $89$1 = HEAP32[$88 + 4 >> 2];
    var $90 = $87 | 0;
    HEAP32[$90 >> 2] = $89$0;
    HEAP32[$90 + 4 >> 2] = $89$1;
    var $91 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($71, $64, 0);
    if ($91) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $92 = __ZNK2js12CallReceiver4rvalEv($72);
    var $93 = $92 | 0;
    var $st$2$0 = $93 | 0;
    var $94$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $93 + 4 | 0;
    var $94$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $88 | 0;
    HEAP32[$st$6$0 >> 2] = $94$0;
    var $st$6$1 = $88 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $94$1;
    __ZN2js15InvokeArgsGuardD1Ev($64);
    __label__ = 17;
    break;
   case 16:
    __ZN2js15InvokeArgsGuardD1Ev($64);
    var $_3 = 0;
    __label__ = 26;
    break;
   case 17:
    var $97 = __ZNK2JS5Value8isObjectEv($vp);
    if ($97) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 18:
    var $99 = __ZNK2JS5Value8toObjectEv($vp);
    var $100 = __ZNK8JSObject8getClassEv($99);
    if (($100 | 0) == (__ZN2js11NumberClassE | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $103 = $cx;
    var $104 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($103, $vp, $d);
    if ($104) {
      __label__ = 20;
      break;
    } else {
      var $_3 = 0;
      __label__ = 26;
      break;
    }
   case 20:
    var $106 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $107 = __ZN2JS5Value9setNumberEd($vp, $106);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 21:
    if (($100 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $111 = $cx;
    var $112 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($111, $vp);
    if (($112 | 0) == 0) {
      var $_3 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JS5Value9setStringEP8JSString($vp, $112);
    var $_3 = 1;
    __label__ = 26;
    break;
   case 24:
    if (($100 | 0) == (__ZN2js12BooleanClassE | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_3 = 1;
      __label__ = 26;
      break;
    }
   case 25:
    var $118 = $99;
    var $119 = __ZNK8JSObject16getPrimitiveThisEv($118);
    var $120 = $119 | 0;
    var $st$3$0 = $120 | 0;
    var $121$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $120 + 4 | 0;
    var $121$1 = HEAP32[$st$3$1 >> 2];
    var $122 = $vp | 0;
    var $st$8$0 = $122 | 0;
    HEAP32[$st$8$0 >> 2] = $121$0;
    var $st$8$1 = $122 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $121$1;
    var $_3 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext["X"] = 1;

function __ZN14KeyStringifierIjE8toStringEP9JSContextj($cx, $index) {
  var $1 = $cx;
  var $2 = __ZN2js13IndexToStringEP9JSContextj($1, $index);
  return $2 | 0;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE($this, $cx, $sb, $gap, $replacer, $propertyList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $sb;
  HEAP32[$this + 4 >> 2] = $gap;
  HEAP32[$this + 8 >> 2] = $replacer;
  HEAP32[$this + 12 >> 2] = $propertyList;
  HEAP32[$this + 16 >> 2] = 0;
  var $7 = $this + 20 | 0;
  var $8 = $1;
  var $9 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($8, $9);
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($7, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $22 = __ZNK2JS5Value8isObjectEv($1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js11ObjectClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js11ObjectClassE, $3, $10, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js11ObjectClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj($this, $t, $needed) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] + $needed | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $this;
    var $9 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($8, $needed);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj($this, $t, $needed);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj($this, $t, $needed) {
  var $1 = $this;
  var $2 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($1);
  __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt($2, $needed, $t);
  var $3 = $this + 8 | 0;
  var $5 = HEAP32[$3 >> 2] + $needed | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZL18js_DoubleToIntegerd2596($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd2585($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd2597($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev($this) {
  __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj($5, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser5errorEPKc($this, $msg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 28 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 2, 0, 228, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $msg, tempInt));
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser10readNumberEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $digitStart = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $dummy = __stackBase__ + 12;
    var $d = __stackBase__ + 16;
    var $d1 = __stackBase__ + 24;
    var $finish = __stackBase__ + 32;
    var $3 = $this + 4 | 0;
    var $4 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $6 = HEAP16[$4 >> 1] << 16 >> 16 == 45;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $9 = $this + 8 | 0;
    var $10 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str2606 | 0);
    var $12 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $12;
    __label__ = 41;
    break;
   case 4:
    var $15 = HEAP32[$3 >> 2];
    HEAP32[$digitStart >> 2] = $15;
    var $17 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$17 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str12607 | 0);
    var $23 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $23;
    __label__ = 41;
    break;
   case 6:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3, undef);
    var $25 = __ZNK7mozilla9RangedPtrIKtEdeEv($1);
    var $_pre = $this + 8 | 0;
    if (HEAP16[$25 >> 1] << 16 >> 16 == 48) {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $_pre);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    }
   case 8:
    var $30 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$30 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 9;
      break;
    } else {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    }
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3, undef);
    __label__ = 7;
    break;
   case 10:
    var $_pre_phi;
    var $36 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($3, $_pre_phi);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $39 = HEAP16[$38 >> 1];
    if ($39 << 16 >> 16 == 46 || $39 << 16 >> 16 == 101 || $39 << 16 >> 16 == 69) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $42 = HEAP32[$this >> 2];
    var $43 = __ZNK7mozilla9RangedPtrIKtE3getEv($digitStart);
    var $44 = __ZNK7mozilla9RangedPtrIKtE3getEv($3);
    var $45 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($42, $43, $44, 10, $dummy, $d);
    if ($45) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $47 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $47;
    __label__ = 41;
    break;
   case 14:
    var $49 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($6) {
      __label__ = 15;
      break;
    } else {
      var $53 = $49;
      __label__ = 16;
      break;
    }
   case 15:
    var $53 = -$49;
    __label__ = 16;
    break;
   case 16:
    var $53;
    var $54 = __ZN10JSONParser11numberTokenEd($this, $53);
    var $_0 = 1;
    __label__ = 41;
    break;
   case 17:
    var $56 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $_pre_phi);
    if ($56) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $58 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (HEAP16[$58 >> 1] << 16 >> 16 == 46) {
      __label__ = 19;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 19:
    var $62 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $63 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($62, $_pre_phi);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str22608 | 0);
    var $65 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $65;
    __label__ = 41;
    break;
   case 21:
    var $67 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$67 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str32609 | 0);
    var $73 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $73;
    __label__ = 41;
    break;
   case 23:
    var $74 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $75 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($74, $_pre_phi);
    if ($75) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $77 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$77 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $82 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $_pre_phi);
    if ($82) {
      __label__ = 26;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 26:
    var $84 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $85 = HEAP16[$84 >> 1];
    if ($85 << 16 >> 16 == 101 || $85 << 16 >> 16 == 69) {
      __label__ = 27;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 27:
    var $87 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $88 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($87, $_pre_phi);
    if ($88) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str42610 | 0);
    var $90 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $90;
    __label__ = 41;
    break;
   case 29:
    var $92 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $93 = HEAP16[$92 >> 1];
    if ($93 << 16 >> 16 == 43 || $93 << 16 >> 16 == 45) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $95 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $96 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($95, $_pre_phi);
    if ($96) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str52611 | 0);
    var $98 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $98;
    __label__ = 41;
    break;
   case 32:
    var $100 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$100 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str62612 | 0);
    var $106 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $106;
    __label__ = 41;
    break;
   case 34:
    var $107 = __ZN7mozilla9RangedPtrIKtEppEv($3);
    var $108 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($107, $_pre_phi);
    if ($108) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    var $110 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (((HEAPU16[$110 >> 1] & 65535) - 48 | 0) >>> 0 < 10) {
      __label__ = 34;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $116 = HEAP32[$this >> 2];
    var $117 = __ZNK7mozilla9RangedPtrIKtE3getEv($digitStart);
    var $118 = __ZNK7mozilla9RangedPtrIKtE3getEv($3);
    var $119 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($116, $117, $118, $finish, $d1);
    if (($119 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $122 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $122;
    __label__ = 41;
    break;
   case 38:
    var $124 = (tempDoubleI32[0] = HEAP32[$d1 >> 2], tempDoubleI32[1] = HEAP32[$d1 + 4 >> 2], tempDoubleF64[0]);
    if ($6) {
      __label__ = 39;
      break;
    } else {
      var $128 = $124;
      __label__ = 40;
      break;
    }
   case 39:
    var $128 = -$124;
    __label__ = 40;
    break;
   case 40:
    var $128;
    var $129 = __ZN10JSONParser11numberTokenEd($this, $128);
    var $_0 = 1;
    __label__ = 41;
    break;
   case 41:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readNumberEv["X"] = 1;

function __ZN10JSONParser11numberTokenEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11NumberValueEd2666($1, $d);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL16IsJSONWhitespacet($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($c << 16 >> 16 == 9 || $c << 16 >> 16 == 13 || $c << 16 >> 16 == 10 || $c << 16 >> 16 == 32) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($this, $other) {
  return HEAPU32[$this >> 2] >>> 0 >= HEAPU32[$other >> 2] >>> 0;
}

function __ZNK7mozilla9RangedPtrIKtEmiERKS2_($this, $other) {
  return (HEAP32[$this >> 2] - HEAP32[$other >> 2] | 0) >>> 1;
}

function __ZN10JSONParser7advanceEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = $this + 4 | 0;
    var $9 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $11 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($8, $9);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $13 = __ZNK7mozilla9RangedPtrIKtEdeEv($8);
    var $14 = HEAP16[$13 >> 1];
    var $15 = __ZL16IsJSONWhitespacet($14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $8, undef);
    __label__ = 2;
    break;
   case 5:
    var $17 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($8, $9);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str72613 | 0);
    var $19 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $19;
    __label__ = 36;
    break;
   case 7:
    var $21 = __ZNK7mozilla9RangedPtrIKtEdeEv($8);
    var $23 = HEAPU16[$21 >> 1] & 65535;
    if (($23 | 0) == 34) {
      __label__ = 8;
      break;
    } else if (($23 | 0) == 45 || ($23 | 0) == 48 || ($23 | 0) == 49 || ($23 | 0) == 50 || ($23 | 0) == 51 || ($23 | 0) == 52 || ($23 | 0) == 53 || ($23 | 0) == 54 || ($23 | 0) == 55 || ($23 | 0) == 56 || ($23 | 0) == 57) {
      __label__ = 9;
      break;
    } else if (($23 | 0) == 116) {
      __label__ = 10;
      break;
    } else if (($23 | 0) == 102) {
      __label__ = 16;
      break;
    } else if (($23 | 0) == 110) {
      __label__ = 23;
      break;
    } else if (($23 | 0) == 91) {
      __label__ = 29;
      break;
    } else if (($23 | 0) == 93) {
      __label__ = 30;
      break;
    } else if (($23 | 0) == 123) {
      __label__ = 31;
      break;
    } else if (($23 | 0) == 125) {
      __label__ = 32;
      break;
    } else if (($23 | 0) == 44) {
      __label__ = 33;
      break;
    } else if (($23 | 0) == 58) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 8:
    var $25 = __ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv($this);
    var $_0 = $25;
    __label__ = 36;
    break;
   case 9:
    var $27 = __ZN10JSONParser10readNumberEv($this);
    var $_0 = $27;
    __label__ = 36;
    break;
   case 10:
    var $29 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($9, $8);
    if ($29 >>> 0 < 4) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 1);
    if (HEAP16[$32 >> 1] << 16 >> 16 == 114) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $36 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 2);
    if (HEAP16[$36 >> 1] << 16 >> 16 == 117) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $40 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 3);
    if (HEAP16[$40 >> 1] << 16 >> 16 == 101) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $44 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $44;
    __label__ = 36;
    break;
   case 15:
    var $46 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 4);
    var $47 = __ZN10JSONParser5tokenENS_5TokenE(undef, 2);
    var $_0 = $47;
    __label__ = 36;
    break;
   case 16:
    var $49 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($9, $8);
    if ($49 >>> 0 < 5) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 1);
    if (HEAP16[$52 >> 1] << 16 >> 16 == 97) {
      __label__ = 18;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $56 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 2);
    if (HEAP16[$56 >> 1] << 16 >> 16 == 108) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $60 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 3);
    if (HEAP16[$60 >> 1] << 16 >> 16 == 115) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $64 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 4);
    if (HEAP16[$64 >> 1] << 16 >> 16 == 101) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $68 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $68;
    __label__ = 36;
    break;
   case 22:
    var $70 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 5);
    var $71 = __ZN10JSONParser5tokenENS_5TokenE(undef, 3);
    var $_0 = $71;
    __label__ = 36;
    break;
   case 23:
    var $73 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($9, $8);
    if ($73 >>> 0 < 4) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 1);
    if (HEAP16[$76 >> 1] << 16 >> 16 == 117) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $80 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 2);
    if (HEAP16[$80 >> 1] << 16 >> 16 == 108) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $84 = __ZNK7mozilla9RangedPtrIKtEixEi($8, 3);
    if (HEAP16[$84 >> 1] << 16 >> 16 == 108) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str82614 | 0);
    var $88 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $88;
    __label__ = 36;
    break;
   case 28:
    var $90 = __ZN7mozilla9RangedPtrIKtEpLEj($8, 4);
    var $91 = __ZN10JSONParser5tokenENS_5TokenE(undef, 4);
    var $_0 = $91;
    __label__ = 36;
    break;
   case 29:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $8, undef);
    var $93 = __ZN10JSONParser5tokenENS_5TokenE(undef, 5);
    var $_0 = $93;
    __label__ = 36;
    break;
   case 30:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $8, undef);
    var $95 = __ZN10JSONParser5tokenENS_5TokenE(undef, 6);
    var $_0 = $95;
    __label__ = 36;
    break;
   case 31:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $8, undef);
    var $97 = __ZN10JSONParser5tokenENS_5TokenE(undef, 7);
    var $_0 = $97;
    __label__ = 36;
    break;
   case 32:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $8, undef);
    var $99 = __ZN10JSONParser5tokenENS_5TokenE(undef, 8);
    var $_0 = $99;
    __label__ = 36;
    break;
   case 33:
    __ZN7mozilla9RangedPtrIKtEppEi($6, $8, undef);
    var $101 = __ZN10JSONParser5tokenENS_5TokenE(undef, 10);
    var $_0 = $101;
    __label__ = 36;
    break;
   case 34:
    __ZN7mozilla9RangedPtrIKtEppEi($7, $8, undef);
    var $103 = __ZN10JSONParser5tokenENS_5TokenE(undef, 9);
    var $_0 = $103;
    __label__ = 36;
    break;
   case 35:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str92615 | 0);
    var $105 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $105;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser7advanceEv["X"] = 1;

function __ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $start = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $buffer = __stackBase__ + 12;
    var $3 = __stackBase__ + 92;
    var $4 = __stackBase__ + 96;
    var $5 = __stackBase__ + 100;
    var $6 = $this + 4 | 0;
    var $7 = __ZN7mozilla9RangedPtrIKtEppEv($6);
    var $8 = $this + 8 | 0;
    var $9 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($7, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str232629 | 0);
    var $11 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_1 = $11;
    __label__ = 65;
    break;
   case 3:
    var $14 = HEAP32[$6 >> 2];
    HEAP32[$start >> 2] = $14;
    __label__ = 4;
    break;
   case 4:
    var $17 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $19 = __ZNK7mozilla9RangedPtrIKtEdeEv($6);
    var $20 = HEAPU16[$19 >> 1];
    if ($20 << 16 >> 16 == 34) {
      __label__ = 6;
      break;
    } else if ($20 << 16 >> 16 == 92) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $22 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($6, $start);
    __ZN7mozilla9RangedPtrIKtEppEi($1, $6, undef);
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZNK7mozilla9RangedPtrIKtE3getEv($start);
    var $26 = $24;
    var $27 = __Z17js_NewStringCopyNP9JSContextPKtj($26, $25, $22);
    if (($27 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_1 = $30;
    __label__ = 65;
    break;
   case 8:
    var $32 = $27 | 0;
    var $33 = __ZN10JSONParser11stringTokenEP8JSString($this, $32);
    var $_1 = 0;
    __label__ = 65;
    break;
   case 9:
    if (($20 & 65535) < 32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str242630 | 0);
    var $37 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_1 = $37;
    __label__ = 65;
    break;
   case 11:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $6, undef);
    __label__ = 4;
    break;
   case 12:
    var $41 = HEAP32[$this >> 2];
    __ZN2js12StringBufferC1EP9JSContext($buffer, $41);
    var $42 = $buffer;
    __label__ = 13;
    break;
   case 13:
    var $44 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($start, $6);
    if ($44) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $46 = __ZNK7mozilla9RangedPtrIKtE3getEv($start);
    var $47 = __ZNK7mozilla9RangedPtrIKtE3getEv($6);
    var $48 = __ZN2js12StringBuffer6appendEPKtS2_($42, $46, $47);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $50;
    __label__ = 64;
    break;
   case 16:
    var $52 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($6, $8);
    if ($52) {
      __label__ = 63;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $6, undef);
    var $54 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $55 = HEAP16[$54 >> 1];
    if ($55 << 16 >> 16 == 34) {
      __label__ = 18;
      break;
    } else if ($55 << 16 >> 16 == 92) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $57 = $buffer;
    var $58 = __ZN2js12StringBuffer12finishStringEv($57);
    if (($58 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $61 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $61;
    __label__ = 64;
    break;
   case 20:
    var $63 = $58 | 0;
    var $64 = __ZN10JSONParser11stringTokenEP8JSString($this, $63);
    var $_0 = 0;
    __label__ = 64;
    break;
   case 21:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str252631 | 0);
    var $66 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $66;
    __label__ = 64;
    break;
   case 22:
    var $68 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($6, $8);
    if ($68) {
      __label__ = 63;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $6, undef);
    var $70 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $72 = HEAPU16[$70 >> 1] & 65535;
    if (($72 | 0) == 47) {
      __label__ = 24;
      break;
    } else if (($72 | 0) == 92) {
      __label__ = 25;
      break;
    } else if (($72 | 0) == 98) {
      __label__ = 26;
      break;
    } else if (($72 | 0) == 102) {
      __label__ = 27;
      break;
    } else if (($72 | 0) == 110) {
      __label__ = 28;
      break;
    } else if (($72 | 0) == 114) {
      __label__ = 29;
      break;
    } else if (($72 | 0) == 116) {
      __label__ = 30;
      break;
    } else if (($72 | 0) == 117) {
      __label__ = 31;
      break;
    } else if (($72 | 0) == 34) {
      var $c_0 = 34;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 24:
    var $c_0 = 47;
    __label__ = 55;
    break;
   case 25:
    var $c_0 = 92;
    __label__ = 55;
    break;
   case 26:
    var $c_0 = 8;
    __label__ = 55;
    break;
   case 27:
    var $c_0 = 12;
    __label__ = 55;
    break;
   case 28:
    var $c_0 = 10;
    __label__ = 55;
    break;
   case 29:
    var $c_0 = 13;
    __label__ = 55;
    break;
   case 30:
    var $c_0 = 9;
    __label__ = 55;
    break;
   case 31:
    var $81 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($8, $6);
    if ($81 >>> 0 < 4) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str262632 | 0);
    var $84 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $84;
    __label__ = 64;
    break;
   case 33:
    var $86 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    if ((HEAPU16[$86 >> 1] & 65535) < 128) {
      __label__ = 34;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 34:
    var $90 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $92 = HEAPU16[$90 >> 1] & 65535;
    var $93 = _isxdigit($92);
    if (($93 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $96 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    if ((HEAPU16[$96 >> 1] & 65535) < 128) {
      __label__ = 36;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 36:
    var $100 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $102 = HEAPU16[$100 >> 1] & 65535;
    var $103 = _isxdigit($102);
    if (($103 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $106 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    if ((HEAPU16[$106 >> 1] & 65535) < 128) {
      __label__ = 38;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 38:
    var $110 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $112 = HEAPU16[$110 >> 1] & 65535;
    var $113 = _isxdigit($112);
    if (($113 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $116 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    if ((HEAPU16[$116 >> 1] & 65535) < 128) {
      __label__ = 40;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 40:
    var $120 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $122 = HEAPU16[$120 >> 1] & 65535;
    var $123 = _isxdigit($122);
    if (($123 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $126 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $130 = ((HEAPU16[$126 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $131 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $133 = HEAPU16[$131 >> 1] & 65535;
    if ($130) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $140 = $133 - 48 | 0;
    __label__ = 44;
    break;
   case 43:
    var $137 = _tolower($133);
    var $140 = $137 - 87 | 0;
    __label__ = 44;
    break;
   case 44:
    var $140;
    var $141 = $140 << 12;
    var $142 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $146 = ((HEAPU16[$142 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $147 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $149 = HEAPU16[$147 >> 1] & 65535;
    if ($146) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $156 = $149 - 48 | 0;
    __label__ = 47;
    break;
   case 46:
    var $153 = _tolower($149);
    var $156 = $153 - 87 | 0;
    __label__ = 47;
    break;
   case 47:
    var $156;
    var $157 = $156 << 8;
    var $158 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $162 = ((HEAPU16[$158 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $163 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $165 = HEAPU16[$163 >> 1] & 65535;
    if ($162) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $172 = $165 - 48 | 0;
    __label__ = 50;
    break;
   case 49:
    var $169 = _tolower($165);
    var $172 = $169 - 87 | 0;
    __label__ = 50;
    break;
   case 50:
    var $172;
    var $173 = $172 << 4;
    var $174 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $178 = ((HEAPU16[$174 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $179 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $181 = HEAPU16[$179 >> 1] & 65535;
    if ($178) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $188 = $181 - 48 | 0;
    __label__ = 53;
    break;
   case 52:
    var $185 = _tolower($181);
    var $188 = $185 - 87 | 0;
    __label__ = 53;
    break;
   case 53:
    var $188;
    var $192 = ($157 | $141 | $173 | $188) & 65535;
    var $193 = __ZN7mozilla9RangedPtrIKtEpLEj($6, 4);
    var $c_0 = $192;
    __label__ = 55;
    break;
   case 54:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str272633 | 0);
    var $195 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $195;
    __label__ = 64;
    break;
   case 55:
    var $c_0;
    var $197 = __ZN2js12StringBuffer6appendEt($buffer, $c_0);
    if ($197) {
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $199 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $199;
    __label__ = 64;
    break;
   case 57:
    var $201 = __ZN7mozilla9RangedPtrIKtEaSERKS2_($start, $6);
    __label__ = 58;
    break;
   case 58:
    var $203 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($203) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $205 = __ZNK7mozilla9RangedPtrIKtEdeEv($6);
    var $206 = HEAPU16[$205 >> 1];
    if ($206 << 16 >> 16 == 34 || $206 << 16 >> 16 == 92) {
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    if (($206 & 65535) < 32) {
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $6, undef);
    __label__ = 58;
    break;
   case 62:
    var $211 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($211) {
      __label__ = 13;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str282634 | 0);
    var $213 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $213;
    __label__ = 64;
    break;
   case 64:
    var $_0;
    __ZN2js12StringBufferD1Ev($buffer);
    var $_1 = $_0;
    __label__ = 65;
    break;
   case 65:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv["X"] = 1;

function __ZNK7mozilla9RangedPtrIKtEixEi($this, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $4 = HEAP32[$this >> 2] + ($index << 1) | 0;
  __ZNK7mozilla9RangedPtrIKtE6createEPS1_($1, undef, $4);
  var $5 = __ZNK7mozilla9RangedPtrIKtEdeEv($1);
  STACKTOP = __stackBase__;
  return $5;
}

function __ZN10JSONParser22advanceAfterObjectOpenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $4 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $6 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $4);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZL16IsJSONWhitespacet($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3, undef);
    __label__ = 2;
    break;
   case 5:
    var $12 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($3, $4);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str102616 | 0);
    var $14 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 7:
    var $16 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $17 = HEAP16[$16 >> 1];
    if ($17 << 16 >> 16 == 34) {
      __label__ = 8;
      break;
    } else if ($17 << 16 >> 16 == 125) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $19 = __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this);
    var $_0 = $19;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3, undef);
    var $21 = __ZN10JSONParser5tokenENS_5TokenE(undef, 8);
    var $_0 = $21;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str112617 | 0);
    var $23 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $23;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10JSONParser11stringValueEv($agg_result, $this) {
  var $1 = $this + 16 | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $agg_result | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZNK10JSONParser11numberValueEv($agg_result, $this) {
  var $1 = $this + 16 | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $agg_result | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  return;
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $start = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $buffer = __stackBase__ + 12;
    var $3 = __stackBase__ + 92;
    var $4 = __stackBase__ + 96;
    var $5 = __stackBase__ + 100;
    var $6 = $this + 4 | 0;
    var $7 = __ZN7mozilla9RangedPtrIKtEppEv($6);
    var $8 = $this + 8 | 0;
    var $9 = __ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE($7, $8);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str232629 | 0);
    var $11 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_1 = $11;
    __label__ = 65;
    break;
   case 3:
    var $14 = HEAP32[$6 >> 2];
    HEAP32[$start >> 2] = $14;
    __label__ = 4;
    break;
   case 4:
    var $17 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $19 = __ZNK7mozilla9RangedPtrIKtEdeEv($6);
    var $20 = HEAPU16[$19 >> 1];
    if ($20 << 16 >> 16 == 34) {
      __label__ = 6;
      break;
    } else if ($20 << 16 >> 16 == 92) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $22 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($6, $start);
    __ZN7mozilla9RangedPtrIKtEppEi($1, $6, undef);
    var $24 = HEAP32[$this >> 2];
    var $25 = __ZNK7mozilla9RangedPtrIKtE3getEv($start);
    var $26 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($24, $25, $22, 0);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_1 = $29;
    __label__ = 65;
    break;
   case 8:
    var $31 = $26 | 0;
    var $32 = __ZN10JSONParser11stringTokenEP8JSString($this, $31);
    var $_1 = 0;
    __label__ = 65;
    break;
   case 9:
    if (($20 & 65535) < 32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str242630 | 0);
    var $36 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_1 = $36;
    __label__ = 65;
    break;
   case 11:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $6, undef);
    __label__ = 4;
    break;
   case 12:
    var $40 = HEAP32[$this >> 2];
    __ZN2js12StringBufferC1EP9JSContext($buffer, $40);
    var $41 = $buffer;
    __label__ = 13;
    break;
   case 13:
    var $43 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($start, $6);
    if ($43) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $45 = __ZNK7mozilla9RangedPtrIKtE3getEv($start);
    var $46 = __ZNK7mozilla9RangedPtrIKtE3getEv($6);
    var $47 = __ZN2js12StringBuffer6appendEPKtS2_($41, $45, $46);
    if ($47) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $49;
    __label__ = 64;
    break;
   case 16:
    var $51 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($6, $8);
    if ($51) {
      __label__ = 63;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $6, undef);
    var $53 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $54 = HEAP16[$53 >> 1];
    if ($54 << 16 >> 16 == 34) {
      __label__ = 18;
      break;
    } else if ($54 << 16 >> 16 == 92) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 18:
    var $56 = $buffer;
    var $57 = __ZN2js12StringBuffer10finishAtomEv($56);
    if (($57 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $60 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $60;
    __label__ = 64;
    break;
   case 20:
    var $62 = $57 | 0;
    var $63 = __ZN10JSONParser11stringTokenEP8JSString($this, $62);
    var $_0 = 0;
    __label__ = 64;
    break;
   case 21:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str252631 | 0);
    var $65 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $65;
    __label__ = 64;
    break;
   case 22:
    var $67 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($6, $8);
    if ($67) {
      __label__ = 63;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN7mozilla9RangedPtrIKtEppEi($4, $6, undef);
    var $69 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $71 = HEAPU16[$69 >> 1] & 65535;
    if (($71 | 0) == 47) {
      __label__ = 24;
      break;
    } else if (($71 | 0) == 92) {
      __label__ = 25;
      break;
    } else if (($71 | 0) == 98) {
      __label__ = 26;
      break;
    } else if (($71 | 0) == 102) {
      __label__ = 27;
      break;
    } else if (($71 | 0) == 110) {
      __label__ = 28;
      break;
    } else if (($71 | 0) == 114) {
      __label__ = 29;
      break;
    } else if (($71 | 0) == 116) {
      __label__ = 30;
      break;
    } else if (($71 | 0) == 117) {
      __label__ = 31;
      break;
    } else if (($71 | 0) == 34) {
      var $c_0 = 34;
      __label__ = 55;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 24:
    var $c_0 = 47;
    __label__ = 55;
    break;
   case 25:
    var $c_0 = 92;
    __label__ = 55;
    break;
   case 26:
    var $c_0 = 8;
    __label__ = 55;
    break;
   case 27:
    var $c_0 = 12;
    __label__ = 55;
    break;
   case 28:
    var $c_0 = 10;
    __label__ = 55;
    break;
   case 29:
    var $c_0 = 13;
    __label__ = 55;
    break;
   case 30:
    var $c_0 = 9;
    __label__ = 55;
    break;
   case 31:
    var $80 = __ZNK7mozilla9RangedPtrIKtEmiERKS2_($8, $6);
    if ($80 >>> 0 < 4) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str262632 | 0);
    var $83 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $83;
    __label__ = 64;
    break;
   case 33:
    var $85 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    if ((HEAPU16[$85 >> 1] & 65535) < 128) {
      __label__ = 34;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 34:
    var $89 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $91 = HEAPU16[$89 >> 1] & 65535;
    var $92 = _isxdigit($91);
    if (($92 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $95 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    if ((HEAPU16[$95 >> 1] & 65535) < 128) {
      __label__ = 36;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 36:
    var $99 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $101 = HEAPU16[$99 >> 1] & 65535;
    var $102 = _isxdigit($101);
    if (($102 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $105 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    if ((HEAPU16[$105 >> 1] & 65535) < 128) {
      __label__ = 38;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 38:
    var $109 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $111 = HEAPU16[$109 >> 1] & 65535;
    var $112 = _isxdigit($111);
    if (($112 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $115 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    if ((HEAPU16[$115 >> 1] & 65535) < 128) {
      __label__ = 40;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 40:
    var $119 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $121 = HEAPU16[$119 >> 1] & 65535;
    var $122 = _isxdigit($121);
    if (($122 | 0) == 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $125 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $129 = ((HEAPU16[$125 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $130 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 0);
    var $132 = HEAPU16[$130 >> 1] & 65535;
    if ($129) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    var $139 = $132 - 48 | 0;
    __label__ = 44;
    break;
   case 43:
    var $136 = _tolower($132);
    var $139 = $136 - 87 | 0;
    __label__ = 44;
    break;
   case 44:
    var $139;
    var $140 = $139 << 12;
    var $141 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $145 = ((HEAPU16[$141 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $146 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 1);
    var $148 = HEAPU16[$146 >> 1] & 65535;
    if ($145) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $155 = $148 - 48 | 0;
    __label__ = 47;
    break;
   case 46:
    var $152 = _tolower($148);
    var $155 = $152 - 87 | 0;
    __label__ = 47;
    break;
   case 47:
    var $155;
    var $156 = $155 << 8;
    var $157 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $161 = ((HEAPU16[$157 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $162 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 2);
    var $164 = HEAPU16[$162 >> 1] & 65535;
    if ($161) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $171 = $164 - 48 | 0;
    __label__ = 50;
    break;
   case 49:
    var $168 = _tolower($164);
    var $171 = $168 - 87 | 0;
    __label__ = 50;
    break;
   case 50:
    var $171;
    var $172 = $171 << 4;
    var $173 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $177 = ((HEAPU16[$173 >> 1] & 65535) - 48 | 0) >>> 0 < 10;
    var $178 = __ZNK7mozilla9RangedPtrIKtEixEi($6, 3);
    var $180 = HEAPU16[$178 >> 1] & 65535;
    if ($177) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $187 = $180 - 48 | 0;
    __label__ = 53;
    break;
   case 52:
    var $184 = _tolower($180);
    var $187 = $184 - 87 | 0;
    __label__ = 53;
    break;
   case 53:
    var $187;
    var $191 = ($156 | $140 | $172 | $187) & 65535;
    var $192 = __ZN7mozilla9RangedPtrIKtEpLEj($6, 4);
    var $c_0 = $191;
    __label__ = 55;
    break;
   case 54:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str272633 | 0);
    var $194 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $194;
    __label__ = 64;
    break;
   case 55:
    var $c_0;
    var $196 = __ZN2js12StringBuffer6appendEt($buffer, $c_0);
    if ($196) {
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $198 = __ZN10JSONParser5tokenENS_5TokenE(undef, 11);
    var $_0 = $198;
    __label__ = 64;
    break;
   case 57:
    var $200 = __ZN7mozilla9RangedPtrIKtEaSERKS2_($start, $6);
    __label__ = 58;
    break;
   case 58:
    var $202 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($202) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    var $204 = __ZNK7mozilla9RangedPtrIKtEdeEv($6);
    var $205 = HEAPU16[$204 >> 1];
    if ($205 << 16 >> 16 == 34 || $205 << 16 >> 16 == 92) {
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    if (($205 & 65535) < 32) {
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    __ZN7mozilla9RangedPtrIKtEppEi($5, $6, undef);
    __label__ = 58;
    break;
   case 62:
    var $210 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($6, $8);
    if ($210) {
      __label__ = 13;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str282634 | 0);
    var $212 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $212;
    __label__ = 64;
    break;
   case 64:
    var $_0;
    __ZN2js12StringBufferD1Ev($buffer);
    var $_1 = $_0;
    __label__ = 65;
    break;
   case 65:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv["X"] = 1;

function __ZN10JSONParser24advanceAfterArrayElementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = $this + 4 | 0;
    var $5 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($4, $5);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $10 = HEAP16[$9 >> 1];
    var $11 = __ZL16IsJSONWhitespacet($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $4, undef);
    __label__ = 2;
    break;
   case 5:
    var $13 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($4, $5);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str122618 | 0);
    var $15 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 7:
    var $17 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $18 = HEAP16[$17 >> 1];
    if ($18 << 16 >> 16 == 44) {
      __label__ = 8;
      break;
    } else if ($18 << 16 >> 16 == 93) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $4, undef);
    var $20 = __ZN10JSONParser5tokenENS_5TokenE(undef, 10);
    var $_0 = $20;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $4, undef);
    var $22 = __ZN10JSONParser5tokenENS_5TokenE(undef, 6);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str132619 | 0);
    var $24 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $24;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser19advancePropertyNameEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $4 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $6 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $4);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZL16IsJSONWhitespacet($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3, undef);
    __label__ = 2;
    break;
   case 5:
    var $12 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($3, $4);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str142620 | 0);
    var $14 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 7:
    var $16 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $17 = HEAP16[$16 >> 1];
    if ($17 << 16 >> 16 == 34) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $20 = __ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv($this);
    var $_0 = $20;
    __label__ = 12;
    break;
   case 9:
    if ((HEAP32[$this + 24 >> 2] | 0) == 1 & $17 << 16 >> 16 == 125) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3, undef);
    var $27 = __ZN10JSONParser5tokenENS_5TokenE(undef, 8);
    var $_0 = $27;
    __label__ = 12;
    break;
   case 11:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str152621 | 0);
    var $29 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $29;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser20advancePropertyColonEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $this + 4 | 0;
    var $4 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $6 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($3, $4);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZL16IsJSONWhitespacet($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $3, undef);
    __label__ = 2;
    break;
   case 5:
    var $12 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($3, $4);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str162622 | 0);
    var $14 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $14;
    __label__ = 10;
    break;
   case 7:
    var $16 = __ZNK7mozilla9RangedPtrIKtEdeEv($3);
    if (HEAP16[$16 >> 1] << 16 >> 16 == 58) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $3, undef);
    var $20 = __ZN10JSONParser5tokenENS_5TokenE(undef, 9);
    var $_0 = $20;
    __label__ = 10;
    break;
   case 9:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str172623 | 0);
    var $22 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $22;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser20advanceAfterPropertyEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = $this + 4 | 0;
    var $5 = $this + 8 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($4, $5);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $10 = HEAP16[$9 >> 1];
    var $11 = __ZL16IsJSONWhitespacet($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN7mozilla9RangedPtrIKtEppEi($1, $4, undef);
    __label__ = 2;
    break;
   case 5:
    var $13 = __ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE($4, $5);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str182624 | 0);
    var $15 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 7:
    var $17 = __ZNK7mozilla9RangedPtrIKtEdeEv($4);
    var $18 = HEAP16[$17 >> 1];
    if ($18 << 16 >> 16 == 44) {
      __label__ = 8;
      break;
    } else if ($18 << 16 >> 16 == 125) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    __ZN7mozilla9RangedPtrIKtEppEi($2, $4, undef);
    var $20 = __ZN10JSONParser5tokenENS_5TokenE(undef, 10);
    var $_0 = $20;
    __label__ = 11;
    break;
   case 9:
    __ZN7mozilla9RangedPtrIKtEppEi($3, $4, undef);
    var $22 = __ZN10JSONParser5tokenENS_5TokenE(undef, 8);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 10:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str192625 | 0);
    var $24 = __ZN10JSONParser5tokenENS_5TokenE(undef, 12);
    var $_0 = $24;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSONParser5parseEPN2JS5ValueE($this, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 212;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stateStack = __stackBase__;
    var $1 = __stackBase__ + 24;
    var $valueStack = __stackBase__ + 28;
    var $2 = __stackBase__ + 120;
    var $v = __stackBase__ + 128;
    var $3 = __stackBase__ + 136;
    var $4 = __stackBase__ + 144;
    var $v1 = __stackBase__ + 152;
    var $5 = __stackBase__ + 160;
    var $6 = __stackBase__ + 168;
    var $7 = __stackBase__ + 176;
    var $8 = __stackBase__ + 184;
    var $9 = __stackBase__ + 192;
    var $10 = __stackBase__ + 200;
    var $11 = __stackBase__ + 208;
    var $12 = $this | 0;
    var $13 = HEAP32[$12 >> 2];
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $13);
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_($stateStack, $1);
    var $14 = HEAP32[$12 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($valueStack, $14);
    __ZN2JSL14UndefinedValueEv2637($2);
    var $15 = $2 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = $valueStack | 0;
    var $19 = $this + 24 | 0;
    var $state_0 = 2;
    __label__ = 2;
    break;
   case 2:
    var $state_0;
    if (($state_0 | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($state_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else if (($state_0 | 0) == 2) {
      __label__ = 19;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 3:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($v, $18);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($3, $18);
    var $22 = __ZNK2JS5Value8toStringEv($3);
    var $23 = __ZNK8JSString6asAtomEv($22);
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom2638($23);
    var $25 = HEAP32[$12 >> 2];
    var $26 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($18);
    var $27 = __ZNK2JS5Value8toObjectEv($26);
    var $28 = $25;
    var $29 = $27;
    var $30 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($28, $29, $24, $v, 10, 12, 1, 0, 0, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = __ZN10JSONParser20advanceAfterPropertyEv($this);
    if (($33 | 0) == 12) {
      __label__ = 6;
      break;
    } else if (($33 | 0) == 10) {
      __label__ = 7;
      break;
    } else if (($33 | 0) == 8) {
      __label__ = 40;
      break;
    } else if (($33 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str202626 | 0);
    __label__ = 6;
    break;
   case 6:
    var $35 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $35;
    __label__ = 48;
    break;
   case 7:
    var $37 = __ZN10JSONParser19advancePropertyNameEv($this);
    var $token_0 = $37;
    __label__ = 8;
    break;
   case 8:
    var $token_0;
    if (($token_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else if (($token_0 | 0) == 12) {
      __label__ = 14;
      break;
    } else if (($token_0 | 0) == 8) {
      __label__ = 40;
      break;
    } else if (($token_0 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    __ZNK10JSONParser9atomValueEv($4, $this);
    var $40 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $4);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 10:
    var $42 = __ZN10JSONParser20advancePropertyColonEv($this);
    if (($42 | 0) == 9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $45;
    __label__ = 48;
    break;
   case 12:
    var $47 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 1);
    if ($47) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 13:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str212627 | 0);
    __label__ = 14;
    break;
   case 14:
    var $49 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $49;
    __label__ = 48;
    break;
   case 15:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($v1, $18);
    var $51 = HEAP32[$12 >> 2];
    var $52 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv($18);
    var $53 = __ZNK2JS5Value8toObjectEv($52);
    var $54 = __Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE($51, $53, $v1);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $57 = __ZN10JSONParser24advanceAfterArrayElementEv($this);
    if (($57 | 0) == 10) {
      __label__ = 17;
      break;
    } else if (($57 | 0) == 6) {
      __label__ = 40;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $59 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 0);
    if ($59) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 18:
    var $61 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $61;
    __label__ = 48;
    break;
   case 19:
    var $63 = __ZN10JSONParser7advanceEv($this);
    var $token_1 = $63;
    __label__ = 20;
    break;
   case 20:
    var $token_1;
    if (($token_1 | 0) == 0) {
      __label__ = 21;
      break;
    } else if (($token_1 | 0) == 1) {
      __label__ = 22;
      break;
    } else if (($token_1 | 0) == 2) {
      __label__ = 24;
      break;
    } else if (($token_1 | 0) == 3) {
      __label__ = 25;
      break;
    } else if (($token_1 | 0) == 4) {
      __label__ = 26;
      break;
    } else if (($token_1 | 0) == 5) {
      __label__ = 27;
      break;
    } else if (($token_1 | 0) == 7) {
      __label__ = 31;
      break;
    } else if (($token_1 | 0) == 6) {
      __label__ = 34;
      break;
    } else if (($token_1 | 0) == 8 || ($token_1 | 0) == 9 || ($token_1 | 0) == 10) {
      __label__ = 38;
      break;
    } else if (($token_1 | 0) == 12) {
      __label__ = 39;
      break;
    } else if (($token_1 | 0) == 11) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 21:
    __ZNK10JSONParser11stringValueEv($5, $this);
    __label__ = 23;
    break;
   case 22:
    __ZNK10JSONParser11numberValueEv($5, $this);
    __label__ = 23;
    break;
   case 23:
    var $68 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $5);
    if ($68) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 24:
    __ZN2JSL12BooleanValueEb2639($6, 1);
    var $70 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $6);
    if ($70) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 25:
    __ZN2JSL12BooleanValueEb2639($7, 0);
    var $72 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $7);
    if ($72) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 26:
    __ZN2JSL9NullValueEv2640($8);
    var $74 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $8);
    if ($74) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 27:
    var $76 = HEAP32[$12 >> 2];
    var $77 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($76, 0);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN2JSL11ObjectValueER8JSObject2641($9, $77);
    var $80 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $9);
    if ($80) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 29:
    var $82 = __ZN10JSONParser7advanceEv($this);
    if (($82 | 0) == 6) {
      __label__ = 40;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $85 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($stateStack, 0);
    if ($85) {
      var $token_1 = $82;
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 31:
    var $87 = HEAP32[$12 >> 2];
    var $88 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642($87);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    __ZN2JSL11ObjectValueER8JSObject2641($10, $88);
    var $91 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($18, $10);
    if ($91) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 48;
      break;
    }
   case 33:
    var $93 = __ZN10JSONParser22advanceAfterObjectOpenEv($this);
    if (($93 | 0) == 8) {
      __label__ = 40;
      break;
    } else {
      var $token_0 = $93;
      __label__ = 8;
      break;
    }
   case 34:
    if ((HEAP32[$19 >> 2] | 0) == 1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 35:
    var $99 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($stateStack);
    if ($99) {
      __label__ = 38;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $101 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($stateStack);
    if ((HEAP32[$101 >> 2] | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($stateStack);
    __label__ = 40;
    break;
   case 38:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str92615 | 0);
    var $105 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $105;
    __label__ = 48;
    break;
   case 39:
    var $107 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $107;
    __label__ = 48;
    break;
   case 40:
    var $108 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv($stateStack);
    if ($108) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $109 = $this + 4 | 0;
    var $110 = $this + 8 | 0;
    __label__ = 43;
    break;
   case 42:
    var $112 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv($stateStack);
    var $state_0 = $112;
    __label__ = 2;
    break;
   case 43:
    var $114 = __ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE($109, $110);
    if ($114) {
      __label__ = 44;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 44:
    var $116 = __ZNK7mozilla9RangedPtrIKtEdeEv($109);
    var $117 = HEAP16[$116 >> 1];
    var $118 = __ZL16IsJSONWhitespacet($117);
    if ($118) {
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    __ZN10JSONParser5errorEPKc($this, STRING_TABLE.__str222628 | 0);
    var $120 = __ZN10JSONParser11errorReturnEv($this);
    var $_0 = $120;
    __label__ = 48;
    break;
   case 46:
    __ZN7mozilla9RangedPtrIKtEppEi($11, $109, undef);
    __label__ = 43;
    break;
   case 47:
    var $123 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($18, 0);
    var $124 = $123 | 0;
    var $125$0 = HEAP32[$124 >> 2];
    var $125$1 = HEAP32[$124 + 4 >> 2];
    HEAP32[$17 >> 2] = $125$0;
    HEAP32[$17 + 4 >> 2] = $125$1;
    var $_0 = 1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($valueStack);
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev($stateStack);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10JSONParser5parseEPN2JS5ValueE["X"] = 1;

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL14UndefinedValueEv2637($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv($agg_result, $this) {
  var $1 = $this + 12 | 0;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv($agg_result, $1);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2638($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2665($1);
  return $2;
}

function __ZNK10JSONParser9atomValueEv($agg_result, $this) {
  __ZNK10JSONParser11stringValueEv($agg_result, $this);
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12BooleanValueEb2639($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2JSL9NullValueEv2640($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2JSL11ObjectValueER8JSObject2641($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642($cx) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb2650($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651($cx, $4);
  return $5;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZL14JSID_FROM_BITSj2665($bits) {
  return $bits;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefI11ParserStateEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN7mozilla9RangedPtrIKtEaSERKS2_($this, $other) {
  var $2 = HEAP32[$other >> 2];
  HEAP32[$this >> 2] = $2;
  return $this;
}

function __ZN2js2gcL15GetGCObjectKindEjb2650($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_GetVariableBytecodeLength4JSOpPh($op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 70) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 149) {
      var $jmplen_0 = 4;
      __label__ = 3;
      break;
    } else if (($op | 0) == 150) {
      var $jmplen_1 = 4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $jmplen_0 = 2;
    __label__ = 3;
    break;
   case 3:
    var $jmplen_0;
    var $_sum23 = $jmplen_0 | 1;
    var $_0 = $_sum23 + 4 + (1 - (((HEAPU8[$pc + $_sum23 | 0] & 255) << 8 | HEAPU8[$jmplen_0 + ($pc + 2) | 0] & 255) << 16 >> 16) + (((HEAPU8[$jmplen_0 + ($pc + 3) | 0] & 255) << 8 | HEAPU8[$jmplen_0 + ($pc + 4) | 0] & 255) << 16 >> 16)) * $jmplen_0 | 0;
    __label__ = 6;
    break;
   case 4:
    var $jmplen_1 = 2;
    __label__ = 5;
    break;
   case 5:
    var $jmplen_1;
    var $_sum1 = $jmplen_1 | 1;
    var $_sum = $jmplen_1 + 2 | 0;
    var $_0 = $_sum1 + 2 + ((HEAPU8[$pc + $_sum1 | 0] & 255) << 8 | HEAPU8[$pc + $_sum | 0] & 255) * $_sum | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetVariableStackUses($op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 11) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 202) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 210) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    __label__ = 6;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    __label__ = 6;
    break;
   case 4:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) + 1 | 0;
    __label__ = 6;
    break;
   case 5:
    var $_0 = ((HEAPU8[$pc + 1 | 0] & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255) + 2 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv($this) {
  var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv($this);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj1EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap << 2;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_($1, $src_02);
    var $13 = __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($1);
    var $14 = HEAP32[$13 >> 2];
    HEAP32[$dst_01 >> 2] = $14;
    __label__ = 5;
    break;
   case 5:
    var $16 = $dst_01 + 4 | 0;
    var $17 = $src_02 + 4 | 0;
    var $18 = __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($17 | 0) == ($18 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $16;
      var $src_02 = $17;
      __label__ = 3;
      break;
    }
   case 6:
    var $20 = $v + 4 | 0;
    var $22 = HEAP32[$20 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $22);
    HEAP32[$20 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefI11ParserStateEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefI11ParserStateEC1ERS1_($this, $t) {
  __ZN2js7MoveRefI11ParserStateEC2ERS1_($this, $t);
  return;
}

function __ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_($1, $p_01);
    var $5 = __ZNK2js7MoveRefI11ParserStateEcvRS1_Ev($1);
    var $6 = HEAP32[$5 >> 2];
    HEAP32[$_02 >> 2] = $6;
    __label__ = 4;
    break;
   case 4:
    var $8 = $p_01 + 4 | 0;
    if (($8 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $8;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefI11ParserStateEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv($agg_result, $this) {
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $agg_result | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv($this);
  return;
}

function __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 8 | 0;
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj1EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN10JSONParser11stringTokenEP8JSString($this, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11StringValueEP8JSString2648($1, $str);
  var $2 = $1 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $this + 16 | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2JSL11StringValueEP8JSString2648($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js11ObjectClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd2666($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function _js_GetIndexFromBytecode($cx, $script, $pc, $pcoff) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc);
    var $4 = HEAP8[_js_CodeSpec + ($1 << 3) | 0] << 24 >> 24;
    if (($4 + $pc - HEAP32[$script >> 2] | 0) >>> 0 < HEAPU32[$script + 8 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $base_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $15 = $pc + $4 | 0;
    var $16 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $15);
    if (($16 | 0) == 192) {
      __label__ = 3;
      break;
    } else if (($16 | 0) == 193) {
      __label__ = 4;
      break;
    } else {
      var $base_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $base_0 = (HEAPU8[$pc - 1 | 0] & 255) << 16;
    __label__ = 5;
    break;
   case 4:
    var $23 = $pc - 1 | 0;
    var $24 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $23);
    var $base_0 = ($24 << 16) - 13762560 | 0;
    __label__ = 5;
    break;
   case 5:
    var $base_0;
    return HEAPU8[$pcoff + ($pc + 2) | 0] & 255 | $base_0 | (HEAPU8[$pcoff + ($pc + 1) | 0] & 255) << 8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetEnterBlockStackDefs($cx, $script, $pc) {
  var $1 = _js_GetIndexFromBytecode($cx, $script, $pc, 0);
  var $2 = __ZN8JSScript9getObjectEj($script, $1);
  var $3 = $2;
  var $4 = __ZNK8JSObject13propertyCountEv($3);
  return $4;
}

function __ZN2js19SprintReserveAmountEPNS_8SprinterEj($sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $len);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $sp + 16 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $len | 0;
    HEAP32[$4 >> 2] = $6;
    var $_0 = HEAP32[$sp + 8 >> 2] + $5 | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = $len + 1 + HEAP32[$sp + 16 >> 2] | 0;
    var $5 = $sp + 12 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $7 = $4 - $6 | 0;
    if (($7 | 0) < 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $sp + 8 | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $14 = HEAPU32[$sp + 4 >> 2];
    var $16 = HEAPU32[$14 + 16 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $19 = HEAP32[$14 + 24 >> 2];
    var $22 = $19 + $7 & ($19 ^ -1);
    var $23 = $16 + 12 | 0;
    var $24 = HEAPU32[$23 >> 2];
    var $26 = HEAPU32[$16 + 8 >> 2];
    if ($22 >>> 0 > $26 >>> 0 | $24 >>> 0 > ($26 - $22 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $31 = _JS_ArenaAllocate($14, $22);
    var $_p_0 = $31;
    __label__ = 6;
    break;
   case 5:
    var $34 = $22 + $24 | 0;
    HEAP32[$23 >> 2] = $34;
    var $_p_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    var $base_0 = $_p_0;
    __label__ = 14;
    break;
   case 7:
    var $38 = $16 + 12 | 0;
    var $40 = $11;
    var $42 = HEAP32[$14 + 24 >> 2];
    var $44 = $42 ^ -1;
    if ((HEAP32[$38 >> 2] | 0) == (($42 + $6 & $44) + $40 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $50 = $42 + $4 & $44;
    var $52 = HEAPU32[$16 + 8 >> 2];
    if ($52 >>> 0 < $50 >>> 0 | $40 >>> 0 > ($52 - $50 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $57 = $50 + $40 | 0;
    HEAP32[$38 >> 2] = $57;
    var $base_0 = $11;
    __label__ = 14;
    break;
   case 10:
    if (($40 | 0) == (HEAP32[$16 + 4 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $63 = _JS_ArenaRealloc($14, $11, $6, $7);
    var $base_0 = $63;
    __label__ = 14;
    break;
   case 12:
    var $65 = _JS_ArenaGrow($14, $11, $6, $7);
    var $base_0 = $65;
    __label__ = 14;
    break;
   case 13:
    var $67 = _JS_ArenaGrow($14, $11, $6, $7);
    var $base_0 = $67;
    __label__ = 14;
    break;
   case 14:
    var $base_0;
    if (($base_0 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $72 = HEAP32[$sp >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($72);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 16:
    HEAP32[$10 >> 2] = $base_0;
    var $75 = HEAP32[$5 >> 2] + $7 | 0;
    HEAP32[$5 >> 2] = $75;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18SprintEnsureBufferPN2js8SprinterEj["X"] = 1;

function __ZN2js9SprintPutEPNS_8SprinterEPKcj($sp, $s, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$sp + 12 >> 2];
    var $3 = $sp + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $len);
    if (($5 | 0) == 0) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAPU32[$3 >> 2];
    if (($8 | 0) == ($4 | 0) | $4 >>> 0 > $s >>> 0) {
      var $_01 = $s;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($4 + $2 | 0) >>> 0 > $s >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_01 = $s;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01 = $8 + ($s - $4) | 0;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $20 = $sp + 16 | 0;
    var $21 = HEAP32[$20 >> 2];
    var $22 = $21 + $len | 0;
    HEAP32[$20 >> 2] = $22;
    var $23 = $8 + $21 | 0;
    _llvm_memmove_p0i8_p0i8_i32($23, $_01, $len, 1, 0);
    HEAP8[$8 + $22 | 0] = 0;
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $s) {
  var $1 = _strlen($s);
  var $2 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($sp, $s, $1);
  return $2;
}

function __ZN2js12SprintStringEPNS_8SprinterEP8JSString($sp, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $size = __stackBase__;
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $sp | 0;
    var $3 = HEAP32[$2 >> 2];
    var $4 = __ZN8JSString8getCharsEP9JSContext($str, $3);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$2 >> 2];
    var $9 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($8, $4, $1);
    HEAP32[$size >> 2] = $9;
    if (($9 | 0) == -1) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $9);
    if (($12 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $sp + 16 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $9 + $16 | 0;
    HEAP32[$15 >> 2] = $17;
    var $19 = $sp + 8 | 0;
    var $21 = HEAP32[$19 >> 2] + $16 | 0;
    var $22 = HEAP32[$2 >> 2];
    var $23 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($22, $4, $1, $21, $size);
    HEAP8[HEAP32[$19 >> 2] + HEAP32[$15 >> 2] | 0] = 0;
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    HEAP32[$ap >> 2] = arguments[__ZN2js6SprintEPNS_8SprinterEPKcz.length];
    var $2 = HEAP32[$ap >> 2];
    var $3 = _JS_vsmprintf($format, $2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$sp >> 2];
    _JS_ReportOutOfMemory($7);
    var $_0 = -1;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $3);
    __ZN9JSContext5free_EPv(undef, $3);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_QuoteString($cx, $str, $quote) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sprinter = __stackBase__;
    var $1 = $cx + 72 | 0;
    var $2 = $cx + 88 | 0;
    var $5 = HEAPU32[HEAP32[$2 >> 2] + 12 >> 2];
    var $6 = $5;
    HEAP32[$sprinter >> 2] = $cx;
    HEAP32[$sprinter + 4 >> 2] = $1;
    HEAP32[$sprinter + 8 >> 2] = 0;
    HEAP32[$sprinter + 12 >> 2] = 0;
    HEAP32[$sprinter + 16 >> 2] = 0;
    var $12 = $quote & 65535;
    var $13 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($sprinter, $str, $12);
    if (($13 | 0) == 0) {
      var $18 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = _JS_NewStringCopyZ($cx, $13);
    var $18 = $16;
    __label__ = 3;
    break;
   case 3:
    var $18;
    var $19 = HEAPU32[$2 >> 2];
    if (($19 | 0) == ($1 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAP32[$19 + 4 >> 2];
    var $26 = $19 + 12 | 0;
    if (($5 - $24 | 0) >>> 0 > (HEAP32[$26 >> 2] - $24 | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[$cx + 96 >> 2];
    var $35 = $32 + $5 & ($32 ^ -1);
    HEAP32[$26 >> 2] = $35;
    __label__ = 7;
    break;
   case 6:
    _JS_ArenaRelease($1, $6);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11QuoteStringPN2js8SprinterEP8JSStringj($sp, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = ($quote & 65536 | 0) == 0;
    var $4 = $sp + 16 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = ($quote & 65535) << 16 >> 16 != 0;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $quote << 24 >> 24;
    var $9 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    if (($9 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$sp >> 2];
    var $14 = __ZN8JSString8getCharsEP9JSContext($str, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZNK8JSString6lengthEv($str);
    var $18 = $14 + ($17 << 1) | 0;
    var $19 = $quote & 65535;
    var $20 = $sp + 8 | 0;
    var $_not = $6 ^ 1;
    var $s_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $s_0;
    if ($s_0 >>> 0 < $18 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 6:
    var $c_0 = HEAP16[$s_0 >> 1];
    var $t_1 = $s_0;
    __label__ = 7;
    break;
   case 7:
    var $t_1;
    var $c_0;
    var $26 = $c_0 & 65535;
    if (($c_0 & 65535) < 127) {
      __label__ = 8;
      break;
    } else {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    }
   case 8:
    var $29 = _isprint($26);
    if (($29 | 0) == 0 | ($26 | 0) == ($19 | 0)) {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($c_0 << 16 >> 16 == 92 || $c_0 << 16 >> 16 == 9) {
      var $c_1 = $c_0;
      var $t_2 = $t_1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $t_1 + 2 | 0;
    var $34 = HEAPU16[$33 >> 1];
    if (($33 | 0) == ($18 | 0)) {
      var $c_1 = $34;
      var $t_2 = $33;
      __label__ = 11;
      break;
    } else {
      var $c_0 = $34;
      var $t_1 = $33;
      __label__ = 7;
      break;
    }
   case 11:
    var $t_2;
    var $c_1;
    var $38 = $t_2 - $s_0 | 0;
    var $39 = $38 >> 1;
    var $40 = __ZL18SprintEnsureBufferPN2js8SprinterEj($sp, $39);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = HEAPU32[$20 >> 2];
    var $44 = HEAP32[$4 >> 2];
    var $45 = $43 + $44 | 0;
    var $46 = $44 + $39 | 0;
    HEAP32[$4 >> 2] = $46;
    if (($38 | 0) > 0) {
      __label__ = 13;
      break;
    } else {
      var $bp_0_lcssa = $45;
      __label__ = 16;
      break;
    }
   case 13:
    var $48 = -$39 | 0;
    var $smax = ($48 | 0) > -1 ? $48 : -1;
    var $50 = $46 + $smax | 0;
    var $s_18 = $s_0;
    var $len_09 = $39;
    var $bp_010 = $45;
    __label__ = 14;
    break;
   case 14:
    var $bp_010;
    var $len_09;
    var $s_18;
    var $52 = $len_09 - 1 | 0;
    HEAP8[$bp_010] = HEAP16[$s_18 >> 1] & 255;
    if (($52 | 0) > 0) {
      var $s_18 = $s_18 + 2 | 0;
      var $len_09 = $52;
      var $bp_010 = $bp_010 + 1 | 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $bp_0_lcssa = $50 + ($43 + 1) | 0;
    __label__ = 16;
    break;
   case 16:
    var $bp_0_lcssa;
    HEAP8[$bp_0_lcssa] = 0;
    if (($t_2 | 0) == ($18 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = $c_1 & 65535;
    var $62 = ($61 & 65280 | 0) != 0;
    if ($62) {
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $memchr = _memchr(STRING_TABLE._js_EscapeMap | 0, $61, 19);
    if (($memchr | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($2) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $68 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $61 << 24 >> 24, tempInt));
    var $ok_0_in_in_in = $68;
    __label__ = 23;
    break;
   case 21:
    var $72 = HEAP8[$memchr + 1 | 0] << 24 >> 24;
    var $73 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1472820 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $72, tempInt));
    var $ok_0_in_in_in = $73;
    __label__ = 23;
    break;
   case 22:
    var $75 = $62 | $_not ? STRING_TABLE.__str1492822 : STRING_TABLE.__str1482821;
    var $76 = $75 | 0;
    var $77 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $76, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $61, tempInt));
    var $ok_0_in_in_in = $77;
    __label__ = 23;
    break;
   case 23:
    var $ok_0_in_in_in;
    if (($ok_0_in_in_in | 0) > -1) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 24:
    var $s_0 = $t_2 + 2 | 0;
    __label__ = 5;
    break;
   case 25:
    if ($6) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $84 = $quote << 24 >> 24;
    var $85 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, STRING_TABLE.__str1462819 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $84, tempInt));
    if (($85 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if (($5 | 0) == (HEAP32[$4 >> 2] | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $91 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, __str93064 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (($91 | 0) < 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_0 = HEAP32[$20 >> 2] + $5 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11QuoteStringPN2js8SprinterEP8JSStringj["X"] = 1;

function _js_NewPrinter($cx, $name, $fun, $indent, $pretty, $grouped, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($cx, 76);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $cx;
    var $7 = $1 + 20 | 0;
    HEAP32[$1 + 4 >> 2] = $7;
    HEAP32[$1 + 8 >> 2] = 0;
    HEAP32[$1 + 12 >> 2] = 0;
    HEAP32[$1 + 16 >> 2] = 0;
    _JS_InitArenaPool($7, undef, 256, 1);
    HEAP32[$1 + 48 >> 2] = $indent;
    HEAP8[$1 + 52 | 0] = ($pretty | 0) != 0 & 1;
    HEAP8[$1 + 53 | 0] = ($grouped | 0) != 0 & 1;
    HEAP8[$1 + 54 | 0] = ($strict | 0) != 0 & 1;
    HEAP32[$1 + 56 >> 2] = 0;
    HEAP32[$1 + 60 >> 2] = 0;
    HEAP32[$1 + 64 >> 2] = 0;
    HEAP32[$1 + 68 >> 2] = $fun;
    var $36 = $1 + 72 | 0;
    HEAP32[$36 >> 2] = 0;
    if (($fun | 0) == 0) {
      var $_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $39 = __ZNK10JSFunction13isInterpretedEv($fun);
    if ($39) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 4:
    var $41 = __ZNK10JSFunction6scriptEv($fun);
    var $43 = $41 + 64 | 0;
    var $44 = __ZNK2js8Bindings13hasLocalNamesEv($43);
    if ($44) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $2;
      __label__ = 8;
      break;
    }
   case 5:
    var $46 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($cx, $cx);
    HEAP32[$36 >> 2] = $46;
    if (($46 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $49 = __ZNK10JSFunction6scriptEv($fun);
    var $51 = $49 + 64 | 0;
    var $52 = $46;
    var $53 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($51, undef, $52);
    if ($53) {
      var $_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _js_DestroyPrinter($2);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_NewPrinter["X"] = 1;

function __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($this, $p1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSContext7malloc_Ej($this, 24);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $p1);
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DestroyPrinter($jp) {
  var $1 = $jp + 20 | 0;
  _JS_FinishArenaPool($1);
  var $3 = HEAP32[$jp + 72 >> 2];
  __ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_($3);
  var $4 = $jp;
  __ZN9JSContext5free_EPv(undef, $4);
  return;
}

function __ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free2859($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetPrinterOutput($jp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $jp | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $jp + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 5;
    break;
   case 3:
    var $13 = _JS_NewStringCopyZ($2, $4);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $jp + 20 | 0;
    _JS_FreeArenaPool($16);
    HEAP32[$1 >> 2] = $2;
    HEAP32[$jp + 4 >> 2] = $16;
    HEAP32[$3 >> 2] = 0;
    HEAP32[$jp + 12 >> 2] = 0;
    HEAP32[$jp + 16 >> 2] = 0;
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_printf($jp, $format) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (HEAP8[$format] << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ap >> 2] = arguments[_js_printf.length];
    if (HEAP8[$format] << 24 >> 24 == 9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = $format;
    var $_pre_phi = $jp + 52 | 0;
    __label__ = 7;
    break;
   case 4:
    var $8 = $format + 1 | 0;
    var $9 = $jp + 52 | 0;
    if ((HEAP8[$9] & 1) << 24 >> 24 == 0) {
      var $_01 = $8;
      var $_pre_phi = $9;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $jp | 0;
    var $16 = HEAP32[$jp + 48 >> 2];
    var $17 = __ZN2js6SprintEPNS_8SprinterEPKcz($14, STRING_TABLE.__str262699 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $16, HEAP32[tempInt + 4 >> 2] = __str93064 | 0, tempInt));
    if (($17 | 0) < 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $8;
      var $_pre_phi = $9;
      __label__ = 7;
      break;
    }
   case 6:
    var $_0 = -1;
    __label__ = 16;
    break;
   case 7:
    var $_pre_phi;
    var $_01;
    if ((HEAP8[$_pre_phi] & 1) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = _strlen($_01);
    var $25 = $24 - 1 | 0;
    if (HEAP8[$_01 + $25 | 0] << 24 >> 24 == 10) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $31 = HEAP32[$jp >> 2];
    var $32 = _JS_strdup($31, $_01);
    if (($32 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $_0 = -1;
    __label__ = 16;
    break;
   case 11:
    var $35 = HEAP32[$ap >> 2];
    var $36 = _JS_vsmprintf($_01, $35);
    var $42 = $36;
    __label__ = 13;
    break;
   case 12:
    HEAP8[$32 + $25 | 0] = 0;
    var $39 = HEAP32[$ap >> 2];
    var $40 = _JS_vsmprintf($32, $39);
    __ZN9JSContext5free_EPv(undef, $32);
    var $42 = $40;
    __label__ = 13;
    break;
   case 13:
    var $42;
    if (($42 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $46 = HEAP32[$jp >> 2];
    _JS_ReportOutOfMemory($46);
    var $_0 = -1;
    __label__ = 16;
    break;
   case 15:
    var $48 = _strlen($42);
    var $49 = $jp | 0;
    var $50 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($49, $42, $48);
    var $cc_0 = ($50 | 0) < 0 ? -1 : $48;
    __ZN9JSContext5free_EPv(undef, $42);
    var $_0 = $cc_0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_printf["X"] = 1;

function _js_puts($jp, $s) {
  var $1 = $jp | 0;
  var $2 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $s);
  return $2 >>> 31 ^ 1;
}

function __Z8GetLocalP11SprintStacki($ss, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $4 = HEAP32[HEAP32[$ss + 20 >> 2] + ($i << 2) >> 2];
    if (($4 | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$ss + 8 >> 2] + $4 | 0;
    __label__ = 18;
    break;
   case 3:
    var $14 = HEAP32[HEAP32[$ss + 40 >> 2] + 56 >> 2];
    var $16 = HEAP8[$14 + 16 | 0];
    var $17 = __ZN8JSScript13isValidOffsetEh($16);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZL6GetStrP11SprintStackj($ss, $i);
    var $_0 = $19;
    __label__ = 18;
    break;
   case 5:
    var $21 = __ZN8JSScript7objectsEv($14);
    var $23 = HEAP32[$21 + 4 >> 2];
    var $j_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $j_0;
    if (($j_0 | 0) == ($23 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = __ZN8JSScript9getObjectEj($14, $j_0);
    var $28 = __ZNK8JSObject7isBlockEv($27);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    var $30 = __ZNK8JSObject12getFixedSlotEj($27, 0);
    var $31 = __ZNK2JS5Value7toInt32Ev($30);
    var $32 = $27;
    var $33 = __ZNK8JSObject13propertyCountEv($32);
    var $34 = $i - $31 | 0;
    if ($34 >>> 0 < $33 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 9:
    var $37 = __ZNK8JSObject12lastPropertyEv($27);
    __ZN2js5Shape5RangeC1EPKS0_($r, $37);
    var $38 = $r;
    __label__ = 10;
    break;
   case 10:
    var $40 = __ZNK2js5Shape5Range5emptyEv($38);
    if ($40) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = __ZNK2js5Shape5Range5frontEv($r);
    if ((HEAP16[$42 + 30 >> 1] << 16 >> 16 | 0) == ($34 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $49 = HEAP32[$42 + 12 >> 2];
    var $50 = __ZL12JSID_IS_ATOMi2840($49);
    if (($50 | 0) == 0) {
      var $_0 = __str93064 | 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = __ZL12JSID_TO_ATOMi2841($49);
    var $54 = $ss | 0;
    var $55 = $53 | 0;
    var $56 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($54, $55, 0);
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $63 = $56 - HEAP32[$ss + 8 >> 2] | 0;
    HEAP32[$ss + 16 >> 2] = $63;
    var $_0 = $56;
    __label__ = 18;
    break;
   case 15:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 10;
    break;
   case 16:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 6;
    break;
   case 17:
    var $68 = __ZL6GetStrP11SprintStackj($ss, $i);
    var $_0 = $68;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z8GetLocalP11SprintStacki["X"] = 1;

function __ZL6GetStrP11SprintStackj($ss, $i) {
  var $1 = __ZL6GetOffP11SprintStackj($ss, $i);
  return HEAP32[$ss + 8 >> 2] + $1 | 0;
}

function __ZL12JSID_IS_ATOMi2840($id) {
  var $1 = _JSID_IS_STRING2879($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi2841($id) {
  var $1 = _JSID_TO_STRING2878($id);
  return $1;
}

function _js_DecompileScript($jp, $script) {
  var $2 = HEAP32[$script >> 2];
  var $3 = __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $script, $2);
  return $3;
}

function __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$script + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $jp + 54 | 0;
    if ((HEAP8[$6] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = HEAP32[$jp + 68 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP16[$12 + 58 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = _js_printf($jp, STRING_TABLE.__str1442817 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 6:
    var $22 = _js_printf($jp, STRING_TABLE.__str1452818 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 7;
    break;
   case 7:
    HEAP8[$6] = 1;
    __label__ = 8;
    break;
   case 8:
    var $32 = HEAP32[$script >> 2] + HEAP32[$script + 8 >> 2] - $pc | 0;
    var $33 = __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($jp, $script, $pc, $32, 0);
    return $33;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DecompileToString($cx, $name, $fun, $indent, $pretty, $grouped, $strict, $decompiler) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_NewPrinter($cx, undef, $fun, $indent, $pretty, $grouped, $strict);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = FUNCTION_TABLE[$decompiler]($1);
    if (($4 | 0) == 0) {
      var $str_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = _js_GetPrinterOutput($1);
    var $str_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $str_0;
    _js_DestroyPrinter($1);
    var $_0 = $str_0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DecompileFunctionBody($jp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$jp + 68 >> 2];
    var $3 = __ZNK10JSFunction13isInterpretedEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _js_printf($jp, STRING_TABLE.__ZL15native_code_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZNK10JSFunction6scriptEv($2);
    var $9 = HEAP32[$7 >> 2];
    var $10 = __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $7, $9);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_DecompileFunction($jp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pc = __stackBase__;
    var $ss = __stackBase__ + 4;
    var $untrapper = __stackBase__ + 48;
    var $2 = HEAPU32[$jp + 68 >> 2];
    var $3 = $jp + 52 | 0;
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _js_printf($jp, STRING_TABLE.__str282701 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 6;
    break;
   case 3:
    if ((HEAP8[$jp + 53 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP16[$2 + 58 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = _js_puts($jp, STRING_TABLE.__str292702 | 0);
    __label__ = 6;
    break;
   case 6:
    var $22 = _js_printf($jp, STRING_TABLE.__str302703 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_function_str | 0, tempInt));
    var $24 = HEAP32[$2 + 72 >> 2];
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $jp | 0;
    var $28 = $24 | 0;
    var $29 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($27, $28, 0);
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 44;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = _js_puts($jp, STRING_TABLE.__str292702 | 0);
    var $33 = __ZNK10JSFunction13isInterpretedEv($2);
    if ($33) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $35 = _js_printf($jp, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $36 = $jp + 48 | 0;
    var $38 = HEAP32[$36 >> 2] + 4 | 0;
    HEAP32[$36 >> 2] = $38;
    var $39 = _js_printf($jp, STRING_TABLE.__ZL15native_code_str | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $41 = HEAP32[$36 >> 2] - 4 | 0;
    HEAP32[$36 >> 2] = $41;
    var $42 = _js_printf($jp, STRING_TABLE.__str322705 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 10:
    var $44 = __ZNK10JSFunction6scriptEv($2);
    var $45 = __ZN8JSScript4mainEv($44);
    HEAP32[$pc >> 2] = $45;
    var $46 = $jp | 0;
    var $47 = $jp | 0;
    var $48 = HEAP32[$47 >> 2];
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $48, $44, $pc);
    var $49 = HEAP32[$pc >> 2];
    var $52 = $49 + HEAP32[$44 + 8 >> 2] | 0;
    var $53 = $ss + 40 | 0;
    HEAP32[$53 >> 2] = 0;
    var $54 = $jp + 56 | 0;
    HEAP32[$54 >> 2] = $44;
    var $59 = HEAPU32[HEAP32[HEAP32[$47 >> 2] + 88 >> 2] + 12 >> 2];
    var $60 = $59;
    var $61 = $2 + 56 | 0;
    var $_idx = $44 + 14 | 0;
    var $_idx1 = $44 + 44 | 0;
    var $ok_0 = 1;
    var $i_0 = 0;
    var $63 = $49;
    __label__ = 11;
    break;
   case 11:
    var $63;
    var $i_0;
    var $ok_0;
    if ($i_0 >>> 0 < (HEAPU16[$61 >> 1] & 65535) >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $ok_3 = $ok_0;
      var $107 = $63;
      __label__ = 24;
      break;
    }
   case 12:
    if (($i_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $70 = _js_puts($jp, STRING_TABLE.__str332706 | 0);
    __label__ = 14;
    break;
   case 14:
    var $72 = __ZL15GetArgOrVarAtomP9JSPrinterj($jp, $i_0);
    if (($72 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 15:
    if (HEAP8[$63] << 24 >> 24 == 84) {
      __label__ = 16;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 16:
    var $78 = $63 + 3 | 0;
    HEAP32[$pc >> 2] = $78;
    if (HEAP8[$78] << 24 >> 24 == 12) {
      __label__ = 17;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 17:
    if ((HEAP32[$53 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 19;
      break;
    }
   case 18:
    var $85 = HEAP32[$47 >> 2];
    var $_idx_val = HEAP16[$_idx >> 1];
    var $_idx1_val = HEAP16[$_idx1 >> 1];
    var $86 = __ZL10StackDepthP8JSScript($_idx_val, $_idx1_val);
    var $87 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($85, $ss, $jp, $86);
    if (($87 | 0) == 0) {
      var $ok_3 = 0;
      var $107 = $78;
      __label__ = 24;
      break;
    } else {
      var $ok_1 = $87;
      __label__ = 19;
      break;
    }
   case 19:
    var $ok_1;
    var $90 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $78, $52);
    HEAP32[$pc >> 2] = $90;
    if (($90 | 0) == 0) {
      var $ok_3 = 0;
      var $107 = $90;
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (HEAP8[$90] << 24 >> 24 == 81) {
      __label__ = 21;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 21:
    var $96 = $90 + 1 | 0;
    HEAP32[$pc >> 2] = $96;
    var $97 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $98 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($46, $97);
    if (($98 | 0) < 0) {
      var $ok_3 = 0;
      var $107 = $96;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $ok_1;
      var $105 = $96;
      __label__ = 23;
      break;
    }
   case 22:
    var $101 = $72 | 0;
    var $102 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($46, $101, 0);
    if (($102 | 0) == 0) {
      var $ok_3 = 0;
      var $107 = $63;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $ok_0;
      var $105 = $63;
      __label__ = 23;
      break;
    }
   case 23:
    var $105;
    var $ok_2;
    var $ok_0 = $ok_2;
    var $i_0 = $i_0 + 1 | 0;
    var $63 = $105;
    __label__ = 11;
    break;
   case 24:
    var $107;
    var $ok_3;
    HEAP32[$54 >> 2] = 0;
    var $108 = HEAPU32[$47 >> 2];
    var $110 = HEAP32[$108 + 88 >> 2];
    if (($110 | 0) == ($108 + 72 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $115 = HEAP32[$110 + 4 >> 2];
    var $117 = $110 + 12 | 0;
    if (($59 - $115 | 0) >>> 0 > (HEAP32[$117 >> 2] - $115 | 0) >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $123 = HEAP32[$108 + 96 >> 2];
    var $126 = $123 + $59 & ($123 ^ -1);
    HEAP32[$117 >> 2] = $126;
    __label__ = 28;
    break;
   case 27:
    var $128 = $108 + 72 | 0;
    _JS_ArenaRelease($128, $60);
    __label__ = 28;
    break;
   case 28:
    if (($ok_3 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $132 = _js_printf($jp, STRING_TABLE.__str342707 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $133 = $2 + 58 | 0;
    if ((HEAP16[$133 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $138 = _js_printf($jp, STRING_TABLE.__str352708 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $139 = $jp + 48 | 0;
    var $141 = HEAP32[$139 >> 2] + 4 | 0;
    HEAP32[$139 >> 2] = $141;
    __label__ = 31;
    break;
   case 31:
    var $143 = __ZL13DecompileBodyP9JSPrinterP8JSScriptPh($jp, $44, $107);
    if (($143 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP16[$133 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $150 = $jp + 48 | 0;
    var $152 = HEAP32[$150 >> 2] - 4 | 0;
    HEAP32[$150 >> 2] = $152;
    var $153 = _js_printf($jp, STRING_TABLE.__str322705 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 34;
    break;
   case 34:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    __label__ = 35;
    break;
   case 35:
    if ((HEAP8[$3] & 1) << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      var $_1 = 1;
      __label__ = 44;
      break;
    }
   case 36:
    if ((HEAP8[$jp + 53 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 37;
      break;
    } else {
      var $_1 = 1;
      __label__ = 44;
      break;
    }
   case 37:
    if ((HEAP16[$2 + 58 >> 1] & 8) << 16 >> 16 == 0) {
      var $_1 = 1;
      __label__ = 44;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $170 = _js_puts($jp, STRING_TABLE.__str362709 | 0);
    var $_1 = 1;
    __label__ = 44;
    break;
   case 39:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 40:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 41:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 42:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 43:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    var $_1 = 0;
    __label__ = 44;
    break;
   case 44:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_DecompileFunction["X"] = 1;

function __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc) {
  __ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc);
  return;
}

function __ZL10StackDepthP8JSScript($script_0_4_val, $script_0_19_val) {
  return ($script_0_19_val & 65535) - ($script_0_4_val & 65535) | 0;
}

function __ZN2js10StackFrame13clearImacropcEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -8193;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js10StackFrame11setImacropcEPh($this, $pc) {
  HEAP32[$this + 40 >> 2] = $pc;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] | 8192;
  HEAP32[$2 >> 2] = $4;
  return;
}

function __ZN2js17CallResultEscapesEPh($pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP8[$pc] << 24 >> 24 == 58) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $pc + 3 | 0;
    var $_01 = HEAP8[$4] << 24 >> 24 == 109 ? $pc + 6 | 0 : $4;
    var $8 = HEAP8[$_01];
    if ($8 << 24 >> 24 == 32) {
      __label__ = 3;
      break;
    } else if ($8 << 24 >> 24 == 81) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $12 = $8;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP8[$_01 + 1 | 0];
    __label__ = 4;
    break;
   case 4:
    var $12;
    var $_0 = $12 << 24 >> 24 != 7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15GetArgOrVarAtomP9JSPrinterj($jp, $slot) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$jp + 68 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK10JSFunction6scriptEv($2);
    var $7 = $5 + 64 | 0;
    var $8 = __ZNK2js8Bindings15countLocalNamesEv($7);
    if ($8 >>> 0 > $slot >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$jp + 72 >> 2];
    var $13 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($12, $slot);
    var $_0 = HEAP32[$13 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($cx, $ss, $jp, $depth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$ss >> 2] = $cx;
    var $2 = $cx + 72 | 0;
    HEAP32[$ss + 4 >> 2] = $2;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    HEAP32[$ss + 16 >> 2] = 3;
    var $7 = $depth << 2;
    var $9 = HEAP32[$cx + 88 >> 2];
    var $11 = HEAP32[$cx + 96 >> 2];
    var $15 = $7 + $depth + $11 & ($11 ^ -1);
    var $16 = $9 + 12 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $19 = HEAPU32[$9 + 8 >> 2];
    if ($15 >>> 0 > $19 >>> 0 | $17 >>> 0 > ($19 - $15 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $24 = _JS_ArenaAllocate($2, $15);
    var $_p_0 = $24;
    __label__ = 4;
    break;
   case 3:
    var $27 = $15 + $17 | 0;
    HEAP32[$16 >> 2] = $27;
    var $_p_0 = $17;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    HEAP32[$ss + 20 >> 2] = $_p_0;
    HEAP32[$ss + 24 >> 2] = $_p_0 + $7 | 0;
    HEAP32[$ss + 32 >> 2] = 0;
    HEAP32[$ss + 28 >> 2] = 0;
    HEAP32[$ss + 36 >> 2] = 0;
    HEAP32[$ss + 40 >> 2] = $jp;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj["X"] = 1;

function __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $pc, $endpc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    if (HEAP8[$pc] << 24 >> 24 == 12) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 2:
    var $4 = $ss | 0;
    var $5 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str1002773 | 0, 1);
    if (($5 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZL7PushOffP11SprintStacki4JSOp($ss, $5, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $ss + 16 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $13 = $12 - 3 | 0;
    HEAP32[$11 >> 2] = $13;
    if (($5 | 0) == ($12 - 4 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 5:
    var $17 = $ss + 8 | 0;
    if (HEAP8[HEAP32[$17 >> 2] + $5 | 0] << 24 >> 24 == 91) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 6:
    var $24 = HEAPU32[$ss >> 2];
    var $27 = HEAP32[$ss + 40 >> 2] + 56 | 0;
    var $28 = $24;
    var $29 = $24 + 52 | 0;
    var $pc_pn = $pc;
    var $lasti_0 = -1;
    __label__ = 7;
    break;
   case 7:
    var $lasti_0;
    var $pc_pn;
    var $_01 = $pc_pn + 1 | 0;
    if ($_01 >>> 0 < $endpc >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_2 = $_01;
      __label__ = 48;
      break;
    }
   case 8:
    var $33 = HEAPU8[$_01] & 255;
    var $36 = HEAP8[_js_CodeSpec + ($33 << 3) | 0] << 24 >> 24;
    if (($33 | 0) == 81) {
      __label__ = 9;
      break;
    } else if (($33 | 0) == 63) {
      __label__ = 10;
      break;
    } else if (($33 | 0) == 88) {
      __label__ = 11;
      break;
    } else if (($33 | 0) == 190) {
      __label__ = 12;
      break;
    } else if (($33 | 0) == 218) {
      __label__ = 13;
      break;
    } else if (($33 | 0) == 219) {
      __label__ = 14;
      break;
    } else if (($33 | 0) == 60) {
      __label__ = 15;
      break;
    } else if (($33 | 0) == 62) {
      var $d_0 = 0;
      var $i_0 = 0;
      __label__ = 18;
      break;
    } else if (($33 | 0) == 187 || ($33 | 0) == 53 || ($33 | 0) == 220) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 9:
    var $_2 = $36 + ($pc_pn + 1) | 0;
    __label__ = 48;
    break;
   case 10:
    var $d_0 = 1;
    var $i_0 = 1;
    __label__ = 18;
    break;
   case 11:
    var $48 = (HEAPU8[$pc_pn + 2 | 0] & 255) << 8 | HEAPU8[$pc_pn + 3 | 0] & 255;
    var $d_0 = $48 | 0;
    var $i_0 = $48;
    __label__ = 18;
    break;
   case 12:
    var $63 = HEAPU8[$pc_pn + 4 | 0] & 255 | (HEAPU8[$pc_pn + 2 | 0] & 255) << 16 | (HEAPU8[$pc_pn + 3 | 0] & 255) << 8;
    var $d_0 = $63 | 0;
    var $i_0 = $63;
    __label__ = 18;
    break;
   case 13:
    var $67 = HEAP8[$pc_pn + 2 | 0];
    var $d_0 = $67 << 24 >> 24;
    var $i_0 = $67 << 24 >> 24;
    __label__ = 18;
    break;
   case 14:
    var $88 = (HEAPU8[$pc_pn + 3 | 0] & 255) << 16 | (HEAPU8[$pc_pn + 2 | 0] & 255) << 24 | HEAPU8[$pc_pn + 5 | 0] & 255 | (HEAPU8[$pc_pn + 4 | 0] & 255) << 8;
    var $d_0 = $88 | 0;
    var $i_0 = $88;
    __label__ = 18;
    break;
   case 15:
    var $91 = HEAP32[$27 >> 2];
    var $92 = _js_GetIndexFromBytecode($24, $91, $_01, 0);
    var $93 = HEAP32[$27 >> 2];
    var $94 = __ZN8JSScript8getConstEj($93, $92);
    var $95 = __ZNK2JS5Value8toDoubleEv($94);
    var $96 = __ZL18JSDOUBLE_IS_FINITEd2876($95);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $99 = _JSDOUBLE_IS_NEGZERO2875($95);
    if (($99 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 17:
    var $d_0 = $95;
    var $i_0 = $95 & -1;
    __label__ = 18;
    break;
   case 18:
    var $i_0;
    var $d_0;
    var $104 = HEAP32[$27 >> 2];
    var $105 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($28, $104, $_01);
    var $106 = $36 + ($pc_pn + 1) | 0;
    if (($106 | 0) == ($endpc | 0)) {
      var $_0 = $106;
      __label__ = 49;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $109 = HEAPU8[$106];
    var $113 = HEAP8[_js_CodeSpec + (($109 & 255) << 3) | 0] << 24 >> 24;
    if ($109 << 24 >> 24 == 55) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 20:
    if (($105 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $118 = HEAPU8[$105];
    if (($118 & 255) < 192 & ($118 & -8) << 24 >> 24 == 8) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    HEAP8[HEAP32[$17 >> 2] + $5 | 0] = 123;
    var $123 = __ZN2js6SprintEPNS_8SprinterEPKcz($4, STRING_TABLE.__str1412814 | 0, (tempInt = STACKTOP, STACKTOP += 8, tempDoubleF64[0] = $d_0, HEAP32[tempInt >> 2] = tempDoubleI32[0], HEAP32[tempInt + 4 >> 2] = tempDoubleI32[1], tempInt));
    if (($123 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $_1 = $106;
      var $nameoff_0 = -1;
      var $oplen_0 = $113;
      var $lasti_2 = $lasti_0;
      __label__ = 32;
      break;
    }
   case 23:
    if (($i_0 | 0) == $d_0) {
      var $lasti_1 = $lasti_0;
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 24:
    var $lasti_1;
    var $127 = $lasti_1 + 1 | 0;
    if (($127 | 0) < ($i_0 | 0)) {
      __label__ = 25;
      break;
    } else {
      var $_1 = $106;
      var $nameoff_0 = -1;
      var $oplen_0 = $113;
      var $lasti_2 = $127;
      __label__ = 32;
      break;
    }
   case 25:
    var $130 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str332706 | 0, 2);
    if (($130 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $lasti_1 = $127;
      __label__ = 24;
      break;
    }
   case 26:
    var $133 = HEAP32[$27 >> 2];
    var $134 = _js_GetIndexFromBytecode($24, $133, $_01, 0);
    var $135 = HEAPU32[$27 >> 2];
    var $137 = HEAPU32[$135 >> 2];
    if ($_01 >>> 0 < $137 >>> 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if (($137 + HEAP32[$135 + 8 >> 2] | 0) >>> 0 > $_01 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $146 = HEAP32[$29 >> 2] + 209948 | 0;
    var $147 = __ZN11JSAtomState16commonAtomsStartEv($146);
    var $atom_0 = HEAP32[$147 + ($134 << 2) >> 2];
    __label__ = 30;
    break;
   case 29:
    var $151 = __ZN8JSScript7getAtomEj($135, $134);
    var $atom_0 = $151;
    __label__ = 30;
    break;
   case 30:
    var $atom_0;
    HEAP8[HEAP32[$17 >> 2] + $5 | 0] = 123;
    var $155 = HEAP32[$11 >> 2];
    var $156 = $atom_0 | 0;
    var $158 = __Z15js_IsIdentifierP14JSLinearString($atom_0 | 0);
    var $160 = ($158 | 0) != 0 ? 0 : 39;
    var $161 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($4, $156, $160);
    if (($161 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $164 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str1422815 | 0, 2);
    if (($164 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $_1 = $_01;
      var $nameoff_0 = $155;
      var $oplen_0 = $36;
      var $lasti_2 = $lasti_0;
      __label__ = 32;
      break;
    }
   case 32:
    var $lasti_2;
    var $oplen_0;
    var $nameoff_0;
    var $_1;
    var $166 = $_1 + $oplen_0 | 0;
    if (($166 | 0) == ($endpc | 0)) {
      var $_0 = $166;
      __label__ = 49;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $169 = __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $166, $endpc, $hole);
    if (($169 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if (($nameoff_0 | 0) > -1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 35:
    var $174 = HEAPU32[$11 >> 2];
    var $175 = HEAPU32[$17 >> 2];
    if (HEAP8[$175 + $174 | 0] << 24 >> 24 == 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 36:
    var $180 = $174 - $nameoff_0 | 0;
    if (($180 | 0) > 3) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 37:
    if (($180 & 1 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    var $187 = ($180 - 2 | 0) >>> 1;
    var $_sum = $187 + $nameoff_0 | 0;
    var $188 = $175 + $_sum | 0;
    var $189 = _strncmp($188, STRING_TABLE.__str1422815 | 0, 2);
    if (($189 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $192 = $175 + $nameoff_0 | 0;
    var $193 = $_sum + ($175 + 2) | 0;
    var $194 = _strncmp($192, $193, $187);
    if (($194 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $197 = $174 - 2 - $187 | 0;
    HEAP8[$175 + $197 | 0] = 0;
    HEAP32[$11 >> 2] = $197;
    __label__ = 41;
    break;
   case 41:
    if (($169 | 0) == ($endpc | 0)) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if (HEAP8[$169] << 24 >> 24 == 12) {
      __label__ = 43;
      break;
    } else {
      var $_2 = $169;
      __label__ = 48;
      break;
    }
   case 43:
    var $206 = HEAP32[$27 >> 2];
    var $207 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($28, $206, $169);
    if (($207 | 0) == 0) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $210 = HEAPU8[$207];
    var $_mask = $210 & -8;
    if (($210 & 255) > 191 | $_mask << 24 >> 24 != 40) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    if (($210 & 255) < 192 & $_mask << 24 >> 24 == 48) {
      var $_2 = $169;
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 46:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      var $pc_pn = $169;
      var $lasti_0 = $lasti_2;
      __label__ = 7;
      break;
    }
   case 47:
    var $217 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, STRING_TABLE.__str332706 | 0, 2);
    if (($217 | 0) < 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      var $pc_pn = $169;
      var $lasti_0 = $lasti_2;
      __label__ = 7;
      break;
    }
   case 48:
    var $_2;
    var $_str562729__str1432816 = HEAP8[HEAP32[$17 >> 2] + $5 | 0] << 24 >> 24 == 91 ? STRING_TABLE.__str562729 : STRING_TABLE.__str1432816;
    var $223 = $_str562729__str1432816 | 0;
    var $224 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($4, $223, 1);
    var $__2 = ($224 | 0) < 0 ? 0 : $_2;
    var $_0 = $__2;
    __label__ = 49;
    break;
   case 49:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22DecompileDestructuringP11SprintStackPhS1_["X"] = 1;

function __ZL6PopStrP11SprintStack4JSOp($ss, $op) {
  var $2 = HEAP8[_js_CodeSpec + ($op << 3) + 3 | 0];
  var $3 = __ZL10PopStrPrecP11SprintStackh($ss, $2);
  return $3;
}

function __ZN19AutoScriptUntrapperD1Ev($this) {
  __ZN19AutoScriptUntrapperD2Ev($this);
  return;
}

function _js_DecompileValueGenerator($cx, $spindex, $0, $fallback) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $v | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK9JSContext5hasfpEv($cx);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 2:
    var $7 = __ZNK9JSContext2fpEv($cx);
    var $8 = __ZNK2js10StackFrame13isScriptFrameEv($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 3:
    var $10 = __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852($cx);
    var $11 = __ZNK2js10StackFrame6scriptEv($10);
    var $12 = __ZNK2js10StackFrame11hasImacropcEv($10);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK2js10StackFrame8imacropcEv($10);
    var $20 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZNK9JSContext4regsEv($cx);
    var $20 = HEAP32[$16 + 4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $20;
    var $21 = __ZN8JSScript4mainEv($11);
    if ($20 >>> 0 < $21 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($spindex | 0) == 0) {
      var $pc_1 = $20;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_idx_val = HEAP16[$11 + 14 >> 1];
    var $_idx1_val = HEAP16[$11 + 44 >> 1];
    var $26 = __ZL10StackDepthP8JSScript($_idx_val, $_idx1_val);
    var $27 = $26 << 2;
    var $28 = __ZN9JSContext7malloc_Ej($cx, $27);
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $11, $20, $29);
    if (($32 | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($spindex | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $32 + $spindex | 0;
    if (($37 | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = HEAP32[$29 + ($37 << 2) >> 2];
    __ZN9JSContext5free_EPv(undef, $28);
    var $pc_1 = $40;
    __label__ = 20;
    break;
   case 13:
    var $42 = $10;
    var $43 = __ZNK2js10StackFrame4baseEv($42);
    var $44 = __ZNK9JSContext4regsEv($cx);
    var $sp_0 = HEAP32[$44 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $sp_0;
    if (($sp_0 | 0) == ($43 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = $sp_0 - 8 | 0;
    var $51 = __ZNK2JS5ValueneERKS0_($50, $v);
    if ($51) {
      var $sp_0 = $50;
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ($50 >>> 0 < ($43 + ($32 << 3) | 0) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $pc_0 = $20;
      __label__ = 19;
      break;
    }
   case 17:
    var $pc_0 = HEAP32[$29 + ($50 - $43 >> 3 << 2) >> 2];
    __label__ = 19;
    break;
   case 18:
    __ZN9JSContext5free_EPv(undef, $28);
    __label__ = 25;
    break;
   case 19:
    var $pc_0;
    __ZN9JSContext5free_EPv(undef, $28);
    var $pc_1 = $pc_0;
    __label__ = 20;
    break;
   case 20:
    var $pc_1;
    var $64 = __ZNK9JSContext4regsEv($cx);
    var $65 = $64 + 4 | 0;
    var $66 = HEAP32[$65 >> 2];
    var $67 = __ZNK2js10StackFrame13maybeImacropcEv($10);
    var $68 = ($67 | 0) != 0;
    if ($68) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    HEAP32[$65 >> 2] = $67;
    __ZN2js10StackFrame13clearImacropcEv($10);
    if (($pc_1 - HEAP32[$11 >> 2] | 0) >>> 0 < HEAPU32[$11 + 8 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $name_05 = 1;
      __label__ = 23;
      break;
    }
   case 22:
    var $79 = $10;
    var $80 = __ZNK2js10StackFrame8maybeFunEv($79);
    var $81 = $80;
    var $82 = __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($cx, $11, $81, $pc_1);
    if ($68) {
      var $name_05 = $82;
      __label__ = 23;
      break;
    } else {
      var $name_04 = $82;
      __label__ = 24;
      break;
    }
   case 23:
    var $name_05;
    var $83 = __ZNK9JSContext4regsEv($cx);
    HEAP32[$83 + 4 >> 2] = $66;
    __ZN2js10StackFrame11setImacropcEPh($10, $67);
    var $name_04 = $name_05;
    __label__ = 24;
    break;
   case 24:
    var $name_04;
    if (($name_04 | 0) == 1) {
      __label__ = 25;
      break;
    } else {
      var $_0 = $name_04;
      __label__ = 29;
      break;
    }
   case 25:
    if (($fallback | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $_01 = $fallback;
      __label__ = 27;
      break;
    }
   case 26:
    var $90 = $cx;
    var $91 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($90, $v);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      var $_01 = $91;
      __label__ = 27;
      break;
    }
   case 27:
    var $_01;
    var $94 = __ZNK8JSString6lengthEv($_01);
    var $95 = __ZN8JSString8getCharsEP9JSContext($_01, $cx);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $98 = $cx;
    var $99 = __ZN2js13DeflateStringEP9JSContextPKtj($98, $95, $94);
    var $_0 = $99;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_DecompileValueGenerator["X"] = 1;

function __ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852($cx) {
  var $1 = __ZNK9JSContext7maybefpEv($cx);
  return $1;
}

function __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $target, $pcstack) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pcdepth = __stackBase__;
    var $2 = HEAPU32[$script >> 2];
    if ($2 >>> 0 > $target >>> 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 + HEAP32[$script + 8 >> 2] | 0) >>> 0 > $target >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = -1;
      __label__ = 19;
      break;
    }
   case 3:
    HEAP32[$pcdepth >> 2] = 0;
    var $10 = $cx;
    var $11 = $script;
    var $pc_0 = $2;
    __label__ = 4;
    break;
   case 4:
    var $pc_0;
    if ($pc_0 >>> 0 < $target >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 5:
    var $15 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc_0);
    var $16 = _js_CodeSpec + ($15 << 3) | 0;
    var $18 = HEAP8[$16 | 0];
    var $19 = $18 << 24 >> 24;
    if ($18 << 24 >> 24 < 0) {
      __label__ = 6;
      break;
    } else {
      var $oplen_0 = $19;
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __Z28js_GetVariableBytecodeLengthPh($pc_0);
    var $oplen_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $oplen_0;
    if ((HEAP32[_js_CodeSpec + ($15 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $oplen_2 = $oplen_0;
      var $pc_2 = $pc_0;
      __label__ = 16;
      break;
    }
   case 8:
    var $29 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($10, $11, $pc_0);
    if (($29 | 0) == 0) {
      var $pc_15 = $pc_0;
      var $oplen_17 = $oplen_0;
      var $op_09 = $15;
      var $cs_011 = $16;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAPU8[$29];
    if (($32 & 255) < 192 & ($32 & -8) << 24 >> 24 == 72) {
      __label__ = 10;
      break;
    } else {
      var $pc_16 = $pc_0;
      var $oplen_18 = $oplen_0;
      var $op_010 = $15;
      var $cs_012 = $16;
      var $51 = $32;
      __label__ = 14;
      break;
    }
   case 10:
    var $35 = _js_GetSrcNoteOffset($29, 0);
    var $36 = $pc_0 + $35 | 0;
    if ($36 >>> 0 < $target >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $pc_16 = $pc_0;
      var $oplen_18 = $oplen_0;
      var $op_010 = $15;
      var $cs_012 = $16;
      var $51 = $32;
      __label__ = 14;
      break;
    }
   case 11:
    var $39 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $36);
    var $40 = _js_CodeSpec + ($39 << 3) | 0;
    var $43 = HEAP8[$40 | 0] << 24 >> 24;
    var $_val = HEAP8[$36];
    var $44 = __ZL13GetJumpOffsetPhS_($_val, $36);
    if (($pc_0 + ($44 + $35) | 0) >>> 0 < $target >>> 0) {
      var $oplen_2 = $44;
      var $pc_2 = $36;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = HEAPU32[$pcdepth >> 2];
    if (($48 | 0) == 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$pcdepth >> 2] = $48 - 1 | 0;
    var $pc_16 = $36;
    var $oplen_18 = $43;
    var $op_010 = $39;
    var $cs_012 = $40;
    var $51 = HEAP8[$29];
    __label__ = 14;
    break;
   case 14:
    var $51;
    var $cs_012;
    var $op_010;
    var $oplen_18;
    var $pc_16;
    if (($51 & 255) < 192 & ($51 & -8) << 24 >> 24 == 88) {
      var $oplen_2 = $oplen_18;
      var $pc_2 = $pc_16;
      __label__ = 16;
      break;
    } else {
      var $pc_15 = $pc_16;
      var $oplen_17 = $oplen_18;
      var $op_09 = $op_010;
      var $cs_011 = $cs_012;
      __label__ = 15;
      break;
    }
   case 15:
    var $cs_011;
    var $op_09;
    var $oplen_17;
    var $pc_15;
    var $cs_011_idx_val = HEAP8[$cs_011 + 1 | 0];
    var $cs_011_idx1_val = HEAP8[$cs_011 + 2 | 0];
    var $53 = __ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj($cx, $script, $op_09, $cs_011_idx_val, $cs_011_idx1_val, $pc_15, $pcstack, $pcdepth);
    if (($53 | 0) < 0) {
      var $_0 = -1;
      __label__ = 19;
      break;
    } else {
      var $oplen_2 = $oplen_17;
      var $pc_2 = $pc_15;
      __label__ = 16;
      break;
    }
   case 16:
    var $pc_2;
    var $oplen_2;
    var $pc_0 = $pc_2 + $oplen_2 | 0;
    __label__ = 4;
    break;
   case 17:
    if (($pc_0 | 0) == ($target | 0)) {
      __label__ = 18;
      break;
    } else {
      var $_0 = -1;
      __label__ = 19;
      break;
    }
   case 18:
    var $_0 = HEAP32[$pcdepth >> 2];
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_["X"] = 1;

function __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($cx, $script, $fun, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $untrapper = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $pc;
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $cx, $script, $1);
    var $2 = HEAPU32[$1 >> 2];
    var $3 = HEAPU8[$2];
    var $4 = $3 & 255;
    if ($3 << 24 >> 24 == 1) {
      __label__ = 2;
      break;
    } else if ($3 << 24 >> 24 == 65) {
      __label__ = 3;
      break;
    } else if ($3 << 24 >> 24 == 110) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = _JS_strdup($cx, STRING_TABLE._js_undefined_str | 0);
    var $name_1 = $6;
    var $pcstack_0 = 0;
    __label__ = 17;
    break;
   case 3:
    var $8 = _JS_strdup($cx, STRING_TABLE._js_this_str | 0);
    var $name_1 = $8;
    var $pcstack_0 = 0;
    __label__ = 17;
    break;
   case 4:
    var $13 = $2 + (HEAP8[_js_CodeSpec + ($4 << 3) | 0] << 24 >> 24) | 0;
    var $16 = HEAP32[_js_CodeSpec + ($4 << 3) + 4 >> 2] & 224;
    if (($16 | 0) == 64 || ($16 | 0) == 96 || ($16 | 0) == 128 || ($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $end_0 = $13;
      var $begin_0 = $2;
      __label__ = 10;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = $script;
    var $20 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($18, $19, $2);
    if (($20 | 0) == 0) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAPU8[$20];
    if (($23 & 255) > 191) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = ($23 & 255) >>> 3;
    if (($27 | 0) == 12) {
      __label__ = 8;
      break;
    } else if (($27 | 0) == 7) {
      __label__ = 9;
      break;
    } else {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    }
   case 8:
    var $29 = _js_GetSrcNoteOffset($20, 0);
    var $end_0 = $13;
    var $begin_0 = $2 + -$29 | 0;
    __label__ = 10;
    break;
   case 9:
    var $33 = _js_GetSrcNoteOffset($20, 0);
    var $end_0 = $2 + $33 | 0;
    var $begin_0 = $13;
    __label__ = 10;
    break;
   case 10:
    var $begin_0;
    var $end_0;
    var $38 = $end_0 - $begin_0 | 0;
    if (($38 | 0) < 1) {
      var $name_1 = 1;
      var $pcstack_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx1_val = HEAP16[$script + 44 >> 1];
    var $41 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx1_val);
    var $42 = $41 << 2;
    var $43 = __ZN9JSContext7malloc_Ej($cx, $42);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $name_1 = 0;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $47 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $begin_0, $44);
    if (($47 | 0) < 0) {
      var $name_1 = 1;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = _js_NewPrinter($cx, undef, $fun, 0, 0, 0, 0);
    if (($50 | 0) == 0) {
      var $name_1 = 0;
      var $pcstack_0 = $44;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$50 + 60 >> 2] = $end_0;
    HEAP32[$50 + 64 >> 2] = $44;
    var $55 = __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($50, $script, $begin_0, $38, $47);
    if (($55 | 0) == 0) {
      var $name_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $59 = HEAP32[$50 + 8 >> 2];
    var $61 = ($59 | 0) == 0 ? __str93064 | 0 : $59;
    var $62 = _JS_strdup($cx, $61);
    var $name_0 = $62;
    __label__ = 16;
    break;
   case 16:
    var $name_0;
    _js_DestroyPrinter($50);
    var $name_1 = $name_0;
    var $pcstack_0 = $44;
    __label__ = 17;
    break;
   case 17:
    var $pcstack_0;
    var $name_1;
    __ZN9JSContext5free_EPv(undef, $pcstack_0);
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    STACKTOP = __stackBase__;
    return $name_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh["X"] = 1;

function _js_ReconstructStackDepth($cx, $script, $pc) {
  var $1 = __ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_($cx, $script, $pc, 0);
  return $1;
}

function __ZL13GetJumpOffsetPhS_($pc_val, $pc2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $9 = HEAPU8[$pc2 + 1 | 0] & 255;
    if (((HEAP32[_js_CodeSpec + (($pc_val & 255) << 3) + 4 >> 2] & 31) - 9 | 0) >>> 0 < 3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255) << 16 | $9 << 24 | HEAPU8[$pc2 + 4 | 0] & 255 | (HEAPU8[$pc2 + 3 | 0] & 255) << 8;
    __label__ = 4;
    break;
   case 3:
    var $_0 = (HEAPU8[$pc2 + 2 | 0] & 255 | $9 << 8) << 16 >> 16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825($script, $pc);
    var $3 = HEAP8[_js_CodeSpec + ($1 << 3) | 0];
    if ($3 << 24 >> 24 == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $3 << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $8 = __Z28js_GetVariableBytecodeLength4JSOpPh($1, $pc);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj($cx, $script, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    __ZN2js13BytecodeRangeC1EP9JSContextP8JSScript($r, $cx, $script);
    __label__ = 2;
    break;
   case 2:
    var $2 = __ZNK2js13BytecodeRange5emptyEv($r);
    if ($2) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __ZNK2js13BytecodeRange11frontOffsetEv($r);
    if ($4 >>> 0 < $offset >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = ($4 | 0) == ($offset | 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2js13BytecodeRange8popFrontEv($r);
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13BytecodeRangeC1EP9JSContextP8JSScript($this, $cx, $script) {
  __ZN2js13BytecodeRangeC2EP9JSContextP8JSScript($this, $cx, $script);
  return;
}

function _js_free2859($p) {
  _free($p);
  return;
}

function __ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj($cx, $script, $op, $cs_0_1_val, $cs_0_2_val, $pc, $pcstack, $pcdepth) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_GetStackUses2860($cs_0_1_val, $op, $pc);
    var $2 = _js_GetStackDefs($cx, $cs_0_2_val, $script, $pc);
    var $3 = HEAPU32[$pcdepth >> 2];
    if ($3 >>> 0 < $1 >>> 0) {
      var $_0 = -1;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 - $1 | 0;
    HEAP32[$pcdepth >> 2] = $6;
    var $7 = $6 + $2 | 0;
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx2_val = HEAP16[$script + 44 >> 1];
    var $8 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx2_val);
    if ($7 >>> 0 > $8 >>> 0) {
      var $_0 = -1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($op | 0) == 12) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 13) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 10) {
      __label__ = 11;
      break;
    } else if (($op | 0) == 121 || ($op | 0) == 147) {
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($pcstack | 0) == 0 | ($2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i_01 = 0;
      var $14 = $6;
      __label__ = 5;
      break;
    }
   case 5:
    var $14;
    var $i_01;
    HEAP32[$pcstack + ($14 + $i_01 << 2) >> 2] = $pc;
    var $17 = $i_01 + 1 | 0;
    if (($17 | 0) == ($2 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_01 = $17;
    var $14 = HEAP32[$pcdepth >> 2];
    __label__ = 5;
    break;
   case 7:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$pcstack + ($6 + 1 << 2) >> 2] = $23;
    __label__ = 13;
    break;
   case 9:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$pcstack + ($6 + 2 << 2) >> 2] = $30;
    var $33 = HEAP32[$pcdepth >> 2];
    var $36 = HEAP32[$pcstack + ($33 + 1 << 2) >> 2];
    var $38 = $pcstack + ($33 + 3 << 2) | 0;
    HEAP32[$38 >> 2] = $36;
    __label__ = 13;
    break;
   case 11:
    if (($pcstack | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $43 = $pcstack + ($6 + 1 << 2) | 0;
    var $44 = HEAP32[$43 >> 2];
    var $46 = HEAP32[$pcstack + ($6 << 2) >> 2];
    HEAP32[$43 >> 2] = $46;
    var $48 = $pcstack + (HEAP32[$pcdepth >> 2] << 2) | 0;
    HEAP32[$48 >> 2] = $44;
    __label__ = 13;
    break;
   case 13:
    var $50 = HEAP32[$pcdepth >> 2] + $2 | 0;
    HEAP32[$pcdepth >> 2] = $50;
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj["X"] = 1;

function _js_GetStackUses2860($cs_0_1_val, $op, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_1_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_1_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetVariableStackUses($op, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_GetStackDefs($cx, $cs_0_2_val, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($cs_0_2_val << 24 >> 24 > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $cs_0_2_val << 24 >> 24;
    __label__ = 4;
    break;
   case 3:
    var $5 = _js_GetEnterBlockStackDefs($cx, $script, $pc);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj($jp, $script, $pc, $len, $pcdepth) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $ss = __stackBase__ + 4;
    var $untrapper = __stackBase__ + 48;
    HEAP32[$1 >> 2] = $pc;
    var $script_idx_val = HEAP16[$script + 14 >> 1];
    var $script_idx1_val = HEAP16[$script + 44 >> 1];
    var $2 = __ZL10StackDepthP8JSScript($script_idx_val, $script_idx1_val);
    var $4 = HEAPU32[$jp >> 2];
    __ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh($untrapper, $4, $script, $1);
    var $5 = $4 + 72 | 0;
    var $6 = $4 + 88 | 0;
    var $9 = HEAPU32[HEAP32[$6 >> 2] + 12 >> 2];
    var $10 = $9;
    var $11 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($4, $ss, $jp, $2);
    if (($11 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $ss + 28 | 0;
    HEAP32[$14 >> 2] = $pcdepth;
    if (($pcdepth | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $ss + 20 | 0;
    var $17 = $jp + 64 | 0;
    var $18 = $ss + 24 | 0;
    var $i_01 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_01;
    var $22 = HEAP32[$16 >> 2] + ($i_01 << 2) | 0;
    HEAP32[$22 >> 2] = -2 - $i_01 | 0;
    var $26 = HEAP8[HEAP32[HEAP32[$17 >> 2] + ($i_01 << 2) >> 2]];
    HEAP8[HEAP32[$18 >> 2] + $i_01 | 0] = $26;
    var $29 = $i_01 + 1 | 0;
    if (($29 | 0) == ($pcdepth | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $29;
      __label__ = 4;
      break;
    }
   case 5:
    var $30 = $jp + 56 | 0;
    var $31 = HEAP32[$30 >> 2];
    HEAP32[$30 >> 2] = $script;
    var $32 = HEAP32[$1 >> 2];
    var $33 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $32, $len);
    var $34 = ($33 | 0) != 0;
    var $35 = $34 & 1;
    HEAP32[$30 >> 2] = $31;
    if ($34) {
      __label__ = 6;
      break;
    } else {
      var $ok_0 = $35;
      __label__ = 10;
      break;
    }
   case 6:
    if ((HEAP32[$14 >> 2] | 0) == 0) {
      var $ok_0 = $35;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $39 = $ss + 8 | 0;
    __label__ = 8;
    break;
   case 8:
    var $41 = HEAP32[$39 >> 2];
    var $42 = __ZL6PopOffP11SprintStack4JSOp($ss, 81);
    if (HEAPU32[$14 >> 2] >>> 0 > $pcdepth >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $46 = $41 + $42 | 0;
    var $47 = _js_printf($jp, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $46, tempInt));
    var $ok_0 = $35;
    __label__ = 10;
    break;
   case 10:
    var $ok_0;
    var $49 = HEAPU32[$6 >> 2];
    if (($49 | 0) == ($5 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $54 = HEAP32[$49 + 4 >> 2];
    var $56 = $49 + 12 | 0;
    if (($9 - $54 | 0) >>> 0 > (HEAP32[$56 >> 2] - $54 | 0) >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $62 = HEAP32[$4 + 96 >> 2];
    var $65 = $62 + $9 & ($62 ^ -1);
    HEAP32[$56 >> 2] = $65;
    __label__ = 14;
    break;
   case 13:
    _JS_ArenaRelease($5, $10);
    __label__ = 14;
    break;
   case 14:
    __ZN19AutoScriptUntrapperD1Ev($untrapper);
    STACKTOP = __stackBase__;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj["X"] = 1;

function __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc, $nb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 140;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $todo = __stackBase__;
    var $saveop = __stackBase__ + 4;
    var $i = __stackBase__ + 8;
    var $val = __stackBase__ + 12;
    var $1 = __stackBase__ + 24;
    var $smallv = __stackBase__ + 36;
    var $r = __stackBase__ + 56;
    var $2 = __stackBase__ + 64;
    var $ss2 = __stackBase__ + 72;
    var $3 = __stackBase__ + 116;
    var $4 = __stackBase__ + 124;
    var $5 = __stackBase__ + 132;
    var $6 = $ss | 0;
    var $8 = HEAPU32[$ss >> 2];
    if (__stackBase__ + 20 >>> 0 < HEAPU32[$8 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($8);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 3:
    var $16 = HEAPU32[$ss + 40 >> 2];
    var $17 = ($nb | 0) < 0;
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $19 = $16 + 56 | 0;
    var $20 = HEAP32[$19 >> 2];
    var $29 = HEAP32[$20 >> 2] + HEAP32[$20 + 8 >> 2] | 0;
    var $_pre_phi = $19;
    __label__ = 6;
    break;
   case 5:
    var $29 = $pc + $nb | 0;
    var $_pre_phi = $16 + 56 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $29;
    HEAP32[$todo >> 2] = -2;
    HEAP32[$saveop >> 2] = 0;
    var $30 = $ss + 28 | 0;
    var $31 = $nb ^ -1;
    var $32 = $16 + 60 | 0;
    var $33 = $8;
    var $34 = $8;
    var $35 = $16 + 48 | 0;
    var $36 = $ss + 24 | 0;
    var $37 = $ss + 8 | 0;
    var $38 = $ss + 16 | 0;
    var $39 = $16 + 52 | 0;
    var $40 = $16 + 53 | 0;
    var $41 = $16 + 54 | 0;
    var $42 = $ss + 20 | 0;
    var $43 = $smallv | 0;
    var $44 = $r;
    var $45 = $16 | 0;
    var $46 = $16 + 68 | 0;
    var $47 = $16 + 72 | 0;
    var $48 = $29;
    var $49 = $ss + 36 | 0;
    var $50 = $ss + 32 | 0;
    var $51 = $8 + 52 | 0;
    var $52 = $2 | 0;
    var $53 = $val | 0;
    var $54 = $8 + 72 | 0;
    var $55 = $8 + 88 | 0;
    var $56 = $ss2 + 36 | 0;
    var $57 = $ss2 + 28 | 0;
    var $58 = $ss2 + 24 | 0;
    var $59 = $54 | 0;
    var $60 = $8 + 96 | 0;
    var $61 = $8;
    var $62 = $8;
    var $63 = $4 | 0;
    var $64 = $5 | 0;
    var $_016 = $pc;
    var $rval_0 = 0;
    var $foreach_0 = 0;
    var $inXML_0 = 0;
    var $quoteAttr_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $quoteAttr_0;
    var $inXML_0;
    var $foreach_0;
    var $rval_0;
    var $_016;
    if ($17 | $_016 >>> 0 < $29 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $_016;
      __label__ = 742;
      break;
    }
   case 8:
    var $67 = HEAPU32[$saveop >> 2];
    var $69 = HEAPU8[$_016] & 255;
    var $70 = _js_CodeSpec + ($69 << 3) | 0;
    if ((HEAP32[_js_CodeSpec + ($69 << 3) + 4 >> 2] & 262144 | 0) == 0) {
      var $_1 = $_016;
      var $op_0 = $69;
      var $cs_0 = $70;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $79 = $_016 + (HEAP8[$70 | 0] << 24 >> 24) | 0;
    if ($79 >>> 0 < $29 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $79;
      __label__ = 742;
      break;
    }
   case 10:
    var $83 = HEAPU8[$79] & 255;
    var $_1 = $79;
    var $op_0 = $83;
    var $cs_0 = _js_CodeSpec + ($83 << 3) | 0;
    __label__ = 11;
    break;
   case 11:
    var $cs_0;
    var $op_0;
    var $_1;
    HEAP32[$saveop >> 2] = $op_0;
    var $87 = HEAPU32[$cs_0 >> 2];
    var $89 = $87 << 24 >> 24;
    var $91 = ($87 & 65535 & 65535) >>> 8 & 255;
    var $92 = _js_GetStackUses2860($91, $op_0, $_1);
    var $94 = $87 >>> 16 & 255;
    if ($17) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (HEAPU32[$30 >> 2] >>> 0 < $92 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $99 = HEAP32[$_pre_phi >> 2];
    var $100 = _js_GetStackDefs($8, $94, $99, $_1);
    if (($100 - $92 + HEAP32[$30 >> 2] | 0) == ($31 | 0)) {
      var $_0 = $_1;
      __label__ = 742;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $107 = HEAPU32[__ZL9CodeToken + ($op_0 << 2) >> 2];
    var $108 = $_1 + $89 | 0;
    if (($108 | 0) == (HEAP32[$32 >> 2] | 0)) {
      __label__ = 15;
      break;
    } else {
      var $op_2 = $op_0;
      __label__ = 35;
      break;
    }
   case 15:
    var $112 = __Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE($8, 0);
    var $114 = HEAPU32[$cs_0 + 4 >> 2];
    if (($112 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js12ContextStackC2EP9JSContext($1, $33);
    var $117 = $112;
    var $118 = __ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE($117, $1, 0, 0);
    if (($_1 | 0) == ($118 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if (($114 & 12192 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 18:
    if (($_1 | 0) != ($pc | 0) | ($92 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if (($114 & 12192 | 0) == 0) {
      var $op_1 = $op_0;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $129 = $114 & 224;
    if (($129 | 0) == 32) {
      __label__ = 21;
      break;
    } else if (($129 | 0) == 64) {
      __label__ = 25;
      break;
    } else if (($129 | 0) == 96) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $131 = $114 & 31;
    if (($131 | 0) == 6) {
      var $137 = 84;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $135 = ($131 | 0) == 7 ? 86 : 59;
    var $137 = $135;
    __label__ = 23;
    break;
   case 23:
    var $137;
    var $141 = $92 - (HEAP8[_js_CodeSpec + ($137 << 3) + 1 | 0] << 24 >> 24) | 0;
    HEAP32[$i >> 2] = $141 - 1 | 0;
    if (($141 | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      var $op_1_ph = $137;
      __label__ = 29;
      break;
    }
   case 24:
    var $144 = __ZL6PopOffP11SprintStack4JSOp($ss, 0);
    var $_pr = HEAP32[$i >> 2];
    var $145 = $_pr - 1 | 0;
    HEAP32[$i >> 2] = $145;
    if (($_pr | 0) > 0) {
      __label__ = 24;
      break;
    } else {
      var $op_1_ph = $137;
      __label__ = 29;
      break;
    }
   case 25:
    var $150 = ($114 & 256 | 0) != 0 ? 232 : 53;
    var $op_1 = $150;
    __label__ = 30;
    break;
   case 26:
    var $154 = ($114 & 256 | 0) != 0 ? 233 : 55;
    var $op_1 = $154;
    __label__ = 30;
    break;
   case 27:
    if (($op_0 | 0) == 173) {
      __label__ = 28;
      break;
    } else if (($op_0 | 0) == 124 || ($op_0 | 0) == 209) {
      var $op_1_ph = 55;
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 28:
    HEAP32[$saveop >> 2] = 233;
    __label__ = 33;
    break;
   case 29:
    var $op_1_ph;
    HEAP32[$saveop >> 2] = $op_1_ph;
    var $op_1204 = $op_1_ph;
    __label__ = 34;
    break;
   case 30:
    var $op_1;
    HEAP32[$saveop >> 2] = $op_1;
    if (($op_1 | 0) > 231) {
      __label__ = 31;
      break;
    } else {
      var $op_1204 = $op_1;
      __label__ = 34;
      break;
    }
   case 31:
    if (($op_1 | 0) == 232) {
      __label__ = 32;
      break;
    } else if (($op_1 | 0) == 233) {
      __label__ = 33;
      break;
    } else {
      var $op_1204 = $op_1;
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$saveop >> 2] = 53;
    var $op_1204 = 232;
    __label__ = 34;
    break;
   case 33:
    HEAP32[$saveop >> 2] = 55;
    var $op_1204 = 233;
    __label__ = 34;
    break;
   case 34:
    var $op_1204;
    HEAP32[$32 >> 2] = 0;
    var $op_2 = $op_1204;
    __label__ = 35;
    break;
   case 35:
    var $op_2;
    if (($107 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($92 | 0) == 2) {
      __label__ = 37;
      break;
    } else if (($92 | 0) == 1) {
      __label__ = 44;
      break;
    } else if (($92 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 37:
    var $166 = HEAP32[$_pre_phi >> 2];
    var $167 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $166, $_1);
    if (($167 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $170 = HEAPU8[$167];
    if (($170 & 255) < 192 & ($170 & -8) << 24 >> 24 == 64) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $174 = HEAPU8[$108] & 255;
    var $175 = __ZL6PopStrP11SprintStack4JSOp($ss, $174);
    var $176 = __ZL6PopStrP11SprintStack4JSOp($ss, $174);
    var $177 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $175);
    HEAP32[$todo >> 2] = $177;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $175;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 40:
    if (($inXML_0 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $180 = $cs_0 + 3 | 0;
    var $183 = $cs_0 + 4 | 0;
    var $187 = (HEAPU32[$183 >> 2] >>> 16 & 1) + (HEAPU8[$180] & 255) & 255;
    var $188 = __ZL10PopStrPrecP11SprintStackh($ss, $187);
    var $195 = (HEAPU32[$183 >> 2] >>> 16 & 1 ^ 1) + (HEAPU8[$180] & 255) & 255;
    var $196 = __ZL10PopStrPrecP11SprintStackh($ss, $195);
    var $197 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str402713 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $196, HEAP32[tempInt + 4 >> 2] = $107, HEAP32[tempInt + 8 >> 2] = $188, tempInt));
    HEAP32[$todo >> 2] = $197;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $188;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 42:
    if (($op_2 | 0) == 27) {
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 43:
    var $201 = __ZL6PopStrP11SprintStack4JSOp($ss, 27);
    var $202 = __ZL6PopStrP11SprintStack4JSOp($ss, 27);
    var $203 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $202, HEAP32[tempInt + 4 >> 2] = $201, tempInt));
    HEAP32[$todo >> 2] = $203;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $201;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 44:
    var $205 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $206 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $107, HEAP32[tempInt + 4 >> 2] = $205, tempInt));
    HEAP32[$todo >> 2] = $206;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $205;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 45:
    var $208 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $107);
    HEAP32[$todo >> 2] = $208;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 46:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 47:
    if (($op_2 | 0) == 7 || ($op_2 | 0) == 142) {
      __label__ = 48;
      break;
    } else if (($op_2 | 0) == 0) {
      __label__ = 49;
      break;
    } else if (($op_2 | 0) == 1) {
      __label__ = 87;
      break;
    } else if (($op_2 | 0) == 110 || ($op_2 | 0) == 217) {
      __label__ = 91;
      break;
    } else if (($op_2 | 0) == 134) {
      __label__ = 92;
      break;
    } else if (($op_2 | 0) == 135) {
      __label__ = 93;
      break;
    } else if (($op_2 | 0) == 117) {
      __label__ = 96;
      break;
    } else if (($op_2 | 0) == 116 || ($op_2 | 0) == 146) {
      __label__ = 99;
      break;
    } else if (($op_2 | 0) == 11) {
      __label__ = 100;
      break;
    } else if (($op_2 | 0) == 81 || ($op_2 | 0) == 2) {
      __label__ = 138;
      break;
    } else if (($op_2 | 0) == 3) {
      __label__ = 161;
      break;
    } else if (($op_2 | 0) == 4) {
      __label__ = 163;
      break;
    } else if (($op_2 | 0) == 201) {
      __label__ = 167;
      break;
    } else if (($op_2 | 0) == 202 || ($op_2 | 0) == 210) {
      __label__ = 209;
      break;
    } else if (($op_2 | 0) == 136 || ($op_2 | 0) == 137) {
      __label__ = 222;
      break;
    } else if (($op_2 | 0) == 215 || ($op_2 | 0) == 86) {
      __label__ = 232;
      break;
    } else if (($op_2 | 0) == 87 || ($op_2 | 0) == 132) {
      __label__ = 241;
      break;
    } else if (($op_2 | 0) == 101 || ($op_2 | 0) == 102) {
      __label__ = 244;
      break;
    } else if (($op_2 | 0) == 103 || ($op_2 | 0) == 104) {
      __label__ = 247;
      break;
    } else if (($op_2 | 0) == 155) {
      __label__ = 250;
      break;
    } else if (($op_2 | 0) == 5) {
      __label__ = 251;
      break;
    } else if (($op_2 | 0) == 154) {
      __label__ = 256;
      break;
    } else if (($op_2 | 0) == 206) {
      __label__ = 260;
      break;
    } else if (($op_2 | 0) == 207) {
      __label__ = 270;
      break;
    } else if (($op_2 | 0) == 153) {
      __label__ = 284;
      break;
    } else if (($op_2 | 0) == 112) {
      __label__ = 285;
      break;
    } else if (($op_2 | 0) == 75) {
      __label__ = 288;
      break;
    } else if (($op_2 | 0) == 78) {
      __label__ = 289;
      break;
    } else if (($op_2 | 0) == 6 || ($op_2 | 0) == 141) {
      __label__ = 292;
      break;
    } else if (($op_2 | 0) == 68 || ($op_2 | 0) == 144) {
      var $xval_0 = STRING_TABLE.__str2063358 | 0;
      __label__ = 355;
      break;
    } else if (($op_2 | 0) == 69 || ($op_2 | 0) == 145) {
      __label__ = 365;
      break;
    } else if (($op_2 | 0) == 124 || ($op_2 | 0) == 209) {
      __label__ = 366;
      break;
    } else if (($op_2 | 0) == 125 || ($op_2 | 0) == 126) {
      __label__ = 370;
      break;
    } else if (($op_2 | 0) == 13) {
      __label__ = 371;
      break;
    } else if (($op_2 | 0) == 12) {
      __label__ = 373;
      break;
    } else if (($op_2 | 0) == 85) {
      __label__ = 381;
      break;
    } else if (($op_2 | 0) == 14 || ($op_2 | 0) == 111 || ($op_2 | 0) == 157) {
      __label__ = 382;
      break;
    } else if (($op_2 | 0) == 82 || ($op_2 | 0) == 58 || ($op_2 | 0) == 123 || ($op_2 | 0) == 108 || ($op_2 | 0) == 79) {
      __label__ = 400;
      break;
    } else if (($op_2 | 0) == 74) {
      __label__ = 419;
      break;
    } else if (($op_2 | 0) == 36) {
      __label__ = 420;
      break;
    } else if (($op_2 | 0) == 37) {
      __label__ = 427;
      break;
    } else if (($op_2 | 0) == 38) {
      __label__ = 433;
      break;
    } else if (($op_2 | 0) == 186) {
      __label__ = 435;
      break;
    } else if (($op_2 | 0) == 200 || ($op_2 | 0) == 39 || ($op_2 | 0) == 40) {
      __label__ = 436;
      break;
    } else if (($op_2 | 0) == 97 || ($op_2 | 0) == 98) {
      __label__ = 437;
      break;
    } else if (($op_2 | 0) == 41 || ($op_2 | 0) == 44 || ($op_2 | 0) == 158 || ($op_2 | 0) == 159) {
      __label__ = 438;
      break;
    } else if (($op_2 | 0) == 42 || ($op_2 | 0) == 45) {
      __label__ = 446;
      break;
    } else if (($op_2 | 0) == 43 || ($op_2 | 0) == 46) {
      __label__ = 452;
      break;
    } else if (($op_2 | 0) == 99 || ($op_2 | 0) == 100) {
      __label__ = 456;
      break;
    } else if (($op_2 | 0) == 47 || ($op_2 | 0) == 50 || ($op_2 | 0) == 160 || ($op_2 | 0) == 161) {
      __label__ = 457;
      break;
    } else if (($op_2 | 0) == 48 || ($op_2 | 0) == 51) {
      __label__ = 465;
      break;
    } else if (($op_2 | 0) == 49 || ($op_2 | 0) == 52) {
      __label__ = 471;
      break;
    } else if (($op_2 | 0) == 232) {
      __label__ = 475;
      break;
    } else if (($op_2 | 0) == 187 || ($op_2 | 0) == 53 || ($op_2 | 0) == 198 || ($op_2 | 0) == 220) {
      var $op_9 = $op_2;
      __label__ = 476;
      break;
    } else if (($op_2 | 0) == 54 || ($op_2 | 0) == 226) {
      __label__ = 484;
      break;
    } else if (($op_2 | 0) == 233) {
      __label__ = 495;
      break;
    } else if (($op_2 | 0) == 196 || ($op_2 | 0) == 55) {
      __label__ = 496;
      break;
    } else if (($op_2 | 0) == 56) {
      __label__ = 501;
      break;
    } else if (($op_2 | 0) == 138) {
      __label__ = 508;
      break;
    } else if (($op_2 | 0) == 139) {
      __label__ = 509;
      break;
    } else if (($op_2 | 0) == 216 || ($op_2 | 0) == 84) {
      __label__ = 510;
      break;
    } else if (($op_2 | 0) == 57 || ($op_2 | 0) == 59 || ($op_2 | 0) == 156 || ($op_2 | 0) == 214) {
      __label__ = 512;
      break;
    } else if (($op_2 | 0) == 88) {
      __label__ = 518;
      break;
    } else if (($op_2 | 0) == 190) {
      __label__ = 519;
      break;
    } else if (($op_2 | 0) == 218) {
      __label__ = 520;
      break;
    } else if (($op_2 | 0) == 219) {
      __label__ = 521;
      break;
    } else if (($op_2 | 0) == 60) {
      __label__ = 523;
      break;
    } else if (($op_2 | 0) == 61) {
      __label__ = 524;
      break;
    } else if (($op_2 | 0) == 130 || ($op_2 | 0) == 224) {
      __label__ = 530;
      break;
    } else if (($op_2 | 0) == 131) {
      __label__ = 571;
      break;
    } else if (($op_2 | 0) == 80) {
      __label__ = 572;
      break;
    } else if (($op_2 | 0) == 162) {
      __label__ = 573;
      break;
    } else if (($op_2 | 0) == 70 || ($op_2 | 0) == 149) {
      __label__ = 575;
      break;
    } else if (($op_2 | 0) == 71 || ($op_2 | 0) == 150) {
      __label__ = 592;
      break;
    } else if (($op_2 | 0) == 120) {
      __label__ = 604;
      break;
    } else if (($op_2 | 0) == 121 || ($op_2 | 0) == 147) {
      __label__ = 624;
      break;
    } else if (($op_2 | 0) == 127 || ($op_2 | 0) == 222) {
      __label__ = 626;
      break;
    } else if (($op_2 | 0) == 83) {
      __label__ = 627;
      break;
    } else if (($op_2 | 0) == 221) {
      __label__ = 631;
      break;
    } else if (($op_2 | 0) == 89) {
      __label__ = 632;
      break;
    } else if (($op_2 | 0) == 90) {
      __label__ = 641;
      break;
    } else if (($op_2 | 0) == 91) {
      __label__ = 642;
      break;
    } else if (($op_2 | 0) == 92) {
      __label__ = 643;
      break;
    } else if (($op_2 | 0) == 94) {
      __label__ = 652;
      break;
    } else if (($op_2 | 0) == 93 || ($op_2 | 0) == 227) {
      __label__ = 655;
      break;
    } else if (($op_2 | 0) == 95) {
      __label__ = 670;
      break;
    } else if (($op_2 | 0) == 96) {
      __label__ = 671;
      break;
    } else if (($op_2 | 0) == 115) {
      __label__ = 672;
      break;
    } else if (($op_2 | 0) == 194 || ($op_2 | 0) == 195) {
      __label__ = 673;
      break;
    } else if (($op_2 | 0) == 163) {
      __label__ = 674;
      break;
    } else if (($op_2 | 0) == 164) {
      __label__ = 675;
      break;
    } else if (($op_2 | 0) == 165) {
      __label__ = 678;
      break;
    } else if (($op_2 | 0) == 166) {
      __label__ = 684;
      break;
    } else if (($op_2 | 0) == 167) {
      __label__ = 690;
      break;
    } else if (($op_2 | 0) == 168) {
      __label__ = 691;
      break;
    } else if (($op_2 | 0) == 169) {
      __label__ = 692;
      break;
    } else if (($op_2 | 0) == 170) {
      __label__ = 693;
      break;
    } else if (($op_2 | 0) == 171) {
      __label__ = 694;
      break;
    } else if (($op_2 | 0) == 172) {
      __label__ = 697;
      break;
    } else if (($op_2 | 0) == 173) {
      __label__ = 698;
      break;
    } else if (($op_2 | 0) == 181 || ($op_2 | 0) == 180) {
      __label__ = 699;
      break;
    } else if (($op_2 | 0) == 179) {
      __label__ = 700;
      break;
    } else if (($op_2 | 0) == 178 || ($op_2 | 0) == 199 || ($op_2 | 0) == 174 || ($op_2 | 0) == 176) {
      __label__ = 701;
      break;
    } else if (($op_2 | 0) == 177) {
      __label__ = 702;
      break;
    } else if (($op_2 | 0) == 175) {
      __label__ = 705;
      break;
    } else if (($op_2 | 0) == 183) {
      __label__ = 708;
      break;
    } else if (($op_2 | 0) == 184) {
      __label__ = 714;
      break;
    } else if (($op_2 | 0) == 185) {
      __label__ = 720;
      break;
    } else if (($op_2 | 0) == 208) {
      __label__ = 733;
      break;
    } else if (($op_2 | 0) == 76) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else if (($op_2 | 0) == 118 || ($op_2 | 0) == 8 || ($op_2 | 0) == 143) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 734;
      break;
    }
   case 48:
    var $_12 = $_1;
    var $oplen_1 = $89;
    var $rval_11 = $rval_0;
    var $elseif_0 = 0;
    var $_12_val = HEAP8[$_1];
    __label__ = 324;
    break;
   case 49:
    var $213 = HEAP32[$_pre_phi >> 2];
    var $214 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $213, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($214 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $217 = HEAPU8[$214];
    if (($217 & 255) > 191) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $221 = ($217 & 255) >>> 3;
    if (($221 | 0) == 4) {
      __label__ = 52;
      break;
    } else if (($221 | 0) == 3) {
      var $_2 = $_1;
      var $op_3 = $op_2;
      var $sn_0 = $214;
      var $rval_1 = __str93064 | 0;
      __label__ = 55;
      break;
    } else if (($221 | 0) == 13) {
      __label__ = 71;
      break;
    } else if (($221 | 0) == 14) {
      __label__ = 74;
      break;
    } else if (($221 | 0) == 15) {
      __label__ = 77;
      break;
    } else if (($221 | 0) == 19) {
      __label__ = 78;
      break;
    } else if (($221 | 0) == 10) {
      __label__ = 85;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 52:
    var $223 = $_1 + 1 | 0;
    var $225 = HEAP32[$_pre_phi >> 2];
    var $226 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $225, $223);
    var $227 = _js_GetSrcNoteOffset($226, 0);
    var $228 = $227 + ($_1 + 1) | 0;
    var $229 = HEAP8[$228];
    if ($229 << 24 >> 24 == 8 || $229 << 24 >> 24 == -113) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 53:
    var $231 = _js_printf($16, STRING_TABLE.__str412714 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $233 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $233;
    var $234 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $223, $227);
    if (($234 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $238 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $238;
    var $249 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $250 = __ZL6PopStrP11SprintStack4JSOp($ss, $249);
    var $251 = _js_printf($16, STRING_TABLE.__str422715 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $250, tempInt));
    var $256 = HEAP8[_js_CodeSpec + ((HEAPU8[$228] & 255) << 3) | 0] << 24 >> 24;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $228;
    var $len_10 = $256;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 55:
    var $rval_1;
    var $sn_0;
    var $op_3;
    var $_2;
    var $258 = $_2 + 1 | 0;
    var $259 = _js_GetSrcNoteOffset($sn_0, 0);
    var $260 = _js_GetSrcNoteOffset($sn_0, 1);
    var $261 = _js_GetSrcNoteOffset($sn_0, 2);
    var $262 = ($259 | 0) != ($261 | 0);
    if ($262) {
      __label__ = 56;
      break;
    } else {
      var $pc2_0 = $258;
      __label__ = 58;
      break;
    }
   case 56:
    var $264 = HEAP8[$258];
    if ($264 << 24 >> 24 == 6 || $264 << 24 >> 24 == -115) {
      __label__ = 57;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 57:
    var $_sum94 = $264 << 24 >> 24 == 6 ? 4 : 6;
    var $pc2_0 = $_2 + $_sum94 | 0;
    __label__ = 58;
    break;
   case 58:
    var $pc2_0;
    var $269 = $261 + ($_2 + 1) | 0;
    var $_val10 = HEAP8[$269];
    var $270 = __ZL13GetJumpOffsetPhS_($_val10, $269);
    var $274 = $pc2_0 - $258 | 0;
    if (($270 + $261 | 0) == ($274 | 0)) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 59:
    var $277 = _js_printf($16, STRING_TABLE.__str432716 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $rval_1, tempInt));
    if ($262) {
      __label__ = 60;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 60:
    var $279 = $259 + ($_2 + 1) | 0;
    var $280 = $261 - $259 | 0;
    var $281 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $279, $280);
    if (($281 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $284 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_3);
    var $285 = _js_printf($16, STRING_TABLE.__str442717 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $284, tempInt));
    __label__ = 62;
    break;
   case 62:
    var $287 = _js_puts($16, STRING_TABLE.__str452718 | 0);
    if (($260 | 0) == ($259 | 0)) {
      var $rval_2 = $rval_1;
      __label__ = 69;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $290 = HEAPU32[$30 >> 2];
    var $291 = $260 + ($_2 + 1) | 0;
    var $293 = $259 - 1 - $260 | 0;
    var $294 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $291, $293);
    if (($294 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $297 = HEAPU32[$30 >> 2];
    if (($297 - $290 | 0) >>> 0 < 2) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 65:
    if (($297 | 0) == ($290 | 0)) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    var $309 = HEAP32[$37 >> 2] + HEAP32[$38 >> 2] | 0;
    __label__ = 68;
    break;
   case 67:
    var $307 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_3);
    var $309 = $307;
    __label__ = 68;
    break;
   case 68:
    var $309;
    var $310 = _js_printf($16, STRING_TABLE.__str442717 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $309, tempInt));
    var $rval_2 = $309;
    __label__ = 69;
    break;
   case 69:
    var $rval_2;
    var $312 = _js_printf($16, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $314 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $314;
    var $315 = $260 - $274 | 0;
    var $316 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc2_0, $315);
    if (($316 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $320 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $320;
    var $321 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $258;
    var $len_10 = (HEAP8[_js_CodeSpec + ((HEAPU8[$269] & 255) << 3) | 0] << 24 >> 24) + $261 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_2;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 71:
    var $329 = _js_GetSrcNoteOffset($214, 0);
    var $330 = HEAPU32[$_pre_phi >> 2];
    if ($329 >>> 0 < HEAPU32[$330 + 40 >> 2] >>> 0) {
      __label__ = 72;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 72:
    var $338 = HEAP32[HEAP32[$330 + 56 >> 2] + ($329 << 2) >> 2];
    var $340 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $340;
    var $341 = $338 | 0;
    var $342 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $341, 0);
    if (($342 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $348 = $342 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $348;
    var $349 = _js_printf($16, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $342, tempInt));
    var $351 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $351;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $342;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 74:
    var $353 = _js_GetSrcNoteOffset($214, 0);
    var $354 = HEAPU32[$_pre_phi >> 2];
    if ($353 >>> 0 < HEAPU32[$354 + 40 >> 2] >>> 0) {
      __label__ = 75;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 75:
    var $363 = HEAP32[HEAP32[$354 + 56 >> 2] + ($353 << 2) >> 2] | 0;
    var $364 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $363, 0);
    if (($364 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $370 = $364 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $370;
    var $371 = _js_printf($16, STRING_TABLE.__str482721 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $364, tempInt));
    var $373 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $373;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $364;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 77:
    var $376 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $376;
    var $377 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 78:
    var $379 = HEAP32[$_pre_phi >> 2];
    var $380 = _js_GetSrcNoteOffset($214, 0);
    var $381 = __ZN8JSScript11getFunctionEj($379, $380);
    var $fun_0 = $381;
    __label__ = 79;
    break;
   case 79:
    var $fun_0;
    var $383 = _js_puts($16, STRING_TABLE.__str492722 | 0);
    var $384 = HEAP32[$35 >> 2];
    var $387 = HEAP8[$39] & 1 & 255;
    var $390 = HEAP8[$40] & 1 & 255;
    var $393 = HEAP8[$41] & 1 & 255;
    var $394 = _js_NewPrinter($8, undef, $fun_0, $384, $387, $390, $393);
    if (($394 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $397 = _js_DecompileFunction($394);
    if (($397 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $401 = HEAP32[$394 + 8 >> 2];
    if (($401 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $404 = _js_puts($16, $401);
    __label__ = 84;
    break;
   case 83:
    _js_DestroyPrinter($394);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 84:
    _js_DestroyPrinter($394);
    var $406 = _js_puts($16, STRING_TABLE.__str512724 | 0);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 85:
    var $408 = _js_printf($16, STRING_TABLE.__str522725 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $410 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $410;
    var $411 = _js_GetSrcNoteOffset($214, 0);
    var $412 = $411 - $89 | 0;
    var $413 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $412);
    if (($413 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $417 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $417;
    var $418 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $411;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 87:
    var $421 = HEAP32[$_pre_phi >> 2];
    var $422 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $421, $_1);
    if (($422 | 0) == 0) {
      __label__ = 91;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $425 = HEAPU8[$422];
    if (($425 & 255) < 192 & ($425 & -8) << 24 >> 24 == 56) {
      __label__ = 89;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 89:
    var $428 = __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $_1, $29, $422, $todo);
    if (($428 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    if (HEAP8[$428] << 24 >> 24 == 11) {
      var $_3 = $428;
      var $oplen_0 = 3;
      __label__ = 117;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 91:
    var $433 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str93064 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $433;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 92:
    var $435 = _js_printf($16, STRING_TABLE.__str532726 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $437 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $437;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 93:
    var $440 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $440;
    var $441 = _js_printf($16, STRING_TABLE.__str542727 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $443 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $443;
    var $444 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $444;
    if (($444 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    var $447 = __ZL7PushOffP11SprintStacki4JSOp($ss, $444, 135);
    if (($447 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $450 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $450;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 96:
    var $452 = __ZL6PopStrP11SprintStack4JSOp($ss, 117);
    var $453 = _strcmp($452, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie | 0);
    if (($453 | 0) == 0) {
      __label__ = 97;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 97:
    var $456 = __ZL6PopStrP11SprintStack4JSOp($ss, 117);
    var $457 = _strcmp($456, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($457 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 98:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $452;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 99:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 100:
    var $462 = HEAPU32[$30 >> 2];
    var $470 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $471 = $462 - $470 | 0;
    if ($471 >>> 0 > $462 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    HEAP32[$todo >> 2] = -2;
    var $475 = HEAP32[$_pre_phi >> 2];
    var $476 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $475, $_1);
    if (($476 | 0) == 0) {
      __label__ = 136;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $479 = HEAPU8[$476];
    var $480 = ($479 & 255) < 192;
    var $_mask116 = $479 & -8;
    if ($480 & $_mask116 << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    if ($480 & $_mask116 << 24 >> 24 == 56) {
      __label__ = 104;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 104:
    var $482 = __ZL9VarPrefixPh($476);
    var $483 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str552728 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $482, tempInt));
    HEAP32[$todo >> 2] = $483;
    if (($483 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $485 = $462 - 1 | 0;
    var $i2_0 = $471;
    __label__ = 106;
    break;
   case 106:
    var $i2_0;
    if ($i2_0 >>> 0 < $462 >>> 0) {
      __label__ = 107;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 107:
    var $493 = HEAP32[$37 >> 2] + HEAP32[HEAP32[$42 >> 2] + ($i2_0 << 2) >> 2] | 0;
    var $495 = ($i2_0 | 0) == ($471 | 0) ? __str93064 | 0 : STRING_TABLE.__str332706 | 0;
    if (($i2_0 | 0) == ($485 | 0)) {
      __label__ = 108;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 108:
    if (HEAP8[$493] << 24 >> 24 == 0) {
      var $502 = STRING_TABLE.__str332706 | 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $502 = $493;
    __label__ = 110;
    break;
   case 110:
    var $502;
    var $503 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $495, HEAP32[tempInt + 4 >> 2] = $502, tempInt));
    if (($503 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 111:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 106;
    break;
   case 112:
    var $508 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str562729 | 0, 1);
    if (($508 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    if (($470 | 0) == 0) {
      __label__ = 114;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 114:
    var $513 = HEAP32[$todo >> 2];
    HEAP32[$38 >> 2] = $513;
    var $_3 = $_1;
    var $oplen_0 = $89;
    __label__ = 117;
    break;
   case 115:
    if ($471 >>> 0 < $462 >>> 0) {
      __label__ = 116;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 116:
    var $517 = __ZL6GetOffP11SprintStackj($ss, $471);
    HEAP32[$38 >> 2] = $517;
    HEAP32[$30 >> 2] = $471;
    var $_3 = $_1;
    var $oplen_0 = $89;
    __label__ = 117;
    break;
   case 117:
    var $oplen_0;
    var $_3;
    if (HEAP8[$_3] << 24 >> 24 == 11) {
      __label__ = 118;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 118:
    var $524 = HEAP32[$37 >> 2] + HEAP32[$todo >> 2] | 0;
    HEAP32[$todo >> 2] = -2;
    var $525 = $_3 + $oplen_0 | 0;
    if (HEAP8[$525] << 24 >> 24 == 0) {
      __label__ = 119;
      break;
    } else {
      var $pc2_1 = $525;
      __label__ = 122;
      break;
    }
   case 119:
    var $530 = HEAP8[$oplen_0 + ($_3 + 1) | 0];
    if ($530 << 24 >> 24 == -67) {
      __label__ = 120;
      break;
    } else if ($530 << 24 >> 24 == -68) {
      __label__ = 121;
      break;
    } else {
      var $pc2_1 = $525;
      __label__ = 122;
      break;
    }
   case 120:
    var $pc2_1 = $oplen_0 + ($_3 + 2) | 0;
    __label__ = 122;
    break;
   case 121:
    var $pc2_1 = $oplen_0 + ($_3 + 4) | 0;
    __label__ = 122;
    break;
   case 122:
    var $pc2_1;
    if (HEAP8[$pc2_1] << 24 >> 24 == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 123:
    var $540 = HEAP32[$_pre_phi >> 2];
    var $541 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $540, $pc2_1);
    if (($541 | 0) == 0) {
      __label__ = 132;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $544 = HEAPU8[$541];
    var $545 = ($544 & 255) < 192;
    var $_mask87 = $544 & -8;
    if ($545 & $_mask87 << 24 >> 24 == 24) {
      var $_2 = $pc2_1;
      var $op_3 = 0;
      var $sn_0 = $541;
      var $rval_1 = $524;
      __label__ = 55;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    if ($545 & $_mask87 << 24 >> 24 == 48) {
      __label__ = 127;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $578 = HEAP32[$todo >> 2];
    __label__ = 134;
    break;
   case 127:
    var $547 = HEAP32[$30 >> 2];
    var $548 = HEAP32[$_pre_phi >> 2];
    var $_idx13_val = HEAP16[$548 + 14 >> 1];
    var $_idx14_val = HEAP16[$548 + 44 >> 1];
    var $549 = __ZL10StackDepthP8JSScript($_idx13_val, $_idx14_val);
    if (($547 | 0) == ($549 | 0)) {
      __label__ = 128;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 128:
    var $552 = _js_GetSrcNoteOffset($541, 0);
    if (HEAP8[$552 + ($pc2_1 + 1) | 0] << 24 >> 24 == -54) {
      __label__ = 129;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 129:
    var $557 = $pc2_1 + 1 | 0;
    var $558 = _js_printf($16, STRING_TABLE.__str572730 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $524, tempInt));
    var $559 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $557;
    var $len_10 = $552;
    var $cs_3 = $cs_0;
    var $rval_18 = $524;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 130:
    var $561 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $524);
    HEAP32[$todo >> 2] = $561;
    if (($561 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    var $564 = __ZL7PushOffP11SprintStacki4JSOp($ss, $561, 0);
    if (($564 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $pc2_1_pn = $pc2_1;
      var $op_6 = 81;
      var $sn_1 = $541;
      var $rval_3 = $524;
      __label__ = 147;
      break;
    }
   case 132:
    if (((HEAPU8[$_3 + 1 | 0] & 255) << 8 | HEAPU8[$_3 + 2 | 0] & 255 | 0) == 0) {
      var $_16 = $_3;
      var $len_10 = $oplen_0;
      var $cs_3 = $cs_0;
      var $rval_18 = $524;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 133;
      break;
    }
   case 133:
    var $577 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $524);
    HEAP32[$todo >> 2] = $577;
    HEAP32[$saveop >> 2] = 0;
    var $578 = $577;
    __label__ = 134;
    break;
   case 134:
    var $578;
    if (($578 | 0) == -2) {
      __label__ = 135;
      break;
    } else {
      var $_16 = $_3;
      var $len_10 = $oplen_0;
      var $cs_3 = $cs_0;
      var $rval_18 = $524;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 135:
    var $580 = _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $524, tempInt));
    var $_16 = $_3;
    var $len_10 = $oplen_0;
    var $cs_3 = $cs_0;
    var $rval_18 = $524;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 136:
    if ($471 >>> 0 < $462 >>> 0) {
      __label__ = 137;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 137:
    var $583 = __ZL6GetOffP11SprintStackj($ss, $471);
    HEAP32[$38 >> 2] = $583;
    HEAP32[$30 >> 2] = $471;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 138:
    var $586 = HEAP32[$_pre_phi >> 2];
    var $587 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $586, $_1);
    if (($587 | 0) == 0) {
      __label__ = 154;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 139:
    var $590 = HEAPU8[$587];
    if (($590 & 255) > 191) {
      __label__ = 154;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    var $594 = ($590 & 255) >>> 3;
    if (($594 | 0) == 3) {
      __label__ = 141;
      break;
    } else if (($594 | 0) == 7) {
      __label__ = 142;
      break;
    } else if (($594 | 0) == 11) {
      __label__ = 146;
      break;
    } else if (($594 | 0) == 6) {
      var $pc2_1_pn = $_1;
      var $op_6 = 2;
      var $sn_1 = $587;
      var $rval_3 = $rval_0;
      __label__ = 147;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 141:
    var $op_5 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] << 24 >> 24 == 113 ? 24 : 2;
    var $602 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_5);
    HEAP32[$todo >> 2] = -2;
    var $_2 = $_1;
    var $op_3 = $op_5;
    var $sn_0 = $587;
    var $rval_1 = $602;
    __label__ = 55;
    break;
   case 142:
    var $604 = __ZL6PopStrP11SprintStack4JSOp($ss, 81);
    var $605 = _JS_strdup($8, $604);
    if (($605 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 143:
    var $608 = _js_GetSrcNoteOffset($587, 0);
    var $609 = $_1 + $608 | 0;
    var $612 = $609 - $108 | 0;
    var $613 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $612);
    if (($613 | 0) == 0) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    __ZN9JSContext5free_EPv(undef, $605);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 145:
    var $617 = __ZL6PopStrP11SprintStack4JSOp($ss, 81);
    var $618 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str592732 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $605, HEAP32[tempInt + 4 >> 2] = $617, tempInt));
    HEAP32[$todo >> 2] = $618;
    __ZN9JSContext5free_EPv(undef, $605);
    var $_16 = $609;
    var $len_10 = 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $617;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 146:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 147:
    var $rval_3;
    var $sn_1;
    var $op_6;
    var $pc2_1_pn;
    var $_4 = $pc2_1_pn + 1 | 0;
    var $621 = _js_GetSrcNoteOffset($sn_1, 0);
    var $623 = HEAP8[$621 + ($pc2_1_pn + 1) | 0];
    if ($623 << 24 >> 24 == -54) {
      __label__ = 148;
      break;
    } else if ($623 << 24 >> 24 == -46) {
      __label__ = 150;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 148:
    var $625 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_6);
    var $626 = _js_printf($16, STRING_TABLE.__str572730 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $625, tempInt));
    var $628 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $628;
    var $629 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_4, $621);
    if (($629 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    var $633 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $633;
    var $634 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_4;
    var $len_10 = $621;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_3;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 150:
    var $636 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $637 = _JS_strdup($8, $636);
    if (($637 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    HEAP32[$saveop >> 2] = 210;
    var $640 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_4, $621);
    if (($640 | 0) == 0) {
      __label__ = 152;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 152:
    __ZN9JSContext5free_EPv(undef, $637);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 153:
    var $644 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $647 = HEAP8[$644] << 24 >> 24 == 123 ? STRING_TABLE.__str602733 | 0 : STRING_TABLE.__str612734 | 0;
    var $648 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $647, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $637, HEAP32[tempInt + 4 >> 2] = $644, tempInt));
    HEAP32[$todo >> 2] = $648;
    __ZN9JSContext5free_EPv(undef, $637);
    var $_16 = $_4;
    var $len_10 = $621;
    var $cs_3 = $cs_0;
    var $rval_18 = $644;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 154:
    var $op_7 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] << 24 >> 24 == -50 ? 0 : 2;
    var $655 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_7);
    var $656 = HEAP8[$655];
    if ($656 << 24 >> 24 == 47) {
      __label__ = 155;
      break;
    } else if ($656 << 24 >> 24 == 123) {
      var $668 = STRING_TABLE.__str622735 | 0;
      __label__ = 158;
      break;
    } else if ($656 << 24 >> 24 == 0) {
      __label__ = 160;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 155:
    if (HEAP8[$655 + 1 | 0] << 24 >> 24 == 42) {
      __label__ = 159;
      break;
    } else {
      __label__ = 156;
      break;
    }
   case 156:
    var $661 = _strncmp($655, STRING_TABLE._js_function_str | 0, 8);
    if (($661 | 0) == 0) {
      __label__ = 157;
      break;
    } else {
      var $668 = STRING_TABLE.__str582731 | 0;
      __label__ = 158;
      break;
    }
   case 157:
    var $phitmp112 = HEAP8[$655 + 8 | 0] << 24 >> 24 == 32 ? STRING_TABLE.__str622735 | 0 : STRING_TABLE.__str582731 | 0;
    var $668 = $phitmp112;
    __label__ = 158;
    break;
   case 158:
    var $668;
    var $669 = _js_printf($16, $668, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $655, tempInt));
    __label__ = 160;
    break;
   case 159:
    var $671 = _strcmp($655, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($671 | 0) == 0) {
      __label__ = 160;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 160:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $655;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 161:
    var $675 = HEAP32[$_pre_phi >> 2];
    var $676 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $675, $_1);
    if (($676 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 162:
    var $679 = __ZL6PopStrP11SprintStack4JSOp($ss, 3);
    var $680 = _js_printf($16, STRING_TABLE.__str632736 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $679, tempInt));
    var $682 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $682;
    var $683 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $683;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $679;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 163:
    var $686 = HEAP32[$_pre_phi >> 2];
    var $687 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $686, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($687 | 0) == 0) {
      __label__ = 165;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    var $690 = HEAPU8[$687];
    if (($690 & 255) < 192 & ($690 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    var $692 = __ZL6PopStrP11SprintStack4JSOp($ss, 4);
    var $693 = _strcmp($692, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie | 0);
    if (($693 | 0) == 0) {
      __label__ = 166;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 166:
    var $697 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $697;
    var $698 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $692;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 167:
    var $700 = HEAP32[$_pre_phi >> 2];
    var $701 = _js_GetIndexFromBytecode($8, $700, $_1, 0);
    var $702 = HEAP32[$_pre_phi >> 2];
    var $703 = __ZN8JSScript9getObjectEj($702, $701);
    var $704 = $703;
    var $705 = __ZNK8JSObject13propertyCountEv($704);
    if ($705 >>> 0 < 6) {
      var $atomv_0 = $43;
      __label__ = 169;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 168:
    var $708 = $705 << 2;
    var $709 = __ZN9JSContext7malloc_Ej($8, $708);
    var $710 = $709;
    if (($709 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atomv_0 = $710;
      __label__ = 169;
      break;
    }
   case 169:
    var $atomv_0;
    var $713 = __ZNK8JSObject12lastPropertyEv($703);
    var $714 = $713;
    __ZNK2js5Shape3allEv($44, $714);
    __label__ = 170;
    break;
   case 170:
    var $716 = __ZNK2js5Shape5Range5emptyEv($44);
    if ($716) {
      var $rval_5 = $rval_0;
      var $storemerge104 = 0;
      __label__ = 175;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 171:
    var $718 = __ZNK2js5Shape5Range5frontEv($r);
    var $719 = $718;
    var $720 = __ZNK2js5Shape10hasShortIDEv($719);
    if ($720) {
      __label__ = 172;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 172:
    var $724 = HEAP16[$718 + 30 >> 1] << 16 >> 16;
    if (($724 | 0) < ($705 | 0)) {
      __label__ = 173;
      break;
    } else {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = $rval_0;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 173:
    var $728 = HEAP32[$718 + 12 >> 2];
    var $729 = __ZL12JSID_TO_ATOMi2841($728);
    HEAP32[$atomv_0 + ($724 << 2) >> 2] = $729;
    __label__ = 174;
    break;
   case 174:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 170;
    break;
   case 175:
    var $storemerge104;
    var $rval_5;
    HEAP32[$i >> 2] = $storemerge104;
    if (($storemerge104 | 0) < ($705 | 0)) {
      __label__ = 176;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 176:
    var $736 = HEAP32[$atomv_0 + ($storemerge104 << 2) >> 2] | 0;
    var $737 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $736, 0);
    if (($737 | 0) == 0) {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = 0;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $743 = $737 - HEAP32[$37 >> 2] | 0;
    var $744 = __ZL7PushOffP11SprintStacki4JSOp($ss, $743, 201);
    if (($744 | 0) == 0) {
      var $_10 = $_1;
      var $len_3 = $89;
      var $rval_7 = $737;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 178;
      break;
    }
   case 178:
    var $rval_5 = $737;
    var $storemerge104 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 175;
    break;
   case 179:
    var $751 = HEAP32[$_pre_phi >> 2];
    var $752 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $751, $_1);
    if (($752 | 0) == 0) {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    } else {
      __label__ = 180;
      break;
    }
   case 180:
    var $755 = HEAPU8[$752];
    if (($755 & 255) > 191) {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 181:
    var $759 = ($755 & 255) >>> 3;
    if (($759 | 0) == 10) {
      __label__ = 182;
      break;
    } else if (($759 | 0) == 20) {
      __label__ = 184;
      break;
    } else {
      var $_9 = $_1;
      var $len_2 = $89;
      var $rval_6 = $rval_5;
      var $ok_1 = 1;
      __label__ = 205;
      break;
    }
   case 182:
    var $761 = _js_printf($16, STRING_TABLE.__str522725 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $763 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $763;
    var $764 = _js_GetSrcNoteOffset($752, 0);
    var $765 = $764 - $89 | 0;
    var $766 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $765);
    var $767 = ($766 | 0) != 0;
    var $768 = $767 & 1;
    if ($767) {
      __label__ = 183;
      break;
    } else {
      var $_10 = $_1;
      var $len_3 = $764;
      var $rval_7 = $rval_5;
      var $ok_2 = $768;
      __label__ = 206;
      break;
    }
   case 183:
    var $771 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $771;
    var $772 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_9 = $_1;
    var $len_2 = $764;
    var $rval_6 = $rval_5;
    var $ok_1 = $768;
    __label__ = 205;
    break;
   case 184:
    var $775 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $775;
    var $776 = _js_printf($16, STRING_TABLE.__str642737 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if (HEAP8[$108] << 24 >> 24 == 118) {
      __label__ = 185;
      break;
    } else {
      var $_10 = $108;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 185:
    var $780 = $89 + ($_1 + 1) | 0;
    var $781 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $781;
    if (($781 | 0) < 0) {
      var $_10 = $780;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 186:
    var $784 = __ZL7PushOffP11SprintStacki4JSOp($ss, $781, 118);
    if (($784 | 0) == 0) {
      var $_10 = $780;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    if (HEAP8[$780] << 24 >> 24 == 12) {
      __label__ = 188;
      break;
    } else {
      var $_6 = $780;
      __label__ = 193;
      break;
    }
   case 188:
    var $791 = HEAP32[$_pre_phi >> 2];
    var $792 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $791, $780);
    if (($792 | 0) == 0) {
      __label__ = 190;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 189:
    var $795 = HEAPU8[$792];
    if (($795 & 255) > 191 | ($795 & -8) << 24 >> 24 != 48) {
      __label__ = 190;
      break;
    } else {
      var $_6 = $780;
      __label__ = 193;
      break;
    }
   case 190:
    var $797 = _js_GetSrcNoteOffset($752, 0);
    if (($797 | 0) == 0) {
      var $_10 = $780;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 191;
      break;
    }
   case 191:
    var $800 = $89 + ($_1 + 2) | 0;
    var $801 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $801;
    if (($801 | 0) < 0) {
      var $_10 = $800;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 192;
      break;
    }
   case 192:
    var $804 = __ZL7PushOffP11SprintStacki4JSOp($ss, $801, 118);
    if (($804 | 0) == 0) {
      var $_10 = $800;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      var $_6 = $800;
      __label__ = 193;
      break;
    }
   case 193:
    var $_6;
    var $806 = HEAP8[$_6];
    if ($806 << 24 >> 24 == 12) {
      __label__ = 194;
      break;
    } else if ($806 << 24 >> 24 == -124) {
      __label__ = 197;
      break;
    } else {
      var $_10 = $_6;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 194:
    var $808 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $_6, $29);
    if (($808 | 0) == 0) {
      var $_10 = 0;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      __label__ = 195;
      break;
    }
   case 195:
    if (HEAP8[$808] << 24 >> 24 == 81) {
      __label__ = 196;
      break;
    } else {
      var $_10 = $808;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 196:
    var $814 = $808 + 1 | 0;
    var $815 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $816 = _js_puts($16, $815);
    var $_7 = $814;
    __label__ = 198;
    break;
   case 197:
    var $830 = ((HEAPU8[$_6 + 1 | 0] & 255) << 8 | HEAPU8[$_6 + 2 | 0] & 255) - (HEAPU16[HEAP32[$_pre_phi >> 2] + 14 >> 1] & 65535) | 0;
    HEAP32[$i >> 2] = $830;
    var $831 = $_6 + 3 | 0;
    var $832 = __ZNK8JSObject12getFixedSlotEj($703, 0);
    var $833 = __ZNK2JS5Value7toInt32Ev($832);
    var $837 = HEAP32[$atomv_0 + ($830 - $833 << 2) >> 2] | 0;
    var $838 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($45, $837, 0);
    if (($838 | 0) == 0) {
      var $_10 = $831;
      var $len_3 = $89;
      var $rval_7 = $rval_5;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    } else {
      var $_7 = $831;
      __label__ = 198;
      break;
    }
   case 198:
    var $_7;
    var $841 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $842 = _strcmp($841, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($842 | 0) == 0) {
      __label__ = 199;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $89;
      var $rval_7 = $841;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 199:
    var $845 = _js_GetSrcNoteOffset($752, 0);
    if (($845 | 0) == 0) {
      var $_8 = $_7;
      var $ok_0 = 1;
      __label__ = 204;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 200:
    var $851 = $845 + ($_1 - $_7) | 0;
    if (($851 | 0) > 0) {
      __label__ = 201;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $851;
      var $rval_7 = $841;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 201:
    var $854 = _js_printf($16, STRING_TABLE.__str652738 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $855 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_7, $851);
    var $856 = ($855 | 0) != 0;
    var $857 = $856 & 1;
    if ($856) {
      __label__ = 202;
      break;
    } else {
      var $_10 = $_7;
      var $len_3 = $851;
      var $rval_7 = $841;
      var $ok_2 = $857;
      __label__ = 206;
      break;
    }
   case 202:
    var $859 = __ZL6PopStrP11SprintStack4JSOp($ss, 201);
    var $860 = _js_printf($16, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $859, tempInt));
    var $861 = $_7 + $851 | 0;
    var $862 = HEAPU8[$861];
    if ($862 << 24 >> 24 == 7 || $862 << 24 >> 24 == -114) {
      __label__ = 203;
      break;
    } else {
      var $_10 = $861;
      var $len_3 = $851;
      var $rval_7 = $841;
      var $ok_2 = 0;
      __label__ = 206;
      break;
    }
   case 203:
    var $_8 = $_7 + ((HEAP8[_js_CodeSpec + (($862 & 255) << 3) | 0] << 24 >> 24) + $851) | 0;
    var $ok_0 = $857;
    __label__ = 204;
    break;
   case 204:
    var $ok_0;
    var $_8;
    var $870 = _js_printf($16, STRING_TABLE.__str312704 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $872 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $872;
    var $_9 = $_8;
    var $len_2 = 0;
    var $rval_6 = $841;
    var $ok_1 = $ok_0;
    __label__ = 205;
    break;
   case 205:
    var $ok_1;
    var $rval_6;
    var $len_2;
    var $_9;
    HEAP32[$todo >> 2] = -2;
    var $_10 = $_9;
    var $len_3 = $len_2;
    var $rval_7 = $rval_6;
    var $ok_2 = $ok_1;
    __label__ = 206;
    break;
   case 206:
    var $ok_2;
    var $rval_7;
    var $len_3;
    var $_10;
    if (($atomv_0 | 0) == ($43 | 0)) {
      __label__ = 208;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 207:
    __ZN9JSContext5free_EPv(undef, $atomv_0);
    __label__ = 208;
    break;
   case 208:
    if (($ok_2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_10;
      var $len_10 = $len_3;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_7;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 209:
    var $880 = HEAP32[$_pre_phi >> 2];
    var $881 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $880, $_1);
    HEAP32[$todo >> 2] = -2;
    var $882 = ($op_2 | 0) == 210;
    if ($882) {
      __label__ = 210;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 210:
    var $884 = HEAPU8[$881];
    if (($884 & 255) < 192 & ($884 & -8) << 24 >> 24 == 96) {
      __label__ = 211;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 211:
    var $887 = __ZL6PopStrP11SprintStack4JSOp($ss, 210);
    var $rval_8 = $887;
    __label__ = 219;
    break;
   case 212:
    if (($881 | 0) == 0) {
      var $rval_8 = $rval_0;
      __label__ = 219;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    if (($op_2 | 0) == 202) {
      __label__ = 214;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 214:
    var $893 = HEAPU8[$881];
    var $894 = ($893 & 255) < 192;
    var $_mask99 = $893 & -8;
    if ($894 & $_mask99 << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 215:
    if ($894 & $_mask99 << 24 >> 24 == -96) {
      __label__ = 216;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 216:
    var $896 = _js_GetSrcNoteOffset($881, 0);
    var $897 = HEAP32[$30 >> 2];
    if (($896 | 0) == ($897 | 0)) {
      var $rval_8 = $rval_0;
      __label__ = 219;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    if (($896 | 0) == ($897 - 1 | 0)) {
      __label__ = 218;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 218:
    var $903 = __ZL6PopStrP11SprintStack4JSOp($ss, 202);
    var $904 = _strcmp($903, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie | 0);
    if (($904 | 0) == 0) {
      var $rval_8 = $903;
      __label__ = 219;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 219:
    var $rval_8;
    var $906 = HEAPU32[$30 >> 2];
    var $914 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    if ($906 >>> 0 < $914 >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 220;
      break;
    }
   case 220:
    var $917 = $906 - $914 | 0;
    HEAP32[$30 >> 2] = $917;
    var $918 = __ZL6GetOffP11SprintStackj($ss, $917);
    HEAP32[$38 >> 2] = $918;
    if ($882) {
      __label__ = 221;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_8;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 221:
    var $920 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $rval_8);
    HEAP32[$todo >> 2] = $920;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_8;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 222:
    var $922 = HEAP32[$46 >> 2];
    if (($922 | 0) == 0) {
      __label__ = 223;
      break;
    } else {
      var $930 = $922;
      __label__ = 224;
      break;
    }
   case 223:
    var $926 = HEAP32[$_pre_phi >> 2];
    var $927 = __ZN8JSScript17getCallerFunctionEv($926);
    var $928 = $927;
    HEAP32[$46 >> 2] = $928;
    var $930 = $928;
    __label__ = 224;
    break;
   case 224:
    var $930;
    if ((HEAP32[$47 >> 2] | 0) == 0) {
      __label__ = 225;
      break;
    } else {
      var $944 = $930;
      __label__ = 228;
      break;
    }
   case 225:
    var $934 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($8, $8);
    HEAP32[$47 >> 2] = $934;
    if (($934 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 226:
    var $937 = HEAP32[$46 >> 2];
    var $938 = __ZNK10JSFunction6scriptEv($937);
    var $940 = $938 + 64 | 0;
    var $941 = $934;
    var $942 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($940, undef, $941);
    if ($942) {
      __label__ = 227;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 227:
    var $944 = HEAP32[$46 >> 2];
    __label__ = 228;
    break;
   case 228:
    var $944;
    var $952 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $953 = __ZNK10JSFunction6scriptEv($944);
    var $954 = $953 + 64 | 0;
    var $955 = __ZNK2js8Bindings11countUpvarsEv($954);
    if ($952 >>> 0 < ($955 & 65535) >>> 0) {
      __label__ = 229;
      break;
    } else {
      __label__ = 230;
      break;
    }
   case 229:
    var $959 = __ZNK2js8Bindings16countArgsAndVarsEv($954);
    var $index_0 = $959 + $952 | 0;
    __label__ = 231;
    break;
   case 230:
    var $962 = HEAP32[$_pre_phi >> 2];
    var $963 = __ZN8JSScript6upvarsEv($962);
    var $966 = HEAP32[$963 >> 2] + ($952 << 2) | 0;
    var $967 = __ZNK2js11UpvarCookie4slotEv($966);
    var $index_0 = $967 & 65535;
    __label__ = 231;
    break;
   case 231:
    var $index_0;
    var $970 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $index_0);
    var $len_6 = $89;
    var $lval_6 = __str93064 | 0;
    var $atom_10 = $970;
    __label__ = 516;
    break;
   case 232:
    var $_1_idx20_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx21_val = HEAP8[$_1 + 2 | 0];
    var $972 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx20_val, $_1_idx21_val, $i);
    var $974 = HEAPU32[$i >> 2];
    if (($972 | 0) == 0) {
      __label__ = 234;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    var $976 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $974);
    if (($976 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str93064 | 0;
      var $atom_10 = $976;
      __label__ = 516;
      break;
    }
   case 234:
    if ($974 >>> 0 < HEAPU32[$30 >> 2] >>> 0) {
      __label__ = 235;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 235:
    var $983 = HEAP32[$_pre_phi >> 2];
    var $984 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $983, $_1);
    if (($984 | 0) == 0) {
      var $sn_2 = 0;
      __label__ = 240;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 236:
    var $987 = HEAPU8[$984];
    if (($987 & 255) < 192 & ($987 & -8) << 24 >> 24 == 56) {
      __label__ = 237;
      break;
    } else {
      var $sn_2 = $984;
      __label__ = 240;
      break;
    }
   case 237:
    if (($48 - $_1 | 0) > 3 | $_1 >>> 0 > $pc >>> 0) {
      __label__ = 238;
      break;
    } else {
      var $sn_2 = 0;
      __label__ = 240;
      break;
    }
   case 238:
    var $995 = __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $_1, $29, $984, $todo);
    if (($995 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 239:
    if (HEAP8[$995] << 24 >> 24 == 11) {
      var $_3 = $995;
      var $oplen_0 = 3;
      __label__ = 117;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 240:
    var $sn_2;
    var $1000 = HEAP32[$i >> 2];
    var $1001 = __Z8GetLocalP11SprintStacki($ss, $1000);
    var $1002 = __ZL9VarPrefixPh($sn_2);
    var $1003 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1002, HEAP32[tempInt + 4 >> 2] = $1001, tempInt));
    HEAP32[$todo >> 2] = $1003;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1001;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 241:
    var $_1_idx18_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx19_val = HEAP8[$_1 + 2 | 0];
    var $1005 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx18_val, $_1_idx19_val, $i);
    var $1007 = HEAP32[$i >> 2];
    if (($1005 | 0) == 0) {
      __label__ = 243;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 242:
    var $1009 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1007);
    if (($1009 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_0 = $1009;
      __label__ = 386;
      break;
    }
   case 243:
    var $1012 = __Z8GetLocalP11SprintStacki($ss, $1007);
    var $1013 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $op_8 = $op_2;
    var $cs_1 = $cs_0;
    var $lval_1 = $1012;
    var $rval_13 = $1013;
    __label__ = 389;
    break;
   case 244:
    var $_1_idx16_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx17_val = HEAP8[$_1 + 2 | 0];
    var $1015 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx16_val, $_1_idx17_val, $i);
    var $1017 = HEAP32[$i >> 2];
    if (($1015 | 0) == 0) {
      __label__ = 246;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $1019 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1017);
    if (($1019 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_3 = $1019;
      __label__ = 442;
      break;
    }
   case 246:
    var $1022 = __Z8GetLocalP11SprintStacki($ss, $1017);
    var $lval_4 = $1022;
    __label__ = 444;
    break;
   case 247:
    var $_1_idx_val = HEAP8[$_1 + 1 | 0];
    var $_1_idx15_val = HEAP8[$_1 + 2 | 0];
    var $1024 = __ZL9IsVarSlotP9JSPrinterPhPi($16, $_1_idx_val, $_1_idx15_val, $i);
    var $1026 = HEAP32[$i >> 2];
    if (($1024 | 0) == 0) {
      __label__ = 249;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $1028 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1026);
    if (($1028 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_5 = $1028;
      __label__ = 461;
      break;
    }
   case 249:
    var $1031 = __Z8GetLocalP11SprintStacki($ss, $1026);
    var $lval_5 = $1031;
    __label__ = 463;
    break;
   case 250:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 251:
    var $1034 = HEAP32[$46 >> 2];
    if (($1034 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 252;
      break;
    }
   case 252:
    var $1037 = $1034 + 58 | 0;
    if ((HEAP16[$1037 >> 1] & 4096) << 16 >> 16 == 0) {
      __label__ = 256;
      break;
    } else {
      __label__ = 253;
      break;
    }
   case 253:
    var $1042 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1045 = HEAP8[$1042] << 24 >> 24 == 123 ? STRING_TABLE.__str662739 | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0;
    if ((HEAP16[$1037 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 254;
      break;
    } else {
      var $1054 = __str93064 | 0;
      __label__ = 255;
      break;
    }
   case 254:
    var $phitmp83 = (HEAP32[$1034 + 72 >> 2] | 0) == 0 ? __str93064 | 0 : STRING_TABLE.__str452718 | 0;
    var $1054 = $phitmp83;
    __label__ = 255;
    break;
   case 255:
    var $1054;
    var $1055 = _js_printf($16, $1045, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1042, HEAP32[tempInt + 4 >> 2] = $1054, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1042;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 256:
    var $1057 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (HEAP8[$1057] << 24 >> 24 == 0) {
      __label__ = 258;
      break;
    } else {
      __label__ = 257;
      break;
    }
   case 257:
    var $1061 = _js_printf($16, STRING_TABLE.__str672740 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_return_str | 0, HEAP32[tempInt + 4 >> 2] = $1057, tempInt));
    __label__ = 259;
    break;
   case 258:
    var $1063 = _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_return_str | 0, tempInt));
    __label__ = 259;
    break;
   case 259:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1057;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 260:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 262;
      break;
    } else {
      __label__ = 261;
      break;
    }
   case 261:
    var $1070 = HEAP32[$_pre_phi >> 2];
    var $1071 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1070, $_1);
    if (($1071 | 0) == 0) {
      __label__ = 262;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 262:
    var $1074 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    if (HEAP8[$1074] << 24 >> 24 == 0) {
      __label__ = 267;
      break;
    } else {
      __label__ = 263;
      break;
    }
   case 263:
    var $1078 = _strncmp($1074, STRING_TABLE._js_yield_str | 0, 5);
    if (($1078 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      var $1087 = STRING_TABLE.__str692742 | 0;
      __label__ = 266;
      break;
    }
   case 264:
    var $1082 = HEAP8[$1074 + 5 | 0];
    if ($1082 << 24 >> 24 == 32) {
      var $1087 = STRING_TABLE.__str682741 | 0;
      __label__ = 266;
      break;
    } else {
      __label__ = 265;
      break;
    }
   case 265:
    var $phitmp80 = $1082 << 24 >> 24 == 0 ? STRING_TABLE.__str682741 | 0 : STRING_TABLE.__str692742 | 0;
    var $1087 = $phitmp80;
    __label__ = 266;
    break;
   case 266:
    var $1087;
    var $1088 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1087, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, HEAP32[tempInt + 4 >> 2] = $1074, tempInt));
    var $1092 = $1088;
    __label__ = 268;
    break;
   case 267:
    var $1090 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE._js_yield_str | 0);
    var $1092 = $1090;
    __label__ = 268;
    break;
   case 268:
    var $1092;
    HEAP32[$todo >> 2] = $1092;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1074;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 269:
    var $1094 = HEAPU8[$1071];
    if (($1094 & 255) < 192 & ($1094 & -8) << 24 >> 24 == 88) {
      __label__ = 270;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 270:
    var $1097 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1098 = HEAPU32[$30 >> 2];
    var $pos_0 = $1098;
    __label__ = 271;
    break;
   case 271:
    var $pos_0;
    if (($pos_0 | 0) == 0) {
      var $pos_1 = 0;
      __label__ = 273;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    var $1102 = $pos_0 - 1 | 0;
    if (HEAP8[HEAP32[$36 >> 2] + $1102 | 0] << 24 >> 24 == -55) {
      var $pos_1 = $1102;
      __label__ = 273;
      break;
    } else {
      var $pos_0 = $1102;
      __label__ = 271;
      break;
    }
   case 273:
    var $pos_1;
    var $1108 = $pos_1 + 1 | 0;
    if ($1108 >>> 0 < $1098 >>> 0) {
      __label__ = 274;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 274:
    var $1110 = HEAPU32[$36 >> 2];
    var $1112 = HEAPU8[$1110 + $pos_1 | 0];
    var $1114 = ($pos_1 | 0) == 0;
    if ($1112 << 24 >> 24 != -55 | $1114) {
      var $pos_2_lcssa = $pos_1;
      var $_lcssa = $1112;
      var $_lcssa248 = $1114;
      __label__ = 276;
      break;
    } else {
      var $pos_2250 = $pos_1;
      __label__ = 275;
      break;
    }
   case 275:
    var $pos_2250;
    var $1115 = $pos_2250 - 1 | 0;
    var $1117 = HEAP8[$1110 + $1115 | 0];
    var $1119 = ($1115 | 0) == 0;
    if ($1117 << 24 >> 24 != -55 | $1119) {
      var $pos_2_lcssa = $1115;
      var $_lcssa = $1117;
      var $_lcssa248 = $1119;
      __label__ = 276;
      break;
    } else {
      var $pos_2250 = $1115;
      __label__ = 275;
      break;
    }
   case 276:
    var $_lcssa248;
    var $_lcssa;
    var $pos_2_lcssa;
    if ((HEAP32[$saveop >> 2] | 0) == 206) {
      __label__ = 277;
      break;
    } else {
      __label__ = 280;
      break;
    }
   case 277:
    if ($_lcssa248) {
      __label__ = 278;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 278:
    var $1128 = HEAP32[$37 >> 2] + HEAP32[HEAP32[$42 >> 2] + ($1108 << 2) >> 2] | 0;
    HEAP32[$38 >> 2] = 3;
    var $1129 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1097, HEAP32[tempInt + 4 >> 2] = $1128, tempInt));
    HEAP32[$todo >> 2] = $1129;
    if (($1129 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 279;
      break;
    }
   case 279:
    var $1132 = HEAP32[$42 >> 2];
    HEAP32[$1132 >> 2] = $1129;
    var $1134 = HEAP32[$30 >> 2] + 1 | 0;
    HEAP32[$30 >> 2] = $1134;
    var $_0 = $_1;
    __label__ = 742;
    break;
   case 280:
    if ($_lcssa << 24 >> 24 == 89) {
      __label__ = 281;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 281:
    var $1138 = HEAP32[$42 >> 2];
    var $1140 = HEAP32[$1138 + ($pos_2_lcssa << 2) >> 2];
    var $1141 = HEAP32[$37 >> 2];
    var $1142 = $1141 + $1140 | 0;
    var $1143 = HEAP8[$1142];
    if ($1143 << 24 >> 24 == 91 || $1143 << 24 >> 24 == 35) {
      __label__ = 282;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 282:
    var $1147 = $1141 + HEAP32[$1138 + ($1108 << 2) >> 2] | 0;
    HEAP32[$38 >> 2] = $1140;
    var $1148 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1142, HEAP32[tempInt + 4 >> 2] = $1097, HEAP32[tempInt + 8 >> 2] = $1147, tempInt));
    HEAP32[$todo >> 2] = $1148;
    if (($1148 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 283;
      break;
    }
   case 283:
    var $1152 = HEAP32[$42 >> 2] + ($pos_2_lcssa << 2) | 0;
    HEAP32[$1152 >> 2] = $1148;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1097;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 284:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 285:
    var $1156 = HEAP32[$_pre_phi >> 2];
    var $1157 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1156, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($1157 | 0) == 0) {
      __label__ = 287;
      break;
    } else {
      __label__ = 286;
      break;
    }
   case 286:
    var $1160 = HEAPU8[$1157];
    if (($1160 & 255) < 192 & ($1160 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 287;
      break;
    }
   case 287:
    var $1162 = __ZL6PopStrP11SprintStack4JSOp($ss, 112);
    var $1163 = _js_printf($16, STRING_TABLE.__str672740 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_throw_str | 0, HEAP32[tempInt + 4 >> 2] = $1162, tempInt));
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1162;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 288:
    var $1169 = (HEAP8[$_1 + 1 | 0] & 6) << 24 >> 24 == 2 & 1;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $1169;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 289:
    var $1172 = HEAP32[$_pre_phi >> 2];
    var $1173 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1172, $_1);
    HEAP32[$todo >> 2] = -2;
    if (($1173 | 0) == 0) {
      __label__ = 291;
      break;
    } else {
      __label__ = 290;
      break;
    }
   case 290:
    var $1176 = HEAPU8[$1173];
    if (($1176 & 255) < 192 & ($1176 & -8) << 24 >> 24 == 88) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 291;
      break;
    }
   case 291:
    var $1178 = __ZL6PopOffP11SprintStack4JSOp($ss, 78);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 292:
    var $1181 = HEAP32[$_pre_phi >> 2];
    var $1182 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1181, $_1);
    if (($1182 | 0) == 0) {
      __label__ = 322;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1185 = HEAPU8[$1182];
    if (($1185 & 255) > 191) {
      __label__ = 322;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $1189 = ($1185 & 255) >>> 3;
    if (($1189 | 0) == 2) {
      __label__ = 295;
      break;
    } else if (($1189 | 0) == 4) {
      __label__ = 311;
      break;
    } else if (($1189 | 0) == 17) {
      __label__ = 315;
      break;
    } else if (($1189 | 0) == 5) {
      __label__ = 318;
      break;
    } else if (($1189 | 0) == 16) {
      __label__ = 319;
      break;
    } else if (($1189 | 0) == 11) {
      var $_11 = $_1;
      var $len_4 = $89;
      var $rval_10 = $rval_0;
      __label__ = 323;
      break;
    } else {
      __label__ = 322;
      break;
    }
   case 295:
    var $_1_val9 = HEAP8[$_1];
    var $1191 = __ZL13GetJumpOffsetPhS_($_1_val9, $_1);
    var $1192 = _js_GetSrcNoteOffset($1182, 0);
    var $1193 = _js_GetSrcNoteOffset($1182, 1);
    var $1194 = $1192 - $89 | 0;
    var $1195 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1194);
    if (($1195 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $1198 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1199 = _strlen($1198);
    HEAP8[$1198 + ($1199 - 9) | 0] = 0;
    var $1202 = HEAPU32[$30 >> 2];
    if (($1202 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 298;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 298:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 307;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    var $1211 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1212 = HEAP32[$30 >> 2];
    if (($1212 | 0) == 0) {
      __label__ = 303;
      break;
    } else {
      __label__ = 300;
      break;
    }
   case 300:
    if (HEAP8[HEAP32[$36 >> 2] + ($1212 - 1) | 0] << 24 >> 24 == -22) {
      __label__ = 301;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 301:
    var $1224 = HEAP32[HEAP32[$42 >> 2] + ($1212 << 2) >> 2] - 3 | 0;
    HEAP32[$38 >> 2] = $1224;
    var $1226 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE._js_for_str | 0;
    var $1227 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str702743 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1226, HEAP32[tempInt + 4 >> 2] = $1198, HEAP32[tempInt + 8 >> 2] = $1211, tempInt));
    if (($1227 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $storemerge74 = HEAP32[HEAP32[$42 >> 2] + (HEAP32[$30 >> 2] - 1 << 2) >> 2];
    __label__ = 304;
    break;
   case 303:
    var $1237 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE._js_for_str | 0;
    var $1238 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str702743 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1237, HEAP32[tempInt + 4 >> 2] = $1198, HEAP32[tempInt + 8 >> 2] = $1211, tempInt));
    var $storemerge74 = $1238;
    __label__ = 304;
    break;
   case 304:
    var $storemerge74;
    HEAP32[$todo >> 2] = $storemerge74;
    if (($storemerge74 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 305;
      break;
    }
   case 305:
    var $1242 = __ZL7PushOffP11SprintStacki4JSOp($ss, $storemerge74, 234);
    if (($1242 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 306;
      break;
    }
   case 306:
    var $1245 = $1192 + ($_1 + 1) | 0;
    var $1247 = $1191 - 1 - $1192 | 0;
    var $1248 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1245, $1247);
    if (($1248 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $rval_9 = $1211;
      __label__ = 309;
      break;
    }
   case 307:
    var $1251 = $1202 - 1 | 0;
    var $1252 = __ZL6GetStrP11SprintStackj($ss, $1251);
    var $1254 = $_1 + $1192 | 0;
    var $1255 = HEAP32[$_pre_phi >> 2];
    var $1256 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1255, $1254);
    var $1257 = __ZL9VarPrefixPh($1256);
    var $1259 = ($foreach_0 | 0) != 0 ? STRING_TABLE.__ZL15js_for_each_str | 0 : STRING_TABLE._js_for_str | 0;
    var $1260 = _js_printf($16, STRING_TABLE.__str712744 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $1259, HEAP32[tempInt + 4 >> 2] = $1257, HEAP32[tempInt + 8 >> 2] = $1198, HEAP32[tempInt + 12 >> 2] = $1252, tempInt));
    var $1262 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1262;
    var $1263 = $1192 + ($_1 + 1) | 0;
    var $1265 = $1191 - 1 - $1192 | 0;
    var $1266 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1263, $1265);
    if (($1266 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 308;
      break;
    }
   case 308:
    var $1270 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1270;
    var $1271 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $rval_9 = $1252;
    __label__ = 309;
    break;
   case 309:
    var $rval_9;
    var $1273 = $_1 + $1193 | 0;
    var $1274 = HEAPU8[$1273];
    if ($1274 << 24 >> 24 == 8 || $1274 << 24 >> 24 == -113) {
      __label__ = 310;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 310:
    var $_11 = $1273;
    var $len_4 = HEAP8[_js_CodeSpec + (($1274 & 255) << 3) | 0] << 24 >> 24;
    var $rval_10 = $rval_9;
    __label__ = 323;
    break;
   case 311:
    var $_1_val8 = HEAP8[$_1];
    var $1281 = __ZL13GetJumpOffsetPhS_($_1_val8, $_1);
    var $1282 = _js_GetSrcNoteOffset($1182, 0);
    var $1283 = $_1 + $1281 | 0;
    var $1284 = $1282 - $1281 | 0;
    var $1285 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1283, $1284);
    if (($1285 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 312;
      break;
    }
   case 312:
    var $1298 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $1299 = __ZL6PopStrP11SprintStack4JSOp($ss, $1298);
    var $1300 = _js_printf($16, STRING_TABLE.__str722745 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1299, tempInt));
    var $1302 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1302;
    var $1303 = $1281 - $89 | 0;
    var $1304 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1303);
    if (($1304 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 313:
    var $1308 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1308;
    var $1309 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1310 = $_1 + $1282 | 0;
    var $1311 = HEAPU8[$1310];
    if ($1311 << 24 >> 24 == 8 || $1311 << 24 >> 24 == -113) {
      __label__ = 314;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 314:
    var $1316 = HEAP8[_js_CodeSpec + (($1311 & 255) << 3) | 0] << 24 >> 24;
    HEAP32[$todo >> 2] = -2;
    var $_11 = $1310;
    var $len_4 = $1316;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 315:
    var $1318 = _js_GetSrcNoteOffset($1182, 0);
    var $1319 = HEAPU32[$_pre_phi >> 2];
    if ($1318 >>> 0 < HEAPU32[$1319 + 40 >> 2] >>> 0) {
      __label__ = 316;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 316:
    var $1328 = HEAP32[HEAP32[$1319 + 56 >> 2] + ($1318 << 2) >> 2] | 0;
    var $1329 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $1328, 0);
    if (($1329 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 317;
      break;
    }
   case 317:
    var $1335 = $1329 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1335;
    var $1336 = _js_printf($16, STRING_TABLE.__str732746 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1329, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $1329;
    __label__ = 323;
    break;
   case 318:
    var $1338 = _js_printf($16, STRING_TABLE.__str742747 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 319:
    var $1340 = _js_GetSrcNoteOffset($1182, 0);
    var $1341 = HEAPU32[$_pre_phi >> 2];
    if ($1340 >>> 0 < HEAPU32[$1341 + 40 >> 2] >>> 0) {
      __label__ = 320;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 320:
    var $1350 = HEAP32[HEAP32[$1341 + 56 >> 2] + ($1340 << 2) >> 2] | 0;
    var $1351 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $1350, 0);
    if (($1351 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 321;
      break;
    }
   case 321:
    var $1357 = $1351 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1357;
    var $1358 = _js_printf($16, STRING_TABLE.__str752748 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1351, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $1351;
    __label__ = 323;
    break;
   case 322:
    var $1359 = _js_printf($16, STRING_TABLE.__str762749 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_11 = $_1;
    var $len_4 = $89;
    var $rval_10 = $rval_0;
    __label__ = 323;
    break;
   case 323:
    var $rval_10;
    var $len_4;
    var $_11;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_11;
    var $len_10 = $len_4;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_10;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 324:
    var $_12_val;
    var $elseif_0;
    var $rval_11;
    var $oplen_1;
    var $_12;
    var $1361 = __ZL13GetJumpOffsetPhS_($_12_val, $_12);
    var $1363 = HEAP32[$_pre_phi >> 2];
    var $1364 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1363, $_12);
    if (($1364 | 0) == 0) {
      var $_16 = $_12;
      var $len_10 = $1361;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 325;
      break;
    }
   case 325:
    var $1367 = HEAPU8[$1364];
    if (($1367 & 255) > 191) {
      var $_16 = $_12;
      var $len_10 = $1361;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 326;
      break;
    }
   case 326:
    var $1371 = ($1367 & 255) >>> 3;
    if (($1371 | 0) == 1 || ($1371 | 0) == 2) {
      __label__ = 327;
      break;
    } else if (($1371 | 0) == 9) {
      __label__ = 347;
      break;
    } else {
      var $_16 = $_12;
      var $len_10 = $1361;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_11;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 327:
    var $1383 = (HEAP32[_js_CodeSpec + ((HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255) << 3) + 4 >> 2] & 256 | 0) != 0 ? 7 : 0;
    var $1384 = __ZL6PopStrP11SprintStack4JSOp($ss, $1383);
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 328;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 328:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 332;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 329:
    var $1391 = HEAPU8[$1364];
    if (($1391 & 255) < 192 & ($1391 & -8) << 24 >> 24 == 8) {
      __label__ = 330;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 330:
    var $1395 = HEAP32[$38 >> 2] - 3 | 0;
    HEAP32[$38 >> 2] = $1395;
    var $1396 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str772750 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1384, tempInt));
    if (($1396 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 331;
      break;
    }
   case 331:
    __ZL12AddParenSlopP11SprintStack($ss);
    __label__ = 333;
    break;
   case 332:
    var $_str782751__str792752 = ($elseif_0 | 0) != 0 ? STRING_TABLE.__str782751 : STRING_TABLE.__str792752;
    var $1401 = $_str782751__str792752 | 0;
    var $1402 = _js_printf($16, $1401, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1384, tempInt));
    var $1404 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1404;
    __label__ = 333;
    break;
   case 333:
    var $1406 = HEAPU8[$1364];
    if (($1406 & 255) < 192 & ($1406 & -8) << 24 >> 24 == 8) {
      __label__ = 334;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 334:
    var $1410 = $1361 - $oplen_1 | 0;
    var $1411 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1410);
    if (($1411 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_13 = $_12;
      var $len_5 = $1361;
      __label__ = 343;
      break;
    }
   case 335:
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 336;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 336:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 337;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 337:
    var $1419 = _js_GetSrcNoteOffset($1364, 0);
    var $1421 = $1419 - $oplen_1 | 0;
    var $1422 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1421);
    if (($1422 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 338;
      break;
    }
   case 338:
    var $1426 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1426;
    var $1427 = $_12 + $1419 | 0;
    var $1428 = HEAPU8[$1427];
    if ($1428 << 24 >> 24 == 6 || $1428 << 24 >> 24 == -115) {
      __label__ = 339;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 339:
    var $1433 = HEAP8[_js_CodeSpec + (($1428 & 255) << 3) | 0] << 24 >> 24;
    var $1434 = __ZL13GetJumpOffsetPhS_($1428, $1427);
    var $1435 = _js_printf($16, STRING_TABLE.__str802753 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1436 = _js_GetSrcNoteOffset($1364, 1);
    if (($1436 | 0) == 0) {
      __label__ = 342;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    var $_sum69 = $1433 + $1419 | 0;
    var $1439 = $_12 + $_sum69 | 0;
    var $1440 = $1436 - $_sum69 | 0;
    var $1441 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1439, $1440);
    if (($1441 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 341;
      break;
    }
   case 341:
    var $1444 = $_12 + $1436 | 0;
    var $1445 = HEAPU8[$1444];
    var $1449 = HEAP8[_js_CodeSpec + (($1445 & 255) << 3) | 0] << 24 >> 24;
    var $_12 = $1444;
    var $oplen_1 = $1449;
    var $rval_11 = $1384;
    var $elseif_0 = 1;
    var $_12_val = $1445;
    __label__ = 324;
    break;
   case 342:
    var $1451 = _js_printf($16, STRING_TABLE.__str812754 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $1453 = HEAP32[$35 >> 2] + 4 | 0;
    HEAP32[$35 >> 2] = $1453;
    var $1454 = $_12 + ($1433 + $1419) | 0;
    var $1455 = $1434 - $1433 | 0;
    var $1456 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1454, $1455);
    if (($1456 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_13 = $1427;
      var $len_5 = $1434;
      __label__ = 343;
      break;
    }
   case 343:
    var $len_5;
    var $_13;
    if ((HEAP32[$50 >> 2] | 0) == 0) {
      __label__ = 344;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 344:
    if ((HEAP32[$49 >> 2] | 0) == 0) {
      __label__ = 345;
      break;
    } else {
      __label__ = 346;
      break;
    }
   case 345:
    var $1466 = HEAP32[$35 >> 2] - 4 | 0;
    HEAP32[$35 >> 2] = $1466;
    var $1467 = _js_printf($16, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 346;
    break;
   case 346:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_13;
    var $len_10 = $len_5;
    var $cs_3 = $cs_0;
    var $rval_18 = $1384;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 347:
    var $1470 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1471 = _JS_strdup($8, $1470);
    if (($1471 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 348;
      break;
    }
   case 348:
    var $1474 = _js_GetSrcNoteOffset($1364, 0);
    var $1476 = $1474 - $oplen_1 | 0;
    var $1477 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_12 + $oplen_1 | 0, $1476);
    if (($1477 | 0) == 0) {
      __label__ = 353;
      break;
    } else {
      __label__ = 349;
      break;
    }
   case 349:
    var $1480 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1481 = _JS_strdup($8, $1480);
    if (($1481 | 0) == 0) {
      __label__ = 353;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    var $1484 = $_12 + $1474 | 0;
    var $1485 = HEAPU8[$1484];
    if ($1485 << 24 >> 24 == 6 || $1485 << 24 >> 24 == -115) {
      __label__ = 351;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 351:
    var $1490 = HEAP8[_js_CodeSpec + (($1485 & 255) << 3) | 0] << 24 >> 24;
    var $1491 = __ZL13GetJumpOffsetPhS_($1485, $1484);
    var $1492 = $_12 + ($1490 + $1474) | 0;
    var $1493 = $1491 - $1490 | 0;
    var $1494 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $1492, $1493);
    if (($1494 | 0) == 0) {
      __label__ = 354;
      break;
    } else {
      __label__ = 352;
      break;
    }
   case 352:
    var $1497 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1498 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str822755 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1471, HEAP32[tempInt + 4 >> 2] = $1481, HEAP32[tempInt + 8 >> 2] = $1497, tempInt));
    HEAP32[$todo >> 2] = $1498;
    __ZN9JSContext5free_EPv(undef, $1471);
    __ZN9JSContext5free_EPv(undef, $1481);
    var $_16 = $1484;
    var $len_10 = $1491;
    var $cs_3 = $cs_0;
    var $rval_18 = $1497;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 353:
    __ZN9JSContext5free_EPv(undef, $1471);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 354:
    __ZN9JSContext5free_EPv(undef, $1471);
    __ZN9JSContext5free_EPv(undef, $1481);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 355:
    var $xval_0;
    var $1501 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $1502 = _JS_strdup($8, $1501);
    if (($1502 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 356;
      break;
    }
   case 356:
    var $_1_val5 = HEAP8[$_1];
    var $1505 = __ZL13GetJumpOffsetPhS_($_1_val5, $_1);
    var $1509 = $_1 + $1505 - $108 | 0;
    var $1510 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $108, $1509);
    if (($1510 | 0) == 0) {
      __label__ = 357;
      break;
    } else {
      __label__ = 358;
      break;
    }
   case 357:
    __ZN9JSContext5free_EPv(undef, $1502);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 358:
    var $1514 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if ((HEAP8[$39] & 1) << 24 >> 24 == 0) {
      __label__ = 363;
      break;
    } else {
      __label__ = 359;
      break;
    }
   case 359:
    var $1519 = HEAP32[$35 >> 2];
    var $1520 = _strlen($1502);
    var $1521 = _strlen($1514);
    if (($1521 + ($1520 + ($1519 + 8)) | 0) >>> 0 > 75) {
      __label__ = 360;
      break;
    } else {
      __label__ = 363;
      break;
    }
   case 360:
    var $1527 = _JS_strdup($8, $1514);
    if (($1527 | 0) == 0) {
      __label__ = 362;
      break;
    } else {
      __label__ = 361;
      break;
    }
   case 361:
    var $1530 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str842757 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1502, HEAP32[tempInt + 4 >> 2] = $xval_0, tempInt));
    HEAP32[$todo >> 2] = $1530;
    var $1532 = HEAP32[$35 >> 2] + 4 | 0;
    var $1533 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str852758 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1532, HEAP32[tempInt + 4 >> 2] = __str93064 | 0, HEAP32[tempInt + 8 >> 2] = $1527, tempInt));
    __ZN9JSContext5free_EPv(undef, $1527);
    if (($1533 | 0) < 0) {
      __label__ = 362;
      break;
    } else {
      var $rval_12 = $1527;
      __label__ = 364;
      break;
    }
   case 362:
    HEAP32[$todo >> 2] = -1;
    var $rval_12 = $1527;
    __label__ = 364;
    break;
   case 363:
    var $1535 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str402713 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1502, HEAP32[tempInt + 4 >> 2] = $xval_0, HEAP32[tempInt + 8 >> 2] = $1514, tempInt));
    HEAP32[$todo >> 2] = $1535;
    var $rval_12 = $1514;
    __label__ = 364;
    break;
   case 364:
    var $rval_12;
    __ZN9JSContext5free_EPv(undef, $1502);
    var $_16 = $108;
    var $len_10 = $1509;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_12;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 365:
    var $xval_0 = STRING_TABLE.__str2073359 | 0;
    __label__ = 355;
    break;
   case 366:
    var $1539 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1540 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    var $1541 = HEAP32[$saveop >> 2];
    var $1542 = __ZL6PopStrP11SprintStack4JSOp($ss, $1541);
    var $1543 = _strcmp($1542, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie | 0);
    if (($1543 | 0) == 0) {
      __label__ = 367;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 367:
    if (HEAP8[$1539] << 24 >> 24 == 0) {
      __label__ = 368;
      break;
    } else {
      __label__ = 369;
      break;
    }
   case 368:
    var $1549 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1540);
    HEAP32[$todo >> 2] = $1549;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1542;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 369:
    var $1553 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $1554 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1553, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1540, HEAP32[tempInt + 4 >> 2] = $1539, tempInt));
    HEAP32[$todo >> 2] = $1554;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1542;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 370:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 371:
    var $1558 = HEAP32[$30 >> 2] - 2 | 0;
    var $1559 = __ZL6GetStrP11SprintStackj($ss, $1558);
    var $1560 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1559);
    HEAP32[$todo >> 2] = $1560;
    if (($1560 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 372;
      break;
    }
   case 372:
    var $1568 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 2) | 0] & 255;
    var $1569 = __ZL7PushOffP11SprintStacki4JSOp($ss, $1560, $1568);
    if (($1569 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 373:
    var $1573 = HEAP32[$_pre_phi >> 2];
    var $1574 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1573, $_1);
    if (($1574 | 0) == 0) {
      __label__ = 380;
      break;
    } else {
      __label__ = 374;
      break;
    }
   case 374:
    var $1577 = HEAPU8[$1574];
    if (($1577 & 255) < 192 & ($1577 & -8) << 24 >> 24 == 48) {
      __label__ = 375;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 375:
    var $1580 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $_1, $29);
    if (($1580 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 376;
      break;
    }
   case 376:
    var $1583 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    HEAP32[$saveop >> 2] = 124;
    var $1584 = __ZL6PopStrP11SprintStack4JSOp($ss, 124);
    var $1585 = _strcmp($1584, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie | 0);
    var $1586 = ($1585 | 0) == 0;
    var $1587 = __ZL9VarPrefixPh($1574);
    if ($1586) {
      __label__ = 377;
      break;
    } else {
      __label__ = 379;
      break;
    }
   case 377:
    var $1589 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1587, HEAP32[tempInt + 4 >> 2] = $1583, tempInt));
    HEAP32[$todo >> 2] = $1589;
    if (HEAP8[$1580] << 24 >> 24 == 81) {
      __label__ = 378;
      break;
    } else {
      var $_16 = $1580;
      var $len_10 = 0;
      var $cs_3 = $cs_0;
      var $rval_18 = $1584;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 378:
    var $_16 = $1580;
    var $len_10 = 1;
    var $cs_3 = $cs_0;
    var $rval_18 = $1584;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 379:
    var $1594 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str872760 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1587, HEAP32[tempInt + 4 >> 2] = $1583, HEAP32[tempInt + 8 >> 2] = $1584, tempInt));
    HEAP32[$todo >> 2] = $1594;
    var $_16 = $1580;
    var $len_10 = 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $1584;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 380:
    var $1597 = HEAP32[$30 >> 2] - 1 | 0;
    var $1598 = __ZL6GetStrP11SprintStackj($ss, $1597);
    var $1604 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0] & 255;
    HEAP32[$saveop >> 2] = $1604;
    var $1605 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $1598);
    HEAP32[$todo >> 2] = $1605;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1598;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 381:
    var $1614 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1615 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1614);
    if (($1615 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_0 = $1615;
      __label__ = 386;
      break;
    }
   case 382:
    var $1618 = HEAP32[$_pre_phi >> 2];
    var $1619 = _js_GetIndexFromBytecode($8, $1618, $_1, 0);
    var $1620 = HEAPU32[$_pre_phi >> 2];
    var $1622 = HEAPU32[$1620 >> 2];
    if ($_1 >>> 0 < $1622 >>> 0) {
      __label__ = 384;
      break;
    } else {
      __label__ = 383;
      break;
    }
   case 383:
    if (($1622 + HEAP32[$1620 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 385;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $1631 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1632 = __ZN11JSAtomState16commonAtomsStartEv($1631);
    var $atom_0 = HEAP32[$1632 + ($1619 << 2) >> 2];
    __label__ = 386;
    break;
   case 385:
    var $1636 = __ZN8JSScript7getAtomEj($1620, $1619);
    var $atom_0 = $1636;
    __label__ = 386;
    break;
   case 386:
    var $atom_0;
    var $1639 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_0 | 0, 0);
    if (($1639 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 387;
      break;
    }
   case 387:
    var $1642 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (($op_2 | 0) == 157 || ($op_2 | 0) == 111) {
      __label__ = 388;
      break;
    } else {
      var $op_8 = $op_2;
      var $cs_1 = $cs_0;
      var $lval_1 = $1639;
      var $rval_13 = $1642;
      __label__ = 389;
      break;
    }
   case 388:
    var $1644 = __ZL6PopOffP11SprintStack4JSOp($ss, $op_2);
    var $op_8 = $op_2;
    var $cs_1 = $cs_0;
    var $lval_1 = $1639;
    var $rval_13 = $1642;
    __label__ = 389;
    break;
   case 389:
    var $rval_13;
    var $lval_1;
    var $cs_1;
    var $op_8;
    var $1648 = HEAP32[$_pre_phi >> 2];
    var $1649 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1648, $_1 - 1 | 0);
    if (($1649 | 0) == 0) {
      __label__ = 395;
      break;
    } else {
      __label__ = 390;
      break;
    }
   case 390:
    var $1652 = HEAPU8[$1649];
    if (($1652 & 255) < 192 & ($1652 & -8) << 24 >> 24 == 64) {
      __label__ = 391;
      break;
    } else {
      __label__ = 395;
      break;
    }
   case 391:
    if (($67 | 0) == 125) {
      var $1662 = STRING_TABLE._js_getter_str | 0;
      __label__ = 394;
      break;
    } else {
      __label__ = 392;
      break;
    }
   case 392:
    if (($67 | 0) == 126) {
      var $1662 = STRING_TABLE._js_setter_str | 0;
      __label__ = 394;
      break;
    } else {
      __label__ = 393;
      break;
    }
   case 393:
    var $1662 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 394;
    break;
   case 394:
    var $1662;
    var $1663 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str882761 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $lval_1, HEAP32[tempInt + 4 >> 2] = $1662, HEAP32[tempInt + 8 >> 2] = $rval_13, tempInt));
    var $storemerge = $1663;
    __label__ = 396;
    break;
   case 395:
    var $1665 = HEAP32[$_pre_phi >> 2];
    var $1666 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $1665, $_1);
    var $1667 = __ZL9VarPrefixPh($1666);
    var $1668 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str872760 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1667, HEAP32[tempInt + 4 >> 2] = $lval_1, HEAP32[tempInt + 8 >> 2] = $rval_13, tempInt));
    var $storemerge = $1668;
    __label__ = 396;
    break;
   case 396:
    var $storemerge;
    HEAP32[$todo >> 2] = $storemerge;
    if (($op_8 | 0) == 132) {
      __label__ = 397;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_1;
      var $rval_18 = $rval_13;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 397:
    var $1672 = HEAP32[$saveop >> 2];
    var $1673 = __ZL7PushOffP11SprintStacki4JSOp($ss, $storemerge, $1672);
    if (($1673 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 398;
      break;
    }
   case 398:
    var $1676 = __ZL6PopStrP11SprintStack4JSOp($ss, 132);
    if (HEAP8[$1676] << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 399;
      break;
    }
   case 399:
    var $1680 = _js_printf($16, STRING_TABLE.__str582731 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $1676, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_1;
    var $rval_18 = $1676;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 400:
    var $1689 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1691 = ($1689 << 2) + 4 | 0;
    var $1692 = __ZN9JSContext7malloc_Ej($8, $1691);
    var $1693 = $1692;
    if (($1692 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 401;
      break;
    }
   case 401:
    HEAP32[$i >> 2] = $1689;
    var $1695 = ($1689 | 0) == 0;
    if ($1695) {
      __label__ = 403;
      break;
    } else {
      __label__ = 402;
      break;
    }
   case 402:
    var $1696 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $1697 = _JS_strdup($8, $1696);
    var $1699 = $1693 + (HEAP32[$i >> 2] << 2) | 0;
    HEAP32[$1699 >> 2] = $1697;
    var $1701 = HEAP32[$i >> 2] - 1 | 0;
    HEAP32[$i >> 2] = $1701;
    if (($1701 | 0) > 0) {
      __label__ = 402;
      break;
    } else {
      __label__ = 403;
      break;
    }
   case 403:
    if (HEAPU32[$30 >> 2] >>> 0 > 1) {
      __label__ = 404;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 404:
    var $1706 = __ZL6PopOffP11SprintStack4JSOp($ss, 111);
    var $1711 = HEAPU8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    var $1712 = $1711 & 255;
    var $1713 = HEAPU32[$saveop >> 2];
    if (($1713 | 0) == 82) {
      __label__ = 405;
      break;
    } else {
      __label__ = 407;
      break;
    }
   case 405:
    if ($1711 << 24 >> 24 == 123 || $1711 << 24 >> 24 == 108 || $1711 << 24 >> 24 == 79 || $1711 << 24 >> 24 == 58) {
      var $1723 = 59;
      __label__ = 408;
      break;
    } else {
      __label__ = 406;
      break;
    }
   case 406:
    if ((HEAP32[_js_CodeSpec + ($1712 << 3) + 4 >> 2] & 524288 | 0) == 0) {
      __label__ = 407;
      break;
    } else {
      var $1723 = 59;
      __label__ = 408;
      break;
    }
   case 407:
    var $1723 = $1713;
    __label__ = 408;
    break;
   case 408:
    var $1723;
    var $1724 = __ZL6PopStrP11SprintStack4JSOp($ss, $1723);
    var $1725 = HEAP32[$saveop >> 2];
    var $1726 = _JS_strdup($8, $1724);
    HEAP32[$1693 >> 2] = $1726;
    var $ok_3 = ($1726 | 0) != 0 & 1;
    if (($1725 | 0) == 82) {
      __label__ = 409;
      break;
    } else {
      __label__ = 410;
      break;
    }
   case 409:
    var $rval_14 = $1695 ? __str93064 | 0 : STRING_TABLE.__str362709 | 0;
    var $lval_2 = $1695 ? __str93064 | 0 : STRING_TABLE.__str292702 | 0;
    var $1729 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str892762 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_new_str | 0, HEAP32[tempInt + 4 >> 2] = $1726, HEAP32[tempInt + 8 >> 2] = $lval_2, tempInt));
    var $rval_15 = $rval_14;
    var $storemerge59 = $1729;
    __label__ = 411;
    break;
   case 410:
    var $1731 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1726, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str292702 | 0, tempInt));
    var $rval_15 = STRING_TABLE.__str362709 | 0;
    var $storemerge59 = $1731;
    __label__ = 411;
    break;
   case 411:
    var $storemerge59;
    var $rval_15;
    HEAP32[$todo >> 2] = $storemerge59;
    var $ok_4 = ($storemerge59 | 0) < 0 ? 0 : $ok_3;
    var $storemerge60 = 1;
    __label__ = 412;
    break;
   case 412:
    var $storemerge60;
    HEAP32[$i >> 2] = $storemerge60;
    if (($storemerge60 | 0) > ($1689 | 0)) {
      var $ok_5 = $ok_4;
      __label__ = 416;
      break;
    } else {
      __label__ = 413;
      break;
    }
   case 413:
    var $1738 = HEAP32[$1693 + ($storemerge60 << 2) >> 2];
    if (($1738 | 0) == 0) {
      var $ok_5 = 0;
      __label__ = 416;
      break;
    } else {
      __label__ = 414;
      break;
    }
   case 414:
    var $1742 = ($storemerge60 | 0) < ($1689 | 0) ? STRING_TABLE.__str332706 | 0 : __str93064 | 0;
    var $1743 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1738, HEAP32[tempInt + 4 >> 2] = $1742, tempInt));
    if (($1743 | 0) < 0) {
      var $ok_5 = 0;
      __label__ = 416;
      break;
    } else {
      __label__ = 415;
      break;
    }
   case 415:
    var $storemerge60 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 412;
    break;
   case 416:
    var $ok_5;
    var $1749 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $rval_15, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$i >> 2] = 0;
    var $storemerge61246 = 0;
    __label__ = 417;
    break;
   case 417:
    var $storemerge61246;
    var $1752 = HEAP32[$1693 + ($storemerge61246 << 2) >> 2];
    __ZN9JSContext5free_EPv(undef, $1752);
    var $1754 = HEAP32[$i >> 2] + 1 | 0;
    HEAP32[$i >> 2] = $1754;
    if (($1754 | 0) > ($1689 | 0)) {
      __label__ = 418;
      break;
    } else {
      var $storemerge61246 = $1754;
      __label__ = 417;
      break;
    }
   case 418:
    var $1757 = ($1749 | 0) < 0;
    __ZN9JSContext5free_EPv(undef, $1692);
    if ($1757 | ($ok_5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_15;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 419:
    var $1761 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str93064 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $1761;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 420:
    var $1763 = HEAP32[$_pre_phi >> 2];
    var $1764 = _js_GetIndexFromBytecode($8, $1763, $_1, 0);
    var $1765 = HEAPU32[$_pre_phi >> 2];
    var $1767 = HEAPU32[$1765 >> 2];
    if ($_1 >>> 0 < $1767 >>> 0) {
      __label__ = 422;
      break;
    } else {
      __label__ = 421;
      break;
    }
   case 421:
    if (($1767 + HEAP32[$1765 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 423;
      break;
    } else {
      __label__ = 422;
      break;
    }
   case 422:
    var $1776 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1777 = __ZN11JSAtomState16commonAtomsStartEv($1776);
    var $atom_1 = HEAP32[$1777 + ($1764 << 2) >> 2];
    __label__ = 424;
    break;
   case 423:
    var $1781 = __ZN8JSScript7getAtomEj($1765, $1764);
    var $atom_1 = $1781;
    __label__ = 424;
    break;
   case 424:
    var $atom_1;
    var $1784 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_1 | 0, 0);
    if (($1784 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 425;
      break;
    }
   case 425:
    var $1790 = $1784 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1790;
    var $lval_3 = $1784;
    __label__ = 426;
    break;
   case 426:
    var $lval_3;
    var $1792 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_delete_str | 0, HEAP32[tempInt + 4 >> 2] = $lval_3, tempInt));
    HEAP32[$todo >> 2] = $1792;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 427:
    var $1794 = HEAP32[$_pre_phi >> 2];
    var $1795 = _js_GetIndexFromBytecode($8, $1794, $_1, 0);
    var $1796 = HEAPU32[$_pre_phi >> 2];
    var $1798 = HEAPU32[$1796 >> 2];
    if ($_1 >>> 0 < $1798 >>> 0) {
      __label__ = 429;
      break;
    } else {
      __label__ = 428;
      break;
    }
   case 428:
    if (($1798 + HEAP32[$1796 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 430;
      break;
    } else {
      __label__ = 429;
      break;
    }
   case 429:
    var $1807 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1808 = __ZN11JSAtomState16commonAtomsStartEv($1807);
    var $atom_2 = HEAP32[$1808 + ($1795 << 2) >> 2];
    __label__ = 431;
    break;
   case 430:
    var $1812 = __ZN8JSScript7getAtomEj($1796, $1795);
    var $atom_2 = $1812;
    __label__ = 431;
    break;
   case 431:
    var $atom_2;
    var $1815 = __Z15js_IsIdentifierP14JSLinearString($atom_2 | 0);
    var $1816 = ($1815 | 0) == 0;
    var $_150 = $1816 ? 39 : 0;
    var $1818 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_2 | 0, $_150);
    if (($1818 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 432;
      break;
    }
   case 432:
    var $_151 = $1816 ? STRING_TABLE.__str902763 | 0 : STRING_TABLE.__str912764 | 0;
    var $1821 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1822 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_151, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_delete_str | 0, HEAP32[tempInt + 4 >> 2] = $1821, HEAP32[tempInt + 8 >> 2] = $1818, tempInt));
    HEAP32[$todo >> 2] = $1822;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1818;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 433:
    var $1824 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1825 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    if (HEAP8[$1824] << 24 >> 24 == 0) {
      var $lval_3 = $1825;
      __label__ = 426;
      break;
    } else {
      __label__ = 434;
      break;
    }
   case 434:
    var $1831 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str912764 | 0 : STRING_TABLE.__str902763 | 0;
    var $1832 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1831, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_delete_str | 0, HEAP32[tempInt + 4 >> 2] = $1825, HEAP32[tempInt + 8 >> 2] = $1824, tempInt));
    HEAP32[$todo >> 2] = $1832;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 435:
    var $1834 = __ZL6PopStrP11SprintStack4JSOp($ss, 186);
    var $1835 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1836 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str922765 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_delete_str | 0, HEAP32[tempInt + 4 >> 2] = $1835, HEAP32[tempInt + 8 >> 2] = $1834, tempInt));
    HEAP32[$todo >> 2] = $1836;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 436:
    var $1838 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $_ = ($op_2 | 0) == 40 ? STRING_TABLE._js_void_str : STRING_TABLE._js_typeof_str;
    var $1840 = $_ | 0;
    var $1841 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1840, HEAP32[tempInt + 4 >> 2] = $1838, tempInt));
    HEAP32[$todo >> 2] = $1841;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $1838;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 437:
    var $1850 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1851 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1850);
    if (($1851 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_3 = $1851;
      __label__ = 442;
      break;
    }
   case 438:
    var $1854 = HEAP32[$_pre_phi >> 2];
    var $1855 = _js_GetIndexFromBytecode($8, $1854, $_1, 0);
    var $1856 = HEAPU32[$_pre_phi >> 2];
    var $1858 = HEAPU32[$1856 >> 2];
    if ($_1 >>> 0 < $1858 >>> 0) {
      __label__ = 440;
      break;
    } else {
      __label__ = 439;
      break;
    }
   case 439:
    if (($1858 + HEAP32[$1856 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 441;
      break;
    } else {
      __label__ = 440;
      break;
    }
   case 440:
    var $1867 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1868 = __ZN11JSAtomState16commonAtomsStartEv($1867);
    var $atom_3 = HEAP32[$1868 + ($1855 << 2) >> 2];
    __label__ = 442;
    break;
   case 441:
    var $1872 = __ZN8JSScript7getAtomEj($1856, $1855);
    var $atom_3 = $1872;
    __label__ = 442;
    break;
   case 442:
    var $atom_3;
    var $1875 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_3 | 0, 0);
    if (($1875 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 443;
      break;
    }
   case 443:
    var $1881 = $1875 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $1881;
    var $lval_4 = $1875;
    __label__ = 444;
    break;
   case 444:
    var $lval_4;
    var $1887 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1888 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1887, HEAP32[tempInt + 4 >> 2] = $lval_4, tempInt));
    HEAP32[$todo >> 2] = $1888;
    var $1890 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($1890 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 445;
      break;
    }
   case 445:
    var $1898 = HEAP8[_js_CodeSpec + ($1890 << 3) | 0] << 24 >> 24;
    var $1899 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $1898);
    var $_16 = $_1;
    var $len_10 = $1899 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 446:
    var $1902 = HEAP32[$_pre_phi >> 2];
    var $1903 = _js_GetIndexFromBytecode($8, $1902, $_1, 0);
    var $1904 = HEAPU32[$_pre_phi >> 2];
    var $1906 = HEAPU32[$1904 >> 2];
    if ($_1 >>> 0 < $1906 >>> 0) {
      __label__ = 448;
      break;
    } else {
      __label__ = 447;
      break;
    }
   case 447:
    if (($1906 + HEAP32[$1904 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 449;
      break;
    } else {
      __label__ = 448;
      break;
    }
   case 448:
    var $1915 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1916 = __ZN11JSAtomState16commonAtomsStartEv($1915);
    var $atom_4 = HEAP32[$1916 + ($1903 << 2) >> 2];
    __label__ = 450;
    break;
   case 449:
    var $1920 = __ZN8JSScript7getAtomEj($1904, $1903);
    var $atom_4 = $1920;
    __label__ = 450;
    break;
   case 450:
    var $atom_4;
    var $1923 = __Z15js_IsIdentifierP14JSLinearString($atom_4 | 0);
    var $1924 = ($1923 | 0) == 0;
    var $_152 = $1924 ? 39 : 0;
    var $1926 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_4 | 0, $_152);
    if (($1926 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 451;
      break;
    }
   case 451:
    var $_153 = $1924 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format | 0;
    var $1929 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $1934 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1935 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_153, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1934, HEAP32[tempInt + 4 >> 2] = $1929, HEAP32[tempInt + 8 >> 2] = $1926, tempInt));
    HEAP32[$todo >> 2] = $1935;
    var $1936 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 4);
    var $_16 = $_1;
    var $len_10 = $1936 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $1926;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 452:
    var $1939 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $1940 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$1939] << 24 >> 24 == 0) {
      __label__ = 454;
      break;
    } else {
      __label__ = 453;
      break;
    }
   case 453:
    var $1946 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format | 0;
    var $1951 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1952 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $1946, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $1951, HEAP32[tempInt + 4 >> 2] = $1940, HEAP32[tempInt + 8 >> 2] = $1939, tempInt));
    var $storemerge54 = $1952;
    __label__ = 455;
    break;
   case 454:
    var $1958 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $1959 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $1958, HEAP32[tempInt + 4 >> 2] = $1940, tempInt));
    var $storemerge54 = $1959;
    __label__ = 455;
    break;
   case 455:
    var $storemerge54;
    HEAP32[$todo >> 2] = $storemerge54;
    var $1961 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 2);
    var $_16 = $_1;
    var $len_10 = $1961 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 456:
    var $1971 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    var $1972 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $1971);
    if (($1972 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $atom_5 = $1972;
      __label__ = 461;
      break;
    }
   case 457:
    var $1975 = HEAP32[$_pre_phi >> 2];
    var $1976 = _js_GetIndexFromBytecode($8, $1975, $_1, 0);
    var $1977 = HEAPU32[$_pre_phi >> 2];
    var $1979 = HEAPU32[$1977 >> 2];
    if ($_1 >>> 0 < $1979 >>> 0) {
      __label__ = 459;
      break;
    } else {
      __label__ = 458;
      break;
    }
   case 458:
    if (($1979 + HEAP32[$1977 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 460;
      break;
    } else {
      __label__ = 459;
      break;
    }
   case 459:
    var $1988 = HEAP32[$51 >> 2] + 209948 | 0;
    var $1989 = __ZN11JSAtomState16commonAtomsStartEv($1988);
    var $atom_5 = HEAP32[$1989 + ($1976 << 2) >> 2];
    __label__ = 461;
    break;
   case 460:
    var $1993 = __ZN8JSScript7getAtomEj($1977, $1976);
    var $atom_5 = $1993;
    __label__ = 461;
    break;
   case 461:
    var $atom_5;
    var $1996 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_5 | 0, 0);
    if (($1996 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 462;
      break;
    }
   case 462:
    var $2002 = $1996 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $2002;
    var $lval_5 = $1996;
    __label__ = 463;
    break;
   case 463:
    var $lval_5;
    var $2008 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2009 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $lval_5, HEAP32[tempInt + 4 >> 2] = $2008, tempInt));
    HEAP32[$todo >> 2] = $2009;
    var $2011 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($2011 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    } else {
      __label__ = 464;
      break;
    }
   case 464:
    var $2019 = HEAP8[_js_CodeSpec + ($2011 << 3) | 0] << 24 >> 24;
    var $2020 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $2019);
    var $_16 = $_1;
    var $len_10 = $2020 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 465:
    var $2023 = HEAP32[$_pre_phi >> 2];
    var $2024 = _js_GetIndexFromBytecode($8, $2023, $_1, 0);
    var $2025 = HEAPU32[$_pre_phi >> 2];
    var $2027 = HEAPU32[$2025 >> 2];
    if ($_1 >>> 0 < $2027 >>> 0) {
      __label__ = 467;
      break;
    } else {
      __label__ = 466;
      break;
    }
   case 466:
    if (($2027 + HEAP32[$2025 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 468;
      break;
    } else {
      __label__ = 467;
      break;
    }
   case 467:
    var $2036 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2037 = __ZN11JSAtomState16commonAtomsStartEv($2036);
    var $atom_6 = HEAP32[$2037 + ($2024 << 2) >> 2];
    __label__ = 469;
    break;
   case 468:
    var $2041 = __ZN8JSScript7getAtomEj($2025, $2024);
    var $atom_6 = $2041;
    __label__ = 469;
    break;
   case 469:
    var $atom_6;
    var $2044 = __Z15js_IsIdentifierP14JSLinearString($atom_6 | 0);
    var $2045 = ($2044 | 0) == 0;
    var $_154 = $2045 ? 39 : 0;
    var $2047 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_6 | 0, $_154);
    if (($2047 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 470;
      break;
    }
   case 470:
    var $_155 = $2045 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format | 0;
    var $2050 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $2055 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2056 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_155, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2050, HEAP32[tempInt + 4 >> 2] = $2047, HEAP32[tempInt + 8 >> 2] = $2055, tempInt));
    HEAP32[$todo >> 2] = $2056;
    var $2057 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 4);
    var $_16 = $_1;
    var $len_10 = $2057 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $2047;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 471:
    var $2060 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2061 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$2060] << 24 >> 24 == 0) {
      __label__ = 473;
      break;
    } else {
      __label__ = 472;
      break;
    }
   case 472:
    var $2067 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format | 0 : STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format | 0;
    var $2072 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2073 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2067, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2061, HEAP32[tempInt + 4 >> 2] = $2060, HEAP32[tempInt + 8 >> 2] = $2072, tempInt));
    var $storemerge49 = $2073;
    __label__ = 474;
    break;
   case 473:
    var $2079 = STRING_TABLE.__ZL13js_incop_strs + (HEAPU32[$cs_0 + 4 >> 2] >>> 11 & 1 ^ 1) * 3 | 0;
    var $2080 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2061, HEAP32[tempInt + 4 >> 2] = $2079, tempInt));
    var $storemerge49 = $2080;
    __label__ = 474;
    break;
   case 474:
    var $storemerge49;
    HEAP32[$todo >> 2] = $storemerge49;
    var $2082 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, 2);
    var $_16 = $_1;
    var $len_10 = $2082 + $89 | 0;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 475:
    var $2085 = __ZL6PopOffP11SprintStack4JSOp($ss, $67);
    var $op_9 = 53;
    __label__ = 476;
    break;
   case 476:
    var $op_9;
    var $2087 = HEAP32[$_pre_phi >> 2];
    var $2088 = _js_GetIndexFromBytecode($8, $2087, $_1, 0);
    var $2089 = HEAPU32[$_pre_phi >> 2];
    var $2091 = HEAPU32[$2089 >> 2];
    if ($_1 >>> 0 < $2091 >>> 0) {
      __label__ = 478;
      break;
    } else {
      __label__ = 477;
      break;
    }
   case 477:
    if (($2091 + HEAP32[$2089 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 479;
      break;
    } else {
      __label__ = 478;
      break;
    }
   case 478:
    var $2100 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2101 = __ZN11JSAtomState16commonAtomsStartEv($2100);
    var $atom_7 = HEAP32[$2101 + ($2088 << 2) >> 2];
    __label__ = 480;
    break;
   case 479:
    var $2105 = __ZN8JSScript7getAtomEj($2089, $2088);
    var $atom_7 = $2105;
    __label__ = 480;
    break;
   case 480:
    var $atom_7;
    var $2108 = __Z15js_IsIdentifierP14JSLinearString($atom_7 | 0);
    var $2109 = ($2108 | 0) == 0;
    var $_156 = $2109 ? 39 : 0;
    var $_157 = $2109 ? STRING_TABLE.__str1402813 | 0 : STRING_TABLE.__str1392812 | 0;
    var $2111 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_7 | 0, $_156);
    if (($2111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 481;
      break;
    }
   case 481:
    var $2118 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($2118 << 24 >> 24 == 58 || $2118 << 24 >> 24 == 123 || $2118 << 24 >> 24 == 108 || $2118 << 24 >> 24 == 79) {
      __label__ = 482;
      break;
    } else {
      __label__ = 483;
      break;
    }
   case 482:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 483;
    break;
   case 483:
    var $2121 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_9);
    var $2122 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_157, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2121, HEAP32[tempInt + 4 >> 2] = $2111, tempInt));
    HEAP32[$todo >> 2] = $2122;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2111;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 484:
    var $2124 = HEAP32[$_pre_phi >> 2];
    var $2125 = _js_GetIndexFromBytecode($8, $2124, $_1, 0);
    var $2126 = HEAPU32[$_pre_phi >> 2];
    var $2128 = HEAPU32[$2126 >> 2];
    if ($_1 >>> 0 < $2128 >>> 0) {
      __label__ = 486;
      break;
    } else {
      __label__ = 485;
      break;
    }
   case 485:
    if (($2128 + HEAP32[$2126 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 487;
      break;
    } else {
      __label__ = 486;
      break;
    }
   case 486:
    var $2137 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2138 = __ZN11JSAtomState16commonAtomsStartEv($2137);
    var $atom_8 = HEAP32[$2138 + ($2125 << 2) >> 2];
    __label__ = 488;
    break;
   case 487:
    var $2142 = __ZN8JSScript7getAtomEj($2126, $2125);
    var $atom_8 = $2142;
    __label__ = 488;
    break;
   case 488:
    var $atom_8;
    var $2145 = __Z15js_IsIdentifierP14JSLinearString($atom_8 | 0);
    var $2146 = ($2145 | 0) == 0;
    var $_158 = $2146 ? 39 : 0;
    var $_159 = $2146 ? STRING_TABLE.__str932766 | 0 : STRING_TABLE.__str942767 | 0;
    var $2148 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_8 | 0, $_158);
    if (($2148 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 489;
      break;
    }
   case 489:
    var $2151 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $2152 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    var $2155 = HEAP32[$_pre_phi >> 2];
    var $2156 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2155, $_1 - 1 | 0);
    if (($2156 | 0) == 0) {
      var $2168 = __str93064 | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 490;
      break;
    }
   case 490:
    var $2159 = HEAPU8[$2156];
    if (($2159 & 255) < 192 & ($2159 & -8) << 24 >> 24 == 64) {
      __label__ = 491;
      break;
    } else {
      var $2168 = __str93064 | 0;
      __label__ = 494;
      break;
    }
   case 491:
    if (($67 | 0) == 125) {
      var $2168 = STRING_TABLE._js_getter_str | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 492;
      break;
    }
   case 492:
    if (($67 | 0) == 126) {
      var $2168 = STRING_TABLE._js_setter_str | 0;
      __label__ = 494;
      break;
    } else {
      __label__ = 493;
      break;
    }
   case 493:
    var $2168 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 494;
    break;
   case 494:
    var $2168;
    var $2169 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $_159, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $2152, HEAP32[tempInt + 4 >> 2] = $2148, HEAP32[tempInt + 8 >> 2] = $2168, HEAP32[tempInt + 12 >> 2] = $2151, tempInt));
    HEAP32[$todo >> 2] = $2169;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2151;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 495:
    var $2171 = __ZL6PopOffP11SprintStack4JSOp($ss, $67);
    __label__ = 496;
    break;
   case 496:
    var $2173 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2174 = HEAP32[$saveop >> 2];
    var $2179 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($2179 << 24 >> 24 == 58 || $2179 << 24 >> 24 == 123 || $2179 << 24 >> 24 == 108 || $2179 << 24 >> 24 == 79) {
      __label__ = 497;
      break;
    } else {
      __label__ = 498;
      break;
    }
   case 497:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 498;
    break;
   case 498:
    var $2182 = __ZL6PopStrP11SprintStack4JSOp($ss, $2174);
    if (HEAP8[$2173] << 24 >> 24 == 0) {
      __label__ = 499;
      break;
    } else {
      __label__ = 500;
      break;
    }
   case 499:
    var $2186 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str382711 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2182, tempInt));
    HEAP32[$todo >> 2] = $2186;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 500:
    var $2190 = ($67 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $2191 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2190, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $2182, HEAP32[tempInt + 4 >> 2] = $2173, tempInt));
    HEAP32[$todo >> 2] = $2191;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 501:
    var $2193 = __ZL6PopStrP11SprintStack4JSOp($ss, 56);
    var $2194 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2199 = HEAPU8[HEAP32[$36 >> 2] + HEAP32[$30 >> 2] | 0] & 255;
    var $2200 = _js_CodeSpec + ($2199 << 3) | 0;
    var $2201 = __ZL6PopStrP11SprintStack4JSOp($ss, 55);
    if (HEAP8[$2194] << 24 >> 24 == 0) {
      var $op_8 = HEAP32[$saveop >> 2];
      var $cs_1 = $2200;
      var $lval_1 = $2201;
      var $rval_13 = $2193;
      __label__ = 389;
      break;
    } else {
      __label__ = 502;
      break;
    }
   case 502:
    var $2208 = HEAP32[$_pre_phi >> 2];
    var $2209 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2208, $_1 - 1 | 0);
    var $2212 = ($2199 - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str942767 | 0 : STRING_TABLE.__str932766 | 0;
    if (($2209 | 0) == 0) {
      var $2224 = __str93064 | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 503;
      break;
    }
   case 503:
    var $2215 = HEAPU8[$2209];
    if (($2215 & 255) < 192 & ($2215 & -8) << 24 >> 24 == 64) {
      __label__ = 504;
      break;
    } else {
      var $2224 = __str93064 | 0;
      __label__ = 507;
      break;
    }
   case 504:
    if (($67 | 0) == 125) {
      var $2224 = STRING_TABLE._js_getter_str | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 505;
      break;
    }
   case 505:
    if (($67 | 0) == 126) {
      var $2224 = STRING_TABLE._js_setter_str | 0;
      __label__ = 507;
      break;
    } else {
      __label__ = 506;
      break;
    }
   case 506:
    var $2224 = HEAP32[__ZL9CodeToken + ($67 << 2) >> 2];
    __label__ = 507;
    break;
   case 507:
    var $2224;
    var $2225 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $2212, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $2201, HEAP32[tempInt + 4 >> 2] = $2194, HEAP32[tempInt + 8 >> 2] = $2224, HEAP32[tempInt + 12 >> 2] = $2193, tempInt));
    HEAP32[$todo >> 2] = $2225;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $2200;
    var $rval_18 = $2193;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 508:
    var $2234 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2234;
    var $2235 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str952768 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_arguments_str | 0, HEAP32[tempInt + 4 >> 2] = $2234, tempInt));
    HEAP32[$todo >> 2] = $2235;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 509:
    var $2237 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1392812 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_arguments_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_length_str | 0, tempInt));
    HEAP32[$todo >> 2] = $2237;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 510:
    var $2246 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2246;
    var $2247 = __ZL15GetArgOrVarAtomP9JSPrinterj($16, $2246);
    if (($2247 | 0) == 0) {
      __label__ = 511;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str93064 | 0;
      var $atom_10 = $2247;
      __label__ = 516;
      break;
    }
   case 511:
    var $2250 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str952768 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = STRING_TABLE._js_arguments_str | 0, HEAP32[tempInt + 4 >> 2] = $2246, tempInt));
    HEAP32[$todo >> 2] = $2250;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 512:
    var $2252 = HEAP32[$_pre_phi >> 2];
    var $2253 = _js_GetIndexFromBytecode($8, $2252, $_1, 0);
    var $2254 = HEAPU32[$_pre_phi >> 2];
    var $2256 = HEAPU32[$2254 >> 2];
    if ($_1 >>> 0 < $2256 >>> 0) {
      __label__ = 514;
      break;
    } else {
      __label__ = 513;
      break;
    }
   case 513:
    if (($2256 + HEAP32[$2254 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 515;
      break;
    } else {
      __label__ = 514;
      break;
    }
   case 514:
    var $2265 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2266 = __ZN11JSAtomState16commonAtomsStartEv($2265);
    var $len_6 = $89;
    var $lval_6 = __str93064 | 0;
    var $atom_10 = HEAP32[$2266 + ($2253 << 2) >> 2];
    __label__ = 516;
    break;
   case 515:
    var $2270 = __ZN8JSScript7getAtomEj($2254, $2253);
    var $len_6 = $89;
    var $lval_6 = __str93064 | 0;
    var $atom_10 = $2270;
    __label__ = 516;
    break;
   case 516:
    var $atom_10;
    var $lval_6;
    var $len_6;
    var $2272 = HEAP32[$_pre_phi >> 2];
    var $2273 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2272, $_1);
    var $2276 = ($inXML_0 | 0) != 0 ? 65536 : 0;
    var $2277 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_10 | 0, $2276);
    if (($2277 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 517;
      break;
    }
   case 517:
    var $2283 = $2277 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $2283;
    var $2284 = __ZL9VarPrefixPh($2273);
    var $2285 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2284, HEAP32[tempInt + 4 >> 2] = $lval_6, HEAP32[tempInt + 8 >> 2] = $2277, tempInt));
    HEAP32[$todo >> 2] = $2285;
    var $_16 = $_1;
    var $len_10 = $len_6;
    var $cs_3 = $cs_0;
    var $rval_18 = $2277;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 518:
    var $2294 = (HEAPU8[$_1 + 1 | 0] & 255) << 8 | HEAPU8[$_1 + 2 | 0] & 255;
    HEAP32[$i >> 2] = $2294;
    var $2333 = $2294;
    __label__ = 522;
    break;
   case 519:
    var $2308 = HEAPU8[$_1 + 3 | 0] & 255 | (HEAPU8[$_1 + 1 | 0] & 255) << 16 | (HEAPU8[$_1 + 2 | 0] & 255) << 8;
    HEAP32[$i >> 2] = $2308;
    var $2333 = $2308;
    __label__ = 522;
    break;
   case 520:
    var $2312 = HEAP8[$_1 + 1 | 0] << 24 >> 24;
    HEAP32[$i >> 2] = $2312;
    var $2333 = $2312;
    __label__ = 522;
    break;
   case 521:
    var $2331 = (HEAPU8[$_1 + 2 | 0] & 255) << 16 | (HEAPU8[$_1 + 1 | 0] & 255) << 24 | HEAPU8[$_1 + 4 | 0] & 255 | (HEAPU8[$_1 + 3 | 0] & 255) << 8;
    HEAP32[$i >> 2] = $2331;
    var $2333 = $2331;
    __label__ = 522;
    break;
   case 522:
    var $2333;
    var $2334 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2333, tempInt));
    HEAP32[$todo >> 2] = $2334;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 523:
    var $2336 = HEAP32[$_pre_phi >> 2];
    var $2337 = _js_GetIndexFromBytecode($8, $2336, $_1, 0);
    var $2338 = HEAP32[$_pre_phi >> 2];
    var $2339 = __ZN8JSScript8getConstEj($2338, $2337);
    var $2340 = __ZNK2JS5Value8toDoubleEv($2339);
    _DOUBLE_TO_JSVAL2862($2, $2340);
    var $2341$0 = HEAP32[$52 >> 2];
    var $2341$1 = HEAP32[$52 + 4 >> 2];
    HEAP32[$53 >> 2] = $2341$0;
    HEAP32[$53 + 4 >> 2] = $2341$1;
    var $2342 = __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($6, $2341$0, $2341$1, $saveop);
    HEAP32[$todo >> 2] = $2342;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 524:
    var $2344 = HEAP32[$_pre_phi >> 2];
    var $2345 = _js_GetIndexFromBytecode($8, $2344, $_1, 0);
    var $2346 = HEAPU32[$_pre_phi >> 2];
    var $2348 = HEAPU32[$2346 >> 2];
    if ($_1 >>> 0 < $2348 >>> 0) {
      __label__ = 526;
      break;
    } else {
      __label__ = 525;
      break;
    }
   case 525:
    if (($2348 + HEAP32[$2346 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 527;
      break;
    } else {
      __label__ = 526;
      break;
    }
   case 526:
    var $2357 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2358 = __ZN11JSAtomState16commonAtomsStartEv($2357);
    var $atom_11 = HEAP32[$2358 + ($2345 << 2) >> 2];
    __label__ = 528;
    break;
   case 527:
    var $2362 = __ZN8JSScript7getAtomEj($2346, $2345);
    var $atom_11 = $2362;
    __label__ = 528;
    break;
   case 528:
    var $atom_11;
    var $2366 = ($inXML_0 | 0) != 0 ? 65536 : 34;
    var $2367 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_11 | 0, $2366);
    if (($2367 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 529;
      break;
    }
   case 529:
    var $2373 = $2367 - HEAP32[$37 >> 2] | 0;
    HEAP32[$todo >> 2] = $2373;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2367;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 530:
    var $2376 = HEAP32[$_pre_phi >> 2];
    var $2377 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2376, $_1);
    if (($2377 | 0) == 0) {
      __label__ = 569;
      break;
    } else {
      __label__ = 531;
      break;
    }
   case 531:
    var $2380 = HEAPU8[$2377];
    if (($2380 & 255) < 192 & ($2380 & -8) << 24 >> 24 == 8) {
      __label__ = 532;
      break;
    } else {
      __label__ = 569;
      break;
    }
   case 532:
    var $2383 = HEAP32[$_pre_phi >> 2];
    var $2384 = _js_GetIndexFromBytecode($8, $2383, $_1, 0);
    var $2385 = HEAP32[$_pre_phi >> 2];
    var $2386 = __ZN8JSScript11getFunctionEj($2385, $2384);
    var $2389 = HEAPU32[HEAP32[$55 >> 2] + 12 >> 2];
    var $2390 = $2389;
    var $2391 = __ZNK10JSFunction6scriptEv($2386);
    var $2393 = $2391 + 64 | 0;
    var $2394 = __ZNK2js8Bindings13hasLocalNamesEv($2393);
    if ($2394) {
      __label__ = 533;
      break;
    } else {
      var $innerLocalNames_0 = 0;
      __label__ = 535;
      break;
    }
   case 533:
    var $2396 = __ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_($8, $8);
    if (($2396 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 534;
      break;
    }
   case 534:
    var $2399 = __ZNK10JSFunction6scriptEv($2386);
    var $2401 = $2399 + 64 | 0;
    var $2402 = $2396;
    var $2403 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($2401, undef, $2402);
    if ($2403) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $innerLocalNames_0 = $2396;
      __label__ = 535;
      break;
    }
   case 535:
    var $innerLocalNames_0;
    var $2405 = __ZNK10JSFunction6scriptEv($2386);
    var $_idx_val = HEAP16[$2405 + 14 >> 1];
    var $_idx12_val = HEAP16[$2405 + 44 >> 1];
    var $2406 = __ZL10StackDepthP8JSScript($_idx_val, $_idx12_val);
    var $2407 = __ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj($8, $ss2, $16, $2406);
    if (($2407 | 0) == 0) {
      __label__ = 536;
      break;
    } else {
      __label__ = 540;
      break;
    }
   case 536:
    var $2410 = HEAP32[$55 >> 2];
    if (($2410 | 0) == ($59 | 0)) {
      __label__ = 539;
      break;
    } else {
      __label__ = 537;
      break;
    }
   case 537:
    var $2414 = HEAP32[$2410 + 4 >> 2];
    var $2416 = $2410 + 12 | 0;
    if (($2389 - $2414 | 0) >>> 0 > (HEAP32[$2416 >> 2] - $2414 | 0) >>> 0) {
      __label__ = 539;
      break;
    } else {
      __label__ = 538;
      break;
    }
   case 538:
    var $2421 = HEAPU32[$60 >> 2];
    var $2424 = $2421 + $2389 & ($2421 ^ -1);
    HEAP32[$2416 >> 2] = $2424;
    var $_0 = 0;
    __label__ = 742;
    break;
   case 539:
    _JS_ArenaRelease($54, $2390);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 540:
    HEAP32[$56 >> 2] = 1;
    var $2427 = HEAPU32[$_pre_phi >> 2];
    var $2429 = $2427 | 0;
    var $2433 = $2427 + 8 | 0;
    if (($_1 - HEAP32[$2429 >> 2] | 0) >>> 0 > HEAPU32[$2433 >> 2] >>> 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 541;
      break;
    }
   case 541:
    var $2437 = HEAP32[$47 >> 2];
    var $2438 = HEAP32[$46 >> 2];
    HEAP32[$_pre_phi >> 2] = $2405;
    HEAP32[$46 >> 2] = $2386;
    HEAP32[$47 >> 2] = $innerLocalNames_0;
    var $2439 = __ZN8JSScript4mainEv($2405);
    var $2444 = HEAP32[$2405 + 8 >> 2] - HEAP32[$2405 + 32 >> 2] | 0;
    var $2445 = __ZL9DecompileP11SprintStackPhi4JSOp($ss2, $2439, $2444);
    var $2446 = ($2445 | 0) == 0;
    HEAP32[$_pre_phi >> 2] = $2427;
    HEAP32[$46 >> 2] = $2438;
    HEAP32[$47 >> 2] = $2437;
    if ($2446) {
      __label__ = 542;
      break;
    } else {
      __label__ = 546;
      break;
    }
   case 542:
    var $2448 = HEAP32[$55 >> 2];
    if (($2448 | 0) == ($59 | 0)) {
      __label__ = 545;
      break;
    } else {
      __label__ = 543;
      break;
    }
   case 543:
    var $2452 = HEAP32[$2448 + 4 >> 2];
    var $2454 = $2448 + 12 | 0;
    if (($2389 - $2452 | 0) >>> 0 > (HEAP32[$2454 >> 2] - $2452 | 0) >>> 0) {
      __label__ = 545;
      break;
    } else {
      __label__ = 544;
      break;
    }
   case 544:
    var $2459 = HEAPU32[$60 >> 2];
    var $2462 = $2459 + $2389 & ($2459 ^ -1);
    HEAP32[$2454 >> 2] = $2462;
    var $_0 = 0;
    __label__ = 742;
    break;
   case 545:
    _JS_ArenaRelease($54, $2390);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 546:
    var $2465 = HEAP8[$108];
    if ($2465 << 24 >> 24 == -68) {
      __label__ = 547;
      break;
    } else if ($2465 << 24 >> 24 == -67) {
      __label__ = 548;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 547:
    var $_sum39_pn = $89 + 3 | 0;
    __label__ = 549;
    break;
   case 548:
    var $_sum39_pn = $89 + 1 | 0;
    __label__ = 549;
    break;
   case 549:
    var $_sum39_pn;
    if (HEAP8[$_1 + $_sum39_pn | 0] << 24 >> 24 == 1) {
      __label__ = 550;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 550:
    var $2472 = $_sum39_pn + ($_1 + 1) | 0;
    if (HEAP8[$2472] << 24 >> 24 == 58) {
      __label__ = 551;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 551:
    if (((HEAPU8[$_sum39_pn + ($_1 + 2) | 0] & 255) << 8 | HEAPU8[$_sum39_pn + ($_1 + 3) | 0] & 255 | 0) == 0) {
      __label__ = 552;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 552:
    var $2486 = $_sum39_pn + ($_1 + 4) | 0;
    var $2487 = HEAP8[$2486];
    if ($2487 << 24 >> 24 == 109 || $2487 << 24 >> 24 == 0) {
      __label__ = 553;
      break;
    } else {
      var $pc2_2 = $2486;
      __label__ = 554;
      break;
    }
   case 553:
    var $pc2_2 = $_sum39_pn + ($_1 + 5) | 0;
    __label__ = 554;
    break;
   case 554:
    var $pc2_2;
    if ($pc2_2 >>> 0 < $29 >>> 0) {
      __label__ = 556;
      break;
    } else {
      __label__ = 555;
      break;
    }
   case 555:
    if ($29 >>> 0 < (HEAP32[$2429 >> 2] + HEAP32[$2433 >> 2] | 0) >>> 0) {
      __label__ = 556;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 556:
    if ((HEAP32[$57 >> 2] | 0) == 1) {
      __label__ = 557;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 557:
    HEAP8[HEAP32[$58 >> 2]] = 81;
    if (($pc2_2 | 0) == ($29 | 0)) {
      var $op_10 = 111;
      __label__ = 563;
      break;
    } else {
      __label__ = 558;
      break;
    }
   case 558:
    var $2507 = HEAPU32[_js_CodeSpec + ((HEAPU8[$pc2_2] & 255) << 3) + 4 >> 2];
    if (($2507 & 1048576 | 0) == 0) {
      __label__ = 559;
      break;
    } else {
      var $2524 = 81;
      __label__ = 561;
      break;
    }
   case 559:
    if (($2507 & 2097152 | 0) == 0) {
      var $2524 = 111;
      __label__ = 561;
      break;
    } else {
      __label__ = 560;
      break;
    }
   case 560:
    var $phitmp38 = ((HEAPU8[$pc2_2 + 1 | 0] & 255) << 8 | HEAPU8[$pc2_2 + 2 | 0] & 255 | 0) == 1 ? 81 : 111;
    var $2524 = $phitmp38;
    __label__ = 561;
    break;
   case 561:
    var $2524;
    if (HEAP8[_js_CodeSpec + (HEAP32[$saveop >> 2] << 3) + 3 | 0] << 24 >> 24 == 19) {
      __label__ = 562;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 562:
    HEAP32[$saveop >> 2] = 59;
    var $op_10 = $2524;
    __label__ = 563;
    break;
   case 563:
    var $op_10;
    var $2531 = __ZL6PopStrP11SprintStack4JSOp($ss2, $op_10);
    var $2532 = _JS_strdup($8, $2531);
    var $2533 = HEAP32[$55 >> 2];
    if (($2533 | 0) == ($59 | 0)) {
      __label__ = 566;
      break;
    } else {
      __label__ = 564;
      break;
    }
   case 564:
    var $2537 = HEAP32[$2533 + 4 >> 2];
    var $2539 = $2533 + 12 | 0;
    if (($2389 - $2537 | 0) >>> 0 > (HEAP32[$2539 >> 2] - $2537 | 0) >>> 0) {
      __label__ = 566;
      break;
    } else {
      __label__ = 565;
      break;
    }
   case 565:
    var $2544 = HEAPU32[$60 >> 2];
    var $2547 = $2544 + $2389 & ($2544 ^ -1);
    HEAP32[$2539 >> 2] = $2547;
    __label__ = 567;
    break;
   case 566:
    _JS_ArenaRelease($54, $2390);
    __label__ = 567;
    break;
   case 567:
    if (($2532 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 568;
      break;
    }
   case 568:
    var $2552 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $2532);
    HEAP32[$todo >> 2] = $2552;
    __ZN9JSContext5free_EPv(undef, $2532);
    var $_16 = $2472;
    var $len_10 = 3;
    var $cs_3 = $cs_0;
    var $rval_18 = $2532;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 569:
    var $2553 = HEAP32[$_pre_phi >> 2];
    var $2554 = _js_GetIndexFromBytecode($8, $2553, $_1, 0);
    var $2555 = HEAP32[$_pre_phi >> 2];
    var $2556 = __ZN8JSScript11getFunctionEj($2555, $2554);
    var $2565 = ((HEAPU16[$2556 + 58 >> 1] & 65535) >>> 12 & 1 ^ 1) & 65535;
    var $2566 = (HEAPU8[$2555 + 36 | 0] & 255) >>> 3 & 1 & 255;
    var $2567 = _js_DecompileToString($8, undef, $2556, 0, 0, $2565, $2566, 50);
    if (($2567 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $str_0 = $2567;
      __label__ = 570;
      break;
    }
   case 570:
    var $str_0;
    var $2570 = __ZN2js12SprintStringEPNS_8SprinterEP8JSString($6, $str_0);
    HEAP32[$todo >> 2] = $2570;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 571:
    var $2575 = HEAP32[HEAP32[$46 >> 2] + 72 >> 2] | 0;
    var $2576 = __ZN2js12SprintStringEPNS_8SprinterEP8JSString($6, $2575);
    HEAP32[$todo >> 2] = $2576;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 572:
    var $2578 = HEAP32[$_pre_phi >> 2];
    var $2579 = _js_GetIndexFromBytecode($8, $2578, $_1, 0);
    var $2580 = HEAP32[$_pre_phi >> 2];
    var $2581 = __ZN8JSScript9getObjectEj($2580, $2579);
    __ZN2JSL11ObjectValueER8JSObject2863($3, $2581);
    var $2582 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($61, $3);
    if (($2582 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $str_0 = $2582;
      __label__ = 570;
      break;
    }
   case 573:
    var $2585 = HEAP32[$_pre_phi >> 2];
    var $2586 = _js_GetIndexFromBytecode($8, $2585, $_1, 0);
    var $2587 = HEAP32[$_pre_phi >> 2];
    var $2588 = __ZN8JSScript9getRegExpEj($2587, $2586);
    var $2589 = $2588;
    var $2590 = __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($62, $2589, $val);
    if (($2590 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 574;
      break;
    }
   case 574:
    var $2593$0 = HEAP32[$53 >> 2];
    var $2593$1 = HEAP32[$53 + 4 >> 2];
    var $2594 = _JSVAL_TO_STRING2864($2593$0, $2593$1);
    var $str_0 = $2594;
    __label__ = 570;
    break;
   case 575:
    var $2597 = HEAP32[$_pre_phi >> 2];
    var $2598 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2597, $_1);
    if (($2598 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 576;
      break;
    }
   case 576:
    var $2601 = HEAPU8[$2598];
    if (($2601 & 255) < 192 & ($2601 & -8) << 24 >> 24 == -112) {
      __label__ = 577;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 577:
    var $2604 = _js_GetSrcNoteOffset($2598, 0);
    var $2606 = ($op_2 | 0) == 70 ? 2 : 4;
    var $_1_val4 = HEAP8[$_1];
    var $2607 = __ZL13GetJumpOffsetPhS_($_1_val4, $_1);
    var $2616 = ((HEAPU8[$_1 + ($2606 | 1) | 0] & 255) << 8 | HEAPU8[$2606 + ($_1 + 2) | 0] & 255) << 16 >> 16;
    var $2621 = $2606 + ($_1 + 4) | 0;
    var $2627 = (((HEAPU8[$2606 + ($_1 + 3) | 0] & 255) << 8 | HEAPU8[$2621] & 255) << 16 >> 16) - $2616 + 1 | 0;
    if (($2627 | 0) == 0) {
      var $j_2233 = 0;
      var $table_0234 = 0;
      __label__ = 590;
      break;
    } else {
      __label__ = 578;
      break;
    }
   case 578:
    var $2630 = $2627 * 24 | 0;
    var $2631 = __ZN9JSContext7malloc_Ej($8, $2630);
    var $2632 = $2631;
    if (($2631 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $pc2_3 = $2621;
      var $j_0 = 0;
      var $storemerge32 = 0;
      __label__ = 579;
      break;
    }
   case 579:
    var $storemerge32;
    var $j_0;
    var $pc2_3;
    HEAP32[$i >> 2] = $storemerge32;
    if (($storemerge32 | 0) < ($2627 | 0)) {
      __label__ = 580;
      break;
    } else {
      __label__ = 587;
      break;
    }
   case 580:
    var $2636 = $2632 + $j_0 * 24 + 12 | 0;
    HEAP32[$2636 >> 2] = 0;
    var $_1_val3 = HEAP8[$_1];
    var $2637 = __ZL13GetJumpOffsetPhS_($_1_val3, $pc2_3);
    if (($2637 | 0) == 0) {
      var $j_1 = $j_0;
      __label__ = 586;
      break;
    } else {
      __label__ = 581;
      break;
    }
   case 581:
    var $2641 = HEAP32[$_pre_phi >> 2];
    var $2642 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2641, $pc2_3);
    if (($2642 | 0) == 0) {
      __label__ = 585;
      break;
    } else {
      __label__ = 582;
      break;
    }
   case 582:
    var $2645 = HEAPU8[$2642];
    if (($2645 & 255) < 192 & ($2645 & -8) << 24 >> 24 == 104) {
      __label__ = 583;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 583:
    var $2648 = _js_GetSrcNoteOffset($2642, 0);
    var $2649 = HEAPU32[$_pre_phi >> 2];
    if ($2648 >>> 0 < HEAPU32[$2649 + 40 >> 2] >>> 0) {
      __label__ = 584;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 584:
    var $2657 = HEAP32[HEAP32[$2649 + 56 >> 2] + ($2648 << 2) >> 2];
    HEAP32[$2636 >> 2] = $2657;
    __label__ = 585;
    break;
   case 585:
    var $2660 = HEAP32[$i >> 2] + $2616 | 0;
    _INT_TO_JSVAL2865($4, $2660);
    var $st$3$0 = $63 | 0;
    var $2661$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $63 + 4 | 0;
    var $2661$1 = HEAP32[$st$3$1 >> 2];
    var $2662 = $2632 + $j_0 * 24 | 0;
    var $st$8$0 = $2662 | 0;
    HEAP32[$st$8$0 >> 2] = $2661$0;
    var $st$8$1 = $2662 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2661$1;
    HEAP32[$2632 + $j_0 * 24 + 8 >> 2] = $2637;
    HEAP32[$2632 + $j_0 * 24 + 16 >> 2] = $j_0;
    var $j_1 = $j_0 + 1 | 0;
    __label__ = 586;
    break;
   case 586:
    var $j_1;
    var $pc2_3 = $pc2_3 + $2606 | 0;
    var $j_0 = $j_1;
    var $storemerge32 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 579;
    break;
   case 587:
    var $2672 = __ZN9JSContext7malloc_Ej($8, $j_0 * 24 | 0);
    if (($2672 | 0) == 0) {
      __label__ = 589;
      break;
    } else {
      __label__ = 588;
      break;
    }
   case 588:
    var $2675 = __Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType($2631, $j_0, 24, 204, 0, $2672, 1);
    __ZN9JSContext5free_EPv(undef, $2672);
    if ($2675) {
      var $j_2233 = $j_0;
      var $table_0234 = $2632;
      __label__ = 590;
      break;
    } else {
      __label__ = 589;
      break;
    }
   case 589:
    __ZN9JSContext5free_EPv(undef, $2631);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 590:
    var $table_0234;
    var $j_2233;
    var $2676 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $table_0234, $j_2233, $_1, $2604, $2607, 0);
    __ZN9JSContext5free_EPv(undef, $table_0234);
    if (($2676 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 591;
      break;
    }
   case 591:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2604;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 592:
    var $2682 = HEAP32[$_pre_phi >> 2];
    var $2683 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2682, $_1);
    if (($2683 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 593;
      break;
    }
   case 593:
    var $2686 = HEAPU8[$2683];
    if (($2686 & 255) < 192 & ($2686 & -8) << 24 >> 24 == -112) {
      __label__ = 594;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 594:
    var $2689 = _js_GetSrcNoteOffset($2683, 0);
    var $2691 = ($op_2 | 0) == 71 ? 2 : 4;
    var $_1_val2 = HEAP8[$_1];
    var $2692 = __ZL13GetJumpOffsetPhS_($_1_val2, $_1);
    var $_sum21 = $2691 + 2 | 0;
    var $2697 = $_1 + $_sum21 | 0;
    var $2700 = (HEAPU8[$_1 + ($2691 | 1) | 0] & 255) << 8 | HEAPU8[$2697] & 255;
    var $2701 = $2700 * 24 | 0;
    var $2702 = __ZN9JSContext7malloc_Ej($8, $2701);
    var $2703 = $2702;
    if (($2702 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $k_0 = 0;
      var $pc2_4 = $2697;
      __label__ = 595;
      break;
    }
   case 595:
    var $pc2_4;
    var $k_0;
    if ($k_0 >>> 0 < $2700 >>> 0) {
      __label__ = 596;
      break;
    } else {
      __label__ = 602;
      break;
    }
   case 596:
    var $2708 = HEAP32[$_pre_phi >> 2];
    var $2709 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2708, $pc2_4);
    if (($2709 | 0) == 0) {
      __label__ = 600;
      break;
    } else {
      __label__ = 597;
      break;
    }
   case 597:
    var $2712 = HEAPU8[$2709];
    if (($2712 & 255) < 192 & ($2712 & -8) << 24 >> 24 == 104) {
      __label__ = 598;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 598:
    var $2715 = _js_GetSrcNoteOffset($2709, 0);
    var $2716 = HEAPU32[$_pre_phi >> 2];
    if ($2715 >>> 0 < HEAPU32[$2716 + 40 >> 2] >>> 0) {
      __label__ = 599;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 599:
    var $2724 = HEAP32[HEAP32[$2716 + 56 >> 2] + ($2715 << 2) >> 2];
    HEAP32[$2703 + $k_0 * 24 + 12 >> 2] = $2724;
    __label__ = 601;
    break;
   case 600:
    HEAP32[$2703 + $k_0 * 24 + 12 >> 2] = 0;
    __label__ = 601;
    break;
   case 601:
    var $2733 = $pc2_4 + 2 | 0;
    var $2736 = (HEAPU8[$pc2_4 + 1 | 0] & 255) << 8 | HEAPU8[$2733] & 255;
    var $_1_val = HEAP8[$_1];
    var $2737 = __ZL13GetJumpOffsetPhS_($_1_val, $2733);
    var $2738 = $pc2_4 + $_sum21 | 0;
    var $2739 = HEAP32[$_pre_phi >> 2];
    var $2740 = __ZN8JSScript8getConstEj($2739, $2736);
    var $2741 = $2740 | 0;
    var $2742$0 = HEAP32[$2741 >> 2];
    var $2742$1 = HEAP32[$2741 + 4 >> 2];
    var $2743 = $2703 + $k_0 * 24 | 0;
    HEAP32[$2743 >> 2] = $2742$0;
    HEAP32[$2743 + 4 >> 2] = $2742$1;
    HEAP32[$2703 + $k_0 * 24 + 8 >> 2] = $2737;
    var $k_0 = $k_0 + 1 | 0;
    var $pc2_4 = $2738;
    __label__ = 595;
    break;
   case 602:
    var $2747 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $2703, $2700, $_1, $2689, $2692, 0);
    __ZN9JSContext5free_EPv(undef, $2702);
    if (($2747 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 603;
      break;
    }
   case 603:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2689;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 604:
    var $2752 = HEAP32[$_pre_phi >> 2];
    var $2753 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2752, $_1);
    if (($2753 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 605;
      break;
    }
   case 605:
    var $2756 = HEAPU8[$2753];
    if (($2756 & 255) < 192 & ($2756 & -8) << 24 >> 24 == -112) {
      __label__ = 606;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 606:
    var $2759 = _js_GetSrcNoteOffset($2753, 0);
    var $2760 = _js_GetSrcNoteOffset($2753, 1);
    var $ncases_0 = 0;
    var $off236_0 = $2760;
    var $pc2_5 = $_1;
    __label__ = 607;
    break;
   case 607:
    var $pc2_5;
    var $off236_0;
    var $ncases_0;
    if (($off236_0 | 0) == 0) {
      __label__ = 613;
      break;
    } else {
      __label__ = 608;
      break;
    }
   case 608:
    var $2764 = $pc2_5 + $off236_0 | 0;
    var $2765 = HEAP8[$2764];
    if ($2765 << 24 >> 24 == 121 || $2765 << 24 >> 24 == -109) {
      __label__ = 609;
      break;
    } else if ($2765 << 24 >> 24 == 122 || $2765 << 24 >> 24 == -108) {
      var $off236_1 = 0;
      __label__ = 612;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 609:
    var $2768 = HEAP32[$_pre_phi >> 2];
    var $2769 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2768, $2764);
    if (($2769 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 610;
      break;
    }
   case 610:
    var $2772 = HEAPU8[$2769];
    if (($2772 & 255) < 192 & ($2772 & -8) << 24 >> 24 == 56) {
      __label__ = 611;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 611:
    var $2775 = _js_GetSrcNoteOffset($2769, 0);
    var $off236_1 = $2775;
    __label__ = 612;
    break;
   case 612:
    var $off236_1;
    var $ncases_0 = $ncases_0 + 1 | 0;
    var $off236_0 = $off236_1;
    var $pc2_5 = $2764;
    __label__ = 607;
    break;
   case 613:
    var $2780 = __ZN9JSContext7malloc_Ej($8, $ncases_0 * 24 | 0);
    var $2781 = $2780;
    if (($2780 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 614;
      break;
    }
   case 614:
    var $2783 = $_1;
    var $off236_2 = $2760;
    var $pc2_6 = $_1;
    var $2785 = 0;
    __label__ = 615;
    break;
   case 615:
    var $2785;
    var $pc2_6;
    var $off236_2;
    HEAP32[$i >> 2] = $2785;
    if (($2785 | 0) < ($ncases_0 | 0)) {
      __label__ = 616;
      break;
    } else {
      __label__ = 622;
      break;
    }
   case 616:
    var $2788 = $pc2_6 + $off236_2 | 0;
    var $2789 = HEAP8[$2788];
    if ($2789 << 24 >> 24 == 121 || $2789 << 24 >> 24 == 122 || $2789 << 24 >> 24 == -109 || $2789 << 24 >> 24 == -108) {
      __label__ = 617;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 617:
    var $2792 = $2788 - $2783 | 0;
    _INT_TO_JSVAL2865($5, $2792);
    var $st$3$0 = $64 | 0;
    var $2793$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $64 + 4 | 0;
    var $2793$1 = HEAP32[$st$3$1 >> 2];
    var $2794 = $2781 + $2785 * 24 | 0;
    var $st$8$0 = $2794 | 0;
    HEAP32[$st$8$0 >> 2] = $2793$0;
    var $st$8$1 = $2794 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $2793$1;
    var $_val1 = HEAP8[$2788];
    var $2795 = __ZL13GetJumpOffsetPhS_($_val1, $2788);
    var $2798 = $2781 + HEAP32[$i >> 2] * 24 + 8 | 0;
    HEAP32[$2798 >> 2] = $2795 + $2792 | 0;
    var $2799 = HEAP8[$2788];
    if ($2799 << 24 >> 24 == 121 || $2799 << 24 >> 24 == -109) {
      __label__ = 618;
      break;
    } else {
      var $off236_3 = $off236_2;
      __label__ = 621;
      break;
    }
   case 618:
    var $2802 = HEAP32[$_pre_phi >> 2];
    var $2803 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2802, $2788);
    if (($2803 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 619;
      break;
    }
   case 619:
    var $2806 = HEAPU8[$2803];
    if (($2806 & 255) < 192 & ($2806 & -8) << 24 >> 24 == 56) {
      __label__ = 620;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 620:
    var $2809 = _js_GetSrcNoteOffset($2803, 0);
    var $off236_3 = $2809;
    __label__ = 621;
    break;
   case 621:
    var $off236_3;
    var $off236_2 = $off236_3;
    var $pc2_6 = $2788;
    var $2785 = HEAP32[$i >> 2] + 1 | 0;
    __label__ = 615;
    break;
   case 622:
    var $2815 = $2781 + ($ncases_0 - 1) * 24 | 0;
    var $2816$0 = HEAP32[$2815 >> 2];
    var $2816$1 = HEAP32[$2815 + 4 >> 2];
    var $2817 = _JSVAL_TO_INT($2816$0, $2816$1);
    var $2818 = $_1 + $2817 | 0;
    var $_val = HEAP8[$2818];
    var $2819 = __ZL13GetJumpOffsetPhS_($_val, $2818);
    var $2820 = $2819 + $2817 | 0;
    var $2821 = __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $2781, $ncases_0, $_1, $2759, $2820, 1);
    __ZN9JSContext5free_EPv(undef, $2780);
    if (($2821 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 623;
      break;
    }
   case 623:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $2759;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 624:
    var $2825 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    if (($2825 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 625;
      break;
    }
   case 625:
    var $2828 = _js_printf($16, STRING_TABLE.__str982771 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2825, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 626:
    var $2830 = HEAP32[$_pre_phi >> 2];
    var $2831 = _js_GetIndexFromBytecode($8, $2830, $_1, 0);
    var $2832 = HEAP32[$_pre_phi >> 2];
    var $2833 = __ZN8JSScript11getFunctionEj($2832, $2831);
    HEAP32[$todo >> 2] = -2;
    var $fun_0 = $2833;
    __label__ = 79;
    break;
   case 627:
    var $2836 = HEAP32[$_pre_phi >> 2];
    var $2837 = _JS_GetTrapOpcode(undef, $2836, $_1);
    HEAP32[$saveop >> 2] = $2837;
    HEAP8[$_1] = $2837 & 255;
    var $2839 = _js_CodeSpec + ($2837 << 3) | 0;
    var $2842 = HEAP8[$2839 | 0] << 24 >> 24;
    var $2843 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $_1, $2842);
    if (($2843 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 628;
      break;
    }
   case 628:
    var $2847 = HEAPU8[$_1] & 255;
    if ((HEAP32[_js_CodeSpec + ($2847 << 3) + 4 >> 2] & 134217728 | 0) == 0) {
      var $len_7 = $2842;
      __label__ = 630;
      break;
    } else {
      __label__ = 629;
      break;
    }
   case 629:
    var $2855 = HEAP8[_js_CodeSpec + ($2847 << 3) | 0] << 24 >> 24;
    var $2856 = __ZN2jsL18GetDecomposeLengthEPhj2861($_1, $2855);
    var $len_7 = $2856 + $2842 | 0;
    __label__ = 630;
    break;
   case 630:
    var $len_7;
    HEAP8[$_1] = 83;
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $len_7;
    var $cs_3 = $2839;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 631:
    var $2860 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, __str93064 | 0, 0);
    HEAP32[$todo >> 2] = $2860;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 632:
    var $2863 = HEAPU8[$_1 + 1 | 0];
    var $2864 = $2863 & 255;
    HEAP32[$i >> 2] = $2864;
    if ($2863 << 24 >> 24 == 3 || $2863 << 24 >> 24 == 1) {
      __label__ = 633;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 633:
    var $2866 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2866;
    var $2867 = HEAPU8[$108];
    if ($2867 << 24 >> 24 == -26) {
      __label__ = 634;
      break;
    } else {
      var $len_8 = $89;
      var $op_11_in = $2867;
      __label__ = 635;
      break;
    }
   case 634:
    var $2870 = $89 + 3 | 0;
    var $len_8 = $2870;
    var $op_11_in = HEAP8[$_1 + $2870 | 0];
    __label__ = 635;
    break;
   case 635:
    var $op_11_in;
    var $len_8;
    if ($op_11_in << 24 >> 24 == 95) {
      __label__ = 636;
      break;
    } else {
      var $_1517 = $_1;
      var $len_9 = $len_8;
      var $cs_2 = $cs_0;
      var $2888 = $2864;
      __label__ = 638;
      break;
    }
   case 636:
    var $2883 = (HEAPU8[$len_8 + ($_1 + 3) | 0] & 255) << 8 | HEAPU8[$len_8 + ($_1 + 4) | 0] & 255;
    var $2884 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str992772 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $2883, tempInt));
    if (($2884 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 637;
      break;
    }
   case 637:
    var $_1517 = $_1 + $len_8 | 0;
    var $len_9 = 5;
    var $cs_2 = _js_CodeSpec + 760 | 0;
    var $2888 = HEAP32[$i >> 2];
    __label__ = 638;
    break;
   case 638:
    var $2888;
    var $cs_2;
    var $len_9;
    var $_1517;
    if (($2888 | 0) == 3) {
      __label__ = 639;
      break;
    } else {
      __label__ = 640;
      break;
    }
   case 639:
    var $2892 = HEAP32[$50 >> 2] + 1 | 0;
    HEAP32[$50 >> 2] = $2892;
    var $2893 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1002773 | 0);
    if (($2893 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1517;
      var $len_10 = $len_9;
      var $cs_3 = $cs_2;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 640:
    var $2896 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1012774 | 0);
    if (($2896 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1517;
      var $len_10 = $len_9;
      var $cs_3 = $cs_2;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 641:
    var $2899 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2899;
    var $2901 = HEAP32[$50 >> 2] + 1 | 0;
    HEAP32[$50 >> 2] = $2901;
    var $2902 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1002773 | 0);
    if (($2902 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 642:
    var $2905 = HEAP32[$38 >> 2];
    HEAP32[$todo >> 2] = $2905;
    var $2906 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, STRING_TABLE.__str1012774 | 0);
    if (($2906 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      var $_16 = $_1;
      var $len_10 = $89;
      var $cs_3 = $cs_0;
      var $rval_18 = $rval_0;
      var $foreach_1 = $foreach_0;
      var $inXML_1 = $inXML_0;
      var $quoteAttr_1 = $quoteAttr_0;
      __label__ = 735;
      break;
    }
   case 643:
    var $2909 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2911 = HEAP32[$_pre_phi >> 2];
    var $2912 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2911, $_1);
    var $xval_1 = $2909;
    __label__ = 644;
    break;
   case 644:
    var $xval_1;
    var $2914 = HEAP8[$xval_1];
    if ($2914 << 24 >> 24 == 91 || $2914 << 24 >> 24 == 123) {
      __label__ = 646;
      break;
    } else {
      __label__ = 645;
      break;
    }
   case 645:
    var $xval_1 = $xval_1 + 1 | 0;
    __label__ = 644;
    break;
   case 646:
    var $2917 = $2914 << 24 >> 24 == 91;
    if ($2917) {
      __label__ = 647;
      break;
    } else {
      __label__ = 648;
      break;
    }
   case 647:
    var $2920 = HEAP32[$50 >> 2] - 1 | 0;
    HEAP32[$50 >> 2] = $2920;
    __label__ = 648;
    break;
   case 648:
    if (($2912 | 0) == 0) {
      var $2928 = __str93064 | 0;
      __label__ = 651;
      break;
    } else {
      __label__ = 649;
      break;
    }
   case 649:
    var $2924 = HEAPU8[$2912];
    if (($2924 & 255) > 191) {
      var $2928 = __str93064 | 0;
      __label__ = 651;
      break;
    } else {
      __label__ = 650;
      break;
    }
   case 650:
    var $phitmp5 = ($2924 & -8) << 24 >> 24 == 40 ? STRING_TABLE.__str332706 | 0 : __str93064 | 0;
    var $2928 = $phitmp5;
    __label__ = 651;
    break;
   case 651:
    var $2928;
    var $2929 = $2917 ? 93 : 125;
    var $2930 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1022775 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2909, HEAP32[tempInt + 4 >> 2] = $2928, HEAP32[tempInt + 8 >> 2] = $2929, tempInt));
    HEAP32[$todo >> 2] = $2930;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2909;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 652:
    var $2936 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 3) | 0];
    var $2937 = __ZL15IsInitializerOph($2936);
    var $2938 = __ZL6PopStrP11SprintStack4JSOp($ss, 111);
    var $2939 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2940 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $2942 = HEAP32[$_pre_phi >> 2];
    var $2943 = __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($34, $2942, $_1);
    if (($2943 | 0) == 0) {
      __label__ = 654;
      break;
    } else {
      __label__ = 653;
      break;
    }
   case 653:
    var $2947 = HEAPU8[$2943];
    if (($2947 & 255) < 192 & ($2947 & -8) << 24 >> 24 == 8) {
      var $isFirst_0 = $2937 & 1;
      var $lval_7 = $2940;
      var $rval_16 = $2938;
      var $xval_2 = $2939;
      __label__ = 661;
      break;
    } else {
      __label__ = 654;
      break;
    }
   case 654:
    var $2949 = $2937 ? __str93064 | 0 : STRING_TABLE.__str332706 | 0;
    var $2950 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $2940, HEAP32[tempInt + 4 >> 2] = $2949, HEAP32[tempInt + 8 >> 2] = $2938, tempInt));
    HEAP32[$todo >> 2] = $2950;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $2938;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 655:
    var $2952 = HEAP32[$_pre_phi >> 2];
    var $2953 = _js_GetIndexFromBytecode($8, $2952, $_1, 0);
    var $2954 = HEAPU32[$_pre_phi >> 2];
    var $2956 = HEAPU32[$2954 >> 2];
    if ($_1 >>> 0 < $2956 >>> 0) {
      __label__ = 657;
      break;
    } else {
      __label__ = 656;
      break;
    }
   case 656:
    if (($2956 + HEAP32[$2954 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 658;
      break;
    } else {
      __label__ = 657;
      break;
    }
   case 657:
    var $2965 = HEAP32[$51 >> 2] + 209948 | 0;
    var $2966 = __ZN11JSAtomState16commonAtomsStartEv($2965);
    var $atom_12 = HEAP32[$2966 + ($2953 << 2) >> 2];
    __label__ = 659;
    break;
   case 658:
    var $2970 = __ZN8JSScript7getAtomEj($2954, $2953);
    var $atom_12 = $2970;
    __label__ = 659;
    break;
   case 659:
    var $atom_12;
    var $2972 = $atom_12 | 0;
    var $2974 = __Z15js_IsIdentifierP14JSLinearString($atom_12 | 0);
    var $2976 = ($2974 | 0) != 0 ? 0 : 39;
    var $2977 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $2972, $2976);
    if (($2977 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 660;
      break;
    }
   case 660:
    var $2984 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 2) | 0];
    var $2985 = __ZL15IsInitializerOph($2984);
    var $2986 = $2985 & 1;
    var $2987 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $2988 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $isFirst_0 = $2986;
    var $lval_7 = $2988;
    var $rval_16 = $2987;
    var $xval_2 = $2977;
    __label__ = 661;
    break;
   case 661:
    var $xval_2;
    var $rval_16;
    var $lval_7;
    var $isFirst_0;
    var $2991 = ($isFirst_0 | 0) != 0 ? __str93064 | 0 : STRING_TABLE.__str332706 | 0;
    var $2992 = ($67 | 0) == 125;
    if (($67 - 125 | 0) >>> 0 < 2) {
      __label__ = 662;
      break;
    } else {
      __label__ = 669;
      break;
    }
   case 662:
    var $2995 = _strlen($rval_16);
    if (HEAP8[$rval_16] << 24 >> 24 == 40) {
      __label__ = 663;
      break;
    } else {
      var $_sum_pn = $2995;
      var $rval_17 = $rval_16;
      __label__ = 664;
      break;
    }
   case 663:
    var $_sum_pn = $2995 - 1 | 0;
    var $rval_17 = $rval_16 + 1 | 0;
    __label__ = 664;
    break;
   case 664:
    var $rval_17;
    var $_sum_pn;
    var $end_0 = $rval_16 + $_sum_pn | 0;
    var $3001 = _strncmp($rval_17, STRING_TABLE._js_function_str | 0, 8);
    if (($3001 | 0) == 0) {
      __label__ = 665;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 665:
    if (HEAP8[$rval_17 + 8 | 0] << 24 >> 24 == 32) {
      __label__ = 666;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 666:
    var $3008 = $rval_17 + 9 | 0;
    var $3009 = HEAP8[$end_0];
    if ($3009 << 24 >> 24 == 0) {
      __label__ = 667;
      break;
    } else if ($3009 << 24 >> 24 == 41) {
      __label__ = 668;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 667:
    if (HEAP8[$rval_16 + ($_sum_pn - 1) | 0] << 24 >> 24 == 125) {
      __label__ = 668;
      break;
    } else {
      var $_0 = 0;
      __label__ = 742;
      break;
    }
   case 668:
    var $_15 = $2992 ? STRING_TABLE._js_get_str : STRING_TABLE._js_set_str;
    var $3015 = $_15 | 0;
    var $3018 = HEAP8[$3008] << 24 >> 24 != 40 ? STRING_TABLE._js_space_str | 0 : __str93064 | 0;
    var $3022 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1032776 | 0, (tempInt = STACKTOP, STACKTOP += 28, HEAP32[tempInt >> 2] = $lval_7, HEAP32[tempInt + 4 >> 2] = $2991, HEAP32[tempInt + 8 >> 2] = $3015, HEAP32[tempInt + 12 >> 2] = $xval_2, HEAP32[tempInt + 16 >> 2] = $3018, HEAP32[tempInt + 20 >> 2] = $end_0 - $3008 | 0, HEAP32[tempInt + 24 >> 2] = $3008, tempInt));
    HEAP32[$todo >> 2] = $3022;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3008;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 669:
    var $3024 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1052778 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = $lval_7, HEAP32[tempInt + 4 >> 2] = $2991, HEAP32[tempInt + 8 >> 2] = $xval_2, HEAP32[tempInt + 12 >> 2] = $rval_16, tempInt));
    HEAP32[$todo >> 2] = $3024;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_16;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 670:
    HEAP32[$i >> 2] = (HEAPU8[$_1 + 3 | 0] & 255) << 8 | HEAPU8[$_1 + 4 | 0] & 255;
    var $3034 = __ZL6PopStrP11SprintStack4JSOp($ss, 95);
    var $3035 = HEAP32[$i >> 2];
    var $3036 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1062779 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3035, HEAP32[tempInt + 4 >> 2] = $3034, tempInt));
    HEAP32[$todo >> 2] = $3036;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3034;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 671:
    var $3045 = (HEAPU8[$_1 + 3 | 0] & 255) << 8 | HEAPU8[$_1 + 4 | 0] & 255;
    HEAP32[$i >> 2] = $3045;
    var $3046 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1072780 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3045, tempInt));
    HEAP32[$todo >> 2] = $3046;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 672:
    var $3048 = _js_printf($16, STRING_TABLE.__str1082781 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 673:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = ($op_2 | 0) == 194 & 1;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 674:
    var $3053 = __ZL6PopStrP11SprintStack4JSOp($ss, 163);
    var $3054 = _js_printf($16, STRING_TABLE.__str1092782 | 0, (tempInt = STACKTOP, STACKTOP += 16, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_xml_str | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE._js_namespace_str | 0, HEAP32[tempInt + 12 >> 2] = $3053, tempInt));
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3053;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 675:
    if (HEAP8[$_1 + 1 | 0] << 24 >> 24 == -88) {
      __label__ = 676;
      break;
    } else {
      __label__ = 677;
      break;
    }
   case 676:
    var $3060 = $89 + 1 | 0;
    var $3061 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1102783 | 0, 2);
    HEAP32[$todo >> 2] = $3061;
    var $_16 = $_1;
    var $len_10 = $3060;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 677:
    var $3063 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE._js_star_str | 0, 1);
    HEAP32[$todo >> 2] = $3063;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 678:
    var $3065 = HEAP32[$_pre_phi >> 2];
    var $3066 = _js_GetIndexFromBytecode($8, $3065, $_1, 0);
    var $3067 = HEAPU32[$_pre_phi >> 2];
    var $3069 = HEAPU32[$3067 >> 2];
    if ($_1 >>> 0 < $3069 >>> 0) {
      __label__ = 680;
      break;
    } else {
      __label__ = 679;
      break;
    }
   case 679:
    if (($3069 + HEAP32[$3067 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 681;
      break;
    } else {
      __label__ = 680;
      break;
    }
   case 680:
    var $3078 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3079 = __ZN11JSAtomState16commonAtomsStartEv($3078);
    var $atom_13 = HEAP32[$3079 + ($3066 << 2) >> 2];
    __label__ = 682;
    break;
   case 681:
    var $3083 = __ZN8JSScript7getAtomEj($3067, $3066);
    var $atom_13 = $3083;
    __label__ = 682;
    break;
   case 682:
    var $atom_13;
    if (HEAP8[$_1 + 3 | 0] << 24 >> 24 == -88) {
      __label__ = 683;
      break;
    } else {
      var $len_6 = $89;
      var $lval_6 = __str93064 | 0;
      var $atom_10 = $atom_13;
      __label__ = 516;
      break;
    }
   case 683:
    HEAP32[$saveop >> 2] = 168;
    var $len_6 = $89 + 1 | 0;
    var $lval_6 = STRING_TABLE.__str1112784 | 0;
    var $atom_10 = $atom_13;
    __label__ = 516;
    break;
   case 684:
    var $3091 = HEAP32[$_pre_phi >> 2];
    var $3092 = _js_GetIndexFromBytecode($8, $3091, $_1, 0);
    var $3093 = HEAPU32[$_pre_phi >> 2];
    var $3095 = HEAPU32[$3093 >> 2];
    if ($_1 >>> 0 < $3095 >>> 0) {
      __label__ = 686;
      break;
    } else {
      __label__ = 685;
      break;
    }
   case 685:
    if (($3095 + HEAP32[$3093 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 687;
      break;
    } else {
      __label__ = 686;
      break;
    }
   case 686:
    var $3104 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3105 = __ZN11JSAtomState16commonAtomsStartEv($3104);
    var $atom_14 = HEAP32[$3105 + ($3092 << 2) >> 2];
    __label__ = 688;
    break;
   case 687:
    var $3109 = __ZN8JSScript7getAtomEj($3093, $3092);
    var $atom_14 = $3109;
    __label__ = 688;
    break;
   case 688:
    var $atom_14;
    var $3112 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_14 | 0, 0);
    if (($3112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 689;
      break;
    }
   case 689:
    var $3118 = $3112 - HEAP32[$37 >> 2] | 0;
    HEAP32[$38 >> 2] = $3118;
    var $3119 = __ZL6PopStrP11SprintStack4JSOp($ss, 166);
    var $3120 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1122785 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3119, HEAP32[tempInt + 4 >> 2] = $3112, tempInt));
    HEAP32[$todo >> 2] = $3120;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3112;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 690:
    var $3122 = __ZL6PopStrP11SprintStack4JSOp($ss, 167);
    var $3123 = __ZL6PopStrP11SprintStack4JSOp($ss, 167);
    var $3124 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1132786 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3123, HEAP32[tempInt + 4 >> 2] = $3122, tempInt));
    HEAP32[$todo >> 2] = $3124;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3122;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 691:
    var $3126 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $3127 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1142787 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3126, tempInt));
    HEAP32[$todo >> 2] = $3127;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3126;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 692:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 693:
    var $3130 = __ZL6PopStrP11SprintStack4JSOp($ss, 170);
    var $3131 = __ZL6PopStrP11SprintStack4JSOp($ss, 170);
    var $3132 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str692742 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3131, HEAP32[tempInt + 4 >> 2] = $3130, tempInt));
    HEAP32[$todo >> 2] = $3132;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3130;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = 1;
    __label__ = 735;
    break;
   case 694:
    var $3134 = __ZL6PopStrP11SprintStack4JSOp($ss, 171);
    var $3135 = __ZL6PopStrP11SprintStack4JSOp($ss, 171);
    if (($quoteAttr_0 | 0) == 0) {
      __label__ = 696;
      break;
    } else {
      __label__ = 695;
      break;
    }
   case 695:
    var $3138 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1152788 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3135, HEAP32[tempInt + 4 >> 2] = $3134, tempInt));
    HEAP32[$todo >> 2] = $3138;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3134;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 696:
    var $3140 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1162789 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3135, HEAP32[tempInt + 4 >> 2] = $3134, tempInt));
    HEAP32[$todo >> 2] = $3140;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3134;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = 0;
    __label__ = 735;
    break;
   case 697:
    var $3142 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str93064 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $3142;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 698:
    var $3144 = __ZL6PopStrP11SprintStack4JSOp($ss, 173);
    var $3145 = __ZL6PopOffP11SprintStack4JSOp($ss, 173);
    var $3146 = __ZL6PopStrP11SprintStack4JSOp($ss, 173);
    var $op_8 = 173;
    var $cs_1 = $cs_0;
    var $lval_1 = $3146;
    var $rval_13 = $3144;
    __label__ = 389;
    break;
   case 699:
    var $3148 = __ZL6PopStrP11SprintStack4JSOp($ss, $op_2);
    var $3149 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1172790 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3148, tempInt));
    HEAP32[$todo >> 2] = $3149;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 1;
    var $quoteAttr_1 = 0;
    __label__ = 735;
    break;
   case 700:
    var $3151 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $3152 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1182791 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $3151, tempInt));
    HEAP32[$todo >> 2] = $3152;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 701:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = 0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 702:
    var $3155 = __ZL6PopStrP11SprintStack4JSOp($ss, 177);
    var $3160 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($3160 << 24 >> 24 == 58 || $3160 << 24 >> 24 == 123 || $3160 << 24 >> 24 == 108 || $3160 << 24 >> 24 == 79) {
      __label__ = 703;
      break;
    } else {
      __label__ = 704;
      break;
    }
   case 703:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 704;
    break;
   case 704:
    var $3163 = __ZL6PopStrP11SprintStack4JSOp($ss, 177);
    var $3164 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1192792 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3163, HEAP32[tempInt + 4 >> 2] = $3155, tempInt));
    HEAP32[$todo >> 2] = $3164;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3155;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 705:
    var $3166 = __ZL6PopStrP11SprintStack4JSOp($ss, 175);
    var $3171 = HEAP8[HEAP32[$36 >> 2] + (HEAP32[$30 >> 2] - 1) | 0];
    if ($3171 << 24 >> 24 == 58 || $3171 << 24 >> 24 == 123 || $3171 << 24 >> 24 == 108 || $3171 << 24 >> 24 == 79) {
      __label__ = 706;
      break;
    } else {
      __label__ = 707;
      break;
    }
   case 706:
    HEAP32[$saveop >> 2] = 58;
    __label__ = 707;
    break;
   case 707:
    var $3174 = __ZL6PopStrP11SprintStack4JSOp($ss, 175);
    var $3175 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1202793 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $3174, HEAP32[tempInt + 4 >> 2] = $3166, tempInt));
    HEAP32[$todo >> 2] = $3175;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3166;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 708:
    var $3177 = HEAP32[$_pre_phi >> 2];
    var $3178 = _js_GetIndexFromBytecode($8, $3177, $_1, 0);
    var $3179 = HEAPU32[$_pre_phi >> 2];
    var $3181 = HEAPU32[$3179 >> 2];
    if ($_1 >>> 0 < $3181 >>> 0) {
      __label__ = 710;
      break;
    } else {
      __label__ = 709;
      break;
    }
   case 709:
    if (($3181 + HEAP32[$3179 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 711;
      break;
    } else {
      __label__ = 710;
      break;
    }
   case 710:
    var $3190 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3191 = __ZN11JSAtomState16commonAtomsStartEv($3190);
    var $atom_15 = HEAP32[$3191 + ($3178 << 2) >> 2];
    __label__ = 712;
    break;
   case 711:
    var $3195 = __ZN8JSScript7getAtomEj($3179, $3178);
    var $atom_15 = $3195;
    __label__ = 712;
    break;
   case 712:
    var $atom_15;
    var $3197 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1212794 | 0, 9);
    HEAP32[$todo >> 2] = $3197;
    var $3199 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_15 | 0, 65536);
    if (($3199 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 713;
      break;
    }
   case 713:
    var $3202 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1222795 | 0, 3);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 714:
    var $3204 = HEAP32[$_pre_phi >> 2];
    var $3205 = _js_GetIndexFromBytecode($8, $3204, $_1, 0);
    var $3206 = HEAPU32[$_pre_phi >> 2];
    var $3208 = HEAPU32[$3206 >> 2];
    if ($_1 >>> 0 < $3208 >>> 0) {
      __label__ = 716;
      break;
    } else {
      __label__ = 715;
      break;
    }
   case 715:
    if (($3208 + HEAP32[$3206 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 717;
      break;
    } else {
      __label__ = 716;
      break;
    }
   case 716:
    var $3217 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3218 = __ZN11JSAtomState16commonAtomsStartEv($3217);
    var $atom_16 = HEAP32[$3218 + ($3205 << 2) >> 2];
    __label__ = 718;
    break;
   case 717:
    var $3222 = __ZN8JSScript7getAtomEj($3206, $3205);
    var $atom_16 = $3222;
    __label__ = 718;
    break;
   case 718:
    var $atom_16;
    var $3224 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1232796 | 0, 4);
    HEAP32[$todo >> 2] = $3224;
    var $3226 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_16 | 0, 65536);
    if (($3226 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 719;
      break;
    }
   case 719:
    var $3229 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1242797 | 0, 3);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 720:
    var $3231 = HEAP32[$_pre_phi >> 2];
    var $3232 = _js_GetIndexFromBytecode($8, $3231, $_1, 0);
    var $3233 = HEAPU32[$_pre_phi >> 2];
    var $3235 = HEAPU32[$3233 >> 2];
    if ($_1 >>> 0 < $3235 >>> 0) {
      __label__ = 722;
      break;
    } else {
      __label__ = 721;
      break;
    }
   case 721:
    if (($3235 + HEAP32[$3233 + 8 >> 2] | 0) >>> 0 > $_1 >>> 0) {
      __label__ = 723;
      break;
    } else {
      __label__ = 722;
      break;
    }
   case 722:
    var $3244 = HEAP32[$51 >> 2] + 209948 | 0;
    var $3245 = __ZN11JSAtomState16commonAtomsStartEv($3244);
    var $atom_17 = HEAP32[$3245 + ($3232 << 2) >> 2];
    __label__ = 724;
    break;
   case 723:
    var $3249 = __ZN8JSScript7getAtomEj($3233, $3232);
    var $atom_17 = $3249;
    __label__ = 724;
    break;
   case 724:
    var $atom_17;
    var $3251 = __ZL6PopStrP11SprintStack4JSOp($ss, 185);
    var $3252 = _JS_strdup($8, $3251);
    if (($3252 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 725;
      break;
    }
   case 725:
    var $3255 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1252798 | 0, 2);
    HEAP32[$todo >> 2] = $3255;
    var $3257 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($6, $atom_17 | 0, 0);
    if (($3257 | 0) == 0) {
      __label__ = 729;
      break;
    } else {
      __label__ = 726;
      break;
    }
   case 726:
    if (HEAP8[$3252] << 24 >> 24 == 0) {
      __label__ = 731;
      break;
    } else {
      __label__ = 727;
      break;
    }
   case 727:
    var $3263 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE._js_space_str | 0, 1);
    if (($3263 | 0) > -1) {
      __label__ = 728;
      break;
    } else {
      __label__ = 730;
      break;
    }
   case 728:
    var $3266 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($6, $3252);
    var $3267 = ($3266 | 0) == 0;
    __ZN9JSContext5free_EPv(undef, $3252);
    if ($3267) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 732;
      break;
    }
   case 729:
    __ZN9JSContext5free_EPv(undef, $3252);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 730:
    __ZN9JSContext5free_EPv(undef, $3252);
    var $_0 = 0;
    __label__ = 742;
    break;
   case 731:
    __ZN9JSContext5free_EPv(undef, $3252);
    __label__ = 732;
    break;
   case 732:
    var $3269 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1262799 | 0, 2);
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $3252;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 733:
    var $3271 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE._js_function_str | 0, 8);
    HEAP32[$todo >> 2] = $3271;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 734:
    HEAP32[$todo >> 2] = -2;
    var $_16 = $_1;
    var $len_10 = $89;
    var $cs_3 = $cs_0;
    var $rval_18 = $rval_0;
    var $foreach_1 = $foreach_0;
    var $inXML_1 = $inXML_0;
    var $quoteAttr_1 = $quoteAttr_0;
    __label__ = 735;
    break;
   case 735:
    var $quoteAttr_1;
    var $inXML_1;
    var $foreach_1;
    var $rval_18;
    var $cs_3;
    var $len_10;
    var $_16;
    var $3273 = HEAP32[$todo >> 2];
    if (($3273 | 0) < 0) {
      __label__ = 736;
      break;
    } else {
      __label__ = 737;
      break;
    }
   case 736:
    if (($3273 | 0) == -1) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 737:
    var $3278 = HEAP32[$saveop >> 2];
    var $3279 = __ZL7PushOffP11SprintStacki4JSOp($ss, $3273, $3278);
    if (($3279 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 738;
      break;
    }
   case 738:
    if ((HEAP32[$cs_3 + 4 >> 2] & 524288 | 0) == 0) {
      __label__ = 741;
      break;
    } else {
      __label__ = 739;
      break;
    }
   case 739:
    var $3287 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, __str93064 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    HEAP32[$todo >> 2] = $3287;
    if (($3287 | 0) < 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 740;
      break;
    }
   case 740:
    var $3290 = HEAP32[$saveop >> 2];
    var $3291 = __ZL7PushOffP11SprintStacki4JSOp($ss, $3287, $3290);
    if (($3291 | 0) == 0) {
      var $_0 = 0;
      __label__ = 742;
      break;
    } else {
      __label__ = 741;
      break;
    }
   case 741:
    var $_016 = $_16 + $len_10 | 0;
    var $rval_0 = $rval_18;
    var $foreach_0 = $foreach_1;
    var $inXML_0 = $inXML_1;
    var $quoteAttr_0 = $quoteAttr_1;
    __label__ = 7;
    break;
   case 742:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9DecompileP11SprintStackPhi4JSOp["X"] = 1;

function _JSVAL_TO_INT32_IMPL2866($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL15IsInitializerOph($op) {
  return ($op - 89 & 255 & 255) < 3;
}

function _JSVAL_IS_STRING_IMPL2869($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_IS_DOUBLE_IMPL2870($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_TO_STRING_IMPL2873($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSDOUBLE_IS_NEGZERO2875($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18JSDOUBLE_IS_FINITEd2876($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd2877($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL9IsVarSlotP9JSPrinterPhPi($jp, $pc_1_val, $pc_2_val, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = ($pc_1_val & 255) << 8 | $pc_2_val & 255;
    var $9 = HEAPU16[HEAP32[$jp + 56 >> 2] + 14 >> 1] & 65535;
    if ($4 >>> 0 < $9 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = 1;
    var $storemerge = (HEAPU16[HEAP32[$jp + 68 >> 2] + 56 >> 1] & 65535) + $4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $_0 = 0;
    var $storemerge = $4 - $9 | 0;
    __label__ = 4;
    break;
   case 4:
    var $storemerge;
    var $_0;
    HEAP32[$indexp >> 2] = $storemerge;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18GetDecomposeLengthEPhj2861($pc, $len) {
  return HEAPU8[$pc + ($len - 1) | 0] & 255;
}

function __ZL14CompareOffsetsPvPKvS1_Pi($arg, $v1, $v2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$v1 + 8 >> 2];
    var $6 = HEAP32[$v2 + 8 >> 2];
    if (($3 | 0) == ($6 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $21 = HEAP32[$v1 + 16 >> 2] - HEAP32[$v2 + 16 >> 2] | 0;
    __label__ = 4;
    break;
   case 3:
    var $21 = $3 - $6 >> 31 | 1;
    __label__ = 4;
    break;
   case 4:
    var $21;
    HEAP32[$result >> 2] = $21;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL2872($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL6PopOffP11SprintStack4JSOp($ss, $op) {
  var $2 = HEAP8[_js_CodeSpec + ($op << 3) + 3 | 0];
  var $3 = __ZL10PopOffPrecP11SprintStackh($ss, $2);
  return $3;
}

function __ZL10PopOffPrecP11SprintStackh($ss, $prec) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 28 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - 1 | 0;
    HEAP32[$1 >> 2] = $5;
    var $6 = __ZL6GetOffP11SprintStackj($ss, $5);
    var $13 = HEAPU8[_js_CodeSpec + ((HEAPU8[HEAP32[$ss + 24 >> 2] + $5 | 0] & 255) << 3) + 3 | 0];
    if ($13 << 24 >> 24 != 0 & ($13 & 255) < ($prec & 255)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $17 = $6 - 2 | 0;
    var $20 = HEAP32[$ss + 20 >> 2] + ($5 << 2) | 0;
    HEAP32[$20 >> 2] = $17;
    var $21 = $ss | 0;
    HEAP32[$ss + 16 >> 2] = $17;
    var $25 = HEAP32[$ss + 8 >> 2] + $6 | 0;
    var $26 = __ZN2js6SprintEPNS_8SprinterEPKcz($21, STRING_TABLE.__str392712 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $25, tempInt));
    var $_0 = $26;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$ss + 16 >> 2] = $6;
    var $_0 = $6;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6GetOffP11SprintStackj($ss, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 20 | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + ($i << 2) >> 2];
    if (($4 | 0) > -1) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($4 | 0) < -1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $10 = HEAP32[$ss + 40 >> 2];
    var $12 = HEAP32[$10 + 64 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$12 + (-2 - $4 << 2) >> 2];
    var $18 = $ss | 0;
    var $20 = HEAP32[$ss >> 2];
    var $22 = HEAP32[$10 + 56 >> 2];
    var $24 = HEAP32[$10 + 68 >> 2];
    var $25 = __ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh($20, $22, $24, $17);
    var $magicptr = $25;
    if (($magicptr | 0) == 1) {
      __label__ = 6;
      break;
    } else if (($magicptr | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($18, $25);
    var $off_0 = ($27 | 0) < 0 ? 0 : $27;
    var $30 = HEAP32[$1 >> 2] + ($i << 2) | 0;
    HEAP32[$30 >> 2] = $off_0;
    __ZN9JSContext5free_EPv(undef, $25);
    var $_0 = $off_0;
    __label__ = 9;
    break;
   case 6:
    var $32 = $ss + 8 | 0;
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $36 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($18, __str93064 | 0, 0);
    if (($36 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$32 >> 2];
    var $41 = HEAP32[$ss + 16 >> 2];
    _memset($39, 0, $41, 1);
    var $43 = HEAP32[$1 >> 2] + ($i << 2) | 0;
    HEAP32[$43 >> 2] = -1;
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6GetOffP11SprintStackj["X"] = 1;

function __ZL10PopStrPrecP11SprintStackh($ss, $prec) {
  var $1 = __ZL10PopOffPrecP11SprintStackh($ss, $prec);
  return HEAP32[$ss + 8 >> 2] + $1 | 0;
}

function __ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi($ss, $pc, $endpc, $sn, $todop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $hole = __stackBase__;
    var $1 = HEAPU8[$pc];
    var $4 = HEAP8[_js_CodeSpec + (($1 & 255) << 3) | 0];
    if ($1 << 24 >> 24 == 86 || $1 << 24 >> 24 == 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 2:
    var $6 = $ss | 0;
    var $7 = __ZL9VarPrefixPh($sn);
    var $8 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, STRING_TABLE.__str1362809 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $7, tempInt));
    if (($8 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZL7PushOffP11SprintStacki4JSOp($ss, $8, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $ss + 16 | 0;
    var $16 = HEAP32[$14 >> 2] - 3 | 0;
    HEAP32[$14 >> 2] = $16;
    var $_04 = $pc;
    var $oplen_0_in = $4;
    __label__ = 5;
    break;
   case 5:
    var $oplen_0_in;
    var $_04;
    var $17 = $_04 + ($oplen_0_in << 24 >> 24) | 0;
    if (($17 | 0) == ($endpc | 0)) {
      var $_0 = $17;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $17, $endpc, $hole);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($20 | 0) == ($endpc | 0)) {
      var $_0 = $20;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = HEAPU8[$20];
    var $28 = HEAP8[_js_CodeSpec + (($25 & 255) << 3) | 0];
    if ($25 << 24 >> 24 == 86 || $25 << 24 >> 24 == 1) {
      __label__ = 9;
      break;
    } else if ($25 << 24 >> 24 == 11) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    if ((HEAP32[$hole >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_04 = $20;
      var $oplen_0_in = $28;
      __label__ = 5;
      break;
    }
   case 10:
    var $33 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str332706 | 0, 2);
    if (($33 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $_04 = $20;
      var $oplen_0_in = $28;
      __label__ = 5;
      break;
    }
   case 11:
    var $36 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str1372810 | 0, 5);
    if (($36 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = $ss + 28 | 0;
    var $40 = HEAPU32[$39 >> 2];
    var $41 = $40 - 1 | 0;
    var $50 = $41 - ((HEAPU8[$20 + 1 | 0] & 255) << 8 | HEAPU8[$20 + 2 | 0] & 255) | 0;
    var $51 = $40 - 2 | 0;
    var $i_0 = $50;
    __label__ = 13;
    break;
   case 13:
    var $i_0;
    if ($i_0 >>> 0 < $41 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    var $55 = __ZL6GetStrP11SprintStackj($ss, $i_0);
    var $57 = ($i_0 | 0) == ($50 | 0) ? STRING_TABLE.__str382711 | 0 : STRING_TABLE.__str1382811 | 0;
    if (($i_0 | 0) == ($51 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if (HEAP8[$55] << 24 >> 24 == 0) {
      var $64 = STRING_TABLE.__str332706 | 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = $55;
    __label__ = 17;
    break;
   case 17:
    var $64;
    var $65 = __ZN2js6SprintEPNS_8SprinterEPKcz($6, $57, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $64, tempInt));
    if (($65 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 19:
    var $70 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($6, STRING_TABLE.__str562729 | 0, 1);
    if (($70 | 0) < 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $76 = HEAP32[HEAP32[$ss + 20 >> 2] + ($i_0 << 2) >> 2];
    HEAP32[$14 >> 2] = $76;
    HEAP32[$39 >> 2] = $50;
    HEAP32[$todop >> 2] = $8;
    var $_0 = $20;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi["X"] = 1;

function __ZL7PushOffP11SprintStacki4JSOp($ss, $off, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss | 0;
    var $2 = __ZL18SprintEnsureBufferPN2js8SprinterEj($1, 3);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $ss + 28 | 0;
    var $6 = HEAPU32[$5 >> 2];
    var $10 = HEAP32[HEAP32[$ss + 40 >> 2] + 56 >> 2];
    var $_idx_val = HEAP16[$10 + 14 >> 1];
    var $_idx1_val = HEAP16[$10 + 44 >> 1];
    var $11 = __ZL10StackDepthP8JSScript($_idx_val, $_idx1_val);
    if ($6 >>> 0 < $11 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAP32[$ss >> 2];
    _JS_ReportOutOfMemory($15);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $19 = HEAP32[$ss + 20 >> 2] + ($6 << 2) | 0;
    HEAP32[$19 >> 2] = $off;
    if (($op | 0) == 232) {
      var $25 = 53;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $phitmp = ($op | 0) == 233 ? 55 : $op & 255;
    var $25 = $phitmp;
    __label__ = 6;
    break;
   case 6:
    var $25;
    HEAP8[HEAP32[$ss + 24 >> 2] + $6 | 0] = $25;
    HEAP32[$5 >> 2] = $6 + 1 | 0;
    __ZL12AddParenSlopP11SprintStack($ss);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9VarPrefixPh($sn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($sn | 0) == 0) {
      var $_0 = __str93064 | 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = HEAPU8[$sn];
    var $_mask = $3 & -8;
    if (($3 & 255) < 192 & ($_mask << 24 >> 24 == 48 | $_mask << 24 >> 24 == 56)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = __str93064 | 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = _js_GetSrcNoteOffset($sn, 0);
    if ($6 >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      var $_0 = __str93064 | 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[__ZL10var_prefix + ($6 << 2) >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12AddParenSlopP11SprintStack($ss) {
  var $3 = $ss + 16 | 0;
  var $5 = HEAP32[$ss + 8 >> 2] + HEAP32[$3 >> 2] | 0;
  HEAP8[$5] = 0;
  HEAP8[$5 + 1] = 0;
  HEAP8[$5 + 2] = 0;
  var $7 = HEAP32[$3 >> 2] + 3 | 0;
  HEAP32[$3 >> 2] = $7;
  return;
}

function _DOUBLE_TO_JSVAL2862($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($sp, $_0_0_0_val$0, $_0_0_0_val$1, $opp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cbuf = __stackBase__;
    var $1 = _JSVAL_TO_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1);
    var $2 = _JSDOUBLE_IS_NEGZERO2875($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, STRING_TABLE.__str1292802 | 0);
    HEAP32[$opp >> 2] = 34;
    var $_1 = $5;
    __label__ = 10;
    break;
   case 3:
    var $7 = __ZL18JSDOUBLE_IS_FINITEd2876($1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = __ZL15JSDOUBLE_IS_NaNd2877($1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $16 = STRING_TABLE.__str1302803 | 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $1 < 0 ? STRING_TABLE.__str1312804 | 0 : STRING_TABLE.__str1322805 | 0;
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    var $17 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($sp, $16);
    HEAP32[$opp >> 2] = 30;
    var $_1 = $17;
    __label__ = 10;
    break;
   case 7:
    __ZN2js12ToCStringBufC2Ev($cbuf);
    var $19 = $sp | 0;
    var $20 = HEAP32[$19 >> 2];
    var $21 = __ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi($20, $cbuf, $1, 10);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $23 = HEAP32[$19 >> 2];
    _JS_ReportOutOfMemory($23);
    __ZN2js12ToCStringBufD2Ev($cbuf);
    var $_1 = -1;
    __label__ = 10;
    break;
   case 9:
    var $25 = __ZN2js6SprintEPNS_8SprinterEPKcz($sp, $21, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __ZN2js12ToCStringBufD2Ev($cbuf);
    var $_1 = $25;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject2863($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function _JSVAL_TO_STRING2864($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL2873($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _INT_TO_JSVAL2865($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL2872($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout2871($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii($ss, $table, $tableLength, $pc, $switchLength, $defaultOffset, $isCondSwitch) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $junk = __stackBase__ + 8;
    var $1 = $ss | 0;
    var $3 = HEAP32[$ss >> 2];
    var $5 = HEAPU32[$ss + 40 >> 2];
    var $6 = ($isCondSwitch | 0) != 0;
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$ss + 28 >> 2] - 1 | 0;
    var $11 = __ZL6GetOffP11SprintStackj($ss, $10);
    var $15 = $11;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZL6PopOffP11SprintStack4JSOp($ss, 0);
    var $15 = $13;
    __label__ = 4;
    break;
   case 4:
    var $15;
    var $16 = $ss + 8 | 0;
    var $18 = HEAP32[$16 >> 2] + $15 | 0;
    var $19 = _js_printf($5, STRING_TABLE.__str1272800 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $18, tempInt));
    if (($tableLength | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = HEAP32[$table + 8 >> 2] - $defaultOffset | 0;
    var $26 = $5 + 48 | 0;
    if (($24 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $_pre_phi = $26;
      __label__ = 8;
      break;
    }
   case 6:
    var $29 = HEAP32[$26 >> 2] + 2 | 0;
    HEAP32[$26 >> 2] = $29;
    var $30 = _js_printf($5, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $32 = HEAP32[$26 >> 2] + 2 | 0;
    HEAP32[$26 >> 2] = $32;
    var $33 = $pc + $defaultOffset | 0;
    var $34 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $33, $24);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $38 = HEAP32[$26 >> 2] - 4 | 0;
    HEAP32[$26 >> 2] = $38;
    var $_pre_phi = $26;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $40 = $key | 0;
    var $41 = $ss + 28 | 0;
    var $42 = $3;
    var $43 = $ss + 16 | 0;
    var $i_0 = 0;
    var $caseExprOff_0 = $6 & 1;
    __label__ = 9;
    break;
   case 9:
    var $caseExprOff_0;
    var $i_0;
    if ($i_0 >>> 0 < $tableLength >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 10:
    var $47 = HEAP32[$table + $i_0 * 24 + 8 >> 2];
    var $48 = $i_0 + 1 | 0;
    if ($48 >>> 0 < $tableLength >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $54 = $switchLength;
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[$table + $48 * 24 + 8 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $54;
    var $55 = $table + $i_0 * 24 | 0;
    var $st$2$0 = $55 | 0;
    var $56$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $55 + 4 | 0;
    var $56$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $40 | 0;
    HEAP32[$st$6$0 >> 2] = $56$0;
    var $st$6$1 = $40 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $56$1;
    if ($6) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $58 = _JSVAL_TO_INT($56$0, $56$1);
    var $65 = (HEAP8[_js_CodeSpec + ((HEAPU8[$pc + $58 | 0] & 255) << 3) | 0] << 24 >> 24) + $58 | 0;
    var $67 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $67;
    var $68 = $pc + $caseExprOff_0 | 0;
    var $69 = $65 - $caseExprOff_0 | 0;
    var $70 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $68, $69);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $74 = HEAP32[$41 >> 2] - 1 | 0;
    HEAP32[$41 >> 2] = $74;
    var $caseExprOff_1 = $65;
    __label__ = 25;
    break;
   case 15:
    var $77 = HEAP32[$table + $i_0 * 24 + 12 >> 2];
    if (($77 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $80 = $77 | 0;
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$2$0 = $$emscripten$temp$0 | 0;
    var $81$0 = HEAPU32[$st$2$0 >> 2];
    var $st$2$1 = $$emscripten$temp$0 + 4 | 0;
    var $81$1 = HEAPU32[$st$2$1 >> 2];
    var $st$6$0 = $40 | 0;
    HEAP32[$st$6$0 >> 2] = $81$0;
    var $st$6$1 = $40 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $81$1;
    var $str_0_ph = $80;
    var $95$1 = $81$1;
    var $95$0 = $81$0;
    __label__ = 22;
    break;
   case 17:
    var $83 = _JSVAL_IS_DOUBLE($56$0, $56$1);
    if (($83 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $86 = __ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp($1, $56$0, $56$1, $junk);
    if (($86 | 0) < 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $89 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($42, $key);
    if (($89 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $str_0_ph = $89;
    var $95$1 = HEAP32[$40 + 4 >> 2];
    var $95$0 = HEAP32[$40 >> 2];
    __label__ = 22;
    break;
   case 21:
    var $92 = HEAP32[$16 >> 2];
    var $rval_0 = $92 + $86 | 0;
    var $102 = $92;
    __label__ = 24;
    break;
   case 22:
    var $95$0;
    var $95$1;
    var $str_0_ph;
    var $96 = _JSVAL_IS_STRING2868($95$0, $95$1);
    var $98 = ($96 | 0) != 0 ? 34 : 0;
    var $99 = __ZL11QuoteStringPN2js8SprinterEP8JSStringj($1, $str_0_ph, $98);
    if (($99 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $rval_0 = $99;
    var $102 = HEAP32[$16 >> 2];
    __label__ = 24;
    break;
   case 24:
    var $102;
    var $rval_0;
    HEAP32[$43 >> 2] = $rval_0 - $102 | 0;
    var $107 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $107;
    var $108 = _js_printf($5, STRING_TABLE.__str982771 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $rval_0, tempInt));
    var $caseExprOff_1 = $caseExprOff_0;
    __label__ = 25;
    break;
   case 25:
    var $caseExprOff_1;
    var $111 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $111;
    if (($47 | 0) <= ($defaultOffset | 0) & ($54 | 0) > ($defaultOffset | 0)) {
      __label__ = 26;
      break;
    } else {
      var $off_1 = $47;
      __label__ = 30;
      break;
    }
   case 26:
    if (($47 | 0) == ($defaultOffset | 0)) {
      var $off_0 = $47;
      var $122 = $111;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $117 = $defaultOffset - $47 | 0;
    var $118 = $pc + $47 | 0;
    var $119 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $118, $117);
    if (($119 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $off_0 = $defaultOffset;
    var $122 = HEAP32[$_pre_phi >> 2];
    __label__ = 29;
    break;
   case 29:
    var $122;
    var $off_0;
    HEAP32[$_pre_phi >> 2] = $122 - 2 | 0;
    var $124 = _js_printf($5, STRING_TABLE.__str472720 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $126 = HEAP32[$_pre_phi >> 2] + 2 | 0;
    HEAP32[$_pre_phi >> 2] = $126;
    var $off_1 = $off_0;
    __label__ = 30;
    break;
   case 30:
    var $off_1;
    var $128 = $pc + $off_1 | 0;
    var $130 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $128, $54 - $off_1 | 0);
    if (($130 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $134 = HEAP32[$_pre_phi >> 2] - 4 | 0;
    HEAP32[$_pre_phi >> 2] = $134;
    if ($6) {
      __label__ = 32;
      break;
    } else {
      var $i_0 = $48;
      var $caseExprOff_0 = $caseExprOff_1;
      __label__ = 9;
      break;
    }
   case 32:
    var $137 = HEAP32[$41 >> 2] + 1 | 0;
    HEAP32[$41 >> 2] = $137;
    var $i_0 = $48;
    var $caseExprOff_0 = $caseExprOff_1;
    __label__ = 9;
    break;
   case 33:
    if (($defaultOffset | 0) == ($switchLength | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $140 = $5 + 48 | 0;
    var $142 = HEAP32[$140 >> 2] + 2 | 0;
    HEAP32[$140 >> 2] = $142;
    var $143 = _js_printf($5, STRING_TABLE.__str1282801 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_default_str | 0, tempInt));
    var $145 = HEAP32[$140 >> 2] - 2 | 0;
    HEAP32[$140 >> 2] = $145;
    __label__ = 35;
    break;
   case 35:
    var $147 = _js_printf($5, STRING_TABLE.__str462719 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($6) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 36:
    var $149 = $ss + 28 | 0;
    var $151 = HEAP32[$149 >> 2] - 1 | 0;
    HEAP32[$149 >> 2] = $151;
    var $_0 = 1;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii["X"] = 1;

function _JSVAL_TO_INT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL2866($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_DOUBLE_IMPL2870($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_STRING2868($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL2869($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_DOUBLE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE2867($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSID_TO_STRING2878($iden) {
  return $iden;
}

function _JSID_IS_STRING2879($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js6Parser13setPrincipalsEP12JSPrincipals($this, $prin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($prin | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $prin + 12 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 956 >> 2] = $prin;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSFunctionBox17inAnyDynamicScopeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funbox_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $funbox_0;
    if (($funbox_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$funbox_0 + 60 >> 2] & 805306368 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $funbox_0 = HEAP32[$funbox_0 + 36 >> 2];
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13JSFunctionBox17scopeIsExtensibleEv($this) {
  return (HEAP32[$this + 60 >> 2] & 536870912 | 0) != 0;
}

function __ZNK13JSFunctionBox13shouldUnbrandEjj($this, $methods, $slowMethods) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($slowMethods | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      var $funbox_0 = $this;
      __label__ = 2;
      break;
    }
   case 2:
    var $funbox_0;
    if (($funbox_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$funbox_0 + 60 >> 2] & 2097152 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$funbox_0 + 56 >> 2] & 2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $funbox_0 = HEAP32[$funbox_0 + 36 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi($ss, $pc, $endpc, $hole) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $bytes = __stackBase__ + 4;
    HEAP32[$hole >> 2] = 0;
    var $1 = $ss | 0;
    var $3 = HEAP32[$ss >> 2];
    var $5 = HEAP32[$ss + 40 >> 2];
    var $6 = HEAPU8[$pc];
    var $7 = $6 & 255;
    var $10 = HEAP8[_js_CodeSpec + ($7 << 3) | 0] << 24 >> 24;
    if (($7 | 0) == 81) {
      __label__ = 2;
      break;
    } else if (($7 | 0) == 12) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == 85 || ($7 | 0) == 87) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == 132) {
      __label__ = 8;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    HEAP32[$hole >> 2] = 1;
    var $12 = __ZN2js9SprintPutEPNS_8SprinterEPKcj($1, STRING_TABLE.__str332706 | 0, 2);
    var $_03 = $pc;
    var $todo_1 = $12;
    var $oplen_0 = $10;
    __label__ = 28;
    break;
   case 3:
    var $14 = __ZL22DecompileDestructuringP11SprintStackPhS1_($ss, $pc, $endpc);
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($14 | 0) == ($endpc | 0)) {
      var $_1 = $14;
      __label__ = 30;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = HEAPU8[$14];
    var $22 = HEAP8[_js_CodeSpec + (($19 & 255) << 3) | 0];
    var $23 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $24 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $23);
    if ($19 << 24 >> 24 == 11) {
      var $_1 = $14;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAP8[$14] << 24 >> 24 == 81) {
      var $_03 = $14;
      var $todo_1 = $24;
      var $oplen_0 = $22 << 24 >> 24;
      __label__ = 28;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    var $32 = HEAP8[$pc + $10 | 0];
    if ($32 << 24 >> 24 == 81 || $32 << 24 >> 24 == 11) {
      __label__ = 8;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 8:
    var $36 = HEAPU8[$pc + 1 | 0];
    if ($6 << 24 >> 24 == 85) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $43 = ($36 & 255) << 8 | HEAPU8[$pc + 2 | 0] & 255;
    var $44 = __ZL15GetArgOrVarAtomP9JSPrinterj($5, $43);
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $atom_0_ph = $44;
      __label__ = 13;
      break;
    }
   case 10:
    var $pc_idx1_val = HEAP8[$pc + 2 | 0];
    var $47 = __ZL9IsVarSlotP9JSPrinterPhPi($5, $36, $pc_idx1_val, $i);
    var $49 = HEAP32[$i >> 2];
    if (($47 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = __ZL15GetArgOrVarAtomP9JSPrinterj($5, $49);
    if (($51 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $atom_0_ph = $51;
      __label__ = 13;
      break;
    }
   case 12:
    var $54 = __Z8GetLocalP11SprintStacki($ss, $49);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $lval_1 = $54;
    __label__ = 14;
    break;
   case 13:
    var $atom_0_ph;
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $56 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($3, $atom_0_ph, $bytes);
    var $lval_1 = $56;
    __label__ = 14;
    break;
   case 14:
    var $lval_1;
    if (($lval_1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_1 = 0;
    __label__ = 30;
    break;
   case 16:
    var $60 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $lval_1);
    __ZN16JSAutoByteStringD1Ev($bytes);
    if ($6 << 24 >> 24 == -124) {
      var $_03 = $pc;
      var $todo_1 = $60;
      var $oplen_0 = $10;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = $pc + $10 | 0;
    if (($63 | 0) == ($endpc | 0)) {
      var $_1 = $63;
      __label__ = 30;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $66 = HEAPU8[$63];
    if ($66 << 24 >> 24 == 11) {
      var $_1 = $63;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($66 << 24 >> 24 == 81) {
      var $_03 = $63;
      var $todo_1 = $60;
      var $oplen_0 = HEAP8[_js_CodeSpec + (($66 & 255) << 3) | 0] << 24 >> 24;
      __label__ = 28;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 20:
    var $75 = $ss + 16 | 0;
    var $76 = HEAPU32[$75 >> 2];
    HEAP32[$75 >> 2] = $76 + 3 | 0;
    var $78 = $ss + 28 | 0;
    var $80 = -HEAP32[$78 >> 2] | 0;
    var $81 = __ZL9DecompileP11SprintStackPhi4JSOp($ss, $pc, $80);
    if (($81 | 0) == 0) {
      var $_1 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if (($81 | 0) == ($endpc | 0)) {
      var $_1 = $81;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $86 = HEAPU8[$81];
    var $90 = HEAP8[_js_CodeSpec + (($86 & 255) << 3) | 0] << 24 >> 24;
    if ($86 << 24 >> 24 == -47 || $86 << 24 >> 24 == 124) {
      __label__ = 23;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 23:
    var $92 = __ZL6PopStrP11SprintStack4JSOp($ss, 0);
    var $93 = __ZL6PopStrP11SprintStack4JSOp($ss, 53);
    HEAP32[$75 >> 2] = $76;
    if (HEAP8[$93] << 24 >> 24 == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $97 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $92);
    var $_03 = $81;
    var $todo_1 = $97;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 25:
    if (HEAP8[$92] << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $102 = __ZN2js13SprintCStringEPNS_8SprinterEPKc($1, $93);
    var $_03 = $81;
    var $todo_1 = $102;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 27:
    var $113 = ((HEAPU8[HEAP32[$ss + 24 >> 2] + (HEAP32[$78 >> 2] + 1) | 0] & 255) - 164 | 0) >>> 0 < 5 ? STRING_TABLE.__str1392812 | 0 : STRING_TABLE.__str1402813 | 0;
    var $114 = __ZN2js6SprintEPNS_8SprinterEPKcz($1, $113, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $93, HEAP32[tempInt + 4 >> 2] = $92, tempInt));
    var $_03 = $81;
    var $todo_1 = $114;
    var $oplen_0 = $90;
    __label__ = 28;
    break;
   case 28:
    var $oplen_0;
    var $todo_1;
    var $_03;
    if (($todo_1 | 0) > -1 & $_03 >>> 0 < $endpc >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 29:
    var $_1 = $_03 + $oplen_0 | 0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi["X"] = 1;

function __ZN19AutoScriptUntrapperD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $4 = HEAP32[$this + 8 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $this + 4 | 0;
    var $12 = HEAP32[HEAP32[$9 >> 2] >> 2];
    var $14 = $12 + ($4 - $2) | 0;
    __ZN9JSContext5free_EPv(undef, $12);
    var $16 = HEAP32[$9 >> 2] | 0;
    HEAP32[$16 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh($this, $cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    HEAP32[$this + 4 >> 2] = $script;
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$pc >> 2];
    HEAP32[$3 >> 2] = $4;
    var $5 = $cx;
    var $6 = $script;
    var $7 = _js_UntrapScriptCode($5, $6);
    var $8 = $script | 0;
    var $9 = HEAP32[$8 >> 2];
    var $11 = HEAP32[$3 >> 2];
    if (($7 | 0) == ($9 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 12 >> 2] = $11;
    __label__ = 4;
    break;
   case 3:
    var $18 = $11 + ($7 - $9) | 0;
    HEAP32[$this + 12 >> 2] = $18;
    HEAP32[$pc >> 2] = $18;
    HEAP32[$8 >> 2] = $7;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode6becomeEPS_($this, $pn2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn2);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $22 = HEAP32[$pn2 >> 2];
    var $_pre_phi = $this;
    __label__ = 6;
    break;
   case 3:
    var $5 = HEAP32[$pn2 + 36 >> 2] + 28 | 0;
    var $6 = HEAP32[$5 >> 2];
    if (($6 | 0) == ($pn2 | 0)) {
      var $pnup_0_lcssa = $5;
      __label__ = 5;
      break;
    } else {
      var $8 = $6;
      __label__ = 4;
      break;
    }
   case 4:
    var $8;
    var $9 = $8 + 28 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == ($pn2 | 0)) {
      var $pnup_0_lcssa = $9;
      __label__ = 5;
      break;
    } else {
      var $8 = $10;
      __label__ = 4;
      break;
    }
   case 5:
    var $pnup_0_lcssa;
    HEAP32[$pnup_0_lcssa >> 2] = $this;
    var $12 = $pn2 + 28 | 0;
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$this + 28 >> 2] = $13;
    var $15 = $this;
    var $17 = HEAP32[$15 >> 2] | 1073741824;
    HEAP32[$15 >> 2] = $17;
    HEAP32[$12 >> 2] = 0;
    var $18 = $pn2;
    var $20 = HEAP32[$18 >> 2] & -1073741825;
    HEAP32[$18 >> 2] = $20;
    var $22 = $20;
    var $_pre_phi = $15;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $22;
    var $23 = $pn2;
    var $27 = HEAP32[$_pre_phi >> 2] & -65536 | $22 & 65535;
    HEAP32[$_pre_phi >> 2] = $27;
    var $31 = $27 & -16711681 | HEAP32[$23 >> 2] & 16711680;
    HEAP32[$_pre_phi >> 2] = $31;
    var $33 = HEAP32[$23 >> 2] & 520093696;
    var $35 = $31 & -520093697 | $33;
    HEAP32[$_pre_phi >> 2] = $35;
    var $39 = $35 & -536870913 | HEAP32[$23 >> 2] & 536870912;
    HEAP32[$_pre_phi >> 2] = $39;
    var $40 = $this + 32 | 0;
    var $42 = $40;
    var $43 = $pn2 + 32 | 0;
    HEAP32[$42 >> 2] = HEAP32[$43 >> 2];
    HEAP32[$42 + 4 >> 2] = HEAP32[$43 + 4 >> 2];
    HEAP32[$42 + 8 >> 2] = HEAP32[$43 + 8 >> 2];
    HEAP32[$42 + 12 >> 2] = HEAP32[$43 + 12 >> 2];
    var $44 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($this, 34);
    if ($44) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $46 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($this, 4);
    if ($46) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $50 = HEAP32[$40 >> 2] + 24 | 0;
    HEAP32[$50 >> 2] = $this;
    __label__ = 12;
    break;
   case 9:
    if (($33 | 0) == 83886080) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $54 = $40 | 0;
    if ((HEAP32[$54 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$this + 36 >> 2] = $54;
    __label__ = 12;
    break;
   case 12:
    __ZN11JSParseNode5clearEv($pn2);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode6becomeEPS_["X"] = 1;

function __ZN11JSParseNode5clearEv($this) {
  var $1 = $this;
  var $3 = HEAP32[$1 >> 2] & -65536;
  HEAP32[$1 >> 2] = $3;
  __ZN11JSParseNode5setOpE4JSOp($this, 0);
  var $5 = HEAP32[$1 >> 2] & 16777215;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($this, $cx, $prin, $cfp, $foldConstants) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -3);
    HEAP32[$this + 12 >> 2] = $cx;
    var $3 = $this + 40 | 0;
    __ZN2js11TokenStreamC2EP9JSContext($3, $cx);
    HEAP32[$this + 956 >> 2] = 0;
    HEAP32[$this + 960 >> 2] = $cfp;
    var $6 = $this + 964 | 0;
    if (($cfp | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js10StackFrame6varObjEv($cfp);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    HEAP32[$6 >> 2] = $11;
    HEAP32[$this + 968 >> 2] = 0;
    HEAP32[$this + 972 >> 2] = 0;
    HEAP32[$this + 976 >> 2] = 0;
    HEAP32[$this + 980 >> 2] = 0;
    var $16 = $this + 984 | 0;
    var $18 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($16, $18);
    HEAP8[$this + 988 | 0] = $foldConstants & 1;
    var $21 = $cx + 308 | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $24 = $this + 16 | 0;
    __ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_($24);
    __ZN2js6Parser13setPrincipalsEP12JSPrincipals($this, $prin);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 24, 1);
  return;
}

function __ZN2js6Parser4initEPKtjPKcj9JSVersion($this, $base, $length, $filename, $lineno, $version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 12 >> 2];
    var $3 = __ZN9JSContext18ensureParseMapPoolEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$2 + 88 >> 2] + 12 >> 2];
    HEAP32[$this + 952 >> 2] = $9;
    var $11 = $this + 40 | 0;
    var $12 = __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($11, $base, $length, $filename, $lineno, $version);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext18ensureParseMapPoolEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 100 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_($this);
    HEAP32[$1 >> 2] = $5;
    var $_0 = ($5 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6ParserD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $3 = $this + 956 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 + 12 | 0;
    var $9 = HEAP32[$7 >> 2] - 1 | 0;
    HEAP32[$7 >> 2] = $9;
    var $11 = HEAP32[$3 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[$11 + 16 >> 2];
    FUNCTION_TABLE[$14]($2, $11);
    __label__ = 4;
    break;
   case 4:
    var $17 = HEAPU32[$this + 952 >> 2];
    var $18 = $2 + 72 | 0;
    var $20 = HEAP32[$2 + 88 >> 2];
    if (($20 | 0) == ($18 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $17;
    var $26 = HEAP32[$20 + 4 >> 2];
    var $28 = $20 + 12 | 0;
    if (($24 - $26 | 0) >>> 0 > (HEAP32[$28 >> 2] - $26 | 0) >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = HEAP32[$2 + 96 >> 2];
    var $37 = $34 + $24 & ($34 ^ -1);
    HEAP32[$28 >> 2] = $37;
    __label__ = 8;
    break;
   case 7:
    _JS_ArenaRelease($18, $17);
    __label__ = 8;
    break;
   case 8:
    var $40 = $2 + 308 | 0;
    var $42 = HEAP32[$40 >> 2] - 1 | 0;
    HEAP32[$40 >> 2] = $42;
    var $43 = $this + 984 | 0;
    __ZN2js13AutoKeepAtomsD1Ev($43);
    var $44 = $this + 40 | 0;
    __ZN2js11TokenStreamD2Ev($44);
    var $45 = $this | 0;
    __ZN2js12AutoGCRooterD2Ev($45);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6ParserD2Ev["X"] = 1;

function __ZN2js6Parser12newObjectBoxEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 24 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $23 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($26);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $28 = $this + 976 | 0;
    var $29 = HEAP32[$28 >> 2];
    HEAP32[$23 >> 2] = $29;
    HEAP32[$28 >> 2] = $23;
    HEAP32[$23 + 4 >> 2] = 0;
    HEAP32[$23 + 8 >> 2] = $obj;
    HEAP8[$23 + 20 | 0] = 0;
    var $_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($this, $obj, $fn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 88 >> 2];
    var $6 = HEAP32[$2 + 96 >> 2];
    var $9 = $6 + 64 & ($6 ^ -1);
    var $10 = $4 + 12 | 0;
    var $11 = HEAPU32[$10 >> 2];
    if ($11 >>> 0 > (HEAP32[$4 + 8 >> 2] - $9 | 0) >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $17 = $2 + 72 | 0;
    var $18 = _JS_ArenaAllocate($17, $9);
    var $_p_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $21 = $9 + $11 | 0;
    HEAP32[$10 >> 2] = $21;
    var $_p_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_p_0;
    var $23 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $26 = HEAP32[$1 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($26);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $28 = $this + 976 | 0;
    var $29 = HEAP32[$28 >> 2];
    HEAP32[$23 >> 2] = $29;
    HEAP32[$28 >> 2] = $23 | 0;
    HEAP32[$23 + 4 >> 2] = 0;
    HEAP32[$23 + 8 >> 2] = $obj;
    HEAP8[$23 + 20 | 0] = 1;
    HEAP32[$23 + 24 >> 2] = $fn;
    var $36 = $tc + 84 | 0;
    var $37 = HEAP32[$36 >> 2];
    HEAP32[$23 + 28 >> 2] = $37;
    HEAP32[$36 >> 2] = $23;
    var $41 = HEAP32[$tc + 48 >> 2] + 972 | 0;
    var $43 = HEAP32[$41 >> 2] + 1 | 0;
    HEAP32[$41 >> 2] = $43;
    HEAP32[$23 + 32 >> 2] = 0;
    var $46 = HEAP32[$tc + 80 >> 2];
    HEAP32[$23 + 36 >> 2] = $46;
    HEAP32[$23 + 40 >> 2] = 0;
    var $49 = $23 + 44 | 0;
    if (($49 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js8BindingsC1EP9JSContext($49, undef);
    __label__ = 8;
    break;
   case 8:
    var $55 = $_p_0 + 56 | 0;
    var $57 = HEAP32[$55 >> 2] & -4;
    HEAP32[$55 >> 2] = $57;
    var $stmt_0_in = $tc + 24 | 0;
    __label__ = 9;
    break;
   case 9:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $69 = $57;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAPU16[$stmt_0 >> 1] & 65535) > 10) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $66 = $57 | 2;
    HEAP32[$55 >> 2] = $66;
    var $69 = $66;
    __label__ = 13;
    break;
   case 12:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 9;
    break;
   case 13:
    var $69;
    var $75 = $69 & -65533 | HEAP32[$tc + 76 >> 2] << 2 & 65532;
    HEAP32[$55 >> 2] = $75;
    var $78 = HEAP32[$tc >> 2] & 270336;
    var $79 = $78 | 2;
    var $80 = $23 + 60 | 0;
    HEAP32[$80 >> 2] = $79;
    if ((HEAP32[$tc + 88 >> 2] | 0) == 0) {
      var $_0 = $23;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $85 = $78 | 268435458;
    HEAP32[$80 >> 2] = $85;
    var $_0 = $23;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZNK13JSFunctionBox8joinableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK13JSFunctionBox8functionEv($this);
    var $2 = __ZNK10JSFunction13isNullClosureEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = (HEAP32[$this + 60 >> 2] & 9344 | 0) == 8192;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $objbox_03 = HEAP32[$this + 976 >> 2];
    if (($objbox_03 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $trc;
    var $objbox_04 = $objbox_03;
    __label__ = 3;
    break;
   case 3:
    var $objbox_04;
    var $6 = HEAP32[$objbox_04 + 8 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $6, undef);
    if ((HEAP8[$objbox_04 + 20 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js8Bindings5traceEP8JSTracer($objbox_04 + 44 | 0, $3);
    __label__ = 5;
    break;
   case 5:
    var $objbox_0 = HEAP32[$objbox_04 >> 2];
    if (($objbox_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $objbox_04 = $objbox_0;
      __label__ = 3;
      break;
    }
   case 6:
    var $tc_01 = HEAP32[$this + 980 >> 2];
    if (($tc_01 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $tc_02 = $tc_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $tc_02;
    __ZN13JSTreeContext5traceEP8JSTracer($tc_02, $trc);
    var $tc_0 = HEAP32[$tc_02 + 72 >> 2];
    if (($tc_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $tc_02 = $tc_0;
      __label__ = 7;
      break;
    }
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $funboxHead) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $link_0_ph = $funboxHead;
    __label__ = 2;
    break;
   case 2:
    var $link_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $1 = HEAP32[$link_0_ph >> 2];
    __label__ = 4;
    break;
   case 4:
    var $1;
    if (($1 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $4 = $1 + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $9 = HEAP32[$1 + 28 >> 2];
    HEAP32[$link_0_ph >> 2] = $9;
    var $1 = $9;
    __label__ = 4;
    break;
   case 7:
    if ((HEAP32[$5 + 32 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $17 = HEAP32[$1 + 28 >> 2];
    HEAP32[$link_0_ph >> 2] = $17;
    var $18 = HEAP32[$4 >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($18, $this);
    __label__ = 3;
    break;
   case 9:
    var $methodLink_0_ph = $1 + 40 | 0;
    __label__ = 10;
    break;
   case 10:
    var $methodLink_0_ph;
    var $22 = HEAP32[$methodLink_0_ph >> 2];
    __label__ = 11;
    break;
   case 11:
    var $22;
    if (($22 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $29 = $22 + 28 | 0;
    if ((HEAP32[$22 + 32 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $methodLink_0_ph = $29;
      __label__ = 10;
      break;
    }
   case 13:
    var $31 = HEAP32[$29 >> 2];
    HEAP32[$methodLink_0_ph >> 2] = $31;
    var $22 = $31;
    __label__ = 11;
    break;
   case 14:
    __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $1 + 32 | 0);
    var $link_0_ph = $1 + 28 | 0;
    __label__ = 2;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode8initListEPS_($this, $pn) {
  HEAP32[$this + 32 >> 2] = $pn;
  HEAP32[$this + 36 >> 2] = $pn + 24 | 0;
  HEAP32[$this + 40 >> 2] = 1;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __ZN11JSParseNode6appendEPS_($this, $pn) {
  var $1 = $this + 36 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$2 >> 2] = $pn;
  HEAP32[$1 >> 2] = $pn + 24 | 0;
  var $4 = $this + 40 | 0;
  var $6 = HEAP32[$4 >> 2] + 1 | 0;
  HEAP32[$4 >> 2] = $6;
  return;
}

function __ZN13JSTreeContext13setScopeChainEP8JSObject($this, $scopeChain) {
  HEAP32[$this + 60 >> 2] = $scopeChain;
  return;
}

function __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($pn, $parser) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 7);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $pn + 32 | 0;
    var $5 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$parser + 12 >> 2];
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($4, $8);
    __label__ = 4;
    break;
   case 4:
    var $10 = $parser + 968 | 0;
    var $11 = HEAP32[$10 >> 2];
    HEAP32[$pn + 24 >> 2] = $11;
    HEAP32[$10 >> 2] = $pn;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext($arity, $tc) {
  var $3 = HEAP32[$tc + 48 >> 2] + 40 | 0;
  var $4 = __ZNK2js11TokenStream12currentTokenEv($3);
  var $6 = HEAP32[$4 >> 2];
  var $7 = $4 + 4 | 0;
  var $8 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext($arity, $6, 0, $7, $tc);
  return $8;
}

function __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext($arity, $type, $op, $pos, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_idx_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($1, $type, $op, $arity);
    var $5 = $1 + 4 | 0;
    var $6 = $pos;
    HEAP32[$5 >> 2] = HEAP32[$6 >> 2];
    HEAP32[$5 + 4 >> 2] = HEAP32[$6 + 4 >> 2];
    HEAP32[$5 + 8 >> 2] = HEAP32[$6 + 8 >> 2];
    HEAP32[$5 + 12 >> 2] = HEAP32[$6 + 12 >> 2];
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17NewOrRecycledNodeP13JSTreeContext($tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc_0_11_val + 968 | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = HEAPU32[$tc_0_11_val + 12 >> 2];
    var $8 = HEAP32[$6 + 88 >> 2];
    var $10 = HEAP32[$6 + 96 >> 2];
    var $13 = $10 + 48 & ($10 ^ -1);
    var $14 = $8 + 12 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if ($15 >>> 0 > (HEAP32[$8 + 8 >> 2] - $13 | 0) >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = $6 + 72 | 0;
    var $22 = _JS_ArenaAllocate($21, $13);
    var $_p_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $25 = $13 + $15 | 0;
    HEAP32[$14 >> 2] = $25;
    var $_p_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $_p_0;
      __label__ = 8;
      break;
    }
   case 6:
    __Z20js_ReportOutOfMemoryP9JSContext($6);
    var $pn_02 = 0;
    __label__ = 9;
    break;
   case 7:
    var $30 = HEAP32[$2 + 24 >> 2];
    HEAP32[$1 >> 2] = $30;
    var $pn_01 = $2;
    __label__ = 8;
    break;
   case 8:
    var $pn_01;
    __ZN11JSParseNode7setUsedEb($pn_01, 0);
    __ZN11JSParseNode7setDefnEb($pn_01, 0);
    var $33 = $pn_01 + 32 | 0;
    for (var $$dest = $33, $$stop = $$dest + 16; $$dest < $$stop; $$dest++) {
      HEAP8[$$dest] = 0;
    }
    HEAP32[$pn_01 + 24 >> 2] = 0;
    var $pn_02 = $pn_01;
    __label__ = 9;
    break;
   case 9:
    var $pn_02;
    return $pn_02;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($this, $type, $op, $arity) {
  var $2 = $this;
  var $11 = $op << 16 & 16711680 | $type & 65535 | $arity << 24 & 520093696 | HEAP32[$2 >> 2] & -1073741824;
  HEAP32[$2 >> 2] = $11;
  var $13 = $this + 32 | 0;
  __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv($13);
  HEAP32[$this + 28 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  return;
}

function __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($tt, $op, $left, $right, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($left | 0) == 0 | ($right | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, $tt);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 3:
    var $6 = __ZNK11JSParseNode4isOpE4JSOp($left, $op);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 4:
    if ((HEAP32[_js_CodeSpec + ($op << 3) + 4 >> 2] & 65536 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $left;
    if ((HEAP32[$13 >> 2] & 520093696 | 0) == 83886080) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $_pre_phi = ($tt | 0) == 15;
    __label__ = 16;
    break;
   case 7:
    var $19 = HEAP32[$left + 32 >> 2];
    var $22 = HEAP32[$left + 36 >> 2];
    __ZN11JSParseNode8setArityE16JSParseNodeArity($left, 5);
    var $24 = HEAP32[$13 >> 2] & -536870913;
    HEAP32[$13 >> 2] = $24;
    __ZN11JSParseNode8initListEPS_($left, $19);
    __ZN11JSParseNode6appendEPS_($left, $22);
    var $25 = ($tt | 0) == 15;
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_pre_phi = $25;
      __label__ = 16;
      break;
    }
   case 8:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 31);
    if ($27) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = $left + 44 | 0;
    var $32 = HEAP32[$30 >> 2] | 1;
    HEAP32[$30 >> 2] = $32;
    __label__ = 12;
    break;
   case 10:
    var $34 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 30);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $left + 44 | 0;
    var $39 = HEAP32[$37 >> 2] | 2;
    HEAP32[$37 >> 2] = $39;
    __label__ = 12;
    break;
   case 12:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 31);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $43 = $left + 44 | 0;
    var $45 = HEAP32[$43 >> 2] | 1;
    HEAP32[$43 >> 2] = $45;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $48 = $right + 12 | 0;
    var $49 = $left + 12 | 0;
    var $st$10$0 = $48 | 0;
    var $50$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $48 + 4 | 0;
    var $50$1 = HEAP32[$st$10$1 >> 2];
    var $st$14$0 = $49 | 0;
    HEAP32[$st$14$0 >> 2] = $50$0;
    var $st$14$1 = $49 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $50$1;
    __label__ = 18;
    break;
   case 14:
    var $52 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 30);
    if ($52) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $54 = $left + 44 | 0;
    var $56 = HEAP32[$54 >> 2] | 2;
    HEAP32[$54 >> 2] = $56;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $59 = $right + 12 | 0;
    var $60 = $left + 12 | 0;
    var $st$10$0 = $59 | 0;
    var $61$0 = HEAP32[$st$10$0 >> 2];
    var $st$10$1 = $59 + 4 | 0;
    var $61$1 = HEAP32[$st$10$1 >> 2];
    var $st$14$0 = $60 | 0;
    HEAP32[$st$14$0 >> 2] = $61$0;
    var $st$14$1 = $60 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $61$1;
    __label__ = 18;
    break;
   case 16:
    var $_pre_phi;
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $65 = $right + 12 | 0;
    var $66 = $left + 12 | 0;
    var $67$0 = HEAP32[$65 >> 2];
    var $67$1 = HEAP32[$65 + 4 >> 2];
    var $st$10$0 = $66 | 0;
    HEAP32[$st$10$0 >> 2] = $67$0;
    var $st$10$1 = $66 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $67$1;
    if ($_pre_phi) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $left;
      __label__ = 29;
      break;
    }
   case 17:
    __ZN11JSParseNode6appendEPS_($left, $right);
    var $70 = $right + 12 | 0;
    var $71 = $left + 12 | 0;
    var $st$5$0 = $70 | 0;
    var $72$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $70 + 4 | 0;
    var $72$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $71 | 0;
    HEAP32[$st$9$0 >> 2] = $72$0;
    var $st$9$1 = $71 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $72$1;
    __label__ = 18;
    break;
   case 18:
    var $74 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 31);
    if ($74) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $77 = $left + 44 | 0;
    var $79 = HEAP32[$77 >> 2] | 1;
    HEAP32[$77 >> 2] = $79;
    var $_0 = $left;
    __label__ = 29;
    break;
   case 20:
    var $81 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 30);
    if ($81) {
      var $_0 = $left;
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $84 = $left + 44 | 0;
    var $86 = HEAP32[$84 >> 2] | 2;
    HEAP32[$84 >> 2] = $86;
    var $_0 = $left;
    __label__ = 29;
    break;
   case 22:
    if (($tt | 0) == 15) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $90 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 30);
    if ($90) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $92 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($right, 30);
    if ($92) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if ((HEAP8[HEAP32[$tc + 48 >> 2] + 988 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $102 = $right + 32 | 0;
    var $103 = (tempDoubleI32[0] = HEAP32[$102 >> 2], tempDoubleI32[1] = HEAP32[$102 + 4 >> 2], tempDoubleF64[0]);
    var $105 = $left + 32 | 0;
    var $106 = (tempDoubleI32[0] = HEAP32[$105 >> 2], tempDoubleI32[1] = HEAP32[$105 + 4 >> 2], tempDoubleF64[0]);
    var $107 = $106 + $103;
    tempDoubleF64[0] = $107, HEAP32[$105 >> 2] = tempDoubleI32[0], HEAP32[$105 + 4 >> 2] = tempDoubleI32[1];
    var $110 = $right + 12 | 0;
    var $111 = $left + 12 | 0;
    var $112$0 = HEAP32[$110 >> 2];
    var $112$1 = HEAP32[$110 + 4 >> 2];
    HEAP32[$111 >> 2] = $112$0;
    HEAP32[$111 + 4 >> 2] = $112$1;
    var $113 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($right, $tc);
    var $_0 = $left;
    __label__ = 29;
    break;
   case 27:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $114 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_idx_val);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity($114, $tt, $op, 2);
    var $119 = $left + 4 | 0;
    var $120 = $114 + 4 | 0;
    var $st$5$0 = $119 | 0;
    var $121$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $119 + 4 | 0;
    var $121$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $120 | 0;
    HEAP32[$st$9$0 >> 2] = $121$0;
    var $st$9$1 = $120 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $121$1;
    var $124 = $right + 12 | 0;
    var $125 = $114 + 12 | 0;
    var $126$0 = HEAP32[$124 >> 2];
    var $126$1 = HEAP32[$124 + 4 >> 2];
    var $st$21$0 = $125 | 0;
    HEAP32[$st$21$0 >> 2] = $126$0;
    var $st$21$1 = $125 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $126$1;
    var $127 = $114 + 32 | 0;
    HEAP32[$127 >> 2] = $left;
    var $128 = $114 + 36 | 0;
    HEAP32[$128 >> 2] = $right;
    var $_0 = $114;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext["X"] = 1;

function __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stack = __stackBase__;
    if (($pn | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$pn + 24 >> 2];
    __ZN2js9NodeStackC1Ev($stack);
    var $tc_idx = $tc + 48 | 0;
    var $_01 = $pn;
    __label__ = 3;
    break;
   case 3:
    var $_01;
    var $6 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($_01, $stack);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($_01, $tc_idx_val);
    __label__ = 5;
    break;
   case 5:
    var $9 = __ZN2js9NodeStack5emptyEv($stack);
    if ($9) {
      var $_0 = $4;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZN2js9NodeStack3popEv($stack);
    var $_01 = $11;
    __label__ = 3;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(6, $tc);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_pre_phi = $1;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$1 + 32 >> 2] = $atom;
    var $5 = $1;
    __ZN2js8NameNode10initCommonEP13JSTreeContext($5, $tc);
    var $_pre_phi = $5;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    return $_pre_phi;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8NameNode10initCommonEP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 36 >> 2] = 0;
    var $3 = $this + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($3);
    var $5 = HEAP32[$tc + 24 >> 2];
    if (($5 | 0) == 0) {
      var $12 = 32;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $phitmp = HEAP16[$5 >> 1] << 16 >> 16 == 4 ? 32 : 0;
    var $12 = $phitmp;
    __label__ = 3;
    break;
   case 3:
    var $12;
    var $14 = $this + 44 | 0;
    var $17 = HEAP32[$14 >> 2] & -4096 | $12;
    HEAP32[$14 >> 2] = $17;
    var $18 = $tc;
    var $19 = __ZN13JSTreeContext7blockidEv($18);
    HEAP32[$14 >> 2] = $19 << 12 | $12;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser5parseEP8JSObject($this, $chain) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $globaltc = __stackBase__;
    __ZN13JSTreeContextC1EPN2js6ParserE($globaltc, $this);
    var $1 = $this + 12 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $globaltc;
    var $4 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($3, $2, 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    __ZN13JSTreeContext13setScopeChainEP8JSObject($globaltc, $chain);
    var $6 = $globaltc + 4 | 0;
    var $7 = __ZL15GenerateBlockIdP13JSTreeContextRj($globaltc, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    var $9 = __ZN2js6Parser10statementsEv($this);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $this + 40 | 0;
    var $13 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 0);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    if ((HEAP8[$this + 988 | 0] & 1) << 24 >> 24 == 0) {
      var $_0 = $9;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = HEAP32[$1 >> 2];
    var $23 = _js_FoldConstants($22, $9, $globaltc, 0);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $9;
      __label__ = 9;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    __ZN13JSTreeContextD1Ev($globaltc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContextC1EPN2js6ParserE($this, $prs) {
  var $1 = $this;
  var $2 = $prs;
  __ZN13JSTreeContextC2EPN2js6ParserE($1, $2);
  return;
}

function __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $blockid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 1048576) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($8, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str1073259 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $10;
    HEAP32[$blockid >> 2] = $2;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser10statementsEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inDirectivePrologue = __stackBase__ + 4;
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 3:
    var $9 = $this + 980 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = __ZN2js8ListNode6createEP13JSTreeContext($10);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($12, 25);
    __ZN11JSParseNode9makeEmptyEv($12);
    var $16 = HEAP32[$9 >> 2];
    var $17 = __ZN13JSTreeContext7blockidEv($16);
    var $19 = $11 + 44 | 0;
    var $23 = HEAP32[$19 >> 2] & 4095 | $17 << 12;
    HEAP32[$19 >> 2] = $23;
    var $25 = HEAP32[$9 >> 2] + 36 | 0;
    var $26 = HEAP32[$25 >> 2];
    HEAP32[$25 >> 2] = $12;
    var $27 = HEAP32[$9 >> 2];
    var $28 = __ZN13JSTreeContext11atBodyLevelEv($27);
    HEAP8[$inDirectivePrologue] = $28 & 1;
    var $30 = $this + 40 | 0;
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($30, 0);
    __label__ = 5;
    break;
   case 5:
    var $32 = __ZN2js11TokenStream9peekTokenEj($30, 8);
    if (($32 | 0) < 1 | ($32 | 0) == 26) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    if (($32 | 0) == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 7:
    var $38 = __ZNK2js11TokenStream5isEOFEv($30);
    if ($38) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 8:
    __ZN2js11TokenStream16setUnexpectedEOFEb($30, 1);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 9:
    var $41 = __ZN2js6Parser9statementEv($this);
    if (($41 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $44 = __ZNK2js11TokenStream5isEOFEv($30);
    if ($44) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 11:
    __ZN2js11TokenStream16setUnexpectedEOFEb($30, 1);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 12:
    if ((HEAP8[$inDirectivePrologue] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($this, $41, $inDirectivePrologue);
    if ($51) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 20;
      break;
    }
   case 14:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($41, 34);
    if ($53) {
      __label__ = 15;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $55 = HEAP32[$9 >> 2];
    var $56 = __ZN13JSTreeContext11atBodyLevelEv($55);
    if ($56) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $59 = HEAP32[$19 >> 2] | 256;
    HEAP32[$19 >> 2] = $59;
    __label__ = 18;
    break;
   case 17:
    var $61 = $55 | 0;
    var $63 = HEAP32[$61 >> 2] | 2048;
    HEAP32[$61 >> 2] = $63;
    var $64 = HEAP32[$9 >> 2];
    __ZN13JSTreeContext22noteHasExtensibleScopeEv($64);
    __label__ = 18;
    break;
   case 18:
    __ZN11JSParseNode6appendEPS_($12, $41);
    __label__ = 5;
    break;
   case 19:
    var $68 = HEAP32[$9 >> 2] + 36 | 0;
    var $69 = HEAP32[$68 >> 2];
    HEAP32[$68 >> 2] = $26;
    var $70 = $69 + 12 | 0;
    var $71 = __ZNK2js11TokenStream12currentTokenEv($30);
    var $73 = $71 + 12 | 0;
    var $74 = $70;
    var $75$0 = HEAP32[$73 >> 2];
    var $75$1 = HEAP32[$73 + 4 >> 2];
    var $st$13$0 = $74 | 0;
    HEAP32[$st$13$0 >> 2] = $75$0;
    var $st$13$1 = $74 + 4 | 0;
    HEAP32[$st$13$1 >> 2] = $75$1;
    var $_0 = $69;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10statementsEv["X"] = 1;

function __ZN2js11TokenStream10matchTokenENS_9TokenKindE($this, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream8getTokenEv($this);
    if (($1 | 0) == ($tt | 0)) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $pn, $flags, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $args = __stackBase__;
  HEAP32[$args >> 2] = arguments[__ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz.length];
  var $2 = $this + 40 | 0;
  var $3 = HEAP32[$args >> 2];
  var $4 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($2, $pn, $flags, $errorNumber, $3);
  STACKTOP = __stackBase__;
  return $4;
}

function _js_FoldConstants($cx, $pn, $tc, $inCond) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 146;
    break;
   case 3:
    var $7 = __ZNK11JSParseNode8getArityEv($pn);
    if (($7 | 0) == 4) {
      __label__ = 4;
      break;
    } else if (($7 | 0) == 5) {
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      __label__ = 16;
      break;
    } else if (($7 | 0) == 2) {
      __label__ = 25;
      break;
    } else if (($7 | 0) == 1) {
      __label__ = 32;
      break;
    } else if (($7 | 0) == 6) {
      __label__ = 37;
      break;
    } else if (($7 | 0) == 7) {
      __label__ = 44;
      break;
    } else {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 4:
    var $9 = $tc | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $tc + 84 | 0;
    var $12 = HEAP32[$11 >> 2];
    var $14 = $pn + 32 | 0;
    var $17 = HEAP32[HEAP32[$14 >> 2] + 60 >> 2];
    HEAP32[$9 >> 2] = $17;
    var $20 = HEAP32[HEAP32[$14 >> 2] + 32 >> 2];
    HEAP32[$11 >> 2] = $20;
    var $23 = HEAP32[$pn + 36 >> 2];
    var $24 = _js_FoldConstants($cx, $23, $tc, 0);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$11 >> 2];
    var $29 = HEAP32[$14 >> 2] + 32 | 0;
    HEAP32[$29 >> 2] = $27;
    HEAP32[$9 >> 2] = $10;
    HEAP32[$11 >> 2] = $12;
    var $pn1_1 = 0;
    var $pn2_1 = 0;
    var $pn3_0 = 0;
    __label__ = 45;
    break;
   case 6:
    if ($inCond) {
      __label__ = 7;
      break;
    } else {
      var $36 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $32 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if ($32) {
      var $36 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 8);
    var $36 = $34;
    __label__ = 9;
    break;
   case 9:
    var $36;
    var $38 = HEAPU32[$pn + 32 >> 2];
    var $39 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 27);
    if ($39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 49);
    if ($41) {
      __label__ = 11;
      break;
    } else {
      var $pn2_0 = $38;
      __label__ = 13;
      break;
    }
   case 11:
    var $43 = __ZNK11JSParseNode10isInParensEv($38);
    if ($43) {
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $38;
      __label__ = 13;
      break;
    }
   case 12:
    var $pn2_0 = HEAP32[$38 + 24 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $pn1_1 = $38;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = _js_FoldConstants($cx, $pn2_0, $tc, $36);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 13;
    break;
   case 16:
    var $56 = HEAPU32[$pn + 32 >> 2];
    var $57 = $pn + 36 | 0;
    var $58 = HEAP32[$57 >> 2];
    var $59 = $58;
    var $62 = HEAPU32[$pn + 40 >> 2];
    if (($56 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $65 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 35);
    var $66 = _js_FoldConstants($cx, $56, $tc, $65);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($58 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 83);
    var $72 = _js_FoldConstants($cx, $59, $tc, $71);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $75 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 83);
    if ($75) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $77 = __ZNK11JSParseNode4isOpE4JSOp($59, 67);
    if ($77) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $79 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($59, $tc);
    HEAP32[$57 >> 2] = 0;
    __label__ = 23;
    break;
   case 23:
    if (($62 | 0) == 0) {
      var $pn1_1 = $56;
      var $pn2_1 = $59;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $83 = _js_FoldConstants($cx, $62, $tc, 0);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $56;
      var $pn2_1 = $59;
      var $pn3_0 = $62;
      __label__ = 45;
      break;
    }
   case 25:
    var $87 = HEAP32[$pn + 32 >> 2];
    var $90 = HEAP32[$pn + 36 >> 2];
    var $91 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if ($91) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $93 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 8);
    if ($93) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    var $95 = _js_FoldConstants($cx, $87, $tc, $inCond);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $98 = _js_FoldConstants($cx, $90, $tc, $inCond);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $87;
      var $pn2_1 = $90;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 29:
    if (($87 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $103 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 40);
    var $104 = _js_FoldConstants($cx, $87, $tc, $103);
    if (($104 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $107 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 41);
    var $108 = _js_FoldConstants($cx, $90, $tc, $107);
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $87;
      var $pn2_1 = $90;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 32:
    var $112 = HEAP32[$pn + 32 >> 2];
    var $113 = __ZNK11JSParseNode4isOpE4JSOp($pn, 39);
    if ($113) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $115 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($112, 29);
    if ($115) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN11JSParseNode5setOpE4JSOp($pn, 200);
    __label__ = 35;
    break;
   case 35:
    if (($112 | 0) == 0) {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $120 = __ZNK11JSParseNode4isOpE4JSOp($pn, 32);
    var $121 = _js_FoldConstants($cx, $112, $tc, $120);
    if (($121 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $112;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 37:
    var $124 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($124) {
      var $pn1_1 = 0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $pn1_0_in = HEAP32[$pn + 36 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $pn1_0_in;
    var $pn1_0 = $pn1_0_in;
    if (($pn1_0_in | 0) == 0) {
      var $pn1_1 = $pn1_0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $131 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn1_0, 6);
    if ($131) {
      __label__ = 41;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 41:
    var $133 = __ZNK11JSParseNode6isUsedEv($pn1_0);
    if ($133) {
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $pn1_0_in = HEAP32[$pn1_0_in + 36 >> 2];
    __label__ = 39;
    break;
   case 43:
    var $138 = _js_FoldConstants($cx, $pn1_0, $tc, 0);
    if (($138 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $pn1_0;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 44:
    var $143 = HEAP32[$pn + 36 >> 2];
    var $144 = _js_FoldConstants($cx, $143, $tc, 0);
    if (($144 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      var $pn1_1 = $143;
      var $pn2_1 = 0;
      var $pn3_0 = 0;
      __label__ = 45;
      break;
    }
   case 45:
    var $pn3_0;
    var $pn2_1;
    var $pn1_1;
    var $146 = __ZNK11JSParseNode7getKindEv($pn);
    if (($146 | 0) == 35) {
      __label__ = 46;
      break;
    } else if (($146 | 0) == 5) {
      __label__ = 48;
      break;
    } else if (($146 | 0) == 7 || ($146 | 0) == 8) {
      __label__ = 66;
      break;
    } else if (($146 | 0) == 4) {
      __label__ = 86;
      break;
    } else if (($146 | 0) == 15) {
      __label__ = 88;
      break;
    } else if (($146 | 0) == 17 || ($146 | 0) == 14 || ($146 | 0) == 16 || ($146 | 0) == 18) {
      __label__ = 110;
      break;
    } else if (($146 | 0) == 19) {
      __label__ = 124;
      break;
    } else if (($146 | 0) == 75 || ($146 | 0) == 76 || ($146 | 0) == 61 || ($146 | 0) == 59 || ($146 | 0) == 60 || ($146 | 0) == 63) {
      __label__ = 137;
      break;
    } else if (($146 | 0) == 70) {
      __label__ = 139;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 46:
    var $148 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn2_1);
    if (($148 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 47:
    var $151 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn3_0);
    if (($151 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 48:
    var $154 = __ZNK11JSParseNode7getKindEv($pn1_1);
    if (($154 | 0) == 30) {
      __label__ = 49;
      break;
    } else if (($154 | 0) == 31) {
      __label__ = 52;
      break;
    } else if (($154 | 0) == 33) {
      __label__ = 54;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 49:
    var $157 = $pn1_1 + 32 | 0;
    var $158 = (tempDoubleI32[0] = HEAP32[$157 >> 2], tempDoubleI32[1] = HEAP32[$157 + 4 >> 2], tempDoubleF64[0]);
    if ($158 == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $161 = __ZL15JSDOUBLE_IS_NaNd2908($158);
    if (($161 | 0) == 0) {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $pn2_2 = $pn3_0;
    __label__ = 57;
    break;
   case 52:
    var $168 = HEAP32[$pn1_1 + 32 >> 2] | 0;
    var $169 = __ZNK8JSString6lengthEv($168);
    if (($169 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    }
   case 53:
    var $pn2_2 = $pn3_0;
    __label__ = 57;
    break;
   case 54:
    var $173 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 67);
    if ($173) {
      var $pn2_2 = $pn2_1;
      __label__ = 57;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $175 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 66);
    if ($175) {
      var $pn2_2 = $pn3_0;
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $177 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 64);
    if ($177) {
      var $pn2_2 = $pn3_0;
      __label__ = 57;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 57:
    var $pn2_2;
    if (($pn2_2 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    if ((HEAP32[$tc >> 2] & 4096 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 59:
    var $185 = __ZNK11JSParseNode6isDefnEv($pn2_2);
    if ($185) {
      __label__ = 61;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    __ZN11JSParseNode6becomeEPS_($pn, $pn2_2);
    __label__ = 61;
    break;
   case 61:
    var $187 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 2);
    if ($187) {
      __label__ = 62;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 62:
    if ((HEAP32[$pn + 32 >> 2] | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 25);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 5);
    __ZN11JSParseNode9makeEmptyEv($pn);
    __label__ = 64;
    break;
   case 64:
    var $193 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_2, $tc);
    if (($pn3_0 | 0) == 0 | ($pn3_0 | 0) == ($pn2_2 | 0)) {
      __label__ = 143;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $197 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn3_0, $tc);
    __label__ = 143;
    break;
   case 66:
    if ($inCond) {
      __label__ = 67;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 67:
    var $200 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($200) {
      __label__ = 68;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 68:
    var $202 = $pn + 32 | 0;
    var $203 = $pn + 40 | 0;
    var $pnp_0 = $202;
    var $pn1_2 = $pn1_1;
    __label__ = 69;
    break;
   case 69:
    var $pn1_2;
    var $pnp_0;
    var $205 = __ZL7BoolishP11JSParseNode($pn1_2);
    var $206 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if (($205 | 0) == ($206 & 1 | 0)) {
      __label__ = 70;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 70:
    var $210 = $pn1_2 + 24 | 0;
    var $211 = HEAP32[$210 >> 2];
    if (($211 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $pn2_325 = $211;
      __label__ = 71;
      break;
    }
   case 71:
    var $pn2_325;
    var $214 = HEAP32[$pn2_325 + 24 >> 2];
    var $215 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_325, $tc);
    var $217 = HEAP32[$203 >> 2] - 1 | 0;
    HEAP32[$203 >> 2] = $217;
    if (($214 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $pn2_325 = $214;
      __label__ = 71;
      break;
    }
   case 72:
    HEAP32[$210 >> 2] = 0;
    __label__ = 79;
    break;
   case 73:
    if (($205 | 0) == -1) {
      __label__ = 77;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    if ((HEAP32[$203 >> 2] | 0) == 1) {
      __label__ = 75;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 75:
    var $242 = HEAP32[$202 >> 2];
    __label__ = 81;
    break;
   case 76:
    var $227 = HEAP32[$pn1_2 + 24 >> 2];
    HEAP32[$pnp_0 >> 2] = $227;
    var $228 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_2, $tc);
    var $230 = HEAP32[$203 >> 2] - 1 | 0;
    HEAP32[$203 >> 2] = $230;
    var $pnp_1 = $pnp_0;
    __label__ = 78;
    break;
   case 77:
    var $pnp_1 = $pn1_2 + 24 | 0;
    __label__ = 78;
    break;
   case 78:
    var $pnp_1;
    var $234 = HEAPU32[$pnp_1 >> 2];
    if (($234 | 0) == 0) {
      __label__ = 79;
      break;
    } else {
      var $pnp_0 = $pnp_1;
      var $pn1_2 = $234;
      __label__ = 69;
      break;
    }
   case 79:
    var $_pr = HEAP32[$203 >> 2];
    var $236 = HEAP32[$202 >> 2];
    if (($_pr | 0) == 2) {
      __label__ = 80;
      break;
    } else if (($_pr | 0) == 1) {
      var $242 = $236;
      __label__ = 81;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 80:
    var $238 = $236 + 24 | 0;
    var $239 = HEAP32[$238 >> 2];
    HEAP32[$238 >> 2] = 0;
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 2);
    HEAP32[$202 >> 2] = $236;
    var $_c3 = $239;
    HEAP32[$pn + 36 >> 2] = $_c3;
    __label__ = 143;
    break;
   case 81:
    var $242;
    __ZN11JSParseNode6becomeEPS_($pn, $242);
    var $243 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($242, $tc);
    __label__ = 143;
    break;
   case 82:
    var $245 = __ZL7BoolishP11JSParseNode($pn1_1);
    var $246 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    if (($245 | 0) == ($246 & 1 | 0)) {
      __label__ = 83;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 83:
    var $249 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_1, $tc);
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_1);
    __label__ = 144;
    break;
   case 84:
    if (($245 | 0) == -1) {
      __label__ = 143;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $253 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __ZN11JSParseNode6becomeEPS_($pn, $pn2_1);
    __label__ = 143;
    break;
   case 86:
    var $255 = __ZNK11JSParseNode4isOpE4JSOp($pn, 0);
    if ($255) {
      __label__ = 143;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $257 = __ZNK11JSParseNode4isOpE4JSOp($pn, 27);
    if ($257) {
      __label__ = 88;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 88:
    var $259 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($259) {
      __label__ = 89;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 89:
    var $263 = HEAP32[$pn + 44 >> 2];
    if (($263 & 2 | 0) == 0) {
      __label__ = 90;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 90:
    if (($263 & 4095 | 0) == 1) {
      var $length_0 = 0;
      var $pn2_4 = $pn1_1;
      __label__ = 91;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 91:
    var $pn2_4;
    var $length_0;
    if (($pn2_4 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $271 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_4, 31);
    if (($271 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    var $274 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_4, 31);
    if ($274) {
      __label__ = 94;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 94:
    var $279 = HEAP32[$pn2_4 + 32 >> 2] | 0;
    var $280 = __ZNK8JSString6lengthEv($279);
    var $length_0 = $280 + $length_0 | 0;
    var $pn2_4 = HEAP32[$pn2_4 + 24 >> 2];
    __label__ = 91;
    break;
   case 95:
    var $287 = __ZN9JSContext7malloc_Ej($cx, ($length_0 << 1) + 2 | 0);
    var $288 = $287;
    if (($287 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    HEAP16[$288 + ($length_0 << 1) >> 1] = 0;
    var $292 = $cx;
    var $293 = __Z12js_NewStringP9JSContextPtj($292, $288, $length_0);
    var $294 = $293 | 0;
    if (($293 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    if (($pn1_1 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      var $pn2_519 = $pn1_1;
      var $chars_020 = $288;
      __label__ = 99;
      break;
    }
   case 98:
    __ZN9JSContext5free_EPv(undef, $287);
    var $_0 = 0;
    __label__ = 146;
    break;
   case 99:
    var $chars_020;
    var $pn2_519;
    var $300 = HEAP32[$pn2_519 + 32 >> 2];
    var $301 = $300 | 0;
    var $302 = __ZNK8JSString6lengthEv($301);
    var $303 = $chars_020;
    var $304 = $300 | 0;
    var $305 = __ZNK14JSLinearString5charsEv($304);
    var $306 = $305;
    var $307 = $302 << 1;
    _memcpy($303, $306, $307, 1);
    var $308 = $chars_020 + ($302 << 1) | 0;
    var $309 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_519, $tc);
    if (($309 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      var $pn2_519 = $309;
      var $chars_020 = $308;
      __label__ = 99;
      break;
    }
   case 100:
    var $311 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $294, 0);
    HEAP32[$pn + 32 >> 2] = $311;
    if (($311 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    __label__ = 143;
    break;
   case 102:
    var $316 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 31);
    if ($316) {
      __label__ = 104;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    var $318 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 31);
    if ($318) {
      __label__ = 104;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 104:
    var $320 = $316 ? $pn2_1 : $pn1_1;
    var $321 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $320, 31);
    if (($321 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    var $324 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 31);
    if ($324) {
      __label__ = 106;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 106:
    var $326 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 31);
    if ($326) {
      __label__ = 107;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 107:
    var $331 = HEAP32[$pn1_1 + 32 >> 2] | 0;
    var $335 = HEAP32[$pn2_1 + 32 >> 2] | 0;
    var $336 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $331, $335);
    if (($336 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $339 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $336, 0);
    var $_c1 = $339;
    HEAP32[$pn + 32 >> 2] = $_c1;
    if (($339 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $343 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    var $344 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2_1, $tc);
    __label__ = 143;
    break;
   case 110:
    var $346 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($346) {
      var $pn2_6 = $pn1_1;
      __label__ = 111;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 111:
    var $pn2_6;
    if (($pn2_6 | 0) == 0) {
      var $pn2_7 = $pn1_1;
      __label__ = 114;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $349 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_6, 30);
    if (($349 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $pn2_6 = HEAP32[$pn2_6 + 24 >> 2];
    __label__ = 111;
    break;
   case 114:
    var $pn2_7;
    if (($pn2_7 | 0) == 0) {
      __label__ = 117;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $356 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_7, 30);
    if ($356) {
      __label__ = 116;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 116:
    var $pn2_7 = HEAP32[$pn2_7 + 24 >> 2];
    __label__ = 114;
    break;
   case 117:
    var $360 = __ZNK11JSParseNode5getOpEv($pn);
    var $362 = HEAP32[$pn1_1 + 24 >> 2];
    var $364 = HEAP32[$362 + 24 >> 2];
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($360, $pn1_1, $362, $pn, $tc);
    if (($364 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $pn3_113 = $364;
      __label__ = 118;
      break;
    }
   case 118:
    var $pn3_113;
    var $367 = HEAP32[$pn3_113 + 24 >> 2];
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($360, $pn, $pn3_113, $pn, $tc);
    if (($367 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $pn3_113 = $367;
      __label__ = 118;
      break;
    }
   case 119:
    var $370 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn1_1, 30);
    if (($370 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    var $373 = __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn2_1, 30);
    if (($373 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 121:
    var $376 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 30);
    if ($376) {
      __label__ = 122;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 122:
    var $378 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 30);
    if ($378) {
      __label__ = 123;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 123:
    var $380 = __ZNK11JSParseNode5getOpEv($pn);
    __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($380, $pn1_1, $pn2_1, $pn, $tc);
    __label__ = 143;
    break;
   case 124:
    var $382 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 30);
    if ($382) {
      __label__ = 125;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 125:
    var $385 = $pn1_1 + 32 | 0;
    var $386 = (tempDoubleI32[0] = HEAP32[$385 >> 2], tempDoubleI32[1] = HEAP32[$385 + 4 >> 2], tempDoubleF64[0]);
    var $387 = __ZNK11JSParseNode5getOpEv($pn);
    if (($387 | 0) == 33) {
      __label__ = 126;
      break;
    } else if (($387 | 0) == 34) {
      __label__ = 127;
      break;
    } else if (($387 | 0) == 32) {
      __label__ = 128;
      break;
    } else if (($387 | 0) == 35) {
      var $d_0 = $386;
      __label__ = 131;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 126:
    var $389 = __ZL20js_DoubleToECMAInt32d2909($386);
    var $d_0 = $389 ^ -1 | 0;
    __label__ = 131;
    break;
   case 127:
    var $d_0 = -$386;
    __label__ = 131;
    break;
   case 128:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 33);
    if ($386 == 0) {
      var $400 = 67;
      __label__ = 130;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    var $397 = __ZL15JSDOUBLE_IS_NaNd2908($386);
    var $phitmp = ($397 | 0) != 0 ? 67 : 66;
    var $400 = $phitmp;
    __label__ = 130;
    break;
   case 130:
    var $400;
    __ZN11JSParseNode5setOpE4JSOp($pn, $400);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_0 = 1;
    __label__ = 146;
    break;
   case 131:
    var $d_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $403 = $pn + 32 | 0;
    tempDoubleF64[0] = $d_0, HEAP32[$403 >> 2] = tempDoubleI32[0], HEAP32[$403 + 4 >> 2] = tempDoubleI32[1];
    var $404 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 132:
    var $406 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 33);
    if ($406) {
      __label__ = 133;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 133:
    var $408 = __ZNK11JSParseNode4isOpE4JSOp($pn, 32);
    if ($408) {
      __label__ = 134;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 134:
    var $410 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 67);
    if ($410) {
      __label__ = 136;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $412 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 66);
    if ($412) {
      __label__ = 136;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 136:
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_1);
    var $414 = __ZNK11JSParseNode4isOpE4JSOp($pn, 67);
    var $415 = $414 ? 66 : 67;
    __ZN11JSParseNode5setOpE4JSOp($pn, $415);
    var $416 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 137:
    var $418 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($418) {
      __label__ = 138;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 138:
    var $420 = __ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc);
    var $421 = ($420 | 0) == 0;
    if ($421 | $inCond ^ 1) {
      var $_0 = $421 & 1 ^ 1;
      __label__ = 146;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 139:
    var $424 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 63);
    if ($424) {
      __label__ = 140;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 140:
    var $429 = HEAP32[$pn1_1 + 32 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString2910($v, $429);
    var $430 = $cx;
    var $431 = __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($430, $v);
    if (($431 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 141;
      break;
    }
   case 141:
    var $435 = HEAP32[$tc + 48 >> 2];
    var $436 = __ZNK2JS5Value8toObjectEv($v);
    var $437 = __ZN2js6Parser12newObjectBoxEP8JSObject($435, $436);
    if (($437 | 0) == 0) {
      var $_0 = 0;
      __label__ = 146;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 142:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 63);
    __ZN11JSParseNode5setOpE4JSOp($pn, 80);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_c = $437;
    HEAP32[$pn + 32 >> 2] = $_c;
    var $441 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_1, $tc);
    __label__ = 143;
    break;
   case 143:
    if ($inCond) {
      __label__ = 144;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 144:
    var $443 = __ZL7BoolishP11JSParseNode($pn);
    if (($443 | 0) > -1) {
      __label__ = 145;
      break;
    } else {
      var $_0 = 1;
      __label__ = 146;
      break;
    }
   case 145:
    __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($pn, $tc);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 33);
    var $447 = ($443 | 0) != 0 ? 67 : 66;
    __ZN11JSParseNode5setOpE4JSOp($pn, $447);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $_0 = 1;
    __label__ = 146;
    break;
   case 146:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_FoldConstants["X"] = 1;

function __ZN13JSTreeContextD1Ev($this) {
  var $1 = $this;
  __ZN13JSTreeContextD2Ev($1);
  return;
}

function __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($this, $cx, $prin, $cfp) {
  var $1 = $this | 0;
  __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($1, $cx, $prin, $cfp, 1);
  HEAP32[$this + 992 >> 2] = 0;
  return;
}

function __ZNK2js11TokenStream9getLinenoEv($this) {
  return HEAP32[$this + 140 >> 2];
}

function __ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj($cx, $scopeChain, $callerFrame, $principals, $tcflags, $chars, $length, $filename, $lineno, $version, $source, $staticLevel) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 2068;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $inDirectivePrologue = __stackBase__;
    var $compiler = __stackBase__ + 4;
    var $cg = __stackBase__ + 1e3;
    var $globalScope = __stackBase__ + 1616;
    var $_ = __stackBase__ + 2060;
    var $bodyid = __stackBase__ + 2064;
    __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($compiler, $cx, $principals, $callerFrame);
    var $1 = __ZN2js8Compiler4initEPKtjPKcj9JSVersion($compiler, $chars, $length, $filename, $lineno, $version);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 57;
      break;
    }
   case 2:
    var $3 = $compiler | 0;
    var $4 = $compiler + 40 | 0;
    var $5 = __ZNK2js11TokenStream9getLinenoEv($4);
    var $6 = $cg;
    var $7 = $compiler;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($6, $7, $5);
    var $8 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($6, $cx, 0);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 56;
      break;
    }
   case 3:
    if (($scopeChain | 0) == 0) {
      var $19 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $scopeChain;
    var $13 = __ZNK8JSObject9getGlobalEv($12);
    if (($13 | 0) == ($scopeChain | 0)) {
      __label__ = 5;
      break;
    } else {
      var $19 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = $13;
    __label__ = 6;
    break;
   case 6:
    var $19;
    __ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator($globalScope, $cx, $19 | 0, $cg);
    var $21 = $cg | 0;
    var $22 = $cg | 0;
    var $24 = HEAP32[$22 >> 2] | $tcflags;
    HEAP32[$22 >> 2] = $24;
    __ZN13JSTreeContext13setScopeChainEP8JSObject($21, $scopeChain);
    HEAP32[$compiler + 992 >> 2] = $globalScope;
    var $26 = __ZL14SetStaticLevelP13JSTreeContextj($21, $staticLevel);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 7:
    var $28 = ($callerFrame | 0) != 0;
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $30 = __ZNK2js10StackFrame13isScriptFrameEv($callerFrame);
    if ($30) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $32 = __ZNK2js10StackFrame6scriptEv($callerFrame);
    if ((HEAP8[$32 + 36 | 0] & 8) << 24 >> 24 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = HEAP32[$22 >> 2] | 262144;
    HEAP32[$22 >> 2] = $39;
    __ZN2js11TokenStream13setStrictModeEb($4, 1);
    __label__ = 11;
    break;
   case 11:
    if (($tcflags & 8192 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($source | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $source, 0);
    if (($46 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $49 = __ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj($6, $46, $_);
    if ($49) {
      __label__ = 15;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 15:
    if ($28) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $52 = __ZNK2js10StackFrame15isFunctionFrameEv($callerFrame);
    if ($52) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $54 = __ZNK2js10StackFrame3funEv($callerFrame);
    var $55 = $54 | 0;
    var $56 = __ZN2js6Parser12newObjectBoxEP8JSObject($3, $55);
    if (($56 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $59 = $cg + 296 | 0;
    var $60 = HEAP32[$59 >> 2];
    HEAP32[$56 + 4 >> 2] = $60;
    HEAP32[$59 >> 2] = $56;
    var $62 = $cg + 292 | 0;
    var $64 = HEAP32[$62 >> 2] + 1 | 0;
    HEAP32[$62 >> 2] = $64;
    __label__ = 19;
    break;
   case 19:
    var $66 = __ZL15GenerateBlockIdP13JSTreeContextRj($21, $bodyid);
    if ($66) {
      __label__ = 20;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 20:
    var $68 = HEAP32[$bodyid >> 2];
    HEAP32[$cg + 4 >> 2] = $68;
    HEAP8[$inDirectivePrologue] = 1;
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($4, 0);
    var $70 = $cg + 84 | 0;
    var $onlyXML_0 = 1;
    var $pn_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $pn_0;
    var $onlyXML_0;
    var $72 = __ZN2js11TokenStream9peekTokenEj($4, 8);
    if (($72 | 0) < 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    if (($72 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 23:
    var $77 = __ZN2js6Parser9statementEv($3);
    if (($77 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP8[$inDirectivePrologue] & 1) << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $84 = __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($3, $77, $inDirectivePrologue);
    if ($84) {
      __label__ = 26;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 26:
    var $86 = _js_FoldConstants($cx, $77, $21, 0);
    if (($86 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $89 = __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($3, $21);
    if ($89) {
      __label__ = 28;
      break;
    } else {
      var $script_0 = 0;
      __label__ = 54;
      break;
    }
   case 28:
    HEAP32[$70 >> 2] = 0;
    var $91 = _js_EmitTree($cx, $6, $77);
    if (($91 | 0) == 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $94 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($77, 2);
    if ($94) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $97 = HEAP32[$77 + 32 >> 2];
    if (($97 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $100 = __ZNK11JSParseNode7getKindEv($97);
    var $101 = __ZN2jsL13TreeTypeIsXMLENS_9TokenKindE($100);
    if ($101) {
      var $onlyXML_1 = $onlyXML_0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $onlyXML_1 = 0;
    __label__ = 33;
    break;
   case 33:
    var $onlyXML_1;
    var $104 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($77, $21);
    var $onlyXML_0 = $onlyXML_1;
    var $pn_0 = $77;
    __label__ = 21;
    break;
   case 34:
    if (($pn_0 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if (($onlyXML_0 & 1) << 24 >> 24 == 0 | $28) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $111 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($3, 0, 0, 79, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 37:
    var $113 = __ZNK15JSCodeGenerator9hasSharpsEv($6);
    if ($113) {
      __label__ = 38;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 38:
    var $116 = HEAP32[$cg + 172 >> 2];
    var $118 = HEAP32[$116 >> 2];
    var $124 = $118 + (HEAP32[$116 + 8 >> 2] - $118) | 0;
    var $code_0 = $118;
    __label__ = 39;
    break;
   case 39:
    var $code_0;
    if (($code_0 | 0) == ($124 | 0)) {
      __label__ = 50;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $129 = HEAPU8[$code_0] & 255;
    var $131 = HEAPU8[_js_CodeSpec + ($129 << 3) | 0];
    if ($131 << 24 >> 24 > 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $138 = $131 << 24 >> 24;
    __label__ = 43;
    break;
   case 42:
    var $136 = __Z28js_GetVariableBytecodeLengthPh($code_0);
    var $138 = $136;
    __label__ = 43;
    break;
   case 43:
    var $138;
    var $140 = HEAP32[_js_CodeSpec + ($129 << 3) + 4 >> 2];
    var $142 = ($140 & 16777216 | 0) == 0;
    if ($142) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    if ((($140 & 31) - 7 | 0) >>> 0 < 2) {
      __label__ = 45;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 45:
    var $146 = $code_0 + 1 | 0;
    var $150 = $code_0 + 2 | 0;
    var $153 = (HEAPU8[$146] & 255) << 8 | HEAPU8[$150] & 255;
    if ($142) {
      __label__ = 46;
      break;
    } else {
      var $slot_0 = $153;
      __label__ = 47;
      break;
    }
   case 46:
    var $155 = __ZNK15JSCodeGenerator10sharpSlotsEv($cg);
    var $slot_0 = $155 + $153 | 0;
    __label__ = 47;
    break;
   case 47:
    var $slot_0;
    if ($slot_0 >>> 0 > 65535) {
      __label__ = 55;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    HEAP8[$146] = $slot_0 >>> 8 & 255;
    HEAP8[$150] = $slot_0 & 255;
    __label__ = 49;
    break;
   case 49:
    var $code_0 = $code_0 + $138 | 0;
    __label__ = 39;
    break;
   case 50:
    var $165 = _js_Emit1($cx, $6, 197);
    if (($165 | 0) < 0) {
      var $script_0 = 0;
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $168 = $cx;
    var $169 = $cg;
    var $170 = __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($168, $169);
    var $171 = $170;
    if (($170 | 0) == 0) {
      var $script_0 = $171;
      __label__ = 54;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $174 = __ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript($cx, $globalScope, $171);
    if ($174) {
      var $script_0 = $171;
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 54:
    var $script_0;
    __ZN2js11GlobalScopeD1Ev($globalScope);
    var $_0 = $script_0;
    __label__ = 56;
    break;
   case 55:
    var $177 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($3, 0, 0, 199, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $script_0 = 0;
    __label__ = 54;
    break;
   case 56:
    var $_0;
    __ZN15JSCodeGeneratorD2Ev($6);
    var $_1 = $_0;
    __label__ = 57;
    break;
   case 57:
    var $_1;
    __ZN2js8CompilerD1Ev($compiler);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj["X"] = 1;

function __ZN2js8Compiler4initEPKtjPKcj9JSVersion($this, $base, $length, $filename, $lineno, $version) {
  var $1 = $this | 0;
  var $2 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($1, $base, $length, $filename, $lineno, $version);
  return $2;
}

function __ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg) {
  __ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg);
  return;
}

function __ZL14SetStaticLevelP13JSTreeContextj($tc, $staticLevel) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $staticLevel & 65535;
    var $2 = __ZN2js11UpvarCookie15isLevelReservedEt($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($7, 2, 0, 25, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_function_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$tc + 76 >> 2] = $staticLevel;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream13setStrictModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 64);
  return;
}

function __ZN2js11TokenStream23setOctalCharacterEscapeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 4096);
  return;
}

function __ZN2js11TokenStream9peekTokenEj($this, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream9peekTokenEv($this);
  __ZN2js11TokenStream7FlaggerD1Ev($flagger);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2jsL13TreeTypeIsXMLENS_9TokenKindE($tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tt - 67 | 0) >>> 0 < 3 | ($tt | 0) == 75) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($tt | 0) == 76;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6Parser9statementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__ + 4;
    var $stmtInfo1 = __stackBase__ + 36;
    var $stmtInfo4 = __stackBase__ + 68;
    var $stmtInfo11 = __stackBase__ + 100;
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 96;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($10 | 0) == 35) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 37) {
      __label__ = 14;
      break;
    } else if (($10 | 0) == 40) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 41) {
      __label__ = 19;
      break;
    } else if (($10 | 0) == 42) {
      __label__ = 26;
      break;
    } else if (($10 | 0) == 53) {
      __label__ = 27;
      break;
    } else if (($10 | 0) == 56) {
      __label__ = 28;
      break;
    } else if (($10 | 0) == 54) {
      __label__ = 33;
      break;
    } else if (($10 | 0) == 55) {
      __label__ = 34;
      break;
    } else if (($10 | 0) == 43) {
      __label__ = 35;
      break;
    } else if (($10 | 0) == 44) {
      __label__ = 49;
      break;
    } else if (($10 | 0) == 47) {
      __label__ = 66;
      break;
    } else if (($10 | 0) == 46) {
      __label__ = 67;
      break;
    } else if (($10 | 0) == 81) {
      __label__ = 69;
      break;
    } else if (($10 | 0) == 48) {
      __label__ = 70;
      break;
    } else if (($10 | 0) == 25) {
      __label__ = 71;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 80;
      break;
    } else if (($10 | 0) == 58) {
      __label__ = 82;
      break;
    } else if (($10 | 0) == 39) {
      __label__ = 84;
      break;
    } else if (($10 | 0) == -1) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 4:
    var $12 = __ZN2js11TokenStream9peekTokenEj($9, 32);
    if (($12 | 0) == 71) {
      __label__ = 94;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZN2js6Parser12functionStmtEv($this);
    var $_0 = $15;
    __label__ = 96;
    break;
   case 6:
    var $17 = $this + 980 | 0;
    var $18 = HEAP32[$17 >> 2];
    var $19 = __ZN2js11TernaryNode6createEP13JSTreeContext($18);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZN2js6Parser9conditionEv($this);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = HEAP32[$17 >> 2];
    var $28 = $stmtInfo;
    _js_PushStatement($27, $28, 1, -1);
    var $29 = __ZN2js6Parser9statementEv($this);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($9, 36, 8);
    if ($32) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    HEAP16[$stmtInfo >> 1] = 2;
    var $35 = __ZN2js6Parser9statementEv($this);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = $35 + 12 | 0;
    var $41 = $19 + 12 | 0;
    var $st$4$0 = $40 | 0;
    var $42$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $40 + 4 | 0;
    var $42$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $41 | 0;
    HEAP32[$st$8$0 >> 2] = $42$0;
    var $st$8$1 = $41 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $42$1;
    var $pn3_0 = $35;
    __label__ = 13;
    break;
   case 12:
    var $46 = $29 + 12 | 0;
    var $47 = $19 + 12 | 0;
    var $st$4$0 = $46 | 0;
    var $48$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $46 + 4 | 0;
    var $48$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $47 | 0;
    HEAP32[$st$8$0 >> 2] = $48$0;
    var $st$8$1 = $47 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $48$1;
    var $pn3_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $pn3_0;
    var $50 = HEAP32[$17 >> 2];
    __ZL12PopStatementP13JSTreeContext($50);
    var $51 = $19 + 32 | 0;
    HEAP32[$51 >> 2] = $23;
    var $52 = $19 + 36 | 0;
    HEAP32[$52 >> 2] = $29;
    var $53 = $19 + 40 | 0;
    HEAP32[$53 >> 2] = $pn3_0;
    var $_0 = $20;
    __label__ = 96;
    break;
   case 14:
    var $55 = __ZN2js6Parser15switchStatementEv($this);
    var $_0 = $55;
    __label__ = 96;
    break;
   case 15:
    var $57 = $this + 980 | 0;
    var $58 = HEAP32[$57 >> 2];
    var $59 = __ZN2js10BinaryNode6createEP13JSTreeContext($58);
    var $60 = $59 | 0;
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = HEAP32[$57 >> 2];
    _js_PushStatement($64, $stmtInfo1, 14, -1);
    var $65 = __ZN2js6Parser9conditionEv($this);
    if (($65 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = $59 + 32 | 0;
    HEAP32[$68 >> 2] = $65;
    var $69 = __ZN2js6Parser9statementEv($this);
    if (($69 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = HEAP32[$57 >> 2];
    __ZL12PopStatementP13JSTreeContext($72);
    var $75 = $69 + 12 | 0;
    var $76 = $59 + 12 | 0;
    var $st$6$0 = $75 | 0;
    var $77$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $75 + 4 | 0;
    var $77$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $76 | 0;
    HEAP32[$st$10$0 >> 2] = $77$0;
    var $st$10$1 = $76 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $77$1;
    var $78 = $59 + 36 | 0;
    HEAP32[$78 >> 2] = $69;
    var $_0 = $60;
    __label__ = 96;
    break;
   case 19:
    var $80 = $this + 980 | 0;
    var $81 = HEAP32[$80 >> 2];
    var $82 = __ZN2js10BinaryNode6createEP13JSTreeContext($81);
    var $83 = $82 | 0;
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $87 = HEAP32[$80 >> 2];
    _js_PushStatement($87, $stmtInfo4, 11, -1);
    var $88 = __ZN2js6Parser9statementEv($this);
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $91 = $82 + 32 | 0;
    HEAP32[$91 >> 2] = $88;
    var $92 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($92 | 0) == 40) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $95 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 84, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 23:
    var $97 = __ZN2js6Parser9conditionEv($this);
    if (($97 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $100 = HEAP32[$80 >> 2];
    __ZL12PopStatementP13JSTreeContext($100);
    var $103 = $97 + 12 | 0;
    var $104 = $82 + 12 | 0;
    var $st$6$0 = $103 | 0;
    var $105$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $103 + 4 | 0;
    var $105$1 = HEAP32[$st$6$1 >> 2];
    var $st$10$0 = $104 | 0;
    HEAP32[$st$10$0 >> 2] = $105$0;
    var $st$10$1 = $104 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $105$1;
    var $106 = $82 + 36 | 0;
    HEAP32[$106 >> 2] = $97;
    var $107 = __ZNK2js6Parser13versionNumberEv($this);
    if (($107 | 0) == 148) {
      var $pn_0 = $83;
      __label__ = 95;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $110 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 2);
    var $_0 = $83;
    __label__ = 96;
    break;
   case 26:
    var $112 = __ZN2js6Parser12forStatementEv($this);
    var $_0 = $112;
    __label__ = 96;
    break;
   case 27:
    var $114 = __ZN2js6Parser12tryStatementEv($this);
    var $_0 = $114;
    __label__ = 96;
    break;
   case 28:
    var $117 = HEAP32[$this + 980 >> 2];
    var $118 = __ZN2js9UnaryNode6createEP13JSTreeContext($117);
    var $119 = $118 | 0;
    if (($118 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $122 = __ZN2js11TokenStream17peekTokenSameLineEj($9, 8);
    if (($122 | 0) == 26 || ($122 | 0) == 2 || ($122 | 0) == 1 || ($122 | 0) == 0) {
      __label__ = 30;
      break;
    } else if (($122 | 0) == -1) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $124 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 31:
    var $126 = __ZN2js6Parser4exprEv($this);
    if (($126 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $131 = $126 + 12 | 0;
    var $132 = $118 + 12 | 0;
    var $st$4$0 = $131 | 0;
    var $133$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $131 + 4 | 0;
    var $133$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $132 | 0;
    HEAP32[$st$8$0 >> 2] = $133$0;
    var $st$8$1 = $132 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $133$1;
    __ZN11JSParseNode5setOpE4JSOp($119, 112);
    var $134 = $118 + 32 | 0;
    HEAP32[$134 >> 2] = $126;
    var $pn_0 = $119;
    __label__ = 95;
    break;
   case 33:
    var $136 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 119, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 34:
    var $138 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 120, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 35:
    var $140 = $this + 980 | 0;
    var $141 = HEAP32[$140 >> 2];
    var $142 = __ZN2js11NullaryNode6createEP13JSTreeContext($141);
    var $143 = $142 | 0;
    if (($142 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $146 = __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($9, $143);
    if (($146 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $151 = HEAP32[HEAP32[$140 >> 2] + 24 >> 2];
    var $154 = HEAP32[$142 + 32 >> 2];
    var $155 = ($154 | 0) != 0;
    if ($155) {
      var $stmt_0 = $151;
      __label__ = 38;
      break;
    } else {
      var $stmt_1 = $151;
      __label__ = 43;
      break;
    }
   case 38:
    var $stmt_0;
    if (($stmt_0 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $158 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 121, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 40:
    if (HEAP16[$stmt_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    if ((HEAP32[$stmt_0 + 20 >> 2] | 0) == ($154 | 0)) {
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $stmt_0 = HEAP32[$stmt_0 + 24 >> 2];
    __label__ = 38;
    break;
   case 43:
    var $stmt_1;
    if (($stmt_1 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $172 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 122, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 45:
    var $175 = HEAPU16[$stmt_1 >> 1];
    if (($175 & 65535) > 10 | $175 << 16 >> 16 == 5) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $stmt_1 = HEAP32[$stmt_1 + 24 >> 2];
    __label__ = 43;
    break;
   case 47:
    if ($155) {
      __label__ = 48;
      break;
    } else {
      var $pn_0 = $143;
      __label__ = 95;
      break;
    }
   case 48:
    var $182 = $142 + 12 | 0;
    var $183 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $185 = $183 + 12 | 0;
    var $186 = $182;
    var $st$5$0 = $185 | 0;
    var $187$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $185 + 4 | 0;
    var $187$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $186 | 0;
    HEAP32[$st$9$0 >> 2] = $187$0;
    var $st$9$1 = $186 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $187$1;
    var $pn_0 = $143;
    __label__ = 95;
    break;
   case 49:
    var $189 = $this + 980 | 0;
    var $190 = HEAP32[$189 >> 2];
    var $191 = __ZN2js11NullaryNode6createEP13JSTreeContext($190);
    var $192 = $191 | 0;
    if (($191 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    var $195 = __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($9, $192);
    if (($195 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $200 = HEAPU32[HEAP32[$189 >> 2] + 24 >> 2];
    var $203 = HEAP32[$191 + 32 >> 2];
    var $204 = ($203 | 0) != 0;
    if ($204) {
      var $stmt2_0 = 0;
      var $stmt9_0 = $200;
      __label__ = 52;
      break;
    } else {
      var $stmt9_1 = $200;
      __label__ = 60;
      break;
    }
   case 52:
    var $stmt9_0;
    var $stmt2_0;
    if (($stmt9_0 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $207 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 121, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 54:
    if (HEAP16[$stmt9_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 55;
      break;
    } else {
      var $stmt2_1 = $stmt9_0;
      __label__ = 59;
      break;
    }
   case 55:
    if ((HEAP32[$stmt9_0 + 20 >> 2] | 0) == ($203 | 0)) {
      __label__ = 56;
      break;
    } else {
      var $stmt2_1 = $stmt2_0;
      __label__ = 59;
      break;
    }
   case 56:
    if (($stmt2_0 | 0) == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if ((HEAPU16[$stmt2_0 >> 1] & 65535) > 10) {
      __label__ = 64;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $223 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 123, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 59:
    var $stmt2_1;
    var $stmt2_0 = $stmt2_1;
    var $stmt9_0 = HEAP32[$stmt9_0 + 24 >> 2];
    __label__ = 52;
    break;
   case 60:
    var $stmt9_1;
    if (($stmt9_1 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $229 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 123, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 62:
    if ((HEAPU16[$stmt9_1 >> 1] & 65535) > 10) {
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $stmt9_1 = HEAP32[$stmt9_1 + 24 >> 2];
    __label__ = 60;
    break;
   case 64:
    if ($204) {
      __label__ = 65;
      break;
    } else {
      var $pn_0 = $192;
      __label__ = 95;
      break;
    }
   case 65:
    var $238 = $191 + 12 | 0;
    var $239 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $241 = $239 + 12 | 0;
    var $242 = $238;
    var $st$5$0 = $241 | 0;
    var $243$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $241 + 4 | 0;
    var $243$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $242 | 0;
    HEAP32[$st$9$0 >> 2] = $243$0;
    var $st$9$1 = $242 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $243$1;
    var $pn_0 = $192;
    __label__ = 95;
    break;
   case 66:
    var $245 = __ZN2js6Parser13withStatementEv($this);
    var $_0 = $245;
    __label__ = 96;
    break;
   case 67:
    var $247 = __ZN2js6Parser9variablesEb($this, 0);
    if (($247 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $251 = $247 + 44 | 0;
    var $253 = HEAP32[$251 >> 2] | 4;
    HEAP32[$251 >> 2] = $253;
    var $pn_0 = $247;
    __label__ = 95;
    break;
   case 69:
    var $255 = __ZN2js6Parser12letStatementEv($this);
    var $_0 = $255;
    __label__ = 96;
    break;
   case 70:
    var $257 = __ZN2js6Parser13returnOrYieldEb($this, 0);
    if (($257 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      var $pn_0 = $257;
      __label__ = 95;
      break;
    }
   case 71:
    var $260 = $this + 980 | 0;
    var $262 = HEAP32[$260 >> 2] | 0;
    var $263 = HEAPU32[$262 >> 2];
    var $264 = $263 & -2049;
    HEAP32[$262 >> 2] = $264;
    var $265 = HEAP32[$260 >> 2];
    var $266 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo11, 4, $265);
    if ($266) {
      __label__ = 72;
      break;
    } else {
      var $_0 = 0;
      __label__ = 96;
      break;
    }
   case 72:
    var $268 = __ZN2js6Parser10statementsEv($this);
    if (($268 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $271 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($271 | 0) == 26) {
      __label__ = 75;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $274 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 101, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 75:
    var $276 = HEAP32[$260 >> 2];
    __ZL12PopStatementP13JSTreeContext($276);
    var $277 = HEAP32[$260 >> 2];
    var $279 = HEAP32[$277 >> 2];
    if (($279 & 2048 | 0) == 0) {
      var $297 = $277;
      var $296 = $279;
      __label__ = 79;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $284 = HEAP32[$277 + 24 >> 2];
    if (($284 | 0) == 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    if (HEAP16[$284 >> 1] << 16 >> 16 == 4) {
      __label__ = 78;
      break;
    } else {
      var $297 = $277;
      var $296 = $279;
      __label__ = 79;
      break;
    }
   case 78:
    var $292 = $268 + 44 | 0;
    var $294 = HEAP32[$292 >> 2] | 128;
    HEAP32[$292 >> 2] = $294;
    var $_pre = HEAP32[$260 >> 2];
    var $297 = $_pre;
    var $296 = HEAP32[$_pre >> 2];
    __label__ = 79;
    break;
   case 79:
    var $296;
    var $297;
    var $300 = $296 & 629442540 | $263;
    HEAP32[$297 >> 2] = $300;
    var $_0 = $268;
    __label__ = 96;
    break;
   case 80:
    var $303 = HEAP32[$this + 980 >> 2];
    var $304 = __ZN2js9UnaryNode6createEP13JSTreeContext($303);
    var $305 = $304 | 0;
    if (($304 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($305, 2);
    var $_0 = $305;
    __label__ = 96;
    break;
   case 82:
    var $309 = $this + 980 | 0;
    var $310 = HEAP32[$309 >> 2];
    var $311 = __ZN2js11NullaryNode6createEP13JSTreeContext($310);
    var $312 = $311 | 0;
    if (($311 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($312, 58);
    var $316 = HEAP32[$309 >> 2] | 0;
    var $318 = HEAP32[$316 >> 2] | 256;
    HEAP32[$316 >> 2] = $318;
    var $pn_0 = $312;
    __label__ = 95;
    break;
   case 84:
    var $320 = $this + 980 | 0;
    var $321 = HEAP32[$320 >> 2];
    var $322 = __ZN2js9UnaryNode6createEP13JSTreeContext($321);
    var $323 = $322 | 0;
    if (($322 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $326 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 29);
    if ($326) {
      __label__ = 86;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 86:
    var $328 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$328 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210424 >> 2] | 0)) {
      __label__ = 87;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 87:
    var $339 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 29);
    if ($339) {
      __label__ = 88;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 88:
    var $341 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$341 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210392 >> 2] | 0)) {
      __label__ = 89;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 89:
    var $352 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 4);
    if ($352) {
      __label__ = 90;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 90:
    var $354 = __ZNK2js11TokenStream12currentTokenEv($9);
    if ((HEAP32[$354 + 24 >> 2] | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $359 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 172, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 96;
    break;
   case 92:
    var $362 = HEAP32[$320 >> 2] | 0;
    var $364 = HEAP32[$362 >> 2] | 256;
    HEAP32[$362 >> 2] = $364;
    var $365 = __ZN2js6Parser4exprEv($this);
    if (($365 | 0) == 0) {
      var $_0 = 0;
      __label__ = 96;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 93:
    __ZN11JSParseNode5setOpE4JSOp($323, 163);
    var $370 = $365 + 12 | 0;
    var $371 = $322 + 12 | 0;
    var $st$5$0 = $370 | 0;
    var $372$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $370 + 4 | 0;
    var $372$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $371 | 0;
    HEAP32[$st$9$0 >> 2] = $372$0;
    var $st$9$1 = $371 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $372$1;
    var $373 = $322 + 32 | 0;
    HEAP32[$373 >> 2] = $365;
    var $pn_0 = $323;
    __label__ = 95;
    break;
   case 94:
    var $375 = __ZN2js6Parser19expressionStatementEv($this);
    var $_0 = $375;
    __label__ = 96;
    break;
   case 95:
    var $pn_0;
    var $377 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($9);
    var $379 = ($377 | 0) != 0 ? $pn_0 : 0;
    var $_0 = $379;
    __label__ = 96;
    break;
   case 96:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9statementEv["X"] = 1;

function __ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb($this, $pn, $isDirectivePrologueMember) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode21isStringExprStatementEv($pn);
    HEAP8[$isDirectivePrologueMember] = $1 & 1;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $5 = HEAPU32[$pn + 32 >> 2];
    var $6 = __ZNK11JSParseNode25isEscapeFreeStringLiteralEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 3:
    HEAP32[$pn + 40 >> 2] = 1;
    if ((HEAP32[$5 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210364 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $21 = $this + 40 | 0;
    var $22 = __ZNK2js11TokenStream23hasOctalCharacterEscapeEv($21);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $28 = HEAP32[$this + 980 >> 2] | 0;
    var $30 = HEAP32[$28 >> 2] | 262144;
    HEAP32[$28 >> 2] = $30;
    __ZN2js11TokenStream13setStrictModeEb($21, 1);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 84 | 0;
    __ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox($this, $1);
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser11markFunArgsEP13JSFunctionBox($this, $2);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = HEAP32[$1 >> 2];
    __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($this, $7, 0);
    var $8 = HEAP32[$1 >> 2];
    var $9 = $tc | 0;
    __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($this, $8, $9);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK15JSCodeGenerator10sharpSlotsEv($this) {
  var $1 = $this;
  var $2 = __ZNK15JSCodeGenerator9hasSharpsEv($1);
  var $3 = $2 ? 2 : 0;
  return $3;
}

function __ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript($cx, $globalScope, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__;
    var $worklist = __stackBase__ + 8;
    var $1 = __stackBase__ + 88;
    var $3 = HEAPU32[$globalScope >> 2];
    var $4 = $globalScope + 8 | 0;
    var $5 = $cx;
    var $6 = $3;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $8 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv($4);
    if ($i_0 >>> 0 < $8 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $11 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($4, $i_0);
    var $13 = HEAP32[$11 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL12ATOM_TO_JSIDP6JSAtom2903($13);
    var $18 = HEAP32[$11 + 4 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = __ZNK13JSFunctionBox8functionEv($18);
    var $22 = $21 | 0;
    __ZN2JS5Value9setObjectER8JSObject($rval, $22);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $3, $16, $rval);
    __label__ = 7;
    break;
   case 6:
    __ZN2JS5Value12setUndefinedEv($rval);
    __label__ = 7;
    break;
   case 7:
    var $25 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($5, $6, $16, $rval, 10, 12, 5, 0, 0, 16);
    if (($25 | 0) == 0) {
      var $_1 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = HEAP32[$25 + 24 >> 2];
    HEAP32[$11 + 8 >> 2] = $29;
    __label__ = 9;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 10:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_($worklist, $1);
    var $34 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($worklist, $script);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 11:
    var $35 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv($worklist);
    if (($35 | 0) == 0) {
      var $_0 = 1;
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv($worklist);
    var $39 = HEAPU32[$38 >> 2];
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv($worklist);
    var $41 = HEAP8[$39 + 16 | 0];
    var $42 = __ZN8JSScript13isValidOffsetEh($41);
    if ($42) {
      __label__ = 13;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 13:
    var $44 = __ZN8JSScript7objectsEv($39);
    var $50 = $44 + 4 | 0;
    var $51 = $44 | 0;
    var $52 = $39 + 37 | 0;
    var $i1_0 = (HEAPU8[$39 + 36 | 0] & 255) >>> 1 & 1 & 255;
    __label__ = 14;
    break;
   case 14:
    var $i1_0;
    if ($i1_0 >>> 0 < HEAPU32[$50 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 15:
    var $59 = HEAP32[HEAP32[$51 >> 2] + ($i1_0 << 2) >> 2];
    var $60 = __ZNK8JSObject10isFunctionEv($59);
    if ($60) {
      __label__ = 16;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 16:
    var $62 = __ZNK8JSObject18getFunctionPrivateEv($59);
    var $63 = __ZNK10JSFunction6scriptEv($62);
    var $64 = HEAP8[$52];
    if (($64 & 8) << 24 >> 24 == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = $64 | 16;
    HEAP8[$52] = $68;
    var $69 = $63 + 37 | 0;
    var $71 = HEAP8[$69] | 32;
    HEAP8[$69] = $71;
    __label__ = 18;
    break;
   case 18:
    var $74 = HEAP8[$63 + 20 | 0];
    var $75 = __ZN8JSScript13isValidOffsetEh($74);
    if ($75) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $78 = HEAP8[$63 + 16 | 0];
    var $79 = __ZN8JSScript13isValidOffsetEh($78);
    if ($79) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $81 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($worklist, $63);
    if ($81) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 21:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 14;
    break;
   case 22:
    var $85 = HEAP8[$39 + 20 | 0];
    var $86 = __ZN8JSScript13isValidOffsetEh($85);
    if ($86) {
      __label__ = 23;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 23:
    var $88 = __ZN8JSScript7globalsEv($39);
    var $90 = HEAP32[$88 + 4 >> 2];
    if (($90 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $92 = $88 | 0;
    var $i3_01 = 0;
    __label__ = 25;
    break;
   case 25:
    var $i3_01;
    var $95 = HEAP32[$92 >> 2] + ($i3_01 << 3) + 4 | 0;
    var $96 = HEAP32[$95 >> 2];
    var $97 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($4, $96);
    var $99 = HEAP32[$97 + 8 >> 2];
    HEAP32[$95 >> 2] = $99;
    var $100 = $i3_01 + 1 | 0;
    if (($100 | 0) == ($90 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $i3_01 = $100;
      __label__ = 25;
      break;
    }
   case 26:
    var $_0;
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev($worklist);
    var $_1 = $_0;
    __label__ = 27;
    break;
   case 27:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript["X"] = 1;

function __ZN2js11GlobalScopeD1Ev($this) {
  __ZN2js11GlobalScopeD2Ev($this);
  return;
}

function __ZN2js8CompilerD1Ev($this) {
  __ZN2js8CompilerD2Ev($this);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + $i * 12 | 0;
}

function __ZL12ATOM_TO_JSIDP6JSAtom2903($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj2961($1);
  return $2;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN8JSScript7globalsEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAPU8[$this + 20 | 0] & 255) | 0;
}

function __ZN10JSFunction11setArgCountEt($this, $nargs) {
  HEAP16[$this + 56 >> 1] = $nargs;
  return;
}

function __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($this, $newKind) {
  var $3 = $this + 4 + (HEAP32[$this + 132 >> 2] << 5) | 0;
  HEAP32[$3 >> 2] = $newKind;
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $lhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext16needStrictChecksEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($lhs, 29);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 1;
      __label__ = 9;
      break;
    }
   case 3:
    var $8 = HEAP32[$lhs + 32 >> 2];
    var $10 = HEAP32[$cx + 52 >> 2];
    if (($8 | 0) == (HEAP32[$10 + 210212 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($8 | 0) == (HEAP32[$10 + 210176 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_1 = 1;
      __label__ = 9;
      break;
    }
   case 5:
    __ZN16JSAutoByteStringC1Ev($name);
    var $21 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $8, $name);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $27 = __ZNK16JSAutoByteString3ptrEv($name);
    var $28 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $26, $1, $lhs, 236, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $27, tempInt));
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_1 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext16needStrictChecksEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 8;
      break;
    }
   case 2:
    var $5 = HEAP32[$cx + 52 >> 2];
    if ((HEAP32[$5 + 210212 >> 2] | 0) == ($atom | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$5 + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $atom | 0;
    var $17 = __ZNK12JSFlatString6charsZEv($16);
    var $18 = $atom | 0;
    var $19 = __ZNK8JSString6lengthEv($18);
    var $20 = __ZN2js11FindKeywordEPKtj($17, $19);
    if (($20 | 0) == 0) {
      var $_1 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN16JSAutoByteStringC1Ev($name);
    var $23 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $29 = __ZNK16JSAutoByteString3ptrEv($name);
    var $30 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $28, $1, $pn, 237, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $29, tempInt));
    var $_0 = $30;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($name);
    var $_1 = $_0;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12functionBodyEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2];
    var $4 = $stmtInfo;
    _js_PushStatement($3, $4, 4, -1);
    HEAP16[$stmtInfo + 2 >> 1] = 2;
    var $7 = HEAP32[$1 >> 2] | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 & -13;
    HEAP32[$7 >> 2] = $9;
    var $10 = $this + 40 | 0;
    var $11 = __ZNK2js11TokenStream12currentTokenEv($10);
    if ((HEAP32[$11 >> 2] | 0) == 25) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = __ZN2js6Parser10statementsEv($this);
    var $pn_0 = $16;
    __label__ = 8;
    break;
   case 3:
    var $18 = HEAP32[$1 >> 2];
    var $19 = __ZN2js9UnaryNode6createEP13JSTreeContext($18);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $pn_0 = $20;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = __ZN2js6Parser10assignExprEv($this);
    var $24 = $19 + 32 | 0;
    HEAP32[$24 >> 2] = $23;
    if (($23 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = HEAP32[$1 >> 2];
    if ((HEAP32[$27 >> 2] & 512 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = HEAP32[$this + 12 >> 2];
    var $35 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($34, $27, $20, 0, 208, 209);
    var $pn_1 = 0;
    __label__ = 13;
    break;
   case 7:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($20, 48);
    __ZN11JSParseNode5setOpE4JSOp($20, 5);
    var $40 = HEAP32[$24 >> 2] + 12 | 0;
    var $41 = $19 + 12 | 0;
    var $42$0 = HEAP32[$40 >> 2];
    var $42$1 = HEAP32[$40 + 4 >> 2];
    var $st$11$0 = $41 | 0;
    HEAP32[$st$11$0 >> 2] = $42$0;
    var $st$11$1 = $41 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $42$1;
    var $pn_0 = $20;
    __label__ = 8;
    break;
   case 8:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $47 = HEAP32[$1 >> 2];
    _js_PopStatement($47);
    var $49 = HEAP32[$this + 12 >> 2];
    var $50 = __ZNK9JSContext15hasStrictOptionEv($49);
    if ($50) {
      __label__ = 10;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    }
   case 10:
    var $52 = HEAP32[$1 >> 2];
    if ((HEAP32[$52 >> 2] & 4 | 0) == 0) {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $58 = __ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode($49, $52, $pn_0);
    if (($58 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 13;
      break;
    }
   case 12:
    var $pn_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $pn_1;
    var $62 = HEAP32[$1 >> 2] | 0;
    var $65 = HEAP32[$62 >> 2] & 629442528 | $8;
    HEAP32[$62 >> 2] = $65;
    STACKTOP = __stackBase__;
    return $pn_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12functionBodyEv["X"] = 1;

function __ZN2js9UnaryNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(1, $tc);
  return $1;
}

function __ZN2js6Parser10assignExprEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($9, 77, 8);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZN2js6Parser13returnOrYieldEb($this, 1);
    var $_0 = $12;
    __label__ = 15;
    break;
   case 5:
    var $14 = __ZN2js6Parser9condExpr1Ev($this);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($9, 4);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $_0 = $14;
    __label__ = 15;
    break;
   case 8:
    var $20 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $22 = HEAPU32[$20 + 24 >> 2];
    var $23 = __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $14, $22);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 9:
    var $25 = __ZN2js6Parser10assignExprEv($this);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($14, 29);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $30 = __ZNK11JSParseNode6isUsedEv($14);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = HEAP32[$14 + 36 >> 2];
    var $34 = $33;
    var $35 = __ZNK11JSParseNode10isAssignedEv($34);
    if ($35) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = $25 + 12 | 0;
    var $40 = $33 + 12 | 0;
    var $41$0 = HEAP32[$39 >> 2];
    var $41$1 = HEAP32[$39 + 4 >> 2];
    var $st$8$0 = $40 | 0;
    HEAP32[$st$8$0 >> 2] = $41$0;
    var $st$8$1 = $40 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $41$1;
    __label__ = 14;
    break;
   case 14:
    var $44 = HEAP32[$this + 980 >> 2];
    var $45 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, $22, $14, $25, $44);
    var $_0 = $45;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10assignExprEv["X"] = 1;

function __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($cx, $tc, $pn, $flags, $errnum, $anonerrnum) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    __ZN16JSAutoByteStringC1Ev($name);
    var $1 = $tc;
    var $2 = __ZNK13JSTreeContext3funEv($1);
    var $4 = HEAP32[$2 + 72 >> 2];
    if (($4 | 0) == 0) {
      var $_01 = $anonerrnum;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $4, $name);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $_01 = $errnum;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01;
    var $12 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $13 = __ZNK16JSAutoByteString3ptrEv($name);
    var $14 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $12, $pn, $flags, $_01, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $13, tempInt));
    var $_0 = $14 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN16JSAutoByteStringD1Ev($name);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14HasFinalReturnP11JSParseNode($pn);
    if (($1 | 0) == 1) {
      var $7 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($cx, $tc, $pn, 5, 110, 157);
    var $7 = ($4 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion($cx, $fun, $principals, $bindings, $chars, $length, $filename, $lineno, $version) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1640;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $compiler = __stackBase__;
    var $funcg = __stackBase__ + 996;
    var $names = __stackBase__ + 1612;
    var $1 = __stackBase__ + 1636;
    __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE($compiler, $cx, $principals, 0);
    var $2 = __ZN2js8Compiler4initEPKtjPKcj9JSVersion($compiler, $chars, $length, $filename, $lineno, $version);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 24;
      break;
    }
   case 2:
    var $4 = $compiler | 0;
    var $5 = $compiler + 40 | 0;
    var $6 = __ZNK2js11TokenStream9getLinenoEv($5);
    var $7 = $funcg;
    var $8 = $compiler;
    __ZN15JSCodeGeneratorC2EPN2js6ParserEj($7, $8, $6);
    var $9 = __ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE($7, $cx, 0);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 3:
    var $11 = $funcg | 0;
    var $12 = $funcg | 0;
    var $14 = HEAP32[$12 >> 2] | 2;
    HEAP32[$12 >> 2] = $14;
    var $15 = $funcg;
    __ZN13JSTreeContext11setFunctionEP10JSFunction($15, $fun);
    var $16 = $funcg + 92 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($16, undef, $bindings);
    var $17 = __ZNK2js8Bindings9countArgsEv($16);
    __ZN10JSFunction11setArgCountEt($fun, $17);
    var $18 = $funcg + 4 | 0;
    var $19 = __ZL15GenerateBlockIdP13JSTreeContextRj($11, $18);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 4:
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($5, 29);
    var $21 = __ZN2js12FunctionNode6createEP13JSTreeContext($11);
    var $22 = $21 | 0;
    if (($21 | 0) == 0) {
      var $fn_1 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$21 + 36 >> 2] = 0;
    var $27 = $21 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($27);
    var $29 = HEAPU16[$fun + 56 >> 1];
    var $30 = $29 & 65535;
    if ($29 << 16 >> 16 == 0) {
      var $fn_1 = $22;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($names, $1);
    var $33 = $16;
    var $34 = $names;
    var $35 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($33, undef, $34);
    if ($35) {
      var $i_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $fn_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $30 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $fn_0 = $22;
      __label__ = 10;
      break;
    }
   case 8:
    var $38 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($names, $i_0);
    var $39 = HEAP32[$38 >> 2];
    var $40 = __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($22, $39, $i_0, $11);
    if ($40) {
      __label__ = 9;
      break;
    } else {
      var $fn_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 10:
    var $fn_0;
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($names);
    var $fn_1 = $fn_0;
    __label__ = 11;
    break;
   case 11:
    var $fn_1;
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($5, 25);
    if (($fn_1 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = __ZN2js6Parser12functionBodyEv($4);
    if (($46 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($cx, $11);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      var $pn_1 = 0;
      __label__ = 22;
      break;
    }
   case 14:
    var $51 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($5, 0);
    if ($51) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $53 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($4, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $pn_1 = 0;
    __label__ = 22;
    break;
   case 16:
    var $55 = _js_FoldConstants($cx, $46, $11, 0);
    if (($55 | 0) == 0) {
      var $pn_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $58 = __ZN2js6Parser16analyzeFunctionsEP13JSTreeContext($4, $11);
    if ($58) {
      __label__ = 18;
      break;
    } else {
      var $pn_1 = 0;
      __label__ = 22;
      break;
    }
   case 18:
    var $60 = $fn_1 + 36 | 0;
    var $61 = HEAP32[$60 >> 2];
    if (($61 | 0) == 0) {
      var $pn_0 = $46;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = $61;
    __ZN11JSParseNode6appendEPS_($64, $46);
    var $68 = HEAP32[$60 >> 2] + 4 | 0;
    var $69 = $46 + 4 | 0;
    HEAP32[$68 >> 2] = HEAP32[$69 >> 2];
    HEAP32[$68 + 4 >> 2] = HEAP32[$69 + 4 >> 2];
    HEAP32[$68 + 8 >> 2] = HEAP32[$69 + 8 >> 2];
    HEAP32[$68 + 12 >> 2] = HEAP32[$69 + 12 >> 2];
    var $pn_0 = HEAP32[$60 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $pn_0;
    var $73 = _js_EmitFunctionScript($cx, $7, $pn_0);
    if (($73 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $pn_1 = $pn_0;
      __label__ = 22;
      break;
    }
   case 21:
    var $pn_1 = 0;
    __label__ = 22;
    break;
   case 22:
    var $pn_1;
    var $_0 = ($pn_1 | 0) != 0;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    __ZN15JSCodeGeneratorD2Ev($7);
    var $_1 = $_0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    __ZN2js8CompilerD1Ev($compiler);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion["X"] = 1;

function __ZN2js12FunctionNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(4, $tc);
  return $1;
}

function __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($pn, $atom, $i, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = $tc | 0;
    var $14 = HEAP32[$12 >> 2] | 64;
    HEAP32[$12 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    var $16 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc);
    var $17 = $16 | 0;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = $16 + 44 | 0;
    var $23 = HEAP32[$21 >> 2] | 4;
    HEAP32[$21 >> 2] = $23;
    var $24 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($17, $atom, $tc, 0);
    if ($24) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $26 = $pn + 36 | 0;
    var $27 = HEAP32[$26 >> 2];
    var $28 = $27;
    if (($27 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $argsbody_0 = $28;
      __label__ = 8;
      break;
    }
   case 6:
    var $31 = __ZN2js8ListNode6createEP13JSTreeContext($tc);
    var $32 = $31 | 0;
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($32, 84);
    __ZN11JSParseNode5setOpE4JSOp($32, 0);
    __ZN11JSParseNode9makeEmptyEv($32);
    HEAP32[$26 >> 2] = $31;
    var $argsbody_0 = $32;
    __label__ = 8;
    break;
   case 8:
    var $argsbody_0;
    __ZN11JSParseNode6appendEPS_($argsbody_0, $17);
    __ZN11JSParseNode5setOpE4JSOp($17, 84);
    var $37 = $16 + 40 | 0;
    var $40 = HEAP32[$tc + 76 >> 2] & 65535;
    var $41 = $i & 65535;
    __ZN2js11UpvarCookie3setEtt($37, $40, $41);
    var $43 = HEAP32[$21 >> 2] | 512;
    HEAP32[$21 >> 2] = $43;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext["X"] = 1;

function __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($cx, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $parameters = __stackBase__;
    var $1 = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $name = __stackBase__ + 40;
    var $p = __stackBase__ + 44;
    var $2 = __stackBase__ + 52;
    var $3 = __stackBase__ + 60;
    var $4 = $tc;
    var $5 = __ZN13JSTreeContext16needStrictChecksEv($4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 19;
      break;
    }
   case 2:
    var $7 = $tc + 92 | 0;
    var $8 = __ZNK2js8Bindings9countArgsEv($7);
    if ($8 << 16 >> 16 == 0) {
      var $_1 = 1;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$cx + 52 >> 2];
    var $15 = HEAP32[$12 + 210176 >> 2] | 0;
    var $18 = HEAP32[$12 + 210212 >> 2] | 0;
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
    __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($parameters, $1);
    var $19 = __ZNK2js8Bindings9countArgsEv($7);
    var $20 = $19 & 65535;
    var $21 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($parameters, $20);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $23 = $7;
    var $24 = __ZNK2js8Bindings12lastVariableEv($23);
    var $25 = $24;
    __ZN2js5Shape5RangeC1EPKS0_($r, $25);
    var $26 = $r;
    var $27 = $p | 0;
    var $28 = $2 | 0;
    __label__ = 5;
    break;
   case 5:
    var $30 = __ZNK2js5Shape5Range5emptyEv($26);
    if ($30) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $32 = __ZNK2js5Shape5Range5frontEv($r);
    var $34 = HEAP32[$32 + 12 >> 2];
    var $35 = __ZL12JSID_IS_ATOMi2955($34);
    if (($35 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $38 = __ZL12JSID_TO_ATOMi2949($34);
    HEAP32[$name >> 2] = $38;
    if (($38 | 0) == ($15 | 0) | ($38 | 0) == ($18 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $42 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $38, 237);
    if ($42) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $44 = __ZNK13JSTreeContext12inStrictModeEv($4);
    if ($44) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $46 = $38 | 0;
    var $47 = __ZNK12JSFlatString6charsZEv($46);
    var $48 = $38 | 0;
    var $49 = __ZNK8JSString6lengthEv($48);
    var $50 = __ZN2js11FindKeywordEPKtj($47, $49);
    if (($50 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $53 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $38, 132);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    __ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $parameters, $name);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $27);
    if ((HEAP32[$28 >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $58 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($27);
    if ((HEAP8[$58 + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $64 = HEAP32[$name >> 2];
    var $65 = __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $64, 111);
    if ($65) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 15:
    var $67 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($27);
    HEAP8[$67 + 4 | 0] = 1;
    __label__ = 17;
    break;
   case 16:
    HEAP8[$3] = 0;
    var $70 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb($parameters, $p, $name, $3);
    if ($70) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 5;
    break;
   case 18:
    var $_0;
    __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($parameters);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21CheckStrictParametersP9JSContextP13JSTreeContext["X"] = 1;

function __ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE($this, $tc, $atom, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $tc;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $3 = HEAP32[$_0 + 72 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $6 = $_0;
    var $7 = __ZNK13JSTreeContext10inFunctionEv($6);
    if ($7) {
      var $11 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK13JSTreeContext10scopeChainEv($6);
    var $11 = $9;
    __label__ = 5;
    break;
   case 5:
    var $11;
    var $13 = HEAP32[$this + 12 >> 2];
    var $15 = ($kind | 0) == 0 ? 16392 : 16384;
    var $16 = __Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom($13, 0, 0, 0, $15, $11, $atom);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK13JSTreeContext12compileAndGoEv($6);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 | 0;
    __ZN8JSObject11clearParentEv($21);
    __ZN8JSObject9clearTypeEv($21);
    __label__ = 8;
    break;
   case 8:
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11markFunArgsEP13JSFunctionBox($this, $funbox) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $queue = __stackBase__;
    var $upvars = __stackBase__ + 16;
    var $r = __stackBase__ + 20;
    var $1 = __stackBase__ + 40;
    __ZN18JSFunctionBoxQueueC1Ev($queue);
    var $3 = HEAP32[$this + 972 >> 2];
    var $4 = __ZN18JSFunctionBoxQueue4initEj($queue, $3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 12 >> 2];
    __Z20js_ReportOutOfMemoryP9JSContext($7);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 3:
    var $9 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($funbox, -1, $queue);
    var $10 = __ZN18JSFunctionBoxQueue4pullEv($queue);
    if (($10 | 0) == 0) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $upvars | 0;
    var $13 = $upvars | 0;
    var $15 = $10;
    __label__ = 5;
    break;
   case 5:
    var $15;
    var $19 = HEAP32[HEAP32[$15 + 24 >> 2] + 36 >> 2];
    var $20 = $19;
    var $21 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($20, 85);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZN18JSFunctionBoxQueue4pullEv($queue);
    if (($22 | 0) == 0) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      var $15 = $22;
      __label__ = 5;
      break;
    }
   case 7:
    var $27 = HEAP32[$19 + 32 >> 2];
    HEAP32[$12 >> 2] = $27;
    var $28 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($13);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $28);
    var $29 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = $15 + 56 | 0;
    __label__ = 9;
    break;
   case 9:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $33 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($1);
    var $34 = HEAP32[$33 >> 2];
    var $35 = __ZN12JSDefinition7resolveEv($34);
    var $36 = __ZNK12JSDefinition9isFreeVarEv($35);
    if ($36) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $35 | 0;
    var $39 = __ZNK11JSParseNode8isFunArgEv($38);
    if ($39) {
      __label__ = 20;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = __ZN12JSDefinition4kindEv($35);
    if (($41 | 0) == 3) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $44 = __ZNK11JSParseNode4isOpE4JSOp($38, 131);
    if ($44) {
      __label__ = 13;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    __ZN11JSParseNode9setFunArgEv($38);
    var $46 = __ZNK11JSParseNode4isOpE4JSOp($38, 131);
    if ($46) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $49 = $35 + 40 | 0;
    var $50 = __ZNK2js11UpvarCookie5levelEv($49);
    var $51 = $50 & 65535;
    var $55 = (HEAPU32[$31 >> 2] >>> 2 & 16383) + 1 | 0;
    if (($55 | 0) == ($51 | 0)) {
      var $afunbox_0_lcssa = $15;
      __label__ = 16;
      break;
    } else {
      var $afunbox_01 = $15;
      var $staticLevel_02 = $55;
      __label__ = 15;
      break;
    }
   case 15:
    var $staticLevel_02;
    var $afunbox_01;
    var $58 = HEAP32[$afunbox_01 + 36 >> 2];
    var $59 = $staticLevel_02 - 1 | 0;
    if (($59 | 0) == ($51 | 0)) {
      var $afunbox_0_lcssa = $58;
      __label__ = 16;
      break;
    } else {
      var $afunbox_01 = $58;
      var $staticLevel_02 = $59;
      __label__ = 15;
      break;
    }
   case 16:
    var $afunbox_0_lcssa;
    var $62 = HEAP32[$afunbox_0_lcssa + 24 >> 2];
    __ZN11JSParseNode9setFunArgEv($62);
    var $afunbox_1 = $afunbox_0_lcssa;
    __label__ = 18;
    break;
   case 17:
    var $afunbox_1 = HEAP32[$35 + 32 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $afunbox_1;
    __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($queue, $afunbox_1);
    var $69 = HEAPU32[$afunbox_1 + 32 >> 2];
    if (($69 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $76 = HEAPU32[$afunbox_1 + 56 >> 2] >>> 2 & 16383;
    var $77 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($69, $76, $queue);
    __label__ = 20;
    break;
   case 20:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $79 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($79) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 21:
    var $_0;
    __ZN18JSFunctionBoxQueueD1Ev($queue);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11markFunArgsEP13JSFunctionBox["X"] = 1;

function __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($this, $funbox, $hasExtensibleParent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($funbox | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_01 = $funbox;
      __label__ = 2;
      break;
    }
   case 2:
    var $_01;
    if ($hasExtensibleParent) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js8Bindings20setExtensibleParentsEv($_01 + 44 | 0);
    __label__ = 4;
    break;
   case 4:
    var $6 = HEAP32[$_01 + 32 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($hasExtensibleParent) {
      var $12 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $10 = __ZNK13JSFunctionBox17scopeIsExtensibleEv($_01);
    var $12 = $10;
    __label__ = 7;
    break;
   case 7:
    var $12;
    __ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb($this, $6, $12);
    __label__ = 8;
    break;
   case 8:
    var $15 = HEAP32[$_01 + 28 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_01 = $15;
      __label__ = 2;
      break;
    }
   case 9:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueue4pullEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == (HEAP32[$this + 4 >> 2] | 0)) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $7;
    var $14 = HEAP32[HEAP32[$this >> 2] + ((HEAP32[$this + 12 >> 2] & $2) << 2) >> 2];
    var $16 = $14 + 56 | 0;
    var $18 = HEAP32[$16 >> 2] & -2;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $14;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN11JSParseNode9setFunArgEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1073741824 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$this + 36 >> 2] + 44 | 0;
    var $_c = HEAP32[$8 >> 2] | 256;
    HEAP32[$8 >> 2] = $_c;
    __label__ = 3;
    break;
   case 3:
    var $14 = $this + 44 | 0;
    var $16 = HEAP32[$14 >> 2] | 256;
    HEAP32[$14 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($this, $funbox) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $funbox + 56 | 0;
    if ((HEAP32[$2 >> 2] & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this + 4 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = $8 + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    var $15 = HEAP32[$this >> 2] + ((HEAP32[$this + 12 >> 2] & $8) << 2) | 0;
    HEAP32[$15 >> 2] = $funbox;
    var $17 = HEAP32[$2 >> 2] | 1;
    HEAP32[$2 >> 2] = $17;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSFunction7setKindEt($this, $k) {
  var $1 = $this + 58 | 0;
  var $4 = HEAP16[$1 >> 1] & 16383 | $k;
  HEAP16[$1 >> 1] = $4;
  return;
}

function __ZN2js8Bindings20setExtensibleParentsEv($this) {
  HEAP8[$this + 10 | 0] = 1;
  return;
}

function __ZN12JSDefinition10kindStringENS_4KindE($kind) {
  return HEAP32[_table + ($kind << 2) >> 2];
}

function __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($this, $funbox, $tcflags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $upvars = __stackBase__;
    var $r = __stackBase__ + 4;
    var $1 = __stackBase__ + 24;
    var $upvars1 = __stackBase__ + 32;
    var $r2 = __stackBase__ + 36;
    var $2 = __stackBase__ + 56;
    if (($funbox | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $upvars | 0;
    var $5 = $upvars | 0;
    var $6 = $upvars1 | 0;
    var $7 = $upvars1 | 0;
    var $_06 = $funbox;
    __label__ = 3;
    break;
   case 3:
    var $_06;
    var $10 = HEAP32[$_06 + 24 >> 2];
    var $12 = HEAP32[$10 + 36 >> 2];
    var $13 = $12;
    var $15 = HEAP32[$_06 + 32 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj($this, $15, $tcflags);
    __ZL18ConsiderUnbrandingP13JSFunctionBox($_06);
    __label__ = 5;
    break;
   case 5:
    var $19 = __ZNK13JSFunctionBox8functionEv($_06);
    if ((HEAP32[$_06 + 60 >> 2] & 256 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    var $25 = __ZNK13JSFunctionBox17inAnyDynamicScopeEv($_06);
    if ($25) {
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($13, 85);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $31 = HEAP32[$12 + 32 >> 2];
    HEAP32[$4 >> 2] = $31;
    var $32 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($5);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $32);
    var $hasUpvars_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $hasUpvars_0;
    var $34 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $36 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($1);
    var $37 = HEAP32[$36 >> 2];
    var $38 = __ZN12JSDefinition7resolveEv($37);
    var $39 = __ZNK12JSDefinition9isFreeVarEv($38);
    if ($39) {
      var $hasUpvars_1 = $hasUpvars_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = HEAP32[$tcflags >> 2];
    var $42 = __ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj($38, $_06, $41);
    if ($42) {
      var $hasUpvars_1 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 12:
    var $hasUpvars_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $hasUpvars_0 = $hasUpvars_1;
    __label__ = 9;
    break;
   case 13:
    if (($hasUpvars_0 & 1) << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN10JSFunction7setKindEt($19, -16384);
    __label__ = 19;
    break;
   case 15:
    __ZN10JSFunction7setKindEt($19, -32768);
    var $48 = __ZNK11JSParseNode5getOpEv($10);
    if (($48 | 0) == 127) {
      __label__ = 16;
      break;
    } else if (($48 | 0) == 140) {
      __label__ = 17;
      break;
    } else if (($48 | 0) == 130) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    __ZN11JSParseNode5setOpE4JSOp($10, 222);
    __label__ = 19;
    break;
   case 17:
    __ZN11JSParseNode5setOpE4JSOp($10, 223);
    __label__ = 19;
    break;
   case 18:
    __ZN11JSParseNode5setOpE4JSOp($10, 224);
    __label__ = 19;
    break;
   case 19:
    var $52 = __ZNK10JSFunction4kindEv($19);
    if ($52 << 16 >> 16 == 16384) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $55 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($13, 85);
    if ($55) {
      __label__ = 21;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 21:
    var $59 = HEAP32[$12 + 32 >> 2];
    HEAP32[$6 >> 2] = $59;
    var $60 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($7);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r2, $60);
    var $61 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r2);
    if ($61) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($2, $r2);
    var $62 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($2);
    var $63 = HEAP32[$62 >> 2];
    var $64 = __ZN12JSDefinition7resolveEv($63);
    var $65 = __ZNK12JSDefinition9isFreeVarEv($64);
    if ($65) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj($64, $_06, $tcflags);
    __label__ = 24;
    break;
   case 24:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r2);
    var $68 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r2);
    if ($68) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 25:
    var $69 = __ZNK13JSFunctionBox8joinableEv($_06);
    if ($69) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    __ZN10JSFunction11setJoinableEv($19);
    __label__ = 27;
    break;
   case 27:
    var $73 = HEAP32[$_06 + 28 >> 2];
    if (($73 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $_06 = $73;
      __label__ = 3;
      break;
    }
   case 28:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj["X"] = 1;

function __ZN18JSFunctionBoxQueueC1Ev($this) {
  __ZN18JSFunctionBoxQueueC2Ev($this);
  return;
}

function __ZN18JSFunctionBoxQueue4initEj($this, $count) {
  var $1 = _JS_CeilingLog2($count);
  HEAP32[$this + 12 >> 2] = (1 << $1) - 1 | 0;
  var $5 = __ZN18JSFunctionBoxQueue6lengthEv($this);
  var $6 = $5 << 6;
  var $7 = __ZN2js11OffTheBooks7malloc_Ej($6);
  HEAP32[$this >> 2] = $7;
  return ($7 | 0) != 0;
}

function __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($funbox, $level, $queue) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __stackBase__ + 20;
    var $_0 = $funbox;
    var $allskipmin_0 = 16383;
    __label__ = 2;
    break;
   case 2:
    var $allskipmin_0;
    var $_0;
    var $4 = HEAPU32[$_0 + 24 >> 2];
    var $5 = __ZNK13JSFunctionBox8functionEv($_0);
    if ((HEAP32[$_0 + 60 >> 2] & 768 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN11JSParseNode9setFunArgEv($4);
    var $kid_03 = HEAP32[$_0 + 32 >> 2];
    if (($kid_03 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $kid_04 = $kid_03;
      __label__ = 4;
      break;
    }
   case 4:
    var $kid_04;
    var $14 = HEAP32[$kid_04 + 24 >> 2];
    __ZN11JSParseNode9setFunArgEv($14);
    var $kid_0 = HEAP32[$kid_04 + 28 >> 2];
    if (($kid_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $kid_04 = $kid_0;
      __label__ = 4;
      break;
    }
   case 5:
    var $18 = HEAP32[$4 + 36 >> 2];
    var $19 = $18;
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 85);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $skipmin_2 = 16383;
      __label__ = 14;
      break;
    }
   case 6:
    var $23 = $18 + 32 | 0;
    var $24 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($23);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $24);
    var $25 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($25) {
      var $skipmin_2 = 16383;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $_0 + 56 | 0;
    var $skipmin_01 = 16383;
    __label__ = 8;
    break;
   case 8:
    var $skipmin_01;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $29 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($1);
    var $30 = HEAP32[$29 >> 2];
    var $31 = __ZN12JSDefinition7resolveEv($30);
    var $32 = __ZNK12JSDefinition9isFreeVarEv($31);
    if ($32) {
      var $skipmin_1 = $skipmin_01;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $34 = $31 | 0;
    var $35 = __ZNK11JSParseNode10frameLevelEv($34);
    if (($35 | 0) > ($level | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode9setFunArgEv($4);
    __label__ = 11;
    break;
   case 11:
    var $43 = 1 - $35 + (HEAPU32[$27 >> 2] >>> 2 & 16383) | 0;
    if ($43 >>> 0 < $skipmin_01 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $skipmin_1 = $skipmin_01;
      __label__ = 13;
      break;
    }
   case 12:
    var $skipmin_1 = $43;
    __label__ = 13;
    break;
   case 13:
    var $skipmin_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $47 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($47) {
      var $skipmin_2 = $skipmin_1;
      __label__ = 14;
      break;
    } else {
      var $skipmin_01 = $skipmin_1;
      __label__ = 8;
      break;
    }
   case 14:
    var $skipmin_2;
    var $48 = __ZNK11JSParseNode8isFunArgEv($4);
    if ($48) {
      __label__ = 15;
      break;
    } else {
      var $fnlevel_0 = $level;
      __label__ = 16;
      break;
    }
   case 15:
    __ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox($queue, $_0);
    var $fnlevel_0 = HEAPU32[$_0 + 56 >> 2] >>> 2 & 16383;
    __label__ = 16;
    break;
   case 16:
    var $fnlevel_0;
    var $56 = HEAP32[$_0 + 32 >> 2];
    if (($56 | 0) == 0) {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $59 = __ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue($56, $fnlevel_0, $queue);
    if (($59 | 0) == 16383) {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = $59 - 1 | 0;
    if (($62 | 0) != 0 & $62 >>> 0 < $skipmin_2 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $skipmin_3 = $skipmin_2;
      __label__ = 20;
      break;
    }
   case 19:
    var $skipmin_3 = $62;
    __label__ = 20;
    break;
   case 20:
    var $skipmin_3;
    if (($skipmin_3 | 0) == 16383) {
      var $allskipmin_1 = $allskipmin_0;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP16[$5 + 64 >> 1] = $skipmin_3 & 65535;
    if ($skipmin_3 >>> 0 < $allskipmin_0 >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $allskipmin_1 = $allskipmin_0;
      __label__ = 23;
      break;
    }
   case 22:
    var $allskipmin_1 = $skipmin_3;
    __label__ = 23;
    break;
   case 23:
    var $allskipmin_1;
    var $76 = HEAPU32[$_0 + 28 >> 2];
    if (($76 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = $76;
      var $allskipmin_0 = $allskipmin_1;
      __label__ = 2;
      break;
    }
   case 24:
    STACKTOP = __stackBase__;
    return $allskipmin_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue["X"] = 1;

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($agg_result, $this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($1, $4);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($agg_result, $1);
    __label__ = 4;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $9 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_($agg_result, $6, $9);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 4;
    break;
   case 3:
    var $9 = $this | 0;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($9);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 8 >> 2];
    var $5 = $4 | 0;
    var $6 = $4 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($agg_result, $5, $6);
    __label__ = 4;
    break;
   case 3:
    var $8 = $this | 0;
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($8);
    var $10 = $9 | 0;
    var $11 = $9 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($agg_result, $10, $11);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12JSDefinition7resolveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK11JSParseNode6isDefnEv($1);
    if ($2) {
      var $pn_0_lcssa = $1;
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $pn_01;
    var $3 = __ZNK11JSParseNode7getKindEv($pn_01);
    if (($3 | 0) == 4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $pn_0_be = HEAP32[$pn_01 + 32 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $pn_0_be;
    var $8 = __ZNK11JSParseNode6isDefnEv($pn_0_be);
    if ($8) {
      var $pn_0_lcssa = $pn_0_be;
      __label__ = 6;
      break;
    } else {
      var $pn_01 = $pn_0_be;
      __label__ = 2;
      break;
    }
   case 5:
    var $10 = __ZNK11JSParseNode6lexdefEv($pn_01);
    var $pn_0_be = $10 | 0;
    __label__ = 4;
    break;
   case 6:
    var $pn_0_lcssa;
    return $pn_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK12JSDefinition9isFreeVarEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this + 40 | 0;
    var $3 = __ZNK2js11UpvarCookie6isFreeEv($2);
    if ($3) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZNK11JSParseNode4testEj($5, 64);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode8isFunArgEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 256);
  return $1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv($this);
    __label__ = 4;
    break;
   case 3:
    var $4 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($4);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueueD1Ev($this) {
  __ZN18JSFunctionBoxQueueD2Ev($this);
  return;
}

function __ZL18ConsiderUnbrandingP13JSFunctionBox($funbox) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $funbox + 60 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $6 = HEAP32[HEAP32[$funbox + 24 >> 2] + 36 >> 2];
    var $7 = $6;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 85);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $pn2_0 = $7;
      __label__ = 3;
      break;
    }
   case 2:
    var $pn2_0 = HEAP32[$6 + 36 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $pn2_0;
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 84);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $pn2_1 = $pn2_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK11JSParseNode4lastEv($pn2_0);
    var $pn2_1 = $15;
    __label__ = 5;
    break;
   case 5:
    var $pn2_1;
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 25);
    if ($17 & ($2 & 4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $method_01 = HEAP32[$funbox + 40 >> 2];
    if (($method_01 | 0) == 0) {
      var $slowMethodSets_0_lcssa = 0;
      __label__ = 8;
      break;
    } else {
      var $slowMethodSets_02 = 0;
      var $method_03 = $method_01;
      __label__ = 7;
      break;
    }
   case 7:
    var $method_03;
    var $slowMethodSets_02;
    var $26 = HEAP32[$method_03 + 32 >> 2];
    var $27 = __ZNK13JSFunctionBox8joinableEv($26);
    var $slowMethodSets_0_ = ($27 & 1 ^ 1) + $slowMethodSets_02 | 0;
    var $method_0 = HEAPU32[$method_03 + 28 >> 2];
    if (($method_0 | 0) == 0) {
      var $slowMethodSets_0_lcssa = $slowMethodSets_0_;
      __label__ = 8;
      break;
    } else {
      var $slowMethodSets_02 = $slowMethodSets_0_;
      var $method_03 = $method_0;
      __label__ = 7;
      break;
    }
   case 8:
    var $slowMethodSets_0_lcssa;
    var $32 = __ZNK13JSFunctionBox13shouldUnbrandEjj($funbox, undef, $slowMethodSets_0_lcssa);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$1 >> 2] = $2 | 1048576;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj($dn, $funbox, $tcflags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dn | 0;
    var $2 = __ZNK11JSParseNode10frameLevelEv($1);
    var $afunbox_0 = $funbox;
    __label__ = 2;
    break;
   case 2:
    var $afunbox_0;
    var $6 = HEAPU32[$afunbox_0 + 56 >> 2];
    if (($6 >>> 2 & 16383 | 0) == ($2 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAPU32[$afunbox_0 + 36 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$12 + 24 >> 2];
    var $17 = __ZNK11JSParseNode8isFunArgEv($16);
    if ($17) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$12 + 60 >> 2] & 512 | 0) == 0) {
      var $afunbox_0 = $12;
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 6:
    if (($6 & 2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $28 = HEAPU32[$afunbox_0 + 36 >> 2];
    var $29 = ($28 | 0) == 0;
    if ($29) {
      var $34 = $tcflags;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = HEAP32[$28 + 60 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $34;
    if (($34 & 256 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 10:
    var $38 = __ZNK13JSFunctionBox8functionEv($afunbox_0);
    if ((HEAP16[$38 + 58 >> 1] & 8) << 16 >> 16 == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $44 = __ZN12JSDefinition13isBindingFormEv($dn);
    if ($44) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = $dn + 4 | 0;
    var $49 = HEAP32[$afunbox_0 + 24 >> 2] + 4 | 0;
    var $50 = __ZN2js8TokenPosgeERKS0_($46, $49);
    if ($50) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = __ZNK11JSParseNode13isInitializedEv($1);
    if ($52) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $54 = __ZN12JSDefinition4kindEv($dn);
    if (($54 | 0) == 1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $56 = __ZNK11JSParseNode10isAssignedEv($1);
    if ($56) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($54 | 0) == 4) {
      __label__ = 17;
      break;
    } else if (($54 | 0) == 3) {
      __label__ = 22;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    if ($29) {
      var $63 = $tcflags;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $63 = HEAP32[$28 + 60 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $63;
    if (($63 & 128 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 20:
    var $66 = $dn + 12 | 0;
    var $68 = HEAPU32[$afunbox_0 + 24 >> 2];
    var $69 = $68 + 12 | 0;
    var $70 = __ZN2js8TokenPtrgeERKS0_($66, $69);
    if ($70) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $75 = HEAPU32[$dn + 44 >> 2] >>> 12;
    var $76 = __ZL10MinBlockIdP11JSParseNodej($68, $75);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj["X"] = 1;

function __ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj($dn, $funbox, $tcflags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dn | 0;
    var $2 = __ZNK11JSParseNode10frameLevelEv($1);
    var $3 = ($2 | 0) == 0;
    var $_0 = $funbox;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    var $6 = HEAPU32[$_0 + 36 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (((HEAPU32[$6 + 56 >> 2] >>> 2 & 16383) + 1 | 0) == ($2 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = $6 + 60 | 0;
    var $18 = HEAP32[$16 >> 2] | 256;
    HEAP32[$16 >> 2] = $18;
    __label__ = 11;
    break;
   case 5:
    if ($3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $21 = __ZNK11JSParseNode5isLetEv($1);
    if ($21) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $6 + 60 | 0;
    var $25 = HEAP32[$23 >> 2] | 256;
    HEAP32[$23 >> 2] = $25;
    __label__ = 11;
    break;
   case 8:
    var $27 = $6 + 60 | 0;
    var $29 = HEAP32[$27 >> 2] | 4194304;
    HEAP32[$27 >> 2] = $29;
    var $_0 = $6;
    __label__ = 2;
    break;
   case 9:
    var $30 = HEAP32[$tcflags >> 2];
    if (($30 & 2 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = $30 | 256;
    HEAP32[$tcflags >> 2] = $34;
    __label__ = 11;
    break;
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSFunction11setJoinableEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2JSL9NullValueEv2953($1);
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  var $3 = $this + 58 | 0;
  var $5 = HEAP16[$3 >> 1] | 1;
  HEAP16[$3 >> 1] = $5;
  STACKTOP = __stackBase__;
  return;
}

function __ZN11JSParseNode7setDefnEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & 2147483647 | ($enabled & 1) << 31;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN11JSParseNode9makeEmptyEv($this) {
  var $1 = $this + 32 | 0;
  HEAP32[$1 >> 2] = 0;
  HEAP32[$this + 36 >> 2] = $1;
  HEAP32[$this + 40 >> 2] = 0;
  HEAP32[$this + 44 >> 2] = 0;
  return;
}

function __ZN13JSTreeContext11atBodyLevelEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      var $10 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = (HEAP16[$2 + 2 >> 1] & 2) << 16 >> 16 != 0;
    __label__ = 3;
    break;
   case 3:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode($this, $funtc, $funbox, $listp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $data = __stackBase__;
    var $slot = __stackBase__ + 20;
    var $slot1 = __stackBase__ + 24;
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEv($1);
    if (($2 | 0) == 27) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 69, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 3:
    var $7 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 28);
    if ($7) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $data | 0;
    var $9 = $data + 4 | 0;
    var $10 = $data + 8 | 0;
    var $11 = $funtc + 92 | 0;
    var $12 = $this + 12 | 0;
    var $13 = $funtc + 76 | 0;
    var $14 = $funtc + 40 | 0;
    var $15 = $funbox + 24 | 0;
    var $list_0 = 0;
    var $destructuringArg_0 = 0;
    var $duplicatedArg_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $duplicatedArg_0;
    var $destructuringArg_0;
    var $list_0;
    var $17 = __ZN2js11TokenStream8getTokenEv($1);
    if (($17 | 0) == 23 || ($17 | 0) == 25) {
      __label__ = 6;
      break;
    } else if (($17 | 0) == 29) {
      __label__ = 15;
      break;
    } else if (($17 | 0) == -1) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 6:
    if (($duplicatedArg_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $duplicatedArg_2 = $duplicatedArg_0;
      __label__ = 20;
      break;
    }
   case 7:
    __ZN8BindDataC1Ev($data);
    HEAP32[$8 >> 2] = 0;
    HEAP32[$9 >> 2] = 129;
    HEAP32[$10 >> 2] = 206;
    var $21 = __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $17);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = HEAP32[$12 >> 2];
    var $25 = __ZN2js8Bindings16addDestructuringEP9JSContextPt($11, $24, $slot);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 9:
    var $32 = HEAP32[HEAP32[HEAP32[$12 >> 2] + 52 >> 2] + 209972 >> 2] | 0;
    var $33 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($32, $funtc);
    var $34 = $33 | 0;
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($34, 29);
    __ZN11JSParseNode5setOpE4JSOp($34, 84);
    var $38 = $33 + 40 | 0;
    var $40 = HEAP32[$13 >> 2] & 65535;
    var $41 = HEAP16[$slot >> 1];
    __ZN2js11UpvarCookie3setEtt($38, $40, $41);
    var $43 = $33 + 44 | 0;
    var $45 = HEAP32[$43 >> 2] | 512;
    HEAP32[$43 >> 2] = $45;
    var $46 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, 0, $21, $34, $funtc);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($list_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $list_1 = $list_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $51 = __ZN2js8ListNode6createEP13JSTreeContext($funtc);
    var $52 = $51 | 0;
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($52, 46);
    __ZN11JSParseNode9makeEmptyEv($52);
    HEAP32[$listp >> 2] = $52;
    var $list_1 = $52;
    __label__ = 14;
    break;
   case 14:
    var $list_1;
    __ZN11JSParseNode6appendEPS_($list_1, $46);
    var $list_2 = $list_1;
    var $destructuringArg_1 = 1;
    var $duplicatedArg_3 = $duplicatedArg_0;
    __label__ = 21;
    break;
   case 15:
    var $57 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $59 = HEAPU32[$57 + 28 >> 2];
    var $60 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($14, $59);
    if (($60 | 0) == 0) {
      var $duplicatedArg_1 = $duplicatedArg_0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($destructuringArg_0 & 1) << 24 >> 24 == 0) {
      var $duplicatedArg_1 = $59;
      __label__ = 17;
      break;
    } else {
      var $duplicatedArg_2 = $59;
      __label__ = 20;
      break;
    }
   case 17:
    var $duplicatedArg_1;
    var $66 = HEAP32[$12 >> 2];
    var $67 = __ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt($11, $66, $59, $slot1);
    if ($67) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 18:
    var $69 = HEAP32[$15 >> 2];
    var $71 = HEAPU16[$slot1 >> 1] & 65535;
    var $72 = __ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext($69, $59, $71, $funtc);
    if ($72) {
      var $list_2 = $list_0;
      var $destructuringArg_1 = $destructuringArg_0;
      var $duplicatedArg_3 = $duplicatedArg_1;
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 19:
    var $74 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 70, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 20:
    var $duplicatedArg_2;
    var $76 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($14, $duplicatedArg_2);
    var $77 = $76 | 0;
    var $78 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $77, 0, 76, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 21:
    var $duplicatedArg_3;
    var $destructuringArg_1;
    var $list_2;
    var $80 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($80) {
      var $list_0 = $list_2;
      var $destructuringArg_0 = $destructuringArg_1;
      var $duplicatedArg_0 = $duplicatedArg_3;
      __label__ = 5;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $82 = __ZN2js11TokenStream8getTokenEv($1);
    if (($82 | 0) == 28) {
      var $_0 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $85 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 71, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode["X"] = 1;

function __ZN8BindDataC1Ev($this) {
  __ZN8BindDataC2Ev($this);
  return;
}

function __ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 48 | 0;
    if ((HEAP32[HEAP32[HEAP32[HEAP32[$1 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0) == ($atom | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = $tc | 0;
    var $14 = HEAP32[$12 >> 2] | 64;
    HEAP32[$12 >> 2] = $14;
    __label__ = 3;
    break;
   case 3:
    var $16 = $tc + 40 | 0;
    var $17 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($16, $atom);
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $21 = HEAP32[$1 >> 2] + 40 | 0;
    var $22 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $21, 0, 0, 76, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $25 = HEAP32[$data >> 2];
    __ZN11JSParseNode5setOpE4JSOp($25, 87);
    var $27 = $25 + 44 | 0;
    var $29 = HEAP32[$27 >> 2] | 512;
    HEAP32[$27 >> 2] = $29;
    var $30 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($25, $atom, $tc, 0);
    var $_0 = $30 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $tt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $5 = HEAP32[$3 >> 2] | 65536;
    HEAP32[$3 >> 2] = $5;
    var $6 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $tt, 0);
    var $8 = HEAP32[$1 >> 2] | 0;
    var $10 = HEAP32[$8 >> 2] & -65537;
    HEAP32[$8 >> 2] = $10;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = HEAP32[$this + 12 >> 2];
    var $15 = HEAP32[$1 >> 2];
    var $16 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($14, $data, $6, $15);
    var $_ = $16 ? $6 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings16addDestructuringEP9JSContextPt($this, $cx, $slotp) {
  var $2 = HEAP16[$this + 4 >> 1];
  HEAP16[$slotp >> 1] = $2;
  var $3 = $this;
  var $4 = $cx;
  var $5 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($3, $4, 0, 1);
  return $5;
}

function __ZN2js8ListNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(5, $tc);
  return $1;
}

function __ZN2js9AtomDecls11lookupFirstEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $3 = HEAP32[$this + 4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $3, $1);
    var $4 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $8 = $7;
    var $9 = __ZNK2js12DefnOrHeader8isHeaderEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZNK2js12DefnOrHeader6headerEv($8);
    var $_0 = HEAP32[$11 >> 2];
    __label__ = 5;
    break;
   case 4:
    var $15 = __ZNK2js12DefnOrHeader4defnEv($8);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $funAtom, $type, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 148;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $name = __stackBase__ + 4;
    var $index = __stackBase__ + 8;
    var $funtc = __stackBase__ + 12;
    var $prelude = __stackBase__ + 120;
    var $iter = __stackBase__ + 124;
    HEAP32[$1 >> 2] = $funAtom;
    var $2 = $this + 40 | 0;
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($2, 34, 0);
    var $3 = $this + 980 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZN2js12FunctionNode6createEP13JSTreeContext($4);
    var $6 = $5 | 0;
    if (($5 | 0) == 0) {
      var $_2 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $5 + 36 | 0;
    HEAP32[$9 >> 2] = 0;
    var $11 = $5 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($11);
    var $12 = HEAP32[$3 >> 2];
    var $13 = __ZN13JSTreeContext11atBodyLevelEv($12);
    var $14 = ($kind | 0) == 0;
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = $5 + 44 | 0;
    var $19 = HEAP32[$16 >> 2] & -4096 | 256;
    HEAP32[$16 >> 2] = $19;
    var $pn_2 = $6;
    var $120 = 0;
    __label__ = 21;
    break;
   case 4:
    var $phitmp = $13 ? 0 : 256;
    var $22 = $5 + 44 | 0;
    var $25 = HEAP32[$22 >> 2] & -4096 | $phitmp;
    HEAP32[$22 >> 2] = $25;
    var $26 = ($kind | 0) == 1;
    if ($26) {
      __label__ = 5;
      break;
    } else {
      var $pn_2 = $6;
      var $120 = 0;
      __label__ = 21;
      break;
    }
   case 5:
    var $29 = HEAP32[$3 >> 2] + 40 | 0;
    var $30 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($29, $funAtom);
    if (($30 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = __ZN12JSDefinition4kindEv($30);
    var $34 = $this + 12 | 0;
    var $35 = HEAP32[$34 >> 2];
    var $36 = __ZNK9JSContext15hasStrictOptionEv($35);
    if ($36 | ($33 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    __ZN16JSAutoByteStringC1Ev($name);
    var $39 = HEAP32[$34 >> 2];
    var $40 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($39, $funAtom, $name);
    if (($40 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $44 = ($33 | 0) != 1 ? 5 : 0;
    var $45 = __ZN12JSDefinition10kindStringENS_4KindE($33);
    var $46 = __ZNK16JSAutoByteString3ptrEv($name);
    var $47 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, $44, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $45, HEAP32[tempInt + 4 >> 2] = $46, tempInt));
    if ($47) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_2 = 0;
    __label__ = 71;
    break;
   case 10:
    __ZN16JSAutoByteStringD1Ev($name);
    __label__ = 11;
    break;
   case 11:
    if ($13) {
      __label__ = 12;
      break;
    } else {
      var $pn_2 = $6;
      var $120 = $26;
      __label__ = 21;
      break;
    }
   case 12:
    var $52 = HEAP32[$3 >> 2] + 40 | 0;
    var $53 = $5;
    __ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition($52, $funAtom, $53);
    __ZN11JSParseNode7setDefnEb($6, 1);
    var $54 = $30 | 0;
    var $55 = $5 + 28 | 0;
    HEAP32[$55 >> 2] = $54;
    var $56 = HEAP32[$3 >> 2];
    var $57 = __ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext($30, $6, $funAtom, $56);
    if (($57 | 0) == 0) {
      var $_2 = 0;
      __label__ = 71;
      break;
    } else {
      var $pn_19 = $6;
      var $89 = $funAtom;
      __label__ = 17;
      break;
    }
   case 13:
    if ($13) {
      __label__ = 14;
      break;
    } else {
      var $pn_2 = $6;
      var $120 = 1;
      __label__ = 21;
      break;
    }
   case 14:
    var $62 = HEAP32[$3 >> 2] + 64 | 0;
    var $63 = __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($62, $funAtom);
    if (($63 | 0) == 0) {
      var $pn_0 = $6;
      var $86 = $funAtom;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $66 = $63 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($66, 34);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($66, 4);
    var $69 = $5 + 4 | 0;
    var $70 = $63 + 4 | 0;
    var $71$0 = HEAP32[$69 >> 2];
    var $71$1 = HEAP32[$69 + 4 >> 2];
    var $st$11$0 = $70 | 0;
    HEAP32[$st$11$0 >> 2] = $71$0;
    var $st$11$1 = $70 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $71$1;
    var $74 = $5 + 12 | 0;
    var $75 = $63 + 12 | 0;
    var $76$0 = HEAP32[$74 >> 2];
    var $76$1 = HEAP32[$74 + 4 >> 2];
    var $st$23$0 = $75 | 0;
    HEAP32[$st$23$0 >> 2] = $76$0;
    var $st$23$1 = $75 + 4 | 0;
    HEAP32[$st$23$1 >> 2] = $76$1;
    var $77 = $63 + 36 | 0;
    HEAP32[$77 >> 2] = 0;
    var $79 = $63 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($79);
    var $81 = HEAP32[$3 >> 2] + 64 | 0;
    var $82 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($81);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($82, $1);
    var $83 = HEAP32[$3 >> 2];
    var $84 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($6, $83);
    var $pn_0 = $66;
    var $86 = HEAP32[$1 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $86;
    var $pn_0;
    var $87 = HEAP32[$3 >> 2];
    var $88 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($pn_0, $86, $87, 0);
    if ($88) {
      var $pn_19 = $pn_0;
      var $89 = $86;
      __label__ = 17;
      break;
    } else {
      var $_2 = 0;
      __label__ = 71;
      break;
    }
   case 17:
    var $89;
    var $pn_19;
    var $90 = HEAP32[$3 >> 2];
    var $91 = $90;
    var $92 = __ZNK13JSTreeContext10inFunctionEv($91);
    if ($92) {
      __label__ = 18;
      break;
    } else {
      var $pn_2 = $pn_19;
      var $120 = $26;
      __label__ = 21;
      break;
    }
   case 18:
    var $95 = $this + 12 | 0;
    var $97 = $90 + 92 | 0;
    var $98 = HEAP32[$95 >> 2];
    var $99 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($97, $98, $89, $index);
    if (($99 | 0) == 0 || ($99 | 0) == 1) {
      __label__ = 19;
      break;
    } else if (($99 | 0) == 2) {
      __label__ = 20;
      break;
    } else {
      var $pn_2 = $pn_19;
      var $120 = $26;
      __label__ = 21;
      break;
    }
   case 19:
    var $102 = HEAP32[$3 >> 2] + 92 | 0;
    var $103 = __ZNK2js8Bindings9countVarsEv($102);
    var $104 = $103 & 65535;
    HEAP32[$index >> 2] = $104;
    var $105 = HEAP32[$95 >> 2];
    var $106 = __ZN2js8Bindings11addVariableEP9JSContextP6JSAtom($102, $105, $89);
    if ($106) {
      __label__ = 20;
      break;
    } else {
      var $_2 = 0;
      __label__ = 71;
      break;
    }
   case 20:
    var $113 = HEAP32[HEAP32[$3 >> 2] + 76 >> 2] & 65535;
    var $115 = HEAP32[$index >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($pn_19 + 40 | 0, $113, $115);
    var $117 = $pn_19 + 44 | 0;
    var $119 = HEAP32[$117 >> 2] | 512;
    HEAP32[$117 >> 2] = $119;
    var $pn_2 = $pn_19;
    var $120 = $26;
    __label__ = 21;
    break;
   case 21:
    var $120;
    var $pn_2;
    var $121 = HEAPU32[$3 >> 2];
    var $123 = HEAP32[$121 + 48 >> 2];
    __ZN13JSTreeContextC1EPN2js6ParserE($funtc, $123);
    var $124 = $this + 12 | 0;
    var $125 = HEAP32[$124 >> 2];
    var $126 = $funtc;
    var $127 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($126, $125, 0);
    if ($127) {
      __label__ = 22;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 22:
    var $129 = HEAPU32[$1 >> 2];
    var $130 = __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($pn_2, $funtc, $129, $kind);
    if (($130 | 0) == 0) {
      var $_1 = 0;
      __label__ = 70;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $133 = __ZNK13JSFunctionBox8functionEv($130);
    HEAP32[$prelude >> 2] = 0;
    var $134 = __ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode($this, $funtc, $130, $prelude);
    if ($134) {
      __label__ = 24;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 24:
    var $136 = $funtc + 92 | 0;
    var $137 = __ZNK2js8Bindings9countArgsEv($136);
    __ZN10JSFunction11setArgCountEt($133, $137);
    var $138 = HEAPU32[$prelude >> 2];
    var $139 = ($138 | 0) == 0;
    if ($139) {
      __label__ = 29;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $141 = $funtc + 40 | 0;
    __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($iter, $141);
    __label__ = 26;
    break;
   case 26:
    var $142 = __ZN2js13AtomDeclsIterclEv($iter);
    if (($142 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $145 = $142 | 0;
    var $146 = __ZNK11JSParseNode4isOpE4JSOp($145, 87);
    if ($146) {
      __label__ = 28;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 28:
    var $148 = HEAP32[$124 >> 2];
    var $149 = __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($148, $funtc, $145, 2);
    if ($149) {
      __label__ = 26;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 29:
    if (($type | 0) == 0) {
      __label__ = 30;
      break;
    } else if (($type | 0) == 1) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 30:
    if (HEAP16[$133 + 56 >> 1] << 16 >> 16 == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $155 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 251, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_getter_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str22883 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_1 = 0;
    __label__ = 70;
    break;
   case 32:
    if (HEAP16[$133 + 56 >> 1] << 16 >> 16 == 1) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $161 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 251, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_setter_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str52886 | 0, HEAP32[tempInt + 8 >> 2] = __str93064 | 0, tempInt));
    var $_1 = 0;
    __label__ = 70;
    break;
   case 34:
    var $163 = __ZN2js11TokenStream8getTokenEj($2, 8);
    var $164 = ($163 | 0) == 25;
    if ($164) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    __ZN2js11TokenStream10ungetTokenEv($2);
    var $166 = $133 + 58 | 0;
    var $168 = HEAP16[$166 >> 1] | 4096;
    HEAP16[$166 >> 1] = $168;
    __label__ = 36;
    break;
   case 36:
    var $170 = __ZN2js6Parser12functionBodyEv($this);
    if (($170 | 0) == 0) {
      var $_1 = 0;
      __label__ = 70;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    if (($129 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $175 = HEAP32[$124 >> 2];
    var $176 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($175, $funtc, $129, $pn_2);
    if ($176) {
      __label__ = 39;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 39:
    var $178 = HEAP32[$124 >> 2];
    var $179 = __ZL21CheckStrictParametersP9JSContextP13JSTreeContext($178, $funtc);
    if ($179) {
      __label__ = 40;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 40:
    if ($164) {
      __label__ = 41;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 41:
    var $182 = __ZN2js11TokenStream8getTokenEj($2, 0);
    if (($182 | 0) == 26) {
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $185 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 73, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 70;
    break;
   case 43:
    if ($120) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $188 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($2);
    if (($188 | 0) == 0) {
      var $_1 = 0;
      __label__ = 70;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $191 = $pn_2 + 12 | 0;
    var $192 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $194 = $192 + 12 | 0;
    var $195 = $191;
    var $196$0 = HEAP32[$194 >> 2];
    var $196$1 = HEAP32[$194 + 4 >> 2];
    HEAP32[$195 >> 2] = $196$0;
    HEAP32[$195 + 4 >> 2] = $196$1;
    var $197 = __ZNK13JSTreeContext9callsEvalEv($126);
    if ($197) {
      __label__ = 46;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 46:
    __ZN13JSTreeContext13noteCallsEvalEv($121);
    __label__ = 47;
    break;
   case 47:
    if ($139) {
      var $body_1 = $170;
      __label__ = 55;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $201 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($170, 5);
    if ($201) {
      var $body_0 = $170;
      __label__ = 51;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $203 = __ZN2js8ListNode6createEP13JSTreeContext($121);
    var $204 = $203 | 0;
    if (($203 | 0) == 0) {
      var $_1 = 0;
      __label__ = 70;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($204, 82);
    var $209 = $203 + 4 | 0;
    var $210 = $170 + 4 | 0;
    HEAP32[$209 >> 2] = HEAP32[$210 >> 2];
    HEAP32[$209 + 4 >> 2] = HEAP32[$210 + 4 >> 2];
    HEAP32[$209 + 8 >> 2] = HEAP32[$210 + 8 >> 2];
    HEAP32[$209 + 12 >> 2] = HEAP32[$210 + 12 >> 2];
    __ZN11JSParseNode8initListEPS_($204, $170);
    var $body_0 = $204;
    __label__ = 51;
    break;
   case 51:
    var $body_0;
    var $212 = __ZN2js9UnaryNode6createEP13JSTreeContext($121);
    var $213 = $212 | 0;
    if (($212 | 0) == 0) {
      var $_1 = 0;
      __label__ = 70;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($213, 2);
    var $216 = $212 + 4 | 0;
    var $219 = $body_0 + 4 | 0;
    var $220 = $212 + 12 | 0;
    var $221$0 = HEAP32[$219 >> 2];
    var $221$1 = HEAP32[$219 + 4 >> 2];
    HEAP32[$220 >> 2] = $221$0;
    HEAP32[$220 + 4 >> 2] = $221$1;
    var $222 = $216;
    HEAP32[$222 >> 2] = $221$0;
    HEAP32[$222 + 4 >> 2] = $221$1;
    HEAP32[$212 + 32 >> 2] = $138;
    var $224 = $body_0 + 32 | 0;
    var $225 = HEAP32[$224 >> 2];
    var $226 = $212 + 24 | 0;
    HEAP32[$226 >> 2] = $225;
    HEAP32[$224 >> 2] = $213;
    var $227 = $body_0 + 36 | 0;
    if ((HEAP32[$227 >> 2] | 0) == ($224 | 0)) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    HEAP32[$227 >> 2] = $226;
    __label__ = 54;
    break;
   case 54:
    var $232 = $body_0 + 40 | 0;
    var $234 = HEAP32[$232 >> 2] + 1 | 0;
    HEAP32[$232 >> 2] = $234;
    var $236 = $body_0 + 44 | 0;
    var $238 = HEAP32[$236 >> 2] | 512;
    HEAP32[$236 >> 2] = $238;
    var $body_1 = $body_0;
    __label__ = 55;
    break;
   case 55:
    var $body_1;
    if ((HEAP32[$funtc >> 2] & 256 | 0) == 0) {
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    var $245 = $133 + 58 | 0;
    var $247 = HEAP16[$245 >> 1] | 128;
    HEAP16[$245 >> 1] = $247;
    var $248 = $121 | 0;
    var $250 = HEAP32[$248 >> 2] | 256;
    HEAP32[$248 >> 2] = $250;
    __label__ = 59;
    break;
   case 57:
    if ($13 | $120 ^ 1) {
      __label__ = 59;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    var $253 = $121 | 0;
    var $255 = HEAP32[$253 >> 2] | 256;
    HEAP32[$253 >> 2] = $255;
    __label__ = 59;
    break;
   case 59:
    var $_mux = $14 ? 130 : 0;
    if ($14 | $13) {
      var $op_0 = $_mux;
      __label__ = 61;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    __ZN13JSTreeContext20noteMightAliasLocalsEv($121);
    var $op_0 = 127;
    __label__ = 61;
    break;
   case 61:
    var $op_0;
    var $260 = HEAP32[$funtc + 84 >> 2];
    HEAP32[$130 + 32 >> 2] = $260;
    HEAP32[$pn_2 + 32 >> 2] = $130;
    __ZN11JSParseNode5setOpE4JSOp($pn_2, $op_0);
    var $263 = $pn_2 + 36 | 0;
    var $264 = HEAP32[$263 >> 2];
    if (($264 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $267 = $264;
    __ZN11JSParseNode6appendEPS_($267, $body_1);
    var $271 = HEAP32[$263 >> 2] + 4 | 0;
    var $272 = $body_1 + 4 | 0;
    HEAP32[$271 >> 2] = HEAP32[$272 >> 2];
    HEAP32[$271 + 4 >> 2] = HEAP32[$272 + 4 >> 2];
    HEAP32[$271 + 8 >> 2] = HEAP32[$272 + 8 >> 2];
    HEAP32[$271 + 12 >> 2] = HEAP32[$272 + 12 >> 2];
    __label__ = 64;
    break;
   case 63:
    HEAP32[$263 >> 2] = $body_1;
    __label__ = 64;
    break;
   case 64:
    var $275 = $121;
    var $276 = __ZNK13JSTreeContext10inFunctionEv($275);
    if ($276 | $13 ^ 1 | $120 ^ 1) {
      __label__ = 67;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $278 = __ZNK13JSTreeContext9compilingEv($121);
    if ($278) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    var $280 = __ZN13JSTreeContext15asCodeGeneratorEv($275);
    var $281 = $280;
    var $282 = HEAP32[$1 >> 2];
    var $283 = __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn_2, $281, $282);
    if ($283) {
      __label__ = 67;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 67:
    var $285 = __ZN13JSTreeContext7blockidEv($275);
    var $287 = $pn_2 + 44 | 0;
    var $291 = HEAP32[$287 >> 2] & 4095 | $285 << 12;
    HEAP32[$287 >> 2] = $291;
    var $292 = HEAP32[$1 >> 2];
    var $293 = __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($pn_2, $funtc, $292, $kind);
    if ($293) {
      __label__ = 68;
      break;
    } else {
      var $_1 = 0;
      __label__ = 70;
      break;
    }
   case 68:
    var $295 = __ZNK13JSTreeContext12inStrictModeEv($275);
    if ($295) {
      var $_1 = $pn_2;
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    __ZN2js11TokenStream13setStrictModeEb($2, 0);
    var $_1 = $pn_2;
    __label__ = 70;
    break;
   case 70:
    var $_1;
    __ZN13JSTreeContextD1Ev($funtc);
    var $_2 = $_1;
    __label__ = 71;
    break;
   case 71:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE["X"] = 1;

function __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($this, $newKind, $newOp) {
  __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE($this, $newKind);
  __ZN2js11TokenStream17mungeCurrentTokenE4JSOp($this, $newOp);
  return;
}

function __ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $atom;
    var $4 = HEAP32[$this + 4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $4, $1);
    var $5 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $6 = $5;
    var $7 = __ZNK2js12DefnOrHeader8isHeaderEv($6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK2js12DefnOrHeader6headerEv($6);
    HEAP32[$9 >> 2] = $defn;
    __label__ = 4;
    break;
   case 3:
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($2, $defn);
    var $13 = HEAP32[$2 >> 2];
    HEAP32[$5 >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream10ungetTokenEv($this) {
  var $1 = $this + 136 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  var $4 = $this + 132 | 0;
  var $7 = HEAP32[$4 >> 2] + 3 & 3;
  HEAP32[$4 >> 2] = $7;
  return;
}

function __ZN13JSTreeContext13noteCallsEvalEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 8388608;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN13JSTreeContext20noteMightAliasLocalsEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 67108864;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK13JSTreeContext9compilingEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext($dn, $pn, $atom, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN12JSDefinition13isBindingFormEv($dn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = $dn | 0;
    var $4 = __ZNK11JSParseNode4exprEv($3);
    if (($4 | 0) == 0) {
      var $_01 = $dn;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $7 = __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($3, $4, $tc_idx_val);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_01;
    var $12 = $_01 | 0;
    var $13 = __ZNK11JSParseNode5getOpEv($12);
    var $18 = (HEAP32[_js_CodeSpec + ($13 << 3) + 4 >> 2] & 256 | 0) != 0 ? 111 : 59;
    __ZN11JSParseNode5setOpE4JSOp($12, $18);
    var $_1 = $_01;
    __label__ = 8;
    break;
   case 6:
    var $20 = __ZN12JSDefinition4kindEv($dn);
    if (($20 | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $dn;
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = $dn | 0;
    __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($23, $tc);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($23, 29);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($23, 6);
    HEAP32[$dn + 32 >> 2] = $atom;
    var $_1 = $dn;
    __label__ = 8;
    break;
   case 8:
    var $_1;
    var $26 = $_1 | 0;
    var $pnu_03 = HEAP32[$_1 + 28 >> 2];
    if (($pnu_03 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $41 = HEAP32[$pn + 44 >> 2];
    var $_c_pre_phi = $pn;
    __label__ = 12;
    break;
   case 10:
    var $_c2 = $pn;
    var $30 = $pn + 44 | 0;
    var $pnu_04 = $pnu_03;
    __label__ = 11;
    break;
   case 11:
    var $pnu_04;
    HEAP32[$pnu_04 + 36 >> 2] = $_c2;
    var $38 = HEAP32[$30 >> 2] | HEAP32[$pnu_04 + 44 >> 2] & 2312;
    HEAP32[$30 >> 2] = $38;
    var $pnu_0 = HEAP32[$pnu_04 + 28 >> 2];
    if (($pnu_0 | 0) == 0) {
      var $41 = $38;
      var $_c_pre_phi = $_c2;
      __label__ = 12;
      break;
    } else {
      var $pnu_04 = $pnu_0;
      __label__ = 11;
      break;
    }
   case 12:
    var $_c_pre_phi;
    var $41;
    var $43 = $_1 + 44 | 0;
    var $48 = $41 | HEAP32[$43 >> 2] & 2312;
    HEAP32[$pn + 44 >> 2] = $48;
    HEAP32[$pn + 28 >> 2] = $26;
    __ZN11JSParseNode7setDefnEb($26, 0);
    __ZN11JSParseNode7setUsedEb($26, 1);
    HEAP32[$_1 + 36 >> 2] = $_c_pre_phi;
    __ZN2js11UpvarCookie8makeFreeEv($_1 + 40 | 0);
    var $54 = HEAP32[$43 >> 2] & -513;
    HEAP32[$43 >> 2] = $54;
    var $_0 = $26;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext["X"] = 1;

function __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $3 = HEAP32[$this >> 2];
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($p, $3, $1);
    var $4 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($p);
    if (($4 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($p);
    var $10 = HEAP32[$7 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($p, $this, $key);
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($p);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($this, $p);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($pn, $atom, $tc, $let) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $atom;
    if ($let) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $tc + 40 | 0;
    var $4 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($3, $atom);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $dn_1 = $4;
      var $foundLexdep_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = $tc + 64 | 0;
    var $7 = __ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom($6, $atom);
    var $dn_1 = $7;
    var $foundLexdep_0 = ($7 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $foundLexdep_0;
    var $dn_1;
    if (($dn_1 | 0) == 0 | ($dn_1 | 0) == ($pn | 0)) {
      var $58 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $dn_1 + 28 | 0;
    if ($let) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = $pn + 44 | 0;
    var $24 = HEAPU32[$17 >> 2] >>> 12;
    var $_pre_phi3 = $17;
    __label__ = 8;
    break;
   case 7:
    var $24 = HEAP32[$tc + 4 >> 2];
    var $_pre_phi3 = $pn + 44 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi3;
    var $24;
    var $_c = $pn;
    var $pnup_0 = $14;
    __label__ = 9;
    break;
   case 9:
    var $pnup_0;
    var $26 = HEAPU32[$pnup_0 >> 2];
    var $27 = ($26 | 0) != 0;
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 10:
    var $31 = HEAPU32[$26 + 44 >> 2];
    if ($31 >>> 12 >>> 0 < $24 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$26 + 36 >> 2] = $_c;
    var $38 = HEAP32[$_pre_phi3 >> 2] | $31 & 2312;
    HEAP32[$_pre_phi3 >> 2] = $38;
    var $pnup_0 = $26 + 28 | 0;
    __label__ = 9;
    break;
   case 12:
    if (($26 | 0) == (HEAP32[$14 >> 2] | 0)) {
      var $58 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = $pn + 28 | 0;
    var $44 = HEAP32[$43 >> 2];
    HEAP32[$pnup_0 >> 2] = $44;
    var $45 = HEAP32[$14 >> 2];
    HEAP32[$43 >> 2] = $45;
    HEAP32[$14 >> 2] = $26;
    if ($27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if (HEAPU32[$26 + 44 >> 2] >>> 12 >>> 0 >= HEAPU32[$tc + 4 >> 2] >>> 0 | $foundLexdep_0 ^ 1) {
      var $58 = $atom;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if ($foundLexdep_0) {
      __label__ = 16;
      break;
    } else {
      var $58 = $atom;
      __label__ = 17;
      break;
    }
   case 16:
    var $55 = $tc + 64 | 0;
    var $56 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($55);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($56, $1);
    var $58 = HEAP32[$1 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $58;
    var $59 = $tc + 40 | 0;
    if ($let) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $61 = $59;
    var $62 = $pn;
    var $63 = __ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition($61, $58, $62);
    if ($63) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $65 = $pn;
    var $66 = __ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition($59, $58, $65);
    if ($66) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 20:
    __ZN11JSParseNode7setDefnEb($pn, 1);
    var $69 = $pn + 44 | 0;
    var $70 = HEAP32[$69 >> 2];
    var $71 = $70 & -129;
    HEAP32[$69 >> 2] = $71;
    if ((HEAP32[$tc + 72 >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 21:
    var $77 = $70 & -145 | 16;
    HEAP32[$69 >> 2] = $77;
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb["X"] = 1;

function __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($fn, $funtc, $funAtom, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$funtc + 72 >> 2];
    var $3 = $2 + 48 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = __ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE($4, $2, $funAtom, $kind);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$3 >> 2];
    var $9 = $5 | 0;
    var $10 = __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($8, $9, $fn, $2);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $funtc | 0;
    var $17 = HEAP32[$15 >> 2] | HEAP32[$10 + 60 >> 2];
    HEAP32[$15 >> 2] = $17;
    var $19 = HEAP32[$2 + 8 >> 2];
    HEAP32[$funtc + 8 >> 2] = $19;
    var $21 = $funtc + 4 | 0;
    var $22 = __ZL15GenerateBlockIdP13JSTreeContextRj($funtc, $21);
    if ($22) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $24 = $funtc;
    __ZN13JSTreeContext11setFunctionEP10JSFunction($24, $5);
    HEAP32[$funtc + 80 >> 2] = $10;
    var $28 = HEAP32[$2 + 76 >> 2] + 1 | 0;
    var $29 = __ZL14SetStaticLevelP13JSTreeContextj($funtc, $28);
    var $_ = $29 ? $10 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($this, $decls) {
  __ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE($this, $decls);
  return;
}

function __ZN2js13AtomDeclsIterclEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$3 + 4 >> 2];
    HEAP32[$2 >> 2] = $9;
    var $_0 = $7;
    __label__ = 7;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv($11);
    if ($12) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv($1, $11);
    var $14 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv($1);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv($11);
    var $15 = $14;
    var $16 = __ZNK2js12DefnOrHeader8isHeaderEv($15);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK2js12DefnOrHeader4defnEv($15);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 6:
    var $21 = __ZNK2js12DefnOrHeader6headerEv($15);
    var $24 = HEAP32[$21 + 4 >> 2];
    HEAP32[$2 >> 2] = $24;
    var $_0 = HEAP32[$21 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($cx, $tc, $pn, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 92 | 0;
    var $2 = __ZNK2js8Bindings9countVarsEv($1);
    var $5 = HEAP32[$pn + 32 >> 2];
    var $6 = $1;
    var $7 = $cx;
    var $8 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($6, $7, $5, $kind);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $pn + 40 | 0;
    var $14 = HEAP32[$tc + 76 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($11, $14, $2);
    var $16 = $pn + 44 | 0;
    var $18 = HEAP32[$16 >> 2] | 512;
    HEAP32[$16 >> 2] = $18;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8getTokenEj($this, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream8getTokenEv($this);
  __ZN2js11TokenStream7FlaggerD1Ev($flagger);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($ts) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekTokenSameLineEj($ts, 8);
    if (($1 | 0) == 26 || ($1 | 0) == 2 || ($1 | 0) == 1 || ($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js11TokenStream8getTokenEj($ts, 8);
    var $4 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $ts, 0, 0, 109, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($ts, 2);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn, $cg, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $holder = __stackBase__ + 20;
    var $prop = __stackBase__ + 24;
    var $def = __stackBase__ + 28;
    var $index = __stackBase__ + 40;
    HEAP32[$1 >> 2] = $atom;
    var $2 = $cg;
    var $3 = __ZN13JSTreeContext8compilerEv($2);
    var $5 = HEAP32[$3 + 992 >> 2];
    var $7 = HEAP32[$5 >> 2];
    var $8 = __ZNK13JSTreeContext12compileAndGoEv($2);
    if (($7 | 0) == 0 | $8 ^ 1) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZNK15JSCodeGenerator16compilingForEvalEv($cg);
    if ($11) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $5 + 216 | 0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $13, $1);
    var $14 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 4:
    var $20 = HEAP32[HEAP32[$cg + 48 >> 2] + 12 >> 2];
    var $21 = HEAP32[$1 >> 2];
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom2903($21);
    var $23 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($7, $20, $22, $holder, $prop);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      var $32 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = HEAP32[$pn + 32 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $32;
    var $33 = HEAP32[$prop >> 2];
    if (($33 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = $33;
    if (($32 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 9:
    if (($7 | 0) == (HEAP32[$holder >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 10:
    var $42 = $33;
    var $43 = __ZNK2js5Shape12configurableEv($42);
    if ($43) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $45 = __ZNK2js5Shape7hasSlotEv($36);
    if ($45) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 12:
    var $47 = __ZNK2js5Shape26hasDefaultGetterOrIsMethodEv($36);
    if ($47) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 13:
    var $49 = __ZNK2js5Shape16hasDefaultSetterEv($36);
    if ($49) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 21;
      break;
    }
   case 14:
    var $52 = HEAP32[$36 + 24 >> 2];
    __ZN2js11GlobalScope9GlobalDefC1Ej($def, $52);
    __label__ = 16;
    break;
   case 15:
    __ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox($def, $21, $32);
    __label__ = 16;
    break;
   case 16:
    var $56 = $5 + 8 | 0;
    var $57 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($56, $def);
    if ($57) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 17:
    var $59 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($13);
    HEAP32[$index >> 2] = $59;
    var $60 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($13, $p, $1, $index);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $62 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($62) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $64 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $65 = HEAP32[$64 >> 2];
    var $68 = HEAP32[$pn + 32 >> 2];
    var $70 = $5 + 8 | 0;
    var $71 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj($70, $65);
    var $72 = $71 + 4 | 0;
    HEAP32[$72 >> 2] = $68;
    __label__ = 20;
    break;
   case 20:
    var $75 = $pn + 44 | 0;
    var $77 = HEAP32[$75 >> 2] | 64;
    HEAP32[$75 >> 2] = $77;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom["X"] = 1;

function __ZNK11JSParseNode10isInParensEv($this) {
  return (HEAP32[$this >> 2] & 536870912 | 0) != 0;
}

function __ZNK2js11TokenStream23hasOctalCharacterEscapeEv($this) {
  return (HEAP32[$this + 144 >> 2] & 4096 | 0) != 0;
}

function __ZNK2js11TokenStream5isEOFEv($this) {
  return (HEAP32[$this + 144 >> 2] & 2 | 0) != 0;
}

function __ZN13JSTreeContext22noteHasExtensibleScopeEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 536870912;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($fn, $funtc, $funAtom, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $r = __stackBase__ + 4;
    var $atom = __stackBase__ + 24;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $outer_dn = __stackBase__ + 44;
    var $p = __stackBase__ + 48;
    var $iter = __stackBase__ + 64;
    HEAP32[$1 >> 2] = $funAtom;
    var $5 = HEAPU32[$funtc + 72 >> 2];
    var $7 = HEAP32[$funtc + 8 >> 2];
    HEAP32[$5 + 8 >> 2] = $7;
    var $11 = HEAPU32[$fn + 32 >> 2];
    var $15 = $11 + 60 | 0;
    var $17 = HEAP32[$15 >> 2] | HEAP32[$funtc >> 2] & 629450724;
    HEAP32[$15 >> 2] = $17;
    var $19 = $fn + 44 | 0;
    var $20 = HEAP32[$19 >> 2];
    var $21 = $20 | 4;
    HEAP32[$19 >> 2] = $21;
    var $23 = HEAP32[$5 + 24 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAP16[$23 >> 1] << 16 >> 16 == 4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $30 = $20 | 36;
    HEAP32[$19 >> 2] = $30;
    __label__ = 4;
    break;
   case 4:
    var $32 = $funtc + 64 | 0;
    var $33 = $32 | 0;
    var $34 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($33);
    var $35 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($34);
    if (($35 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $_pre_phi6 = $funtc;
    __label__ = 44;
    break;
   case 6:
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $34);
    var $38 = ($kind | 0) == 0;
    var $39 = $funtc + 76 | 0;
    var $40 = $funtc + 4 | 0;
    var $41 = $5 + 40 | 0;
    var $42 = $funtc;
    var $43 = $fn + 4 | 0;
    var $44 = $5 + 64 | 0;
    var $45 = $5 + 88 | 0;
    var $foundCallee_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $foundCallee_0;
    var $47 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($47) {
      __label__ = 38;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($2, $r);
    var $49 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv($2);
    var $50 = HEAPU32[$49 >> 2];
    HEAP32[$atom >> 2] = $50;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($3, $r);
    var $51 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($3);
    var $52 = HEAPU32[$51 >> 2];
    if (($50 | 0) == ($funAtom | 0) & $38) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $55 = $52 | 0;
    __ZN11JSParseNode5setOpE4JSOp($55, 131);
    var $57 = $52 + 40 | 0;
    var $59 = HEAP32[$39 >> 2] & 65535;
    __ZN2js11UpvarCookie3setEtt($57, $59, -1);
    var $61 = $52 + 44 | 0;
    var $63 = HEAP32[$61 >> 2] | 512;
    HEAP32[$61 >> 2] = $63;
    var $64 = __ZNK11JSParseNode8isFunArgEv($55);
    if ($64) {
      __label__ = 10;
      break;
    } else {
      var $foundCallee_1 = 1;
      __label__ = 37;
      break;
    }
   case 10:
    var $67 = HEAP32[$15 >> 2] | 1024;
    HEAP32[$15 >> 2] = $67;
    var $foundCallee_1 = 1;
    __label__ = 37;
    break;
   case 11:
    var $69 = HEAPU32[$15 >> 2];
    if (($69 & 32 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 12:
    var $73 = $52 | 0;
    var $74 = __ZNK11JSParseNode10isAssignedEv($73);
    if ($74) {
      __label__ = 13;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 13:
    var $pnu_0_in = $52 + 28 | 0;
    __label__ = 14;
    break;
   case 14:
    var $pnu_0_in;
    var $pnu_0 = HEAPU32[$pnu_0_in >> 2];
    if (($pnu_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $80 = __ZNK11JSParseNode10isAssignedEv($pnu_0);
    if ($80) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    if (HEAPU32[$pnu_0 + 44 >> 2] >>> 12 >>> 0 < HEAPU32[$40 >> 2] >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$15 >> 2] = $69 | 32;
    __label__ = 19;
    break;
   case 18:
    var $pnu_0_in = $pnu_0 + 28 | 0;
    __label__ = 14;
    break;
   case 19:
    var $92 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($41, $50);
    HEAP32[$outer_dn >> 2] = $92;
    var $93 = __ZNK13JSTreeContext9callsEvalEv($42);
    var $_pre2_pre = ($92 | 0) == 0;
    if ($93) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ($_pre2_pre) {
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $96 = HEAP32[$45 >> 2];
    if (($96 | 0) == 0) {
      var $116 = $92;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $99 = $92 + 4 | 0;
    var $100 = $96 + 4 | 0;
    var $101 = __ZN2js8TokenPosltERKS0_($99, $100);
    if ($101) {
      __label__ = 23;
      break;
    } else {
      var $116 = $92;
      __label__ = 30;
      break;
    }
   case 23:
    var $_idx_val14 = HEAP32[$52 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx_val14, $43);
    var $116 = $92;
    __label__ = 30;
    break;
   case 24:
    var $_idx_val = HEAP32[$52 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx_val, $43);
    if ($_pre2_pre) {
      __label__ = 25;
      break;
    } else {
      var $116 = $92;
      __label__ = 30;
      break;
    }
   case 25:
    var $103 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($44);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p, $103, $atom);
    var $104 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p);
    if (($104 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $107 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p);
    var $108 = HEAP32[$107 >> 2];
    HEAP32[$outer_dn >> 2] = $108;
    var $116 = $108;
    __label__ = 30;
    break;
   case 27:
    var $110 = $52 | 0;
    var $111 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($110, $5);
    HEAP32[$outer_dn >> 2] = $111;
    if (($111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 52;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $114 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($44);
    var $115 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($114, $p, $atom, $outer_dn);
    if ($115) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 52;
      break;
    }
   case 29:
    var $116 = HEAP32[$outer_dn >> 2];
    __label__ = 30;
    break;
   case 30:
    var $116;
    if (($52 | 0) == ($116 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $_pre_phi10 = $116 + 44 | 0;
    __label__ = 36;
    break;
   case 32:
    var $119 = $52 | 0;
    var $120 = $52 + 28 | 0;
    var $121 = HEAP32[$120 >> 2];
    if (($121 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      var $123 = $121;
      __label__ = 34;
      break;
    }
   case 33:
    var $pnup_0_lcssa = $120;
    var $_c1_pre_phi = $116;
    __label__ = 35;
    break;
   case 34:
    var $123;
    var $_c2 = $116;
    HEAP32[$123 + 36 >> 2] = $_c2;
    var $125 = $123 + 28 | 0;
    var $126 = HEAP32[$125 >> 2];
    if (($126 | 0) == 0) {
      var $pnup_0_lcssa = $125;
      var $_c1_pre_phi = $_c2;
      __label__ = 35;
      break;
    } else {
      var $123 = $126;
      __label__ = 34;
      break;
    }
   case 35:
    var $_c1_pre_phi;
    var $pnup_0_lcssa;
    var $128 = $116 + 28 | 0;
    var $129 = HEAP32[$128 >> 2];
    HEAP32[$pnup_0_lcssa >> 2] = $129;
    HEAP32[$128 >> 2] = $119;
    var $135 = $116 + 44 | 0;
    var $137 = HEAP32[$135 >> 2] | HEAP32[$52 + 44 >> 2] & 3967;
    HEAP32[$135 >> 2] = $137;
    __ZN11JSParseNode7setDefnEb($119, 0);
    __ZN11JSParseNode7setUsedEb($119, 1);
    HEAP32[$52 + 36 >> 2] = $_c1_pre_phi;
    var $_pre_phi10 = $135;
    __label__ = 36;
    break;
   case 36:
    var $_pre_phi10;
    var $141 = HEAP32[$_pre_phi10 >> 2] | 2048;
    HEAP32[$_pre_phi10 >> 2] = $141;
    var $foundCallee_1 = $foundCallee_0;
    __label__ = 37;
    break;
   case 37:
    var $foundCallee_1;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $foundCallee_0 = $foundCallee_1;
    __label__ = 7;
    break;
   case 38:
    var $144 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($33);
    var $145 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($144);
    if (($145 | 0) == ($foundCallee_0 | 0)) {
      __label__ = 43;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $148 = $fn + 36 | 0;
    var $149 = HEAP32[$148 >> 2];
    var $150 = $149;
    var $151 = __ZN2js11NameSetNode6createEP13JSTreeContext($5);
    HEAP32[$148 >> 2] = $151;
    if (($151 | 0) == 0) {
      var $_0 = 0;
      __label__ = 52;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $154 = $151 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($154, 85);
    var $158 = HEAP32[$148 >> 2] + 4 | 0;
    var $159 = $149 + 4 | 0;
    HEAP32[$158 >> 2] = HEAP32[$159 >> 2];
    HEAP32[$158 + 4 >> 2] = HEAP32[$159 + 4 >> 2];
    HEAP32[$158 + 8 >> 2] = HEAP32[$159 + 8 >> 2];
    HEAP32[$158 + 12 >> 2] = HEAP32[$159 + 12 >> 2];
    if (($foundCallee_0 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $162 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($33);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($162, $1);
    __label__ = 42;
    break;
   case 42:
    var $165 = HEAP32[$148 >> 2] + 32 | 0;
    var $167 = HEAP32[$32 >> 2];
    HEAP32[$165 >> 2] = $167;
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv($33);
    var $169 = HEAP32[$148 >> 2] + 36 | 0;
    HEAP32[$169 >> 2] = $150;
    var $_pre_phi6 = $42;
    __label__ = 44;
    break;
   case 43:
    var $174 = HEAP32[HEAP32[$funtc + 48 >> 2] + 12 >> 2];
    __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext($33, $174);
    var $_pre_phi6 = $42;
    __label__ = 44;
    break;
   case 44:
    var $_pre_phi6;
    var $176 = __ZNK13JSTreeContext12inStrictModeEv($_pre_phi6);
    if ($176) {
      __label__ = 45;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 45:
    var $179 = HEAP32[$11 + 8 >> 2];
    var $180 = __ZNK8JSObject18getFunctionPrivateEv($179);
    if (HEAP16[$180 + 56 >> 1] << 16 >> 16 == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $185 = $funtc + 40 | 0;
    __ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE($iter, $185);
    __label__ = 47;
    break;
   case 47:
    var $186 = __ZN2js13AtomDeclsIterclEv($iter);
    if (($186 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $189 = __ZN12JSDefinition4kindEv($186);
    if (($189 | 0) == 4) {
      __label__ = 49;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 49:
    var $192 = $186 | 0;
    var $193 = __ZNK11JSParseNode10isAssignedEv($192);
    if ($193) {
      __label__ = 50;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 50:
    var $196 = HEAP32[$15 >> 2] | 16777216;
    HEAP32[$15 >> 2] = $196;
    __label__ = 51;
    break;
   case 51:
    var $197 = $11 + 44 | 0;
    var $198 = $funtc + 92 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($197, undef, $198);
    var $_0 = 1;
    __label__ = 52;
    break;
   case 52:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE["X"] = 1;

function __ZN2js6Parser12functionStmtEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 32);
    if (($2 | 0) == 29) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $7 = HEAP32[$5 + 28 >> 2];
    var $9 = HEAP32[$this + 980 >> 2];
    var $10 = __ZN13JSTreeContext11atBodyLevelEv($9);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 273, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $14 = $9;
    var $15 = __ZNK13JSTreeContext12inStrictModeEv($14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 8, 267, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $19 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $7, 2, 1);
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12functionExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 32);
    if (($2 | 0) == 29) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $name_0 = HEAP32[$5 + 28 >> 2];
    __label__ = 4;
    break;
   case 3:
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $name_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $name_0;
    var $10 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, $name_0, 2, 0);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode21isStringExprStatementEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode7getKindEv($5);
    if (($8 | 0) == 31) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = (HEAP32[$5 >> 2] & 536870912 | 0) == 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode25isEscapeFreeStringLiteralEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 16 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $20 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 32 >> 2] | 0;
    var $12 = HEAP32[$this + 4 >> 2];
    var $13 = __ZNK8JSString6lengthEv($10);
    var $20 = ($13 + ($12 + 2) | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $20;
    return $20;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream16setUnexpectedEOFEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 16);
  return;
}

function __ZN2js6Parser9conditionEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($2 | 0) == 27) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 74, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 3:
    var $7 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($10 | 0) == 28) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 75, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($7, 4);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $17 = __ZNK11JSParseNode4isOpE4JSOp($7, 0);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $19 = __ZNK11JSParseNode10isInParensEv($7);
    if ($19) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $21 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 5, 112, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = __str93064 | 0, tempInt));
    if ($21) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $_0 = $7;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9parenExprEPi($this, $genexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $tmp4 = HEAP32[$2 + 4 >> 2];
    var $tmp6 = HEAP32[$2 + 8 >> 2];
    var $3 = ($genexp | 0) != 0;
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$genexp >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    var $7 = HEAP32[$this + 980 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $7);
    var $8 = __ZN2js6Parser13bracketedExprEv($this);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN11GenexpGuard7endBodyEv($guard);
    var $11 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 42);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 5:
    var $13 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard, $8);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 6:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 3);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK11JSParseNode10isInParensEv($8);
    if ($17) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZNK11JSParseNode4lastEv($8);
    var $20 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $19, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 9:
    var $22 = __ZN2js6Parser13generatorExprEP11JSParseNode($this, $8);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$22 + 4 >> 2] = $tmp4;
    HEAP32[$22 + 8 >> 2] = $tmp6;
    if ($3) {
      __label__ = 11;
      break;
    } else {
      var $pn_0 = $22;
      __label__ = 15;
      break;
    }
   case 11:
    var $26 = __ZN2js11TokenStream8getTokenEv($1);
    if (($26 | 0) == 28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 13:
    var $31 = $22 + 12 | 0;
    var $32 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $34 = $32 + 12 | 0;
    var $35 = $31;
    var $36$0 = HEAP32[$34 >> 2];
    var $36$1 = HEAP32[$34 + 4 >> 2];
    HEAP32[$35 >> 2] = $36$0;
    HEAP32[$35 + 4 >> 2] = $36$1;
    HEAP32[$genexp >> 2] = 1;
    var $pn_0 = $22;
    __label__ = 15;
    break;
   case 14:
    var $38 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $8);
    if ($38) {
      var $pn_0 = $8;
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $pn_0;
    var $_0 = $pn_0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9parenExprEPi["X"] = 1;

function __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $tt, $afterDot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 308;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $seen = __stackBase__ + 4;
    var $atom = __stackBase__ + 232;
    var $1 = __stackBase__ + 236;
    var $2 = __stackBase__ + 244;
    var $p = __stackBase__ + 252;
    var $name = __stackBase__ + 268;
    var $3 = __stackBase__ + 272;
    var $genexp = __stackBase__ + 276;
    var $mdl = __stackBase__ + 280;
    var $dn = __stackBase__ + 288;
    var $p2 = __stackBase__ + 292;
    var $5 = $this + 12 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$6 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_5 = 0;
    __label__ = 154;
    break;
   case 3:
    if (($tt | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($tt | 0) == 23) {
      __label__ = 8;
      break;
    } else if (($tt | 0) == 25) {
      __label__ = 30;
      break;
    } else if (($tt | 0) == 81) {
      __label__ = 74;
      break;
    } else if (($tt | 0) == 51) {
      __label__ = 75;
      break;
    } else if (($tt | 0) == 52) {
      __label__ = 84;
      break;
    } else if (($tt | 0) == 27) {
      __label__ = 87;
      break;
    } else if (($tt | 0) == 17) {
      __label__ = 91;
      break;
    } else if (($tt | 0) == 70) {
      __label__ = 92;
      break;
    } else if (($tt | 0) == 59) {
      __label__ = 93;
      break;
    } else if (($tt | 0) == 31 || ($tt | 0) == 68 || ($tt | 0) == 67 || ($tt | 0) == 69) {
      __label__ = 94;
      break;
    } else if (($tt | 0) == 29) {
      __label__ = 98;
      break;
    } else if (($tt | 0) == 32) {
      __label__ = 139;
      break;
    } else if (($tt | 0) == 30) {
      __label__ = 148;
      break;
    } else if (($tt | 0) == 33) {
      __label__ = 150;
      break;
    } else if (($tt | 0) == -1) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 4:
    var $13 = $this + 40 | 0;
    var $14 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($13, 71, 32);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $17 = HEAP32[$this + 980 >> 2];
    var $18 = __ZN2js11NullaryNode6createEP13JSTreeContext($17);
    var $19 = $18 | 0;
    if (($18 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($19, 34);
    var $22 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $19);
    if (($22 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $22;
      __label__ = 153;
      break;
    }
   case 7:
    var $25 = __ZN2js6Parser12functionExprEv($this);
    if (($25 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $25;
      __label__ = 153;
      break;
    }
   case 8:
    var $28 = $this + 980 | 0;
    var $29 = HEAP32[$28 >> 2];
    var $30 = __ZN2js8ListNode6createEP13JSTreeContext($29);
    var $31 = $30 | 0;
    if (($30 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 24);
    __ZN11JSParseNode5setOpE4JSOp($31, 89);
    __ZN11JSParseNode9makeEmptyEv($31);
    var $38 = $30 + 44 | 0;
    var $42 = HEAP32[$38 >> 2] & 4095 | HEAP32[HEAP32[$28 >> 2] + 8 >> 2] << 12;
    HEAP32[$38 >> 2] = $42;
    var $43 = $this + 40 | 0;
    var $44 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($43, 24, 8);
    if ($44) {
      __label__ = 29;
      break;
    } else {
      var $index_0 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $index_0;
    if (($index_0 | 0) == 491520) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $47 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 200, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 12:
    var $49 = __ZN2js11TokenStream9peekTokenEj($43, 8);
    if (($49 | 0) == 24) {
      __label__ = 13;
      break;
    } else if (($49 | 0) == 3) {
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = HEAP32[$38 >> 2] | 16;
    HEAP32[$38 >> 2] = $52;
    __label__ = 22;
    break;
   case 14:
    var $54 = __ZN2js6Parser10assignExprEv($this);
    if (($54 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $57 = __ZN11JSParseNode10isConstantEv($54);
    if ($57) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $60 = HEAP32[$38 >> 2] | 2048;
    HEAP32[$38 >> 2] = $60;
    __label__ = 19;
    break;
   case 17:
    var $62 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 3);
    var $63 = HEAP32[$28 >> 2];
    var $64 = __ZN2js11NullaryNode6createEP13JSTreeContext($63);
    var $66 = HEAP32[$38 >> 2] | 3072;
    HEAP32[$38 >> 2] = $66;
    if (($64 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = $64 | 0;
    __ZN11JSParseNode6appendEPS_($31, $68);
    __label__ = 21;
    break;
   case 19:
    __ZN11JSParseNode6appendEPS_($31, $54);
    if (($49 | 0) == 3) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $72 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 3);
    if ($72) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 10;
    break;
   case 22:
    if (($index_0 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $77 = $30 + 40 | 0;
    if ((HEAP32[$77 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $81 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 42);
    if ($81) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 78);
    var $83 = __ZNK11JSParseNode4lastEv($31);
    HEAP32[$77 >> 2] = 0;
    var $84 = $30 + 32 | 0;
    var $85 = $30 + 36 | 0;
    HEAP32[$85 >> 2] = $84;
    HEAP32[$84 >> 2] = 0;
    var $87 = HEAPU32[$38 >> 2] >>> 12;
    var $88 = __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $83, $87, 0, 79, 207);
    if (($88 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN11JSParseNode6appendEPS_($31, $88);
    __label__ = 27;
    break;
   case 27:
    var $92 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($92 | 0) == 24) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $95 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 105, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 29:
    var $97 = $30 + 12 | 0;
    var $98 = __ZNK2js11TokenStream12currentTokenEv($43);
    var $100 = $98 + 12 | 0;
    var $101 = $97;
    var $st$5$0 = $100 | 0;
    var $102$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $100 + 4 | 0;
    var $102$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $101 | 0;
    HEAP32[$st$9$0 >> 2] = $102$0;
    var $st$9$1 = $101 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $102$1;
    var $_5 = $31;
    __label__ = 154;
    break;
   case 30:
    __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($seen, $6);
    var $104 = $this + 980 | 0;
    var $105 = HEAP32[$104 >> 2];
    var $106 = __ZN2js8ListNode6createEP13JSTreeContext($105);
    var $107 = $106 | 0;
    if (($106 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($107, 26);
    __ZN11JSParseNode5setOpE4JSOp($107, 89);
    __ZN11JSParseNode9makeEmptyEv($107);
    var $110 = $this + 40 | 0;
    var $112 = $106 + 44 | 0;
    __label__ = 32;
    break;
   case 32:
    var $114 = __ZN2js11TokenStream8getTokenEj($110, 32);
    if (($114 | 0) == 30) {
      __label__ = 33;
      break;
    } else if (($114 | 0) == 29) {
      __label__ = 35;
      break;
    } else if (($114 | 0) == 31) {
      __label__ = 43;
      break;
    } else if (($114 | 0) == 26) {
      __label__ = 71;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 33:
    var $116 = HEAP32[$104 >> 2];
    var $117 = __ZN2js11NullaryNode6createEP13JSTreeContext($116);
    if (($117 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $120 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $122 = $120 + 24 | 0;
    var $123 = (tempDoubleI32[0] = HEAP32[$122 >> 2], tempDoubleI32[1] = HEAP32[$122 + 4 >> 2], tempDoubleF64[0]);
    var $125 = $117 + 32 | 0;
    tempDoubleF64[0] = $123, HEAP32[$125 >> 2] = tempDoubleI32[0], HEAP32[$125 + 4 >> 2] = tempDoubleI32[1];
    var $126 = HEAP32[$5 >> 2];
    __ZN2JSL11DoubleValueEd2907($1, $123);
    var $127 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($126, $1, $atom);
    if ($127) {
      var $_pn = $117;
      __label__ = 46;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 35:
    var $129 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $131 = HEAP32[$129 + 28 >> 2];
    HEAP32[$atom >> 2] = $131;
    var $134 = HEAP32[HEAP32[$5 >> 2] + 52 >> 2];
    if (($131 | 0) == (HEAP32[$134 + 210220 >> 2] | 0)) {
      var $op_0 = 125;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($131 | 0) == (HEAP32[$134 + 210296 >> 2] | 0)) {
      var $op_0 = 126;
      __label__ = 37;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 37:
    var $op_0;
    var $145 = __ZN2js11TokenStream8getTokenEj($110, 32);
    if (($145 | 0) == 31 || ($145 | 0) == 29) {
      __label__ = 38;
      break;
    } else if (($145 | 0) == 30) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    var $147 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $149 = HEAP32[$147 + 28 >> 2];
    HEAP32[$atom >> 2] = $149;
    var $150 = HEAP32[$104 >> 2];
    var $151 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($149, $150);
    var $152 = $151 | 0;
    if (($151 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      var $pn3_0 = $152;
      __label__ = 42;
      break;
    }
   case 39:
    var $155 = HEAP32[$104 >> 2];
    var $156 = __ZN2js11NullaryNode6createEP13JSTreeContext($155);
    if (($156 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $159 = $156 | 0;
    var $160 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $162 = $160 + 24 | 0;
    var $163 = (tempDoubleI32[0] = HEAP32[$162 >> 2], tempDoubleI32[1] = HEAP32[$162 + 4 >> 2], tempDoubleF64[0]);
    var $165 = $156 + 32 | 0;
    tempDoubleF64[0] = $163, HEAP32[$165 >> 2] = tempDoubleI32[0], HEAP32[$165 + 4 >> 2] = tempDoubleI32[1];
    var $166 = HEAP32[$5 >> 2];
    __ZN2JSL11DoubleValueEd2907($2, $163);
    var $167 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($166, $2, $atom);
    if ($167) {
      var $pn3_0 = $159;
      __label__ = 42;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 41:
    __ZN2js11TokenStream10ungetTokenEv($110);
    __label__ = 43;
    break;
   case 42:
    var $pn3_0;
    var $171 = HEAP32[$112 >> 2] | 2048;
    HEAP32[$112 >> 2] = $171;
    var $173 = __ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE($this, 0, ($op_0 | 0) != 125 & 1, 0);
    var $174 = HEAP32[$104 >> 2];
    var $175 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(6, $op_0, $pn3_0, $173, $174);
    var $pn2_1 = $175;
    var $op_1 = $op_0;
    __label__ = 55;
    break;
   case 43:
    var $177 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $179 = HEAPU32[$177 + 28 >> 2];
    HEAP32[$atom >> 2] = $179;
    var $180 = HEAP32[$104 >> 2];
    var $181 = __ZN2js11NullaryNode6createEP13JSTreeContext($180);
    if (($181 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $184 = $181 + 32 | 0;
    HEAP32[$184 >> 2] = $179;
    var $_pn = $181;
    __label__ = 46;
    break;
   case 45:
    var $186 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 131, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 46:
    var $_pn;
    var $pn3_1 = $_pn | 0;
    var $188 = __ZN2js11TokenStream8getTokenEv($110);
    if (($188 | 0) == 6) {
      __label__ = 47;
      break;
    } else if (($188 | 0) == 26 || ($188 | 0) == 3) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 47:
    var $190 = __ZN2js6Parser10assignExprEv($this);
    if (($190 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $193 = __ZN11JSParseNode10isConstantEv($190);
    if ($193) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    if ((HEAP32[$atom >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210292 >> 2] | 0)) {
      __label__ = 50;
      break;
    } else {
      var $pnval_0 = $190;
      __label__ = 54;
      break;
    }
   case 50:
    var $204 = HEAP32[$112 >> 2] | 2048;
    HEAP32[$112 >> 2] = $204;
    var $pnval_0 = $190;
    __label__ = 54;
    break;
   case 51:
    var $206 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 106, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 52:
    __ZN2js11TokenStream10ungetTokenEv($110);
    var $209 = HEAP32[$112 >> 2] | 2560;
    HEAP32[$112 >> 2] = $209;
    var $210 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_1, 29);
    if ($210) {
      __label__ = 53;
      break;
    } else {
      var $pnval_0 = $pn3_1;
      __label__ = 54;
      break;
    }
   case 53:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn3_1, 6);
    var $213 = HEAP32[$104 >> 2];
    __ZN2js8NameNode10initCommonEP13JSTreeContext($_pn, $213);
    var $pnval_0 = $pn3_1;
    __label__ = 54;
    break;
   case 54:
    var $pnval_0;
    var $215 = HEAP32[$104 >> 2];
    var $216 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(6, 93, $pn3_1, $pnval_0, $215);
    var $pn2_1 = $216;
    var $op_1 = 93;
    __label__ = 55;
    break;
   case 55:
    var $op_1;
    var $pn2_1;
    if (($pn2_1 | 0) == 0) {
      var $_4 = 0;
      __label__ = 73;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    __ZN11JSParseNode6appendEPS_($107, $pn2_1);
    if (($op_1 | 0) == 125) {
      __label__ = 57;
      break;
    } else if (($op_1 | 0) == 126) {
      __label__ = 58;
      break;
    } else {
      var $assignType_0 = 7;
      __label__ = 59;
      break;
    }
   case 57:
    var $assignType_0 = 1;
    __label__ = 59;
    break;
   case 58:
    var $assignType_0 = 2;
    __label__ = 59;
    break;
   case 59:
    var $assignType_0;
    __ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_($p, $seen, $atom);
    var $223 = __ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev($p);
    if (($223 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $226 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    var $227 = HEAPU32[$226 >> 2];
    if (($227 & $assignType_0 | 0) == 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $or_cond = ($227 | 0) == 7 & ($assignType_0 | 0) == 7;
    if ($or_cond) {
      __label__ = 62;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 62:
    var $235 = HEAP32[$104 >> 2];
    var $236 = __ZN13JSTreeContext16needStrictChecksEv($235);
    if ($236) {
      __label__ = 63;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 63:
    __ZN16JSAutoByteStringC1Ev($name);
    var $238 = HEAP32[$5 >> 2];
    var $239 = HEAP32[$atom >> 2];
    var $240 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($238, $239, $name);
    if (($240 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($or_cond) {
      __label__ = 65;
      break;
    } else {
      var $249 = 0;
      __label__ = 66;
      break;
    }
   case 65:
    var $245 = HEAP32[$104 >> 2];
    var $246 = __ZNK13JSTreeContext12inStrictModeEv($245);
    var $249 = $246 ^ 1;
    __label__ = 66;
    break;
   case 66:
    var $249;
    var $250 = $249 & 1;
    var $251 = __ZNK16JSAutoByteString3ptrEv($name);
    var $252 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $110, 0, $250, 234, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $251, tempInt));
    __ZN16JSAutoByteStringD1Ev($name);
    if ($252) {
      __label__ = 67;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 67:
    var $254 = $227 | $assignType_0;
    var $255 = __ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv($p);
    HEAP32[$255 >> 2] = $254;
    __label__ = 69;
    break;
   case 68:
    HEAP32[$3 >> 2] = $assignType_0;
    var $257 = __ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj($seen, $p, $atom, $3);
    if ($257) {
      __label__ = 69;
      break;
    } else {
      var $_4 = 0;
      __label__ = 73;
      break;
    }
   case 69:
    var $259 = __ZN2js11TokenStream8getTokenEv($110);
    if (($259 | 0) == 3) {
      __label__ = 32;
      break;
    } else if (($259 | 0) == 26) {
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $261 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 107, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_4 = 0;
    __label__ = 73;
    break;
   case 71:
    var $263 = $106 + 12 | 0;
    var $264 = __ZNK2js11TokenStream12currentTokenEv($110);
    var $266 = $264 + 12 | 0;
    var $267 = $263;
    var $st$5$0 = $266 | 0;
    var $268$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $266 + 4 | 0;
    var $268$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $267 | 0;
    HEAP32[$st$9$0 >> 2] = $268$0;
    var $st$9$1 = $267 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $268$1;
    var $_4 = $107;
    __label__ = 73;
    break;
   case 72:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_4 = 0;
    __label__ = 73;
    break;
   case 73:
    var $_4;
    __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($seen);
    var $_5 = $_4;
    __label__ = 154;
    break;
   case 74:
    var $270 = __ZN2js6Parser8letBlockEi($this, 0);
    if (($270 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $270;
      __label__ = 153;
      break;
    }
   case 75:
    var $273 = $this + 980 | 0;
    var $274 = HEAP32[$273 >> 2];
    var $275 = __ZN2js9UnaryNode6createEP13JSTreeContext($274);
    var $276 = $275 | 0;
    if (($275 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $279 = $this + 40 | 0;
    var $280 = __ZNK2js11TokenStream12currentTokenEv($279);
    var $282 = $280 + 24 | 0;
    var $283 = (tempDoubleI32[0] = HEAP32[$282 >> 2], tempDoubleI32[1] = HEAP32[$282 + 4 >> 2], tempDoubleF64[0]);
    var $285 = $275 + 36 | 0;
    var $_c8 = $283 & -1;
    HEAP32[$285 >> 2] = $_c8;
    var $286 = __ZN2js11TokenStream8getTokenEj($279, 8);
    var $287 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $286, 0);
    var $288 = $275 + 32 | 0;
    HEAP32[$288 >> 2] = $287;
    if (($287 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $291 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($287, 52);
    if ($291) {
      __label__ = 82;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $293 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($287, 51);
    if ($293) {
      __label__ = 82;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $295 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($287, 31);
    if ($295) {
      __label__ = 82;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $297 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($287, 30);
    if ($297) {
      __label__ = 82;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $299 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($287, 33);
    if ($299) {
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    var $301 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $287, 0, 134, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 83:
    var $304 = HEAP32[$273 >> 2];
    var $305 = __ZN13JSTreeContext16ensureSharpSlotsEv($304);
    if ($305) {
      var $pn_0 = $276;
      __label__ = 153;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 84:
    var $307 = $this + 980 | 0;
    var $308 = HEAP32[$307 >> 2];
    var $309 = __ZN2js11NullaryNode6createEP13JSTreeContext($308);
    var $310 = $309 | 0;
    if (($309 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $314 = HEAP32[$307 >> 2];
    var $315 = __ZN13JSTreeContext16ensureSharpSlotsEv($314);
    if ($315) {
      __label__ = 86;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 86:
    var $317 = $this + 40 | 0;
    var $318 = __ZNK2js11TokenStream12currentTokenEv($317);
    var $320 = $318 + 24 | 0;
    var $321 = (tempDoubleI32[0] = HEAP32[$320 >> 2], tempDoubleI32[1] = HEAP32[$320 + 4 >> 2], tempDoubleF64[0]);
    var $323 = $309 + 36 | 0;
    var $_c7 = $321 & -1;
    HEAP32[$323 >> 2] = $_c7;
    var $pn_0 = $310;
    __label__ = 153;
    break;
   case 87:
    var $325 = __ZN2js6Parser9parenExprEPi($this, $genexp);
    if (($325 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    __ZN11JSParseNode11setInParensEb($325, 1);
    if ((HEAP32[$genexp >> 2] | 0) == 0) {
      __label__ = 89;
      break;
    } else {
      var $pn_0 = $325;
      __label__ = 153;
      break;
    }
   case 89:
    var $331 = $this + 40 | 0;
    var $332 = __ZN2js11TokenStream8getTokenEj($331, 0);
    if (($332 | 0) == 28) {
      var $pn_0 = $325;
      __label__ = 153;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $335 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 108, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 91:
    var $337 = __ZN2js6Parser19qualifiedIdentifierEv($this);
    if (($337 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $337;
      __label__ = 153;
      break;
    }
   case 92:
    var $340 = __ZN2js6Parser19attributeIdentifierEv($this);
    if (($340 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $340;
      __label__ = 153;
      break;
    }
   case 93:
    var $343 = __ZN2js6Parser20xmlElementOrListRootEi($this, 1);
    if (($343 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $343;
      __label__ = 153;
      break;
    }
   case 94:
    var $347 = HEAP32[$this + 980 >> 2];
    var $348 = __ZN2js11NullaryNode6createEP13JSTreeContext($347);
    var $349 = $348 | 0;
    if (($348 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $352 = $this + 40 | 0;
    var $353 = __ZNK2js11TokenStream12currentTokenEv($352);
    var $356 = $348 + 32 | 0;
    var $_c5 = HEAP32[$353 + 28 >> 2];
    HEAP32[$356 >> 2] = $_c5;
    var $357 = ($tt | 0) == 69;
    var $358 = __ZNK2js11TokenStream12currentTokenEv($352);
    if ($357) {
      __label__ = 96;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 96:
    var $363 = $348 + 36 | 0;
    var $_c6 = HEAP32[$358 + 24 >> 2];
    HEAP32[$363 >> 2] = $_c6;
    var $pn_0 = $349;
    __label__ = 153;
    break;
   case 97:
    var $366 = HEAP32[$358 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($349, $366);
    var $pn_0 = $349;
    __label__ = 153;
    break;
   case 98:
    var $368 = $this + 40 | 0;
    var $369 = __ZNK2js11TokenStream12currentTokenEv($368);
    var $371 = HEAP32[$369 + 28 >> 2];
    var $372 = $this + 980 | 0;
    var $373 = HEAP32[$372 >> 2];
    var $374 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($371, $373);
    var $375 = $374 | 0;
    if (($374 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    __ZN11JSParseNode5setOpE4JSOp($375, 59);
    var $378 = HEAP32[$372 >> 2];
    var $380 = HEAP32[$378 >> 2];
    if (($380 & 66 | 0) == 2) {
      __label__ = 100;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 100:
    if ((HEAP32[$374 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 101;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 101:
    __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($378, $375);
    if (($afterDot | 0) == 0) {
      __label__ = 102;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 102:
    var $397 = HEAP32[$372 >> 2];
    if ((HEAP32[$397 >> 2] & 65536 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 103:
    var $403 = $397;
    var $404 = __ZN13JSTreeContext11inStatementE10JSStmtType($403, 6);
    if ($404) {
      __label__ = 132;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    __ZN11JSParseNode5setOpE4JSOp($375, 9);
    var $407 = $374 + 44 | 0;
    var $409 = HEAP32[$407 >> 2] | 512;
    HEAP32[$407 >> 2] = $409;
    __label__ = 132;
    break;
   case 105:
    if (($afterDot | 0) == 0) {
      var $417 = $378;
      var $416 = $380;
      __label__ = 108;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $413 = __ZN2js11TokenStream9peekTokenEv($368);
    if (($413 | 0) == 71) {
      __label__ = 107;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 107:
    var $_pre7 = HEAP32[$372 >> 2];
    var $417 = $_pre7;
    var $416 = HEAP32[$_pre7 >> 2];
    __label__ = 108;
    break;
   case 108:
    var $416;
    var $417;
    if (($416 & 65536 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 109:
    var $422 = __ZNK13JSTreeContext10inFunctionEv($417);
    var $_pre14 = $374 + 32 | 0;
    if ($422) {
      var $433 = $417;
      var $_pre_phi15 = $_pre14;
      __label__ = 112;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    if ((HEAP32[$_pre14 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$5 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 111;
      break;
    } else {
      var $433 = $417;
      var $_pre_phi15 = $_pre14;
      __label__ = 112;
      break;
    }
   case 111:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($417, $375);
    var $433 = HEAP32[$372 >> 2];
    var $_pre_phi15 = $_pre14;
    __label__ = 112;
    break;
   case 112:
    var $_pre_phi15;
    var $433;
    var $434 = HEAP32[$_pre_phi15 >> 2];
    var $436 = _js_LexicalLookup($433, $434, 0, 0);
    var $438 = HEAP32[$372 >> 2] + 40 | 0;
    var $439 = HEAP32[$_pre_phi15 >> 2];
    __ZN2js9AtomDecls11lookupMultiEP6JSAtom($mdl, $438, $439);
    var $440 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($440) {
      __label__ = 119;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $442 = __ZN2js14MultiDeclRange5frontEv($mdl);
    var $storemerge = $442;
    __label__ = 114;
    break;
   case 114:
    var $storemerge;
    var $445 = __ZNK11JSParseNode5isLetEv($storemerge | 0);
    if ($445) {
      __label__ = 115;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 115:
    var $450 = HEAPU32[$storemerge + 44 >> 2] >>> 12;
    var $451 = HEAP32[$372 >> 2];
    var $452 = __ZL14BlockIdInScopejP13JSTreeContext($450, $451);
    if ($452) {
      __label__ = 118;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    __ZN2js14MultiDeclRange8popFrontEv($mdl);
    var $454 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($454) {
      __label__ = 118;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $456 = __ZN2js14MultiDeclRange5frontEv($mdl);
    var $storemerge = $456;
    __label__ = 114;
    break;
   case 118:
    HEAP32[$dn >> 2] = $storemerge;
    __label__ = 119;
    break;
   case 119:
    var $457 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($457) {
      __label__ = 121;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    var $459 = __ZN2js14MultiDeclRange5frontEv($mdl);
    HEAP32[$dn >> 2] = $459;
    var $488 = $459;
    __label__ = 127;
    break;
   case 121:
    var $462 = HEAP32[$372 >> 2] + 64 | 0;
    var $463 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($462);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p2, $463, $_pre_phi15);
    var $464 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p2);
    if (($464 | 0) == 0) {
      __label__ = 123;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $467 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p2);
    var $468 = HEAPU32[$467 >> 2];
    HEAP32[$dn >> 2] = $468;
    var $488 = $468;
    __label__ = 127;
    break;
   case 123:
    var $470 = HEAP32[$372 >> 2];
    var $471 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($375, $470);
    HEAP32[$dn >> 2] = $471;
    if (($471 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $475 = HEAP32[$372 >> 2] + 64 | 0;
    var $476 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($475);
    var $478 = $471 + 32 | 0;
    var $479 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($476, $p2, $478, $dn);
    if ($479) {
      __label__ = 125;
      break;
    } else {
      var $_5 = 0;
      __label__ = 154;
      break;
    }
   case 125:
    var $481 = __ZN2js11TokenStream9peekTokenEv($368);
    var $_pre9 = HEAP32[$dn >> 2];
    if (($481 | 0) == 27) {
      var $488 = $_pre9;
      __label__ = 127;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $485 = $_pre9 + 44 | 0;
    var $487 = HEAP32[$485 >> 2] | 256;
    HEAP32[$485 >> 2] = $487;
    var $488 = $_pre9;
    __label__ = 127;
    break;
   case 127:
    var $488;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($375, $488);
    var $489 = __ZN2js11TokenStream9peekTokenEv($368);
    var $_phi_trans_insert11 = $488 + 44 | 0;
    var $_pre12 = HEAP32[$_phi_trans_insert11 >> 2];
    if (($489 | 0) == 27) {
      var $493 = $_pre12;
      __label__ = 129;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $492 = $_pre12 | 256;
    HEAP32[$_phi_trans_insert11 >> 2] = $492;
    var $493 = $492;
    __label__ = 129;
    break;
   case 129:
    var $493;
    var $494 = $493 & 256;
    var $496 = $374 + 44 | 0;
    var $497 = HEAP32[$496 >> 2];
    var $498 = $497 & 3071;
    var $499 = $497 & -4096;
    var $500 = $497 | $494;
    HEAP32[$496 >> 2] = $500;
    if (($436 | 0) == 0) {
      __label__ = 132;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if (HEAP16[$436 >> 1] << 16 >> 16 == 6) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    var $509 = $494 | $499 | $498 | 1024;
    HEAP32[$496 >> 2] = $509;
    __label__ = 132;
    break;
   case 132:
    var $511 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($368, 71);
    if ($511) {
      __label__ = 133;
      break;
    } else {
      var $pn_0 = $375;
      __label__ = 153;
      break;
    }
   case 133:
    if (($afterDot | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 134:
    var $517 = HEAP32[$374 + 32 >> 2];
    var $518 = $517 | 0;
    var $519 = __ZNK12JSFlatString6charsZEv($518);
    var $520 = $517 | 0;
    var $521 = __ZNK8JSString6lengthEv($520);
    var $522 = __ZN2js11FindKeywordEPKtj($519, $521);
    if (($522 | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    if ((HEAP32[$522 + 4 >> 2] | 0) == 34) {
      __label__ = 137;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $529 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 213, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 137:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($375, 0);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($375, 34);
    __label__ = 138;
    break;
   case 138:
    var $532 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $375);
    if (($532 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      var $pn_0 = $532;
      __label__ = 153;
      break;
    }
   case 139:
    var $535 = $this + 980 | 0;
    var $536 = HEAP32[$535 >> 2];
    var $537 = __ZN2js11NullaryNode6createEP13JSTreeContext($536);
    var $538 = $537 | 0;
    if (($537 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    var $541 = HEAP32[$5 >> 2];
    var $542 = __ZNK9JSContext5hasfpEv($541);
    if ($542) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    var $544 = __ZN9JSContext13regExpStaticsEv($541);
    var $545 = $this + 40 | 0;
    var $546 = __ZNK2js11TokenStream11getTokenbufEv($545);
    var $547 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($546);
    var $548 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($546);
    var $549 = __ZNK2js11TokenStream12currentTokenEv($545);
    var $551 = HEAP32[$549 + 24 >> 2];
    var $552 = $545;
    var $553 = __ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE($541, $544, $547, $548, $551, $552);
    var $obj_0 = $553;
    __label__ = 143;
    break;
   case 142:
    var $555 = $this + 40 | 0;
    var $556 = __ZNK2js11TokenStream11getTokenbufEv($555);
    var $557 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($556);
    var $558 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($556);
    var $559 = __ZNK2js11TokenStream12currentTokenEv($555);
    var $561 = HEAP32[$559 + 24 >> 2];
    var $562 = $555;
    var $563 = __ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE($541, $557, $558, $561, $562);
    var $obj_0 = $563;
    __label__ = 143;
    break;
   case 143:
    var $obj_0;
    if (($obj_0 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $567 = HEAP32[$535 >> 2];
    var $568 = $567;
    var $569 = __ZNK13JSTreeContext12compileAndGoEv($568);
    if ($569) {
      var $572 = $567;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 145:
    __ZN8JSObject11clearParentEv($obj_0);
    __ZN8JSObject9clearTypeEv($obj_0);
    var $572 = HEAP32[$535 >> 2];
    __label__ = 146;
    break;
   case 146:
    var $572;
    var $574 = HEAP32[$572 + 48 >> 2];
    var $575 = __ZN2js6Parser12newObjectBoxEP8JSObject($574, $obj_0);
    var $576 = $537 + 32 | 0;
    var $_c = $575;
    HEAP32[$576 >> 2] = $_c;
    if (($575 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    __ZN11JSParseNode5setOpE4JSOp($538, 162);
    var $pn_0 = $538;
    __label__ = 153;
    break;
   case 148:
    var $581 = HEAP32[$this + 980 >> 2];
    var $582 = __ZN2js11NullaryNode6createEP13JSTreeContext($581);
    var $583 = $582 | 0;
    if (($582 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    __ZN11JSParseNode5setOpE4JSOp($583, 60);
    var $586 = $this + 40 | 0;
    var $587 = __ZNK2js11TokenStream12currentTokenEv($586);
    var $589 = $587 + 24 | 0;
    var $590 = (tempDoubleI32[0] = HEAP32[$589 >> 2], tempDoubleI32[1] = HEAP32[$589 + 4 >> 2], tempDoubleF64[0]);
    var $592 = $582 + 32 | 0;
    tempDoubleF64[0] = $590, HEAP32[$592 >> 2] = tempDoubleI32[0], HEAP32[$592 + 4 >> 2] = tempDoubleI32[1];
    var $pn_0 = $583;
    __label__ = 153;
    break;
   case 150:
    var $595 = HEAP32[$this + 980 >> 2];
    var $596 = __ZN2js11NullaryNode6createEP13JSTreeContext($595);
    var $597 = $596 | 0;
    if (($596 | 0) == 0) {
      var $_5 = 0;
      __label__ = 154;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 151:
    var $600 = $this + 40 | 0;
    var $601 = __ZNK2js11TokenStream12currentTokenEv($600);
    var $603 = HEAP32[$601 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($597, $603);
    var $pn_0 = $597;
    __label__ = 153;
    break;
   case 152:
    var $605 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 154;
    break;
   case 153:
    var $pn_0;
    var $_5 = $pn_0;
    __label__ = 154;
    break;
   case 154:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11primaryExprENS_9TokenKindEi["X"] = 1;

function __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $left, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 78);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $7 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $6, $left, 0, 216, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 24);
    var $11 = HEAPU32[$left + 32 >> 2];
    var $12 = ($data | 0) == 0;
    if ($9) {
      var $pn_0 = $11;
      __label__ = 4;
      break;
    } else {
      var $pair_0 = $11;
      __label__ = 17;
      break;
    }
   case 4:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 3);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $17 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_0, 0);
    if ($17) {
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 24);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 26);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $23 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn_0, $tc);
    var $ok_0 = $23 & 1;
    __label__ = 15;
    break;
   case 10:
    if ($12) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_0, 29);
    if ($27) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $31 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $32 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $31, $pn_0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 13:
    var $34 = __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn_0, $tc);
    var $ok_0 = ($34 | 0) != 0 & 1;
    __label__ = 15;
    break;
   case 14:
    var $38 = __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn_0, $tc);
    var $ok_0 = ($38 | 0) != 0 & 1;
    __label__ = 15;
    break;
   case 15:
    var $ok_0;
    if ($ok_0 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $pn_0 = HEAP32[$pn_0 + 24 >> 2];
    __label__ = 4;
    break;
   case 17:
    var $pair_0;
    if (($pair_0 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $50 = HEAP32[$pair_0 + 36 >> 2];
    var $51 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 24);
    if ($51) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 26);
    if ($53) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $55 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $50, $tc);
    var $ok_1 = $55 & 1;
    __label__ = 26;
    break;
   case 21:
    if ($12) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $59 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($50, 29);
    if ($59) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $63 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $64 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $63, $50, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 24:
    var $66 = __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $50, $tc);
    var $ok_1 = ($66 | 0) != 0 & 1;
    __label__ = 26;
    break;
   case 25:
    var $70 = __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $50, $tc);
    var $ok_1 = ($70 | 0) != 0 & 1;
    __label__ = 26;
    break;
   case 26:
    var $ok_1;
    if ($ok_1 << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $pair_0 = HEAP32[$pair_0 + 24 >> 2];
    __label__ = 17;
    break;
   case 28:
    if ($12) {
      __label__ = 32;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ((HEAP32[$data + 8 >> 2] | 0) == 208) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $83 = $tc;
    var $84 = __ZN13JSTreeContext10blockChainEv($83);
    var $85 = $84;
    var $86 = __ZNK8JSObject13propertyCountEv($85);
    if (($86 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $89 = __ZN13JSTreeContext10blockChainEv($83);
    var $94 = HEAP32[HEAP32[$cx + 52 >> 2] + 209972 >> 2] | 0;
    var $95 = __ZL12ATOM_TO_JSIDP6JSAtom2903($94);
    __ZN2JSL14UndefinedValueEv2937($1);
    var $96 = $cx;
    var $97 = $89;
    var $98 = __ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij($96, $97, $95, $1, 0, 0, 5, 64, 0, 0);
    if (($98 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js6Parser13returnOrYieldEb($this, $useAssignExpr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $4 = HEAP32[$2 >> 2];
    var $5 = $this + 980 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = $6;
    var $8 = __ZNK13JSTreeContext10inFunctionEv($7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_ = ($4 | 0) == 48 ? STRING_TABLE._js_return_str : STRING_TABLE._js_yield_str;
    var $11 = $_ | 0;
    var $12 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 124, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $11, tempInt));
    var $_0 = 0;
    __label__ = 26;
    break;
   case 3:
    var $14 = __ZN2js9UnaryNode6createEP13JSTreeContext($6);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = ($4 | 0) == 77;
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $20 = HEAP32[$5 >> 2];
    if ((HEAP32[$20 + 12 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $25 = $20 | 0;
    var $27 = HEAP32[$25 >> 2] | 512;
    HEAP32[$25 >> 2] = $27;
    __label__ = 8;
    break;
   case 7:
    var $29 = $20 + 16 | 0;
    var $31 = HEAP32[$29 >> 2] + 1 | 0;
    HEAP32[$29 >> 2] = $31;
    var $33 = HEAP32[$5 >> 2] + 52 | 0;
    HEAP32[$33 >> 2] = $15;
    __label__ = 8;
    break;
   case 8:
    var $35 = __ZN2js11TokenStream17peekTokenSameLineEj($1, 8);
    if (($35 | 0) == 26 || ($35 | 0) == 2 || ($35 | 0) == 1 || ($35 | 0) == 0) {
      __label__ = 18;
      break;
    } else if (($35 | 0) == -1) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($18) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    if (($35 | 0) == 28 || ($35 | 0) == 24 || ($35 | 0) == 6 || ($35 | 0) == 3) {
      __label__ = 18;
      break;
    } else if (($35 | 0) == 77) {
      __label__ = 20;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($useAssignExpr) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $40 = __ZN2js6Parser10assignExprEv($this);
    var $44 = $40;
    __label__ = 14;
    break;
   case 13:
    var $42 = __ZN2js6Parser4exprEv($this);
    var $44 = $42;
    __label__ = 14;
    break;
   case 14:
    var $44;
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($4 | 0) == 48) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $50 = HEAP32[$5 >> 2] | 0;
    var $52 = HEAP32[$50 >> 2] | 4;
    HEAP32[$50 >> 2] = $52;
    __label__ = 17;
    break;
   case 17:
    var $56 = $44 + 12 | 0;
    var $57 = $14 + 12 | 0;
    var $58$0 = HEAP32[$56 >> 2];
    var $58$1 = HEAP32[$56 + 4 >> 2];
    var $st$8$0 = $57 | 0;
    HEAP32[$st$8$0 >> 2] = $58$0;
    var $st$8$1 = $57 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $58$1;
    var $59 = $14 + 32 | 0;
    HEAP32[$59 >> 2] = $44;
    __label__ = 20;
    break;
   case 18:
    if (($4 | 0) == 48) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $64 = HEAP32[$5 >> 2] | 0;
    var $66 = HEAP32[$64 >> 2] | 8;
    HEAP32[$64 >> 2] = $66;
    __label__ = 20;
    break;
   case 20:
    var $67 = HEAP32[$5 >> 2];
    var $69 = HEAP32[$67 >> 2];
    var $73 = HEAP32[$this + 12 >> 2];
    if (($69 & 516 | 0) == 516) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $75 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($73, $67, $15, 0, 208, 209);
    var $_0 = 0;
    __label__ = 26;
    break;
   case 22:
    var $77 = __ZNK9JSContext15hasStrictOptionEv($73);
    if ($77) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    if (($69 & 12 | 0) == 12) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $82 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($73, $67, $15, 5, 110, 157);
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $_0 = $15;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13returnOrYieldEb["X"] = 1;

function __ZN2js11TokenStream17peekTokenSameLineEj($this, $withFlags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $2 = $1 + 4 | 0;
    var $3 = __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($this, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 136 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = HEAP32[$this + 4 + ((HEAP32[$this + 132 >> 2] + $6 & 3) << 5) >> 2];
    __label__ = 7;
    break;
   case 4:
    var $16 = $this + 144 | 0;
    var $18 = HEAP32[$16 >> 2] & -5;
    HEAP32[$16 >> 2] = $18;
    var $19 = __ZN2js11TokenStream8getTokenEj($this, $withFlags);
    var $20 = HEAP32[$16 >> 2];
    if (($20 & 4 | 0) == 0) {
      var $tt_0 = $19;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = $20 & -5;
    HEAP32[$16 >> 2] = $24;
    var $tt_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $tt_0;
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = $tt_0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser4exprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser10assignExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 3);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 11;
      break;
    }
   case 3:
    var $8 = HEAP32[$this + 980 >> 2];
    var $9 = __ZN2js8ListNode6createEP13JSTreeContext($8);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $1 + 4 | 0;
    var $16 = $9 + 4 | 0;
    var $17$0 = HEAP32[$15 >> 2];
    var $17$1 = HEAP32[$15 + 4 >> 2];
    var $st$8$0 = $16 | 0;
    HEAP32[$st$8$0 >> 2] = $17$0;
    var $st$8$1 = $16 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $17$1;
    __ZN11JSParseNode8initListEPS_($10, $1);
    __label__ = 5;
    break;
   case 5:
    var $19 = __ZNK11JSParseNode4lastEv($10);
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 77);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = __ZNK11JSParseNode10isInParensEv($19);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $19, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $26 = __ZN2js6Parser10assignExprEv($this);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode6appendEPS_($10, $26);
    var $29 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 3);
    if ($29) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $31 = $9 + 12 | 0;
    var $32 = __ZNK11JSParseNode4lastEv($10);
    var $34 = $32 + 12 | 0;
    var $35 = $31;
    var $36$0 = HEAP32[$34 >> 2];
    var $36$1 = HEAP32[$34 + 4 >> 2];
    var $st$9$0 = $35 | 0;
    HEAP32[$st$9$0 >> 2] = $36$0;
    var $st$9$1 = $35 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $36$1;
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser4exprEv["X"] = 1;

function __ZN2js6Parser8letBlockEi($this, $statement) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 27) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 34, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    var $13 = $this + 12 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = HEAP32[$1 >> 2];
    var $16 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($14, $15, $stmtInfo);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16 + 36 | 0;
    var $_c = $3;
    HEAP32[$19 >> 2] = $_c;
    var $20 = __ZN2js6Parser9variablesEb($this, 1);
    var $21 = $3 + 32 | 0;
    HEAP32[$21 >> 2] = $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $25 = $20 + 44 | 0;
    var $28 = HEAP32[$25 >> 2] & -4096 | 4;
    HEAP32[$25 >> 2] = $28;
    var $29 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($29 | 0) == 28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 52, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 8:
    if (($statement | 0) == 0) {
      var $pn_0_ph = $16;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($7, 25, 8);
    if ($36) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$13 >> 2];
    var $40 = HEAP32[$1 >> 2];
    var $41 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($38, $7, $40, $4, 258, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($41) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $43 = HEAP32[$1 >> 2];
    var $44 = __ZN2js9UnaryNode6createEP13JSTreeContext($43);
    var $45 = $44 | 0;
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($45, 2);
    var $48 = $44 + 36 | 0;
    HEAP32[$48 >> 2] = -1;
    var $49 = $44 + 32 | 0;
    HEAP32[$49 >> 2] = $16;
    var $pn_0_ph = $45;
    __label__ = 16;
    break;
   case 13:
    var $51 = __ZN2js6Parser10statementsEv($this);
    var $52 = $3 + 36 | 0;
    HEAP32[$52 >> 2] = $51;
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $55 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($55 | 0) == 26) {
      var $pn_04 = $16;
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 53, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $pn_0_ph;
    __ZN11JSParseNode5setOpE4JSOp($16, 210);
    var $60 = __ZN2js6Parser10assignExprEv($this);
    var $61 = $3 + 36 | 0;
    HEAP32[$61 >> 2] = $60;
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $pn_04 = $pn_0_ph;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn_04;
    var $64 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($64);
    var $_0 = $pn_04;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser8letBlockEi["X"] = 1;

function __ZN2js10BinaryNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(2, $tc);
  return $1;
}

function __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($cx, $tc, $stmt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js16LexicalScopeNode6createEP13JSTreeContext($tc);
    var $2 = $1 | 0;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __Z17js_NewBlockObjectP9JSContext($5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    var $11 = HEAP32[$tc + 48 >> 2];
    var $12 = __ZN2js6Parser12newObjectBoxEP8JSObject($11, $9);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $tc;
    var $16 = $stmt;
    _js_PushBlockScope($15, $16, $12, -1);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($2, 80);
    __ZN11JSParseNode5setOpE4JSOp($2, 202);
    var $_c = $12;
    HEAP32[$1 + 32 >> 2] = $_c;
    var $19 = $1 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($19);
    var $21 = $1 + 44 | 0;
    var $23 = HEAP32[$21 >> 2] & -4096;
    HEAP32[$21 >> 2] = $23;
    var $24 = $stmt + 4 | 0;
    var $25 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $24);
    if ($25) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $31 = HEAP32[$21 >> 2] & 4095 | HEAP32[$24 >> 2] << 12;
    HEAP32[$21 >> 2] = $31;
    var $_0 = $2;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9variablesEb($this, $inLetHead) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $data = __stackBase__;
    __ZN8BindDataC1Ev($data);
    var $1 = $this + 40 | 0;
    var $2 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $4 = HEAP32[$2 >> 2];
    var $5 = ($4 | 0) == 81;
    var $6 = ($4 | 0) == 27;
    var $7 = $5 | $6;
    var $_pre = HEAP32[$this + 980 >> 2];
    if ($inLetHead | ($5 | $6) ^ 1) {
      var $13 = $inLetHead;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP32[$_pre >> 2] & 16 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $13;
    var $14 = $this + 980 | 0;
    var $16 = HEAP32[$_pre + 24 >> 2];
    var $18 = HEAP32[$_pre + 28 >> 2];
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      var $scopeStmt_0 = $18;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $scopeStmt_0;
    if (($scopeStmt_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP16[$scopeStmt_0 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $scopeStmt_0 = HEAP32[$scopeStmt_0 + 28 >> 2];
    __label__ = 4;
    break;
   case 7:
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      var $32 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $32 = HEAP32[$28 + 24 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = $data + 4 | 0;
    HEAP32[$33 >> 2] = $32;
    var $34 = __ZN2js8ListNode6createEP13JSTreeContext($_pre);
    var $35 = $34 | 0;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$33 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($35, $38);
    __ZN11JSParseNode9makeEmptyEv($35);
    var $39 = $data + 8 | 0;
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$39 >> 2] = 208;
    HEAP32[$data + 12 >> 2] = 199;
    __label__ = 13;
    break;
   case 12:
    HEAP32[$39 >> 2] = 210;
    __label__ = 13;
    break;
   case 13:
    var $43 = $this + 12 | 0;
    var $44 = $16 + 24 | 0;
    var $45 = $18 + 28 | 0;
    var $46 = $data | 0;
    var $47 = $data + 16 | 0;
    __label__ = 14;
    break;
   case 14:
    var $49 = __ZN2js11TokenStream8getTokenEv($1);
    if (($49 | 0) == 25 || ($49 | 0) == 23) {
      __label__ = 15;
      break;
    } else if (($49 | 0) == 29) {
      __label__ = 30;
      break;
    } else if (($49 | 0) == -1) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 15:
    var $52 = HEAP32[$14 >> 2] | 0;
    var $54 = HEAP32[$52 >> 2] | 65536;
    HEAP32[$52 >> 2] = $54;
    var $55 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $49, 0);
    var $57 = HEAP32[$14 >> 2] | 0;
    var $59 = HEAP32[$57 >> 2] & -65537;
    HEAP32[$57 >> 2] = $59;
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $62 = HEAP32[$43 >> 2];
    var $63 = HEAP32[$14 >> 2];
    var $64 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($62, $data, $55, $63);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 53;
      break;
    }
   case 17:
    if ((HEAP32[HEAP32[$14 >> 2] >> 2] & 16 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($72 | 0) == 45) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    __ZN11JSParseNode6appendEPS_($35, $55);
    __label__ = 50;
    break;
   case 20:
    var $76 = __ZN2js11TokenStream8getTokenEj($1, 0);
    if (($76 | 0) == 4) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $79 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 50, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 22:
    var $81 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$81 + 24 >> 2] | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 23:
    if ($13) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $86 = __ZN2js6Parser10assignExprEv($this);
    var $100 = $86;
    __label__ = 26;
    break;
   case 25:
    var $88 = HEAP32[$44 >> 2];
    var $90 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$90 >> 2] = $88;
    var $91 = HEAP32[$45 >> 2];
    var $93 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$93 >> 2] = $91;
    var $94 = __ZN2js6Parser10assignExprEv($this);
    var $96 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$96 >> 2] = $16;
    var $98 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$98 >> 2] = $18;
    var $100 = $94;
    __label__ = 26;
    break;
   case 26:
    var $100;
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($55, $100 + 12 | 0);
    var $104 = HEAP32[$14 >> 2];
    var $105 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(4, 0, $55, $100, $104);
    if (($105 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN11JSParseNode6appendEPS_($35, $105);
    __label__ = 50;
    break;
   case 29:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 30:
    var $111 = __ZNK2js11TokenStream12currentTokenEv($1);
    var $113 = HEAP32[$111 + 28 >> 2];
    var $114 = HEAP32[$14 >> 2];
    var $115 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($113, $114, $7);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[$33 >> 2] | 0) == 128) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $122 = $115 + 44 | 0;
    var $124 = HEAP32[$122 >> 2] | 2;
    HEAP32[$122 >> 2] = $124;
    __label__ = 33;
    break;
   case 33:
    HEAP32[$46 >> 2] = $115;
    var $126 = HEAP32[$39 >> 2];
    var $127 = HEAP32[$43 >> 2];
    var $128 = HEAP32[$14 >> 2];
    var $129 = FUNCTION_TABLE[$126]($127, $data, $113, $128);
    if (($129 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    __ZN11JSParseNode6appendEPS_($35, $115);
    var $132 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 4);
    if ($132) {
      __label__ = 35;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 35:
    var $134 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$134 + 24 >> 2] | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 36:
    if ($13) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $139 = __ZN2js6Parser10assignExprEv($this);
    var $153 = $139;
    __label__ = 39;
    break;
   case 38:
    var $141 = HEAP32[$44 >> 2];
    var $143 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$143 >> 2] = $141;
    var $144 = HEAP32[$45 >> 2];
    var $146 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$146 >> 2] = $144;
    var $147 = __ZN2js6Parser10assignExprEv($this);
    var $149 = HEAP32[$14 >> 2] + 24 | 0;
    HEAP32[$149 >> 2] = $16;
    var $151 = HEAP32[$14 >> 2] + 28 | 0;
    HEAP32[$151 >> 2] = $18;
    var $153 = $147;
    __label__ = 39;
    break;
   case 39:
    var $153;
    if (($153 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $156 = __ZNK11JSParseNode6isUsedEv($115);
    if ($156) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $_idx_val = HEAP32[HEAP32[$14 >> 2] + 48 >> 2];
    var $159 = __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($115, $153, $_idx_val);
    if (($159 | 0) == 0) {
      var $_0 = 0;
      __label__ = 53;
      break;
    } else {
      var $pn2_0 = $159;
      __label__ = 43;
      break;
    }
   case 42:
    var $162 = $115 + 36 | 0;
    HEAP32[$162 >> 2] = $153;
    var $pn2_0 = $115;
    __label__ = 43;
    break;
   case 43:
    var $pn2_0;
    var $164 = __ZNK11JSParseNode4isOpE4JSOp($pn2_0, 9);
    if ($164) {
      var $176 = 111;
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if ((HEAP32[$pn2_0 + 44 >> 2] & 512 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      var $176 = 87;
      __label__ = 46;
      break;
    }
   case 45:
    var $174 = (HEAP32[$33 >> 2] | 0) == 128 ? 14 : 111;
    var $176 = $174;
    __label__ = 46;
    break;
   case 46:
    var $176;
    __ZN11JSParseNode5setOpE4JSOp($pn2_0, $176);
    var $177 = HEAP32[$43 >> 2];
    var $178 = HEAP32[$14 >> 2];
    var $182 = (HEAP8[$47] & 1) << 24 >> 24 != 0 ? 4 : 8;
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($177, $pn2_0, $178, $182);
    var $185 = $153 + 12 | 0;
    var $186 = $pn2_0 + 12 | 0;
    var $187$0 = HEAP32[$185 >> 2];
    var $187$1 = HEAP32[$185 + 4 >> 2];
    HEAP32[$186 >> 2] = $187$0;
    HEAP32[$186 + 4 >> 2] = $187$1;
    var $188 = HEAP32[$14 >> 2];
    var $189 = $188;
    var $190 = __ZNK13JSTreeContext10inFunctionEv($189);
    if ($190) {
      __label__ = 47;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 47:
    if (($113 | 0) == (HEAP32[HEAP32[HEAP32[$43 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 48:
    __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($188, $pn2_0);
    if (($4 | 0) == 81 || ($4 | 0) == 27) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $202 = HEAP32[$14 >> 2] | 0;
    var $204 = HEAP32[$202 >> 2] | 256;
    HEAP32[$202 >> 2] = $204;
    __label__ = 50;
    break;
   case 50:
    var $206 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($206) {
      __label__ = 14;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $208 = $34 + 12 | 0;
    var $209 = __ZNK11JSParseNode4lastEv($35);
    var $211 = $209 + 12 | 0;
    var $212 = $208;
    var $213$0 = HEAP32[$211 >> 2];
    var $213$1 = HEAP32[$211 + 4 >> 2];
    var $st$9$0 = $212 | 0;
    HEAP32[$st$9$0 >> 2] = $213$0;
    var $st$9$1 = $212 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $213$1;
    var $_0 = $35;
    __label__ = 53;
    break;
   case 52:
    var $215 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 128, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 53;
    break;
   case 53:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9variablesEb["X"] = 1;

function __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($this, $tt, $withFlags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $flagger = __stackBase__;
  __ZN2js11TokenStream7FlaggerC1EPS0_j($flagger, $this, $withFlags);
  var $1 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($this, $tt);
  __ZN2js11TokenStream7FlaggerD1Ev($flagger);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZL12PopStatementP13JSTreeContext($tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$tc + 24 >> 2];
    if ((HEAP16[$2 + 2 >> 1] & 1) << 16 >> 16 == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = HEAP32[HEAP32[$2 + 20 >> 2] + 8 >> 2];
    var $13 = __ZNK8JSObject12lastPropertyEv($12);
    var $14 = $r;
    var $15 = $13;
    __ZNK2js5Shape3allEv($14, $15);
    var $16 = __ZNK2js5Shape5Range5emptyEv($14);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $tc + 48 | 0;
    var $18 = $tc + 40 | 0;
    __label__ = 4;
    break;
   case 4:
    var $20 = __ZNK2js5Shape5Range5frontEv($r);
    var $22 = HEAP32[$20 + 12 >> 2];
    var $23 = __ZL12JSID_TO_ATOMi2949($22);
    if (($23 | 0) == (HEAP32[HEAP32[HEAP32[HEAP32[$17 >> 2] + 12 >> 2] + 52 >> 2] + 209972 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js9AtomDecls6removeEP6JSAtom($18, $23);
    __label__ = 6;
    break;
   case 6:
    __ZN2js5Shape5Range8popFrontEv($r);
    var $35 = __ZNK2js5Shape5Range5emptyEv($14);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 7:
    var $36 = $tc;
    _js_PopStatement($36);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser15switchStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 980 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 27) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 80, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 4:
    var $13 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($16 | 0) == 28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 81, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 7:
    var $21 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($21 | 0) == 25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 82, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 9:
    var $27 = HEAP32[$1 >> 2];
    _js_PushStatement($27, $stmtInfo, 5, -1);
    var $28 = HEAP32[$1 >> 2];
    var $29 = __ZN2js8ListNode6createEP13JSTreeContext($28);
    var $30 = $29 | 0;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode9makeEmptyEv($30);
    var $33 = HEAP32[$1 >> 2];
    var $34 = __ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext($30, $33);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 11:
    var $37 = HEAP32[$1 >> 2] + 36 | 0;
    var $38 = HEAP32[$37 >> 2];
    HEAP32[$37 >> 2] = $30;
    var $39 = $29 + 40 | 0;
    var $seenDefault_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $seenDefault_0;
    var $41 = __ZN2js11TokenStream8getTokenEv($7);
    if (($41 | 0) == 39) {
      __label__ = 13;
      break;
    } else if (($41 | 0) == 38) {
      var $seenDefault_1 = $seenDefault_0;
      __label__ = 15;
      break;
    } else if (($41 | 0) == 26) {
      __label__ = 32;
      break;
    } else if (($41 | 0) == -1) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 13:
    if (($seenDefault_0 | 0) == 0) {
      var $seenDefault_1 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 114, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 15:
    var $seenDefault_1;
    var $47 = HEAP32[$1 >> 2];
    var $48 = __ZN2js10BinaryNode6createEP13JSTreeContext($47);
    var $49 = $48 | 0;
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($41 | 0) == 38) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $54 = __ZN2js6Parser4exprEv($this);
    var $55 = $48 + 32 | 0;
    HEAP32[$55 >> 2] = $54;
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN11JSParseNode6appendEPS_($30, $49);
    if ((HEAP32[$39 >> 2] | 0) == 65536) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $61 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 115, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 20:
    var $63 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 116, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 21:
    var $65 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($65 | 0) == 6) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $68 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 83, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 33;
    break;
   case 23:
    var $70 = HEAP32[$1 >> 2];
    var $71 = __ZN2js8ListNode6createEP13JSTreeContext($70);
    var $72 = $71 | 0;
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 25);
    __ZN11JSParseNode9makeEmptyEv($72);
    var $76 = $71 + 12 | 0;
    __label__ = 25;
    break;
   case 25:
    var $78 = __ZN2js11TokenStream9peekTokenEj($7, 8);
    if (($78 | 0) != 26 & ($78 - 38 | 0) >>> 0 > 1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    if (($78 | 0) == -1) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $84 = __ZN2js6Parser9statementEv($this);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $88 = $84 + 12 | 0;
    var $st$2$0 = $88 | 0;
    var $89$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $88 + 4 | 0;
    var $89$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $76 | 0;
    HEAP32[$st$6$0 >> 2] = $89$0;
    var $st$6$1 = $76 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $89$1;
    __ZN11JSParseNode6appendEPS_($72, $84);
    __label__ = 25;
    break;
   case 29:
    var $91 = HEAP32[$71 + 32 >> 2];
    if (($91 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $96 = $91 + 4 | 0;
    var $97 = $71 + 4 | 0;
    var $98$0 = HEAP32[$96 >> 2];
    var $98$1 = HEAP32[$96 + 4 >> 2];
    var $st$8$0 = $97 | 0;
    HEAP32[$st$8$0 >> 2] = $98$0;
    var $st$8$1 = $97 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $98$1;
    __label__ = 31;
    break;
   case 31:
    var $101 = $48 + 12 | 0;
    var $st$2$0 = $76 | 0;
    var $102$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $76 + 4 | 0;
    var $102$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $101 | 0;
    HEAP32[$st$6$0 >> 2] = $102$0;
    var $st$6$1 = $101 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $102$1;
    var $103 = $48 + 36 | 0;
    var $_c = $71;
    HEAP32[$103 >> 2] = $_c;
    var $seenDefault_0 = $seenDefault_1;
    __label__ = 12;
    break;
   case 32:
    var $106 = HEAP32[$1 >> 2] + 36 | 0;
    var $107 = HEAP32[$106 >> 2];
    HEAP32[$106 >> 2] = $38;
    var $108 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($108);
    var $109 = $3 + 12 | 0;
    var $110 = $107 + 12 | 0;
    var $111 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $113 = $111 + 12 | 0;
    var $114 = $110;
    var $115$0 = HEAP32[$113 >> 2];
    var $115$1 = HEAP32[$113 + 4 >> 2];
    var $st$16$0 = $114 | 0;
    HEAP32[$st$16$0 >> 2] = $115$0;
    var $st$16$1 = $114 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $115$1;
    var $116 = $109;
    var $st$21$0 = $116 | 0;
    HEAP32[$st$21$0 >> 2] = $115$0;
    var $st$21$1 = $116 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $115$1;
    var $117 = $3 + 32 | 0;
    HEAP32[$117 >> 2] = $13;
    var $118 = $3 + 36 | 0;
    var $pn2_0_c = $107;
    HEAP32[$118 >> 2] = $pn2_0_c;
    var $_0 = $4;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser15switchStatementEv["X"] = 1;

function __ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 24 | 0;
    var $3 = HEAP32[$1 >> 2] + 4 | 0;
    var $4 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = $pn + 44 | 0;
    var $14 = HEAP32[$10 >> 2] & 4095 | HEAP32[HEAP32[$1 >> 2] + 4 >> 2] << 12;
    HEAP32[$10 >> 2] = $14;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906($tt) {
  return ($tt | 0) == 46 | ($tt | 0) == 81;
}

function __ZN2js6Parser12forStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blockInfo = __stackBase__;
    var $stmtInfo = __stackBase__ + 32;
    var $1 = $this + 980 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js10BinaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$1 >> 2];
    var $9 = $stmtInfo;
    _js_PushStatement($8, $9, 12, -1);
    __ZN11JSParseNode5setOpE4JSOp($4, 75);
    var $11 = $3 + 44 | 0;
    HEAP32[$11 >> 2] = 0;
    var $12 = $this + 40 | 0;
    var $13 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 29);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $15 = __ZNK2js11TokenStream12currentTokenEv($12);
    if ((HEAP32[$15 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210208 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$11 >> 2] = 2;
    __label__ = 6;
    break;
   case 5:
    __ZN2js11TokenStream10ungetTokenEv($12);
    __label__ = 6;
    break;
   case 6:
    var $29 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($29 | 0) == 27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 85, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 8:
    var $34 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($34 | 0) == 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      var $pnlet_1 = 0;
      var $tt_1 = 2;
      var $let_1 = 0;
      var $pn1_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $41 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $4, 0, 193, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 11:
    var $44 = HEAP32[$1 >> 2] | 0;
    var $46 = HEAP32[$44 >> 2] | 16;
    HEAP32[$44 >> 2] = $46;
    if (($34 | 0) == 46) {
      __label__ = 12;
      break;
    } else if (($34 | 0) == 81) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 12:
    var $48 = __ZN2js11TokenStream8getTokenEv($12);
    var $49 = __ZN2js6Parser9variablesEb($this, 0);
    var $pnlet_0 = 0;
    var $tt_0 = 46;
    var $let_0 = 0;
    var $pn1_0 = $49;
    __label__ = 18;
    break;
   case 13:
    var $51 = __ZN2js11TokenStream8getTokenEv($12);
    var $52 = __ZN2js11TokenStream9peekTokenEv($12);
    if (($52 | 0) == 27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $55 = __ZN2js6Parser8letBlockEi($this, 0);
    var $pnlet_0 = 0;
    var $tt_0 = 80;
    var $let_0 = 1;
    var $pn1_0 = $55;
    __label__ = 18;
    break;
   case 15:
    var $58 = HEAP32[$this + 12 >> 2];
    var $59 = HEAP32[$1 >> 2];
    var $60 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($58, $59, $blockInfo);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $63 = $blockInfo + 2 | 0;
    var $65 = HEAP16[$63 >> 1] | 4;
    HEAP16[$63 >> 1] = $65;
    var $66 = __ZN2js6Parser9variablesEb($this, 0);
    var $pnlet_0 = $60;
    var $tt_0 = $34;
    var $let_0 = 1;
    var $pn1_0 = $66;
    __label__ = 18;
    break;
   case 17:
    var $68 = __ZN2js6Parser4exprEv($this);
    var $pnlet_0 = 0;
    var $tt_0 = $34;
    var $let_0 = 0;
    var $pn1_0 = $68;
    __label__ = 18;
    break;
   case 18:
    var $pn1_0;
    var $let_0;
    var $tt_0;
    var $pnlet_0;
    var $71 = HEAP32[$1 >> 2] | 0;
    var $73 = HEAP32[$71 >> 2] & -17;
    HEAP32[$71 >> 2] = $73;
    if (($pn1_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pnlet_1 = $pnlet_0;
      var $tt_1 = $tt_0;
      var $let_1 = $let_0;
      var $pn1_1 = $pn1_0;
      __label__ = 19;
      break;
    }
   case 19:
    var $pn1_1;
    var $let_1;
    var $tt_1;
    var $pnlet_1;
    var $76 = HEAP32[$1 >> 2];
    var $77 = __ZN2js11TernaryNode6createEP13JSTreeContext($76);
    var $78 = $77 | 0;
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($pn1_1 | 0) == 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $83 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($12, 45);
    if ($83) {
      __label__ = 22;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 22:
    var $86 = HEAP32[$11 >> 2] | 1;
    HEAP32[$11 >> 2] = $86;
    HEAP16[$stmtInfo >> 1] = 13;
    var $88 = __ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906($tt_1);
    if ($88) {
      __label__ = 23;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 23:
    if (HEAPU32[$pn1_1 + 40 >> 2] >>> 0 > 1) {
      __label__ = 47;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $94 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 128);
    if ($94) {
      __label__ = 47;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $96 = __ZNK2js6Parser13versionNumberEv($this);
    if (($96 | 0) == 170) {
      __label__ = 26;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 26:
    var $99 = __ZNK11JSParseNode4isOpE4JSOp($4, 75);
    if ($99) {
      __label__ = 27;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 27:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 28:
    var $106 = HEAP32[$pn1_1 + 32 >> 2];
    var $107 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 26);
    if ($107) {
      __label__ = 47;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $109 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 24);
    if ($109) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    if ((HEAP32[$106 + 40 >> 2] | 0) == 2) {
      __label__ = 31;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 31:
    var $115 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($106, 4);
    if ($115) {
      __label__ = 32;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 32:
    var $118 = HEAP32[$106 + 32 >> 2];
    var $119 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($118, 24);
    if ($119) {
      __label__ = 33;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 33:
    if ((HEAP32[$118 + 40 >> 2] | 0) == 2) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 34:
    var $125 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 29);
    if ($125) {
      __label__ = 58;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $127 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 22);
    if ($127) {
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $129 = __ZNK2js6Parser13versionNumberEv($this);
    if (($129 | 0) == 170) {
      __label__ = 37;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 37:
    var $132 = __ZNK11JSParseNode4isOpE4JSOp($4, 75);
    if ($132) {
      __label__ = 38;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 38:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $138 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 24);
    if ($138) {
      __label__ = 40;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 40:
    if ((HEAP32[$pn1_1 + 40 >> 2] | 0) == 2) {
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 41:
    var $144 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 24);
    if ($144) {
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $146 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 26);
    if ($146) {
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $148 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 27);
    if ($148) {
      __label__ = 48;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $150 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 19);
    if ($150) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $152 = __ZNK11JSParseNode4isOpE4JSOp($pn1_1, 174);
    if ($152) {
      __label__ = 48;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $154 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn1_1, 23);
    if ($154) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $156 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $pn1_1, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 48:
    if ($88) {
      __label__ = 49;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 49:
    var $160 = $pn1_1 + 44 | 0;
    var $162 = HEAP32[$160 >> 2] | 8;
    HEAP32[$160 >> 2] = $162;
    var $164 = HEAP32[$pn1_1 + 32 >> 2];
    var $165 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 29);
    if ($165) {
      __label__ = 50;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 50:
    var $167 = __ZN11JSParseNode9maybeExprEv($164);
    if (($167 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $170 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 4);
    if ($170) {
      __label__ = 52;
      break;
    } else {
      var $dflag_0 = 8;
      var $pnseq_0 = 0;
      var $pn1_2 = $pn1_1;
      var $pn2_1 = $164;
      __label__ = 57;
      break;
    }
   case 52:
    if (($tt_1 | 0) == 81) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $174 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $164, 0, 268, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 54:
    var $176 = HEAP32[$1 >> 2];
    var $177 = __ZN2js8ListNode6createEP13JSTreeContext($176);
    var $178 = $177 | 0;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($178, 82);
    var $183 = $3 + 4 | 0;
    var $184 = $177 + 4 | 0;
    var $185$0 = HEAP32[$183 >> 2];
    var $185$1 = HEAP32[$183 + 4 >> 2];
    var $st$9$0 = $184 | 0;
    HEAP32[$st$9$0 >> 2] = $185$0;
    var $st$9$1 = $184 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $185$1;
    var $188 = HEAP32[$160 >> 2] & -13 | 4;
    HEAP32[$160 >> 2] = $188;
    __ZN11JSParseNode8initListEPS_($178, $pn1_1);
    var $189 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($164, 4);
    if ($189) {
      __label__ = 56;
      break;
    } else {
      var $dflag_0 = 4;
      var $pnseq_0 = $178;
      var $pn1_2 = 0;
      var $pn2_1 = $164;
      __label__ = 57;
      break;
    }
   case 56:
    var $dflag_0 = 4;
    var $pnseq_0 = $178;
    var $pn1_2 = 0;
    var $pn2_1 = HEAP32[$164 + 32 >> 2];
    __label__ = 57;
    break;
   case 57:
    var $pn2_1;
    var $pn1_2;
    var $pnseq_0;
    var $dflag_0;
    var $194 = HEAP32[$1 >> 2];
    var $195 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($pn2_1, $194);
    if (($195 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $dflag_1 = $dflag_0;
      var $pnseq_1 = $pnseq_0;
      var $pn1_3 = $pn1_2;
      var $pn2_2 = $195;
      __label__ = 59;
      break;
    }
   case 58:
    var $197 = __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $pn1_1, 0);
    if ($197) {
      var $dflag_1 = 8;
      var $pnseq_1 = 0;
      var $pn1_3 = 0;
      var $pn2_2 = $pn1_1;
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 89;
      break;
    }
   case 59:
    var $pn2_2;
    var $pn1_3;
    var $pnseq_1;
    var $dflag_1;
    var $199 = __ZNK11JSParseNode7getKindEv($pn2_2);
    if (($199 | 0) == 29) {
      __label__ = 60;
      break;
    } else if (($199 | 0) == 26 || ($199 | 0) == 24) {
      __label__ = 61;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 60:
    var $202 = HEAP32[$this + 12 >> 2];
    var $203 = HEAP32[$1 >> 2];
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($202, $pn2_2, $203, $dflag_1);
    __label__ = 64;
    break;
   case 61:
    var $205 = __ZNK2js6Parser13versionNumberEv($this);
    if (($205 | 0) == 170) {
      __label__ = 62;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 62:
    var $208 = HEAP32[$11 >> 2];
    if (($208 & 2 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $212 = $208 | 6;
    HEAP32[$11 >> 2] = $212;
    __label__ = 64;
    break;
   case 64:
    var $215 = HEAP32[$1 >> 2] + 24 | 0;
    var $216 = HEAP32[$215 >> 2];
    var $218 = ($let_1 & 1) << 24 >> 24 != 0;
    if ($218) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $221 = HEAP32[$216 + 24 >> 2];
    HEAP32[$215 >> 2] = $221;
    __label__ = 66;
    break;
   case 66:
    var $223 = __ZN2js6Parser4exprEv($this);
    if (($223 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    if ($218) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $228 = HEAP32[$1 >> 2] + 24 | 0;
    HEAP32[$228 >> 2] = $216;
    __label__ = 69;
    break;
   case 69:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 45);
    var $pnseq_2 = $pnseq_1;
    var $pn1_4 = $pn1_3;
    var $pn2_4 = $pn2_2;
    var $pn3_1 = $223;
    __label__ = 81;
    break;
   case 70:
    if ((HEAP32[$11 >> 2] & 2 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $235 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $4, 0, 193, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 72:
    __ZN11JSParseNode5setOpE4JSOp($4, 0);
    var $237 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($237 | 0) == 2) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $240 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 86, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 74:
    var $242 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($242 | 0) == 2) {
      var $pn2_3 = 0;
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $245 = __ZN2js6Parser4exprEv($this);
    if (($245 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pn2_3 = $245;
      __label__ = 76;
      break;
    }
   case 76:
    var $pn2_3;
    var $248 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($248 | 0) == 2) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $251 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 87, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 78:
    var $253 = __ZN2js11TokenStream9peekTokenEj($12, 8);
    if (($253 | 0) == 28) {
      var $pn3_0 = 0;
      __label__ = 80;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $256 = __ZN2js6Parser4exprEv($this);
    if (($256 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      var $pn3_0 = $256;
      __label__ = 80;
      break;
    }
   case 80:
    var $pn3_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 83);
    var $pnseq_2 = 0;
    var $pn1_4 = $pn1_1;
    var $pn2_4 = $pn2_3;
    var $pn3_1 = $pn3_0;
    __label__ = 81;
    break;
   case 81:
    var $pn3_1;
    var $pn2_4;
    var $pn1_4;
    var $pnseq_2;
    __ZN11JSParseNode5setOpE4JSOp($78, 0);
    var $260 = $77 + 32 | 0;
    HEAP32[$260 >> 2] = $pn1_4;
    var $261 = $77 + 36 | 0;
    HEAP32[$261 >> 2] = $pn2_4;
    var $262 = $77 + 40 | 0;
    HEAP32[$262 >> 2] = $pn3_1;
    var $263 = $3 + 32 | 0;
    HEAP32[$263 >> 2] = $78;
    var $264 = __ZN2js11TokenStream8getTokenEj($12, 0);
    if (($264 | 0) == 28) {
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $267 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 88, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 89;
    break;
   case 83:
    var $269 = __ZN2js6Parser9statementEv($this);
    if (($269 | 0) == 0) {
      var $_0 = 0;
      __label__ = 89;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $272 = $3 + 36 | 0;
    HEAP32[$272 >> 2] = $269;
    var $275 = $269 + 12 | 0;
    var $276 = $3 + 12 | 0;
    var $277$0 = HEAP32[$275 >> 2];
    var $277$1 = HEAP32[$275 + 4 >> 2];
    var $st$11$0 = $276 | 0;
    HEAP32[$st$11$0 >> 2] = $277$0;
    var $st$11$1 = $276 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $277$1;
    if (($pnlet_1 | 0) == 0) {
      var $pn_0 = $4;
      __label__ = 86;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    var $280 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($280);
    var $_c1 = $3;
    HEAP32[$pnlet_1 + 36 >> 2] = $_c1;
    var $pn_0 = $pnlet_1;
    __label__ = 86;
    break;
   case 86:
    var $pn_0;
    if (($pnseq_2 | 0) == 0) {
      var $pn_1 = $pn_0;
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    var $287 = $pn_0 + 12 | 0;
    var $288 = $pnseq_2 + 12 | 0;
    var $289$0 = HEAP32[$287 >> 2];
    var $289$1 = HEAP32[$287 + 4 >> 2];
    HEAP32[$288 >> 2] = $289$0;
    HEAP32[$288 + 4 >> 2] = $289$1;
    __ZN11JSParseNode6appendEPS_($pnseq_2, $pn_0);
    var $pn_1 = $pnseq_2;
    __label__ = 88;
    break;
   case 88:
    var $pn_1;
    var $291 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($291);
    var $_0 = $pn_1;
    __label__ = 89;
    break;
   case 89:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12forStatementEv["X"] = 1;

function __ZN2js11TokenStream9peekTokenEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 136 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 4 + ((HEAP32[$this + 132 >> 2] + $2 & 3) << 5) >> 2];
    __label__ = 4;
    break;
   case 3:
    var $12 = __ZN2js11TokenStream16getTokenInternalEv($this);
    __ZN2js11TokenStream10ungetTokenEv($this);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TernaryNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(3, $tc);
  return $1;
}

function __ZNK2js6Parser13versionNumberEv($this) {
  var $1 = $this + 40 | 0;
  var $2 = __ZNK2js11TokenStream13versionNumberEv($1);
  return $2;
}

function __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($opn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tc_idx_val = HEAP32[$tc + 48 >> 2];
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_idx_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode7getKindEv($opn);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($1, $4);
    var $5 = __ZNK11JSParseNode5getOpEv($opn);
    __ZN11JSParseNode5setOpE4JSOp($1, $5);
    var $6 = __ZNK11JSParseNode6isUsedEv($opn);
    __ZN11JSParseNode7setUsedEb($1, $6);
    var $7 = __ZNK11JSParseNode6isDefnEv($opn);
    __ZN11JSParseNode7setDefnEb($1, $7);
    var $8 = __ZNK11JSParseNode8getArityEv($opn);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($1, $8);
    var $9 = __ZNK11JSParseNode10isInParensEv($opn);
    __ZN11JSParseNode11setInParensEb($1, $9);
    var $12 = $1 + 4 | 0;
    var $13 = $opn + 4 | 0;
    HEAP32[$12 >> 2] = HEAP32[$13 >> 2];
    HEAP32[$12 + 4 >> 2] = HEAP32[$13 + 4 >> 2];
    HEAP32[$12 + 8 >> 2] = HEAP32[$13 + 8 >> 2];
    HEAP32[$12 + 12 >> 2] = HEAP32[$13 + 12 >> 2];
    var $14 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($opn, 5);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    __ZN11JSParseNode9makeEmptyEv($1);
    var $opn2_0_in = $opn + 32 | 0;
    __label__ = 4;
    break;
   case 4:
    var $opn2_0_in;
    var $opn2_0 = HEAP32[$opn2_0_in >> 2];
    if (($opn2_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($opn, 26);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $23 = HEAP32[$opn2_0 + 32 >> 2];
    var $24 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($23, $tc);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $29 = HEAP32[$opn2_0 + 36 >> 2];
    var $30 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($29, $tc);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $33 = $opn2_0 + 4 | 0;
    var $34 = __ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext(6, 93, $33, $24, $30, $tc);
    var $pn2_0 = $34 | 0;
    __label__ = 12;
    break;
   case 9:
    var $37 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($opn2_0, 0);
    if ($37) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    var $pn2_0 = $39;
    __label__ = 12;
    break;
   case 11:
    var $41 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    var $pn2_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN11JSParseNode6appendEPS_($1, $pn2_0);
    var $opn2_0_in = $opn2_0 + 24 | 0;
    __label__ = 4;
    break;
   case 14:
    var $52 = $1 + 44 | 0;
    var $55 = HEAP32[$52 >> 2] & -4096 | HEAP32[$opn + 44 >> 2] & 4095;
    HEAP32[$52 >> 2] = $55;
    var $_0 = $1;
    __label__ = 19;
    break;
   case 15:
    var $59 = $1 + 32 | 0;
    var $60 = $opn + 32 | 0;
    HEAP32[$59 >> 2] = HEAP32[$60 >> 2];
    HEAP32[$59 + 4 >> 2] = HEAP32[$60 + 4 >> 2];
    HEAP32[$59 + 8 >> 2] = HEAP32[$60 + 8 >> 2];
    HEAP32[$59 + 12 >> 2] = HEAP32[$60 + 12 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($1, 111);
    var $61 = __ZNK11JSParseNode6isUsedEv($opn);
    var $62 = $1 + 36 | 0;
    if ($61) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $65 = HEAP32[$62 >> 2] + 28 | 0;
    var $66 = HEAP32[$65 >> 2];
    var $67 = $1 + 28 | 0;
    HEAP32[$67 >> 2] = $66;
    HEAP32[$65 >> 2] = $1;
    var $_0 = $1;
    __label__ = 19;
    break;
   case 17:
    HEAP32[$62 >> 2] = 0;
    var $69 = __ZNK11JSParseNode6isDefnEv($opn);
    if ($69) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $1;
      __label__ = 19;
      break;
    }
   case 18:
    var $72 = $1 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($72);
    var $74 = $1 + 44 | 0;
    var $76 = HEAP32[$74 >> 2] & -513;
    HEAP32[$74 >> 2] = $76;
    __ZN11JSParseNode7setDefnEb($1, 0);
    var $77 = $opn;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($1, $77);
    var $_0 = $1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp($this, $pn, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 22) {
      __label__ = 4;
      break;
    } else if (($1 | 0) == 23) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 24 || ($1 | 0) == 26) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 27) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 19) {
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $3 = $this + 12 | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $this + 980 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($4, $6, $pn);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($pn, 86);
    var $10 = $9 ? 87 : 111;
    __ZN11JSParseNode5setOpE4JSOp($pn, $10);
    var $11 = HEAP32[$3 >> 2];
    var $12 = HEAP32[$5 >> 2];
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($11, $pn, $12, 8);
    __label__ = 13;
    break;
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($pn, 54);
    __label__ = 13;
    break;
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($pn, 56);
    __label__ = 13;
    break;
   case 6:
    if (($op | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 51, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $21 = HEAP32[$this + 12 >> 2];
    var $23 = HEAP32[$this + 980 >> 2];
    var $24 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($21, 0, $pn, $23);
    if ($24) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $27 = HEAP32[$this + 12 >> 2];
    var $29 = HEAP32[$this + 980 >> 2];
    var $30 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($27, $pn, $29, 129);
    if ($30) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $32 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN11JSParseNode5setOpE4JSOp($pn, 173);
    __label__ = 13;
    break;
   case 12:
    var $35 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, $dflag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $dflag;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAPU32[$pn + 36 >> 2];
    var $5 = $4;
    var $6 = $4 + 44 | 0;
    var $8 = HEAPU32[$6 >> 2];
    if (($8 & 134 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 3:
    var $12 = __ZNK11JSParseNode12isBlockChildEv($5);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 4:
    var $14 = __ZNK11JSParseNode12isBlockChildEv($pn);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 5:
    if (($8 >>> 12 | 0) == (HEAPU32[$pn + 44 >> 2] >>> 12 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 6:
    var $24 = $4 + 12 | 0;
    var $25 = $pn + 4 | 0;
    var $26 = __ZN2js8TokenPtrleERKS0_($24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 7:
    if ((HEAP32[$4 + 28 >> 2] | 0) == ($pn | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $dflag;
      __label__ = 9;
      break;
    }
   case 8:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    HEAP32[$6 >> 2] = $_0 & 4095 | $8;
    var $36 = $4 + 40 | 0;
    var $37 = __ZNK2js11UpvarCookie6isFreeEv($36);
    if ($37) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = __ZNK11JSParseNode10frameLevelEv($5);
    if ($39 >>> 0 < HEAPU32[$tc + 76 >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_1 = $_0;
      __label__ = 12;
      break;
    }
   case 11:
    var $44 = $tc | 0;
    var $46 = HEAP32[$44 >> 2] | 32;
    HEAP32[$44 >> 2] = $46;
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    var $48 = $pn + 32 | 0;
    var $50 = $pn + 44 | 0;
    var $53 = $_1 & 4095 | HEAP32[$50 >> 2];
    HEAP32[$50 >> 2] = $53;
    var $55 = HEAPU32[$48 >> 2];
    if (($55 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $63 = $tc | 0;
    var $65 = HEAP32[$63 >> 2] | 256;
    HEAP32[$63 >> 2] = $65;
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($tc, $pn);
    __label__ = 17;
    break;
   case 14:
    var $67 = $tc;
    var $68 = __ZNK13JSTreeContext10inFunctionEv($67);
    if ($68) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $70 = __ZNK13JSTreeContext3funEv($67);
    if (($55 | 0) == (HEAP32[$70 + 72 >> 2] | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $75 = $tc | 0;
    var $77 = HEAP32[$75 >> 2] | 256;
    HEAP32[$75 >> 2] = $77;
    __label__ = 17;
    break;
   case 17:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj["X"] = 1;

function __ZN2js6Parser12tryStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $data = __stackBase__ + 32;
    var $1 = $this + 980 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js11TernaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($4, 0);
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($8 | 0) == 25) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 89, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 4:
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo, 8, $13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 5:
    var $16 = __ZN2js6Parser10statementsEv($this);
    var $17 = $3 + 32 | 0;
    HEAP32[$17 >> 2] = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($20 | 0) == 26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 90, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 8:
    var $25 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($25);
    var $26 = __ZN2js11TokenStream8getTokenEv($7);
    if (($26 | 0) == 54) {
      __label__ = 9;
      break;
    } else {
      var $catchList_0 = 0;
      var $tt_0 = $26;
      __label__ = 33;
      break;
    }
   case 9:
    var $29 = HEAP32[$1 >> 2];
    var $30 = __ZN2js8ListNode6createEP13JSTreeContext($29);
    var $31 = $30 | 0;
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($31, 86);
    __ZN11JSParseNode9makeEmptyEv($31);
    var $34 = $this + 12 | 0;
    var $35 = $stmtInfo | 0;
    var $36 = $data | 0;
    var $37 = $data + 4 | 0;
    var $38 = $data + 8 | 0;
    var $39 = $data + 12 | 0;
    var $lastCatch_0 = 0;
    __label__ = 11;
    break;
   case 11:
    var $lastCatch_0;
    __ZN8BindDataC1Ev($data);
    if (($lastCatch_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$lastCatch_0 + 36 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $47 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 118, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 14:
    var $49 = HEAP32[$34 >> 2];
    var $50 = HEAP32[$1 >> 2];
    var $51 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($49, $50, $stmtInfo);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP16[$35 >> 1] = 7;
    var $54 = HEAP32[$1 >> 2];
    var $55 = __ZN2js11TernaryNode6createEP13JSTreeContext($54);
    var $56 = $55 | 0;
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = $51 + 36 | 0;
    var $_c1 = $55;
    HEAP32[$59 >> 2] = $_c1;
    var $60 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($60 | 0) == 27) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $63 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 91, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 18:
    HEAP32[$36 >> 2] = 0;
    HEAP32[$37 >> 2] = 0;
    HEAP32[$38 >> 2] = 208;
    HEAP32[$39 >> 2] = 169;
    var $65 = __ZN2js11TokenStream8getTokenEv($7);
    if (($65 | 0) == 23 || ($65 | 0) == 25) {
      __label__ = 19;
      break;
    } else if (($65 | 0) == 29) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $67 = __ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE($this, $data, $65);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $pn3_0 = $67;
      __label__ = 23;
      break;
    }
   case 20:
    var $70 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $72 = HEAP32[$70 + 28 >> 2];
    var $73 = HEAP32[$1 >> 2];
    var $74 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($72, $73, 1);
    if (($74 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$36 >> 2] = $74;
    var $77 = HEAP32[$38 >> 2];
    var $78 = HEAP32[$34 >> 2];
    var $79 = HEAP32[$1 >> 2];
    var $80 = FUNCTION_TABLE[$77]($78, $data, $72, $79);
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $pn3_0 = $74;
      __label__ = 23;
      break;
    }
   case 22:
    var $83 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 92, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 23:
    var $pn3_0;
    var $85 = $55 + 32 | 0;
    HEAP32[$85 >> 2] = $pn3_0;
    var $86 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($7, 35);
    if ($86) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $88 = __ZN2js6Parser4exprEv($this);
    var $89 = $55 + 36 | 0;
    HEAP32[$89 >> 2] = $88;
    if (($88 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $92 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($92 | 0) == 28) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $95 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 93, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 27:
    var $97 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($97 | 0) == 25) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $100 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 94, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 29:
    var $102 = __ZN2js6Parser10statementsEv($this);
    var $103 = $55 + 40 | 0;
    HEAP32[$103 >> 2] = $102;
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $106 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($106 | 0) == 26) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 95, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 32:
    var $111 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($111);
    __ZN11JSParseNode6appendEPS_($31, $51);
    var $112 = __ZN2js11TokenStream8getTokenEj($7, 8);
    if (($112 | 0) == 54) {
      var $lastCatch_0 = $56;
      __label__ = 11;
      break;
    } else {
      var $catchList_0 = $31;
      var $tt_0 = $112;
      __label__ = 33;
      break;
    }
   case 33:
    var $tt_0;
    var $catchList_0;
    var $114 = $3 + 36 | 0;
    HEAP32[$114 >> 2] = $catchList_0;
    if (($tt_0 | 0) == 55) {
      __label__ = 34;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 34:
    var $117 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($117 | 0) == 25) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $120 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 96, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 36:
    var $122 = HEAP32[$1 >> 2];
    var $123 = __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmtInfo, 9, $122);
    if ($123) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 37:
    var $125 = __ZN2js6Parser10statementsEv($this);
    var $126 = $3 + 40 | 0;
    HEAP32[$126 >> 2] = $125;
    if (($125 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $129 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($129 | 0) == 26) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $132 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 97, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 40:
    var $134 = HEAP32[$1 >> 2];
    __ZL12PopStatementP13JSTreeContext($134);
    __label__ = 42;
    break;
   case 41:
    __ZN2js11TokenStream10ungetTokenEv($7);
    __label__ = 42;
    break;
   case 42:
    if (($catchList_0 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      var $_0 = $4;
      __label__ = 45;
      break;
    }
   case 43:
    if ((HEAP32[$3 + 40 >> 2] | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      var $_0 = $4;
      __label__ = 45;
      break;
    }
   case 44:
    var $144 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 98, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12tryStatementEv["X"] = 1;

function __ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext($stmt, $type, $tc) {
  var $1 = $tc;
  var $2 = $stmt;
  _js_PushStatement($1, $2, $type, -1);
  var $3 = $stmt + 4 | 0;
  var $4 = __ZL15GenerateBlockIdP13JSTreeContextRj($tc, $3);
  return $4;
}

function __ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $3 = HEAPU32[$data >> 2];
    var $4 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $6 = $tc;
    var $7 = __ZN13JSTreeContext10blockChainEv($6);
    var $8 = $tc + 40 | 0;
    var $9 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($8, $atom);
    if (($9 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9 | 0;
    var $16 = HEAPU32[$9 + 44 >> 2] >>> 12;
    var $17 = __ZN13JSTreeContext7blockidEv($6);
    if (($16 | 0) == ($17 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    __ZN16JSAutoByteStringC1Ev($name);
    var $20 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $26 = __ZNK11JSParseNode7isConstEv($12);
    var $27 = $26 ? STRING_TABLE._js_const_str | 0 : STRING_TABLE.__ZL15js_variable_str | 0;
    var $28 = __ZNK16JSAutoByteString3ptrEv($name);
    var $29 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $25, $3, 0, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $27, HEAP32[tempInt + 4 >> 2] = $28, tempInt));
    __label__ = 6;
    break;
   case 6:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 7:
    var $32 = $7;
    var $33 = __ZNK8JSObject13propertyCountEv($32);
    if (($33 | 0) == 65536) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $38 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $40 = HEAP32[$data + 12 >> 2];
    var $41 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $38, $3, 0, $40, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 9:
    var $43 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($3, $atom, $tc, 1);
    if ($43) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    __ZN11JSParseNode5setOpE4JSOp($3, 86);
    var $46 = $3 + 40 | 0;
    var $49 = HEAP32[$tc + 76 >> 2] & 65535;
    var $50 = $33 & 65535;
    __ZN2js11UpvarCookie3setEtt($46, $49, $50);
    var $52 = $3 + 44 | 0;
    var $54 = HEAP32[$52 >> 2] | 513;
    HEAP32[$52 >> 2] = $54;
    var $55 = __ZL12ATOM_TO_JSIDP6JSAtom2903($atom);
    var $56 = $7;
    var $57 = $cx;
    var $58 = __ZN8JSObject19defineBlockVariableEP9JSContextii($56, $57, $55, $33);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $62 = HEAP32[$58 + 24 >> 2];
    var $63 = $3 | 0;
    __ZN2JSL12PrivateValueEPv2951($1, $63);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, $62, $1);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext["X"] = 1;

function __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($atom, $tc, $let) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $removal = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $2 = $tc + 40 | 0;
    var $3 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($2, $atom);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_pn = $3;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $tc + 64 | 0;
    var $7 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($6);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($removal, $7, $1);
    var $8 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($removal);
    if (($8 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($removal);
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $_pn = $12;
      __label__ = 4;
      break;
    }
   case 4:
    var $_pn;
    var $pn_05 = $_pn | 0;
    var $14 = __ZNK11JSParseNode13isPlaceholderEv($pn_05);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $17 = $_pn + 44 | 0;
    var $18 = HEAPU32[$17 >> 2];
    var $19 = $18 >>> 12;
    if ($let) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = $tc;
    var $22 = __ZN13JSTreeContext7blockidEv($21);
    var $27 = $22;
    __label__ = 8;
    break;
   case 7:
    var $27 = HEAP32[$tc + 4 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $27;
    if ($19 >>> 0 < $27 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($let) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = $tc;
    var $32 = __ZN13JSTreeContext7blockidEv($31);
    HEAP32[$17 >> 2] = $18 & 4095 | $32 << 12;
    __label__ = 11;
    break;
   case 11:
    var $37 = $tc + 64 | 0;
    var $38 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($37);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($38, $removal);
    var $_0 = $pn_05;
    __label__ = 15;
    break;
   case 12:
    var $39 = HEAPU32[$1 >> 2];
    var $40 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($39, $tc);
    var $41 = $40 | 0;
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($39 | 0) == (HEAP32[HEAP32[HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $41;
      __label__ = 15;
      break;
    }
   case 14:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($tc, $41);
    var $_0 = $41;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14NewBindingNodeP6JSAtomP13JSTreeContextb["X"] = 1;

function __ZN2js6Parser13withStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $r = __stackBase__ + 32;
    var $1 = __stackBase__ + 52;
    var $2 = $this + 980 | 0;
    var $3 = HEAP32[$2 >> 2];
    if ((HEAP32[$3 >> 2] & 262144 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 233, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 3:
    var $11 = __ZN2js10BinaryNode6createEP13JSTreeContext($3);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $this + 40 | 0;
    var $16 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($16 | 0) == 27) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 99, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $21 = __ZN2js6Parser9parenExprEPi($this, 0);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($24 | 0) == 28) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 100, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 9:
    var $29 = $11 + 32 | 0;
    HEAP32[$29 >> 2] = $21;
    var $31 = HEAP32[$2 >> 2] + 88 | 0;
    var $32 = HEAP32[$31 >> 2];
    HEAP32[$31 >> 2] = $12;
    var $34 = HEAP32[$2 >> 2];
    _js_PushStatement($34, $stmtInfo, 6, -1);
    var $35 = __ZN2js6Parser9statementEv($this);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = HEAP32[$2 >> 2];
    __ZL12PopStatementP13JSTreeContext($38);
    var $39 = $11 + 4 | 0;
    var $42 = $35 + 12 | 0;
    var $43 = $11 + 12 | 0;
    var $44$0 = HEAP32[$42 >> 2];
    var $44$1 = HEAP32[$42 + 4 >> 2];
    var $st$11$0 = $43 | 0;
    HEAP32[$st$11$0 >> 2] = $44$0;
    var $st$11$1 = $43 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $44$1;
    var $45 = $11 + 36 | 0;
    HEAP32[$45 >> 2] = $35;
    var $47 = HEAP32[$2 >> 2] | 0;
    var $49 = HEAP32[$47 >> 2] | 256;
    HEAP32[$47 >> 2] = $49;
    var $51 = HEAP32[$2 >> 2] + 88 | 0;
    HEAP32[$51 >> 2] = $32;
    var $53 = HEAP32[$2 >> 2] + 64 | 0;
    var $54 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($53);
    __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv($r, $54);
    var $55 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($55) {
      var $_0 = $12;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv($1, $r);
    var $56 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv($1);
    var $57 = HEAP32[$56 >> 2];
    var $58 = __ZN12JSDefinition7resolveEv($57);
    var $_idx_val = HEAP32[$58 + 28 >> 2];
    __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($_idx_val, $39);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv($r);
    var $59 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv($r);
    if ($59) {
      var $_0 = $12;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13withStatementEv["X"] = 1;

function __ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE($dn_0_0_6_val, $pos) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($dn_0_0_6_val | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = $pos | 0;
    var $3 = $pos + 8 | 0;
    var $pnu_03 = $dn_0_0_6_val;
    __label__ = 3;
    break;
   case 3:
    var $pnu_03;
    var $6 = __ZN2js8TokenPtrgeERKS0_($pnu_03 + 4 | 0, $2);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZN2js8TokenPtrleERKS0_($pnu_03 + 12 | 0, $3);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $pnu_03 + 44 | 0;
    var $14 = HEAP32[$12 >> 2] | 1024;
    HEAP32[$12 >> 2] = $14;
    __label__ = 6;
    break;
   case 6:
    var $pnu_0 = HEAP32[$pnu_03 + 28 >> 2];
    if (($pnu_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $pnu_03 = $pnu_0;
      __label__ = 3;
      break;
    }
   case 7:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12letStatementEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($2 | 0) == 27) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZN2js6Parser8letBlockEi($this, 1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode4isOpE4JSOp($5, 202);
    if ($8) {
      var $_0 = $5;
      __label__ = 20;
      break;
    } else {
      var $pn_0 = $5;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = $this + 980 | 0;
    var $11 = HEAPU32[$10 >> 2];
    var $13 = HEAPU32[$11 + 24 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAPU16[$13 >> 1];
    if ($17 << 16 >> 16 == 6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((($17 & 65535) - 4 | 0) >>> 0 < 7) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = $13 + 2 | 0;
    var $25 = HEAPU16[$24 >> 1];
    if (($25 & 4) << 16 >> 16 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 223, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 20;
    break;
   case 9:
    if (($25 & 1) << 16 >> 16 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 10:
    if (($25 & 2) << 16 >> 16 == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp($1, 46, 129);
    var $35 = __ZN2js6Parser9variablesEb($this, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = $35 + 44 | 0;
    var $41 = HEAP32[$39 >> 2] | 4;
    HEAP32[$39 >> 2] = $41;
    var $pn_0 = $35;
    __label__ = 19;
    break;
   case 13:
    var $47 = HEAP32[HEAP32[$11 + 48 >> 2] + 12 >> 2];
    var $48 = __Z17js_NewBlockObjectP9JSContext($47);
    var $49 = $48;
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $54 = HEAP32[HEAP32[$10 >> 2] + 48 >> 2];
    var $55 = __ZN2js6Parser12newObjectBoxEP8JSObject($54, $49);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $59 = HEAP16[$24 >> 1] | 1;
    HEAP16[$24 >> 1] = $59;
    var $62 = HEAP32[HEAP32[$10 >> 2] + 28 >> 2];
    HEAP32[$13 + 28 >> 2] = $62;
    var $65 = HEAP32[$10 >> 2] + 28 | 0;
    HEAP32[$65 >> 2] = $13;
    var $67 = HEAP32[$10 >> 2];
    var $68 = __ZN13JSTreeContext10blockChainEv($67);
    __ZN8JSObject9setParentEPS_($49, $68);
    var $71 = HEAP32[HEAP32[$10 >> 2] + 32 >> 2];
    var $72 = $55 + 12 | 0;
    HEAP32[$72 >> 2] = $71;
    var $74 = HEAP32[$10 >> 2] + 32 | 0;
    HEAP32[$74 >> 2] = $55;
    var $_c = $55;
    HEAP32[$13 + 20 >> 2] = $_c;
    var $76 = HEAP32[$10 >> 2];
    var $77 = __ZN2js16LexicalScopeNode6createEP13JSTreeContext($76);
    var $78 = $77 | 0;
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($78, 80);
    __ZN11JSParseNode5setOpE4JSOp($78, 202);
    var $86 = $77 + 4 | 0;
    var $87 = HEAP32[HEAP32[$10 >> 2] + 36 >> 2] + 4 | 0;
    HEAP32[$86 >> 2] = HEAP32[$87 >> 2];
    HEAP32[$86 + 4 >> 2] = HEAP32[$87 + 4 >> 2];
    HEAP32[$86 + 8 >> 2] = HEAP32[$87 + 8 >> 2];
    HEAP32[$86 + 12 >> 2] = HEAP32[$87 + 12 >> 2];
    var $88 = $77 + 32 | 0;
    var $_c1 = $55;
    HEAP32[$88 >> 2] = $_c1;
    var $92 = $77 + 36 | 0;
    var $_c2 = HEAP32[HEAP32[$10 >> 2] + 36 >> 2];
    HEAP32[$92 >> 2] = $_c2;
    var $101 = $77 + 44 | 0;
    var $104 = HEAP32[$101 >> 2] & 4095 | HEAP32[HEAP32[HEAP32[$10 >> 2] + 36 >> 2] + 44 >> 2] & -4096;
    HEAP32[$101 >> 2] = $104;
    var $106 = HEAP32[$10 >> 2] + 36 | 0;
    HEAP32[$106 >> 2] = $78;
    __label__ = 17;
    break;
   case 17:
    var $108 = __ZN2js6Parser9variablesEb($this, 0);
    if (($108 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $112 = $108 + 44 | 0;
    var $115 = HEAP32[$112 >> 2] & -4096 | 4;
    HEAP32[$112 >> 2] = $115;
    var $pn_0 = $108;
    __label__ = 19;
    break;
   case 19:
    var $pn_0;
    var $117 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($1);
    var $119 = ($117 | 0) != 0 ? $pn_0 : 0;
    var $_0 = $119;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12letStatementEv["X"] = 1;

function __ZN2js16LexicalScopeNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(6, $tc);
  return $1;
}

function __ZN2js6Parser19expressionStatementEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $1 = $this + 40 | 0;
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $2 = __ZN2js6Parser4exprEv($this);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($5 | 0) == 6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 3:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($2, 29);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 125, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 5:
    var $14 = HEAP32[$2 + 32 >> 2];
    var $15 = $this + 980 | 0;
    var $stmt_0_in = HEAP32[$15 >> 2] + 24 | 0;
    __label__ = 6;
    break;
   case 6:
    var $stmt_0_in;
    var $stmt_0 = HEAP32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (HEAP16[$stmt_0 >> 1] << 16 >> 16 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[$stmt_0 + 20 >> 2] | 0) == ($14 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $29 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 126, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 28;
    break;
   case 10:
    var $stmt_0_in = $stmt_0 + 24 | 0;
    __label__ = 6;
    break;
   case 11:
    __ZL9ForgetUseP11JSParseNode($2);
    var $33 = __ZN2js11TokenStream8getTokenEv($1);
    var $35 = HEAP32[$15 >> 2];
    var $36 = $stmtInfo;
    _js_PushStatement($35, $36, 0, -1);
    HEAP32[$stmtInfo + 20 >> 2] = $14;
    var $38 = __ZN2js6Parser9statementEv($this);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 2);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    if ((HEAP32[$38 + 32 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($38, 25);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($38, 5);
    __ZN11JSParseNode9makeEmptyEv($38);
    __label__ = 15;
    break;
   case 15:
    var $48 = HEAP32[$15 >> 2];
    __ZL12PopStatementP13JSTreeContext($48);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($2, 6);
    var $51 = $38 + 12 | 0;
    var $52 = $2 + 12 | 0;
    var $53$0 = HEAP32[$51 >> 2];
    var $53$1 = HEAP32[$51 + 4 >> 2];
    HEAP32[$52 >> 2] = $53$0;
    HEAP32[$52 + 4 >> 2] = $53$1;
    HEAP32[$2 + 36 >> 2] = $38;
    var $_0 = $2;
    __label__ = 28;
    break;
   case 16:
    var $56 = $this + 980 | 0;
    var $57 = HEAP32[$56 >> 2];
    var $58 = __ZN2js9UnaryNode6createEP13JSTreeContext($57);
    var $59 = $58 | 0;
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($59, 2);
    var $64 = $58 + 4 | 0;
    var $65 = $2 + 4 | 0;
    HEAP32[$64 >> 2] = HEAP32[$65 >> 2];
    HEAP32[$64 + 4 >> 2] = HEAP32[$65 + 4 >> 2];
    HEAP32[$64 + 8 >> 2] = HEAP32[$65 + 8 >> 2];
    HEAP32[$64 + 12 >> 2] = HEAP32[$65 + 12 >> 2];
    var $66 = $58 + 32 | 0;
    HEAP32[$66 >> 2] = $2;
    var $67 = __ZNK11JSParseNode7getKindEv($2);
    if (($67 | 0) == 27) {
      __label__ = 18;
      break;
    } else if (($67 | 0) == 4) {
      __label__ = 21;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = HEAP32[$2 + 32 >> 2];
    var $71 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($70, 34);
    if ($71) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    var $75 = HEAP32[$70 + 32 >> 2];
    var $77 = HEAP32[$75 + 24 >> 2];
    var $78 = __ZNK11JSParseNode8isFunArgEv($77);
    if ($78) {
      __label__ = 27;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $80 = $75 + 60 | 0;
    var $82 = HEAP32[$80 >> 2] | 2097152;
    HEAP32[$80 >> 2] = $82;
    __label__ = 27;
    break;
   case 21:
    var $86 = HEAP32[HEAP32[$56 >> 2] + 80 >> 2];
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $89 = __ZNK11JSParseNode4isOpE4JSOp($2, 0);
    if ($89) {
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 23:
    var $92 = HEAP32[$2 + 32 >> 2];
    var $93 = __ZNK11JSParseNode4isOpE4JSOp($92, 54);
    if ($93) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $97 = HEAP32[$92 + 36 >> 2];
    var $98 = __ZNK11JSParseNode4isOpE4JSOp($97, 65);
    if ($98) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $100 = $2 + 36 | 0;
    var $101 = HEAP32[$100 >> 2];
    var $102 = $101;
    var $103 = __ZNK11JSParseNode4isOpE4JSOp($102, 130);
    if ($103) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $106 = HEAP32[$86 + 40 >> 2];
    var $107 = $101 + 28 | 0;
    HEAP32[$107 >> 2] = $106;
    var $109 = HEAP32[$100 >> 2];
    var $113 = HEAP32[HEAP32[$56 >> 2] + 80 >> 2] + 40 | 0;
    HEAP32[$113 >> 2] = $109;
    __label__ = 27;
    break;
   case 27:
    var $115 = __ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE($1);
    var $117 = ($115 | 0) != 0 ? $59 : 0;
    var $_0 = $117;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser19expressionStatementEv["X"] = 1;

function __ZL9ForgetUseP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6lexdefEv($pn);
    var $4 = $3 + 28 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $4;
      __label__ = 4;
      break;
    } else {
      var $7 = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $7;
    var $8 = $7 + 28 | 0;
    var $9 = HEAP32[$8 >> 2];
    if (($9 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $7 = $9;
      __label__ = 3;
      break;
    }
   case 4:
    var $pnup_0_lcssa;
    var $12 = HEAP32[$pn + 28 >> 2];
    HEAP32[$pnup_0_lcssa >> 2] = $12;
    __ZN11JSParseNode7setUsedEb($pn, 0);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NullaryNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(0, $tc);
  return $1;
}

function __ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode($ts, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekTokenSameLineEj($ts, 8);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == -1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      var $label_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js11TokenStream8getTokenEv($ts);
    var $4 = __ZNK2js11TokenStream12currentTokenEv($ts);
    var $label_0 = HEAP32[$4 + 28 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $label_0;
    HEAP32[$pn + 32 >> 2] = $label_0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext($cx, $data, $atom, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $mdl = __stackBase__ + 4;
    var $name = __stackBase__ + 12;
    var $name1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $atom;
    var $4 = HEAP32[$data >> 2];
    __ZN11JSParseNode5setOpE4JSOp($4, 59);
    var $5 = __Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode($cx, $tc, $atom, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_2 = 0;
      __label__ = 49;
      break;
    }
   case 2:
    var $7 = $tc;
    var $8 = _js_LexicalLookup($7, $atom, 0, 0);
    var $9 = $8;
    var $10 = ($8 | 0) != 0;
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (HEAP16[$8 >> 1] << 16 >> 16 == 6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP8[$data + 16 | 0] = 0;
    var $18 = $4 + 44 | 0;
    var $20 = HEAP32[$18 >> 2] | 1024;
    HEAP32[$18 >> 2] = $20;
    __ZN13JSTreeContext20noteMightAliasLocalsEv($tc);
    var $_2 = 1;
    __label__ = 49;
    break;
   case 5:
    var $22 = $tc + 40 | 0;
    __ZN2js9AtomDecls11lookupMultiEP6JSAtom($mdl, $22, $atom);
    var $23 = $data + 4 | 0;
    var $24 = HEAP32[$23 >> 2];
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($26) {
      __label__ = 25;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($28) {
      var $47 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __ZN2js14MultiDeclRange5frontEv($mdl);
    if (($30 | 0) == 0) {
      var $47 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZN12JSDefinition4kindEv($30);
    if (($33 | 0) == 4) {
      __label__ = 10;
      break;
    } else {
      var $47 = $33;
      __label__ = 14;
      break;
    }
   case 10:
    __ZN16JSAutoByteStringC1Ev($name);
    var $36 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name);
    if (($36 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $39 = ($24 | 0) == 128;
    var $42 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $43 = __ZNK16JSAutoByteString3ptrEv($name);
    if ($39) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $44 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $42, $4, 0, 164, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $43, tempInt));
    __ZN16JSAutoByteStringD1Ev($name);
    var $_2 = 0;
    __label__ = 49;
    break;
   case 13:
    var $46 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $42, $4, 5, 127, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $43, tempInt));
    __ZN16JSAutoByteStringD1Ev($name);
    if ($46) {
      __label__ = 25;
      break;
    } else {
      var $_2 = 0;
      __label__ = 49;
      break;
    }
   case 14:
    var $47;
    if (($24 | 0) == 128 | ($47 | 0) == 1) {
      var $59 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($47 | 0) == 2) {
      __label__ = 16;
      break;
    } else {
      var $59 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    if (HEAP16[$8 >> 1] << 16 >> 16 == 7) {
      __label__ = 17;
      break;
    } else {
      var $59 = 1;
      __label__ = 18;
      break;
    }
   case 17:
    var $57 = __ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom($tc, $9, $atom);
    var $59 = $57;
    __label__ = 18;
    break;
   case 18:
    var $59;
    var $60 = __ZNK9JSContext15hasStrictOptionEv($cx);
    if ($60) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    if (($24 | 0) == 129 & ($47 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    if ($59) {
      __label__ = 21;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 21:
    __ZN16JSAutoByteStringC1Ev($name1);
    var $66 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $name1);
    if (($66 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $71 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $72 = $59 ? 0 : 5;
    var $73 = __ZN12JSDefinition10kindStringENS_4KindE($47);
    var $74 = __ZNK16JSAutoByteString3ptrEv($name1);
    var $75 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $71, $4, $72, 155, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $73, HEAP32[tempInt + 4 >> 2] = $74, tempInt));
    if ($75) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN16JSAutoByteStringD1Ev($name1);
    var $_2 = 0;
    __label__ = 49;
    break;
   case 24:
    __ZN16JSAutoByteStringD1Ev($name1);
    __label__ = 25;
    break;
   case 25:
    var $78 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($78) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $80 = __ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb($4, $atom, $tc, 0);
    if ($80) {
      var $pn_2 = $4;
      __label__ = 43;
      break;
    } else {
      var $_2 = 0;
      __label__ = 49;
      break;
    }
   case 27:
    var $82 = __ZN2js14MultiDeclRange5frontEv($mdl);
    HEAP8[$data + 16 | 0] = 0;
    var $84 = __ZNK11JSParseNode6isUsedEv($4);
    if ($84) {
      var $dn3_0 = $82;
      __label__ = 31;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $86 = __ZNK11JSParseNode6isDefnEv($4);
    if ($86) {
      __label__ = 29;
      break;
    } else {
      var $pnu_0 = $4;
      __label__ = 30;
      break;
    }
   case 29:
    var $88 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($atom, $tc);
    var $89 = $88 | 0;
    if (($88 | 0) == 0) {
      var $_2 = 0;
      __label__ = 49;
      break;
    } else {
      var $pnu_0 = $89;
      __label__ = 30;
      break;
    }
   case 30:
    var $pnu_0;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($pnu_0, $82);
    __ZN11JSParseNode5setOpE4JSOp($pnu_0, 59);
    var $dn3_0 = $82;
    __label__ = 31;
    break;
   case 31:
    var $dn3_0;
    var $92 = __ZN12JSDefinition4kindEv($dn3_0);
    if (($92 | 0) == 2) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    __ZN2js14MultiDeclRange8popFrontEv($mdl);
    var $95 = __ZNK2js14MultiDeclRange5emptyEv($mdl);
    if ($95) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $97 = __ZN2js14MultiDeclRange5frontEv($mdl);
    var $dn3_0 = $97;
    __label__ = 31;
    break;
   case 34:
    if (($dn3_0 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      var $_2 = 1;
      __label__ = 49;
      break;
    }
   case 35:
    var $101 = __ZNK11JSParseNode6isDefnEv($4);
    if ($101) {
      var $pn_1 = $4;
      var $121 = $atom;
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $103 = $tc + 64 | 0;
    var $104 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($103);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($2, $104, $1);
    var $105 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($2);
    if (($105 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $108 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($103);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($108, $1);
    var $pn_0 = $4;
    var $_pre = HEAP32[$1 >> 2];
    __label__ = 40;
    break;
   case 38:
    var $110 = HEAP32[$1 >> 2];
    var $111 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($110, $tc);
    var $112 = $111 | 0;
    if (($111 | 0) == 0) {
      var $_2 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($112, 29);
    var $117 = $111 + 4 | 0;
    var $118 = $4 + 4 | 0;
    HEAP32[$117 >> 2] = HEAP32[$118 >> 2];
    HEAP32[$117 + 4 >> 2] = HEAP32[$118 + 4 >> 2];
    HEAP32[$117 + 8 >> 2] = HEAP32[$118 + 8 >> 2];
    HEAP32[$117 + 12 >> 2] = HEAP32[$118 + 12 >> 2];
    var $pn_0 = $112;
    var $_pre = $110;
    __label__ = 40;
    break;
   case 40:
    var $_pre;
    var $pn_0;
    __ZN11JSParseNode5setOpE4JSOp($pn_0, 59);
    var $pn_1 = $pn_0;
    var $121 = $_pre;
    __label__ = 41;
    break;
   case 41:
    var $121;
    var $pn_1;
    var $122 = $22;
    var $124 = __ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition($122, $121, $pn_1);
    if ($124) {
      __label__ = 42;
      break;
    } else {
      var $_2 = 0;
      __label__ = 49;
      break;
    }
   case 42:
    __ZN11JSParseNode7setDefnEb($pn_1, 1);
    var $127 = $pn_1 + 44 | 0;
    var $129 = HEAP32[$127 >> 2] & -129;
    HEAP32[$127 >> 2] = $129;
    var $pn_2 = $pn_1;
    __label__ = 43;
    break;
   case 43:
    var $pn_2;
    if ((HEAP32[$23 >> 2] | 0) == 128) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $135 = $pn_2 + 44 | 0;
    var $137 = HEAP32[$135 >> 2] | 2;
    HEAP32[$135 >> 2] = $137;
    __label__ = 45;
    break;
   case 45:
    var $139 = __ZNK13JSTreeContext10inFunctionEv($7);
    if ($139) {
      __label__ = 46;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 46:
    var $141 = __ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext($cx, $data, $tc);
    var $_2 = $141 & 1;
    __label__ = 49;
    break;
   case 47:
    var $144 = __ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($pn_2, $tc);
    var $_2 = $144 & 1;
    __label__ = 49;
    break;
   case 48:
    __ZN16JSAutoByteStringD1Ev($name);
    var $_2 = 0;
    __label__ = 49;
    break;
   case 49:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext["X"] = 1;

function __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($left, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($left, 24);
    var $3 = HEAP32[$left + 32 >> 2];
    var $4 = ($3 | 0) == 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ($4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $end;
    var $pn_04 = $3;
    __label__ = 6;
    break;
   case 4:
    if ($4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $6 = $end;
    var $pair_01 = $3;
    __label__ = 13;
    break;
   case 6:
    var $pn_04;
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 3);
    if ($8) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $10 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_04, 0);
    if ($10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $12 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 24);
    if ($12) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $14 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_04, 26);
    if ($14) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($pn_04, $end);
    __label__ = 12;
    break;
   case 11:
    var $18 = $pn_04 + 12 | 0;
    var $st$2$0 = $5 | 0;
    var $19$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $5 + 4 | 0;
    var $19$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $18 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $18 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    __label__ = 12;
    break;
   case 12:
    var $22 = HEAP32[$pn_04 + 24 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $pn_04 = $22;
      __label__ = 6;
      break;
    }
   case 13:
    var $pair_01;
    var $26 = HEAP32[$pair_01 + 36 >> 2];
    var $27 = $26;
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($27, 24);
    if ($28) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $30 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($27, 26);
    if ($30) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext($27, $end);
    __label__ = 17;
    break;
   case 16:
    var $34 = $26 + 12 | 0;
    var $st$2$0 = $6 | 0;
    var $35$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $6 + 4 | 0;
    var $35$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $34 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    var $st$6$1 = $34 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $35$1;
    __label__ = 17;
    break;
   case 17:
    var $38 = HEAP32[$pair_01 + 24 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $pair_01 = $38;
      __label__ = 13;
      break;
    }
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext["X"] = 1;

function __ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext($pn, $rhs, $tc_0_11_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17NewOrRecycledNodeP13JSTreeContext($tc_0_11_val);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = $pn | 0;
    for (var $$src = $5 >> 2, $$dest = $4 >> 2, $$stop = $$src + 12; $$src < $$stop; $$src++, $$dest++) {
      HEAP32[$$dest] = HEAP32[$$src];
    }
    var $6 = __ZNK11JSParseNode6isUsedEv($pn);
    var $7 = $pn + 36 | 0;
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$7 >> 2] + 28 | 0;
    var $11 = HEAP32[$10 >> 2];
    if (($11 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $10;
      __label__ = 5;
      break;
    } else {
      var $13 = $11;
      __label__ = 4;
      break;
    }
   case 4:
    var $13;
    var $14 = $13 + 28 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == ($pn | 0)) {
      var $pnup_0_lcssa = $14;
      __label__ = 5;
      break;
    } else {
      var $13 = $15;
      __label__ = 4;
      break;
    }
   case 5:
    var $pnup_0_lcssa;
    HEAP32[$pnup_0_lcssa >> 2] = $1;
    var $17 = $pn + 28 | 0;
    var $18 = HEAP32[$17 >> 2];
    HEAP32[$1 + 28 >> 2] = $18;
    HEAP32[$17 >> 2] = 0;
    var $_pre_phi = $7;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 4);
    __ZN11JSParseNode5setOpE4JSOp($pn, 0);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 2);
    __ZN11JSParseNode11setInParensEb($pn, 0);
    __ZN11JSParseNode7setUsedEb($pn, 0);
    __ZN11JSParseNode7setDefnEb($pn, 0);
    HEAP32[$pn + 32 >> 2] = $1;
    HEAP32[$_pre_phi >> 2] = $rhs;
    var $_0 = $1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($this, $pn);
    var $1 = $this | 0;
    var $3 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $3;
    var $5 = HEAP32[$this + 80 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$5 + 24 >> 2] + 44 | 0;
    var $13 = HEAP32[$11 >> 2] | 256;
    HEAP32[$11 >> 2] = $13;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9mulExpr1nEv($this) {
  var $1 = __ZN2js6Parser9mulExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9mulExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9unaryExprEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js11TokenStream8getTokenEv($2);
    if (($7 - 17 | 0) >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $10 = HEAP32[$8 >> 2];
    var $12 = HEAP32[$8 + 24 >> 2];
    var $13 = __ZN2js6Parser9unaryExprEv($this);
    var $14 = HEAP32[$3 >> 2];
    var $15 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($10, $12, $pn_0, $13, $14);
    var $pn_0 = $15;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9addExpr1nEv($this) {
  var $1 = __ZN2js6Parser9addExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9addExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9mulExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_($2, 15, 16);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 >> 2];
    var $13 = ($11 | 0) == 15 ? 27 : 28;
    var $14 = __ZN2js6Parser9mulExpr1nEv($this);
    var $15 = HEAP32[$3 >> 2];
    var $16 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($11, $13, $pn_0, $14, $15);
    var $pn_0 = $16;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11shiftExpr1nEv($this) {
  var $1 = __ZN2js6Parser11shiftExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser11shiftExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9addExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 14);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 + 24 >> 2];
    var $12 = __ZN2js6Parser9addExpr1nEv($this);
    var $13 = HEAP32[$3 >> 2];
    var $14 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(14, $11, $pn_0, $12, $13);
    var $pn_0 = $14;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9relExpr1nEv($this) {
  var $1 = __ZN2js6Parser9relExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser9relExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 980 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    var $4 = HEAP32[$3 >> 2];
    var $5 = $4 & 16;
    var $6 = $4 & -17;
    HEAP32[$3 >> 2] = $6;
    var $7 = __ZN2js6Parser11shiftExpr1iEv($this);
    var $8 = $this + 40 | 0;
    var $9 = ($5 | 0) == 0;
    var $pn_0 = $7;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 13);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 45);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($8, 57);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = __ZNK2js11TokenStream12currentTokenEv($8);
    var $21 = HEAP32[$19 >> 2];
    var $23 = HEAP32[$19 + 24 >> 2];
    var $24 = __ZN2js6Parser11shiftExpr1nEv($this);
    var $25 = HEAP32[$1 >> 2];
    var $26 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext($21, $23, $pn_0, $24, $25);
    var $pn_0 = $26;
    __label__ = 2;
    break;
   case 8:
    var $28 = HEAP32[$1 >> 2] | 0;
    var $30 = HEAP32[$28 >> 2] | $5;
    HEAP32[$28 >> 2] = $30;
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser8eqExpr1nEv($this) {
  var $1 = __ZN2js6Parser8eqExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser8eqExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9relExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 12);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2js11TokenStream12currentTokenEv($2);
    var $11 = HEAP32[$9 + 24 >> 2];
    var $12 = __ZN2js6Parser9relExpr1nEv($this);
    var $13 = HEAP32[$3 >> 2];
    var $14 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(12, $11, $pn_0, $12, $13);
    var $pn_0 = $14;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12bitAndExpr1nEv($this) {
  var $1 = __ZN2js6Parser12bitAndExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser12bitAndExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser8eqExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 11);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser8eqExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(11, 17, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12bitXorExpr1nEv($this) {
  var $1 = __ZN2js6Parser12bitXorExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser12bitXorExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser12bitAndExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 10);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser12bitAndExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(10, 16, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11bitOrExpr1nEv($this) {
  var $1 = __ZN2js6Parser11bitOrExpr1iEv($this);
  return $1;
}

function __ZN2js6Parser11bitOrExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser12bitXorExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 9);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser12bitXorExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(9, 15, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9andExpr1nEv($this) {
  var $1 = __ZN2js6Parser9andExpr1iEv($this);
  return $1;
}

function __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($this, $pn) {
  var $1 = $this + 20 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 56 >> 2] = $pn;
  return;
}

function __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($this, $pos) {
  return (HEAP32[$this + 140 >> 2] | 0) == (HEAP32[$pos + 12 >> 2] | 0);
}

function __ZN11GenexpGuard7endBodyEv($this) {
  var $3 = HEAP32[$this >> 2] + 12 | 0;
  var $5 = HEAP32[$3 >> 2] - 1 | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js6Parser9andExpr1iEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser11bitOrExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 8);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser11bitOrExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(8, 69, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, $msg) {
  var __stackBase__ = STACKTOP;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc + 48 | 0;
    var $3 = HEAP32[$1 >> 2] + 40 | 0;
    var $4 = $tc;
    var $5 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $3, $4, $pn, $msg, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $8 = HEAP32[$pn + 32 >> 2];
    var $9 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 34);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[HEAP32[$8 + 32 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = HEAP32[$1 >> 2] + 40 | 0;
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $20, $pn, 0, $msg, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $24 = $pn + 44 | 0;
    var $26 = HEAP32[$24 >> 2] | 256;
    HEAP32[$24 >> 2] = $26;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser9condExpr1Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser7orExpr1Ev($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($4, 5);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 9;
      break;
    }
   case 3:
    var $7 = $this + 980 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = __ZN2js11TernaryNode6createEP13JSTreeContext($8);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$7 >> 2] | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $15 & -17;
    HEAP32[$14 >> 2] = $16;
    var $17 = __ZN2js6Parser10assignExprEv($this);
    var $19 = HEAP32[$7 >> 2] | 0;
    var $22 = HEAP32[$19 >> 2] & 629442528 | $15;
    HEAP32[$19 >> 2] = $22;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZN2js11TokenStream8getTokenEj($4, 0);
    if (($25 | 0) == 6) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 103, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 7:
    var $30 = __ZN2js6Parser10assignExprEv($this);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $1 + 4 | 0;
    var $36 = $9 + 4 | 0;
    var $37$0 = HEAP32[$35 >> 2];
    var $37$1 = HEAP32[$35 + 4 >> 2];
    var $st$8$0 = $36 | 0;
    HEAP32[$st$8$0 >> 2] = $37$0;
    var $st$8$1 = $36 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $37$1;
    var $40 = $30 + 12 | 0;
    var $41 = $9 + 12 | 0;
    var $42$0 = HEAP32[$40 >> 2];
    var $42$1 = HEAP32[$40 + 4 >> 2];
    var $st$20$0 = $41 | 0;
    HEAP32[$st$20$0 >> 2] = $42$0;
    var $st$20$1 = $41 + 4 | 0;
    HEAP32[$st$20$1 >> 2] = $42$1;
    var $43 = $9 + 32 | 0;
    HEAP32[$43 >> 2] = $1;
    var $44 = $9 + 36 | 0;
    HEAP32[$44 >> 2] = $17;
    var $45 = $9 + 40 | 0;
    HEAP32[$45 >> 2] = $30;
    var $46 = __ZN2js11TokenStream8getTokenEv($4);
    var $_0 = $10;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9condExpr1Ev["X"] = 1;

function __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($this, $type) {
  var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
  return (HEAP32[$1 >> 2] | 0) == ($type | 0);
}

function __ZNK11JSParseNode10isAssignedEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 8);
  return $1;
}

function __ZN2js6Parser9unaryExprEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 29;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 19 || ($10 | 0) == 15 || ($10 | 0) == 16) {
      __label__ = 4;
      break;
    } else if (($10 | 0) == 20 || ($10 | 0) == 21) {
      __label__ = 7;
      break;
    } else if (($10 | 0) == 50) {
      __label__ = 11;
      break;
    } else if (($10 | 0) == -1) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 4:
    var $13 = HEAP32[$this + 980 >> 2];
    var $14 = __ZN2js9UnaryNode6createEP13JSTreeContext($13);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($15, 19);
    var $18 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $20 = HEAP32[$18 + 24 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($15, $20);
    var $21 = __ZN2js6Parser9unaryExprEv($this);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = $21 + 12 | 0;
    var $27 = $14 + 12 | 0;
    var $st$4$0 = $26 | 0;
    var $28$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $26 + 4 | 0;
    var $28$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $27 | 0;
    HEAP32[$st$8$0 >> 2] = $28$0;
    var $st$8$1 = $27 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $28$1;
    var $29 = $14 + 32 | 0;
    HEAP32[$29 >> 2] = $21;
    var $_0 = $15;
    __label__ = 29;
    break;
   case 7:
    var $31 = $this + 980 | 0;
    var $32 = HEAP32[$31 >> 2];
    var $33 = __ZN2js9UnaryNode6createEP13JSTreeContext($32);
    var $34 = $33 | 0;
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = __ZN2js6Parser10memberExprEi($this, 1);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = HEAP32[$2 >> 2];
    var $41 = HEAP32[$31 >> 2];
    var $42 = __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($40, $9, $41, $34, $37, $10, 1);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = $37 + 12 | 0;
    var $48 = $33 + 12 | 0;
    var $st$4$0 = $47 | 0;
    var $49$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $47 + 4 | 0;
    var $49$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $48 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $48 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $_0 = $34;
    __label__ = 29;
    break;
   case 11:
    var $51 = $this + 980 | 0;
    var $52 = HEAP32[$51 >> 2];
    var $53 = __ZN2js9UnaryNode6createEP13JSTreeContext($52);
    var $54 = $53 | 0;
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $57 = __ZN2js6Parser9unaryExprEv($this);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $62 = $57 + 12 | 0;
    var $63 = $53 + 12 | 0;
    var $st$4$0 = $62 | 0;
    var $64$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $62 + 4 | 0;
    var $64$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $63 | 0;
    HEAP32[$st$8$0 >> 2] = $64$0;
    var $st$8$1 = $63 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $64$1;
    if ((HEAP8[$this + 988 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $70 = HEAP32[$2 >> 2];
    var $71 = HEAP32[$51 >> 2];
    var $72 = _js_FoldConstants($70, $57, $71, 0);
    if (($72 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $75 = __ZNK11JSParseNode7getKindEv($57);
    if (($75 | 0) == 27) {
      __label__ = 16;
      break;
    } else if (($75 | 0) == 29) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 16:
    var $78 = $57 + 44 | 0;
    if ((HEAP32[$78 >> 2] & 256 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 17:
    var $83 = HEAP32[$2 >> 2];
    var $84 = HEAP32[$51 >> 2];
    var $85 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($83, $57, $84, 220);
    if ($85) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 18:
    var $88 = HEAP32[$78 >> 2] & -257;
    HEAP32[$78 >> 2] = $88;
    __label__ = 22;
    break;
   case 19:
    var $90 = HEAP32[$2 >> 2];
    var $92 = HEAP32[$51 >> 2];
    var $93 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($90, $9, $92, $54, 235, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($93) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 20:
    __ZN11JSParseNode5setOpE4JSOp($57, 36);
    if ((HEAP32[$57 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $107 = HEAP32[$51 >> 2] | 0;
    var $109 = HEAP32[$107 >> 2] | 256;
    HEAP32[$107 >> 2] = $109;
    var $110 = HEAP32[$51 >> 2];
    __ZN13JSTreeContext17countArgumentsUseEP11JSParseNode($110, $57);
    __label__ = 22;
    break;
   case 22:
    var $112 = $53 + 32 | 0;
    HEAP32[$112 >> 2] = $57;
    var $_0 = $54;
    __label__ = 29;
    break;
   case 23:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $114 = __ZN2js6Parser10memberExprEi($this, 1);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $117 = $114 + 4 | 0;
    var $118 = __ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE($9, $117);
    if ($118) {
      __label__ = 25;
      break;
    } else {
      var $_0 = $114;
      __label__ = 29;
      break;
    }
   case 25:
    var $120 = __ZN2js11TokenStream17peekTokenSameLineEj($9, 8);
    if (($120 - 20 | 0) >>> 0 < 2) {
      __label__ = 26;
      break;
    } else {
      var $_0 = $114;
      __label__ = 29;
      break;
    }
   case 26:
    var $123 = __ZN2js11TokenStream8getTokenEv($9);
    var $124 = $this + 980 | 0;
    var $125 = HEAP32[$124 >> 2];
    var $126 = __ZN2js9UnaryNode6createEP13JSTreeContext($125);
    var $127 = $126 | 0;
    if (($126 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $130 = HEAP32[$2 >> 2];
    var $131 = HEAP32[$124 >> 2];
    var $132 = __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($130, $9, $131, $127, $114, $120, 0);
    if (($132 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $136 = $117;
    var $137 = $126 + 4 | 0;
    var $138$0 = HEAP32[$136 >> 2];
    var $138$1 = HEAP32[$136 + 4 >> 2];
    var $st$7$0 = $137 | 0;
    HEAP32[$st$7$0 >> 2] = $138$0;
    var $st$7$1 = $137 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $138$1;
    var $_0 = $127;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser9unaryExprEv["X"] = 1;

function __ZN2js6Parser10memberExprEi($this, $allowCallSyntax) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__ + 4;
    var $index = __stackBase__ + 36;
    var $2 = $this + 12 | 0;
    var $3 = HEAPU32[$2 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 69;
    break;
   case 3:
    var $9 = $this + 40 | 0;
    var $10 = __ZN2js11TokenStream8getTokenEj($9, 8);
    if (($10 | 0) == 49) {
      __label__ = 4;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 4:
    var $13 = $this + 980 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = __ZN2js8ListNode6createEP13JSTreeContext($14);
    var $16 = $15 | 0;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js6Parser10memberExprEi($this, 0);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($19);
    __ZN11JSParseNode5setOpE4JSOp($16, 82);
    __ZN11JSParseNode8initListEPS_($16, $22);
    var $25 = $22 + 4 | 0;
    var $26 = $15 + 4 | 0;
    var $27$0 = HEAP32[$25 >> 2];
    var $27$1 = HEAP32[$25 + 4 >> 2];
    var $st$11$0 = $26 | 0;
    HEAP32[$st$11$0 >> 2] = $27$0;
    var $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $27$1;
    var $28 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($9, 27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = __ZN2js6Parser12argumentListEP11JSParseNode($this, $16);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if (HEAPU32[$15 + 40 >> 2] >>> 0 > 65536) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $37 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($37, 2, 0, 44, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 10:
    var $39 = $15 + 12 | 0;
    var $40 = __ZNK11JSParseNode4lastEv($16);
    var $42 = $40 + 12 | 0;
    var $43 = $39;
    var $st$5$0 = $42 | 0;
    var $44$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $42 + 4 | 0;
    var $44$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $43 | 0;
    HEAP32[$st$9$0 >> 2] = $44$0;
    var $st$9$1 = $43 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $44$1;
    var $pn_0_ph = $16;
    var $_pre_phi = $13;
    __label__ = 18;
    break;
   case 11:
    var $46 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $10, 0);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $49 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 72);
    if ($49) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $51 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 70);
    if ($51) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $53 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($46, 71);
    if ($53) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $pn_0_ph = $46;
    var $_pre_phi = $this + 980 | 0;
    __label__ = 18;
    break;
   case 16:
    var $55 = $this + 980 | 0;
    var $_idx_val = HEAP32[HEAP32[$55 >> 2] + 48 >> 2];
    var $57 = __ZL17NewOrRecycledNodeP13JSTreeContext($_idx_val);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($57, 19);
    var $62 = $57 + 4 | 0;
    var $63 = $46 + 4 | 0;
    HEAP32[$62 >> 2] = HEAP32[$63 >> 2];
    HEAP32[$62 + 4 >> 2] = HEAP32[$63 + 4 >> 2];
    HEAP32[$62 + 8 >> 2] = HEAP32[$63 + 8 >> 2];
    HEAP32[$62 + 12 >> 2] = HEAP32[$63 + 12 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($57, 174);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($57, 1);
    __ZN11JSParseNode11setInParensEb($57, 0);
    var $64 = $57 + 32 | 0;
    HEAP32[$64 >> 2] = $46;
    var $pn_0_ph = $57;
    var $_pre_phi = $55;
    __label__ = 18;
    break;
   case 18:
    var $_pre_phi;
    var $pn_0_ph;
    var $65 = ($allowCallSyntax | 0) != 0;
    var $pn_0 = $pn_0_ph;
    __label__ = 19;
    break;
   case 19:
    var $pn_0;
    var $66 = __ZN2js11TokenStream8getTokenEv($9);
    if (($66 | 0) > 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 20:
    if (($66 | 0) == 22) {
      __label__ = 21;
      break;
    } else if (($66 | 0) == 73) {
      __label__ = 35;
      break;
    } else if (($66 | 0) == 23) {
      __label__ = 43;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 21:
    var $70 = HEAP32[$_pre_phi >> 2];
    var $71 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext(0, $70);
    var $72 = $71 | 0;
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $75 = __ZN2js11TokenStream8getTokenEj($9, 40);
    var $77 = HEAP32[$_pre_phi >> 2] + 88 | 0;
    var $78 = HEAP32[$77 >> 2];
    var $79 = ($75 | 0) == 27;
    if ($79) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP32[$77 >> 2] = $pn_0;
    var $82 = HEAP32[$_pre_phi >> 2];
    _js_PushStatement($82, $stmtInfo, 6, -1);
    __label__ = 24;
    break;
   case 24:
    var $84 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $75, 1);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if ($79) {
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    if (($75 | 0) == 29) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $90 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($84, 29);
    if ($90) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    __ZN11JSParseNode5setOpE4JSOp($72, 53);
    var $92 = $71 + 36 | 0;
    HEAP32[$92 >> 2] = $pn_0;
    var $96 = $71 + 32 | 0;
    var $_c5 = HEAP32[$84 + 32 >> 2];
    HEAP32[$96 >> 2] = $_c5;
    var $97 = HEAP32[$_pre_phi >> 2];
    var $98 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($84, $97);
    __label__ = 34;
    break;
   case 29:
    var $101 = HEAP32[$_pre_phi >> 2] + 88 | 0;
    HEAP32[$101 >> 2] = $78;
    var $102 = HEAP32[$_pre_phi >> 2];
    __ZL12PopStatementP13JSTreeContext($102);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 74);
    __ZN11JSParseNode5setOpE4JSOp($72, 176);
    var $104 = HEAP32[$_pre_phi >> 2] | 0;
    var $106 = HEAP32[$104 >> 2] | 256;
    HEAP32[$104 >> 2] = $106;
    __label__ = 33;
    break;
   case 30:
    var $107 = __ZNK11JSParseNode7getKindEv($84);
    var $108 = __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($107);
    if ($108) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($72, 23);
    __ZN11JSParseNode5setOpE4JSOp($72, 55);
    __label__ = 33;
    break;
   case 32:
    var $111 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 77, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 33:
    __ZN11JSParseNode8setArityE16JSParseNodeArity($72, 2);
    var $113 = $71 + 32 | 0;
    HEAP32[$113 >> 2] = $pn_0;
    var $114 = $71 + 36 | 0;
    HEAP32[$114 >> 2] = $84;
    __label__ = 34;
    break;
   case 34:
    var $118 = $pn_0 + 4 | 0;
    var $119 = $71 + 4 | 0;
    var $st$4$0 = $118 | 0;
    var $120$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $118 + 4 | 0;
    var $120$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $119 | 0;
    HEAP32[$st$8$0 >> 2] = $120$0;
    var $st$8$1 = $119 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $120$1;
    var $121 = $71 + 12 | 0;
    var $122 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $124 = $122 + 12 | 0;
    var $125 = $121;
    var $st$17$0 = $124 | 0;
    var $126$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $124 + 4 | 0;
    var $126$1 = HEAP32[$st$17$1 >> 2];
    var $st$21$0 = $125 | 0;
    HEAP32[$st$21$0 >> 2] = $126$0;
    var $st$21$1 = $125 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $126$1;
    var $pn_0 = $72;
    __label__ = 19;
    break;
   case 35:
    var $128 = HEAP32[$_pre_phi >> 2];
    var $129 = __ZN2js10BinaryNode6createEP13JSTreeContext($128);
    var $130 = $129 | 0;
    if (($129 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $133 = __ZN2js11TokenStream8getTokenEj($9, 40);
    var $134 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $133, 1);
    if (($134 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $137 = __ZNK11JSParseNode7getKindEv($134);
    if (($137 | 0) == 29) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $140 = __ZNK11JSParseNode10isInParensEv($134);
    if ($140) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($134, 31);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($134, 0);
    __ZN11JSParseNode5setOpE4JSOp($134, 165);
    __label__ = 42;
    break;
   case 40:
    var $143 = __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($137);
    if ($143) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $145 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 77, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 42:
    __ZN11JSParseNode5setOpE4JSOp($130, 175);
    var $147 = $129 + 32 | 0;
    HEAP32[$147 >> 2] = $pn_0;
    var $148 = $129 + 36 | 0;
    HEAP32[$148 >> 2] = $134;
    var $151 = $pn_0 + 4 | 0;
    var $152 = $129 + 4 | 0;
    var $153$0 = HEAP32[$151 >> 2];
    var $153$1 = HEAP32[$151 + 4 >> 2];
    var $st$14$0 = $152 | 0;
    HEAP32[$st$14$0 >> 2] = $153$0;
    var $st$14$1 = $152 + 4 | 0;
    HEAP32[$st$14$1 >> 2] = $153$1;
    var $154 = $129 + 12 | 0;
    var $155 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $157 = $155 + 12 | 0;
    var $158 = $154;
    var $159$0 = HEAP32[$157 >> 2];
    var $159$1 = HEAP32[$157 + 4 >> 2];
    var $st$27$0 = $158 | 0;
    HEAP32[$st$27$0 >> 2] = $159$0;
    var $st$27$1 = $158 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $159$1;
    var $pn_0 = $130;
    __label__ = 19;
    break;
   case 43:
    var $161 = HEAP32[$_pre_phi >> 2];
    var $162 = __ZN2js10BinaryNode6createEP13JSTreeContext($161);
    var $163 = $162 | 0;
    if (($162 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $166 = __ZN2js6Parser4exprEv($this);
    if (($166 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    var $169 = __ZN2js11TokenStream8getTokenEj($9, 0);
    if (($169 | 0) == 24) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $172 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 78, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 47:
    var $176 = $pn_0 + 4 | 0;
    var $177 = $162 + 4 | 0;
    var $st$4$0 = $176 | 0;
    var $178$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $176 + 4 | 0;
    var $178$1 = HEAP32[$st$4$1 >> 2];
    var $st$8$0 = $177 | 0;
    HEAP32[$st$8$0 >> 2] = $178$0;
    var $st$8$1 = $177 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $178$1;
    var $179 = $162 + 12 | 0;
    var $180 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $182 = $180 + 12 | 0;
    var $183 = $179;
    var $st$17$0 = $182 | 0;
    var $184$0 = HEAP32[$st$17$0 >> 2];
    var $st$17$1 = $182 + 4 | 0;
    var $184$1 = HEAP32[$st$17$1 >> 2];
    var $st$21$0 = $183 | 0;
    HEAP32[$st$21$0 >> 2] = $184$0;
    var $st$21$1 = $183 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $184$1;
    var $185 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($166, 31);
    if ($185) {
      __label__ = 48;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 48:
    var $187 = $166 + 32 | 0;
    var $188 = $187;
    var $189 = HEAP32[$188 >> 2];
    var $190 = __ZL12ATOM_TO_JSIDP6JSAtom2903($189);
    var $191 = __Z12js_IdIsIndexiPj($190, $index);
    if (($191 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($163, 22);
    __ZN11JSParseNode5setOpE4JSOp($163, 53);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($163, 6);
    var $194 = $162 + 36 | 0;
    HEAP32[$194 >> 2] = $pn_0;
    var $196 = $162 + 32 | 0;
    var $_c1 = HEAP32[$188 >> 2];
    HEAP32[$196 >> 2] = $_c1;
    var $pn_0 = $163;
    __label__ = 19;
    break;
   case 50:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($166, 30);
    __ZN11JSParseNode5setOpE4JSOp($166, 60);
    var $200 = $187;
    tempDoubleF64[0] = HEAPU32[$index >> 2] >>> 0, HEAP32[$200 >> 2] = tempDoubleI32[0], HEAP32[$200 + 4 >> 2] = tempDoubleI32[1];
    __label__ = 51;
    break;
   case 51:
    __ZN11JSParseNode5setOpE4JSOp($163, 55);
    var $202 = $162 + 32 | 0;
    HEAP32[$202 >> 2] = $pn_0;
    var $203 = $162 + 36 | 0;
    HEAP32[$203 >> 2] = $166;
    var $pn_0 = $163;
    __label__ = 19;
    break;
   case 52:
    if ($65 & ($66 | 0) == 27) {
      __label__ = 53;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 53:
    var $207 = HEAP32[$_pre_phi >> 2];
    var $208 = __ZN2js8ListNode6createEP13JSTreeContext($207);
    var $209 = $208 | 0;
    if (($208 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    __ZN11JSParseNode5setOpE4JSOp($209, 58);
    var $212 = __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($pn_0);
    var $213 = __ZNK11JSParseNode4isOpE4JSOp($212, 59);
    if ($213) {
      __label__ = 55;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 55:
    if ((HEAP32[$212 + 32 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$2 >> 2] + 52 >> 2] + 210212 >> 2] | 0)) {
      __label__ = 56;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 56:
    __ZN11JSParseNode5setOpE4JSOp($209, 123);
    var $226 = HEAP32[$_pre_phi >> 2];
    __ZN13JSTreeContext13noteCallsEvalEv($226);
    var $228 = HEAP32[$_pre_phi >> 2] | 0;
    var $230 = HEAP32[$228 >> 2] | 256;
    HEAP32[$228 >> 2] = $230;
    var $231 = HEAP32[$_pre_phi >> 2];
    var $232 = $231;
    var $233 = __ZNK13JSTreeContext12inStrictModeEv($232);
    if ($233) {
      __label__ = 63;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    __ZN13JSTreeContext22noteHasExtensibleScopeEv($231);
    __label__ = 63;
    break;
   case 58:
    var $236 = __ZNK11JSParseNode4isOpE4JSOp($212, 53);
    if ($236) {
      __label__ = 59;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 59:
    var $240 = HEAP32[$212 + 32 >> 2];
    var $243 = HEAP32[HEAP32[$2 >> 2] + 52 >> 2];
    if (($240 | 0) == (HEAP32[$243 + 210172 >> 2] | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    __ZN11JSParseNode5setOpE4JSOp($209, 79);
    __label__ = 63;
    break;
   case 61:
    if (($240 | 0) == (HEAP32[$243 + 210188 >> 2] | 0)) {
      __label__ = 62;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 62:
    __ZN11JSParseNode5setOpE4JSOp($209, 108);
    __label__ = 63;
    break;
   case 63:
    __ZN11JSParseNode8initListEPS_($209, $212);
    var $258 = $212 + 4 | 0;
    var $259 = $208 + 4 | 0;
    var $st$5$0 = $258 | 0;
    var $260$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $258 + 4 | 0;
    var $260$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $259 | 0;
    HEAP32[$st$9$0 >> 2] = $260$0;
    var $st$9$1 = $259 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $260$1;
    var $261 = __ZN2js6Parser12argumentListEP11JSParseNode($this, $209);
    if (($261 | 0) == 0) {
      var $_0 = 0;
      __label__ = 69;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if (HEAPU32[$208 + 40 >> 2] >>> 0 > 65536) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $268 = HEAP32[$2 >> 2];
    _JS_ReportErrorNumber($268, 2, 0, 45, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 69;
    break;
   case 66:
    var $270 = $208 + 12 | 0;
    var $271 = __ZNK2js11TokenStream12currentTokenEv($9);
    var $273 = $271 + 12 | 0;
    var $274 = $270;
    var $st$5$0 = $273 | 0;
    var $275$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $273 + 4 | 0;
    var $275$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $274 | 0;
    HEAP32[$st$9$0 >> 2] = $275$0;
    var $st$9$1 = $274 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $275$1;
    var $pn_0 = $209;
    __label__ = 19;
    break;
   case 67:
    __ZN2js11TokenStream10ungetTokenEv($9);
    var $_0 = $pn_0;
    __label__ = 69;
    break;
   case 68:
    var $_pn_0 = ($66 | 0) == -1 ? 0 : $pn_0;
    var $_0 = $_pn_0;
    __label__ = 69;
    break;
   case 69:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser10memberExprEi["X"] = 1;

function __ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi($cx, $ts, $tc, $pn, $kid, $tt, $preorder) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = STRING_TABLE.__ZL14incop_name_str + (($tt | 0) == 21 & 1) * 10 | 0;
    var $4 = __ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc($cx, $ts, $tc, $pn, $kid, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode7getKindEv($4);
    if (($7 | 0) == 29) {
      __label__ = 3;
      break;
    } else if (($7 | 0) == 22) {
      __label__ = 7;
      break;
    } else if (($7 | 0) == 27) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == 19) {
      __label__ = 11;
      break;
    } else if (($7 | 0) == 23) {
      __label__ = 13;
      break;
    } else {
      var $op_0 = 0;
      __label__ = 16;
      break;
    }
   case 3:
    var $10 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $10 ? 41 : 47;
    var $16 = $12;
    __label__ = 6;
    break;
   case 5:
    var $14 = $10 ? 44 : 50;
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $4, $tc, 8);
    var $op_0 = $16;
    __label__ = 16;
    break;
   case 7:
    var $19 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = $19 ? 42 : 48;
    var $op_0 = $21;
    __label__ = 16;
    break;
   case 9:
    var $23 = $19 ? 45 : 51;
    var $op_0 = $23;
    __label__ = 16;
    break;
   case 10:
    var $25 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $4, $tc, 221);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 11:
    var $27 = __ZNK11JSParseNode4isOpE4JSOp($4, 174);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN11JSParseNode5setOpE4JSOp($4, 173);
    __label__ = 13;
    break;
   case 13:
    var $31 = ($preorder | 0) != 0;
    if (($tt | 0) == 20) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $33 = $31 ? 43 : 49;
    var $op_0 = $33;
    __label__ = 16;
    break;
   case 15:
    var $35 = $31 ? 46 : 52;
    var $op_0 = $35;
    __label__ = 16;
    break;
   case 16:
    var $op_0;
    __ZN11JSParseNode5setOpE4JSOp($pn, $op_0);
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $adjust, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn + 44 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $5 = ($3 >>> 12) + $adjust | 0;
    HEAP32[$2 >> 2] = $5 << 12 | $3 & 4095;
    var $9 = $5 & 1048575;
    var $10 = $tc + 8 | 0;
    if ($9 >>> 0 < HEAPU32[$10 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$10 >> 2] = $9 + 1 | 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (HEAPU32[$2 + 16 >> 2] >>> 0 > HEAPU32[$this + 4 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$2 + 52 >> 2];
    var $errorNode_0 = ($10 | 0) == 0 ? $pn : $10;
    var $13 = HEAP32[$2 + 48 >> 2];
    var $14 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($13, $errorNode_0, 0, 271, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    if (HEAPU32[$2 + 20 >> 2] >>> 0 > HEAPU32[$this + 8 >> 2] >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = HEAP32[$2 + 56 >> 2];
    var $errorNode1_0 = ($23 | 0) == 0 ? $pn : $23;
    var $26 = HEAP32[$2 + 48 >> 2];
    var $27 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($26, $errorNode1_0, 0, 271, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_arguments_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if ((HEAP32[$2 + 16 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $2 | 0;
    var $9 = HEAP32[$7 >> 2] | 512;
    HEAP32[$7 >> 2] = $9;
    var $10 = HEAP32[$1 >> 2];
    var $11 = $10;
    var $12 = __ZNK13JSTreeContext10inFunctionEv($11);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAP32[$10 + 48 >> 2];
    var $16 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($15, 0, 0, 124, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    if ((HEAP32[$10 >> 2] & 4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $26 = HEAP32[HEAP32[$10 + 48 >> 2] + 12 >> 2];
    var $27 = __ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj($26, $10, $pn, 0, 208, 209);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $pn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dn = __stackBase__;
    var $atom = __stackBase__ + 4;
    var $dn2 = __stackBase__ + 8;
    if (($pn | 0) == 0) {
      var $_0 = 1;
      __label__ = 49;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode8getArityEv($pn);
    if (($3 | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 3) {
      __label__ = 9;
      break;
    } else if (($3 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($3 | 0) == 1) {
      __label__ = 15;
      break;
    } else if (($3 | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($3 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($3 | 0) == 7) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 3:
    var $pn2_0_in = $pn + 32 | 0;
    __label__ = 4;
    break;
   case 4:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $pn2_0);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 6:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 4;
    break;
   case 7:
    var $13 = $pn + 4 | 0;
    var $16 = HEAP32[$this >> 2] + 4 | 0;
    var $17 = __ZN2js8TokenPosgeERKS0_($13, $16);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 8:
    var $20 = HEAP32[$this + 12 >> 2];
    var $22 = HEAP32[$this + 4 >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $20, $22);
    __label__ = 48;
    break;
   case 9:
    var $25 = HEAP32[$pn + 32 >> 2];
    var $26 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $25);
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 10:
    var $30 = HEAP32[$pn + 36 >> 2];
    var $31 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $30);
    if ($31) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 11:
    var $35 = HEAP32[$pn + 40 >> 2];
    var $36 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $35);
    if ($36) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 12:
    var $38 = $pn + 32 | 0;
    var $39 = HEAP32[$38 >> 2];
    var $40 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $39);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 13:
    var $44 = HEAP32[$pn + 36 >> 2];
    if (($44 | 0) == (HEAP32[$38 >> 2] | 0)) {
      __label__ = 48;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $48 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $44);
    if ($48) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 15:
    var $51 = HEAP32[$pn + 32 >> 2];
    var $52 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $51);
    if ($52) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 16:
    var $56 = HEAP32[$pn + 32 >> 2];
    var $57 = $this + 4 | 0;
    var $61 = $this + 16 | 0;
    var $65 = $56 + 56 | 0;
    var $70 = HEAP32[$61 >> 2] + HEAP32[HEAP32[$57 >> 2] + 76 >> 2] << 2 & 65532 | HEAP32[$65 >> 2] & -65533;
    HEAP32[$65 >> 2] = $70;
    var $71 = HEAP32[$61 >> 2];
    var $72 = $71 + 1 | 0;
    HEAP32[$61 >> 2] = $72;
    if (($71 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $80 = HEAP32[$57 >> 2];
    var $82 = HEAP32[$80 + 80 >> 2];
    var $85 = HEAP32[$80 + 72 >> 2] + 84 | 0;
    var $86 = HEAP32[$85 >> 2];
    if (($86 | 0) == ($56 | 0)) {
      var $funboxp_0_lcssa = $85;
      __label__ = 20;
      break;
    } else {
      var $88 = $86;
      __label__ = 19;
      break;
    }
   case 19:
    var $88;
    var $89 = $88 + 28 | 0;
    var $90 = HEAP32[$89 >> 2];
    if (($90 | 0) == ($56 | 0)) {
      var $funboxp_0_lcssa = $89;
      __label__ = 20;
      break;
    } else {
      var $88 = $90;
      __label__ = 19;
      break;
    }
   case 20:
    var $funboxp_0_lcssa;
    var $92 = $56 + 28 | 0;
    var $93 = HEAP32[$92 >> 2];
    HEAP32[$funboxp_0_lcssa >> 2] = $93;
    var $94 = $56 + 36 | 0;
    HEAP32[$94 >> 2] = $82;
    var $95 = $82 + 32 | 0;
    var $96 = HEAP32[$95 >> 2];
    HEAP32[$92 >> 2] = $96;
    HEAP32[$95 >> 2] = $56;
    var $104 = HEAP32[$65 >> 2] & -65533 | HEAP32[HEAP32[$57 >> 2] + 76 >> 2] << 2 & 65532;
    HEAP32[$65 >> 2] = $104;
    __label__ = 21;
    break;
   case 21:
    var $106 = __ZN11JSParseNode9maybeExprEv($pn);
    var $107 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $106);
    if ($107) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 22:
    var $109 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 4);
    if ($109) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $111 = $this + 16 | 0;
    var $113 = HEAP32[$111 >> 2] - 1 | 0;
    HEAP32[$111 >> 2] = $113;
    __label__ = 24;
    break;
   case 24:
    var $115 = __ZNK11JSParseNode6isDefnEv($pn);
    if ($115) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $123 = HEAP32[$this + 4 >> 2];
    var $124 = __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($pn, $123);
    if ($124) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 27:
    var $126 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($126) {
      __label__ = 28;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 28:
    var $128 = $pn + 32 | 0;
    var $130 = HEAP32[$pn + 36 >> 2];
    var $131 = $130;
    HEAP32[$dn >> 2] = $131;
    var $132 = $130;
    var $133 = __ZNK11JSParseNode13isPlaceholderEv($132);
    if ($133) {
      __label__ = 29;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 29:
    var $136 = $130 + 4 | 0;
    var $139 = HEAP32[$this >> 2] + 4 | 0;
    var $140 = __ZN2js8TokenPosgeERKS0_($136, $139);
    if ($140) {
      __label__ = 30;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 30:
    if ((HEAP32[$130 + 28 >> 2] | 0) == ($pn | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 31:
    var $_pre = $this + 4 | 0;
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      var $_pre_phi = $_pre;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $151 = HEAP32[$_pre >> 2];
    var $152 = __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($132, $151);
    if ($152) {
      var $_pre_phi = $_pre;
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 33:
    var $_pre_phi;
    var $153 = $130;
    var $155 = HEAP32[$this + 12 >> 2];
    var $156 = HEAP32[$_pre_phi >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($153, $155, $156);
    __label__ = 34;
    break;
   case 34:
    var $159 = HEAP32[$128 >> 2];
    HEAP32[$atom >> 2] = $159;
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $165 = $130;
    var $166 = __ZNK11JSParseNode4isOpE4JSOp($165, 131);
    if ($166) {
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $169 = $130 + 4 | 0;
    var $170 = $this | 0;
    var $172 = HEAP32[$170 >> 2] + 4 | 0;
    var $173 = __ZN2js8TokenPosltERKS0_($169, $172);
    if ($173) {
      __label__ = 37;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 37:
    var $175 = $this + 4 | 0;
    var $176 = HEAP32[$175 >> 2];
    var $177 = __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($pn, $176);
    HEAP32[$dn2 >> 2] = $177;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 49;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $183 = $177 + 4 | 0;
    var $184 = HEAP32[$170 >> 2] + 4 | 0;
    HEAP32[$183 >> 2] = HEAP32[$184 >> 2];
    HEAP32[$183 + 4 >> 2] = HEAP32[$184 + 4 >> 2];
    HEAP32[$183 + 8 >> 2] = HEAP32[$184 + 8 >> 2];
    HEAP32[$183 + 12 >> 2] = HEAP32[$184 + 12 >> 2];
    var $185 = $130 + 28 | 0;
    var $_c = $177;
    var $187 = $177 + 44 | 0;
    var $pnup_0 = $185;
    __label__ = 39;
    break;
   case 39:
    var $pnup_0;
    var $189 = HEAP32[$pnup_0 >> 2];
    if (($189 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $192 = $189 + 4 | 0;
    var $194 = HEAP32[$170 >> 2] + 4 | 0;
    var $195 = __ZN2js8TokenPosgeERKS0_($192, $194);
    if ($195) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $197 = $189 + 36 | 0;
    HEAP32[$197 >> 2] = $_c;
    var $203 = HEAP32[$187 >> 2] | HEAP32[$189 + 44 >> 2] & 2312;
    HEAP32[$187 >> 2] = $203;
    var $pnup_0 = $189 + 28 | 0;
    __label__ = 39;
    break;
   case 42:
    var $205 = HEAP32[$185 >> 2];
    var $206 = $177 + 28 | 0;
    HEAP32[$206 >> 2] = $205;
    var $207 = HEAP32[$pnup_0 >> 2];
    HEAP32[$185 >> 2] = $207;
    HEAP32[$pnup_0 >> 2] = 0;
    var $209 = HEAP32[$175 >> 2] + 64 | 0;
    var $210 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($209);
    var $211 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($210, $atom, $dn2);
    if ($211) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 43:
    var $213 = __ZNK11JSParseNode13isPlaceholderEv($165);
    if ($213) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $215 = $this + 4 | 0;
    var $219 = HEAP32[HEAP32[$215 >> 2] + 72 >> 2] + 64 | 0;
    var $220 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($219);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_($220, $atom);
    var $222 = HEAP32[$215 >> 2] + 64 | 0;
    var $223 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv($222);
    var $224 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($223, $atom, $dn);
    if ($224) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 45:
    var $225 = $pn + 4 | 0;
    var $228 = HEAP32[$this >> 2] + 4 | 0;
    var $229 = __ZN2js8TokenPosgeERKS0_($225, $228);
    if ($229) {
      __label__ = 46;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 46:
    var $232 = HEAP32[$this + 12 >> 2];
    var $234 = HEAP32[$this + 4 >> 2];
    __ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext($pn, $232, $234);
    __label__ = 48;
    break;
   case 47:
    var $238 = HEAP32[$pn + 36 >> 2];
    var $239 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($this, $238);
    if ($239) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 48:
    var $_0 = 1;
    __label__ = 49;
    break;
   case 49:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN20CompExprTransplanter10transplantEP11JSParseNode["X"] = 1;

function __ZN2js8TokenPosgeERKS0_($this, $bpos) {
  var $1 = __ZN2js8TokenPosltERKS0_($this, $bpos);
  return $1 ^ 1;
}

function __ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn + 40 | 0;
    var $3 = __ZNK2js11UpvarCookie6isFreeEv($2);
    if ($3) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2js11UpvarCookie5levelEv($2);
    var $7 = ($5 & 65535) + 1 | 0;
    if ($7 >>> 0 > 16382) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$tc + 48 >> 2] + 12 >> 2];
    _JS_ReportErrorNumber($13, 2, 0, 25, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_function_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $15 = $7 & 65535;
    var $16 = __ZNK2js11UpvarCookie4slotEv($2);
    __ZN2js11UpvarCookie3setEtt($2, $15, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode13isPlaceholderEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 128);
  return $1;
}

function __ZN2js8TokenPosltERKS0_($this, $bpos) {
  var $1 = $this | 0;
  var $2 = $bpos | 0;
  var $3 = __ZN2js8TokenPtrltERKS0_($1, $2);
  return $3;
}

function __ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$pn + 32 >> 2];
    var $4 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext($3, $tc);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    var $8 = $4 | 0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($8, 29);
    __ZN11JSParseNode5setOpE4JSOp($8, 0);
    __ZN11JSParseNode7setDefnEb($8, 1);
    var $10 = $4 + 44 | 0;
    var $12 = HEAP32[$10 >> 2] | 128;
    HEAP32[$10 >> 2] = $12;
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_($this, $key, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($p, $this, $key);
    var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($p);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$value >> 2];
    var $5 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($p);
    HEAP32[$5 >> 2] = $4;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($this, $p, $key, $value);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $kid, $blockid, $isGenexp, $type, $op) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmtInfo = __stackBase__;
    var $data = __stackBase__ + 32;
    var $transplanter = __stackBase__ + 52;
    var $guard = __stackBase__ + 72;
    __ZN8BindDataC1Ev($data);
    var $1 = ($type | 0) == 2;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 12 >> 2];
    var $6 = HEAP32[$this + 980 >> 2];
    var $7 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($4, $6, $stmtInfo);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $pn_0 = $7;
    var $adjust_0 = (HEAPU32[$7 + 44 >> 2] >>> 12) - $blockid | 0;
    __label__ = 6;
    break;
   case 4:
    var $17 = HEAPU32[$this + 980 >> 2];
    var $18 = $17;
    var $19 = __ZN13JSTreeContext7blockidEv($18);
    var $21 = HEAP32[$this + 12 >> 2];
    var $22 = __ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo($21, $17, $stmtInfo);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$stmtInfo + 4 >> 2] = $blockid;
    var $27 = $22 + 44 | 0;
    var $31 = HEAP32[$27 >> 2] & 4095 | $blockid << 12;
    HEAP32[$27 >> 2] = $31;
    var $pn_0 = $22;
    var $adjust_0 = $blockid - $19 | 0;
    __label__ = 6;
    break;
   case 6:
    var $adjust_0;
    var $pn_0;
    var $35 = $pn_0 + 36 | 0;
    var $36 = $this + 980 | 0;
    var $37 = HEAP32[$36 >> 2];
    __ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj($transplanter, $kid, $37, $1, $adjust_0);
    var $38 = __ZN20CompExprTransplanter10transplantEP11JSParseNode($transplanter, $kid);
    var $39 = $data | 0;
    HEAP32[$39 >> 2] = 0;
    HEAP32[$data + 4 >> 2] = 0;
    var $41 = $data + 8 | 0;
    HEAP32[$41 >> 2] = 208;
    HEAP32[$data + 12 >> 2] = 200;
    var $43 = $this + 40 | 0;
    var $44 = $this + 12 | 0;
    var $pnp_0 = $35;
    __label__ = 7;
    break;
   case 7:
    var $pnp_0;
    var $46 = HEAP32[$36 >> 2];
    var $47 = __ZN2js10BinaryNode6createEP13JSTreeContext($46);
    var $48 = $47 | 0;
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN11JSParseNode5setOpE4JSOp($48, 75);
    var $52 = $47 + 44 | 0;
    HEAP32[$52 >> 2] = 1;
    var $53 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 29);
    if ($53) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $55 = __ZNK2js11TokenStream12currentTokenEv($43);
    if ((HEAP32[$55 + 28 >> 2] | 0) == (HEAP32[HEAP32[HEAP32[$44 >> 2] + 52 >> 2] + 210208 >> 2] | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $67 = HEAP32[$52 >> 2] | 2;
    HEAP32[$52 >> 2] = $67;
    __label__ = 12;
    break;
   case 11:
    __ZN2js11TokenStream10ungetTokenEv($43);
    __label__ = 12;
    break;
   case 12:
    var $70 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($70 | 0) == 27) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $73 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 85, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 14:
    var $75 = HEAP32[$36 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $75);
    var $76 = __ZN2js11TokenStream8getTokenEv($43);
    if (($76 | 0) == 23 || ($76 | 0) == 25) {
      __label__ = 15;
      break;
    } else if (($76 | 0) == 29) {
      __label__ = 16;
      break;
    } else if (($76 | 0) == -1) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $79 = HEAP32[$36 >> 2] | 0;
    var $81 = HEAP32[$79 >> 2] | 65536;
    HEAP32[$79 >> 2] = $81;
    var $82 = __ZN2js6Parser11primaryExprENS_9TokenKindEi($this, $76, 0);
    var $84 = HEAP32[$36 >> 2] | 0;
    var $86 = HEAP32[$84 >> 2] & -65537;
    HEAP32[$84 >> 2] = $86;
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $atom_0 = 0;
      var $pn3_0 = $82;
      __label__ = 18;
      break;
    }
   case 16:
    var $89 = __ZNK2js11TokenStream12currentTokenEv($43);
    var $91 = HEAP32[$89 + 28 >> 2];
    var $92 = HEAP32[$36 >> 2];
    var $93 = __ZL14NewBindingNodeP6JSAtomP13JSTreeContextb($91, $92, 1);
    if (($93 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      var $atom_0 = $91;
      var $pn3_0 = $93;
      __label__ = 18;
      break;
    }
   case 17:
    var $96 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 102, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 18:
    var $pn3_0;
    var $atom_0;
    var $98 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($98 | 0) == 45) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $101 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 211, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 20:
    var $103 = __ZN2js6Parser4exprEv($this);
    if (($103 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $106 = __ZN2js11TokenStream8getTokenEj($43, 0);
    if (($106 | 0) == 28) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $109 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 88, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 23:
    __ZN11GenexpGuard7endBodyEv($guard);
    if ($isGenexp) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $112 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard, $48);
    if ($112) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 25:
    var $114 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $48);
    if ($114) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 26:
    if (($76 | 0) == 23 || ($76 | 0) == 25) {
      __label__ = 27;
      break;
    } else if (($76 | 0) == 29) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 27:
    var $117 = HEAP32[$44 >> 2];
    var $118 = HEAP32[$36 >> 2];
    var $119 = __ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($117, $data, $pn3_0, $118);
    if ($119) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 45;
      break;
    }
   case 28:
    var $121 = __ZNK2js6Parser13versionNumberEv($this);
    if (($121 | 0) == 170) {
      __label__ = 29;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $124 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn3_0, 24);
    if ($124) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    if ((HEAP32[$pn3_0 + 40 >> 2] | 0) == 2) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $130 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 117, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 45;
    break;
   case 32:
    var $132 = HEAP32[$52 >> 2];
    if (($132 & 2 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $136 = $132 | 6;
    HEAP32[$52 >> 2] = $136;
    __label__ = 35;
    break;
   case 34:
    HEAP32[$39 >> 2] = $pn3_0;
    var $138 = HEAP32[$41 >> 2];
    var $139 = HEAP32[$44 >> 2];
    var $140 = HEAP32[$36 >> 2];
    var $141 = FUNCTION_TABLE[$138]($139, $data, $atom_0, $140);
    if (($141 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $144 = HEAP32[$36 >> 2];
    var $145 = __ZN2js8ListNode6createEP13JSTreeContext($144);
    var $146 = $145 | 0;
    if (($145 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN11JSParseNode5setOpE4JSOp($146, 0);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($146, 46);
    var $151 = $145 + 4 | 0;
    var $152 = $pn3_0 + 4 | 0;
    HEAP32[$151 >> 2] = HEAP32[$152 >> 2];
    HEAP32[$151 + 4 >> 2] = HEAP32[$152 + 4 >> 2];
    HEAP32[$151 + 8 >> 2] = HEAP32[$152 + 8 >> 2];
    HEAP32[$151 + 12 >> 2] = HEAP32[$152 + 12 >> 2];
    __ZN11JSParseNode9makeEmptyEv($146);
    __ZN11JSParseNode6appendEPS_($146, $pn3_0);
    var $154 = $145 + 44 | 0;
    var $156 = HEAP32[$154 >> 2] | 8;
    HEAP32[$154 >> 2] = $156;
    var $157 = HEAP32[$36 >> 2];
    var $158 = __ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext($pn3_0, $157);
    if (($158 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $161 = HEAP32[$36 >> 2];
    var $162 = __ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext(45, 0, $146, $158, $103, $161);
    var $163 = $162 | 0;
    var $164 = $47 + 32 | 0;
    HEAP32[$164 >> 2] = $163;
    if (($162 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP32[$pnp_0 >> 2] = $48;
    var $167 = $47 + 36 | 0;
    var $168 = $167;
    var $169 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 42);
    if ($169) {
      var $pnp_0 = $168;
      __label__ = 7;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $171 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($43, 35);
    if ($171) {
      __label__ = 40;
      break;
    } else {
      var $pnp_1 = $168;
      __label__ = 43;
      break;
    }
   case 40:
    var $173 = HEAP32[$36 >> 2];
    var $174 = __ZN2js11TernaryNode6createEP13JSTreeContext($173);
    if (($174 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $177 = __ZN2js6Parser9conditionEv($this);
    var $178 = $174 + 32 | 0;
    HEAP32[$178 >> 2] = $177;
    if (($177 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $_c = $174;
    HEAP32[$167 >> 2] = $_c;
    var $pnp_1 = $174 + 36 | 0;
    __label__ = 43;
    break;
   case 43:
    var $pnp_1;
    var $184 = HEAP32[$36 >> 2];
    var $185 = __ZN2js9UnaryNode6createEP13JSTreeContext($184);
    var $186 = $185 | 0;
    if (($185 | 0) == 0) {
      var $_0 = 0;
      __label__ = 45;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($186, $type);
    __ZN11JSParseNode5setOpE4JSOp($186, $op);
    var $189 = $185 + 32 | 0;
    HEAP32[$189 >> 2] = $kid;
    HEAP32[$pnp_1 >> 2] = $186;
    var $190 = HEAP32[$36 >> 2];
    __ZL12PopStatementP13JSTreeContext($190);
    var $_0 = $pn_0;
    __label__ = 45;
    break;
   case 45:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp["X"] = 1;

function __ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj) {
  __ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj);
  return;
}

function __ZN11GenexpGuardC1EP13JSTreeContext($this, $tc) {
  __ZN11GenexpGuardC2EP13JSTreeContext($this, $tc);
  return;
}

function __ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext($type, $op, $kid1, $kid2, $kid3, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pos = __stackBase__;
    var $2 = ($kid1 | 0) != 0 ? $kid1 : $kid2;
    var $4 = $2 + 4 | 0;
    var $5 = $pos;
    var $6$0 = HEAP32[$4 >> 2];
    var $6$1 = HEAP32[$4 + 4 >> 2];
    HEAP32[$5 >> 2] = $6$0;
    HEAP32[$5 + 4 >> 2] = $6$1;
    var $9 = $kid3 + 12 | 0;
    var $10 = $pos + 8 | 0;
    var $11$0 = HEAP32[$9 >> 2];
    var $11$1 = HEAP32[$9 + 4 >> 2];
    HEAP32[$10 >> 2] = $11$0;
    HEAP32[$10 + 4 >> 2] = $11$1;
    var $12 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext(3, $type, $op, $pos, $tc);
    var $13 = $12;
    if (($12 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$12 + 32 >> 2] = $kid1;
    HEAP32[$12 + 36 >> 2] = $kid2;
    HEAP32[$12 + 40 >> 2] = $kid3;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14TokenKindIsXMLENS_9TokenKindE($tt) {
  return ($tt - 70 | 0) >>> 0 < 3;
}

function __ZN11JSParseNode11setInParensEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & -536870913 | ($enabled & 1) << 29;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2js11TokenStream12isXMLTagModeEv($this) {
  return (HEAP32[$this + 144 >> 2] & 512 | 0) != 0;
}

function __ZN2js6Parser13generatorExprEP11JSParseNode($this, $kid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $gentc = __stackBase__;
    var $1 = $this + 980 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($4, 77);
    __ZN11JSParseNode5setOpE4JSOp($4, 206);
    __ZN11JSParseNode11setInParensEb($4, 1);
    var $8 = $kid + 4 | 0;
    var $9 = $3 + 4 | 0;
    var $10 = $8;
    HEAP32[$9 >> 2] = HEAP32[$10 >> 2];
    HEAP32[$9 + 4 >> 2] = HEAP32[$10 + 4 >> 2];
    HEAP32[$9 + 8 >> 2] = HEAP32[$10 + 8 >> 2];
    HEAP32[$9 + 12 >> 2] = HEAP32[$10 + 12 >> 2];
    var $11 = $3 + 32 | 0;
    HEAP32[$11 >> 2] = $kid;
    var $12 = $3 + 40 | 0;
    HEAP32[$12 >> 2] = 1;
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZN2js12FunctionNode6createEP13JSTreeContext($13);
    var $15 = $14 | 0;
    if (($14 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($15, 34);
    __ZN11JSParseNode5setOpE4JSOp($15, 130);
    var $19 = $14 + 44 | 0;
    var $22 = HEAP32[$19 >> 2] & -4096 | 256;
    HEAP32[$19 >> 2] = $22;
    var $23 = HEAP32[$1 >> 2];
    var $25 = HEAP32[$23 + 48 >> 2];
    __ZN13JSTreeContextC1EPN2js6ParserE($gentc, $25);
    var $27 = HEAP32[$this + 12 >> 2];
    var $28 = $gentc;
    var $29 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($28, $27, 0);
    if ($29) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $31 = __ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($15, $gentc, 0, 0);
    if (($31 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $34 = $23 | 0;
    var $35 = HEAP32[$34 >> 2];
    var $_pre2 = $gentc | 0;
    if (($35 & 32768 | 0) == 0) {
      var $42 = $35;
      var $_pre_phi = $_pre2;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $40 = HEAP32[$_pre2 >> 2] | 2;
    HEAP32[$_pre2 >> 2] = $40;
    var $41 = __ZN13JSTreeContext16ensureSharpSlotsEv($28);
    if ($41) {
      __label__ = 7;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 7:
    var $42 = HEAP32[$34 >> 2];
    var $_pre_phi = $_pre2;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $42;
    var $46 = HEAP32[$_pre_phi >> 2] | $42 & 629441952 | 4608;
    HEAP32[$_pre_phi >> 2] = $46;
    var $47 = $31 + 60 | 0;
    var $49 = $46 | HEAP32[$47 >> 2];
    HEAP32[$47 >> 2] = $49;
    var $50 = $14 + 32 | 0;
    var $_c = $31;
    HEAP32[$50 >> 2] = $_c;
    var $56 = HEAP32[$19 >> 2] & 4095 | HEAP32[$gentc + 4 >> 2] << 12;
    HEAP32[$19 >> 2] = $56;
    var $57 = $23;
    var $58 = __ZN13JSTreeContext7blockidEv($57);
    var $59 = __ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp($this, $4, $58, 1, 2, 0);
    if (($59 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $62 = $14 + 36 | 0;
    var $_c2 = $59;
    HEAP32[$62 >> 2] = $_c2;
    var $63 = $14 + 4 | 0;
    var $65 = $8;
    var $66 = $59 + 4 | 0;
    var $67$0 = HEAP32[$65 >> 2];
    var $67$1 = HEAP32[$65 + 4 >> 2];
    var $st$11$0 = $66 | 0;
    HEAP32[$st$11$0 >> 2] = $67$0;
    var $st$11$1 = $66 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $67$1;
    var $68 = $63;
    var $st$16$0 = $68 | 0;
    HEAP32[$st$16$0 >> 2] = $67$0;
    var $st$16$1 = $68 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $67$1;
    var $69 = $14 + 12 | 0;
    var $70 = $59 + 12 | 0;
    var $71 = $this + 40 | 0;
    var $72 = __ZNK2js11TokenStream12currentTokenEv($71);
    var $74 = $72 + 12 | 0;
    var $75 = $70;
    var $76$0 = HEAP32[$74 >> 2];
    var $76$1 = HEAP32[$74 + 4 >> 2];
    var $st$31$0 = $75 | 0;
    HEAP32[$st$31$0 >> 2] = $76$0;
    var $st$31$1 = $75 + 4 | 0;
    HEAP32[$st$31$1 >> 2] = $76$1;
    var $77 = $69;
    var $st$36$0 = $77 | 0;
    HEAP32[$st$36$0 >> 2] = $76$0;
    var $st$36$1 = $77 + 4 | 0;
    HEAP32[$st$36$1 >> 2] = $76$1;
    var $78 = __ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE($15, $gentc, 0, 0);
    __ZN13JSTreeContextD1Ev($gentc);
    if ($78) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $80 = HEAP32[$1 >> 2];
    var $81 = __ZN2js8ListNode6createEP13JSTreeContext($80);
    var $82 = $81 | 0;
    if (($81 | 0) == 0) {
      var $_1 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($82, 27);
    __ZN11JSParseNode5setOpE4JSOp($82, 58);
    var $87 = $14 + 4 | 0;
    var $88 = $81 + 4 | 0;
    var $89$0 = HEAP32[$87 >> 2];
    var $89$1 = HEAP32[$87 + 4 >> 2];
    var $st$10$0 = $88 | 0;
    HEAP32[$st$10$0 >> 2] = $89$0;
    var $st$10$1 = $88 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $89$1;
    __ZN11JSParseNode8initListEPS_($82, $15);
    var $_1 = $82;
    __label__ = 16;
    break;
   case 12:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 13:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 14:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 15:
    __ZN13JSTreeContextD1Ev($gentc);
    var $_1 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13generatorExprEP11JSParseNode["X"] = 1;

function __ZN2js6Parser12argumentListEP11JSParseNode($this, $listNode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $guard = __stackBase__;
    var $1 = $this + 40 | 0;
    var $2 = __ZN2js11TokenStream10matchTokenENS_9TokenKindEj($1, 28, 8);
    if ($2) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 980 >> 2];
    __ZN11GenexpGuardC1EP13JSTreeContext($guard, $5);
    var $6 = $listNode + 40 | 0;
    var $arg0_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $arg0_0;
    var $8 = __ZN2js6Parser10assignExprEv($this);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($arg0_0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN11GenexpGuard7endBodyEv($guard);
    __label__ = 6;
    break;
   case 6:
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 77);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $15 = __ZNK11JSParseNode10isInParensEv($8);
    if ($15) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($17 | 0) == 3) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $8, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_yield_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 10:
    var $22 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 42);
    if ($22) {
      __label__ = 11;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 11:
    var $24 = __ZN11GenexpGuard14checkValidBodyEP11JSParseNode($guard, $8);
    if ($24) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 12:
    var $26 = __ZN2js6Parser13generatorExprEP11JSParseNode($this, $8);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (HEAPU32[$6 >> 2] >>> 0 > 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $32 = __ZN2js11TokenStream9peekTokenEv($1);
    if (($32 | 0) == 3) {
      __label__ = 15;
      break;
    } else {
      var $argNode_0 = $26;
      __label__ = 18;
      break;
    }
   case 15:
    var $35 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $26, 0, 215, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str2323384 | 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 16:
    if ($arg0_0) {
      __label__ = 17;
      break;
    } else {
      var $argNode_0 = $8;
      __label__ = 18;
      break;
    }
   case 17:
    var $38 = __ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode($guard, $8);
    if ($38) {
      var $argNode_0 = $8;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $argNode_0;
    __ZN11JSParseNode6appendEPS_($listNode, $argNode_0);
    var $40 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($1, 3);
    if ($40) {
      var $arg0_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $42 = __ZN2js11TokenStream8getTokenEv($1);
    if (($42 | 0) == 28) {
      var $_0 = 1;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $45 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 104, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser12argumentListEP11JSParseNode["X"] = 1;

function __ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 34);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    if ((HEAP32[HEAP32[$pn + 32 >> 2] + 60 >> 2] & 1152 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = $pn + 44 | 0;
    var $14 = HEAP32[$12 >> 2] & -257;
    HEAP32[$12 >> 2] = $14;
    __label__ = 4;
    break;
   case 4:
    return $pn;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser13bracketedExprEv($this) {
  var $1 = $this + 980 | 0;
  var $3 = HEAP32[$1 >> 2] | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = $4 & -17;
  HEAP32[$3 >> 2] = $5;
  var $6 = __ZN2js6Parser4exprEv($this);
  var $8 = HEAP32[$1 >> 2] | 0;
  var $11 = HEAP32[$8 >> 2] & 629442528 | $4;
  HEAP32[$8 >> 2] = $11;
  return $6;
}

function __ZN2js6Parser16endBracketedExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser13bracketedExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream8getTokenEj($4, 0);
    if (($5 | 0) == 24) {
      var $_0 = $1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 174, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser16propertySelectorEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js11NullaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($4, 17);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($4, 72);
    __ZN11JSParseNode5setOpE4JSOp($4, 164);
    var $15 = $3 + 32 | 0;
    var $_c1 = HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210412 >> 2];
    HEAP32[$15 >> 2] = $_c1;
    var $_0 = $4;
    __label__ = 5;
    break;
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($4, 165);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($4, 6);
    var $17 = $this + 40 | 0;
    var $18 = __ZNK2js11TokenStream12currentTokenEv($17);
    var $21 = $3 + 32 | 0;
    var $_c = HEAP32[$18 + 28 >> 2];
    HEAP32[$21 >> 2] = $_c;
    var $23 = $3 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($23);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js8NameNode6createEP6JSAtomP13JSTreeContext(0, $2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($pn, 165);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN11JSParseNode5setOpE4JSOp($pn, 59);
    __label__ = 4;
    break;
   case 4:
    var $10 = $this + 40 | 0;
    var $11 = __ZN2js11TokenStream8getTokenEj($10, 32);
    var $12 = ($11 | 0) == 17;
    if (($11 | 0) == 29 || ($11 | 0) == 17) {
      __label__ = 5;
      break;
    } else if (($11 | 0) == 23) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($4, 166);
    var $16 = $pn + 4 | 0;
    var $17 = $3 + 4 | 0;
    var $18$0 = HEAP32[$16 >> 2];
    var $18$1 = HEAP32[$16 + 4 >> 2];
    var $st$9$0 = $17 | 0;
    HEAP32[$st$9$0 >> 2] = $18$0;
    var $st$9$1 = $17 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $18$1;
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = HEAP32[HEAP32[HEAP32[$this + 12 >> 2] + 52 >> 2] + 210412 >> 2] | 0;
    __label__ = 8;
    break;
   case 7:
    var $28 = __ZNK2js11TokenStream12currentTokenEv($10);
    var $32 = HEAP32[$28 + 28 >> 2];
    __label__ = 8;
    break;
   case 8:
    var $32;
    var $33 = $3 + 32 | 0;
    HEAP32[$33 >> 2] = $32;
    var $34 = $3 + 36 | 0;
    HEAP32[$34 >> 2] = $pn;
    var $36 = $3 + 40 | 0;
    __ZN2js11UpvarCookie8makeFreeEv($36);
    var $_0 = $4;
    __label__ = 12;
    break;
   case 9:
    var $38 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $40 = __ZN2js6Parser16endBracketedExprEv($this);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode5setOpE4JSOp($4, 167);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($4, 2);
    var $45 = $pn + 4 | 0;
    var $46 = $3 + 4 | 0;
    var $47$0 = HEAP32[$45 >> 2];
    var $47$1 = HEAP32[$45 + 4 >> 2];
    var $st$10$0 = $46 | 0;
    HEAP32[$st$10$0 >> 2] = $47$0;
    var $st$10$1 = $46 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $47$1;
    var $50 = $40 + 12 | 0;
    var $51 = $3 + 12 | 0;
    var $52$0 = HEAP32[$50 >> 2];
    var $52$1 = HEAP32[$50 + 4 >> 2];
    var $st$22$0 = $51 | 0;
    HEAP32[$st$22$0 >> 2] = $52$0;
    var $st$22$1 = $51 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $52$1;
    var $53 = $3 + 32 | 0;
    HEAP32[$53 >> 2] = $pn;
    var $54 = $3 + 36 | 0;
    HEAP32[$54 >> 2] = $40;
    var $_0 = $4;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser15qualifiedSuffixEP11JSParseNode["X"] = 1;

function __ZN2js6Parser19qualifiedIdentifierEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser16propertySelectorEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 40 | 0;
    var $5 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($4, 71);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $1;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = HEAP32[$this + 980 >> 2] | 0;
    var $11 = HEAP32[$9 >> 2] | 256;
    HEAP32[$9 >> 2] = $11;
    var $12 = __ZN2js6Parser15qualifiedSuffixEP11JSParseNode($this, $1);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser19attributeIdentifierEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($4, 168);
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream8getTokenEj($7, 32);
    if (($8 | 0) == 29 || ($8 | 0) == 17) {
      __label__ = 3;
      break;
    } else if (($8 | 0) == 23) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = __ZN2js6Parser19qualifiedIdentifierEv($this);
    var $pn2_0 = $10;
    __label__ = 6;
    break;
   case 4:
    var $12 = __ZN2js6Parser16endBracketedExprEv($this);
    var $pn2_0 = $12;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 6:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $3 + 32 | 0;
    HEAP32[$18 >> 2] = $pn2_0;
    var $_0 = $4;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser7xmlExprEi($this, $inTag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js9UnaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZN2js11TokenStream12isXMLTagModeEv($7);
    __ZN2js11TokenStream13setXMLTagModeEb($7, 0);
    var $9 = __ZN2js6Parser4exprEv($this);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZN2js11TokenStream8getTokenEj($7, 0);
    if (($12 | 0) == 26) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 176, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    __ZN2js11TokenStream13setXMLTagModeEb($7, $8);
    var $17 = $3 + 32 | 0;
    HEAP32[$17 >> 2] = $9;
    var $19 = ($inTag | 0) != 0 ? 180 : 181;
    __ZN11JSParseNode5setOpE4JSOp($4, $19);
    var $_0 = $4;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream13setXMLTagModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 512);
  return;
}

function __ZN2js6Parser11xmlAtomNodeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 980 >> 2];
    var $3 = __ZN2js11NullaryNode6createEP13JSTreeContext($2);
    var $4 = $3 | 0;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 40 | 0;
    var $8 = __ZNK2js11TokenStream12currentTokenEv($7);
    var $9 = $8 + 24 | 0;
    var $11 = HEAP32[$9 >> 2];
    __ZN11JSParseNode5setOpE4JSOp($4, $11);
    var $14 = $3 + 32 | 0;
    var $_c = HEAP32[$8 + 28 >> 2];
    HEAP32[$14 >> 2] = $_c;
    if ((HEAP32[$8 >> 2] | 0) == 69) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $21 = $3 + 36 | 0;
    var $_c1 = HEAP32[$9 >> 2];
    HEAP32[$21 >> 2] = $_c1;
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser11xmlNameExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    var $2 = $this + 980 | 0;
    var $pn_0 = 0;
    var $list_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $list_0;
    var $pn_0;
    var $3 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$3 >> 2] | 0) == 25) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZN2js6Parser7xmlExprEi($this, 1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $8;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZN2js6Parser11xmlAtomNodeEv($this);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $pn2_0 = $11;
      __label__ = 5;
      break;
    }
   case 5:
    var $pn2_0;
    if (($pn_0 | 0) == 0) {
      var $pn_2 = $pn2_0;
      var $list_2 = $list_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($list_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $pn_1 = $pn_0;
      var $list_1 = $list_0;
      __label__ = 9;
      break;
    }
   case 7:
    var $18 = HEAP32[$2 >> 2];
    var $19 = __ZN2js8ListNode6createEP13JSTreeContext($18);
    var $20 = $19 | 0;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($20, 63);
    var $25 = $pn_0 + 4 | 0;
    var $26 = $19 + 4 | 0;
    var $27$0 = HEAP32[$25 >> 2];
    var $27$1 = HEAP32[$25 + 4 >> 2];
    var $st$9$0 = $26 | 0;
    HEAP32[$st$9$0 >> 2] = $27$0;
    var $st$9$1 = $26 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $27$1;
    __ZN11JSParseNode8initListEPS_($20, $pn_0);
    var $29 = $19 + 44 | 0;
    var $32 = HEAP32[$29 >> 2] & -4096 | 2;
    HEAP32[$29 >> 2] = $32;
    var $pn_1 = $20;
    var $list_1 = $20;
    __label__ = 9;
    break;
   case 9:
    var $list_1;
    var $pn_1;
    var $36 = $pn2_0 + 12 | 0;
    var $37 = $pn_1 + 12 | 0;
    var $38$0 = HEAP32[$36 >> 2];
    var $38$1 = HEAP32[$36 + 4 >> 2];
    HEAP32[$37 >> 2] = $38$0;
    HEAP32[$37 + 4 >> 2] = $38$1;
    __ZN11JSParseNode6appendEPS_($pn_1, $pn2_0);
    var $pn_2 = $pn_1;
    var $list_2 = $list_1;
    __label__ = 10;
    break;
   case 10:
    var $list_2;
    var $pn_2;
    var $40 = __ZN2js11TokenStream8getTokenEv($1);
    if (($40 | 0) == 63 || ($40 | 0) == 25) {
      var $pn_0 = $pn_2;
      var $list_0 = $list_2;
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2js11TokenStream10ungetTokenEv($1);
    var $_0 = $pn_2;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser11xmlNameExprEv["X"] = 1;

function __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, $tagtype, $namep) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser11xmlNameExprEv($this);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($1, 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$1 + 32 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$namep >> 2] = $10;
    var $11 = $this + 40 | 0;
    var $12 = $this + 980 | 0;
    var $list_0 = 0;
    var $pn_0 = $1;
    __label__ = 5;
    break;
   case 5:
    var $pn_0;
    var $list_0;
    var $14 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $pn_0;
      __label__ = 24;
      break;
    }
   case 6:
    var $16 = __ZN2js11TokenStream8getTokenEv($11);
    if (($16 | 0) == 63 || ($16 | 0) == 25) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream10ungetTokenEv($11);
    var $_0 = $pn_0;
    __label__ = 24;
    break;
   case 8:
    var $19 = __ZN2js6Parser11xmlNameExprEv($this);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($list_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $list_1 = $list_0;
      var $pn_1 = $pn_0;
      __label__ = 12;
      break;
    }
   case 10:
    var $24 = HEAP32[$12 >> 2];
    var $25 = __ZN2js8ListNode6createEP13JSTreeContext($24);
    var $26 = $25 | 0;
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($26, $tagtype);
    var $31 = $pn_0 + 4 | 0;
    var $32 = $25 + 4 | 0;
    var $33$0 = HEAP32[$31 >> 2];
    var $33$1 = HEAP32[$31 + 4 >> 2];
    var $st$9$0 = $32 | 0;
    HEAP32[$st$9$0 >> 2] = $33$0;
    var $st$9$1 = $32 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $33$1;
    __ZN11JSParseNode8initListEPS_($26, $pn_0);
    var $list_1 = $26;
    var $pn_1 = $26;
    __label__ = 12;
    break;
   case 12:
    var $pn_1;
    var $list_1;
    __ZN11JSParseNode6appendEPS_($pn_1, $19);
    var $35 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($19, 5);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if ((HEAP32[$19 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $43 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($19, 25);
    if ($43) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $46 = $pn_1 + 44 | 0;
    var $48 = HEAP32[$46 >> 2] | 2;
    HEAP32[$46 >> 2] = $48;
    __label__ = 16;
    break;
   case 16:
    var $50 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    var $51 = __ZN2js11TokenStream8getTokenEj($11, 0);
    if (($51 | 0) == 4) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 183, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 18:
    var $56 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($11, 65);
    var $57 = __ZN2js11TokenStream8getTokenEv($11);
    if (($57 | 0) == 64) {
      __label__ = 19;
      break;
    } else if (($57 | 0) == 25) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    var $59 = __ZN2js6Parser11xmlAtomNodeEv($this);
    var $pn2_0 = $59;
    __label__ = 22;
    break;
   case 20:
    var $61 = __ZN2js6Parser7xmlExprEi($this, 1);
    var $63 = $pn_1 + 44 | 0;
    var $65 = HEAP32[$63 >> 2] | 2;
    HEAP32[$63 >> 2] = $65;
    var $pn2_0 = $61;
    __label__ = 22;
    break;
   case 21:
    var $67 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 184, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 22:
    var $pn2_0;
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $73 = $pn2_0 + 12 | 0;
    var $74 = $pn_1 + 12 | 0;
    var $75$0 = HEAP32[$73 >> 2];
    var $75$1 = HEAP32[$73 + 4 >> 2];
    HEAP32[$74 >> 2] = $75$0;
    HEAP32[$74 + 4 >> 2] = $75$1;
    __ZN11JSParseNode6appendEPS_($pn_1, $pn2_0);
    var $list_0 = $list_1;
    var $pn_0 = $pn_1;
    __label__ = 5;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom["X"] = 1;

function __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 40 | 0;
    __ZN2js11TokenStream13setXMLTagModeEb($1, 0);
    var $3 = $pn + 12 | 0;
    var $5 = $pn + 44 | 0;
    __label__ = 2;
    break;
   case 2:
    var $7 = __ZN2js11TokenStream8getTokenEj($1, 1024);
    if (($7 | 0) < 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $12 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 5:
    var $14 = __ZNK2js11TokenStream12currentTokenEv($1);
    if ((HEAP32[$14 + 28 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZN2js6Parser11xmlAtomNodeEv($this);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $19 + 12 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    HEAP32[$3 >> 2] = $24$0;
    HEAP32[$3 + 4 >> 2] = $24$1;
    __ZN11JSParseNode6appendEPS_($pn, $19);
    __label__ = 8;
    break;
   case 8:
    var $26 = __ZN2js11TokenStream8getTokenEj($1, 8);
    if (($26 | 0) < 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($26 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 10:
    var $31 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 11:
    if (($26 | 0) == 25) {
      __label__ = 12;
      break;
    } else if (($26 | 0) == 59) {
      __label__ = 13;
      break;
    } else if (($26 | 0) == 60) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $34 = __ZN2js6Parser7xmlExprEi($this, 0);
    var $36 = HEAP32[$5 >> 2] | 2;
    HEAP32[$5 >> 2] = $36;
    var $pn21_0 = $34;
    __label__ = 16;
    break;
   case 13:
    var $38 = __ZN2js6Parser16xmlElementOrListEi($this, 0);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $41 = $38 + 44 | 0;
    var $42 = HEAP32[$41 >> 2];
    var $43 = $42 & 4063;
    var $44 = $42 & -33;
    HEAP32[$41 >> 2] = $44;
    var $46 = HEAP32[$5 >> 2] | $43;
    HEAP32[$5 >> 2] = $46;
    var $pn21_02 = $38;
    __label__ = 17;
    break;
   case 15:
    var $48 = __ZN2js6Parser11xmlAtomNodeEv($this);
    var $pn21_0 = $48;
    __label__ = 16;
    break;
   case 16:
    var $pn21_0;
    if (($pn21_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $pn21_02 = $pn21_0;
      __label__ = 17;
      break;
    }
   case 17:
    var $pn21_02;
    var $53 = $pn21_02 + 12 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    HEAP32[$3 >> 2] = $54$0;
    HEAP32[$3 + 4 >> 2] = $54$1;
    __ZN11JSParseNode6appendEPS_($pn, $pn21_02);
    __label__ = 2;
    break;
   case 18:
    __ZN2js11TokenStream13setXMLTagModeEb($1, 1);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser17xmlElementContentEP11JSParseNode["X"] = 1;

function __ZL15JSDOUBLE_IS_NaNd2908($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js11TokenStream6setXMLEb($this, $enabled) {
  HEAP8[$this + 908 | 0] = $enabled & 1;
  return;
}

function __ZNK2js14MultiDeclRange5emptyEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN2js14MultiDeclRange5frontEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js14MultiDeclRange8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 4 >> 2] = 0;
    __label__ = 6;
    break;
   case 3:
    var $8 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $8;
    if (($8 | 0) == 0) {
      var $14 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $14;
    HEAP32[$this + 4 >> 2] = $14;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream11getTokenbufEv($this) {
  return $this + 184 | 0;
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js6Parser16xmlElementOrListEi($this, $allowList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $startAtom = __stackBase__;
    var $endAtom = __stackBase__ + 4;
    var $3 = HEAPU32[$this + 12 >> 2];
    if (__stackBase__ + 8 >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 51;
    break;
   case 3:
    var $9 = $this + 980 | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = __ZN2js8ListNode6createEP13JSTreeContext($10);
    var $12 = $11 | 0;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $this + 40 | 0;
    __ZN2js11TokenStream13setXMLTagModeEb($15, 1);
    var $16 = __ZN2js11TokenStream8getTokenEv($15);
    if (($16 | 0) == 63 || ($16 | 0) == 25) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == -1) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 5:
    var $18 = __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, 59, $startAtom);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($15, 65);
    var $22 = __ZN2js11TokenStream8getTokenEv($15);
    if (($22 | 0) == 61) {
      __label__ = 7;
      break;
    } else if (($22 | 0) == 62) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 7:
    var $24 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 59);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZN11JSParseNode9makeEmptyEv($12);
    var $26 = HEAP32[$9 >> 2];
    var $27 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($12, $26);
    var $pn_0 = $18;
    __label__ = 13;
    break;
   case 9:
    __ZN11JSParseNode8initListEPS_($12, $18);
    var $29 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($18, 5);
    if ($29) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    if ((HEAP32[$18 + 44 >> 2] & 2 | 0) == 0) {
      var $pn_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $37 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 25);
    if ($37) {
      __label__ = 12;
      break;
    } else {
      var $pn_0 = $12;
      __label__ = 13;
      break;
    }
   case 12:
    var $40 = $11 + 44 | 0;
    var $42 = HEAP32[$40 >> 2] | 2;
    HEAP32[$40 >> 2] = $42;
    var $pn_0 = $12;
    __label__ = 13;
    break;
   case 13:
    var $pn_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn_0, 61);
    var $45 = $pn_0 + 44 | 0;
    var $47 = HEAP32[$45 >> 2] | 32;
    HEAP32[$45 >> 2] = $47;
    var $pn_2 = $pn_0;
    __label__ = 44;
    break;
   case 14:
    var $49 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 15:
    var $51 = $18 + 12 | 0;
    var $52 = __ZNK2js11TokenStream12currentTokenEv($15);
    var $54 = $52 + 12 | 0;
    var $55 = $51;
    var $56$0 = HEAP32[$54 >> 2];
    var $56$1 = HEAP32[$54 + 4 >> 2];
    HEAP32[$55 >> 2] = $56$0;
    HEAP32[$55 + 4 >> 2] = $56$1;
    var $57 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 59);
    if ($57) {
      var $pn2_0 = $18;
      var $pn_1 = $12;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN11JSParseNode8initListEPS_($12, $18);
    var $59 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($18, 5);
    if ($59) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if ((HEAP32[$18 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $67 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($18, 25);
    if ($67) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $70 = $11 + 44 | 0;
    var $72 = HEAP32[$70 >> 2] | 2;
    HEAP32[$70 >> 2] = $72;
    __label__ = 20;
    break;
   case 20:
    var $74 = HEAP32[$9 >> 2];
    var $75 = __ZN2js8ListNode6createEP13JSTreeContext($74);
    var $76 = $75 | 0;
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      var $pn2_0 = $12;
      var $pn_1 = $76;
      __label__ = 21;
      break;
    }
   case 21:
    var $pn_1;
    var $pn2_0;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn_1, 75);
    var $81 = $pn2_0 + 4 | 0;
    var $82 = $pn_1 + 4 | 0;
    var $st$7$0 = $81 | 0;
    var $83$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $81 + 4 | 0;
    var $83$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $82 | 0;
    HEAP32[$st$11$0 >> 2] = $83$0;
    var $st$11$1 = $82 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $83$1;
    __ZN11JSParseNode8initListEPS_($pn_1, $pn2_0);
    var $84 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_0, 5);
    if ($84) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    if ((HEAP32[$pn2_0 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $92 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_0, 25);
    if ($92) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $95 = $pn_1 + 44 | 0;
    var $97 = HEAP32[$95 >> 2] | 2;
    HEAP32[$95 >> 2] = $97;
    __label__ = 25;
    break;
   case 25:
    var $99 = $pn_1 + 44 | 0;
    var $101 = HEAP32[$99 >> 2] | 32;
    HEAP32[$99 >> 2] = $101;
    var $102 = __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $pn_1);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $105 = __ZN2js11TokenStream8getTokenEv($15);
    if (($105 | 0) < 1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    if (($105 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 51;
      break;
    }
   case 28:
    var $110 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 190, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 29:
    if (($105 | 0) == 63 || ($105 | 0) == 25) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $113 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 31:
    var $115 = __ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom($this, 60, $endAtom);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $118 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($115, 60);
    if ($118) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $120 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 34:
    var $122 = HEAP32[$endAtom >> 2];
    if (($122 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $125 = HEAP32[$startAtom >> 2];
    if (($125 | 0) == 0 | ($122 | 0) == ($125 | 0)) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $129 = $125 | 0;
    var $130 = __ZNK14JSLinearString5charsEv($129);
    var $131 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, $115, 256, 185, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $130, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 37:
    var $133 = HEAP32[$9 >> 2];
    var $134 = __ZN2js8ListNode6createEP13JSTreeContext($133);
    var $135 = $134 | 0;
    if (($134 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($135, 60);
    __ZN11JSParseNode8initListEPS_($135, $115);
    __ZN11JSParseNode6appendEPS_($pn_1, $135);
    var $138 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($115, 5);
    if ($138) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    if ((HEAP32[$115 + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $146 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($115, 25);
    if ($146) {
      __label__ = 41;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 41:
    var $149 = $134 + 44 | 0;
    var $151 = HEAP32[$149 >> 2] | 2;
    HEAP32[$149 >> 2] = $151;
    var $153 = HEAP32[$99 >> 2] | 2;
    HEAP32[$99 >> 2] = $153;
    __label__ = 42;
    break;
   case 42:
    var $155 = __ZN2js11TokenStream10matchTokenENS_9TokenKindE($15, 65);
    var $156 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($156 | 0) == 62) {
      var $pn_2 = $pn_1;
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $159 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 186, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 44:
    var $pn_2;
    __ZN11JSParseNode5setOpE4JSOp($pn_2, 178);
    var $pn_3 = $pn_2;
    __label__ = 50;
    break;
   case 45:
    if (($allowList | 0) != 0 & ($16 | 0) == 62) {
      __label__ = 46;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 46:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($12, 76);
    __ZN11JSParseNode5setOpE4JSOp($12, 179);
    __ZN11JSParseNode9makeEmptyEv($12);
    var $166 = $11 + 44 | 0;
    var $168 = HEAP32[$166 >> 2] | 32;
    HEAP32[$166 >> 2] = $168;
    var $169 = __ZN2js6Parser17xmlElementContentEP11JSParseNode($this, $12);
    if (($169 | 0) == 0) {
      var $_0 = 0;
      __label__ = 51;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $172 = __ZN2js11TokenStream8getTokenEj($15, 0);
    if (($172 | 0) == 62) {
      var $pn_3 = $12;
      __label__ = 50;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $175 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 187, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 49:
    var $177 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 173, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 51;
    break;
   case 50:
    var $pn_3;
    __ZN2js11TokenStream13setXMLTagModeEb($15, 0);
    var $179 = $pn_3 + 12 | 0;
    var $180 = __ZNK2js11TokenStream12currentTokenEv($15);
    var $182 = $180 + 12 | 0;
    var $183 = $179;
    var $st$7$0 = $182 | 0;
    var $184$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $182 + 4 | 0;
    var $184$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $183 | 0;
    HEAP32[$st$11$0 >> 2] = $184$0;
    var $st$11$1 = $183 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $184$1;
    var $_0 = $pn_3;
    __label__ = 51;
    break;
   case 51:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6Parser16xmlElementOrListEi["X"] = 1;

function __ZN2js6Parser20xmlElementOrListRootEi($this, $allowList) {
  var $1 = $this + 40 | 0;
  var $2 = __ZNK2js11TokenStream6hasXMLEv($1);
  __ZN2js11TokenStream6setXMLEb($1, 1);
  var $3 = __ZN2js6Parser16xmlElementOrListEi($this, $allowList);
  __ZN2js11TokenStream6setXMLEb($1, $2);
  return $3;
}

function __ZNK2js11TokenStream6hasXMLEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 908 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js11TokenStream13versionNumberEv($this);
    var $7 = __ZN2jsL21VersionShouldParseXMLE9JSVersion($6);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser12parseXMLTextEP8JSObjectb($this, $chain, $allowList) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $xmltc = __stackBase__;
    __ZN13JSTreeContextC1EPN2js6ParserE($xmltc, $this);
    var $2 = HEAP32[$this + 12 >> 2];
    var $3 = $xmltc;
    var $4 = __ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE($3, $2, 0);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    __ZN13JSTreeContext13setScopeChainEP8JSObject($xmltc, $chain);
    var $6 = $this + 40 | 0;
    __ZN2js11TokenStream14setXMLOnlyModeEb($6, 1);
    var $7 = __ZN2js11TokenStream8getTokenEj($6, 8);
    if (($7 | 0) == 59) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz($this, 0, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $pn_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $12 = $allowList & 1;
    var $13 = __ZN2js6Parser20xmlElementOrListRootEi($this, $12);
    var $pn_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $pn_0;
    __ZN2js11TokenStream14setXMLOnlyModeEb($6, 0);
    var $_0 = $pn_0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN13JSTreeContextD1Ev($xmltc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream14setXMLOnlyModeEb($this, $enabled) {
  __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, 2048);
  return;
}

function __ZN11JSParseNode10isConstantEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    var $3 = $2 & 65535;
    if (($3 | 0) == 33) {
      __label__ = 2;
      break;
    } else if (($3 | 0) == 24 || ($3 | 0) == 26) {
      __label__ = 4;
      break;
    } else if (($3 | 0) == 30 || ($3 | 0) == 31) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = $2 >>> 16 & 255;
    if (($6 | 0) == 64 || ($6 | 0) == 66 || ($6 | 0) == 67) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($this, 89);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_0 = (HEAP32[$this + 44 >> 2] & 2048 | 0) == 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd2907($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZN2js9AtomDecls11lookupMultiEP6JSAtom($agg_result, $this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $atom;
    var $3 = HEAP32[$this + 4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $3, $1);
    var $4 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js14MultiDeclRangeC1EP12JSDefinition($agg_result, 0);
    __label__ = 6;
    break;
   case 3:
    var $8 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $9 = $8;
    var $10 = __ZNK2js12DefnOrHeader8isHeaderEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZNK2js12DefnOrHeader6headerEv($9);
    var $13 = $12;
    __ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE($agg_result, $13);
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZNK2js12DefnOrHeader4defnEv($9);
    var $16 = $15;
    __ZN2js14MultiDeclRangeC1EP12JSDefinition($agg_result, $16);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14BlockIdInScopejP13JSTreeContext($blockid, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc;
    var $2 = __ZN13JSTreeContext7blockidEv($1);
    if ($2 >>> 0 < $blockid >>> 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $stmt_0_in = $tc + 28 | 0;
    __label__ = 3;
    break;
   case 3:
    var $stmt_0_in;
    var $stmt_0 = HEAPU32[$stmt_0_in >> 2];
    if (($stmt_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$stmt_0 + 4 >> 2] | 0) == ($blockid | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $stmt_0_in = $stmt_0 + 28 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $9 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($9 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($agg_result, $it_0, 1);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($agg_result, $9, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv($this);
  var $2 = $1 ? 1 : 0;
  return $2;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 8 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($10);
    var $_0 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_($this, $p, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$p + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $p + 8 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($this + 200 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_($this, $key, $value);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 4:
    var $13 = HEAP32[$key >> 2];
    var $14 = $7 | 0;
    HEAP32[$14 >> 2] = $13;
    var $15 = HEAP32[$value >> 2];
    var $17 = HEAP32[$6 >> 2] + 4 | 0;
    HEAP32[$17 >> 2] = $15;
    var $18 = $this + 4 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    var $21 = $this | 0;
    var $23 = HEAP32[$21 >> 2] + 1 | 0;
    HEAP32[$21 >> 2] = $23;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $25 = $this + 200 | 0;
    var $26 = $p | 0;
    var $27 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($25, $26, $key, $value);
    var $_0 = $27;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($pn, $dn) {
  var $1 = $dn + 28 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$pn + 28 >> 2] = $2;
  HEAP32[$1 >> 2] = $pn;
  var $9 = $dn + 44 | 0;
  var $11 = HEAP32[$9 >> 2] | HEAP32[$pn + 44 >> 2] & 2312;
  HEAP32[$9 >> 2] = $11;
  __ZN11JSParseNode7setUsedEb($pn, 1);
  HEAP32[$pn + 36 >> 2] = $dn;
  return;
}

function __ZN9JSContext13regExpStaticsEv($this) {
  var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext2940($this);
  var $2 = $1;
  var $3 = __ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE($2);
  return $3;
}

function __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    if (($pn_tr | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn_tr, 46);
    if ($3) {
      var $_0 = $pn_tr;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $5 = __ZNK11JSParseNode8getArityEv($pn_tr);
    if (($5 | 0) == 5) {
      __label__ = 5;
      break;
    } else if (($5 | 0) == 3) {
      __label__ = 9;
      break;
    } else if (($5 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($5 | 0) == 1) {
      __label__ = 15;
      break;
    } else if (($5 | 0) == 6) {
      __label__ = 17;
      break;
    } else if (($5 | 0) == 7) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $pn2_0_in = $pn_tr + 32 | 0;
    __label__ = 6;
    break;
   case 6:
    var $pn2_0_in;
    var $pn2_0 = HEAP32[$pn2_0_in >> 2];
    if (($pn2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $11 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($pn2_0);
    if (($11 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $11;
      __label__ = 19;
      break;
    }
   case 8:
    var $pn2_0_in = $pn2_0 + 24 | 0;
    __label__ = 6;
    break;
   case 9:
    var $17 = HEAP32[$pn_tr + 32 >> 2];
    var $18 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($17);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $18;
      __label__ = 19;
      break;
    }
   case 10:
    var $23 = HEAP32[$pn_tr + 36 >> 2];
    var $24 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($23);
    if (($24 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = $24;
      __label__ = 19;
      break;
    }
   case 11:
    var $pn_tr = HEAP32[$pn_tr + 40 >> 2];
    __label__ = 2;
    break;
   case 12:
    var $31 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $34 = HEAP32[$pn_tr + 32 >> 2];
    var $35 = __ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE($34);
    if (($35 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $_0 = $35;
      __label__ = 19;
      break;
    }
   case 14:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 15:
    var $42 = __ZNK11JSParseNode4isOpE4JSOp($pn_tr, 0);
    if ($42) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 16:
    var $pn_tr = HEAP32[$pn_tr + 32 >> 2];
    __label__ = 2;
    break;
   case 17:
    var $47 = __ZN11JSParseNode9maybeExprEv($pn_tr);
    var $pn_tr = $47;
    __label__ = 2;
    break;
   case 18:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE["X"] = 1;

function __ZL7BoolishP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode5getOpEv($pn);
    if (($1 | 0) == 60) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 61) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 58) {
      __label__ = 6;
      break;
    } else if (($1 | 0) == 64 || ($1 | 0) == 66) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 127 || ($1 | 0) == 130 || ($1 | 0) == 67) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $4 = $pn + 32 | 0;
    var $5 = (tempDoubleI32[0] = HEAP32[$4 >> 2], tempDoubleI32[1] = HEAP32[$4 + 4 >> 2], tempDoubleF64[0]);
    if ($5 != 0) {
      __label__ = 3;
      break;
    } else {
      var $11 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL15JSDOUBLE_IS_NaNd2908($5);
    var $11 = ($8 | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 11;
    break;
   case 5:
    var $17 = HEAP32[$pn + 32 >> 2] | 0;
    var $18 = __ZNK8JSString6lengthEv($17);
    var $_0 = ($18 | 0) != 0 & 1;
    __label__ = 11;
    break;
   case 6:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $27 = HEAP32[$pn + 32 >> 2];
    var $28 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($27, 34);
    if ($28) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[HEAP32[$27 + 32 >> 2] + 60 >> 2] & 4096 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    var $_0 = -1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE($cx, $pn, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, $type);
    if ($2) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($type | 0) == 30) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 31) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 31);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 4:
    var $7 = $pn + 32 | 0;
    var $10 = HEAP32[$7 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString2910($1, $10);
    var $11 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $1, $d);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $13 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $14 = $7;
    tempDoubleF64[0] = $13, HEAP32[$14 >> 2] = tempDoubleI32[0], HEAP32[$14 + 4 >> 2] = tempDoubleI32[1];
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    var $16 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 7:
    var $18 = $pn + 32 | 0;
    var $19 = $18;
    var $20 = (tempDoubleI32[0] = HEAP32[$19 >> 2], tempDoubleI32[1] = HEAP32[$19 + 4 >> 2], tempDoubleF64[0]);
    var $21 = __Z17js_NumberToStringP9JSContextd($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $24 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $21, 0);
    var $_c = $24;
    HEAP32[$18 >> 2] = $_c;
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 31);
    __ZN11JSParseNode5setOpE4JSOp($pn, 61);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIP12JSDefinitionEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext($op, $pn1, $pn2, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $pn1 + 32 | 0;
    var $3 = (tempDoubleI32[0] = HEAP32[$2 >> 2], tempDoubleI32[1] = HEAP32[$2 + 4 >> 2], tempDoubleF64[0]);
    var $5 = $pn2 + 32 | 0;
    var $6 = (tempDoubleI32[0] = HEAP32[$5 >> 2], tempDoubleI32[1] = HEAP32[$5 + 4 >> 2], tempDoubleF64[0]);
    if (($op | 0) == 24 || ($op | 0) == 25) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 27) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 28) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 29) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 30) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 31) {
      __label__ = 15;
      break;
    } else {
      var $d_0 = $3;
      __label__ = 18;
      break;
    }
   case 2:
    var $8 = __ZL20js_DoubleToECMAInt32d2909($3);
    var $9 = __ZL20js_DoubleToECMAInt32d2909($6);
    var $10 = $9 & 31;
    var $14 = ($op | 0) == 24 ? $8 << $10 : $8 >> $10;
    var $d_0 = $14 | 0;
    __label__ = 18;
    break;
   case 3:
    var $17 = __ZL20js_DoubleToECMAInt32d2909($6);
    var $18 = $17 & 31;
    var $19 = __Z21js_DoubleToECMAUint32d($3);
    var $d_0 = $19 >>> ($18 >>> 0) >>> 0;
    __label__ = 18;
    break;
   case 4:
    var $d_0 = $3 + $6;
    __label__ = 18;
    break;
   case 5:
    var $d_0 = $3 - $6;
    __label__ = 18;
    break;
   case 6:
    var $d_0 = $3 * $6;
    __label__ = 18;
    break;
   case 7:
    if ($6 == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if ($3 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZL15JSDOUBLE_IS_NaNd2908($3);
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $36;
    __label__ = 18;
    break;
   case 11:
    var $38 = __ZL15JSDOUBLE_IS_NEGd2917($3);
    var $39 = __ZL15JSDOUBLE_IS_NEGd2917($6);
    if ($38 ^ $39) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $42 = (tempDoubleI32[0] = HEAP32[_js_NegativeInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_NegativeInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $42;
    __label__ = 18;
    break;
   case 13:
    var $44 = (tempDoubleI32[0] = HEAP32[_js_PositiveInfinity >> 2], tempDoubleI32[1] = HEAP32[_js_PositiveInfinity + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $44;
    __label__ = 18;
    break;
   case 14:
    var $d_0 = $3 / $6;
    __label__ = 18;
    break;
   case 15:
    if ($6 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $50 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $d_0 = $50;
    __label__ = 18;
    break;
   case 17:
    var $52 = __ZL7js_fmoddd2918($3, $6);
    var $d_0 = $52;
    __label__ = 18;
    break;
   case 18:
    var $d_0;
    if (($pn1 | 0) == ($pn | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $56 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1, $tc);
    __label__ = 20;
    break;
   case 20:
    if (($pn2 | 0) == ($pn | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $60 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn2, $tc);
    __label__ = 22;
    break;
   case 22:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 30);
    __ZN11JSParseNode5setOpE4JSOp($pn, 60);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn, 0);
    var $63 = $pn + 32 | 0;
    tempDoubleF64[0] = $d_0, HEAP32[$63 >> 2] = tempDoubleI32[0], HEAP32[$63 + 4 >> 2] = tempDoubleI32[1];
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext["X"] = 1;

function __ZL20js_DoubleToECMAInt32d2909($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd2916($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    var $2 = $pn + 32 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = $pn + 44 | 0;
    if ((HEAP32[$5 >> 2] & 2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $accum_1_ph = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if (($1 | 0) == 60) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 4;
      break;
    } else {
      var $accum_1_ph = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $accum_1_ph = HEAP32[HEAP32[$cx + 52 >> 2] + 210388 >> 2] | 0;
    __label__ = 5;
    break;
   case 4:
    var $accum_1_ph = HEAP32[HEAP32[$cx + 52 >> 2] + 210408 >> 2] | 0;
    __label__ = 5;
    break;
   case 5:
    var $accum_1_ph;
    var $22 = $pn + 40 | 0;
    var $23 = $cx;
    var $j_0 = 0;
    var $i_0 = 0;
    var $accum_1 = $accum_1_ph;
    var $pnp_0 = $2;
    var $pn1_0 = $3;
    var $pn2_0 = $3;
    __label__ = 6;
    break;
   case 6:
    var $pn2_0;
    var $pn1_0;
    var $pnp_0;
    var $accum_1;
    var $i_0;
    var $j_0;
    if (($pn2_0 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = __ZNK11JSParseNode7getKindEv($pn2_0);
    if (($27 | 0) == 64) {
      __label__ = 8;
      break;
    } else if (($27 | 0) == 63 || ($27 | 0) == 65 || ($27 | 0) == 66 || ($27 | 0) == 31) {
      __label__ = 9;
      break;
    } else if (($27 | 0) == 68) {
      __label__ = 11;
      break;
    } else if (($27 | 0) == 67) {
      __label__ = 12;
      break;
    } else if (($27 | 0) == 69) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if (($accum_1 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn2_0, 5);
    if ($31) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $str_0 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    __label__ = 22;
    break;
   case 11:
    var $41 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $42 = __Z21js_MakeXMLCDATAStringP9JSContextP8JSString($23, $41);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $42;
      __label__ = 22;
      break;
    }
   case 12:
    var $48 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $49 = __Z23js_MakeXMLCommentStringP9JSContextP8JSString($23, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $49;
      __label__ = 22;
      break;
    }
   case 13:
    var $55 = HEAP32[$pn2_0 + 32 >> 2] | 0;
    var $58 = HEAP32[$pn2_0 + 36 >> 2];
    var $59 = __Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_($23, $55, $58);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $str_0 = $59;
      __label__ = 22;
      break;
    }
   case 14:
    if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    if ((($j_0 ^ $i_0) & 1 | 0) != 0 | ($accum_1 | 0) == 0 | ($pn1_0 | 0) == ($pn2_0 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    if (($accum_1 | 0) == 0 | ($pn1_0 | 0) == ($pn2_0 | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$pn1_0 + 24 >> 2] | 0) == ($pn2_0 | 0)) {
      var $pn1_1_lcssa = $pn1_0;
      __label__ = 19;
      break;
    } else {
      var $pn1_113 = $pn1_0;
      __label__ = 18;
      break;
    }
   case 18:
    var $pn1_113;
    var $72 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_113, $tc);
    var $74 = HEAP32[$22 >> 2] - 1 | 0;
    HEAP32[$22 >> 2] = $74;
    if ((HEAP32[$72 + 24 >> 2] | 0) == ($pn2_0 | 0)) {
      var $pn1_1_lcssa = $72;
      __label__ = 19;
      break;
    } else {
      var $pn1_113 = $72;
      __label__ = 18;
      break;
    }
   case 19:
    var $pn1_1_lcssa;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn1_1_lcssa, 66);
    __ZN11JSParseNode5setOpE4JSOp($pn1_1_lcssa, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn1_1_lcssa, 0);
    var $78 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $accum_1, 0);
    HEAP32[$pn1_1_lcssa + 32 >> 2] = $78;
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$pnp_0 >> 2] = $pn1_1_lcssa;
    __label__ = 21;
    break;
   case 21:
    var $83 = $pn2_0 + 24 | 0;
    var $j_2 = $j_0;
    var $accum_2 = 0;
    var $pnp_1 = $83;
    var $pn1_2 = HEAP32[$83 >> 2];
    __label__ = 29;
    break;
   case 22:
    var $str_0;
    if (($accum_1 | 0) == 0) {
      var $j_2 = $j_0;
      var $accum_2 = $str_0;
      var $pnp_1 = $pnp_0;
      var $pn1_2 = $pn1_0;
      __label__ = 29;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2js16AutoStringRooterC1EP9JSContextP8JSString($tvr, $cx, $accum_1);
    if (($1 | 0) == 61 || ($1 | 0) == 59) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    if (($i_0 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $92 = __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($23, $i_0 & 1, $accum_1, $str_0);
    var $96 = $92;
    __label__ = 27;
    break;
   case 26:
    var $94 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $accum_1, $str_0);
    var $96 = $94;
    __label__ = 27;
    break;
   case 27:
    var $96;
    __ZN2js16AutoStringRooterD1Ev($tvr);
    if (($96 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $j_2 = $j_0 + 1 | 0;
    var $accum_2 = $96;
    var $pnp_1 = $pnp_0;
    var $pn1_2 = $pn1_0;
    __label__ = 29;
    break;
   case 29:
    var $pn1_2;
    var $pnp_1;
    var $accum_2;
    var $j_2;
    var $j_0 = $j_2;
    var $i_0 = $i_0 + 1 | 0;
    var $accum_1 = $accum_2;
    var $pnp_0 = $pnp_1;
    var $pn1_0 = $pn1_2;
    var $pn2_0 = HEAP32[$pn2_0 + 24 >> 2];
    __label__ = 6;
    break;
   case 30:
    if (($accum_1 | 0) == 0) {
      var $pn1_4 = $pn1_0;
      __label__ = 42;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ((HEAP32[$5 >> 2] & 2 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    }
   case 32:
    if (($1 | 0) == 61) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $_pn_in = HEAP32[$cx + 52 >> 2] + 210396 | 0;
    __label__ = 36;
    break;
   case 34:
    if (($1 - 59 | 0) >>> 0 < 2) {
      __label__ = 35;
      break;
    } else {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    }
   case 35:
    var $_pn_in = HEAP32[$cx + 52 >> 2] + 210420 | 0;
    __label__ = 36;
    break;
   case 36:
    var $_pn_in;
    var $_pn = HEAP32[$_pn_in >> 2];
    if (($_pn | 0) == 0) {
      var $accum_3_ph = $accum_1;
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $str_2 = $_pn | 0;
    var $124 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($cx, $accum_1, $str_2);
    if (($124 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      var $accum_3_ph = $124;
      __label__ = 38;
      break;
    }
   case 38:
    var $accum_3_ph;
    if ((HEAP32[$pn1_0 + 24 >> 2] | 0) == 0) {
      var $pn1_3_lcssa = $pn1_0;
      __label__ = 40;
      break;
    } else {
      var $pn1_312 = $pn1_0;
      __label__ = 39;
      break;
    }
   case 39:
    var $pn1_312;
    var $129 = __ZL11RecycleTreeP11JSParseNodeP13JSTreeContext($pn1_312, $tc);
    var $131 = HEAP32[$22 >> 2] - 1 | 0;
    HEAP32[$22 >> 2] = $131;
    if ((HEAP32[$129 + 24 >> 2] | 0) == 0) {
      var $pn1_3_lcssa = $129;
      __label__ = 40;
      break;
    } else {
      var $pn1_312 = $129;
      __label__ = 39;
      break;
    }
   case 40:
    var $pn1_3_lcssa;
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn1_3_lcssa, 66);
    __ZN11JSParseNode5setOpE4JSOp($pn1_3_lcssa, 61);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($pn1_3_lcssa, 0);
    var $135 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($cx, $accum_3_ph, 0);
    HEAP32[$pn1_3_lcssa + 32 >> 2] = $135;
    if (($135 | 0) == 0) {
      var $_0 = 0;
      __label__ = 48;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$pnp_0 >> 2] = $pn1_3_lcssa;
    var $pn1_4 = $pn1_3_lcssa;
    __label__ = 42;
    break;
   case 42:
    var $pn1_4;
    if (($pn1_4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 48;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ((HEAP32[$22 >> 2] | 0) == 1) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 1;
      __label__ = 48;
      break;
    }
   case 44:
    if ((HEAP32[$5 >> 2] & 32 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    __ZN11JSParseNode6becomeEPS_($pn, $pn1_4);
    var $_0 = 1;
    __label__ = 48;
    break;
   case 46:
    if (($1 | 0) == 61) {
      __label__ = 47;
      break;
    } else {
      var $_0 = 1;
      __label__ = 48;
      break;
    }
   case 47:
    __ZN11JSParseNode7setKindEN2js9TokenKindE($pn, 75);
    __ZN11JSParseNode5setOpE4JSOp($pn, 178);
    var $_0 = 1;
    __label__ = 48;
    break;
   case 48:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2JSL11StringValueEP8JSString2910($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stack = __stackBase__;
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 4);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAP32[$pn + 32 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 + 24 | 0;
    HEAP32[$10 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    __ZN2js9NodeStackC1Ev($stack);
    var $12 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($pn, $stack);
    var $13 = __ZN2js9NodeStack5emptyEv($stack);
    if ($13) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $tc_idx = $tc + 48 | 0;
    __label__ = 7;
    break;
   case 7:
    var $14 = __ZN2js9NodeStack3popEv($stack);
    var $15 = __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($14, $stack);
    if ($15) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $tc_idx_val = HEAP32[$tc_idx >> 2];
    __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($14, $tc_idx_val);
    __label__ = 9;
    break;
   case 9:
    var $17 = __ZN2js9NodeStack5emptyEv($stack);
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 10:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_($this, $key, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this + 200 | 0;
    var $4 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($3, $key, $value);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE($27, $1);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIP12JSDefinitionEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIP12JSDefinitionEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIP12JSDefinitionEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev($this);
  return;
}

function _js_malloc2912() {
  var $1 = _malloc(284);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv($this) {
  return (HEAP32[$this + 24 >> 2] | 0) != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb($this, $ptr, $found) {
  HEAP32[$this + 8 >> 2] = $ptr;
  HEAP8[$this + 12 | 0] = 1;
  HEAP8[$this + 13 | 0] = $found & 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p) {
  var $1 = $p;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  HEAP8[$this + 12 | 0] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv($this) {
  return (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 != 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_($this, $key, $value) {
  HEAP32[$this >> 2] = $key;
  HEAP32[$this + 4 >> 2] = $value;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $begin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $newCur_0 = $begin;
    __label__ = 2;
    break;
   case 2:
    var $newCur_0;
    if ($newCur_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$newCur_0 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $newCur_0 = $newCur_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$this + 8 >> 2] = $newCur_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP8[$this + 8 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 200 | 0;
    var $2 = __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($1);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv($this);
    var $6 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($1, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $9 = $this | 0;
    var $11 = $this + 8 + (HEAP32[$9 >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 5;
    break;
   case 5:
    var $it_0;
    if (($it_0 | 0) == ($11 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $it_0 | 0;
    if ((HEAP32[$15 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($1, $15, $it_0 + 4 | 0);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 5;
    break;
   case 9:
    HEAP32[$9 >> 2] = 25;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $p = __stackBase__;
  __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
  var $1 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv($1);
  return $2;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv($1);
  return;
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv($this) {
  var $3 = HEAP32[$this + 24 >> 2];
  var $6 = HEAP32[$this + 8 >> 2] * 12 | 0;
  _memset($3, 0, $6, 1);
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = (HEAP8[$this + 13 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($11);
    var $14 = $12;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($2);
  return $3;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE($this, $p);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb($this, $ptr, $found) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb($this, $ptr, $found);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_($this, $key, $value) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_($this, $key, $value);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv($this) {
  var $3 = HEAP32[$this + 8 >> 2] + 8 | 0;
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $3);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r) {
  var __stackBase__ = STACKTOP;
  var tempParam = $r;
  $r = STACKTOP;
  STACKTOP += 8;
  HEAP32[$r >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$r + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $1);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_($this, $begin, $end_) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_($this, $begin, $end_);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_($this, $begin, $end_) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = $begin;
  HEAP32[$this + 12 >> 2] = $end_;
  HEAP8[$this + 16 | 0] = 1;
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE($this, $begin);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE($this, $r) {
  var __stackBase__ = STACKTOP;
  var tempParam = $r;
  $r = STACKTOP;
  STACKTOP += 8;
  HEAP32[$r >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$r + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP8[$this + 16 | 0] = 0;
  var $5 = $r;
  var $6 = $this;
  var $7$0 = HEAP32[$5 >> 2];
  var $7$1 = HEAP32[$5 + 4 >> 2];
  HEAP32[$6 >> 2] = $7$0;
  HEAP32[$6 + 4 >> 2] = $7$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv($this);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $4, $key);
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $9 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($9 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv($this);
  return $1 & 1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 12;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$p + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$p + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP8[$p + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$p + 4 >> 2] | 0;
    HEAP32[$9 >> 2] = 0;
    var $10 = $this + 4 | 0;
    var $12 = HEAP32[$10 >> 2] - 1 | 0;
    HEAP32[$10 >> 2] = $12;
    __label__ = 4;
    break;
   case 3:
    var $14 = $this + 200 | 0;
    var $16 = HEAP32[$p >> 2];
    HEAP32[$1 >> 2] = $16;
    __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($14, $1);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($1);
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev($1);
  __ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP32[$this + 4 >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($10);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE($this, $p);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $4 = $this + 16 | 0;
  var $5 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($4);
  return ($2 | 0) == ($5 | 0);
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 2;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $6 = $this + 16 | 0;
  var $7 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($6);
  HEAP32[$4 >> 2] = $7;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js9NodeStackC1Ev($this) {
  __ZN2js9NodeStackC2Ev($this);
  return;
}

function __ZN2jsL13VersionNumberE9JSVersion2944($version) {
  return $version & 4095;
}

function __ZN2jsL13VersionHasXMLE9JSVersion2945($version) {
  return ($version & 4096 | 0) != 0;
}

function _JSID_IS_STRING2948($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING2950($iden) {
  return $iden;
}

function __ZL18JSDOUBLE_IS_FINITEd2916($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NEGd2917($d) {
  tempDoubleF64[0] = $d;
  var $1$1 = tempDoubleI32[1];
  var $$emscripten$temp$0$1 = 0;
  return ($1$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && tempDoubleI32[0] >>> 0 < 0 >>> 0;
}

function __ZN11JSParseNode7setUsedEb($this, $enabled) {
  var $2 = $this;
  var $6 = HEAP32[$2 >> 2] & -1073741825 | ($enabled & 1) << 30;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2js9NodeStack5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js9NodeStack3popEv($this) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $4 = HEAP32[$2 + 24 >> 2];
  HEAP32[$1 >> 2] = $4;
  return $2;
}

function __ZN2js9NodeStack8pushListEP11JSParseNode($this, $pn) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  var $4 = HEAP32[$pn + 36 >> 2];
  HEAP32[$4 >> 2] = $2;
  var $6 = HEAP32[$pn + 32 >> 2];
  HEAP32[$1 >> 2] = $6;
  return;
}

function __ZN2js9NodeStack4pushEP11JSParseNode($this, $pn) {
  var $1 = $this | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$pn + 24 >> 2] = $2;
  HEAP32[$1 >> 2] = $pn;
  return;
}

function __ZN2js9NodeStackC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE($this, $node) {
  HEAP32[$this >> 2] = $node;
  var $4 = HEAP32[$node >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN2js14MultiDeclRangeC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = $defn;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE($this, $ie) {
  HEAP32[$this + 4 >> 2] = $ie;
  HEAP8[$this + 8 | 0] = 1;
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$p >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP8[$this + 8 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE($this, $enabled, $flag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($enabled) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = $this + 144 | 0;
    var $4 = HEAP32[$2 >> 2] | $flag;
    HEAP32[$2 >> 2] = $4;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 144 | 0;
    var $9 = HEAP32[$7 >> 2] & ($flag ^ -1);
    HEAP32[$7 >> 2] = $9;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11GenexpGuardC2EP13JSTreeContext($this, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $tc;
    var $2 = $tc + 12 | 0;
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[$tc + 16 >> 2];
    var $_pre_phi = $tc + 20 | 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = $tc + 20 | 0;
    HEAP32[$6 >> 2] = 0;
    HEAP32[$tc + 16 >> 2] = 0;
    HEAP32[$tc + 56 >> 2] = 0;
    HEAP32[$tc + 52 >> 2] = 0;
    var $11 = 0;
    var $_pre_phi = $6;
    __label__ = 4;
    break;
   case 4:
    var $_pre_phi;
    var $11;
    HEAP32[$this + 4 >> 2] = $11;
    var $13 = HEAP32[$_pre_phi >> 2];
    HEAP32[$this + 8 >> 2] = $13;
    var $16 = HEAP32[$2 >> 2] + 1 | 0;
    HEAP32[$2 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj($this, $pn, $tc, $ge, $adj) {
  HEAP32[$this >> 2] = $pn;
  HEAP32[$this + 4 >> 2] = $tc;
  HEAP8[$this + 8 | 0] = $ge & 1;
  HEAP32[$this + 12 >> 2] = $adj;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZN2js8TokenPtrltERKS0_($this, $bptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$bptr + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      var $15 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAPU32[$this >> 2] >>> 0 < HEAPU32[$bptr >> 2] >>> 0;
    __label__ = 4;
    break;
   case 4:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode6lexdefEv($this) {
  return HEAP32[$this + 36 >> 2];
}

function __ZN2js8TokenPtrleERKS0_($this, $bptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$bptr + 4 >> 2];
    if ($2 >>> 0 < $4 >>> 0) {
      var $15 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $15 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = HEAPU32[$this >> 2] >>> 0 <= HEAPU32[$bptr >> 2] >>> 0;
    __label__ = 4;
    break;
   case 4:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE($pn, $stack) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode8getArityEv($pn);
    if (($1 | 0) == 4) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 6) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 3) {
      __label__ = 8;
      break;
    } else if (($1 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($1 | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 2:
    HEAP32[$pn + 32 >> 2] = 0;
    var $4 = $pn + 36 | 0;
    var $6 = HEAP32[$4 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $6);
    HEAP32[$4 >> 2] = 0;
    var $_0 = 0;
    __label__ = 15;
    break;
   case 3:
    var $8 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $pn + 36 | 0;
    var $12 = HEAP32[$10 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $12);
    HEAP32[$10 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    var $14 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($14) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = __ZNK11JSParseNode6isDefnEv($pn);
    var $_0 = $16 ^ 1;
    __label__ = 15;
    break;
   case 7:
    __ZN2js9NodeStack8pushListEP11JSParseNode($stack, $pn);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 8:
    var $21 = HEAP32[$pn + 32 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $21);
    var $24 = HEAP32[$pn + 36 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $24);
    var $27 = HEAP32[$pn + 40 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $27);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 9:
    var $30 = HEAP32[$pn + 32 >> 2];
    var $31 = $pn + 36 | 0;
    var $32 = HEAP32[$31 >> 2];
    if (($30 | 0) == ($32 | 0)) {
      var $37 = $32;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $30);
    var $37 = HEAP32[$31 >> 2];
    __label__ = 11;
    break;
   case 11:
    var $37;
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $37);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 12:
    var $41 = HEAP32[$pn + 32 >> 2];
    __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($stack, $41);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 13:
    var $43 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($43) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $45 = __ZNK11JSParseNode6isDefnEv($pn);
    var $_0 = $45 ^ 1;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE["X"] = 1;

function __ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext($pn, $tc_0_11_val) {
  __ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE($pn, $tc_0_11_val);
  return;
}

function __ZN2js9NodeStack14pushUnlessNullEP11JSParseNode($this, $pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js9NodeStack4pushEP11JSParseNode($this, $pn);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoStringRooterC1EP9JSContextP8JSString($this, $cx, $str) {
  __ZN2js16AutoStringRooterC2EP9JSContextP8JSString($this, $cx, $str);
  return;
}

function __ZN2js16AutoStringRooterD1Ev($this) {
  __ZN2js16AutoStringRooterD2Ev($this);
  return;
}

function __ZN2js16AutoStringRooterD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js16AutoStringRooterC2EP9JSContextP8JSString($this, $cx, $str) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -14);
  HEAP32[$this + 12 >> 2] = $str;
  return;
}

function __ZL7js_fmoddd2918($d, $d2) {
  var $1 = _fmod($d, $d2);
  return $1;
}

function __ZN2JSL14UndefinedValueEv2937($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext2940($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = __ZNK9JSContext5hasfpEv($cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK9JSContext2fpEv($cx);
    var $4 = __ZNK2js10StackFrame10scopeChainEv($3);
    var $5 = $4;
    var $6 = __ZNK8JSObject9getGlobalEv($5);
    var $_0 = $6;
    __label__ = 5;
    break;
   case 3:
    var $10 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $10;
    var $11 = $cx;
    var $12 = $scope;
    var $13 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($11, $12);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$scope >> 2];
    var $17 = __ZN8JSObject8asGlobalEv($16);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($agg_result, $this, $key) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($1, $5, $key);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($agg_result, $1);
    __label__ = 9;
    break;
   case 3:
    var $10 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    var $it_0 = $this + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if (($it_0 | 0) == ($10 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$it_0 >> 2] | 0) == (HEAP32[$key >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($agg_result, $it_0);
    __label__ = 9;
    break;
   case 7:
    var $it_0 = $it_0 + 8 | 0;
    __label__ = 4;
    break;
   case 8:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($agg_result, 0);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($this) {
  var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv($this);
  return $1 & 1;
}

function __ZN2js14MultiDeclRangeC1EP12JSDefinition($this, $defn) {
  __ZN2js14MultiDeclRangeC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv($10);
    var $15 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $15;
    return $15;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE($this, $node) {
  __ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE($this, $node);
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = (HEAP32[$this + 4 >> 2] | 0) != 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv($10);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE($this, $p);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE($this, $ie) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE($this, $ie);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = $this;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_($l);
  var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj($1, $l, $2, 0);
  var $4 = $3;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($agg_result, $4);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE($this, $entry) {
  var $1 = $this;
  var $2 = $entry;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE($1, $2);
  return;
}

function __ZN2jsL21VersionShouldParseXMLE9JSVersion($version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL13VersionHasXMLE9JSVersion2945($version);
    if ($1) {
      var $6 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2jsL13VersionNumberE9JSVersion2944($version);
    var $6 = ($3 | 0) > 159;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream13versionNumberEv($this) {
  var $2 = HEAP32[$this + 904 >> 2];
  var $3 = __ZN2jsL13VersionNumberE9JSVersion2944($2);
  return $3;
}

function __ZL12JSID_TO_ATOMi2949($id) {
  var $1 = _JSID_TO_STRING2950($id);
  return $1;
}

function __ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc($cx, $ts, $tc, $pn, $kid, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 29);
    if ($1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 22);
    if ($3) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 27);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode4isOpE4JSOp($kid, 58);
    if ($7) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZNK11JSParseNode4isOpE4JSOp($kid, 123);
    if ($9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZNK11JSParseNode4isOpE4JSOp($kid, 108);
    if ($11) {
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __ZNK11JSParseNode4isOpE4JSOp($kid, 79);
    if ($13) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 19);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZNK11JSParseNode4isOpE4JSOp($kid, 174);
    if ($17) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $19 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($kid, 23);
    if ($19) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $ts, 0, 0, 130, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $name, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 12:
    var $23 = __Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode($cx, $tc, $kid);
    if ($23) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$pn + 32 >> 2] = $kid;
    var $_0 = $kid;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6Parser7orExpr1Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6Parser9andExpr1iEv($this);
    var $2 = $this + 40 | 0;
    var $3 = $this + 980 | 0;
    var $pn_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $pn_0;
    if (($pn_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE($2, 7);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZN2js6Parser9andExpr1nEv($this);
    var $10 = HEAP32[$3 >> 2];
    var $11 = __ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext(7, 68, $pn_0, $9, $10);
    var $pn_0 = $11;
    __label__ = 2;
    break;
   case 5:
    return $pn_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_($this, $type1, $type2) {
  var $1 = __ZNK2js11TokenStream12currentTokenEv($this);
  var $3 = HEAP32[$1 >> 2];
  return ($3 | 0) == ($type1 | 0) | ($3 | 0) == ($type2 | 0);
}

function __ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom($tc, $stmt, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $tc;
    var $_01 = $stmt;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $4 = HEAP32[$_01 + 28 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    var $8 = _js_LexicalLookup($1, $atom, 0, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    if (HEAP16[$8 >> 1] << 16 >> 16 == 4) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext($cx, $data, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$data >> 2];
    var $5 = HEAP32[$2 + 32 >> 2];
    if (($5 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN11JSParseNode5setOpE4JSOp($2, 9);
    var $14 = $2 + 44 | 0;
    var $16 = HEAP32[$14 >> 2] | 512;
    HEAP32[$14 >> 2] = $16;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $19 = $tc + 92 | 0;
    var $20 = $cx;
    var $21 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($19, $20, $5, 0);
    if (($21 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    var $27 = (HEAP32[$data + 4 >> 2] | 0) == 128 ? 3 : 2;
    var $28 = __ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE($cx, $tc, $2, $27);
    if ($28) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN11JSParseNode5setOpE4JSOp($2, 86);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK13JSTreeContext9compilingEv($tc);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[HEAP32[$tc + 48 >> 2] + 960 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$pn + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $pn + 32 | 0;
    var $16 = $tc;
    var $17 = __ZN13JSTreeContext15asCodeGeneratorEv($16);
    var $18 = $17;
    var $20 = HEAP32[$15 >> 2];
    var $21 = __ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom($pn, $18, $20);
    var $_0 = $21;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8TokenPtrgeERKS0_($this, $bptr) {
  var $1 = __ZN2js8TokenPtrltERKS0_($this, $bptr);
  return $1 ^ 1;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = HEAP32[$this + 4 >> 2] + 4 | 0;
    __label__ = 4;
    break;
   case 3:
    var $10 = $this | 0;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($10);
    var $14 = $11 + 4 | 0;
    __label__ = 4;
    break;
   case 4:
    var $14;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL12PrivateValueEPv2951($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZNK11JSParseNode12isBlockChildEv($this) {
  var $1 = __ZNK11JSParseNode4testEj($this, 32);
  return $1;
}

function __ZNK11JSParseNode10frameLevelEv($this) {
  var $2 = $this + 40 | 0;
  var $3 = __ZNK2js11UpvarCookie5levelEv($2);
  return $3 & 65535;
}

function __ZNK7mozilla14AlignedStorageILj192EE4addrEv($this) {
  return $this;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $5 = HEAP32[$rhs + 4 >> 2];
  HEAP32[$this + 4 >> 2] = $5;
  return;
}

function __ZN2js11TokenStream7FlaggerD2Ev($this) {
  var $6 = HEAP32[$this >> 2] + 144 | 0;
  var $8 = HEAP32[$6 >> 2] & (HEAP32[$this + 4 >> 2] ^ -1);
  HEAP32[$6 >> 2] = $8;
  return;
}

function __ZN2js11TokenStream7FlaggerC2EPS0_j($this, $parent, $withFlags) {
  HEAP32[$this >> 2] = $parent;
  HEAP32[$this + 4 >> 2] = $withFlags;
  var $3 = $parent + 144 | 0;
  var $5 = HEAP32[$3 >> 2] | $withFlags;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZNK15JSCodeGenerator16compilingForEvalEv($this) {
  return (HEAP32[$this >> 2] & 33554432 | 0) != 0;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + HEAP32[$this + 8 >> 2] * 12 | 0;
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox($this, $atom, $box) {
  HEAP32[$this >> 2] = $atom;
  HEAP32[$this + 4 >> 2] = $box;
  return;
}

function __ZN2js11GlobalScope9GlobalDefC2Ej($this, $knownSlot) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 8 >> 2] = $knownSlot;
  return;
}

function __ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv($this) {
  return HEAP32[$this >> 2];
}

function __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn, $tc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $tc + 48 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $5 = HEAPU32[$3 + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$5 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($5);
    var $_0 = 0;
    __label__ = 32;
    break;
   case 3:
    var $11 = __ZL17NewOrRecycledNodeP13JSTreeContext($3);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZNK11JSParseNode7getKindEv($opn);
    __ZN11JSParseNode7setKindEN2js9TokenKindE($11, $14);
    var $15 = __ZNK11JSParseNode5getOpEv($opn);
    __ZN11JSParseNode5setOpE4JSOp($11, $15);
    var $16 = __ZNK11JSParseNode6isUsedEv($opn);
    __ZN11JSParseNode7setUsedEb($11, $16);
    var $17 = __ZNK11JSParseNode6isDefnEv($opn);
    __ZN11JSParseNode7setDefnEb($11, $17);
    var $18 = __ZNK11JSParseNode8getArityEv($opn);
    __ZN11JSParseNode8setArityE16JSParseNodeArity($11, $18);
    var $19 = __ZNK11JSParseNode10isInParensEv($opn);
    __ZN11JSParseNode11setInParensEb($11, $19);
    var $22 = $11 + 4 | 0;
    var $23 = $opn + 4 | 0;
    HEAP32[$22 >> 2] = HEAP32[$23 >> 2];
    HEAP32[$22 + 4 >> 2] = HEAP32[$23 + 4 >> 2];
    HEAP32[$22 + 8 >> 2] = HEAP32[$23 + 8 >> 2];
    HEAP32[$22 + 12 >> 2] = HEAP32[$23 + 12 >> 2];
    var $24 = __ZNK11JSParseNode8getArityEv($11);
    if (($24 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($24 | 0) == 5) {
      __label__ = 8;
      break;
    } else if (($24 | 0) == 3) {
      __label__ = 13;
      break;
    } else if (($24 | 0) == 2) {
      __label__ = 16;
      break;
    } else if (($24 | 0) == 1) {
      __label__ = 21;
      break;
    } else if (($24 | 0) == 6) {
      __label__ = 23;
      break;
    } else if (($24 | 0) == 7) {
      __label__ = 29;
      break;
    } else if (($24 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 5:
    var $26 = HEAP32[$2 >> 2];
    var $31 = HEAP32[HEAP32[$opn + 32 >> 2] + 8 >> 2];
    var $32 = __ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext($26, $31, $11, $tc);
    var $_c9 = $32;
    HEAP32[$11 + 32 >> 2] = $_c9;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $38 = HEAP32[$opn + 36 >> 2];
    var $39 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($38, $tc);
    var $_c10 = $39;
    HEAP32[$11 + 36 >> 2] = $_c10;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $45 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $45;
    var $47 = $opn + 44 | 0;
    var $49 = HEAP32[$47 >> 2] & 4095;
    var $51 = $11 + 44 | 0;
    var $54 = HEAP32[$51 >> 2] & -4096 | $49;
    HEAP32[$51 >> 2] = $54;
    var $57 = HEAP32[$47 >> 2] & -4096 | $49;
    HEAP32[$51 >> 2] = $57;
    __label__ = 31;
    break;
   case 8:
    __ZN11JSParseNode9makeEmptyEv($11);
    var $opn2_0_in = $opn + 32 | 0;
    __label__ = 9;
    break;
   case 9:
    var $opn2_0_in;
    var $opn2_0 = HEAP32[$opn2_0_in >> 2];
    if (($opn2_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $63 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($opn2_0, $tc);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN11JSParseNode6appendEPS_($11, $63);
    var $opn2_0_in = $opn2_0 + 24 | 0;
    __label__ = 9;
    break;
   case 12:
    var $73 = $11 + 44 | 0;
    var $76 = HEAP32[$73 >> 2] & -4096 | HEAP32[$opn + 44 >> 2] & 4095;
    HEAP32[$73 >> 2] = $76;
    __label__ = 31;
    break;
   case 13:
    var $79 = HEAP32[$opn + 32 >> 2];
    var $80 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($79, $tc);
    HEAP32[$11 + 32 >> 2] = $80;
    if (($80 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $86 = HEAP32[$opn + 36 >> 2];
    var $87 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($86, $tc);
    var $_c7 = $87;
    HEAP32[$11 + 36 >> 2] = $_c7;
    if (($87 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $93 = HEAP32[$opn + 40 >> 2];
    var $94 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($93, $tc);
    var $_c8 = $94;
    HEAP32[$11 + 40 >> 2] = $_c8;
    if (($94 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 16:
    var $98 = $opn + 32 | 0;
    var $99 = HEAP32[$98 >> 2];
    var $100 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($99, $tc);
    HEAP32[$11 + 32 >> 2] = $100;
    if (($100 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $106 = HEAP32[$opn + 36 >> 2];
    if (($106 | 0) == (HEAP32[$98 >> 2] | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $110 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($106, $tc);
    var $_c6 = $110;
    HEAP32[$11 + 36 >> 2] = $_c6;
    if (($110 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $_c4 = $100;
    HEAP32[$11 + 36 >> 2] = $_c4;
    __label__ = 20;
    break;
   case 20:
    var $_c5 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $_c5;
    var $122 = HEAP32[$opn + 44 >> 2];
    HEAP32[$11 + 44 >> 2] = $122;
    __label__ = 31;
    break;
   case 21:
    var $127 = HEAP32[$opn + 32 >> 2];
    var $128 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($127, $tc);
    HEAP32[$11 + 32 >> 2] = $128;
    if (($128 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $_c3 = HEAP32[$opn + 36 >> 2];
    HEAP32[$11 + 36 >> 2] = $_c3;
    var $137 = HEAP32[$opn + 40 >> 2];
    HEAP32[$11 + 40 >> 2] = $137;
    __label__ = 31;
    break;
   case 23:
    var $142 = $11 + 32 | 0;
    var $143 = $opn + 32 | 0;
    HEAP32[$142 >> 2] = HEAP32[$143 >> 2];
    HEAP32[$142 + 4 >> 2] = HEAP32[$143 + 4 >> 2];
    HEAP32[$142 + 8 >> 2] = HEAP32[$143 + 8 >> 2];
    HEAP32[$142 + 12 >> 2] = HEAP32[$143 + 12 >> 2];
    var $144 = __ZNK11JSParseNode6isUsedEv($opn);
    if ($144) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $148 = HEAP32[$11 + 36 >> 2] + 28 | 0;
    var $149 = HEAP32[$148 >> 2];
    HEAP32[$11 + 28 >> 2] = $149;
    HEAP32[$148 >> 2] = $11;
    __label__ = 31;
    break;
   case 25:
    var $153 = HEAP32[$opn + 36 >> 2];
    if (($153 | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $156 = $153;
    var $157 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($156, $tc);
    var $_c2 = $157;
    HEAP32[$11 + 36 >> 2] = $_c2;
    if (($157 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $161 = __ZNK11JSParseNode6isDefnEv($opn);
    if ($161) {
      __label__ = 28;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 28:
    __ZN11JSParseNode7setDefnEb($opn, 0);
    var $163 = $11;
    __ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext($opn, $163);
    __label__ = 31;
    break;
   case 29:
    var $_c = HEAP32[$opn + 32 >> 2];
    HEAP32[$11 + 32 >> 2] = $_c;
    var $171 = HEAP32[$opn + 36 >> 2];
    var $172 = __ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext($171, $tc);
    var $_c1 = $172;
    HEAP32[$11 + 36 >> 2] = $_c1;
    if (($172 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $178 = $11 + 32 | 0;
    var $179 = $opn + 32 | 0;
    HEAP32[$178 >> 2] = HEAP32[$179 >> 2];
    HEAP32[$178 + 4 >> 2] = HEAP32[$179 + 4 >> 2];
    HEAP32[$178 + 8 >> 2] = HEAP32[$179 + 8 >> 2];
    HEAP32[$178 + 12 >> 2] = HEAP32[$179 + 12 >> 2];
    __label__ = 31;
    break;
   case 31:
    var $_0 = $11;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext($type, $op, $pos, $left, $right, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext(2, $type, $op, $pos, $tc);
    var $2 = $1;
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 32 >> 2] = $left;
    HEAP32[$1 + 36 >> 2] = $right;
    __label__ = 3;
    break;
   case 3:
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9AtomDecls6removeEP6JSAtom($this, $atom) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $atom;
    var $3 = $this + 4 | 0;
    var $4 = HEAP32[$3 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_($p, $4, $1);
    var $5 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev($p);
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv($p);
    var $9 = $8;
    var $10 = __ZNK2js12DefnOrHeader8isHeaderEv($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$3 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($12, $p);
    __label__ = 7;
    break;
   case 4:
    var $14 = __ZNK2js12DefnOrHeader6headerEv($9);
    var $16 = HEAP32[$14 + 4 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $2;
    __ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE($19, $16);
    var $21 = HEAP32[$2 >> 2];
    HEAP32[$8 >> 2] = $21;
    __label__ = 7;
    break;
   case 6:
    var $24 = HEAP32[$3 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($24, $p);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 12;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$p + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$p + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP8[$p + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$p + 4 >> 2] | 0;
    HEAP32[$9 >> 2] = 0;
    var $10 = $this + 4 | 0;
    var $12 = HEAP32[$10 >> 2] - 1 | 0;
    HEAP32[$10 >> 2] = $12;
    __label__ = 4;
    break;
   case 3:
    var $14 = $this + 200 | 0;
    var $16 = HEAP32[$p >> 2];
    HEAP32[$1 >> 2] = $16;
    __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($14, $1);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this;
    var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi($3, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  var $4 = $1;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($4);
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  var $4 = $1;
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev($4);
  __ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream7FlaggerC1EPS0_j($this, $parent, $withFlags) {
  __ZN2js11TokenStream7FlaggerC2EPS0_j($this, $parent, $withFlags);
  return;
}

function __ZN2js11TokenStream7FlaggerD1Ev($this) {
  __ZN2js11TokenStream7FlaggerD2Ev($this);
  return;
}

function __ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext($cx, $data, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$pn + 32 >> 2];
    if (($3 | 0) == (HEAP32[HEAP32[$cx + 52 >> 2] + 210176 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = $tc | 0;
    var $13 = HEAP32[$11 >> 2] | 256;
    HEAP32[$11 >> 2] = $13;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$data >> 2] = $pn;
    var $17 = HEAP32[$data + 8 >> 2];
    var $18 = FUNCTION_TABLE[$17]($cx, $data, $3, $tc);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $pn + 44 | 0;
    if ((HEAP32[$22 >> 2] & 512 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $27 = __ZNK11JSParseNode4isOpE4JSOp($pn, 9);
    var $28 = $27 ? 111 : 87;
    __ZN11JSParseNode5setOpE4JSOp($pn, $28);
    var $_pre_phi = $data + 4 | 0;
    __label__ = 7;
    break;
   case 6:
    var $30 = $data + 4 | 0;
    var $33 = (HEAP32[$30 >> 2] | 0) == 128 ? 14 : 111;
    __ZN11JSParseNode5setOpE4JSOp($pn, $33);
    var $_pre_phi = $30;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    if ((HEAP32[$_pre_phi >> 2] | 0) == 128) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = HEAP32[$22 >> 2] | 2;
    HEAP32[$22 >> 2] = $39;
    __label__ = 9;
    break;
   case 9:
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 4);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext["X"] = 1;

function __ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext($cx, $pn, $tc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 29) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 22 || ($1 | 0) == 23) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 27) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    __ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 8);
    __label__ = 3;
    break;
   case 3:
    var $4 = __ZNK11JSParseNode5getOpEv($pn);
    if ((HEAP32[_js_CodeSpec + ($4 << 3) + 4 >> 2] & 256 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    __ZN11JSParseNode5setOpE4JSOp($pn, 111);
    __label__ = 9;
    break;
   case 5:
    var $11 = __ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj($cx, $pn, $tc, 129);
    if ($11) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $13 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN11JSParseNode5setOpE4JSOp($pn, 172);
    __label__ = 9;
    break;
   case 8:
    var $18 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $19 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $18, $pn, 0, 129, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GlobalScope9GlobalDefC1Ej($this, $knownSlot) {
  __ZN2js11GlobalScope9GlobalDefC2Ej($this, $knownSlot);
  return;
}

function __ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox($this, $atom, $box) {
  __ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox($this, $atom, $box);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __stackBase__ = STACKTOP;
  var tempParam = $t;
  $t = STACKTOP;
  STACKTOP += 12;
  HEAP32[$t >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$t + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  HEAP32[$t + 8 >> 2] = HEAP32[tempParam + 8 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = $t;
    HEAP32[$4 >> 2] = HEAP32[$5 >> 2];
    HEAP32[$4 + 4 >> 2] = HEAP32[$5 + 4 >> 2];
    HEAP32[$4 + 8 >> 2] = HEAP32[$5 + 8 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7 = $this + 8 | 0;
    var $9 = HEAP32[$7 >> 2] + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj192EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 * 12 | 0;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 134217727) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 134217727) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $v | 0;
    var $3 = $newcap * 12 | 0;
    var $4 = __ZN2js15TempAllocPolicy7malloc_Ej($2, $3);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($v);
    var $9 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($8 | 0) == ($9 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $5;
      var $src_02 = $8;
      __label__ = 3;
      break;
    }
   case 3:
    var $src_02;
    var $dst_01;
    if (($dst_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_($1, $src_02);
    var $13 = __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($1);
    var $14 = $dst_01;
    var $15 = $13;
    HEAP32[$14 >> 2] = HEAP32[$15 >> 2];
    HEAP32[$14 + 4 >> 2] = HEAP32[$15 + 4 >> 2];
    HEAP32[$14 + 8 >> 2] = HEAP32[$15 + 8 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $17 = $dst_01 + 12 | 0;
    var $18 = $src_02 + 12 | 0;
    var $19 = __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv($v);
    if (($18 | 0) == ($19 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $dst_01 = $17;
      var $src_02 = $18;
      __label__ = 3;
      break;
    }
   case 6:
    var $21 = $v + 4 | 0;
    var $23 = HEAP32[$21 >> 2];
    __ZN2js15TempAllocPolicy5free_EPv(undef, $23);
    HEAP32[$21 >> 2] = $5;
    HEAP32[$v + 12 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_($this, $t);
  return;
}

function __ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    if (($_02 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_($1, $p_01);
    var $5 = __ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev($1);
    var $6 = $_02;
    var $7 = $5;
    HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
    HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
    HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $9 = $p_01 + 12 | 0;
    if (($9 | 0) == ($srcend | 0)) {
      __label__ = 5;
      break;
    } else {
      var $p_01 = $9;
      var $_02 = $_02 + 12 | 0;
      __label__ = 2;
      break;
    }
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_($agg_result, $t) {
  __ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js11NameSetNode6createEP13JSTreeContext($tc) {
  var $1 = __ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext(7, $tc);
  return $1;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0);
    __label__ = 4;
    break;
   case 3:
    var $9 = $this | 0;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($9);
    var $12 = $10;
    __label__ = 4;
    break;
   case 4:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this) {
  return (HEAP8[$this + 16 | 0] & 1) << 24 >> 24 != 0;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $begin) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 12 >> 2];
    var $newCur_0 = $begin;
    __label__ = 2;
    break;
   case 2:
    var $newCur_0;
    if ($newCur_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$newCur_0 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $newCur_0 = $newCur_0 + 8 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$this + 8 >> 2] = $newCur_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_($this, $key, $value) {
  HEAP32[$this >> 2] = $key;
  HEAP32[$this + 4 >> 2] = $value;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js12DefnOrHeaderC2EP12JSDefinition($this, $defn) {
  HEAP32[$this >> 2] = $defn;
  return;
}

function __ZN2js11TokenStream17mungeCurrentTokenE4JSOp($this, $newOp) {
  var $3 = $this + 4 + (HEAP32[$this + 132 >> 2] << 5) + 24 | 0;
  HEAP32[$3 >> 2] = $newOp;
  return;
}

function __ZN8BindDataC2Ev($this) {
  HEAP8[$this + 16 | 0] = 1;
  return;
}

function __ZN18JSFunctionBoxQueue6lengthEv($this) {
  return HEAP32[$this + 12 >> 2] + 1 | 0;
}

function __ZN18JSFunctionBoxQueueC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIbEcvRbEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIbEC2ERb($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP8[$this + 4 | 0] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv($agg_result, $this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$this + 8 >> 2];
    var $5 = $4 | 0;
    var $6 = $4 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($agg_result, $5, $6);
    __label__ = 4;
    break;
   case 3:
    var $8 = $this | 0;
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv($8);
    var $10 = $9 | 0;
    var $11 = $9 + 4 | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($agg_result, $10, $11);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv($this);
    __label__ = 4;
    break;
   case 3:
    var $4 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($4);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv($this) {
  var $3 = HEAP32[$this + 8 >> 2] + 8 | 0;
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $3);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($5);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_($this, $key, $value) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_($this, $key, $value);
  return;
}

function __ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE($this, $decls) {
  var $1 = $this | 0;
  __ZN2js9AtomDecls3allEv($1, $decls);
  HEAP32[$this + 20 >> 2] = 0;
  return;
}

function __ZN2js9AtomDecls3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 4 >> 2];
  __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv($agg_result, $2);
  return;
}

function __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv($agg_result, $this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this;
    var $3 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 200 | 0;
    __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($1, $5);
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($agg_result, $1);
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 8 | 0;
    var $10 = $this + 8 + (HEAP32[$this >> 2] << 3) | 0;
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_($agg_result, $7, $10);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r) {
  var __stackBase__ = STACKTOP;
  var tempParam = $r;
  $r = STACKTOP;
  STACKTOP += 8;
  HEAP32[$r >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$r + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $1);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_($this, $begin, $end_) {
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_($this, $begin, $end_);
  return;
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_($this, $begin, $end_) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = $begin;
  HEAP32[$this + 12 >> 2] = $end_;
  HEAP8[$this + 16 | 0] = 1;
  __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE($this, $begin);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 12 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv($4);
    if ($8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $4 + 12 | 0;
    HEAP32[$1 >> 2] = $10;
    var $4 = $10;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE($this, $r) {
  var __stackBase__ = STACKTOP;
  var tempParam = $r;
  $r = STACKTOP;
  STACKTOP += 8;
  HEAP32[$r >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$r + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev($1);
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP8[$this + 16 | 0] = 0;
  var $5 = $r;
  var $6 = $this;
  var $7$0 = HEAP32[$5 >> 2];
  var $7$1 = HEAP32[$5 + 4 >> 2];
  HEAP32[$6 >> 2] = $7$0;
  HEAP32[$6 + 4 >> 2] = $7$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition($this, $atom, $defn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 24;
    HEAP32[$1 >> 2] = $atom;
    var $4 = $this + 4 | 0;
    var $6 = HEAP32[$4 >> 2];
    __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_($p, $6, $1);
    var $7 = __ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev($p);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv($p);
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($2, $defn);
    var $12 = HEAP32[$2 >> 2];
    HEAP32[$10 >> 2] = $12;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $15 = HEAP32[$4 >> 2];
    __ZN2js12DefnOrHeaderC1EP12JSDefinition($3, $defn);
    var $16 = $15;
    var $17 = $3;
    var $18 = __ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_($16, $p, $1, $17);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12DefnOrHeaderC1EP12JSDefinition($this, $defn) {
  __ZN2js12DefnOrHeaderC2EP12JSDefinition($this, $defn);
  return;
}

function __ZN12JSDefinition13isBindingFormEv($this) {
  var $1 = __ZN12JSDefinition4kindEv($this);
  return ($1 | 0) < 3;
}

function __ZN2JSL9NullValueEv2953($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZL10MinBlockIdP11JSParseNodej($fn, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$fn + 44 >> 2] >>> 12 >>> 0 < $id >>> 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK11JSParseNode6isDefnEv($fn);
    if ($7) {
      var $fn_pn = $fn;
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 3:
    var $fn_pn;
    var $pn_0 = HEAP32[$fn_pn + 28 >> 2];
    if (($pn_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAPU32[$pn_0 + 44 >> 2] >>> 12 >>> 0 < $id >>> 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $fn_pn = $pn_0;
      __label__ = 3;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18JSFunctionBoxQueueD2Ev($this) {
  var $3 = HEAP32[$this >> 2];
  __ZN2js10Foreground5free_EPv($3);
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZL12JSID_IS_ATOMi2955($id) {
  var $1 = _JSID_IS_STRING2948($id);
  return $1;
}

function __ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj($cx, $tc, $name, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = $tc + 40 | 0;
    var $2 = __ZN2js9AtomDecls11lookupFirstEP6JSAtom($1, $name);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $3 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $name, $bytes);
    if (($3 | 0) == 0) {
      var $14 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$tc + 48 >> 2] + 40 | 0;
    var $9 = $2 | 0;
    var $10 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $11 = $tc;
    var $12 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $8, $11, $9, $errorNumber, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $10, tempInt));
    var $14 = $12;
    __label__ = 3;
    break;
   case 3:
    var $14;
    __ZN16JSAutoByteStringD1Ev($bytes);
    STACKTOP = __stackBase__;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 212,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $8 = HEAP8[$v] & 1;
    HEAP8[$5 + 4 | 0] = $8;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js15TempAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    var $12 = $this | 0;
    if ($10 >>> 0 > 16777216) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($12);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $15 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $10);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $19 = $this + 16 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $15;
    var $22 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 5;
      break;
    }
   case 5:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE($27, $1);
    __label__ = 7;
    break;
   case 7:
    var $29 = $src_01 + 12 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js15TempAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIbEENS_7MoveRefIT_EERS2_($2, $9);
  var $10 = __ZNK2js7MoveRefIbEcvRbEv($2);
  var $12 = HEAP8[$10] & 1;
  HEAP8[$this + 4 | 0] = $12;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveIbEENS_7MoveRefIT_EERS2_($agg_result, $t) {
  __ZN2js7MoveRefIbEC1ERb($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIbEC1ERb($this, $t) {
  __ZN2js7MoveRefIbEC2ERb($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIP6JSAtombEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP6JSAtombEC1Ev($this) {
  __ZN2js12HashMapEntryIP6JSAtombEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE($1);
  var $3 = __ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZL14JSID_FROM_BITSj2961($bits) {
  return $bits;
}

function __ZN2js11UpvarCookie15isLevelReservedEt($level) {
  return ($level & 65535) > 16382;
}

function _JSVAL_TO_OBJECT_IMPL3001($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_PRIMITIVE_IMPL3003($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function __ZN7mozilla14AlignedStorageILj192EE4addrEv($this) {
  return $this;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE($e) {
  return $e | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv($this) {
  return (HEAP32[$this >> 2] | 0) != 0;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL3005($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function _OBJECT_TO_JSVAL_IMPL3007($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 3:
    var $5 = $length * 171 | 0;
    var $capacity_0 = $5 >>> 0 < 2048 ? 16 : $5 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 5;
      break;
    }
   case 4:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $9 = $roundUp_01 << 1;
    var $10 = $roundUpLog2_02 + 1 | 0;
    if ($9 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $9;
      var $roundUpLog2_02 = $10;
      __label__ = 4;
      break;
    } else {
      var $roundUp_0_lcssa = $9;
      var $roundUpLog2_0_lcssa = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $12 = $this | 0;
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($12, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZL14HasFinalReturnP11JSParseNode($pn) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pn_tr = $pn;
    __label__ = 2;
    break;
   case 2:
    var $pn_tr;
    var $1 = __ZNK11JSParseNode7getKindEv($pn_tr);
    if (($1 | 0) == 25) {
      __label__ = 3;
      break;
    } else if (($1 | 0) == 35) {
      __label__ = 5;
      break;
    } else if (($1 | 0) == 40) {
      __label__ = 7;
      break;
    } else if (($1 | 0) == 41) {
      __label__ = 12;
      break;
    } else if (($1 | 0) == 42) {
      __label__ = 19;
      break;
    } else if (($1 | 0) == 37) {
      __label__ = 22;
      break;
    } else if (($1 | 0) == 47) {
      __label__ = 31;
      break;
    } else if (($1 | 0) == 6 || ($1 | 0) == 80) {
      __label__ = 32;
      break;
    } else if (($1 | 0) == 53) {
      __label__ = 33;
      break;
    } else if (($1 | 0) == 54) {
      __label__ = 38;
      break;
    } else if (($1 | 0) == 81) {
      __label__ = 39;
      break;
    } else if (($1 | 0) == 43) {
      var $_0_ph = 2;
      __label__ = 41;
      break;
    } else if (($1 | 0) == 48 || ($1 | 0) == 56) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 3:
    if ((HEAP32[$pn_tr + 32 >> 2] | 0) == 0) {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode4lastEv($pn_tr);
    var $pn_tr = $7;
    __label__ = 2;
    break;
   case 5:
    var $11 = HEAP32[$pn_tr + 40 >> 2];
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAP32[$pn_tr + 36 >> 2];
    var $17 = __ZL14HasFinalReturnP11JSParseNode($16);
    var $18 = __ZL14HasFinalReturnP11JSParseNode($11);
    return $18 & $17;
   case 7:
    var $22 = HEAP32[$pn_tr + 32 >> 2];
    var $23 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 33);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $25 = __ZNK11JSParseNode4isOpE4JSOp($22, 67);
    if ($25) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($22, 30);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = $22 + 32 | 0;
    var $31 = (tempDoubleI32[0] = HEAP32[$30 >> 2], tempDoubleI32[1] = HEAP32[$30 + 4 >> 2], tempDoubleF64[0]);
    if ($31 != 0) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $_0 = 0;
    __label__ = 43;
    break;
   case 12:
    var $35 = $pn_tr + 32 | 0;
    var $37 = HEAPU32[$pn_tr + 36 >> 2];
    var $38 = $37;
    var $39 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 33);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $41 = __ZNK11JSParseNode4isOpE4JSOp($38, 66);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $pn_tr = HEAP32[$35 >> 2];
    __label__ = 2;
    break;
   case 15:
    var $46 = __ZNK11JSParseNode4isOpE4JSOp($38, 67);
    if ($46) {
      var $_0_ph = 1;
      __label__ = 41;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($38, 30);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    }
   case 17:
    var $51 = $37 + 32 | 0;
    var $52 = (tempDoubleI32[0] = HEAP32[$51 >> 2], tempDoubleI32[1] = HEAP32[$51 + 4 >> 2], tempDoubleF64[0]);
    if ($52 == 0) {
      __label__ = 18;
      break;
    } else {
      var $_0_ph = 1;
      __label__ = 41;
      break;
    }
   case 18:
    var $pn_tr = HEAP32[$35 >> 2];
    __label__ = 2;
    break;
   case 19:
    var $59 = HEAP32[$pn_tr + 32 >> 2];
    var $60 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($59, 3);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    if ((HEAP32[$59 + 36 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = 0;
    __label__ = 43;
    break;
   case 22:
    var $69 = HEAP32[$pn_tr + 36 >> 2];
    var $70 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($69, 80);
    if ($70) {
      __label__ = 23;
      break;
    } else {
      var $pn2_0 = $69;
      __label__ = 24;
      break;
    }
   case 23:
    var $72 = __ZNK11JSParseNode4exprEv($69);
    var $pn2_0 = $72;
    __label__ = 24;
    break;
   case 24:
    var $pn2_0;
    var $pn2_14 = HEAP32[$pn2_0 + 32 >> 2];
    if (($pn2_14 | 0) == 0) {
      var $rv_0_lcssa = 1;
      var $hasDefault_0_lcssa = 0;
      __label__ = 30;
      break;
    } else {
      var $rv_05 = 1;
      var $hasDefault_06 = 0;
      var $pn2_17 = $pn2_14;
      __label__ = 25;
      break;
    }
   case 25:
    var $pn2_17;
    var $hasDefault_06;
    var $rv_05;
    var $76 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_17, 39);
    var $hasDefault_1 = $76 ? 1 : $hasDefault_06;
    var $78 = HEAP32[$pn2_17 + 36 >> 2];
    if ((HEAP32[$78 + 32 >> 2] | 0) == 0) {
      var $rv_1 = $rv_05;
      __label__ = 29;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $83 = $78;
    var $84 = __ZNK11JSParseNode4lastEv($83);
    var $85 = __ZL14HasFinalReturnP11JSParseNode($84);
    if (($85 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    if ((HEAP32[$pn2_17 + 24 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      var $rv_1 = $rv_05;
      __label__ = 29;
      break;
    }
   case 28:
    var $rv_1 = $85 & $rv_05;
    __label__ = 29;
    break;
   case 29:
    var $rv_1;
    var $pn2_1 = HEAP32[$pn2_17 + 24 >> 2];
    if (($rv_1 | 0) == 0 | ($pn2_1 | 0) == 0) {
      var $rv_0_lcssa = $rv_1;
      var $hasDefault_0_lcssa = $hasDefault_1;
      __label__ = 30;
      break;
    } else {
      var $rv_05 = $rv_1;
      var $hasDefault_06 = $hasDefault_1;
      var $pn2_17 = $pn2_1;
      __label__ = 25;
      break;
    }
   case 30:
    var $hasDefault_0_lcssa;
    var $rv_0_lcssa;
    var $_0 = $hasDefault_0_lcssa & $rv_0_lcssa;
    __label__ = 43;
    break;
   case 31:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 32:
    var $102 = __ZNK11JSParseNode4exprEv($pn_tr);
    var $pn_tr = $102;
    __label__ = 2;
    break;
   case 33:
    var $106 = HEAP32[$pn_tr + 40 >> 2];
    if (($106 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $109 = __ZL14HasFinalReturnP11JSParseNode($106);
    if (($109 | 0) == 1) {
      var $_0 = 1;
      __label__ = 43;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $113 = HEAP32[$pn_tr + 32 >> 2];
    var $114 = __ZL14HasFinalReturnP11JSParseNode($113);
    var $116 = HEAP32[$pn_tr + 36 >> 2];
    if (($116 | 0) == 0) {
      var $_0 = $114;
      __label__ = 43;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $pn2_21 = HEAP32[$116 + 32 >> 2];
    if (($pn2_21 | 0) == 0) {
      var $_0 = $114;
      __label__ = 43;
      break;
    } else {
      var $rv_22 = $114;
      var $pn2_23 = $pn2_21;
      __label__ = 37;
      break;
    }
   case 37:
    var $pn2_23;
    var $rv_22;
    var $121 = __ZL14HasFinalReturnP11JSParseNode($pn2_23);
    var $122 = $121 & $rv_22;
    var $pn2_2 = HEAP32[$pn2_23 + 24 >> 2];
    if (($pn2_2 | 0) == 0) {
      var $_0 = $122;
      __label__ = 43;
      break;
    } else {
      var $rv_22 = $122;
      var $pn2_23 = $pn2_2;
      __label__ = 37;
      break;
    }
   case 38:
    var $pn_tr = HEAP32[$pn_tr + 40 >> 2];
    __label__ = 2;
    break;
   case 39:
    var $130 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn_tr, 2);
    if ($130) {
      __label__ = 40;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 41;
      break;
    }
   case 40:
    var $pn_tr = HEAP32[$pn_tr + 36 >> 2];
    __label__ = 2;
    break;
   case 41:
    var $_0_ph;
    var $_0 = $_0_ph;
    __label__ = 43;
    break;
   case 42:
    var $_0 = 1;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14HasFinalReturnP11JSParseNode["X"] = 1;

function __ZN2js8CompilerD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6ParserD2Ev($1);
  return;
}

function __ZN2js11GlobalScopeD2Ev($this) {
  var $1 = $this + 216 | 0;
  __ZN2js9InlineMapIP6JSAtomjLj24EED1Ev($1);
  var $2 = $this + 8 | 0;
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev($2);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator($this, $cx, $globalObj, $cg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $globalObj;
  HEAP32[$this + 4 >> 2] = $cg;
  var $4 = $this + 8 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_($4, $1);
  var $5 = $this + 216 | 0;
  __ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext($5, $cx);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj192EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 16;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_($p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc2912();
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js12ParseMapPoolC1EP9JSContext($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12ParseMapPoolC1EP9JSContext($this, $cx) {
  __ZN2js12ParseMapPoolC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js12ParseMapPoolC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = $this | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($3, $1);
  var $4 = $this + 140 | 0;
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($4, $2);
  HEAP32[$this + 280 >> 2] = $cx;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 32;
  STACKTOP = __stackBase__;
  return;
}

function __ZL8pm_startP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
  return ($2 | 0) != 0 & 1;
}

function __ZL7pm_stopP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
  return ($2 | 0) != 0 & 1;
}

function __ZL8pm_resetP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS15PerfMeasurement5resetEv($2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE($cx, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $3 = __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _BOOLEAN_TO_JSVAL3010($2);
    var $6 = $2 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11pm_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $1 = $obj;
  var $2 = _JS_GetPrivate(undef, $1);
  var $3 = $2;
  __ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_($cx, $3);
  return;
}

function __ZN2JS23RegisterPerfMeasurementEP9JSContextP8JSObject($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = $global;
    var $4 = _JS_InitClass($2, $3, 0, __ZL8pm_class, 214, 1, __ZL8pm_props, __ZL6pm_fns, 0, 0);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = _JS_GetConstructor($2, $4);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $c_0 = __ZL9pm_consts | 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $c_0;
    var $11 = HEAP32[$c_0 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$c_0 + 4 >> 2];
    _INT_TO_JSVAL2997($1, $15);
    var $16 = _JS_DefineProperty($2, $8, $11, $1, 10, 12, 7);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $c_0 = $c_0 + 8 | 0;
    __label__ = 3;
    break;
   case 6:
    var $21 = _JS_FreezeObject($2, $4);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = _JS_FreezeObject($2, $8);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = $5;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12pm_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $mask = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $vp + 16 | 0;
    var $3 = $cx;
    var $4 = _JS_ConvertArguments($3, $argc, $2, STRING_TABLE.__str302996 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $mask, tempInt));
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = _JS_NewObjectForConstructor($3, $vp);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_FreezeObject($3, $7);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_($cx, undef);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportOutOfMemory($3);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $18 = $14;
    var $19 = _JS_SetPrivate(undef, $7, $18);
    _OBJECT_TO_JSVAL3006($1, $8);
    var $20 = $1 | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $vp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _INT_TO_JSVAL2997($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL3005($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JS22ExtractPerfMeasurementENS_5ValueE($0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $2 = _JSVAL_IS_PRIMITIVE2998($tmp$0, $tmp$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = _JSVAL_TO_OBJECT2999($tmp$0, $tmp$1);
    var $6 = $5;
    var $7 = __ZNK8JSObject8getClassEv($6);
    if (($7 | 0) == (__ZL8pm_class | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = __ZNK8JSObject10getPrivateEv($6);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE2998($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL3003($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT2999($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3002($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL3001($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str182984 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str192985 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 16 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str202986 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 24 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str212987 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 32 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str222988 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 40 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str232989 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 48 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str242990 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 56 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str252991 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 64 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str262992 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 72 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str272993 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 80 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str282994 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 88 | 0;
    var $7 = HEAP32[$5 >> 2] + HEAP32[$5 + 4 >> 2] * 4294967296;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $0, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, STRING_TABLE.__str292995 | 0);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAPU32[$2 + 4 >> 2] >>> 0;
    var $8 = _JS_NewNumberValue(undef, $7, $vp);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5GetPMP9JSContextP8JSObjectPKc($cx, $obj, $fname) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $obj;
    var $3 = _JS_GetInstancePrivate($1, $2, __ZL8pm_class, 0);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[__ZL8pm_class >> 2];
    var $9 = _JS_GetClass($2);
    var $11 = HEAP32[$9 >> 2];
    _JS_ReportErrorNumber($1, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $8, HEAP32[tempInt + 4 >> 2] = $fname, HEAP32[tempInt + 8 >> 2] = $11, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 96);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2JS15PerfMeasurementC2ENS0_9EventMaskE($5, undef);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL3006($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3007($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetPMFromThisP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    _JS_THIS($1, $cx, $vp);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = _JSVAL_TO_OBJECT2999($_idx_val$0, $_idx_val$1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = $2;
    var $8 = _JS_GetInstancePrivate($6, $7, __ZL8pm_class, $5);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL_IMPL3011($agg_result) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = 0;
  return;
}

function __ZL10LimitStuffP15SprintfStateStrPKcj($ss, $sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $ss + 8 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $9 = HEAP32[$ss + 4 >> 2] - $3 + HEAP32[$ss + 12 >> 2] | 0;
    var $_0_ph = $9 >>> 0 < $len >>> 0 ? $9 : $len;
    if (($_0_ph | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_012 = $sp;
      var $_03 = $_0_ph;
      var $12 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $12;
    var $_03;
    var $_012;
    var $13 = $_03 - 1 | 0;
    var $14 = HEAP8[$_012];
    HEAP32[$2 >> 2] = $12 + 1 | 0;
    HEAP8[$12] = $14;
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_012 = $_012 + 1 | 0;
    var $_03 = $13;
    var $12 = HEAP32[$2 >> 2];
    __label__ = 2;
    break;
   case 4:
    return 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL3010($agg_result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL3011($1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3004($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JS_THIS($agg_result, $cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = _JSVAL_IS_PRIMITIVE2998($2$0, $2$1);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    _JS_ComputeThis($agg_result, $6, $vp);
    __label__ = 4;
    break;
   case 3:
    var $8$0 = HEAP32[$1 >> 2];
    var $8$1 = HEAP32[$1 + 4 >> 2];
    var $9 = $agg_result | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_sxprintf($func, $arg, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_sxprintf.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_vsxprintf($func, $arg, $fmt, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_vsxprintf($func, $arg, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var $ss = __stackBase__;
  HEAP32[$ss >> 2] = 216;
  HEAP32[$ss + 16 >> 2] = $func;
  HEAP32[$ss + 20 >> 2] = $arg;
  var $4 = $ss + 12 | 0;
  HEAP32[$4 >> 2] = 0;
  var $5 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
  var $8 = ($5 | 0) < 0 ? -1 : HEAP32[$4 >> 2];
  STACKTOP = __stackBase__;
  return $8;
}

function __ZL9FuncStuffP15SprintfStateStrPKcj($ss, $sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$ss + 16 >> 2];
    var $4 = HEAP32[$ss + 20 >> 2];
    var $5 = FUNCTION_TABLE[$2]($4, $sp, $len);
    if (($5 | 0) < 0) {
      var $_0 = $5;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $ss + 12 | 0;
    var $10 = HEAP32[$8 >> 2] + $len | 0;
    HEAP32[$8 >> 2] = $10;
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 200;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    var $rv = __stackBase__ + 8;
    var $pattern = __stackBase__ + 172;
    var $utf8buf = __stackBase__ + 192;
    var $1 = __stackBase__ + 12 | 0;
    var $2 = __ZL13BuildArgArrayPKcPcPiP11NumArgState($fmt, $ap, $rv, $1);
    var $3 = HEAPU32[$rv >> 2];
    if (($3 | 0) < 0) {
      var $_0 = $3;
      __label__ = 77;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $ss | 0;
    var $6 = ($2 | 0) != 0;
    var $7 = $u;
    var $8 = $u | 0;
    var $9 = $u;
    var $10 = $pattern | 0;
    var $11 = $pattern + 1 | 0;
    var $12 = $u;
    var $13 = $utf8buf | 0;
    var $14 = $u;
    var $15 = $u;
    var $16 = $u;
    var $17 = $u;
    var $18 = $ss + 8 | 0;
    var $19 = $ss + 4 | 0;
    var $dolPt_0 = 0;
    var $_05 = $fmt;
    var $_06 = $ap;
    var $_pr = $3;
    __label__ = 3;
    break;
   case 3:
    var $_pr;
    var $_06;
    var $_05;
    var $dolPt_0;
    var $20 = $_05 + 1 | 0;
    var $21 = HEAP8[$_05];
    if ($21 << 24 >> 24 == 37) {
      __label__ = 5;
      break;
    } else if ($21 << 24 >> 24 == 0) {
      __label__ = 75;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $23 = HEAP32[$5 >> 2];
    var $24 = FUNCTION_TABLE[$23]($ss, $_05, 1);
    HEAP32[$rv >> 2] = $24;
    if (($24 | 0) < 0) {
      var $_0 = $24;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_0;
      var $_05 = $20;
      var $_06 = $_06;
      var $_pr = $24;
      __label__ = 3;
      break;
    }
   case 5:
    var $27 = $_05 + 2 | 0;
    var $28 = HEAP8[$20];
    if ($28 << 24 >> 24 == 37) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $31 = HEAP32[$5 >> 2];
    var $32 = FUNCTION_TABLE[$31]($ss, $20, 1);
    HEAP32[$rv >> 2] = $32;
    if (($32 | 0) < 0) {
      var $_0 = $32;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_0;
      var $_05 = $27;
      var $_06 = $_06;
      var $_pr = $32;
      __label__ = 3;
      break;
    }
   case 7:
    if ($6) {
      var $_1 = $27;
      var $c_0 = $28;
      var $i_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $dolPt_1_ph = $dolPt_0;
      var $_2_ph = $27;
      var $_17_ph = $_06;
      var $c_1_ph = $28;
      __label__ = 14;
      break;
    }
   case 8:
    var $i_0;
    var $c_0;
    var $_1;
    if ($c_0 << 24 >> 24 == 36 || $c_0 << 24 >> 24 == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $39 = $i_0 * 10 - 48 + ($c_0 << 24 >> 24) | 0;
    var $41 = HEAP8[$_1];
    var $_1 = $_1 + 1 | 0;
    var $c_0 = $41;
    var $i_0 = $39;
    __label__ = 8;
    break;
   case 10:
    var $43 = $i_0 - 1 | 0;
    if ((HEAP32[$2 + ($43 << 3) >> 2] | 0) == 20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if (($2 | 0) == ($1 | 0)) {
      var $_0 = -1;
      __label__ = 77;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $50 = $2;
    __ZN2js10Foreground5free_EPv($50);
    var $_0 = -1;
    __label__ = 77;
    break;
   case 13:
    var $dolPt_1_ph = $_1;
    var $_2_ph = $_1 + 1 | 0;
    var $_17_ph = HEAP32[$2 + ($43 << 3) + 4 >> 2];
    var $c_1_ph = HEAP8[$_1];
    __label__ = 14;
    break;
   case 14:
    var $c_1_ph;
    var $_17_ph;
    var $_2_ph;
    var $dolPt_1_ph;
    var $_2 = $_2_ph;
    var $c_1 = $c_1_ph;
    var $flags_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $flags_0;
    var $c_1;
    var $_2;
    var $57 = $c_1 << 24 >> 24 == 45;
    if ($c_1 << 24 >> 24 == 48 || $c_1 << 24 >> 24 == 45 || $c_1 << 24 >> 24 == 43 || $c_1 << 24 >> 24 == 32) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $_flags_0 = $57 & 1 | $flags_0;
    var $flags_2 = $c_1 << 24 >> 24 == 43 ? $_flags_0 | 2 : $_flags_0;
    var $_flags_2 = $c_1 << 24 >> 24 == 32 ? $flags_2 | 4 : $flags_2;
    var $flags_4 = $c_1 << 24 >> 24 == 48 ? $_flags_2 | 8 : $_flags_2;
    var $66 = HEAP8[$_2];
    var $_2 = $_2 + 1 | 0;
    var $c_1 = $66;
    var $flags_0 = $flags_4;
    __label__ = 15;
    break;
   case 17:
    var $flags_0_ = ($flags_0 & 2 | 0) == 0 ? $flags_0 : $flags_0 & -5;
    var $flags_6 = ($flags_0_ & 1 | 0) == 0 ? $flags_0_ : $flags_0_ & -9;
    if ($c_1 << 24 >> 24 == 42) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($c_1 - 48 & 255 & 255) < 10) {
      var $width_044 = 0;
      var $c_245 = $c_1;
      var $_346 = $_2;
      __label__ = 20;
      break;
    } else {
      var $_4 = $_2;
      var $_28 = $_17_ph;
      var $c_3 = $c_1;
      var $width_1 = 0;
      __label__ = 21;
      break;
    }
   case 19:
    var $_4 = $_2 + 1 | 0;
    var $_28 = $_17_ph + 4 | 0;
    var $c_3 = HEAP8[$_2];
    var $width_1 = HEAP32[$_17_ph >> 2];
    __label__ = 21;
    break;
   case 20:
    var $_346;
    var $c_245;
    var $width_044;
    var $85 = $width_044 * 10 - 48 + ($c_245 << 24 >> 24) | 0;
    var $86 = $_346 + 1 | 0;
    var $87 = HEAPU8[$_346];
    if (($87 - 48 & 255 & 255) < 10) {
      var $width_044 = $85;
      var $c_245 = $87;
      var $_346 = $86;
      __label__ = 20;
      break;
    } else {
      var $_4 = $86;
      var $_28 = $_17_ph;
      var $c_3 = $87;
      var $width_1 = $85;
      __label__ = 21;
      break;
    }
   case 21:
    var $width_1;
    var $c_3;
    var $_28;
    var $_4;
    if ($c_3 << 24 >> 24 == 46) {
      __label__ = 22;
      break;
    } else {
      var $_6 = $_4;
      var $_39 = $_28;
      var $c_5 = $c_3;
      var $prec_1 = -1;
      __label__ = 26;
      break;
    }
   case 22:
    var $91 = $_4 + 1 | 0;
    var $92 = HEAPU8[$_4];
    if ($92 << 24 >> 24 == 42) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    if (($92 - 48 & 255 & 255) < 10) {
      var $prec_037 = 0;
      var $c_438 = $92;
      var $_539 = $91;
      __label__ = 25;
      break;
    } else {
      var $_6 = $91;
      var $_39 = $_28;
      var $c_5 = $92;
      var $prec_1 = 0;
      __label__ = 26;
      break;
    }
   case 24:
    var $_6 = $_4 + 2 | 0;
    var $_39 = $_28 + 4 | 0;
    var $c_5 = HEAP8[$91];
    var $prec_1 = HEAP32[$_28 >> 2];
    __label__ = 26;
    break;
   case 25:
    var $_539;
    var $c_438;
    var $prec_037;
    var $104 = $prec_037 * 10 - 48 + ($c_438 << 24 >> 24) | 0;
    var $105 = $_539 + 1 | 0;
    var $106 = HEAPU8[$_539];
    if (($106 - 48 & 255 & 255) < 10) {
      var $prec_037 = $104;
      var $c_438 = $106;
      var $_539 = $105;
      __label__ = 25;
      break;
    } else {
      var $_6 = $105;
      var $_39 = $_28;
      var $c_5 = $106;
      var $prec_1 = $104;
      __label__ = 26;
      break;
    }
   case 26:
    var $prec_1;
    var $c_5;
    var $_39;
    var $_6;
    if ($c_5 << 24 >> 24 == 104) {
      __label__ = 27;
      break;
    } else if ($c_5 << 24 >> 24 == 76) {
      __label__ = 28;
      break;
    } else if ($c_5 << 24 >> 24 == 108) {
      __label__ = 29;
      break;
    } else {
      var $_7 = $_6;
      var $c_6 = $c_5;
      var $type_0 = 2;
      __label__ = 31;
      break;
    }
   case 27:
    var $_7 = $_6 + 1 | 0;
    var $c_6 = HEAP8[$_6];
    var $type_0 = 0;
    __label__ = 31;
    break;
   case 28:
    var $_7 = $_6 + 1 | 0;
    var $c_6 = HEAP8[$_6];
    var $type_0 = 6;
    __label__ = 31;
    break;
   case 29:
    var $115 = $_6 + 1 | 0;
    var $116 = HEAP8[$_6];
    if ($116 << 24 >> 24 == 108) {
      __label__ = 30;
      break;
    } else {
      var $_7 = $115;
      var $c_6 = $116;
      var $type_0 = 4;
      __label__ = 31;
      break;
    }
   case 30:
    var $_7 = $_6 + 2 | 0;
    var $c_6 = HEAP8[$115];
    var $type_0 = 6;
    __label__ = 31;
    break;
   case 31:
    var $type_0;
    var $c_6;
    var $_7;
    var $122 = $c_6 << 24 >> 24;
    if (($122 | 0) == 111) {
      __label__ = 32;
      break;
    } else if (($122 | 0) == 117) {
      __label__ = 33;
      break;
    } else if (($122 | 0) == 120) {
      __label__ = 34;
      break;
    } else if (($122 | 0) == 88) {
      __label__ = 35;
      break;
    } else if (($122 | 0) == 100 || ($122 | 0) == 105) {
      var $radix_0 = 10;
      var $type_1 = $type_0;
      var $hexp_0 = STRING_TABLE.__str62084 | 0;
      __label__ = 36;
      break;
    } else if (($122 | 0) == 112) {
      var $hexp_021 = STRING_TABLE.__str62084 | 0;
      var $radix_025 = 16;
      __label__ = 45;
      break;
    } else if (($122 | 0) == 101 || ($122 | 0) == 69 || ($122 | 0) == 102 || ($122 | 0) == 103) {
      __label__ = 51;
      break;
    } else if (($122 | 0) == 99) {
      __label__ = 56;
      break;
    } else if (($122 | 0) == 115) {
      __label__ = 67;
      break;
    } else if (($122 | 0) == 110) {
      __label__ = 71;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 32:
    var $radix_0 = 8;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 33:
    var $radix_0 = 10;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 34:
    var $radix_0 = 16;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__str62084 | 0;
    __label__ = 36;
    break;
   case 35:
    var $radix_0 = 16;
    var $type_1 = $type_0 | 1;
    var $hexp_0 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits | 0;
    __label__ = 36;
    break;
   case 36:
    var $hexp_0;
    var $type_1;
    var $radix_0;
    if (($type_1 | 0) == 0) {
      __label__ = 37;
      break;
    } else if (($type_1 | 0) == 1) {
      __label__ = 39;
      break;
    } else if (($type_1 | 0) == 2) {
      __label__ = 40;
      break;
    } else if (($type_1 | 0) == 3) {
      __label__ = 42;
      break;
    } else if (($type_1 | 0) == 4) {
      __label__ = 43;
      break;
    } else if (($type_1 | 0) == 5) {
      var $hexp_021 = $hexp_0;
      var $radix_025 = $radix_0;
      __label__ = 45;
      break;
    } else if (($type_1 | 0) == 6) {
      __label__ = 47;
      break;
    } else if (($type_1 | 0) == 7) {
      __label__ = 49;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39;
      var $_pr = $_pr;
      __label__ = 3;
      break;
    }
   case 37:
    var $134 = $_39 + 4 | 0;
    var $135 = HEAPU32[$_39 >> 2];
    HEAP32[$7 >> 2] = $135;
    if (($135 | 0) < 0) {
      __label__ = 38;
      break;
    } else {
      var $_410 = $134;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 0;
      var $radix_024 = $radix_0;
      var $169 = $135;
      __label__ = 46;
      break;
    }
   case 38:
    var $138 = -$135 | 0;
    HEAP32[$7 >> 2] = $138;
    var $_410 = $134;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $138;
    __label__ = 46;
    break;
   case 39:
    var $144 = HEAP32[$_39 >> 2] & 65535;
    HEAP32[$7 >> 2] = $144;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_0;
    var $type_122 = 1;
    var $radix_024 = $radix_0;
    var $169 = $144;
    __label__ = 46;
    break;
   case 40:
    var $147 = $_39 + 4 | 0;
    var $148 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $148;
    if (($148 | 0) < 0) {
      __label__ = 41;
      break;
    } else {
      var $_410 = $147;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 2;
      var $radix_024 = $radix_0;
      var $169 = $148;
      __label__ = 46;
      break;
    }
   case 41:
    var $151 = -$148 | 0;
    HEAP32[$7 >> 2] = $151;
    var $_410 = $147;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $151;
    __label__ = 46;
    break;
   case 42:
    var $156 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $156;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_0;
    var $type_122 = 3;
    var $radix_024 = $radix_0;
    var $169 = $156;
    __label__ = 46;
    break;
   case 43:
    var $159 = $_39 + 4 | 0;
    var $160 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $160;
    if (($160 | 0) < 0) {
      __label__ = 44;
      break;
    } else {
      var $_410 = $159;
      var $flags_7 = $flags_6;
      var $hexp_020 = $hexp_0;
      var $type_122 = 4;
      var $radix_024 = $radix_0;
      var $169 = $160;
      __label__ = 46;
      break;
    }
   case 44:
    var $163 = -$160 | 0;
    HEAP32[$7 >> 2] = $163;
    var $_410 = $159;
    var $flags_7 = $flags_6 | 16;
    var $hexp_020 = $hexp_0;
    var $type_122 = $type_1;
    var $radix_024 = $radix_0;
    var $169 = $163;
    __label__ = 46;
    break;
   case 45:
    var $radix_025;
    var $hexp_021;
    var $167 = HEAP32[$_39 >> 2];
    HEAP32[$7 >> 2] = $167;
    var $_410 = $_39 + 4 | 0;
    var $flags_7 = $flags_6;
    var $hexp_020 = $hexp_021;
    var $type_122 = 5;
    var $radix_024 = $radix_025;
    var $169 = $167;
    __label__ = 46;
    break;
   case 46:
    var $169;
    var $radix_024;
    var $type_122;
    var $hexp_020;
    var $flags_7;
    var $_410;
    var $170 = __ZL5cvt_lP15SprintfStateStrliiiiiPKc($ss, $169, $width_1, $prec_1, $radix_024, $type_122, $flags_7, $hexp_020);
    HEAP32[$rv >> 2] = $170;
    if (($170 | 0) < 0) {
      var $_0 = $170;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_410;
      var $_pr = $170;
      __label__ = 3;
      break;
    }
   case 47:
    var $173 = $_39;
    var $174 = $_39 + 8 | 0;
    var $st$2$0 = $173 | 0;
    var $175$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $173 + 4 | 0;
    var $175$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $175$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $175$1;
    var $$emscripten$temp$0$1 = 0;
    if (($175$1 | 0) < ($$emscripten$temp$0$1 | 0) || ($175$1 | 0) == ($$emscripten$temp$0$1 | 0) && $175$0 >>> 0 < 0 >>> 0) {
      __label__ = 48;
      break;
    } else {
      var $_511 = $174;
      var $flags_8 = $flags_6;
      var $185$1 = $175$1;
      var $185$0 = $175$0;
      __label__ = 50;
      break;
    }
   case 48:
    var $178$0 = (i64Math.subtract(0, 0, $175$0, $175$1), i64Math.result[0]);
    var $178$1 = i64Math.result[1];
    HEAP32[$8 >> 2] = $178$0;
    HEAP32[$8 + 4 >> 2] = $178$1;
    var $_511 = $174;
    var $flags_8 = $flags_6 | 16;
    var $185$1 = $178$1;
    var $185$0 = $178$0;
    __label__ = 50;
    break;
   case 49:
    var $181 = $_39;
    var $st$2$0 = $181 | 0;
    var $183$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $181 + 4 | 0;
    var $183$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $183$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $183$1;
    var $_511 = $_39 + 8 | 0;
    var $flags_8 = $flags_6;
    var $185$1 = $183$1;
    var $185$0 = $183$0;
    __label__ = 50;
    break;
   case 50:
    var $185$0;
    var $185$1;
    var $flags_8;
    var $_511;
    var $186 = __ZL6cvt_llP15SprintfStateStrxiiiiiPKc($ss, $185$0, $185$1, $width_1, $prec_1, $radix_0, $type_1, $flags_8, $hexp_0);
    HEAP32[$rv >> 2] = $186;
    if (($186 | 0) < 0) {
      var $_0 = $186;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_511;
      var $_pr = $186;
      __label__ = 3;
      break;
    }
   case 51:
    var $189 = $_39;
    var $190 = $_39 + 8 | 0;
    var $191 = (tempDoubleI32[0] = HEAP32[$189 >> 2], tempDoubleI32[1] = HEAP32[$189 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $191, HEAP32[$9 >> 2] = tempDoubleI32[0], HEAP32[$9 + 4 >> 2] = tempDoubleI32[1];
    if ($6) {
      __label__ = 52;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 52:
    var $195 = $_7 - $dolPt_1_ph | 0;
    if (($195 | 0) < 20) {
      __label__ = 53;
      break;
    } else {
      var $203 = $_pr;
      __label__ = 55;
      break;
    }
   case 53:
    HEAP8[$10] = 37;
    _memcpy($11, $dolPt_1_ph, $195, 1);
    var $199 = $195 + ($pattern + 1) | 0;
    var $200 = __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $191, $10, $199);
    HEAP32[$rv >> 2] = $200;
    var $203 = $200;
    __label__ = 55;
    break;
   case 54:
    var $202 = __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $191, $_05, $_7);
    HEAP32[$rv >> 2] = $202;
    var $203 = $202;
    __label__ = 55;
    break;
   case 55:
    var $203;
    if (($203 | 0) < 0) {
      var $_0 = $203;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $190;
      var $_pr = $203;
      __label__ = 3;
      break;
    }
   case 56:
    var $207 = ($flags_6 & 1 | 0) == 0;
    if ($207) {
      var $width_2 = $width_1;
      var $_pr277 = $_pr;
      __label__ = 57;
      break;
    } else {
      var $width_3 = $width_1;
      var $_pr27 = $_pr;
      __label__ = 59;
      break;
    }
   case 57:
    var $_pr277;
    var $width_2;
    var $208 = $width_2 - 1 | 0;
    if (($width_2 | 0) > 1) {
      __label__ = 58;
      break;
    } else {
      var $width_3 = $208;
      var $_pr27 = $_pr277;
      __label__ = 59;
      break;
    }
   case 58:
    var $211 = HEAP32[$5 >> 2];
    var $212 = FUNCTION_TABLE[$211]($ss, STRING_TABLE._js_space_str | 0, 1);
    HEAP32[$rv >> 2] = $212;
    if (($212 | 0) < 0) {
      var $_0 = $212;
      __label__ = 77;
      break;
    } else {
      var $width_2 = $208;
      var $_pr277 = $212;
      __label__ = 57;
      break;
    }
   case 59:
    var $_pr27;
    var $width_3;
    if (($type_0 | 0) == 0) {
      __label__ = 60;
      break;
    } else if (($type_0 | 0) == 2) {
      __label__ = 62;
      break;
    } else {
      var $_612 = $_39;
      var $233 = $_pr27;
      __label__ = 63;
      break;
    }
   case 60:
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $219 = $_39 + 4 | 0;
    var $220 = HEAP32[$_39 >> 2];
    HEAP16[$12 >> 1] = $220 & 65535;
    var $222 = $220 & 65535;
    var $223 = __Z20js_OneUcs4ToUtf8CharPhj($13, $222);
    var $224 = HEAP32[$5 >> 2];
    var $225 = FUNCTION_TABLE[$224]($ss, $13, $223);
    HEAP32[$rv >> 2] = $225;
    var $_612 = $219;
    var $233 = $225;
    __label__ = 63;
    break;
   case 62:
    var $228 = $_39 + 4 | 0;
    HEAP8[$14] = HEAP32[$_39 >> 2] & 255;
    var $231 = HEAP32[$5 >> 2];
    var $232 = FUNCTION_TABLE[$231]($ss, $14, 1);
    HEAP32[$rv >> 2] = $232;
    var $_612 = $228;
    var $233 = $232;
    __label__ = 63;
    break;
   case 63:
    var $233;
    var $_612;
    if (($233 | 0) < 0) {
      var $_0 = $233;
      __label__ = 77;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($207) {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_612;
      var $_pr = $233;
      __label__ = 3;
      break;
    } else {
      var $width_4 = $width_3;
      var $_pr5 = $233;
      __label__ = 65;
      break;
    }
   case 65:
    var $_pr5;
    var $width_4;
    if (($width_4 | 0) > 1) {
      __label__ = 66;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_612;
      var $_pr = $_pr5;
      __label__ = 3;
      break;
    }
   case 66:
    var $238 = $width_4 - 1 | 0;
    var $239 = HEAP32[$5 >> 2];
    var $240 = FUNCTION_TABLE[$239]($ss, STRING_TABLE._js_space_str | 0, 1);
    HEAP32[$rv >> 2] = $240;
    if (($240 | 0) < 0) {
      var $_0 = $240;
      __label__ = 77;
      break;
    } else {
      var $width_4 = $238;
      var $_pr5 = $240;
      __label__ = 65;
      break;
    }
   case 67:
    if (($type_0 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 68:
    var $246 = HEAP32[$_39 >> 2];
    HEAP32[$15 >> 2] = $246;
    var $247 = __ZL6cvt_wsP15SprintfStateStrPKtiii($ss, $246, $width_1, $prec_1, $flags_6);
    var $storemerge = $247;
    __label__ = 70;
    break;
   case 69:
    var $250 = HEAP32[$_39 >> 2];
    HEAP32[$16 >> 2] = $250;
    var $251 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, $250, $width_1, $prec_1, $flags_6);
    var $storemerge = $251;
    __label__ = 70;
    break;
   case 70:
    var $storemerge;
    HEAP32[$rv >> 2] = $storemerge;
    if (($storemerge | 0) < 0) {
      var $_0 = $storemerge;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39 + 4 | 0;
      var $_pr = $storemerge;
      __label__ = 3;
      break;
    }
   case 71:
    var $256 = $_39 + 4 | 0;
    var $257 = HEAP32[$_39 >> 2];
    HEAP32[$17 >> 2] = $257;
    if (($257 | 0) == 0) {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $256;
      var $_pr = $_pr;
      __label__ = 3;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $264 = HEAP32[$18 >> 2] - HEAP32[$19 >> 2] | 0;
    HEAP32[$257 >> 2] = $264;
    var $dolPt_0 = $dolPt_1_ph;
    var $_05 = $_7;
    var $_06 = $256;
    var $_pr = $_pr;
    __label__ = 3;
    break;
   case 73:
    var $266 = HEAP32[$5 >> 2];
    var $267 = FUNCTION_TABLE[$266]($ss, STRING_TABLE.__str273179 | 0, 1);
    HEAP32[$rv >> 2] = $267;
    if (($267 | 0) < 0) {
      var $_0 = $267;
      __label__ = 77;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $270 = HEAP32[$5 >> 2];
    var $272 = FUNCTION_TABLE[$270]($ss, $_7 - 1 | 0, 1);
    HEAP32[$rv >> 2] = $272;
    if (($272 | 0) < 0) {
      var $_0 = $272;
      __label__ = 77;
      break;
    } else {
      var $dolPt_0 = $dolPt_1_ph;
      var $_05 = $_7;
      var $_06 = $_39;
      var $_pr = $272;
      __label__ = 3;
      break;
    }
   case 75:
    var $275 = HEAP32[$5 >> 2];
    var $276 = FUNCTION_TABLE[$275]($ss, __str23014 | 0, 1);
    HEAP32[$rv >> 2] = $276;
    if (($2 | 0) == 0 | ($2 | 0) == ($1 | 0)) {
      var $_0 = $276;
      __label__ = 77;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $280 = $2;
    __ZN2js10Foreground5free_EPv($280);
    var $_0 = $276;
    __label__ = 77;
    break;
   case 77:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9dosprintfP15SprintfStateStrPKcPc["X"] = 1;

function _JS_smprintf($fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_smprintf.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_vsmprintf($fmt, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_vsmprintf($fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    HEAP32[$ss >> 2] = 218;
    var $2 = $ss + 4 | 0;
    HEAP32[$2 >> 2] = 0;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    var $5 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $7 = HEAP32[$2 >> 2];
    if (($5 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $7;
      __label__ = 4;
      break;
    }
   case 2:
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground5free_EPv($7);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_smprintf_free($mem) {
  __ZN2js10Foreground5free_EPv($mem);
  return;
}

function __ZL9GrowStuffP15SprintfStateStrPKcj($ss, $sp, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ss + 8 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = $ss + 4 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $7 = $2 - $4 | 0;
    var $9 = $ss + 12 | 0;
    var $10 = HEAPU32[$9 >> 2];
    if (($7 + $len | 0) >>> 0 < $10 >>> 0) {
      var $25 = $2;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $len >>> 0 > 32 ? $len : 32;
    var $15 = $10 + $14 | 0;
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZN2js11OffTheBooks8realloc_EPvj($4, $15);
    var $newbase_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $20 = __ZN2js11OffTheBooks7malloc_Ej($15);
    var $newbase_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $newbase_0;
    if (($newbase_0 | 0) == 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$3 >> 2] = $newbase_0;
    HEAP32[$9 >> 2] = $15;
    var $24 = $newbase_0 + $7 | 0;
    HEAP32[$1 >> 2] = $24;
    var $25 = $24;
    __label__ = 7;
    break;
   case 7:
    var $25;
    if (($len | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $_023 = $len;
      var $_014 = $sp;
      var $27 = $25;
      __label__ = 8;
      break;
    }
   case 8:
    var $27;
    var $_014;
    var $_023;
    var $28 = $_023 - 1 | 0;
    var $29 = HEAP8[$_014];
    HEAP32[$1 >> 2] = $27 + 1 | 0;
    HEAP8[$27] = $29;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_023 = $28;
    var $_014 = $_014 + 1 | 0;
    var $27 = HEAP32[$1 >> 2];
    __label__ = 8;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_snprintf($out, $outlen, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (($outlen | 0) < 1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ap >> 2] = arguments[_JS_snprintf.length];
    var $4 = HEAP32[$ap >> 2];
    var $5 = _JS_vsnprintf($out, $outlen, $fmt, $4);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_vsnprintf($out, $outlen, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    if (($outlen | 0) < 1) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$ss >> 2] = 220;
    var $4 = $ss + 4 | 0;
    HEAP32[$4 >> 2] = $out;
    var $5 = $ss + 8 | 0;
    HEAP32[$5 >> 2] = $out;
    HEAP32[$ss + 12 >> 2] = $outlen;
    var $7 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $8 = HEAP32[$5 >> 2];
    var $9 = HEAP32[$4 >> 2];
    if (($8 | 0) == ($9 | 0)) {
      var $18 = $8;
      var $17 = $9;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $8 - 1 | 0;
    if (HEAP8[$12] << 24 >> 24 == 0) {
      var $18 = $8;
      var $17 = $9;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$12] = 0;
    var $18 = HEAP32[$5 >> 2];
    var $17 = HEAP32[$4 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $18;
    var $_0 = $18 - $17 + ((($18 | 0) != ($17 | 0)) << 31 >> 31) | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_sprintf_append($last, $fmt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[_JS_sprintf_append.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = _JS_vsprintf_append($last, $fmt, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function _JS_vsprintf_append($last, $fmt, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ss = __stackBase__;
    HEAP32[$ss >> 2] = 218;
    if (($last | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _strlen($last);
    HEAP32[$ss + 4 >> 2] = $last;
    HEAP32[$ss + 8 >> 2] = $last + $4 | 0;
    HEAP32[$ss + 12 >> 2] = $4;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$ss + 4 >> 2] = 0;
    HEAP32[$ss + 8 >> 2] = 0;
    HEAP32[$ss + 12 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $14 = __ZL9dosprintfP15SprintfStateStrPKcPc($ss, $fmt, $ap);
    var $17 = HEAP32[$ss + 4 >> 2];
    if (($14 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $17;
      __label__ = 7;
      break;
    }
   case 5:
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js10Foreground5free_EPv($17);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13BuildArgArrayPKcPcPiP11NumArgState($fmt, $ap, $rv, $nasArray) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $ap;
    HEAP32[$rv >> 2] = 0;
    var $p_0_ph_ph = $fmt;
    var $indvars_iv = 0;
    __label__ = 2;
    break;
   case 2:
    var $indvars_iv;
    var $p_0_ph_ph;
    var $2 = ($indvars_iv | 0) > 0;
    var $p_0_ph = $p_0_ph_ph;
    var $i_0_ph = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0_ph;
    var $p_0_ph;
    var $p_0 = $p_0_ph;
    __label__ = 4;
    break;
   case 4:
    var $p_0;
    var $3 = $p_0 + 1 | 0;
    var $4 = HEAP8[$p_0];
    if ($4 << 24 >> 24 == 37) {
      __label__ = 5;
      break;
    } else if ($4 << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      var $p_0 = $3;
      __label__ = 4;
      break;
    }
   case 5:
    var $6 = $p_0 + 2 | 0;
    var $7 = HEAP8[$3];
    if ($7 << 24 >> 24 == 37) {
      var $p_0 = $6;
      __label__ = 4;
      break;
    } else {
      var $c_0 = $7;
      var $p_1 = $6;
      __label__ = 6;
      break;
    }
   case 6:
    var $p_1;
    var $c_0;
    if ($c_0 << 24 >> 24 == 0) {
      var $p_0 = $p_1;
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($c_0 - 48 & 255 & 255) > 9) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    if ($c_0 << 24 >> 24 == 36) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    if (($i_0_ph | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 11:
    var $p_0_ph_ph = $p_1;
    var $indvars_iv = $indvars_iv + 1 | 0;
    __label__ = 2;
    break;
   case 12:
    if ($2) {
      __label__ = 13;
      break;
    } else {
      var $p_0_ph = $p_1;
      var $i_0_ph = 1;
      __label__ = 3;
      break;
    }
   case 13:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 14:
    var $c_0 = HEAP8[$p_1];
    var $p_1 = $p_1 + 1 | 0;
    __label__ = 6;
    break;
   case 15:
    if (($indvars_iv | 0) == 0) {
      var $_0 = 0;
      __label__ = 72;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($indvars_iv | 0) > 20) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $29 = _malloc($indvars_iv << 3);
    var $30 = $29;
    if (($29 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $nas_062 = $30;
      __label__ = 20;
      break;
    }
   case 18:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 19:
    if ($2) {
      var $nas_062 = $nasArray;
      __label__ = 20;
      break;
    } else {
      var $nas_061 = $nasArray;
      __label__ = 21;
      break;
    }
   case 20:
    var $nas_062;
    var $i_131 = 0;
    __label__ = 22;
    break;
   case 21:
    var $nas_061;
    var $p_2 = $fmt;
    __label__ = 23;
    break;
   case 22:
    var $i_131;
    HEAP32[$nas_062 + ($i_131 << 3) >> 2] = 20;
    var $36 = $i_131 + 1 | 0;
    if (($36 | 0) == ($indvars_iv | 0)) {
      var $nas_061 = $nas_062;
      __label__ = 21;
      break;
    } else {
      var $i_131 = $36;
      __label__ = 22;
      break;
    }
   case 23:
    var $p_2;
    var $37 = $p_2 + 1 | 0;
    var $38 = HEAP8[$p_2];
    if ($38 << 24 >> 24 == 37) {
      __label__ = 24;
      break;
    } else if ($38 << 24 >> 24 == 0) {
      __label__ = 52;
      break;
    } else {
      var $p_2 = $37;
      __label__ = 23;
      break;
    }
   case 24:
    var $40 = $p_2 + 2 | 0;
    var $41 = HEAP8[$37];
    if ($41 << 24 >> 24 == 37) {
      var $p_2 = $40;
      __label__ = 23;
      break;
    } else {
      var $c_1 = $41;
      var $p_3 = $40;
      var $cn_0 = 0;
      __label__ = 25;
      break;
    }
   case 25:
    var $cn_0;
    var $p_3;
    var $c_1;
    if ($c_1 << 24 >> 24 == 36 || $c_1 << 24 >> 24 == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $47 = $cn_0 * 10 - 48 + ($c_1 << 24 >> 24) | 0;
    var $c_1 = HEAP8[$p_3];
    var $p_3 = $p_3 + 1 | 0;
    var $cn_0 = $47;
    __label__ = 25;
    break;
   case 27:
    if ($c_1 << 24 >> 24 == 0 | ($cn_0 | 0) < 1 | ($cn_0 | 0) > ($indvars_iv | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 29:
    var $55 = $nas_061 + ($cn_0 - 1 << 3) | 0;
    if ((HEAP32[$55 >> 2] | 0) == 20) {
      __label__ = 30;
      break;
    } else {
      var $p_2 = $p_3;
      __label__ = 23;
      break;
    }
   case 30:
    var $59 = HEAPU8[$p_3];
    if ($59 << 24 >> 24 == 42) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $p_420 = $p_3 + 1 | 0;
    if (($59 - 48 & 255 & 255) < 10) {
      var $p_422 = $p_420;
      __label__ = 33;
      break;
    } else {
      var $p_3_pn_lcssa = $p_3;
      var $c_2_lcssa = $59;
      var $p_4_lcssa = $p_420;
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 33:
    var $p_422;
    var $63 = HEAPU8[$p_422];
    var $p_4 = $p_422 + 1 | 0;
    if (($63 - 48 & 255 & 255) < 10) {
      var $p_422 = $p_4;
      __label__ = 33;
      break;
    } else {
      var $p_3_pn_lcssa = $p_422;
      var $c_2_lcssa = $63;
      var $p_4_lcssa = $p_4;
      __label__ = 34;
      break;
    }
   case 34:
    var $p_4_lcssa;
    var $c_2_lcssa;
    var $p_3_pn_lcssa;
    if ($c_2_lcssa << 24 >> 24 == 46) {
      __label__ = 35;
      break;
    } else {
      var $c_4 = $c_2_lcssa;
      var $p_6 = $p_4_lcssa;
      __label__ = 39;
      break;
    }
   case 35:
    var $67 = $p_3_pn_lcssa + 2 | 0;
    var $68 = HEAPU8[$p_4_lcssa];
    if ($68 << 24 >> 24 == 42) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if (($68 - 48 & 255 & 255) < 10) {
      var $p_516 = $67;
      __label__ = 38;
      break;
    } else {
      var $c_4 = $68;
      var $p_6 = $67;
      __label__ = 39;
      break;
    }
   case 37:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 38:
    var $p_516;
    var $72 = $p_516 + 1 | 0;
    var $73 = HEAPU8[$p_516];
    if (($73 - 48 & 255 & 255) < 10) {
      var $p_516 = $72;
      __label__ = 38;
      break;
    } else {
      var $c_4 = $73;
      var $p_6 = $72;
      __label__ = 39;
      break;
    }
   case 39:
    var $p_6;
    var $c_4;
    HEAP32[$55 >> 2] = 2;
    if ($c_4 << 24 >> 24 == 104) {
      __label__ = 40;
      break;
    } else if ($c_4 << 24 >> 24 == 76) {
      __label__ = 41;
      break;
    } else if ($c_4 << 24 >> 24 == 108) {
      __label__ = 42;
      break;
    } else {
      var $c_5 = $c_4;
      var $p_7 = $p_6;
      __label__ = 44;
      break;
    }
   case 40:
    HEAP32[$55 >> 2] = 0;
    var $c_5 = HEAP8[$p_6];
    var $p_7 = $p_6 + 1 | 0;
    __label__ = 44;
    break;
   case 41:
    HEAP32[$55 >> 2] = 6;
    var $c_5 = HEAP8[$p_6];
    var $p_7 = $p_6 + 1 | 0;
    __label__ = 44;
    break;
   case 42:
    HEAP32[$55 >> 2] = 4;
    var $82 = $p_6 + 1 | 0;
    var $83 = HEAP8[$p_6];
    if ($83 << 24 >> 24 == 108) {
      __label__ = 43;
      break;
    } else {
      var $c_5 = $83;
      var $p_7 = $82;
      __label__ = 44;
      break;
    }
   case 43:
    HEAP32[$55 >> 2] = 6;
    var $c_5 = HEAP8[$82];
    var $p_7 = $p_6 + 2 | 0;
    __label__ = 44;
    break;
   case 44:
    var $p_7;
    var $c_5;
    var $89 = $c_5 << 24 >> 24;
    if (($89 | 0) == 100 || ($89 | 0) == 99 || ($89 | 0) == 105 || ($89 | 0) == 111 || ($89 | 0) == 117 || ($89 | 0) == 120 || ($89 | 0) == 88) {
      var $p_2 = $p_7;
      __label__ = 23;
      break;
    } else if (($89 | 0) == 101 || ($89 | 0) == 102 || ($89 | 0) == 103) {
      __label__ = 45;
      break;
    } else if (($89 | 0) == 112) {
      __label__ = 46;
      break;
    } else if (($89 | 0) == 67 || ($89 | 0) == 83 || ($89 | 0) == 69 || ($89 | 0) == 71) {
      __label__ = 47;
      break;
    } else if (($89 | 0) == 115) {
      __label__ = 48;
      break;
    } else if (($89 | 0) == 110) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 45:
    HEAP32[$55 >> 2] = 9;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 46:
    HEAP32[$55 >> 2] = 5;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 47:
    HEAP32[$55 >> 2] = 20;
    __label__ = 51;
    break;
   case 48:
    HEAP32[$55 >> 2] = 8;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 49:
    HEAP32[$55 >> 2] = 10;
    var $p_2 = $p_7;
    __label__ = 23;
    break;
   case 50:
    HEAP32[$55 >> 2] = 20;
    __label__ = 51;
    break;
   case 51:
    HEAP32[$rv >> 2] = -1;
    __label__ = 54;
    break;
   case 52:
    if ((HEAP32[$rv >> 2] | 0) < 0) {
      __label__ = 54;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    var $98 = $1;
    var $cn_1 = 0;
    __label__ = 56;
    break;
   case 54:
    if (($nas_061 | 0) == ($nasArray | 0)) {
      var $_0 = 0;
      __label__ = 72;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    __ZN2js10Foreground5free_EPv($nas_061);
    var $_0 = 0;
    __label__ = 72;
    break;
   case 56:
    var $cn_1;
    if (($cn_1 | 0) < ($indvars_iv | 0)) {
      __label__ = 57;
      break;
    } else {
      var $_0 = $nas_061;
      __label__ = 72;
      break;
    }
   case 57:
    var $105 = $nas_061 + ($cn_1 << 3) | 0;
    if ((HEAP32[$105 >> 2] | 0) == 20) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    var $cn_1 = $cn_1 + 1 | 0;
    __label__ = 56;
    break;
   case 59:
    _llvm_va_copy($nas_061 + ($cn_1 << 3) + 4 | 0, $98);
    var $111 = HEAP32[$105 >> 2];
    if (($111 | 0) == 0 || ($111 | 0) == 1 || ($111 | 0) == 2 || ($111 | 0) == 3) {
      __label__ = 60;
      break;
    } else if (($111 | 0) == 4) {
      __label__ = 61;
      break;
    } else if (($111 | 0) == 5) {
      __label__ = 62;
      break;
    } else if (($111 | 0) == 6) {
      __label__ = 63;
      break;
    } else if (($111 | 0) == 7) {
      __label__ = 64;
      break;
    } else if (($111 | 0) == 8) {
      __label__ = 65;
      break;
    } else if (($111 | 0) == 11) {
      __label__ = 66;
      break;
    } else if (($111 | 0) == 10) {
      __label__ = 67;
      break;
    } else if (($111 | 0) == 9) {
      __label__ = 68;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 60:
    var $114 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $114;
    __label__ = 58;
    break;
   case 61:
    var $117 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $117;
    __label__ = 58;
    break;
   case 62:
    var $120 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $120;
    __label__ = 58;
    break;
   case 63:
    var $123 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $123;
    __label__ = 58;
    break;
   case 64:
    var $126 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $126;
    __label__ = 58;
    break;
   case 65:
    var $129 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $129;
    __label__ = 58;
    break;
   case 66:
    var $132 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $132;
    __label__ = 58;
    break;
   case 67:
    var $135 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $135;
    __label__ = 58;
    break;
   case 68:
    var $138 = HEAP32[$1 >> 2] + 8 | 0;
    HEAP32[$1 >> 2] = $138;
    __label__ = 58;
    break;
   case 69:
    if (($nas_061 | 0) == ($nasArray | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    __ZN2js10Foreground5free_EPv($nas_061);
    __label__ = 71;
    break;
   case 71:
    HEAP32[$rv >> 2] = -1;
    var $_0 = 0;
    __label__ = 72;
    break;
   case 72:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13BuildArgArrayPKcPcPiP11NumArgState["X"] = 1;

function __ZL5cvt_lP15SprintfStateStrliiiiiPKc($ss, $num, $width, $prec, $radix, $type, $flags, $hexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cvtbuf = __stackBase__;
    if (($prec | $num | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cvtbuf + 100 | 0;
    if (($num | 0) == 0) {
      var $cvt_0_lcssa8 = $4;
      __label__ = 5;
      break;
    } else {
      var $cvt_02 = $4;
      var $_013 = $num;
      var $digits_04 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $digits_04;
    var $_013;
    var $cvt_02;
    var $9 = HEAP8[$hexp + (($_013 >>> 0) % ($radix >>> 0) & 15) | 0];
    var $10 = $cvt_02 - 1 | 0;
    HEAP8[$10] = $9;
    var $11 = $digits_04 + 1 | 0;
    var $12 = Math.floor(($_013 >>> 0) / ($radix >>> 0));
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cvt_02 = $10;
      var $_013 = $12;
      var $digits_04 = $11;
      __label__ = 3;
      break;
    }
   case 4:
    if (($11 | 0) == 0) {
      var $cvt_0_lcssa8 = $10;
      __label__ = 5;
      break;
    } else {
      var $digits_1 = $11;
      var $cvt_1 = $10;
      __label__ = 6;
      break;
    }
   case 5:
    var $cvt_0_lcssa8;
    var $15 = $cvt_0_lcssa8 - 1 | 0;
    HEAP8[$15] = 48;
    var $digits_1 = 1;
    var $cvt_1 = $15;
    __label__ = 6;
    break;
   case 6:
    var $cvt_1;
    var $digits_1;
    var $17 = __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $cvt_1, $digits_1, $width, $prec, $type, $flags);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6cvt_llP15SprintfStateStrxiiiiiPKc($ss, $num$0, $num$1, $width, $prec, $radix, $type, $flags, $hexp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cvtbuf = __stackBase__;
    var $2 = $num$0 == 0 && $num$1 == 0;
    if (($prec | 0) == 0 & $2) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4$0 = $radix;
    var $4$1 = ($radix | 0) < 0 ? -1 : 0;
    var $5 = $cvtbuf + 100 | 0;
    if ($2) {
      var $cvt_0_lcssa8 = $5;
      __label__ = 5;
      break;
    } else {
      var $cvt_02 = $5;
      var $_013$1 = $num$1;
      var $_013$0 = $num$0;
      var $digits_04 = 0;
      __label__ = 3;
      break;
    }
   case 3:
    var $digits_04;
    var $_013$0;
    var $_013$1;
    var $cvt_02;
    var $6$0 = (i64Math.divide($_013$0, $_013$1, $4$0, $4$1, true), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    var $7$0 = (i64Math.modulo($_013$0, $_013$1, $4$0, $4$1, true), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    var $11 = HEAP8[$hexp + ($7$0 & 15) | 0];
    var $12 = $cvt_02 - 1 | 0;
    HEAP8[$12] = $11;
    var $13 = $digits_04 + 1 | 0;
    if ($6$0 == 0 && $6$1 == 0) {
      __label__ = 4;
      break;
    } else {
      var $cvt_02 = $12;
      var $_013$1 = $6$1;
      var $_013$0 = $6$0;
      var $digits_04 = $13;
      __label__ = 3;
      break;
    }
   case 4:
    if (($13 | 0) == 0) {
      var $cvt_0_lcssa8 = $12;
      __label__ = 5;
      break;
    } else {
      var $digits_1 = $13;
      var $cvt_1 = $12;
      __label__ = 6;
      break;
    }
   case 5:
    var $cvt_0_lcssa8;
    var $16 = $cvt_0_lcssa8 - 1 | 0;
    HEAP8[$16] = 48;
    var $digits_1 = 1;
    var $cvt_1 = $16;
    __label__ = 6;
    break;
   case 6:
    var $cvt_1;
    var $digits_1;
    var $18 = __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $cvt_1, $digits_1, $width, $prec, $type, $flags);
    var $_0 = $18;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5cvt_fP15SprintfStateStrdPKcS2_($ss, $d, $fmt0, $fmt1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 320;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fin = __stackBase__;
    var $fout = __stackBase__ + 20;
    var $3 = $fmt1 - $fmt0 | 0;
    if (($3 | 0) > 19) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $fin | 0;
    _memcpy($6, $fmt0, $3, 1);
    HEAP8[$fin + $3 | 0] = 0;
    var $8 = $fout | 0;
    var $9 = _sprintf($8, $6, (tempInt = STACKTOP, STACKTOP += 8, tempDoubleF64[0] = $d, HEAP32[tempInt >> 2] = tempDoubleI32[0], HEAP32[tempInt + 4 >> 2] = tempDoubleI32[1], tempInt));
    var $11 = HEAP32[$ss >> 2];
    var $12 = _strlen($8);
    var $13 = FUNCTION_TABLE[$11]($ss, $8, $12);
    var $_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6cvt_wsP15SprintfStateStrPKtiii($ss, $ws, $width, $prec, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ws | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __Z9js_strlenPKt($ws);
    var $4 = __ZN2js13DeflateStringEP9JSContextPKtj(0, $ws, $3);
    if (($4 | 0) == 0) {
      var $_0 = -1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, $4, $width, $prec, $flags);
    __ZN2js10Foreground5free_EPv($4);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZL5cvt_sP15SprintfStateStrPKciii($ss, 0, $width, $prec, $flags);
    var $_0 = $9;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5cvt_sP15SprintfStateStrPKciii($ss, $s, $width, $prec, $flags) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($prec | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = ($s | 0) != 0;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $7 = 6;
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = _strlen($s);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    var $slen_0 = ($prec | 0) > 0 & ($7 | 0) > ($prec | 0) ? $prec : $7;
    var $10 = $3 ? $s : STRING_TABLE.__ZN2js6Probes8nullNameE | 0;
    var $11 = __ZL5fill2P15SprintfStateStrPKciii($ss, $10, $slen_0, $width, $flags);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5fill2P15SprintfStateStrPKciii($ss, $src, $srclen, $width, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $space = __stackBase__;
    HEAP8[$space] = 32;
    var $1 = $width - $srclen | 0;
    if (($1 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      var $_1 = $1;
      __label__ = 8;
      break;
    }
   case 2:
    if (($flags & 1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = $1;
      __label__ = 8;
      break;
    }
   case 3:
    if (($flags & 8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$space] = 48;
    __label__ = 5;
    break;
   case 5:
    var $10 = $ss | 0;
    var $_01 = $1;
    __label__ = 6;
    break;
   case 6:
    var $_01;
    var $12 = $_01 - 1 | 0;
    if (($_01 | 0) > 0) {
      __label__ = 7;
      break;
    } else {
      var $_1 = $12;
      __label__ = 8;
      break;
    }
   case 7:
    var $15 = HEAP32[$10 >> 2];
    var $16 = FUNCTION_TABLE[$15]($ss, $space, 1);
    if (($16 | 0) < 0) {
      var $_0 = $16;
      __label__ = 13;
      break;
    } else {
      var $_01 = $12;
      __label__ = 6;
      break;
    }
   case 8:
    var $_1;
    var $18 = $ss | 0;
    var $19 = HEAP32[$18 >> 2];
    var $20 = FUNCTION_TABLE[$19]($ss, $src, $srclen);
    if (($20 | 0) < 0) {
      var $_0 = $20;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($_1 | 0) > 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    if (($flags & 1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $_2 = $_1;
      __label__ = 11;
      break;
    }
   case 11:
    var $_2;
    if (($_2 | 0) > 0) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $29 = $_2 - 1 | 0;
    var $30 = HEAP32[$18 >> 2];
    var $31 = FUNCTION_TABLE[$30]($ss, $space, 1);
    if (($31 | 0) < 0) {
      var $_0 = $31;
      __label__ = 13;
      break;
    } else {
      var $_2 = $29;
      __label__ = 11;
      break;
    }
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6fill_nP15SprintfStateStrPKciiiii($ss, $src, $srclen, $width, $prec, $type, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sign = __stackBase__;
    if (($type & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $signwidth_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($flags & 16 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$sign] = 45;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 4:
    if (($flags & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$sign] = 43;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 6:
    if (($flags & 4 | 0) == 0) {
      var $signwidth_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP8[$sign] = 32;
    var $signwidth_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $signwidth_0;
    var $or_cond = ($prec | 0) > 0 & ($prec | 0) > ($srclen | 0);
    var $_4 = $or_cond ? $prec - $srclen | 0 : 0;
    var $prec_pn = $or_cond ? $prec : $srclen;
    var $cvtwidth_0 = $signwidth_0 + $prec_pn | 0;
    if (($flags & 8 | 0) != 0 & ($prec | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $cvtwidth_1 = $cvtwidth_0;
      var $zerowidth_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $24 = ($cvtwidth_0 | 0) < ($width | 0);
    var $_ = $24 ? $width - $cvtwidth_0 | 0 : 0;
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $cvtwidth_1 = $cvtwidth_0;
      var $zerowidth_0 = $_;
      __label__ = 11;
      break;
    }
   case 10:
    var $cvtwidth_1 = $width;
    var $zerowidth_0 = $_;
    __label__ = 11;
    break;
   case 11:
    var $zerowidth_0;
    var $cvtwidth_1;
    var $28 = ($flags & 1 | 0) == 0;
    var $_3 = ($cvtwidth_1 | 0) < ($width | 0) ? $width - $cvtwidth_1 | 0 : 0;
    var $_3_ = $28 ? $_3 : 0;
    var $__3 = $28 ? 0 : $_3;
    var $31 = $ss | 0;
    var $leftspaces_0 = $_3_;
    __label__ = 12;
    break;
   case 12:
    var $leftspaces_0;
    if (($leftspaces_0 | 0) > 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $35 = $leftspaces_0 - 1 | 0;
    var $36 = HEAP32[$31 >> 2];
    var $37 = FUNCTION_TABLE[$36]($ss, STRING_TABLE._js_space_str | 0, 1);
    if (($37 | 0) < 0) {
      var $_0 = $37;
      __label__ = 23;
      break;
    } else {
      var $leftspaces_0 = $35;
      __label__ = 12;
      break;
    }
   case 14:
    if (($signwidth_0 | 0) == 0) {
      var $precwidth_1 = $_4;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $42 = HEAP32[$31 >> 2];
    var $43 = FUNCTION_TABLE[$42]($ss, $sign, 1);
    if (($43 | 0) < 0) {
      var $_0 = $43;
      __label__ = 23;
      break;
    } else {
      var $precwidth_1 = $_4;
      __label__ = 16;
      break;
    }
   case 16:
    var $precwidth_1;
    if (($precwidth_1 | 0) > 0) {
      __label__ = 17;
      break;
    } else {
      var $zerowidth_1 = $zerowidth_0;
      __label__ = 18;
      break;
    }
   case 17:
    var $47 = $precwidth_1 - 1 | 0;
    var $48 = HEAP32[$31 >> 2];
    var $49 = FUNCTION_TABLE[$48]($ss, STRING_TABLE.__str64083 | 0, 1);
    if (($49 | 0) < 0) {
      var $_0 = $49;
      __label__ = 23;
      break;
    } else {
      var $precwidth_1 = $47;
      __label__ = 16;
      break;
    }
   case 18:
    var $zerowidth_1;
    var $52 = HEAP32[$31 >> 2];
    if (($zerowidth_1 | 0) > 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $54 = $zerowidth_1 - 1 | 0;
    var $55 = FUNCTION_TABLE[$52]($ss, STRING_TABLE.__str64083 | 0, 1);
    if (($55 | 0) < 0) {
      var $_0 = $55;
      __label__ = 23;
      break;
    } else {
      var $zerowidth_1 = $54;
      __label__ = 18;
      break;
    }
   case 20:
    var $58 = FUNCTION_TABLE[$52]($ss, $src, $srclen);
    if (($58 | 0) < 0) {
      var $_0 = $58;
      __label__ = 23;
      break;
    } else {
      var $rightspaces_1 = $__3;
      __label__ = 21;
      break;
    }
   case 21:
    var $rightspaces_1;
    if (($rightspaces_1 | 0) > 0) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    var $62 = $rightspaces_1 - 1 | 0;
    var $63 = HEAP32[$31 >> 2];
    var $64 = FUNCTION_TABLE[$63]($ss, STRING_TABLE._js_space_str | 0, 1);
    if (($64 | 0) < 0) {
      var $_0 = $64;
      __label__ = 23;
      break;
    } else {
      var $rightspaces_1 = $62;
      __label__ = 21;
      break;
    }
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6fill_nP15SprintfStateStrPKciiiii["X"] = 1;

function __ZL26js_IsPropertyCacheDisabledP9JSContext3032($cx_0_11_val) {
  return HEAPU32[$cx_0_11_val + 209944 >> 2] >>> 0 > 16777215 & 1;
}

function __ZN2js5PCVal9setFunObjER8JSObject($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZN8JSObject7genericEv($this) {
  return (HEAP32[$this + 8 >> 2] & 16 | 0) != 0;
}

function __ZN2js5PCVal7setSlotEj($this, $slot) {
  HEAP32[$this >> 2] = $slot << 1 | 1;
  return;
}

function __ZN2js5PCVal8setShapeEPKNS_5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape | 2;
  return;
}

function __ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE($this, $kpc, $kshape, $vshape, $scopeIndex, $protoIndex, $vword) {
  var __stackBase__ = STACKTOP;
  var tempParam = $vword;
  $vword = STACKTOP;
  STACKTOP += 4;
  HEAP32[$vword >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$this >> 2] = $kpc;
  HEAP32[$this + 4 >> 2] = $kshape;
  HEAP32[$this + 8 >> 2] = $vshape << 8 | $protoIndex | $scopeIndex << 4;
  var $9 = HEAP32[$vword >> 2];
  HEAP32[$this + 12 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js13PropertyCache14purgeForScriptEP9JSContextP8JSScript($this, $cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $0 = $this + 65536 | 0;
    var $2 = $script | 0;
    var $3 = $script + 8 | 0;
    var $entry_01 = $this | 0;
    __label__ = 2;
    break;
   case 2:
    var $entry_01;
    var $4 = $entry_01 | 0;
    if ((HEAP32[$4 >> 2] - HEAP32[$2 >> 2] | 0) >>> 0 < HEAPU32[$3 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$4 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    var $14 = $entry_01 + 16 | 0;
    if ($14 >>> 0 < $0 >>> 0) {
      var $entry_01 = $14;
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11KidsPointer6isNullEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js5Shape9setParentEPS0_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$p + 4 >> 2];
    var $7 = HEAP32[$this + 24 >> 2] + 1 | 0;
    var $_ = $4 >>> 0 > $7 >>> 0 ? $4 : $7;
    HEAP32[$this + 4 >> 2] = $_;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 32 >> 2] = $p;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11KidsPointer8setShapeEPNS_5ShapeE($this, $shape) {
  HEAP32[$this >> 2] = $shape;
  return;
}

function __ZNK2js11KidsPointer7toShapeEv($this) {
  return HEAP32[$this >> 2] & -2;
}

function __ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE($this, $hash) {
  HEAP32[$this >> 2] = $hash | 1;
  return;
}

function __ZNK2js11KidsPointer6toHashEv($this) {
  return HEAP32[$this >> 2] & -2;
}

function __ZNK2js11KidsPointer6isHashEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi($this, $cx, $obj, $scopeIndex, $pobj, $shape, $adding) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vword = __stackBase__;
    var $pc = __stackBase__ + 4;
    var $funobj1 = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $cx_idx = $cx + 52 | 0;
    var $cx_idx_val = HEAP32[$cx_idx >> 2];
    var $2 = __ZL26js_IsPropertyCacheDisabledP9JSContext3032($cx_idx_val);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 2:
    var $5 = $pobj;
    var $6 = $cx;
    var $7 = $shape;
    var $8 = __ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE($5, $6, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 3:
    var $10 = ($adding | 0) != 0;
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZNK8JSObject16inDictionaryModeEv($obj);
    if ($12) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = ($scopeIndex | 0) == 0;
    if ($13) {
      var $protoIndex_0 = 0;
      var $tmp_1 = $obj;
      __label__ = 7;
      break;
    } else {
      var $tmp_04 = $obj;
      var $i_05 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $i_05;
    var $tmp_04;
    var $14 = __ZNK8JSObject9getParentEv($tmp_04);
    var $15 = $i_05 + 1 | 0;
    if (($15 | 0) == ($scopeIndex | 0)) {
      var $protoIndex_0 = 0;
      var $tmp_1 = $14;
      __label__ = 7;
      break;
    } else {
      var $tmp_04 = $14;
      var $i_05 = $15;
      __label__ = 6;
      break;
    }
   case 7:
    var $tmp_1;
    var $protoIndex_0;
    if (($tmp_1 | 0) == ($pobj | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZNK8JSObject8getProtoEv($tmp_1);
    if (($19 | 0) == 0) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = __ZNK8JSObject8isNativeEv($19);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 10:
    var $protoIndex_0 = $protoIndex_0 + 1 | 0;
    var $tmp_1 = $19;
    __label__ = 7;
    break;
   case 11:
    if ($scopeIndex >>> 0 > 15 | $protoIndex_0 >>> 0 > 15) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $29 = $cx + 60 | 0;
    var $30 = __ZNK2js12ContextStack13currentScriptEPPh($29, $pc);
    var $31 = HEAP32[$pc >> 2];
    var $32 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($30, $31);
    var $34 = HEAPU32[_js_CodeSpec + ($32 << 3) + 4 >> 2];
    if (($34 & 524288 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZNK2js5Shape8isMethodEv($shape);
    if ($38) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $40 = __ZNK2js5Shape12methodObjectEv($shape);
    __ZN2js5PCVal9setFunObjER8JSObject($vword, $40);
    __label__ = 35;
    break;
   case 15:
    var $42 = __ZN8JSObject7genericEv($pobj);
    if ($42) {
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $44 = __ZNK2js5Shape16hasDefaultGetterEv($shape);
    if ($44) {
      __label__ = 17;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 17:
    var $47 = HEAP32[$shape + 24 >> 2];
    var $48 = __ZNK8JSObject12containsSlotEj($pobj, $47);
    if ($48) {
      __label__ = 18;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 18:
    var $50 = __ZN9JSContext20typeInferenceEnabledEv($cx);
    if ($50) {
      __label__ = 25;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __ZNK8JSObject13nativeGetSlotEj($pobj, $47);
    var $53 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034($52, $funobj1);
    if ($53) {
      __label__ = 20;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 20:
    var $55 = $pobj;
    var $56 = __ZN8JSObject7brandedEv($55);
    if ($56) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $58 = $cx;
    var $59 = __ZN8JSObject5brandEP9JSContext($55, $58);
    if ($59) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 16;
      __label__ = 40;
      break;
    }
   case 22:
    var $61 = HEAP32[$funobj1 >> 2];
    __ZN2js5PCVal9setFunObjER8JSObject($vword, $61);
    __label__ = 35;
    break;
   case 23:
    if (($34 & 11520 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $66 = $obj;
    var $67 = __ZNK8JSObject7watchedEv($66);
    if ($67) {
      var $_0 = 16;
      __label__ = 40;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($34 & 8448 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 26:
    if (($34 & 3072 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $75 = __ZNK2js5Shape16hasDefaultSetterEv($shape);
    if ($75) {
      __label__ = 28;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 28:
    var $77 = $shape;
    var $78 = __ZNK2js5Shape8writableEv($77);
    if ($78) {
      __label__ = 29;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 29:
    var $80 = __ZNK2js5Shape16hasDefaultGetterEv($shape);
    if ($80) {
      __label__ = 30;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 30:
    var $83 = HEAP32[$shape + 24 >> 2];
    var $84 = __ZNK8JSObject12containsSlotEj($pobj, $83);
    if ($84) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    __ZN2js5PCVal7setSlotEj($vword, $83);
    __label__ = 35;
    break;
   case 32:
    __ZN2js5PCVal8setShapeEPKNS_5ShapeE($vword, $shape);
    if ($10) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $88 = __ZNK8JSObject5shapeEv($pobj);
    if (($88 | 0) == (HEAP32[$shape >> 2] | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $93 = __ZNK2js5Shape8previousEv($shape);
    var $95 = HEAP32[$93 >> 2];
    var $98 = HEAP32[HEAP32[$cx_idx >> 2] + 44 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      var $vshape_1 = $98;
      var $kshape_1 = $95;
      __label__ = 36;
      break;
    }
   case 35:
    var $100 = __ZNK8JSObject5shapeEv($obj);
    var $101 = __ZNK8JSObject5shapeEv($pobj);
    var $vshape_1 = $101;
    var $kshape_1 = $100;
    __label__ = 36;
    break;
   case 36:
    var $kshape_1;
    var $vshape_1;
    if (($obj | 0) == ($pobj | 0)) {
      __label__ = 39;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    if ($13 & ($protoIndex_0 | 0) == 1) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    __ZN8JSObject11setDelegateEv($obj);
    __label__ = 39;
    break;
   case 39:
    var $108 = HEAP32[$pc >> 2];
    var $109 = __ZN2js13PropertyCache4hashEPhj($108, $kshape_1);
    var $110 = $this + ($109 << 4) | 0;
    var $112 = HEAP32[$vword >> 2];
    HEAP32[$1 >> 2] = $112;
    __ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE($110, $108, $kshape_1, $vshape_1, $scopeIndex, $protoIndex_0, $1);
    HEAP32[$this + 65536 >> 2] = 0;
    var $_0 = $110;
    __label__ = 40;
    break;
   case 40:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE($this, $cx, $pc, $objp, $pobjp, $entry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 60 | 0;
    var $2 = __ZNK2js12ContextStack13currentScriptEPPh($1, 0);
    var $3 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033($2, $pc);
    var $4 = _js_CodeSpec + ($3 << 3) | 0;
    var $5 = HEAP32[$objp >> 2];
    var $7 = HEAP32[$entry + 8 >> 2];
    if ((HEAP32[$entry >> 2] | 0) == ($pc | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $12;
    __label__ = 18;
    break;
   case 3:
    var $15 = HEAP32[$entry + 4 >> 2];
    var $16 = __ZNK8JSObject5shapeEv($5);
    if (($15 | 0) == ($16 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $19;
    __label__ = 18;
    break;
   case 5:
    if ((HEAP32[_js_CodeSpec + ($3 << 3) + 4 >> 2] & 224 | 0) == 32) {
      var $vcap_0 = $7;
      var $pobj_0 = $5;
      __label__ = 6;
      break;
    } else {
      var $vcap_1 = $7;
      var $pobj_1 = $5;
      __label__ = 11;
      break;
    }
   case 6:
    var $pobj_0;
    var $vcap_0;
    if (($vcap_0 & 240 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $28 = __ZNK8JSObject9getParentEv($pobj_0);
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = __ZNK8JSObject8isNativeEv($28);
    if ($31) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $vcap_0 = $vcap_0 - 16 | 0;
    var $pobj_0 = $28;
    __label__ = 6;
    break;
   case 10:
    HEAP32[$objp >> 2] = $pobj_0;
    var $vcap_1 = $vcap_0;
    var $pobj_1 = $pobj_0;
    __label__ = 11;
    break;
   case 11:
    var $pobj_1;
    var $vcap_1;
    if (($vcap_1 & 15 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZNK8JSObject8getProtoEv($pobj_1);
    if (($38 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = __ZNK8JSObject8isNativeEv($38);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $vcap_1 = $vcap_1 - 1 | 0;
    var $pobj_1 = $38;
    __label__ = 11;
    break;
   case 15:
    var $46 = __ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj(undef, $pobj_1, $vcap_1 >>> 8);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[$pobjp >> 2] = $pobj_1;
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $49 = __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $3, $4);
    var $_0 = $49;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE["X"] = 1;

function __ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec($cx, $pc, $op, $cs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 220) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 114) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    __label__ = 8;
    break;
   case 3:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2] | 0;
    __label__ = 8;
    break;
   case 4:
    var $14 = $cx + 60 | 0;
    var $15 = __ZNK2js12ContextStack13currentScriptEPPh($14, 0);
    var $20 = (HEAP32[$cs + 4 >> 2] & 31 | 0) == 8 ? 2 : 0;
    var $21 = _js_GetIndexFromBytecode($cx, $15, $pc, $20);
    var $23 = HEAPU32[$15 >> 2];
    if ($23 >>> 0 > $pc >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 + HEAP32[$15 + 8 >> 2] | 0) >>> 0 > $pc >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $33 = HEAP32[$cx + 52 >> 2] + 209948 | 0;
    var $34 = __ZN11JSAtomState16commonAtomsStartEv($33);
    var $_0 = HEAP32[$34 + ($21 << 2) >> 2];
    __label__ = 8;
    break;
   case 7:
    var $38 = __ZN8JSScript7getAtomEj($15, $21);
    var $_0 = $38;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyCache5purgeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 65536 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_($5);
    HEAP32[$1 >> 2] = 1;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_($t) {
  var $1 = $t;
  _memset($1, 0, 65536, 1);
  return;
}

function __ZN2js13PropertyCache7restoreEPNS_18PropertyCacheEntryE($this, $entry) {
  HEAP32[$this + 65536 >> 2] = 0;
  var $3 = HEAP32[$entry >> 2];
  var $5 = HEAP32[$entry + 4 >> 2];
  var $6 = __ZN2js13PropertyCache4hashEPhj($3, $5);
  var $8 = $this + ($6 << 4) | 0;
  var $9 = $entry;
  HEAP32[$8 >> 2] = HEAP32[$9 >> 2];
  HEAP32[$8 + 4 >> 2] = HEAP32[$9 + 4 >> 2];
  HEAP32[$8 + 8 >> 2] = HEAP32[$9 + 8 >> 2];
  HEAP32[$8 + 12 >> 2] = HEAP32[$9 + 12 >> 2];
  return;
}

function __ZN2js12PropertyTree8newShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z13js_NewGCShapeP9JSContext($cx);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    _JS_ReportOutOfMemory($4);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z13js_NewGCShapeP9JSContext($cx) {
  var $1 = __Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj($cx, 14, 40);
  return $1;
}

function __ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_($this, $cx, $parent, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $child;
    var $2 = $parent + 36 | 0;
    var $3 = __ZNK2js11KidsPointer6isNullEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js5Shape9setParentEPS0_($child, $parent);
    __ZN2js11KidsPointer8setShapeEPNS_5ShapeE($2, $child);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 3:
    var $6 = __ZNK2js11KidsPointer7isShapeEv($2);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $8 = __ZNK2js11KidsPointer7toShapeEv($2);
    var $9 = __ZL12HashChildrenPN2js5ShapeES1_($8, $child);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $cx;
    _JS_ReportOutOfMemory($12);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 6:
    __ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE($2, $9);
    __ZN2js5Shape9setParentEPS0_($child, $parent);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 7:
    var $15 = __ZNK2js11KidsPointer6toHashEv($2);
    var $16 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($15, $1);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = $cx;
    _JS_ReportOutOfMemory($18);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    var $20 = HEAP32[$1 >> 2];
    __ZN2js5Shape9setParentEPS0_($20, $parent);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js11KidsPointer7isShapeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] & 1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js11KidsPointer6isNullEv($this);
    var $9 = $6 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12HashChildrenPN2js5ShapeES1_($kid1, $kid2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $kid1;
    HEAP32[$2 >> 2] = $kid2;
    var $3 = __ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v();
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj($3, 2);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_($3);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $9 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($3, $1);
    var $10 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($3, $2);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_($this, $t) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var $p = __stackBase__;
  var $1 = __stackBase__ + 8;
  var $2 = HEAP32[$t >> 2];
  HEAP32[$1 >> 2] = $2;
  __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_($p, $this, $1);
  var $3 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js5Shape11removeChildEPS0_($this, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 36 | 0;
    var $3 = __ZNK2js11KidsPointer7isShapeEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js11KidsPointer7setNullEv($2);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZNK2js11KidsPointer6toHashEv($2);
    HEAP32[$1 >> 2] = $child;
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_($6, $1);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_($this, $l) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($p, $this, $l);
    __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($1, $p);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$p >> 2];
    HEAP32[$2 >> 2] = $8;
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE($this, $2);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_($this, $cx, $parent, $child) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = $parent + 36 | 0;
    var $4 = __ZNK2js11KidsPointer7isShapeEv($3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js11KidsPointer7toShapeEv($3);
    var $7 = __ZNK2js5Shape7matchesEPKS0_($6, $child);
    if ($7) {
      var $_0 = $6;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = __ZNK2js11KidsPointer6isHashEv($3);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2js11KidsPointer6toHashEv($3);
    HEAP32[$1 >> 2] = $child;
    __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($2, $11, $1);
    var $12 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($2);
    var $13 = HEAPU32[$12 >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $13;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = __ZN2js12PropertyTree8newShapeEP9JSContext(undef, $cx);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$child + 12 >> 2];
    var $22 = HEAP32[$child + 16 >> 2];
    var $24 = HEAP32[$child + 20 >> 2];
    var $26 = HEAP32[$child + 24 >> 2];
    var $29 = HEAPU8[$child + 28 | 0] & 255;
    var $32 = HEAPU8[$child + 29 | 0] & 255;
    var $35 = HEAP16[$child + 30 >> 1] << 16 >> 16;
    var $36 = $cx;
    var $37 = __Z16js_GenerateShapeP9JSContext($36);
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($16, $20, $22, $24, $26, $29, $32, $35, $37, 0);
    var $38 = __ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_(undef, $cx, $parent, $16);
    if ($38) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $_0 = $16;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js5Shape7matchesEPKS0_($this, $other) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 12 >> 2] | 0) == (HEAP32[$other + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $24 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$other + 16 >> 2];
    var $10 = HEAP32[$other + 20 >> 2];
    var $12 = HEAP32[$other + 24 >> 2];
    var $15 = HEAPU8[$other + 28 | 0] & 255;
    var $18 = HEAPU8[$other + 29 | 0] & 255;
    var $21 = HEAP16[$other + 30 >> 1] << 16 >> 16;
    var $22 = __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($this, $8, $10, $12, $15, $18, $21);
    var $24 = $22;
    __label__ = 3;
    break;
   case 3:
    var $24;
    return $24;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_($agg_result, $1, $l);
  return;
}

function __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan) {
  __ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan);
  return;
}

function __ZN2js5Shape8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape12inDictionaryEv($1);
    if ($2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 32 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $5;
    var $9 = __ZNK2js2gc4Cell8isMarkedEj($8, 0);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = HEAP32[$4 >> 2];
    __ZN2js5Shape11removeChildEPS0_($11, $this);
    __label__ = 5;
    break;
   case 5:
    var $13 = $this + 36 | 0;
    var $14 = __ZNK2js11KidsPointer6isHashEv($13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZNK2js11KidsPointer6toHashEv($13);
    __ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_($cx, $16);
    __label__ = 7;
    break;
   case 7:
    __ZN2js5Shape9freeTableEP9JSContext($this, $cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape9freeTableEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js5Shape8hasTableEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js5Shape8getTableEv($1);
    var $5 = $4;
    __ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_($cx, $5);
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($this, 0);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function _js_free3045($p) {
  _free($p);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 20 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js17SystemAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN2js11ShapeHasher4hashEPKNS_5ShapeE($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js14JSProxyHandlerD2Ev($this) {
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZNK2js5Shape4hashEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 16 >> 2];
    if (($2 | 0) == 0) {
      var $hash_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $hash_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $hash_0;
    var $8 = HEAPU32[$this + 20 >> 2];
    if (($8 | 0) == 0) {
      var $hash_1 = $hash_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $hash_1 = ($hash_0 << 4 | $hash_0 >>> 28) ^ $8;
    __label__ = 5;
    break;
   case 5:
    var $hash_1;
    var $24 = HEAPU8[$this + 29 | 0] & 255 & 192 ^ ($hash_1 << 4 | $hash_1 >>> 28);
    var $31 = ($24 << 4 | $24 >>> 28) ^ HEAPU8[$this + 28 | 0] & 255;
    var $38 = ($31 << 4 | $31 >>> 28) ^ HEAP16[$this + 30 >> 1] << 16 >> 16;
    var $44 = ($38 << 4 | $38 >>> 28) ^ HEAP32[$this + 24 >> 2];
    return ($44 << 4 | $44 >>> 28) ^ HEAP32[$this + 12 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZNK2js5Shape4hashEv["X"] = 1;

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js5Shape8setTableEPNS_13PropertyTableE($this, $t) {
  HEAP32[$this + 8 >> 2] = $t;
  return;
}

function __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($this, $agetter, $asetter, $aslot, $aattrs, $aflags, $ashortid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 16 >> 2] | 0) == ($agetter | 0)) {
      __label__ = 2;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    if ((HEAP32[$this + 20 >> 2] | 0) == ($asetter | 0)) {
      __label__ = 3;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    if ((HEAP32[$this + 24 >> 2] | 0) == ($aslot | 0)) {
      __label__ = 4;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    if ((HEAPU8[$this + 28 | 0] & 255 | 0) == ($aattrs | 0)) {
      __label__ = 5;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    if (((HEAPU8[$this + 29 | 0] & 255 ^ $aflags) & 192 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $30 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = (HEAP16[$this + 30 >> 1] << 16 >> 16 | 0) == ($ashortid | 0);
    __label__ = 7;
    break;
   case 7:
    var $30;
    return $30;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js14JSProxyHandlerC2EPv($this, $family) {
  HEAP32[$this >> 2] = __ZTVN2js14JSProxyHandlerE + 8 | 0;
  HEAP32[$this + 4 >> 2] = $family;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = HEAP32[$l >> 2];
  var $5 = __ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_($3, $4);
  return $5;
}

function __ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_($k, $l) {
  var $1 = __ZNK2js5Shape7matchesEPKS0_($l, $k);
  return $1;
}

function __ZN2js11ShapeHasher4hashEPKNS_5ShapeE($l) {
  var $1 = __ZNK2js5Shape4hashEv($l);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($hash);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 222,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $2);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 8 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity << 3;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($capacity << 3) | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 8 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_($1, $7);
  var $8 = __ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev($this);
  return;
}

function _js_malloc3046() {
  var $1 = _malloc(24);
  return $1;
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv($2);
  return $3;
}

function __ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13PropertyTableD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTableD1Ev($this) {
  __ZN2js13PropertyTableD2Ev($this);
  return;
}

function __ZN2js13PropertyTableD2Ev($this) {
  var $3 = HEAP32[$this + 16 >> 2];
  __ZN2js10Foreground5free_EPv($3);
  return;
}

function __ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($this, $propid, $getter, $setter, $slot, $attrs, $flags, $shortid, $shapeid, $slotSpan) {
  HEAP32[$this >> 2] = $shapeid;
  HEAP32[$this + 4 >> 2] = $slotSpan;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = $propid;
  HEAP32[$this + 16 >> 2] = $getter;
  HEAP32[$this + 20 >> 2] = $setter;
  HEAP32[$this + 24 >> 2] = $slot;
  HEAP8[$this + 28 | 0] = $attrs & 255;
  HEAP8[$this + 29 | 0] = $flags & 255;
  HEAP16[$this + 30 >> 1] = $shortid & 65535;
  HEAP32[$this + 32 >> 2] = 0;
  var $15 = $this + 36 | 0;
  __ZN2js11KidsPointer7setNullEv($15);
  return;
}

function __ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = _js_malloc3046();
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_($5, $1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($1, $len);
  return $2;
}

function __ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev($p);
    var $3 = $p;
    _js_free3045($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$a] = HEAP8[tempParam];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, $kind, $thingSize);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, $kind);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandlerD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $4 = HEAP32[HEAP32[$this >> 2] + 8 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 0, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$bp] = (HEAP32[$desc + 16 >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $4 = HEAP32[HEAP32[$this >> 2] + 12 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 0, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP8[$bp] = (HEAP32[$desc + 16 >> 2] | 0) != 0 & 1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject($this, $cx, $proxy) {
  return;
}

function __ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject($this, $trc, $proxy) {
  return;
}

function _INT_TO_JSID3072($i) {
  return $i << 1 | 1;
}

function __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc) {
  HEAP32[$desc >> 2] = 0;
  return;
}

function __ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __stackBase__ + 48;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $5 = HEAP32[HEAP32[$this >> 2] + 8 >> 2];
    var $6 = $desc + 16 | 0;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $proxy, $id, 0, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    if ((HEAP32[$desc + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 15;
    break;
   case 4:
    var $14 = $desc + 24 | 0;
    var $15 = HEAP32[$14 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $desc + 20 | 0;
    var $19 = HEAP32[$18 >> 2];
    var $21 = ($19 & 16 | 0) == 0;
    if ($21 & ($15 | 0) == 10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = $desc + 32 | 0;
    var $st$1$0 = $24 | 0;
    var $25$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$1$1 >> 2];
    var $26 = $vp | 0;
    var $st$6$0 = $26 | 0;
    HEAP32[$st$6$0 >> 2] = $25$0;
    var $st$6$1 = $26 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $25$1;
    var $_0 = 1;
    __label__ = 15;
    break;
   case 7:
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE($1, $15);
    var $29 = __ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_($cx, $receiver, $1, 0, 0, $vp);
    var $_0 = $29;
    __label__ = 15;
    break;
   case 9:
    if (($19 & 64 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = $desc + 32 | 0;
    var $st$1$0 = $34 | 0;
    var $35$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $34 + 4 | 0;
    var $35$1 = HEAP32[$st$1$1 >> 2];
    var $36 = $vp | 0;
    var $st$6$0 = $36 | 0;
    HEAP32[$st$6$0 >> 2] = $35$0;
    var $st$6$1 = $36 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $35$1;
    var $39 = $19;
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $39 = HEAP32[$18 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $39;
    if (($39 & 256 | 0) == 0) {
      var $_01 = $id;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $44 = HEAP32[$desc + 40 >> 2];
    var $45 = _INT_TO_JSID3072($44);
    var $_01 = $45;
    __label__ = 14;
    break;
   case 14:
    var $_01;
    var $47 = $cx;
    var $48 = HEAP32[$14 >> 2];
    var $49 = $receiver;
    var $50 = __ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_($47, $48, $49, $_01, $vp);
    var $_0 = $50;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE["X"] = 1;

function __ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $1 = $this;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    var $5 = $desc + 16 | 0;
    var $6 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $id, 1, $5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 2:
    var $8 = $5 | 0;
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $desc + 20 | 0;
    var $13 = HEAPU32[$12 >> 2];
    if (($13 & 2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 4:
    var $17 = $desc + 28 | 0;
    var $18 = HEAPU32[$17 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$17 >> 2] = 12;
    __label__ = 11;
    break;
   case 6:
    if (($13 & 32 | 0) == 0 & ($18 | 0) == 12) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = HEAP32[$desc + 40 >> 2];
    var $28 = $strict & 1;
    var $29 = $cx;
    var $30 = $receiver;
    var $31 = $18;
    var $32 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($29, $30, $id, $31, $13, $27, $28, $vp);
    if ($32) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 8:
    var $34 = __ZNK8JSObject7isProxyEv($proxy);
    if ($34) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 9:
    var $36 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    if (($36 | 0) == ($this | 0)) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 10:
    if ((HEAP32[$12 >> 2] & 64 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 11:
    var $43 = $desc + 24 | 0;
    if ((HEAP32[$43 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$43 >> 2] = 10;
    __label__ = 13;
    break;
   case 13:
    var $48 = $vp | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50 = $desc + 32 | 0;
    HEAP32[$50 >> 2] = $49$0;
    HEAP32[$50 + 4 >> 2] = $49$1;
    var $54 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $55 = FUNCTION_TABLE[$54]($this, $cx, $receiver, $id, $5);
    var $_0 = $55;
    __label__ = 28;
    break;
   case 14:
    var $59 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    var $60 = FUNCTION_TABLE[$59]($this, $cx, $proxy, $id, 1, $5);
    if ($60) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 15:
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $65 = $desc + 20 | 0;
    var $66 = HEAPU32[$65 >> 2];
    if (($66 & 2 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 17:
    var $70 = $desc + 28 | 0;
    var $71 = HEAPU32[$70 >> 2];
    if (($71 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$70 >> 2] = 12;
    __label__ = 24;
    break;
   case 19:
    if (($66 & 32 | 0) == 0 & ($71 | 0) == 12) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $80 = HEAP32[$desc + 40 >> 2];
    var $81 = $strict & 1;
    var $82 = $cx;
    var $83 = $receiver;
    var $84 = $71;
    var $85 = __ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_($82, $83, $id, $84, $66, $80, $81, $vp);
    if ($85) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 28;
      break;
    }
   case 21:
    var $87 = __ZNK8JSObject7isProxyEv($proxy);
    if ($87) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 22:
    var $89 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    if (($89 | 0) == ($this | 0)) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 23:
    if ((HEAP32[$65 >> 2] & 64 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 24:
    var $96 = $desc + 24 | 0;
    if ((HEAP32[$96 >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$96 >> 2] = 10;
    __label__ = 26;
    break;
   case 26:
    var $104 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $105 = FUNCTION_TABLE[$104]($this, $cx, $receiver, $id, $5);
    var $_0 = $105;
    __label__ = 28;
    break;
   case 27:
    HEAP32[$8 >> 2] = $receiver;
    var $107 = $vp | 0;
    var $108$0 = HEAP32[$107 >> 2];
    var $108$1 = HEAP32[$107 + 4 >> 2];
    var $109 = $desc + 32 | 0;
    HEAP32[$109 >> 2] = $108$0;
    HEAP32[$109 + 4 >> 2] = $108$1;
    HEAP32[$desc + 20 >> 2] = 1;
    HEAP32[$desc + 40 >> 2] = 0;
    HEAP32[$desc + 24 >> 2] = 0;
    HEAP32[$desc + 28 >> 2] = 0;
    var $117 = HEAP32[HEAP32[$this >> 2] + 16 >> 2];
    var $118 = FUNCTION_TABLE[$117]($this, $cx, $receiver, $id, $5);
    var $_0 = $118;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE["X"] = 1;

function __ZNK8JSObject15getProxyHandlerEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 0);
  var $2 = __ZNK2JS5Value9toPrivateEv($1);
  return $2;
}

function __ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 20 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $proxy, $props);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $props | 0;
    var $8 = __ZNK2js16AutoVectorRooterIiE6lengthEv($7);
    var $9 = $this;
    var $10 = $desc + 16 | 0;
    var $11 = $desc + 16 | 0;
    var $12 = $desc + 20 | 0;
    var $j_0 = 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    var $j_0;
    if ($j_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $16 = __ZN2js16AutoVectorRooterIiEixEj($7, $j_0);
    var $17 = HEAP32[$16 >> 2];
    var $20 = HEAP32[HEAP32[$9 >> 2] + 12 >> 2];
    var $21 = FUNCTION_TABLE[$20]($this, $cx, $proxy, $17, 0, $10);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    if ((HEAP32[$11 >> 2] | 0) == 0) {
      var $i_1 = $i_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$12 >> 2] & 1 | 0) == 0) {
      var $i_1 = $i_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = $i_0 + 1 | 0;
    var $31 = __ZN2js16AutoVectorRooterIiEixEj($7, $i_0);
    HEAP32[$31 >> 2] = $17;
    var $i_1 = $30;
    __label__ = 8;
    break;
   case 8:
    var $i_1;
    var $j_0 = $j_0 + 1 | 0;
    var $i_0 = $i_1;
    __label__ = 3;
    break;
   case 9:
    var $35 = __ZN2js16AutoVectorRooterIiE6resizeEj($7, $i_0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoVectorRooterIiE6resizeEj($this, $newLength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 12 | 0;
    var $2 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv($1);
    if ($2 >>> 0 < $newLength >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 - $newLength | 0;
    __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj($1, $5);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $7 = $newLength - $2 | 0;
    var $8 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj($1, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv($1);
    var $11 = $10 + ($2 << 2) | 0;
    var $12 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv($1);
    __ZN2jsL15MakeRangeGCSafeEPiS0_($11, $12);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $props = __stackBase__;
    __ZN2js12AutoIdVectorC1EP9JSContext($props, $cx);
    var $4 = HEAP32[$this >> 2];
    if (($flags & 8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$4 + 52 >> 2];
    var $8 = FUNCTION_TABLE[$7]($this, $cx, $proxy, $props);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$4 + 28 >> 2];
    var $12 = FUNCTION_TABLE[$11]($this, $cx, $proxy, $props);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = $proxy;
    var $16 = $props;
    var $17 = __ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($14, $15, $flags, $16, $vp);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($props);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject($this, $cx, $proxy) {
  var $1 = __ZNK8JSObject15isFunctionProxyEv($proxy);
  var $2 = $1 ? STRING_TABLE.__str3048 | 0 : STRING_TABLE.__str4127 | 0;
  var $3 = _JS_NewStringCopyZ($cx, $2);
  return $3;
}

function __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $proxy, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __ZL7GetCallP8JSObject($proxy);
    var $2 = $1 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $fval | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK8JSObject15isFunctionProxyEv($proxy);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = __ZNK2JS5Value11isPrimitiveEv($fval);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2JS5Value8toObjectEv($fval);
    var $10 = __ZNK8JSObject10isFunctionEv($9);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _JS_ReportErrorNumber($cx, 2, 0, 8, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_Function_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_toString_str | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE._js_object_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK2JS5Value8toObjectEv($fval);
    var $14 = __Z18fun_toStringHelperP9JSContextP8JSObjectj($cx, $13, $indent);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7GetCallP8JSObject($proxy) {
  var $1 = __ZNK8JSObject7getSlotEj($proxy, 3);
  return $1;
}

function __ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $proxy, $hint, $vp) {
  var $1 = $cx;
  var $2 = $proxy;
  var $3 = __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($1, $2, $hint, $vp);
  return ($3 | 0) != 0;
}

function __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__;
    __ZN2js15AutoValueRooterC1EP9JSContext($rval, $cx);
    var $1 = $vp + 8 | 0;
    var $2 = __ZL7GetCallP8JSObject($proxy);
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js15AutoValueRooter4addrEv($rval);
    var $5 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $2, $argc, $3, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK2js15AutoValueRooter5valueEv($rval);
    var $8 = $7 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    __label__ = 3;
    break;
   case 3:
    __ZN2js15AutoValueRooterD1Ev($rval);
    STACKTOP = __stackBase__;
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($this, $cx, $proxy, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZL12GetConstructP8JSObject($fval, $proxy);
    var $2 = __ZNK2JS5Value11isUndefinedEv($fval);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL7GetCallP8JSObject($proxy);
    var $5 = __ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_($cx, $4, $argc, $argv, $rval);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv3073($1);
    var $7 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12GetConstructP8JSObject($agg_result, $proxy) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8numSlotsEv($proxy);
    if ($1 >>> 0 < 5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv3073($agg_result);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZNK8JSObject7getSlotEj($proxy, 4);
    var $6 = $5 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $agg_result | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3073($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $proxy, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject3074($1, $proxy);
  var $2 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 31, 1, $1, 0, 0, 0);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2JSL11ObjectValueER8JSObject3074($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject($this, $cx, $proxy) {
  var $1 = __ZNK8JSObject15isFunctionProxyEv($proxy);
  var $2 = $1 ? 2 : 1;
  return $2;
}

function __ZN22JSScriptedProxyHandlerC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js14JSProxyHandlerC2EPv($1, __ZL27sScriptedProxyHandlerFamily);
  HEAP32[$this >> 2] = __ZTV22JSScriptedProxyHandler + 8 | 0;
  return;
}

function __ZN22JSScriptedProxyHandlerD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $15 = __ZNK2JS5Value11isUndefinedEv($10);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc);
    var $26 = 1;
    __label__ = 7;
    break;
   case 5:
    var $21 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $22 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $21, $10);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $10, $desc);
    var $26 = $24;
    __label__ = 7;
    break;
   case 7:
    var $26;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($proxy);
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($1);
  return $2;
}

function __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = __ZL13js_IsCallableRKN2JS5ValueE3075($fvalp);
    if ($3) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $5 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes);
    if (($5 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($cx, 2, 0, 22, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $8, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $id, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $2 = $cx;
    var $3 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setStringEP8JSString($rval, $3);
    var $6 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, 1, $rval, $rval);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $atom, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bytes = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $4 = __Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString($cx, $atom, $bytes);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($1, $proxy);
    var $7 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $8 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 212, 1, $1, 0, $7, 0);
    __label__ = 4;
    break;
   case 4:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $obj, $v, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $descs = __stackBase__;
    __ZN2js23AutoPropDescArrayRooterC1EP9JSContext($descs, $cx);
    var $1 = __ZN2js23AutoPropDescArrayRooter6appendEv($descs);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb($1, $4, $v, 1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$desc >> 2] = $obj;
    var $8 = $1 + 8 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $desc + 16 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    HEAP32[$desc + 4 >> 2] = HEAPU8[$1 + 32 | 0] & 255;
    var $15 = __ZNK2js8PropDesc6getterEv($1);
    HEAP32[$desc + 8 >> 2] = $15;
    var $18 = __ZNK2js8PropDesc6setterEv($1);
    HEAP32[$desc + 12 >> 2] = $18;
    HEAP32[$desc + 24 >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js23AutoPropDescArrayRooterD1Ev($descs);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210436 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $15 = __ZNK2JS5Value11isUndefinedEv($10);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor($desc);
    var $26 = 1;
    __label__ = 7;
    break;
   case 5:
    var $21 = HEAP32[HEAP32[$2 >> 2] + 210440 >> 2] | 0;
    var $22 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $21, $10);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $10, $desc);
    var $26 = $24;
    __label__ = 7;
    break;
   case 7:
    var $26;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $proxy, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $fval = __stackBase__ + 24;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210444 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $11 = $cx;
    var $12 = $desc;
    var $13 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($11, $12, $10);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $16 = $15 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $19 = $18 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = __ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_($cx, $1, $17$0, $17$1, $id, $20$0, $20$1, $10);
    var $23 = $21;
    __label__ = 4;
    break;
   case 4:
    var $23;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $23;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $id, $_0_0_0_val1$0, $_0_0_0_val1$1, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $argv = __stackBase__ + 8;
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $2 = $cx;
    var $3 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setStringEP8JSString($rval, $3);
    var $6 = $argv | 0;
    var $7 = $rval | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $argv | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $_04 = $argv + 8 | 0;
    HEAP32[$_04 >> 2] = $_0_0_0_val1$0;
    HEAP32[$_04 + 4 >> 2] = $_0_0_0_val1$1;
    var $10 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, 2, $6, $rval);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210452 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $12$0, $12$1, 0, 0, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $10, $props);
    var $17 = $15;
    __label__ = 4;
    break;
   case 4:
    var $17;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $handler, $_0_0_0_val$0, $_0_0_0_val$1, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $fval = __stackBase__;
  var $1 = __stackBase__ + 8;
  var $2 = $fval | 0;
  HEAP32[$2 >> 2] = $_0_0_0_val$0;
  HEAP32[$2 + 4 >> 2] = $_0_0_0_val$1;
  __ZN2JSL11ObjectValueER8JSObject3074($1, $handler);
  var $3 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $fval, $argc, $argv, $rval);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $array, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $v = __stackBase__ + 4;
    var $id = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $2 = __ZNK2JS5Value11isPrimitiveEv($array);
    if ($2) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($array);
    var $5 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $4, $length);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = HEAPU32[$length >> 2];
    var $8 = $cx + 52 | 0;
    var $9 = $props;
    var $n_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $n_0;
    if ($n_0 >>> 0 < $7 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 5:
    if ((HEAP32[HEAP32[$8 >> 2] + 144280 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = __Z26js_InvokeOperationCallbackP9JSContext($cx);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($4, $cx, $n_0, $v);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = __ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi($cx, $v, $id);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = HEAP32[$id >> 2];
    var $26 = __Z22js_CheckForStringIndexi($25);
    HEAP32[$1 >> 2] = $26;
    var $27 = __ZN2js16AutoVectorRooterIiE6appendERKi($9, $1);
    if ($27) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 4;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210448 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $16 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $12$0, $12$1, $id, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $16 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $16 = 1;
    __label__ = 4;
    break;
   case 4:
    var $16;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $16;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($v, $bp) {
  var $1 = __Z17js_ValueToBooleanRKN2JS5ValueE($v);
  HEAP8[$bp] = ($1 | 0) != 0 & 1;
  return;
}

function __ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210456 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = $10 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $12$0, $12$1, 0, 0, $7);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $15 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $10, $props);
    var $17 = $15;
    __label__ = 4;
    break;
   case 4:
    var $17;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $17;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE($this, $cx, $proxy, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210460 >> 2] | 0;
    var $7 = __ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $vp);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $vp | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $10$0, $10$1, 0, 0, $vp);
    var $13 = $11;
    __label__ = 3;
    break;
   case 3:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210464 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb($13, $cx, $proxy, $id, $bp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = $10 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $17$0, $17$1, $id, $7);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var $1 = __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp);
  return $1;
}

function __ZL13js_IsCallableRKN2JS5ValueE3075($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210468 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb($13, $cx, $proxy, $id, $bp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = $10 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_($cx, $1, $17$0, $17$1, $id, $7);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb($10, $bp);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $argv = __stackBase__ + 40;
    var $fval = __stackBase__ + 56;
    var $3 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $4 = $cx;
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($4, $1);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString3077($2, $5);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $2);
    var $8 = $argv | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($8, $receiver);
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 8 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 210220 >> 2] | 0;
    var $18 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $19 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $3, $17, $18);
    if ($19) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $21 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $22 = __ZL13js_IsCallableRKN2JS5ValueE3075($21);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = $this | 0;
    var $25 = __ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($24, $cx, $proxy, $receiver, $id, $vp);
    var $_0 = $25;
    __label__ = 6;
    break;
   case 5:
    var $27 = $21 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $3, $28$0, $28$1, 2, $8, $vp);
    var $_0 = $29;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE["X"] = 1;

function __ZN2jsL9IdToValueEi3076($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING3137($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING3138($id);
    __ZN2JSL11StringValueEP8JSString3077($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT3139($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT3141($id);
    __ZN2JSL10Int32ValueEi3140($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT3142($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT3143($id);
    __ZN2JSL11ObjectValueER8JSObject3074($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv3073($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11StringValueEP8JSString3077($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL17ObjectOrNullValueEP8JSObject3078($agg_result, $obj) {
  __ZN2JS5Value15setObjectOrNullEP8JSObject($agg_result, $obj);
  return;
}

function __ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $argv = __stackBase__ + 40;
    var $fval = __stackBase__ + 64;
    var $3 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2jsL9IdToValueEi3076($1, $id);
    var $4 = $cx;
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($4, $1);
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString3077($2, $5);
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $2);
    var $8 = $argv | 0;
    __ZN2JSL17ObjectOrNullValueEP8JSObject3078($8, $receiver);
    var $9 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $10 = $9 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $argv + 8 | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = $vp | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $argv + 16 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __ZN2js15AutoValueRooterC1EP9JSContext($fval, $cx);
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210296 >> 2] | 0;
    var $21 = __ZN2js15AutoValueRooter4addrEv($fval);
    var $22 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $3, $20, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $24 = __ZNK2js15AutoValueRooter5valueEv($fval);
    var $25 = __ZL13js_IsCallableRKN2JS5ValueE3075($24);
    if ($25) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = $this | 0;
    var $28 = __ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($27, $cx, $proxy, $receiver, $id, $strict, $vp);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 5:
    var $30 = $24 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $33 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $3, $31$0, $31$1, 3, $8, $32);
    var $_0 = $33;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($fval);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE["X"] = 1;

function __ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210472 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($13, $cx, $proxy, $props);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = $10 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $17$0, $17$1, 0, 0, $7);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = __ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE($cx, $10, $props);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = __ZL21GetProxyHandlerObjectP9JSContextP8JSObject($proxy);
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $2 = $cx + 52 | 0;
    var $6 = HEAP32[HEAP32[$2 >> 2] + 210476 >> 2] | 0;
    var $7 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $8 = __ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $1, $6, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3075($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $this | 0;
    var $14 = __ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($13, $cx, $proxy, $flags, $vp);
    var $_0 = $14;
    __label__ = 6;
    break;
   case 4:
    var $16 = $10 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = __ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_($cx, $1, $17$0, $17$1, 0, 0, $vp);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = HEAP32[HEAP32[$2 >> 2] + 210476 >> 2] | 0;
    var $24 = __ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE($cx, $proxy, $23, $vp);
    var $_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 8 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $set, $desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($this, $cx, $proxy) {
  __ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject($this, $cx, $proxy);
  return;
}

function __ZN25AutoPendingProxyOperationD1Ev($this) {
  __ZN25AutoPendingProxyOperationD2Ev($this);
  return;
}

function __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibPN2JS5ValueE($cx, $proxy, $id, $set, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    var $desc = __stackBase__ + 16;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $desc + 16 | 0;
    var $8 = __ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $13 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = $7;
    var $10 = $cx;
    var $11 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($10, $phitmp, $vp);
    var $13 = $11;
    __label__ = 5;
    break;
   case 5:
    var $13;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 12 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $set, $desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibPN2JS5ValueE($cx, $proxy, $id, $set, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    var $desc = __stackBase__ + 16;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $desc + 16 | 0;
    var $8 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $proxy, $id, $set, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $13 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $phitmp = $7;
    var $10 = $cx;
    var $11 = __ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE($10, $phitmp, $vp);
    var $13 = $11;
    __label__ = 5;
    break;
   case 5:
    var $13;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $proxy, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 16 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE($cx, $proxy, $id, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    var $desc = __stackBase__ + 16;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $7 = $desc + 16 | 0;
    var $8 = __ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor($cx, $proxy, $v, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $proxy, $id, $7);
    var $12 = $10;
    __label__ = 5;
    break;
   case 5:
    var $12;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 20 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 24 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 28 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE($cx, $proxy, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 32 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 36 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb($cx, $proxy, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 40 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $id, $bp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $proxy, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 44 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $receiver, $id, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($cx, $proxy, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 48 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $receiver, $id, $strict, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE($cx, $proxy, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 52 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $props);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $proxy, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 56 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $flags, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $proxy, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 60 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $argc, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($cx, $proxy, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 64 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $argc, $argv, $rval);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($cx, $proxy, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 68 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $vp, $bp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy6typeOfEP9JSContextP8JSObject($cx, $proxy) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 72 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14JSProxyHandler13isOuterWindowEv($this) {
  return 0;
}

function __ZL19OperationInProgressP9JSContextP8JSObject($cx_0_11_val, $proxy) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $op_0_in = $cx_0_11_val + 209884 | 0;
    __label__ = 2;
    break;
   case 2:
    var $op_0_in;
    var $op_0 = HEAP32[$op_0_in >> 2];
    if (($op_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$op_0 + 4 >> 2] | 0) == ($proxy | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $op_0_in = $op_0 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb3110($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject($cx, $proxy) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 76 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj($cx, $proxy, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 80 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $indent);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__ + 4;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $7 = __ZNK8JSObject15getProxyHandlerEv($proxy);
    var $11 = HEAP32[HEAP32[$7 >> 2] + 84 >> 2];
    var $12 = FUNCTION_TABLE[$11]($7, $cx, $proxy, $hint, $vp);
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp) {
  var $1 = __ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $proxy, $hint, $vp);
  return $1 & 1;
}

function __ZL14proxy_FinalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7getSlotEj($obj, 0);
    var $2 = __ZNK2JS5Value11isUndefinedEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject15getProxyHandlerEv($obj);
    var $8 = HEAP32[HEAP32[$4 >> 2] + 88 >> 2];
    FUNCTION_TABLE[$8]($4, $cx, $obj);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $proxy, $v, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pending = __stackBase__;
    var $b = __stackBase__ + 12;
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $1 = __ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($cx, $proxy, $v, $b);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$bp >> 2] = HEAP8[$b] & 1 & 255;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_TraceObjectP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject15getProxyHandlerEv($obj);
    var $6 = HEAP32[HEAP32[$2 >> 2] + 92 >> 2];
    FUNCTION_TABLE[$6]($2, $trc, $obj);
    var $7 = __ZNK8JSObject15getProxyPrivateEv($obj);
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $7, undef);
    var $8 = __ZNK8JSObject13getProxyExtraEv($obj);
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $8, undef);
    var $9 = __ZNK8JSObject15isFunctionProxyEv($obj);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZL7GetCallP8JSObject($obj);
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $11, undef);
    __ZL12GetConstructP8JSObject($1, $obj);
    __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb($cx, $obj, $1, $found);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP8[$found] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $3, $objp, $propp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var $desc = __stackBase__;
  var $1 = __Z22js_CheckForStringIndexi($id);
  __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
  var $2 = $desc + 16 | 0;
  HEAP32[$2 >> 2] = $obj;
  var $4 = $value | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $desc + 32 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  HEAP32[$desc + 20 >> 2] = $attrs & -257;
  HEAP32[$desc + 24 >> 2] = $getter;
  HEAP32[$desc + 28 >> 2] = $setter;
  HEAP32[$desc + 40 >> 2] = 0;
  var $12 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $1, $2);
  var $13 = $12 & 1;
  __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
  STACKTOP = __stackBase__;
  return $13;
}

function __ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $3, $value, $getter, $setter, $attrs);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $value, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $1, $value, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = __ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  return $2 & 1;
}

function __ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3129($1);
  var $3 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $3, $vp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __Z22js_CheckForStringIndexi($id);
  var $2 = ($strict | 0) != 0;
  var $3 = __ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE($cx, $obj, $obj, $1, $2, $vp);
  return $3 & 1;
}

function __ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $3, $vp, $strict);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $2 = $desc + 16 | 0;
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $1, 0, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$desc + 20 >> 2];
    HEAP32[$attrsp >> 2] = $6;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $3, $attrsp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext($desc, $cx);
    var $2 = $desc + 16 | 0;
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $1, 1, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$attrsp >> 2] & -257;
    HEAP32[$desc + 20 >> 2] = $6;
    var $8 = __ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($cx, $obj, $1, $2);
    var $_0 = $8 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $3, $attrsp);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $deleted = __stackBase__;
    var $1 = __Z22js_CheckForStringIndexi($id);
    var $2 = __ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb($cx, $obj, $1, $deleted);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $obj;
    var $6 = __Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti($4, $5, $1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = (HEAP8[$deleted] & 1) << 24 >> 24 != 0;
    __ZN2JS5Value10setBooleanEb($rval, $10);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$id >> 2];
    var $4 = __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $3, $rval, $strict);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_idx_val);
  var $2 = __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12proxy_TypeOfP9JSContextP8JSObject($cx, $proxy) {
  var $1 = __ZN2js7JSProxy6typeOfEP9JSContextP8JSObject($cx, $proxy);
  return $1;
}

function __ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $fixed, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isFixed = __stackBase__;
    var $1 = __ZN2js8FixProxyEP9JSContextP8JSObjectPi($cx, $obj, $isFixed);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$fixed] = (HEAP32[$isFixed >> 2] | 0) != 0 & 1;
    var $7 = $cx;
    var $8 = $obj;
    var $9 = $props;
    var $10 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($7, $8, 24, $9);
    var $_0 = $10 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17proxy_innerObjectP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($obj);
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($1);
  return $2;
}

function __ZL10proxy_CallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZNK2JS5Value8toObjectEv($vp);
  var $2 = __ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $1, $argc, $vp);
  return $2 & 1;
}

function __ZL15proxy_ConstructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZNK2JS5Value8toObjectEv($vp);
  var $2 = $vp + 16 | 0;
  var $3 = __ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_($cx, $1, $argc, $2, $vp);
  return $3 & 1;
}

function __ZL19proxy_TraceFunctionP8JSTracerP8JSObject($trc, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL17proxy_TraceObjectP8JSTracerP8JSObject($trc, $obj);
  var $2 = __ZL7GetCallP8JSObject($obj);
  __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $2, undef);
  __ZL12GetConstructP8JSObject($1, $obj);
  __ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc($trc, $1, undef);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, $handler, $priv, $proto, $parent, $call, $construct) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = ($call | 0) != 0;
    var $6 = $4 | ($construct | 0) != 0;
    if ($6) {
      var $clasp_0 = __ZN2js18FunctionProxyClassE;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$handler >> 2] + 96 >> 2];
    var $12 = FUNCTION_TABLE[$11]($handler);
    var $13 = $12 ? __ZN2js21OuterWindowProxyClassE : __ZN2js16ObjectProxyClassE;
    var $clasp_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $clasp_0;
    if (($proto | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 1);
    __label__ = 5;
    break;
   case 5:
    var $19 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103($cx, $clasp_0, $proto, $parent);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = $19;
    var $23 = $cx;
    var $24 = __ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj($22, $23, 0);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $26 = $handler;
    __ZN2JSL12PrivateValueEPv3104($1, $26);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 0, $1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 1, $priv);
    if ($6) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    if ($4) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    __ZN2JSL11ObjectValueER8JSObject3074($2, $call);
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL14UndefinedValueEv3073($2);
    __label__ = 11;
    break;
   case 11:
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 3, $2);
    if (($construct | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JSL11ObjectValueER8JSObject3074($3, $construct);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($19, 4, $3);
    __label__ = 13;
    break;
   case 13:
    var $34 = __ZNK8JSObject4typeEv($19);
    __ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb($cx, $34, 0);
    var $_0 = $19;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103($cx, $clasp, $proto, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb3110($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $5);
  return $6;
}

function __ZN2JSL12PrivateValueEPv3104($agg_result, $ptr) {
  __ZN2JS5Value10setPrivateEPv($agg_result, $ptr);
  return;
}

function __ZL12proxy_createP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str53058 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      var $proto_02 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $vp + 24 | 0;
    var $14 = __ZNK2JS5Value8isObjectEv($13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $proto_02 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZNK2JS5Value8toObjectEv($13);
    var $17 = __ZNK8JSObject9getParentEv($16);
    if (($17 | 0) == 0) {
      var $proto_02 = $16;
      __label__ = 7;
      break;
    } else {
      var $parent_1 = $17;
      var $proto_01 = $16;
      __label__ = 8;
      break;
    }
   case 7:
    var $proto_02;
    var $19 = __ZNK2JS5Value8toObjectEv($vp);
    var $20 = __ZNK8JSObject9getParentEv($19);
    var $parent_1 = $20;
    var $proto_01 = $proto_02;
    __label__ = 8;
    break;
   case 8:
    var $proto_01;
    var $parent_1;
    __ZN2JSL11ObjectValueER8JSObject3074($1, $8);
    var $22 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, __ZN22JSScriptedProxyHandler9singletonE | 0, $1, $proto_01, $parent_1, 0, 0);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $22);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $proto = __stackBase__;
    var $1 = __stackBase__ + 4;
    if ($argc >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str63059 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str163973 | 0, HEAP32[tempInt + 8 >> 2] = __str93064 | 0, tempInt));
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $5 = $vp + 16 | 0;
    var $6 = $cx;
    var $7 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value8toObjectEv($vp);
    var $12 = __ZNK8JSObject9getParentEv($11);
    var $13 = $12;
    var $14 = $proto;
    var $15 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($6, $13, 2, $14, 0);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = HEAPU32[$proto >> 2];
    var $19 = __ZNK8JSObject9getParentEv($18);
    var $20 = $vp + 24 | 0;
    var $21 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $20, 65536);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($argc >>> 0 > 2) {
      __label__ = 7;
      break;
    } else {
      var $construct_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $26 = $vp + 32 | 0;
    var $27 = __Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj($cx, $26, 65536);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $construct_0 = $27;
      __label__ = 8;
      break;
    }
   case 8:
    var $construct_0;
    __ZN2JSL11ObjectValueER8JSObject3074($1, $8);
    var $30 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, __ZN22JSScriptedProxyHandler9singletonE | 0, $1, $18, $19, $21, $construct_0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JS5Value9setObjectER8JSObject($vp, $30);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18callable_ConstructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fval = __stackBase__;
    var $protov = __stackBase__ + 8;
    var $proto = __stackBase__ + 16;
    var $rval = __stackBase__ + 20;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $cx;
    var $5 = $3;
    var $6 = __Z13js_CreateThisP9JSContextP8JSObject($4, $5);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK2JS5Value8toObjectEv($vp);
    var $11 = __ZNK8JSObject7getSlotEj($10, 1);
    var $12 = $11 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $fval | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value11isUndefinedEv($fval);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 3:
    var $17 = __ZNK8JSObject7getSlotEj($10, 0);
    var $18 = $17 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $st$6$0 = $14 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $14 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    var $23 = HEAP32[HEAP32[$cx + 52 >> 2] + 210200 >> 2];
    var $24 = __ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE($10, $cx, $23, $protov);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $27 = __ZNK2JS5Value8isObjectEv($protov);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $29 = __ZNK2JS5Value8toObjectEv($protov);
    HEAP32[$proto >> 2] = $29;
    var $35 = $29;
    __label__ = 8;
    break;
   case 6:
    var $31 = $proto;
    var $32 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($4, 0, 1, $31, 0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $35 = HEAP32[$proto >> 2];
    __label__ = 8;
    break;
   case 8:
    var $35;
    var $36 = __ZNK8JSObject9getParentEv($35);
    var $37 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105($cx, $35, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL11ObjectValueER8JSObject3074($1, $37);
    var $40 = __ZNK8JSObject7getSlotEj($10, 0);
    var $41 = $vp + 16 | 0;
    var $42 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $1, $40, $argc, $41, $rval);
    if ($42) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $44 = __ZNK2JS5Value11isPrimitiveEv($rval);
    if ($44) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2JS5Value9setObjectER8JSObject($vp, $37);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 12:
    var $47 = $rval | 0;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = $vp | 0;
    var $st$6$0 = $49 | 0;
    HEAP32[$st$6$0 >> 2] = $48$0;
    var $st$6$1 = $49 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $48$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 13:
    __ZN2JSL11ObjectValueER8JSObject3074($2, $7);
    var $51 = $vp + 16 | 0;
    var $52 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $2, $fval, $argc, $51, $vp);
    var $_0 = $52 & 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18callable_ConstructP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3110($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127($cx, $proto, $parent, $4);
  return $5;
}

function __ZL13callable_CallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZNK2JS5Value8toObjectEv($vp);
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = $vp + 8 | 0;
  var $4 = $vp + 16 | 0;
  var $5 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($cx, $3, $2, $argc, $4, $vp);
  return $5 & 1;
}

function __ZN2js8FixProxyEP9JSContextP8JSObjectPi($cx, $proxy, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $tvr2 = __stackBase__ + 24;
    var $1 = __stackBase__ + 40;
    var $pending = __stackBase__ + 48;
    var $cx_idx_val = HEAP32[$cx + 52 >> 2];
    var $2 = __ZL19OperationInProgressP9JSContextP8JSObject($cx_idx_val, $proxy);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 249, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 15;
    break;
   case 3:
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $cx);
    var $5 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $6 = __ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE($cx, $proxy, $5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      var $_2 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $8 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $9 = __ZNK2JS5Value11isUndefinedEv($8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$bp >> 2] = 0;
    var $_2 = 1;
    __label__ = 14;
    break;
   case 6:
    var $12 = $cx;
    var $13 = __ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE($12, $8);
    if (($13 | 0) == 0) {
      var $_2 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK8JSObject8getProtoEv($proxy);
    var $17 = __ZNK8JSObject9getParentEv($proxy);
    var $18 = __ZNK8JSObject15isFunctionProxyEv($proxy);
    var $19 = $18 ? __ZN2js19CallableObjectClassE : __ZN2js11ObjectClassE;
    var $20 = $proxy;
    var $21 = __ZNK2js2gc4Cell12getAllocKindEv($20);
    var $22 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $19, $16, $17, $21);
    if (($22 | 0) == 0) {
      var $_2 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr2, $cx, $22);
    if ($18 | (__ZN2js11ObjectClassE | 0) == (__ZN2js19CallableObjectClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = __ZL7GetCallP8JSObject($proxy);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($22, 0, $27);
    __ZL12GetConstructP8JSObject($1, $proxy);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($22, 1, $1);
    __label__ = 10;
    break;
   case 10:
    __ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject($pending, $cx, $proxy);
    var $29 = $22;
    var $30 = __Z17js_PopulateObjectP9JSContextP8JSObjectS2_($12, $29, $13);
    var $not_ = ($30 | 0) == 0;
    __ZN25AutoPendingProxyOperationD1Ev($pending);
    if ($not_) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $32 = $proxy;
    var $33 = __ZN8JSObject4swapEP9JSContextPS_($32, $12, $29);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$bp >> 2] = 1;
    var $_1 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    __ZN2js16AutoObjectRooterD1Ev($tvr2);
    var $_2 = $_1;
    __label__ = 14;
    break;
   case 14:
    var $_2;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    var $_3 = $_2;
    __label__ = 15;
    break;
   case 15:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8FixProxyEP9JSContextP8JSObjectPi["X"] = 1;

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE($cx, $clasp, $proto, $parent, $kind) {
  var $1 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $kind);
  return $1;
}

function _js_InitProxyClass($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    var $7 = __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL3109($1, $2);
    var $8 = _JS_DefineProperty($cx, $obj, STRING_TABLE._js_Proxy_str | 0, $1, 10, 12, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_DefineFunctions($cx, $2, __ZL14static_methods | 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $obj;
    __ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE($14, __ZN2js10ProxyClassE);
    var $_0 = $2;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108($cx, $parent) {
  var $3 = HEAPU32[__ZN2js10ProxyClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3110($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111($cx, $parent, $4);
  return $5;
}

function _OBJECT_TO_JSVAL3109($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3126($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3125($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj3130($bits) {
  return $bits;
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js10ProxyClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_STRING3137($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING3138($iden) {
  return $iden;
}

function _JSID_IS_INT3139($iden) {
  return $iden & 1;
}

function _JSID_TO_INT3141($iden) {
  return $iden >> 1;
}

function _JSID_IS_OBJECT3142($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT3143($iden) {
  return $iden & -8;
}

function _INT_TO_JSID3398($i) {
  return $i << 1 | 1;
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3125($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _OBJECT_TO_JSVAL_IMPL3126($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN25AutoPendingProxyOperationD2Ev($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $5 = HEAP32[$this >> 2] + 65604 | 0;
  HEAP32[$5 >> 2] = $2;
  return;
}

function __ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject($this, $cx, $proxy) {
  var $3 = HEAP32[$cx + 52 >> 2];
  var $4 = $3 + 144280 | 0;
  HEAP32[$this >> 2] = $4;
  var $6 = HEAP32[$3 + 209884 >> 2];
  var $7 = $this + 4 | 0;
  HEAP32[$7 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = $proxy;
  var $10 = $3 + 209884 | 0;
  HEAP32[$10 >> 2] = $7;
  return;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $17 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZNK8JSObject9getParentEv($4);
    var $17 = $15;
    __label__ = 7;
    break;
   case 7:
    var $17;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($10, undef, __ZN2js10ProxyClassE, $9, $17, 0, (__ZN2js10ProxyClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $18 = __ZNK2js5Class8isNativeEv(__ZN2js10ProxyClassE);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $10, __ZN2js10ProxyClassE, $9, $kind);
    if ($20) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($10);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js10ProxyClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = __ZNK8JSObject8numSlotsEv($obj);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $obj;
    var $9 = $cx;
    var $10 = __ZN8JSObject10allocSlotsEP9JSContextj($8, $9, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $12 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, $clasp);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, $clasp, $kind);
    var $empty_0 = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, $clasp);
    var $empty_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($parent | 0) != 0 | $1 ^ 1) {
      var $12 = $parent;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZNK8JSObject9getParentEv($proto);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    var $13 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, $clasp, $5, $12, 0, $13);
    var $14 = __ZNK2js5Class8isNativeEv($clasp);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $16 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115($cx, $6, $clasp, $5, $kind);
    if ($16) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZN2jsL15MakeRangeGCSafeEPiS0_($beg, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($beg | 0) == ($end | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = _INT_TO_JSID3072(0);
    var $id_01 = $beg;
    __label__ = 3;
    break;
   case 3:
    var $id_01;
    HEAP32[$id_01 >> 2] = $2;
    var $4 = $id_01 + 4 | 0;
    if (($4 | 0) == ($end | 0)) {
      __label__ = 4;
      break;
    } else {
      var $id_01 = $4;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = $this;
    var $9 = __ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj($8, $incr);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $11;
    HEAP32[$3 >> 2] = $11 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js11ObjectClassE, $1, $parent, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js11ObjectClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom3129($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3130($1);
  return $2;
}

function __ZNK8JSObject13getProxyExtraEv($this) {
  var $1 = __ZNK8JSObject7getSlotEj($this, 2);
  return $1;
}

function __ZN2JSL10Int32ValueEi3140($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE($cx, $handler, $atom, $fvalp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZL12ATOM_TO_JSIDP6JSAtom3129($atom);
    var $8 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($handler, $cx, $7, $fvalp);
    var $_0 = ($8 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tv = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $3 = HEAP32[$this >> 2];
    var $4 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($3, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE($this, $4, $pos);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[__ZN2js13nodeTypeNamesE + ($type << 2) >> 2];
    var $11 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $10, $tv);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = $tv | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $1 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $4, STRING_TABLE.__str1763328 | 0, $1);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$dst >> 2] = $4;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($cx, $parent) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3408($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409($cx, $parent, $4);
  return $5;
}

function __ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE($this, $node, $pos) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL9NullValueEv3400($1);
    var $8 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $node, STRING_TABLE.__str1823334 | 0, $1);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = $loc | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $2 | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $node, STRING_TABLE.__str1823334 | 0, $2);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $s, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = _strlen($s);
    var $4 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($2, $s, $3, 0, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4 | 0;
    __ZN2JS5Value9setStringEP8JSString($dst, $7);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $obj, $name, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $val | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value7isMagicE10JSWhyMagic($val, undef);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($val);
    __label__ = 3;
    break;
   case 3:
    var $8 = $this | 0;
    var $9 = HEAP32[$8 >> 2];
    var $10 = _strlen($name);
    var $11 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($9, $name, $10, 0, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$8 >> 2];
    var $15 = __ZL12ATOM_TO_JSIDP6JSAtom3421($11);
    var $16 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $14, $15, $val, 10, 12, 1);
    var $_0 = ($16 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($2, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $elts | 0;
    var $7 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($6);
    var $8 = $val | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $12 = __ZN2js16AutoVectorRooterIN2JS5ValueEEixEj($6, $i_0);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    HEAP32[$8 >> 2] = $14$0;
    HEAP32[$8 + 4 >> 2] = $14$1;
    var $15 = __ZNK2JS5Value7isMagicE10JSWhyMagic($val, undef);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = HEAP32[$1 >> 2];
    var $18 = _INT_TO_JSID3398($i_0);
    var $19 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($3, $17, $18, $val, 0);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 7:
    __ZN2JS5Value9setObjectER8JSObject($dst, $3);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $loc = __stackBase__;
    var $to = __stackBase__ + 4;
    var $tv = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __stackBase__ + 32;
    var $4 = __stackBase__ + 40;
    var $5 = __stackBase__ + 48;
    var $6 = __stackBase__ + 56;
    var $7 = __stackBase__ + 64;
    if (($pos | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($dst);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 3:
    var $11 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this, $loc);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $13 = HEAP32[$loc >> 2];
    __ZN2JS5Value9setObjectER8JSObject($dst, $13);
    var $14 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this, $to);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 5:
    var $16 = HEAP32[$to >> 2];
    __ZN2JSL11ObjectValueER8JSObject3399($1, $16);
    var $17 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, STRING_TABLE.__str1773329 | 0, $1);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $20 = HEAP32[$pos + 4 >> 2];
    var $21 = __ZN2JS5Value9setNumberEj($tv, $20);
    var $22 = $tv | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $2 | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $25 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $16, STRING_TABLE.__str1783330 | 0, $2);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $28 = HEAP32[$pos >> 2];
    var $29 = __ZN2JS5Value9setNumberEj($tv, $28);
    var $st$3$0 = $22 | 0;
    var $30$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $22 + 4 | 0;
    var $30$1 = HEAP32[$st$3$1 >> 2];
    var $31 = $3 | 0;
    var $st$8$0 = $31 | 0;
    HEAP32[$st$8$0 >> 2] = $30$0;
    var $st$8$1 = $31 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $30$1;
    var $32 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $16, STRING_TABLE.__str1793331 | 0, $3);
    if ($32) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    var $34 = __ZN2js11NodeBuilder9newObjectEPP8JSObject($this, $to);
    if ($34) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 9:
    var $36 = HEAP32[$to >> 2];
    __ZN2JSL11ObjectValueER8JSObject3399($4, $36);
    var $37 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, STRING_TABLE.__str1803332 | 0, $4);
    if ($37) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    var $40 = HEAP32[$pos + 12 >> 2];
    var $41 = __ZN2JS5Value9setNumberEj($tv, $40);
    var $st$3$0 = $22 | 0;
    var $42$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $22 + 4 | 0;
    var $42$1 = HEAP32[$st$3$1 >> 2];
    var $43 = $5 | 0;
    var $st$8$0 = $43 | 0;
    HEAP32[$st$8$0 >> 2] = $42$0;
    var $st$8$1 = $43 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $42$1;
    var $44 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $36, STRING_TABLE.__str1783330 | 0, $5);
    if ($44) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 11:
    var $47 = HEAP32[$pos + 8 >> 2];
    var $48 = __ZN2JS5Value9setNumberEj($tv, $47);
    var $st$3$0 = $22 | 0;
    var $49$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $22 + 4 | 0;
    var $49$1 = HEAP32[$st$3$1 >> 2];
    var $50 = $6 | 0;
    var $st$8$0 = $50 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $50 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $51 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $36, STRING_TABLE.__str1793331 | 0, $6);
    if ($51) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $53 = $this + 16 | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55 = $7 | 0;
    HEAP32[$55 >> 2] = $54$0;
    HEAP32[$55 + 4 >> 2] = $54$1;
    var $56 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, STRING_TABLE._js_source_str | 0, $7);
    var $_0 = $56;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE["X"] = 1;

function __ZN2js11NodeBuilder9newObjectEPP8JSObject($this, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($2, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$dst >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3399($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN2JSL9NullValueEv3400($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 0, STRING_TABLE.__str1833335 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $type, $propName, $elts, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __stackBase__ + 32;
    var $4 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = $this + 24 + ($type << 3) | 0;
    var $st$1$0 = $6 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $6 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $cb | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $1 | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $7$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $7$1;
    var $12 = $array | 0;
    var $st$6$0 = $12 | 0;
    var $13$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$6$1 >> 2];
    var $14 = $2 | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $1, $2, $pos, $dst);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 4:
    var $17 = $array | 0;
    var $st$1$0 = $17 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = $3 | 0;
    var $st$6$0 = $19 | 0;
    HEAP32[$st$6$0 >> 2] = $18$0;
    var $st$6$1 = $19 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $18$1;
    var $20 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, $type, $pos, $propName, $3, $dst);
    var $_0 = $20;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE["X"] = 1;

function __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 28, STRING_TABLE.__str1833335 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 256 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 29, $pos, STRING_TABLE.__str1843336 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 32;
    var $3 = $0 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $fun | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $13 = $argv | 0;
    var $argv5_0 = $argv | 0;
    HEAP32[$argv5_0 >> 2] = $tmp$0;
    HEAP32[$argv5_0 + 4 >> 2] = $tmp$1;
    var $14 = $loc | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = $argv + 8 | 0;
    HEAP32[$16 >> 2] = $15$0;
    HEAP32[$16 + 4 >> 2] = $15$1;
    var $18 = HEAP32[$this >> 2];
    var $19 = $this + 576 | 0;
    var $20 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($18, $19, $fun, 2, $13, $dst);
    var $_0 = $20;
    __label__ = 5;
    break;
   case 4:
    var $argv17_0 = $argv1 | 0;
    HEAP32[$argv17_0 >> 2] = $tmp$0;
    HEAP32[$argv17_0 + 4 >> 2] = $tmp$1;
    var $23 = HEAP32[$this >> 2];
    var $24 = $this + 576 | 0;
    var $25 = $argv1 | 0;
    var $26 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($23, $24, $fun, 1, $25, $dst);
    var $_0 = $26;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, $type, $pos, $childName, $0, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $_02 = $0 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $3 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$node >> 2];
    var $_03 = $2 | 0;
    HEAP32[$_03 >> 2] = $tmp$0;
    HEAP32[$_03 + 4 >> 2] = $tmp$1;
    var $6 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $5, $childName, $2);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $5, $dst);
    var $10 = 1;
    __label__ = 4;
    break;
   case 4:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 240 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $cb | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value6isNullEv($cb);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $3$0;
    HEAP32[$7 + 4 >> 2] = $3$1;
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 27, $pos, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 24;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $fun | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $12 = $argv | 0;
    var $13 = $loc | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $argv | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $17 = HEAP32[$this >> 2];
    var $18 = $this + 576 | 0;
    var $19 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($17, $18, $fun, 1, $12, $dst);
    var $_0 = $19;
    __label__ = 5;
    break;
   case 4:
    var $21 = $argv1 | 0;
    __ZN2JSL9NullValueEv3400($21);
    var $23 = HEAP32[$this >> 2];
    var $24 = $this + 576 | 0;
    var $25 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($23, $24, $fun, 0, $21, $dst);
    var $_0 = $25;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, $type, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $1 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$node >> 2];
    var $4 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $3, $dst);
    var $6 = 1;
    __label__ = 3;
    break;
   case 3:
    var $6;
    STACKTOP = __stackBase__;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $4 = __stackBase__ + 8;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 32;
    var $8 = __stackBase__ + 40;
    var $9 = __stackBase__ + 48;
    var $10 = __stackBase__ + 56;
    var $11 = __stackBase__ + 64;
    var $_021 = $0 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $1 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $2 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $12 = $this + 272 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $cb | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value6isNullEv($cb);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = $4 | 0;
    var $st$1$0 = $17 | 0;
    HEAP32[$st$1$0 >> 2] = $13$0;
    var $st$1$1 = $17 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $13$1;
    var $_023 = $5 | 0;
    var $st$6$0 = $_023 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp22$0;
    var $st$6$1 = $_023 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp22$1;
    var $_014 = $6 | 0;
    var $st$11$0 = $_014 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_014 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_05 = $8 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($7, undef, $8);
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4, $5, $6, $7, $pos, $dst);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $_025 = $9 | 0;
    var $st$1$0 = $_025 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp22$0;
    var $st$1$1 = $_025 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp22$1;
    var $_016 = $10 | 0;
    var $st$6$0 = $_016 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_016 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_07 = $11 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $20 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 31, $pos, STRING_TABLE._js_test_str | 0, $9, STRING_TABLE.__str1863338 | 0, $10, STRING_TABLE.__str1873339 | 0, $11, $dst);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $3, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 48;
    var $5 = $0 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $fun | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $_021 = $1 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $2 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $3 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $15 = $argv | 0;
    var $argv23_0 = $argv | 0;
    var $st$2$0 = $argv23_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp22$0;
    var $st$2$1 = $argv23_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp22$1;
    var $_014 = $argv + 8 | 0;
    var $st$7$0 = $_014 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp13$0;
    var $st$7$1 = $_014 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp13$1;
    var $_05 = $argv + 16 | 0;
    var $st$12$0 = $_05 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp$0;
    var $st$12$1 = $_05 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp$1;
    var $16 = $loc | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $argv + 24 | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $20 = HEAP32[$this >> 2];
    var $21 = $this + 576 | 0;
    var $22 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($20, $21, $fun, 4, $15, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $24 = $argv1 | 0;
    var $argv125_0 = $argv1 | 0;
    var $st$2$0 = $argv125_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp22$0;
    var $st$2$1 = $argv125_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp22$1;
    var $_016 = $argv1 + 8 | 0;
    var $st$7$0 = $_016 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp13$0;
    var $st$7$1 = $_016 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp13$1;
    var $_07 = $argv1 + 16 | 0;
    var $st$12$0 = $_07 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp$0;
    var $st$12$1 = $_07 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp$1;
    var $26 = HEAP32[$this >> 2];
    var $27 = $this + 576 | 0;
    var $28 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($26, $27, $fun, 3, $24, $dst);
    var $_0 = $28;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder3optEN2JS5ValueE($agg_result, $this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $v | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value7isMagicE10JSWhyMagic($v, undef);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JSL14UndefinedValueEv3403($agg_result);
    __label__ = 4;
    break;
   case 3:
    var $8 = $agg_result | 0;
    HEAP32[$8 >> 2] = $3$0;
    HEAP32[$8 + 4 >> 2] = $3$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, $type, $pos, $childName1, $0, $childName2, $1, $childName3, $2, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $4 = __stackBase__ + 4;
    var $5 = __stackBase__ + 12;
    var $6 = __stackBase__ + 20;
    var $_011 = $0 | 0;
    var $tmp12$0 = HEAP32[$_011 >> 2];
    var $tmp12$1 = HEAP32[$_011 + 4 >> 2];
    var $_06 = $1 | 0;
    var $tmp7$0 = HEAP32[$_06 >> 2];
    var $tmp7$1 = HEAP32[$_06 + 4 >> 2];
    var $_02 = $2 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $7 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $9 = HEAP32[$node >> 2];
    var $_013 = $4 | 0;
    HEAP32[$_013 >> 2] = $tmp12$0;
    HEAP32[$_013 + 4 >> 2] = $tmp12$1;
    var $10 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $9, $childName1, $4);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $_08 = $5 | 0;
    var $st$1$0 = $_08 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp7$0;
    var $st$1$1 = $_08 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp7$1;
    var $12 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $9, $childName2, $5);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $_03 = $6 | 0;
    var $st$1$0 = $_03 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_03 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $9, $childName3, $6);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $18 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $9, $dst);
    var $18 = 1;
    __label__ = 6;
    break;
   case 6:
    var $18;
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $_04 = $0 | 0;
    var $st$6$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$6$1 >> 2];
    var $6 = $this + 320 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $cb | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $7$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $7$1;
    var $_05 = $4 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, undef, $4);
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 37, $pos, STRING_TABLE.__str1883340 | 0, $5, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $_04 = $0 | 0;
    var $st$6$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$6$1 >> 2];
    var $6 = $this + 328 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $cb | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $7$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $7$1;
    var $_05 = $4 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, undef, $4);
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 38, $pos, STRING_TABLE.__str1883340 | 0, $5, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 264 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 30, $pos, STRING_TABLE.__str1883340 | 0, $6, STRING_TABLE.__str1833335 | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 40;
    var $4 = $0 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $fun | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $_012 = $1 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $2 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $14 = $argv | 0;
    var $argv14_0 = $argv | 0;
    var $st$2$0 = $argv14_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp13$0;
    var $st$2$1 = $argv14_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp13$1;
    var $_05 = $argv + 8 | 0;
    var $st$7$0 = $_05 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp$0;
    var $st$7$1 = $_05 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp$1;
    var $15 = $loc | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $argv + 16 | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $19 = HEAP32[$this >> 2];
    var $20 = $this + 576 | 0;
    var $21 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($19, $20, $fun, 3, $14, $dst);
    var $_0 = $21;
    __label__ = 5;
    break;
   case 4:
    var $23 = $argv1 | 0;
    var $argv116_0 = $argv1 | 0;
    var $st$2$0 = $argv116_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp13$0;
    var $st$2$1 = $argv116_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp13$1;
    var $_07 = $argv1 + 8 | 0;
    var $st$7$0 = $_07 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp$0;
    var $st$7$1 = $_07 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp$1;
    var $25 = HEAP32[$this >> 2];
    var $26 = $this + 576 | 0;
    var $27 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($25, $26, $fun, 2, $23, $dst);
    var $_0 = $27;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, $type, $pos, $childName1, $0, $childName2, $1, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $3 = __stackBase__ + 4;
    var $4 = __stackBase__ + 12;
    var $_06 = $0 | 0;
    var $tmp7$0 = HEAP32[$_06 >> 2];
    var $tmp7$1 = HEAP32[$_06 + 4 >> 2];
    var $_02 = $1 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $5 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = HEAP32[$node >> 2];
    var $_08 = $3 | 0;
    HEAP32[$_08 >> 2] = $tmp7$0;
    HEAP32[$_08 + 4 >> 2] = $tmp7$1;
    var $8 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $7, $childName1, $3);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $_03 = $4 | 0;
    HEAP32[$_03 >> 2] = $tmp$0;
    HEAP32[$_03 + 4 >> 2] = $tmp$1;
    var $10 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $7, $childName2, $4);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $14 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $7, $dst);
    var $14 = 1;
    __label__ = 5;
    break;
   case 5:
    var $14;
    STACKTOP = __stackBase__;
    return $14;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 360 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 42, $pos, STRING_TABLE.__str1893341 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $_04 = $0 | 0;
    var $st$6$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$6$1 >> 2];
    var $6 = $this + 344 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $cb | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $7$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $7$1;
    var $_05 = $4 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, undef, $4);
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 40, $pos, STRING_TABLE.__str1893341 | 0, $5, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $3, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $5 = __stackBase__ + 8;
    var $6 = __stackBase__ + 16;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 32;
    var $9 = __stackBase__ + 40;
    var $10 = __stackBase__ + 48;
    var $11 = __stackBase__ + 56;
    var $12 = __stackBase__ + 64;
    var $13 = __stackBase__ + 72;
    var $14 = __stackBase__ + 80;
    var $15 = __stackBase__ + 88;
    var $16 = __stackBase__ + 96;
    var $_030 = $0 | 0;
    var $tmp31$0 = HEAP32[$_030 >> 2];
    var $tmp31$1 = HEAP32[$_030 + 4 >> 2];
    var $_021 = $1 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $2 | 0;
    var $st$24$0 = $_012 | 0;
    var $tmp13$0 = HEAP32[$st$24$0 >> 2];
    var $st$24$1 = $_012 + 4 | 0;
    var $tmp13$1 = HEAP32[$st$24$1 >> 2];
    var $_04 = $3 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $17 = $this + 304 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $cb | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $20 = __ZNK2JS5Value6isNullEv($cb);
    if ($20) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $22 = $5 | 0;
    var $st$1$0 = $22 | 0;
    HEAP32[$st$1$0 >> 2] = $18$0;
    var $st$1$1 = $22 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $18$1;
    var $_032 = $7 | 0;
    var $st$6$0 = $_032 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp31$0;
    var $st$6$1 = $_032 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp31$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($6, undef, $7);
    var $_023 = $9 | 0;
    HEAP32[$_023 >> 2] = $tmp22$0;
    HEAP32[$_023 + 4 >> 2] = $tmp22$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($8, undef, $9);
    var $_014 = $11 | 0;
    HEAP32[$_014 >> 2] = $tmp13$0;
    HEAP32[$_014 + 4 >> 2] = $tmp13$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($10, undef, $11);
    var $_05 = $12 | 0;
    var $st$24$0 = $_05 | 0;
    HEAP32[$st$24$0 >> 2] = $tmp$0;
    var $st$24$1 = $_05 + 4 | 0;
    HEAP32[$st$24$1 >> 2] = $tmp$1;
    var $23 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $5, $6, $8, $10, $12, $pos, $dst);
    var $_0 = $23;
    __label__ = 4;
    break;
   case 3:
    var $_034 = $13 | 0;
    var $st$1$0 = $_034 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp31$0;
    var $st$1$1 = $_034 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp31$1;
    var $_025 = $14 | 0;
    var $st$6$0 = $_025 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp22$0;
    var $st$6$1 = $_025 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp22$1;
    var $_016 = $15 | 0;
    HEAP32[$_016 >> 2] = $tmp13$0;
    HEAP32[$_016 + 4 >> 2] = $tmp13$1;
    var $_07 = $16 | 0;
    HEAP32[$_07 >> 2] = $tmp$0;
    HEAP32[$_07 + 4 >> 2] = $tmp$1;
    var $25 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, 35, $pos, STRING_TABLE.__str1903342 | 0, $13, STRING_TABLE._js_test_str | 0, $14, STRING_TABLE.__str1913343 | 0, $15, STRING_TABLE.__str1833335 | 0, $16, $dst);
    var $_0 = $25;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $3, $4, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $4;
  $4 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$4 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$4 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 56;
    var $6 = $0 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $fun | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $_030 = $1 | 0;
    var $tmp31$0 = HEAP32[$_030 >> 2];
    var $tmp31$1 = HEAP32[$_030 + 4 >> 2];
    var $_021 = $2 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $3 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $4 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $16 = $argv | 0;
    var $argv32_0 = $argv | 0;
    var $st$2$0 = $argv32_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp31$0;
    var $st$2$1 = $argv32_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp31$1;
    var $_023 = $argv + 8 | 0;
    var $st$7$0 = $_023 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp22$0;
    var $st$7$1 = $_023 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp22$1;
    var $_014 = $argv + 16 | 0;
    var $st$12$0 = $_014 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp13$0;
    var $st$12$1 = $_014 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp13$1;
    var $_05 = $argv + 24 | 0;
    var $st$17$0 = $_05 | 0;
    HEAP32[$st$17$0 >> 2] = $tmp$0;
    var $st$17$1 = $_05 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $tmp$1;
    var $17 = $loc | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $argv + 32 | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $21 = HEAP32[$this >> 2];
    var $22 = $this + 576 | 0;
    var $23 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($21, $22, $fun, 5, $16, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 4:
    var $25 = $argv1 | 0;
    var $argv134_0 = $argv1 | 0;
    var $st$2$0 = $argv134_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp31$0;
    var $st$2$1 = $argv134_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp31$1;
    var $_025 = $argv1 + 8 | 0;
    var $st$7$0 = $_025 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp22$0;
    var $st$7$1 = $_025 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp22$1;
    var $_016 = $argv1 + 16 | 0;
    var $st$12$0 = $_016 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp13$0;
    var $st$12$1 = $_016 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp13$1;
    var $_07 = $argv1 + 24 | 0;
    var $st$17$0 = $_07 | 0;
    HEAP32[$st$17$0 >> 2] = $tmp$0;
    var $st$17$1 = $_07 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $tmp$1;
    var $27 = HEAP32[$this >> 2];
    var $28 = $this + 576 | 0;
    var $29 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($27, $28, $fun, 4, $25, $dst);
    var $_0 = $29;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, $childName1, $0, $childName2, $1, $childName3, $2, $childName4, $3, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $5 = __stackBase__ + 4;
    var $6 = __stackBase__ + 12;
    var $7 = __stackBase__ + 20;
    var $8 = __stackBase__ + 28;
    var $_016 = $0 | 0;
    var $tmp17$0 = HEAP32[$_016 >> 2];
    var $tmp17$1 = HEAP32[$_016 + 4 >> 2];
    var $_011 = $1 | 0;
    var $tmp12$0 = HEAP32[$_011 >> 2];
    var $tmp12$1 = HEAP32[$_011 + 4 >> 2];
    var $_06 = $2 | 0;
    var $tmp7$0 = HEAP32[$_06 >> 2];
    var $tmp7$1 = HEAP32[$_06 + 4 >> 2];
    var $_02 = $3 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $9 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $11 = HEAP32[$node >> 2];
    var $_018 = $5 | 0;
    HEAP32[$_018 >> 2] = $tmp17$0;
    HEAP32[$_018 + 4 >> 2] = $tmp17$1;
    var $12 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $childName1, $5);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $22 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    var $_013 = $6 | 0;
    var $st$1$0 = $_013 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp12$0;
    var $st$1$1 = $_013 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp12$1;
    var $14 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $childName2, $6);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $22 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $_08 = $7 | 0;
    var $st$1$0 = $_08 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp7$0;
    var $st$1$1 = $_08 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp7$1;
    var $16 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $childName3, $7);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $22 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_03 = $8 | 0;
    var $st$1$0 = $_03 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_03 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $18 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $11, $childName4, $8);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $22 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $11, $dst);
    var $22 = 1;
    __label__ = 7;
    break;
   case 7:
    var $22;
    STACKTOP = __stackBase__;
    return $22;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_["X"] = 1;

function __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($this, $0, $1, $2, $isForEach, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $4 = __stackBase__ + 8;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 32;
    var $8 = __stackBase__ + 40;
    var $9 = __stackBase__ + 48;
    var $10 = __stackBase__ + 56;
    var $11 = __stackBase__ + 64;
    var $12 = __stackBase__ + 72;
    var $_021 = $0 | 0;
    var $st$11$0 = $_021 | 0;
    var $tmp22$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_021 + 4 | 0;
    var $tmp22$1 = HEAP32[$st$11$1 >> 2];
    var $_012 = $1 | 0;
    var $st$16$0 = $_012 | 0;
    var $tmp13$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $_012 + 4 | 0;
    var $tmp13$1 = HEAP32[$st$16$1 >> 2];
    var $_04 = $2 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $13 = $this + 312 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $cb | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = __ZNK2JS5Value6isNullEv($cb);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $18 = $4 | 0;
    var $st$1$0 = $18 | 0;
    HEAP32[$st$1$0 >> 2] = $14$0;
    var $st$1$1 = $18 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $14$1;
    var $_023 = $5 | 0;
    var $st$6$0 = $_023 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp22$0;
    var $st$6$1 = $_023 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp22$1;
    var $_014 = $6 | 0;
    var $st$11$0 = $_014 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_014 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_05 = $7 | 0;
    var $st$16$0 = $_05 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_05 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($8, $isForEach);
    var $19 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $4, $5, $6, $7, $8, $pos, $dst);
    var $_0 = $19;
    __label__ = 4;
    break;
   case 3:
    var $_025 = $9 | 0;
    var $st$1$0 = $_025 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp22$0;
    var $st$1$1 = $_025 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp22$1;
    var $_016 = $10 | 0;
    var $st$6$0 = $_016 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_016 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_07 = $11 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($12, $isForEach);
    var $21 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_($this, 36, $pos, STRING_TABLE.__str1923344 | 0, $9, STRING_TABLE.__str1933345 | 0, $10, STRING_TABLE.__str1833335 | 0, $11, STRING_TABLE._js_each_str | 0, $12, $dst);
    var $_0 = $21;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2JSL12BooleanValueEb3401($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 336 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 39, $pos, STRING_TABLE._js_object_str | 0, $6, STRING_TABLE.__str1833335 | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 288 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 33, $pos, STRING_TABLE._js_test_str | 0, $6, STRING_TABLE.__str1833335 | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 296 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 34, $pos, STRING_TABLE.__str1833335 | 0, $6, STRING_TABLE._js_test_str | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_($this, $0, $elts, $lexical, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $7 = __stackBase__ + 56;
    var $8 = __stackBase__ + 64;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $9 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = $this + 280 | 0;
    var $st$1$0 = $11 | 0;
    var $12$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    var $13 = $cb | 0;
    var $st$6$0 = $13 | 0;
    HEAP32[$st$6$0 >> 2] = $12$0;
    var $st$6$1 = $13 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $12$1;
    var $14 = __ZNK2JS5Value6isNullEv($cb);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $2 | 0;
    var $st$1$0 = $16 | 0;
    HEAP32[$st$1$0 >> 2] = $12$0;
    var $st$1$1 = $16 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $12$1;
    var $_05 = $3 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $17 = $array | 0;
    var $st$11$0 = $17 | 0;
    var $18$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$11$1 >> 2];
    var $19 = $4 | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    __ZN2JSL12BooleanValueEb3401($5, $lexical);
    var $20 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $5, $pos, $dst);
    var $_0 = $20;
    __label__ = 5;
    break;
   case 4:
    var $_07 = $6 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $22 = $array | 0;
    var $st$6$0 = $22 | 0;
    var $23$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$6$1 >> 2];
    var $24 = $7 | 0;
    var $st$11$0 = $24 | 0;
    HEAP32[$st$11$0 >> 2] = $23$0;
    var $st$11$1 = $24 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $23$1;
    __ZN2JSL12BooleanValueEb3401($8, $lexical);
    var $25 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 32, $pos, STRING_TABLE.__str1963348 | 0, $6, STRING_TABLE.__str1973349 | 0, $7, STRING_TABLE.__str1983350 | 0, $8, $dst);
    var $_0 = $25;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $0, $catches, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $handlers = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __stackBase__ + 72;
    var $_012 = $0 | 0;
    var $st$11$0 = $_012 | 0;
    var $tmp13$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_012 + 4 | 0;
    var $tmp13$1 = HEAP32[$st$11$1 >> 2];
    var $_04 = $1 | 0;
    var $st$16$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$16$1 >> 2];
    var $11 = $this + 352 | 0;
    var $st$21$0 = $11 | 0;
    var $12$0 = HEAP32[$st$21$0 >> 2];
    var $st$21$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$21$1 >> 2];
    var $13 = $cb | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZNK2JS5Value6isNullEv($cb);
    var $15 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $catches, $handlers);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $18 = $3 | 0;
    var $st$1$0 = $18 | 0;
    HEAP32[$st$1$0 >> 2] = $12$0;
    var $st$1$1 = $18 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $12$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $19 = $handlers | 0;
    var $st$11$0 = $19 | 0;
    var $20$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$11$1 >> 2];
    var $21 = $5 | 0;
    var $st$16$0 = $21 | 0;
    HEAP32[$st$16$0 >> 2] = $20$0;
    var $st$16$1 = $21 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $20$1;
    var $_05 = $7 | 0;
    var $st$21$0 = $_05 | 0;
    HEAP32[$st$21$0 >> 2] = $tmp$0;
    var $st$21$1 = $_05 + 4 | 0;
    HEAP32[$st$21$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($6, undef, $7);
    var $22 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 4:
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $_016 = $8 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $25 = $handlers | 0;
    var $st$6$0 = $25 | 0;
    var $26$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$6$1 >> 2];
    var $27 = $9 | 0;
    var $st$11$0 = $27 | 0;
    HEAP32[$st$11$0 >> 2] = $26$0;
    var $st$11$1 = $27 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $26$1;
    var $_07 = $10 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $28 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 41, $pos, STRING_TABLE.__str1993351 | 0, $8, STRING_TABLE.__str2003352 | 0, $9, STRING_TABLE.__str2013353 | 0, $10, $dst);
    var $_0 = $28;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 368 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $cb | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value6isNullEv($cb);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $3$0;
    HEAP32[$7 + 4 >> 2] = $3$1;
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 43, $pos, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($this, $op, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $11 = HEAP32[__ZN2js10binopNamesE + ($op << 2) >> 2];
    var $12 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $11, $opName);
    if ($12) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $14 = $this + 104 | 0;
    var $st$1$0 = $14 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $16 = $cb | 0;
    var $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $15$0;
    var $st$6$1 = $16 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $15$1;
    var $17 = __ZNK2JS5Value6isNullEv($cb);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $3 | 0;
    var $st$1$0 = $19 | 0;
    HEAP32[$st$1$0 >> 2] = $15$0;
    var $st$1$1 = $19 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $15$1;
    var $20 = $opName | 0;
    var $st$6$0 = $20 | 0;
    var $21$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$6$1 >> 2];
    var $22 = $4 | 0;
    var $st$11$0 = $22 | 0;
    HEAP32[$st$11$0 >> 2] = $21$0;
    var $st$11$1 = $22 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $21$1;
    var $_014 = $5 | 0;
    var $st$16$0 = $_014 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp13$0;
    var $st$16$1 = $_014 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $23 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 4:
    var $25 = $opName | 0;
    var $st$1$0 = $25 | 0;
    var $26$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$1$1 >> 2];
    var $27 = $7 | 0;
    var $st$6$0 = $27 | 0;
    HEAP32[$st$6$0 >> 2] = $26$0;
    var $st$6$1 = $27 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $26$1;
    var $_016 = $8 | 0;
    var $st$11$0 = $_016 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_016 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_07 = $9 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $28 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 10, $pos, STRING_TABLE.__str2023354 | 0, $7, STRING_TABLE.__str1923344 | 0, $8, STRING_TABLE.__str1933345 | 0, $9, $dst);
    var $_0 = $28;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_["X"] = 1;

function __ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_($this, $unop, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $7 = __stackBase__ + 56;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $9 = HEAP32[__ZN2js9unopNamesE + ($unop << 2) >> 2];
    var $10 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $9, $opName);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $12 = $this + 96 | 0;
    var $st$1$0 = $12 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14 = $cb | 0;
    var $st$6$0 = $14 | 0;
    HEAP32[$st$6$0 >> 2] = $13$0;
    var $st$6$1 = $14 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value6isNullEv($cb);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $2 | 0;
    var $st$1$0 = $17 | 0;
    HEAP32[$st$1$0 >> 2] = $13$0;
    var $st$1$1 = $17 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $13$1;
    var $18 = $opName | 0;
    var $st$6$0 = $18 | 0;
    var $19$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$6$1 >> 2];
    var $20 = $3 | 0;
    var $st$11$0 = $20 | 0;
    HEAP32[$st$11$0 >> 2] = $19$0;
    var $st$11$1 = $20 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $19$1;
    var $_05 = $4 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $21 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $21;
    __label__ = 5;
    break;
   case 4:
    var $23 = $opName | 0;
    var $st$1$0 = $23 | 0;
    var $24$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $23 + 4 | 0;
    var $24$1 = HEAP32[$st$1$1 >> 2];
    var $25 = $5 | 0;
    var $st$6$0 = $25 | 0;
    HEAP32[$st$6$0 >> 2] = $24$0;
    var $st$6$1 = $25 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $24$1;
    var $_07 = $6 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($7, 1);
    var $26 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 9, $pos, STRING_TABLE.__str2023354 | 0, $5, STRING_TABLE.__str1893341 | 0, $6, STRING_TABLE.__str2033355 | 0, $7, $dst);
    var $_0 = $26;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_["X"] = 1;

function __ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($this, $aop, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $11 = HEAP32[__ZN2js8aopNamesE + ($aop << 2) >> 2];
    var $12 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $11, $opName);
    if ($12) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $14 = $this + 112 | 0;
    var $st$1$0 = $14 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $14 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $16 = $cb | 0;
    var $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $15$0;
    var $st$6$1 = $16 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $15$1;
    var $17 = __ZNK2JS5Value6isNullEv($cb);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $19 = $3 | 0;
    var $st$1$0 = $19 | 0;
    HEAP32[$st$1$0 >> 2] = $15$0;
    var $st$1$1 = $19 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $15$1;
    var $20 = $opName | 0;
    var $st$6$0 = $20 | 0;
    var $21$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$6$1 >> 2];
    var $22 = $4 | 0;
    var $st$11$0 = $22 | 0;
    HEAP32[$st$11$0 >> 2] = $21$0;
    var $st$11$1 = $22 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $21$1;
    var $_014 = $5 | 0;
    var $st$16$0 = $_014 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp13$0;
    var $st$16$1 = $_014 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $23 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 4:
    var $25 = $opName | 0;
    var $st$1$0 = $25 | 0;
    var $26$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$1$1 >> 2];
    var $27 = $7 | 0;
    var $st$6$0 = $27 | 0;
    HEAP32[$st$6$0 >> 2] = $26$0;
    var $st$6$1 = $27 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $26$1;
    var $_016 = $8 | 0;
    var $st$11$0 = $_016 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_016 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_07 = $9 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $28 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 11, $pos, STRING_TABLE.__str2023354 | 0, $7, STRING_TABLE.__str1923344 | 0, $8, STRING_TABLE.__str1933345 | 0, $9, $dst);
    var $_0 = $28;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_["X"] = 1;

function __ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_($this, $0, $incr, $prefix, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $7 = __stackBase__ + 56;
    var $8 = __stackBase__ + 64;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $_str2043356__str2053357 = $incr ? STRING_TABLE.__str2043356 : STRING_TABLE.__str2053357;
    var $9 = $_str2043356__str2053357 | 0;
    var $10 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $9, $opName);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $12 = $this + 128 | 0;
    var $st$1$0 = $12 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $12 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14 = $cb | 0;
    var $st$6$0 = $14 | 0;
    HEAP32[$st$6$0 >> 2] = $13$0;
    var $st$6$1 = $14 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value6isNullEv($cb);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $2 | 0;
    var $st$1$0 = $17 | 0;
    HEAP32[$st$1$0 >> 2] = $13$0;
    var $st$1$1 = $17 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $13$1;
    var $_05 = $3 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $18 = $opName | 0;
    var $st$11$0 = $18 | 0;
    var $19$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$11$1 >> 2];
    var $20 = $4 | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __ZN2JSL12BooleanValueEb3401($5, $prefix);
    var $21 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $5, $pos, $dst);
    var $_0 = $21;
    __label__ = 5;
    break;
   case 4:
    var $23 = $opName | 0;
    var $st$1$0 = $23 | 0;
    var $24$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $23 + 4 | 0;
    var $24$1 = HEAP32[$st$1$1 >> 2];
    var $25 = $6 | 0;
    var $st$6$0 = $25 | 0;
    HEAP32[$st$6$0 >> 2] = $24$0;
    var $st$6$1 = $25 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $24$1;
    var $_07 = $7 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($8, $prefix);
    var $26 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 13, $pos, STRING_TABLE.__str2023354 | 0, $6, STRING_TABLE.__str1893341 | 0, $7, STRING_TABLE.__str2033355 | 0, $8, $dst);
    var $_0 = $26;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $lor, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $opName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $_str2063358__str2073359 = $lor ? STRING_TABLE.__str2063358 : STRING_TABLE.__str2073359;
    var $10 = $_str2063358__str2073359 | 0;
    var $11 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $10, $opName);
    if ($11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $13 = $this + 120 | 0;
    var $st$1$0 = $13 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $13 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $cb | 0;
    var $st$6$0 = $15 | 0;
    HEAP32[$st$6$0 >> 2] = $14$0;
    var $st$6$1 = $15 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $14$1;
    var $16 = __ZNK2JS5Value6isNullEv($cb);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $3 | 0;
    var $st$1$0 = $18 | 0;
    HEAP32[$st$1$0 >> 2] = $14$0;
    var $st$1$1 = $18 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $14$1;
    var $19 = $opName | 0;
    var $st$6$0 = $19 | 0;
    var $20$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$6$1 >> 2];
    var $21 = $4 | 0;
    var $st$11$0 = $21 | 0;
    HEAP32[$st$11$0 >> 2] = $20$0;
    var $st$11$1 = $21 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $20$1;
    var $_014 = $5 | 0;
    var $st$16$0 = $_014 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp13$0;
    var $st$16$1 = $_014 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $22 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $24 = $opName | 0;
    var $st$1$0 = $24 | 0;
    var $25$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$1$1 >> 2];
    var $26 = $7 | 0;
    var $st$6$0 = $26 | 0;
    HEAP32[$st$6$0 >> 2] = $25$0;
    var $st$6$1 = $26 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $25$1;
    var $_016 = $8 | 0;
    var $st$11$0 = $_016 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_016 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_07 = $9 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $27 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 12, $pos, STRING_TABLE.__str2023354 | 0, $7, STRING_TABLE.__str1923344 | 0, $8, STRING_TABLE.__str1933345 | 0, $9, $dst);
    var $_0 = $27;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $4 = __stackBase__ + 8;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 32;
    var $8 = __stackBase__ + 40;
    var $9 = __stackBase__ + 48;
    var $10 = __stackBase__ + 56;
    var $_021 = $0 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $1 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $2 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $11 = $this + 88 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $cb | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = __ZNK2JS5Value6isNullEv($cb);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $16 = $4 | 0;
    var $st$1$0 = $16 | 0;
    HEAP32[$st$1$0 >> 2] = $12$0;
    var $st$1$1 = $16 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $12$1;
    var $_023 = $5 | 0;
    var $st$6$0 = $_023 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp22$0;
    var $st$6$1 = $_023 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp22$1;
    var $_014 = $6 | 0;
    var $st$11$0 = $_014 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_014 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    var $_05 = $7 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $17 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4, $5, $6, $7, $pos, $dst);
    var $_0 = $17;
    __label__ = 4;
    break;
   case 3:
    var $_025 = $8 | 0;
    var $st$1$0 = $_025 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp22$0;
    var $st$1$1 = $_025 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp22$1;
    var $_016 = $9 | 0;
    var $st$6$0 = $_016 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_016 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_07 = $10 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $19 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 8, $pos, STRING_TABLE._js_test_str | 0, $8, STRING_TABLE.__str1863338 | 0, $9, STRING_TABLE.__str1873339 | 0, $10, $dst);
    var $_0 = $19;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 7, STRING_TABLE.__str2083360 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $0, $args, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $this + 144 | 0;
    var $st$1$0 = $9 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $cb | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value6isNullEv($cb);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $2 | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $10$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $10$1;
    var $_05 = $3 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $15 = $array | 0;
    var $st$11$0 = $15 | 0;
    var $16$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$11$1 >> 2];
    var $17 = $4 | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $20 = $array | 0;
    var $st$6$0 = $20 | 0;
    var $21$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$6$1 >> 2];
    var $22 = $6 | 0;
    var $st$11$0 = $22 | 0;
    HEAP32[$st$11$0 >> 2] = $21$0;
    var $st$11$1 = $22 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $21$1;
    var $23 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 15, $pos, STRING_TABLE._js_callee_str | 0, $5, STRING_TABLE._js_arguments_str | 0, $6, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $0, $args, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $this + 136 | 0;
    var $st$1$0 = $9 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $cb | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value6isNullEv($cb);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $2 | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $10$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $10$1;
    var $_05 = $3 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $15 = $array | 0;
    var $st$11$0 = $15 | 0;
    var $16$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$11$1 >> 2];
    var $17 = $4 | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $20 = $array | 0;
    var $st$6$0 = $20 | 0;
    var $21$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$6$1 >> 2];
    var $22 = $6 | 0;
    var $st$11$0 = $22 | 0;
    HEAP32[$st$11$0 >> 2] = $21$0;
    var $st$11$1 = $22 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $21$1;
    var $23 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 14, $pos, STRING_TABLE._js_callee_str | 0, $5, STRING_TABLE._js_arguments_str | 0, $6, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $computed, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $8 = __stackBase__ + 48;
    var $9 = __stackBase__ + 56;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $10 = $this + 152 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $cb | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = __ZNK2JS5Value6isNullEv($cb);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $3 | 0;
    var $st$1$0 = $15 | 0;
    HEAP32[$st$1$0 >> 2] = $11$0;
    var $st$1$1 = $15 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $11$1;
    __ZN2JSL12BooleanValueEb3401($4, $computed);
    var $_014 = $5 | 0;
    HEAP32[$_014 >> 2] = $tmp13$0;
    HEAP32[$_014 + 4 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $7 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $8 | 0;
    HEAP32[$_07 >> 2] = $tmp$0;
    HEAP32[$_07 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($9, $computed);
    var $18 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 16, $pos, STRING_TABLE._js_object_str | 0, $7, STRING_TABLE.__str1103262 | 0, $8, STRING_TABLE.__str2113363 | 0, $9, $dst);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 18, STRING_TABLE.__str174263 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kindName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $9 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, STRING_TABLE.__str1903342 | 0, $kindName);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = $this + 424 | 0;
    var $st$1$0 = $11 | 0;
    var $12$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    var $13 = $cb | 0;
    var $st$6$0 = $13 | 0;
    HEAP32[$st$6$0 >> 2] = $12$0;
    var $st$6$1 = $13 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $12$1;
    var $14 = __ZNK2JS5Value6isNullEv($cb);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $3 | 0;
    var $st$1$0 = $16 | 0;
    HEAP32[$st$1$0 >> 2] = $12$0;
    var $st$1$1 = $16 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $12$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    var $st$11$0 = $_05 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_05 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $17 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $17;
    __label__ = 5;
    break;
   case 4:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $19 = $kindName | 0;
    var $st$11$0 = $19 | 0;
    var $20$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$11$1 >> 2];
    var $21 = $8 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $22 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 50, $pos, STRING_TABLE.__str2133365 | 0, $6, STRING_TABLE._js_value_str | 0, $7, STRING_TABLE.__str2153367 | 0, $8, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_($this, $0, $1, $kind, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kindName = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if (($kind | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_str2163368__str2173369 = ($kind | 0) == 1 ? STRING_TABLE._js_get_str : STRING_TABLE._js_set_str;
    var $15 = $_str2163368__str2173369 | 0;
    __label__ = 3;
    break;
   case 3:
    var $15;
    var $16 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $15, $kindName);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $18 = $this + 48 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $20 = $cb | 0;
    var $st$6$0 = $20 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $20 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    var $21 = __ZNK2JS5Value6isNullEv($cb);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = $3 | 0;
    var $st$1$0 = $23 | 0;
    HEAP32[$st$1$0 >> 2] = $19$0;
    var $st$1$1 = $23 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $19$1;
    var $24 = $kindName | 0;
    var $st$6$0 = $24 | 0;
    var $25$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$6$1 >> 2];
    var $26 = $4 | 0;
    var $st$11$0 = $26 | 0;
    HEAP32[$st$11$0 >> 2] = $25$0;
    var $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $25$1;
    var $_014 = $5 | 0;
    var $st$16$0 = $_014 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp13$0;
    var $st$16$1 = $_014 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $27 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $27;
    __label__ = 7;
    break;
   case 6:
    var $_016 = $7 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $8 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $29 = $kindName | 0;
    var $st$11$0 = $29 | 0;
    var $30$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $29 + 4 | 0;
    var $30$1 = HEAP32[$st$11$1 >> 2];
    var $31 = $9 | 0;
    var $st$16$0 = $31 | 0;
    HEAP32[$st$16$0 >> 2] = $30$0;
    var $st$16$1 = $31 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $30$1;
    var $32 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 3, $pos, STRING_TABLE.__str2133365 | 0, $7, STRING_TABLE._js_value_str | 0, $8, STRING_TABLE.__str2153367 | 0, $9, $dst);
    var $_0 = $32;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 19, STRING_TABLE.__str2183370 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 184 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $cb | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value6isNullEv($cb);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $3$0;
    HEAP32[$7 + 4 >> 2] = $3$1;
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 20, $pos, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $_04 = $0 | 0;
    var $st$6$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$6$1 >> 2];
    var $6 = $this + 224 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $cb | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 | 0;
    var $st$1$0 = $11 | 0;
    HEAP32[$st$1$0 >> 2] = $7$0;
    var $st$1$1 = $11 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $7$1;
    var $_05 = $4 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, undef, $4);
    var $12 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 25, $pos, STRING_TABLE.__str1893341 | 0, $5, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_($this, $0, $1, $isForEach, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $8 = __stackBase__ + 48;
    var $9 = __stackBase__ + 56;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $10 = $this + 400 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $cb | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = __ZNK2JS5Value6isNullEv($cb);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $3 | 0;
    var $st$1$0 = $15 | 0;
    HEAP32[$st$1$0 >> 2] = $11$0;
    var $st$1$1 = $15 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $11$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($6, $isForEach);
    var $16 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $7 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $8 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($9, $isForEach);
    var $18 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 47, $pos, STRING_TABLE.__str1923344 | 0, $7, STRING_TABLE.__str1933345 | 0, $8, STRING_TABLE._js_each_str | 0, $9, $dst);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $0, $blocks, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __stackBase__ + 72;
    var $_012 = $0 | 0;
    var $st$11$0 = $_012 | 0;
    var $tmp13$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_012 + 4 | 0;
    var $tmp13$1 = HEAP32[$st$11$1 >> 2];
    var $_04 = $1 | 0;
    var $st$16$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$16$1 >> 2];
    var $11 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $blocks, $array);
    if ($11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $13 = $this + 208 | 0;
    var $st$1$0 = $13 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $13 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $cb | 0;
    var $st$6$0 = $15 | 0;
    HEAP32[$st$6$0 >> 2] = $14$0;
    var $st$6$1 = $15 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $14$1;
    var $16 = __ZNK2JS5Value6isNullEv($cb);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $3 | 0;
    var $st$1$0 = $18 | 0;
    HEAP32[$st$1$0 >> 2] = $14$0;
    var $st$1$1 = $18 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $14$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $19 = $array | 0;
    var $st$11$0 = $19 | 0;
    var $20$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$11$1 >> 2];
    var $21 = $5 | 0;
    var $st$16$0 = $21 | 0;
    HEAP32[$st$16$0 >> 2] = $20$0;
    var $st$16$1 = $21 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $20$1;
    var $_05 = $7 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($6, undef, $7);
    var $22 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_016 = $8 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $24 = $array | 0;
    var $st$6$0 = $24 | 0;
    var $25$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$6$1 >> 2];
    var $26 = $9 | 0;
    var $st$11$0 = $26 | 0;
    HEAP32[$st$11$0 >> 2] = $25$0;
    var $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $25$1;
    var $_07 = $10 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $27 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 23, $pos, STRING_TABLE.__str1833335 | 0, $8, STRING_TABLE.__str2193371 | 0, $9, STRING_TABLE.__str2203372 | 0, $10, $dst);
    var $_0 = $27;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($this, $0, $blocks, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __stackBase__ + 72;
    var $_012 = $0 | 0;
    var $st$11$0 = $_012 | 0;
    var $tmp13$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $_012 + 4 | 0;
    var $tmp13$1 = HEAP32[$st$11$1 >> 2];
    var $_04 = $1 | 0;
    var $st$16$0 = $_04 | 0;
    var $tmp$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $_04 + 4 | 0;
    var $tmp$1 = HEAP32[$st$16$1 >> 2];
    var $11 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $blocks, $array);
    if ($11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $13 = $this + 216 | 0;
    var $st$1$0 = $13 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $13 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $cb | 0;
    var $st$6$0 = $15 | 0;
    HEAP32[$st$6$0 >> 2] = $14$0;
    var $st$6$1 = $15 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $14$1;
    var $16 = __ZNK2JS5Value6isNullEv($cb);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = $3 | 0;
    var $st$1$0 = $18 | 0;
    HEAP32[$st$1$0 >> 2] = $14$0;
    var $st$1$1 = $18 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $14$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $19 = $array | 0;
    var $st$11$0 = $19 | 0;
    var $20$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $19 + 4 | 0;
    var $20$1 = HEAP32[$st$11$1 >> 2];
    var $21 = $5 | 0;
    var $st$16$0 = $21 | 0;
    HEAP32[$st$16$0 >> 2] = $20$0;
    var $st$16$1 = $21 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $20$1;
    var $_05 = $7 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($6, undef, $7);
    var $22 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $22;
    __label__ = 5;
    break;
   case 4:
    var $_016 = $8 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $24 = $array | 0;
    var $st$6$0 = $24 | 0;
    var $25$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $24 + 4 | 0;
    var $25$1 = HEAP32[$st$6$1 >> 2];
    var $26 = $9 | 0;
    var $st$11$0 = $26 | 0;
    HEAP32[$st$11$0 >> 2] = $25$0;
    var $st$11$1 = $26 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $25$1;
    var $_07 = $10 | 0;
    var $st$16$0 = $_07 | 0;
    HEAP32[$st$16$0 >> 2] = $tmp$0;
    var $st$16$1 = $_07 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $tmp$1;
    var $27 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 24, $pos, STRING_TABLE.__str1833335 | 0, $8, STRING_TABLE.__str2193371 | 0, $9, STRING_TABLE.__str2203372 | 0, $10, $dst);
    var $_0 = $27;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_($this, $idx, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $6 = $this + 192 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $cb | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    var $9 = __ZNK2JS5Value6isNullEv($cb);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $2 | 0;
    HEAP32[$11 >> 2] = $7$0;
    HEAP32[$11 + 4 >> 2] = $7$1;
    var $12 = $idx | 0;
    __ZN2JSL11NumberValueEd3402($3, $12);
    var $13 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 3:
    var $15 = $idx | 0;
    __ZN2JSL11NumberValueEd3402($4, $15);
    var $_04 = $5 | 0;
    HEAP32[$_04 >> 2] = $tmp$0;
    HEAP32[$_04 + 4 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 21, $pos, STRING_TABLE._js_index_str | 0, $4, STRING_TABLE.__str1843336 | 0, $5, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd3402($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE($this, $idx, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $this + 200 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $cb | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $7 = __ZNK2JS5Value6isNullEv($cb);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $1 | 0;
    HEAP32[$9 >> 2] = $5$0;
    HEAP32[$9 + 4 >> 2] = $5$1;
    var $10 = $idx | 0;
    __ZN2JSL11NumberValueEd3402($2, $10);
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $1, $2, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $13 = $idx | 0;
    __ZN2JSL11NumberValueEd3402($3, $13);
    var $14 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 22, $pos, STRING_TABLE._js_index_str | 0, $3, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($this, $head, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $head, $array);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $this + 232 | 0;
    var $st$1$0 = $9 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $cb | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value6isNullEv($cb);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $2 | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $10$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $10$1;
    var $15 = $array | 0;
    var $st$6$0 = $15 | 0;
    var $16$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$6$1 >> 2];
    var $17 = $3 | 0;
    var $st$11$0 = $17 | 0;
    HEAP32[$st$11$0 >> 2] = $16$0;
    var $st$11$1 = $17 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $16$1;
    var $_05 = $4 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $20 = $array | 0;
    var $st$1$0 = $20 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = $5 | 0;
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $21$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $21$1;
    var $_07 = $6 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $23 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 26, $pos, STRING_TABLE.__str2223374 | 0, $5, STRING_TABLE.__str1833335 | 0, $6, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_["X"] = 1;

function __ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($this, $head, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $head, $array);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $9 = $this + 376 | 0;
    var $st$1$0 = $9 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $9 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $cb | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value6isNullEv($cb);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $2 | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $10$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $10$1;
    var $15 = $array | 0;
    var $st$6$0 = $15 | 0;
    var $16$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$6$1 >> 2];
    var $17 = $3 | 0;
    var $st$11$0 = $17 | 0;
    HEAP32[$st$11$0 >> 2] = $16$0;
    var $st$11$1 = $17 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $16$1;
    var $_05 = $4 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 4:
    var $20 = $array | 0;
    var $st$1$0 = $20 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = $5 | 0;
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $21$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $21$1;
    var $_07 = $6 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $23 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 44, $pos, STRING_TABLE.__str2223374 | 0, $5, STRING_TABLE.__str1833335 | 0, $6, $dst);
    var $_0 = $23;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_["X"] = 1;

function __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $kind, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $kindName = __stackBase__ + 8;
    var $cb = __stackBase__ + 16;
    var $1 = __stackBase__ + 24;
    var $2 = __stackBase__ + 32;
    var $3 = __stackBase__ + 40;
    var $4 = __stackBase__ + 48;
    var $5 = __stackBase__ + 56;
    var $6 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    if (($kind | 0) == 1) {
      var $13 = STRING_TABLE._js_const_str | 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_str2243376__str2253377 = ($kind | 0) == 2 ? STRING_TABLE._js_let_str : STRING_TABLE._js_var_str;
    var $13 = $_str2243376__str2253377 | 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    var $14 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $13, $kindName);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = $this + 64 | 0;
    var $st$1$0 = $16 | 0;
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $18 = $cb | 0;
    var $st$6$0 = $18 | 0;
    HEAP32[$st$6$0 >> 2] = $17$0;
    var $st$6$1 = $18 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $17$1;
    var $19 = __ZNK2JS5Value6isNullEv($cb);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = $1 | 0;
    var $st$1$0 = $21 | 0;
    HEAP32[$st$1$0 >> 2] = $17$0;
    var $st$1$1 = $21 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $17$1;
    var $22 = $kindName | 0;
    var $st$6$0 = $22 | 0;
    var $23$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$6$1 >> 2];
    var $24 = $2 | 0;
    var $st$11$0 = $24 | 0;
    HEAP32[$st$11$0 >> 2] = $23$0;
    var $st$11$1 = $24 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $23$1;
    var $25 = $array | 0;
    var $st$16$0 = $25 | 0;
    var $26$0 = HEAP32[$st$16$0 >> 2];
    var $st$16$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$16$1 >> 2];
    var $27 = $3 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $1, $2, $3, $pos, $dst);
    var $_0 = $28;
    __label__ = 8;
    break;
   case 7:
    var $30 = $kindName | 0;
    var $st$1$0 = $30 | 0;
    var $31$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $30 + 4 | 0;
    var $31$1 = HEAP32[$st$1$1 >> 2];
    var $32 = $4 | 0;
    var $st$6$0 = $32 | 0;
    HEAP32[$st$6$0 >> 2] = $31$0;
    var $st$6$1 = $32 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $31$1;
    var $33 = $array | 0;
    var $st$11$0 = $33 | 0;
    var $34$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $33 + 4 | 0;
    var $34$1 = HEAP32[$st$11$1 >> 2];
    var $35 = $5 | 0;
    var $st$16$0 = $35 | 0;
    HEAP32[$st$16$0 >> 2] = $34$0;
    var $st$16$1 = $35 + 4 | 0;
    HEAP32[$st$16$1 >> 2] = $34$1;
    var $36 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 5, $pos, STRING_TABLE.__str2153367 | 0, $4, STRING_TABLE.__str2263378 | 0, $5, $dst);
    var $_0 = $36;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE["X"] = 1;

function __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $8 = __stackBase__ + 48;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $9 = $this + 72 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $cb | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZNK2JS5Value6isNullEv($cb);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $3 | 0;
    var $st$1$0 = $14 | 0;
    HEAP32[$st$1$0 >> 2] = $10$0;
    var $st$1$1 = $14 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $10$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $6 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($5, undef, $6);
    var $15 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $7 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $8 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $17 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 6, $pos, STRING_TABLE.__str2273379 | 0, $7, STRING_TABLE.__str1903342 | 0, $8, $dst);
    var $_0 = $17;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js13ASTSerializer3aopE4JSOp($this, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($op | 0) == 27) {
      __label__ = 2;
      break;
    } else if (($op | 0) == 28) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 29) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 30) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 31) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 24) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 25) {
      __label__ = 8;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 15) {
      __label__ = 10;
      break;
    } else if (($op | 0) == 16) {
      __label__ = 11;
      break;
    } else if (($op | 0) == 17) {
      __label__ = 12;
      break;
    } else if (($op | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 3:
    var $_0 = 2;
    __label__ = 14;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 14;
    break;
   case 5:
    var $_0 = 4;
    __label__ = 14;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 14;
    break;
   case 7:
    var $_0 = 6;
    __label__ = 14;
    break;
   case 8:
    var $_0 = 7;
    __label__ = 14;
    break;
   case 9:
    var $_0 = 8;
    __label__ = 14;
    break;
   case 10:
    var $_0 = 9;
    __label__ = 14;
    break;
   case 11:
    var $_0 = 10;
    __label__ = 14;
    break;
   case 12:
    var $_0 = 11;
    __label__ = 14;
    break;
   case 13:
    var $_0 = -1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp($this, $tk, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tk | 0) == 50) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($op | 0) == 35) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 32) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 33) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 39 || ($op | 0) == 200) {
      __label__ = 6;
      break;
    } else if (($op | 0) == 40) {
      __label__ = 7;
      break;
    } else if (($op | 0) == 34) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $_0 = 2;
    __label__ = 9;
    break;
   case 4:
    var $_0 = 3;
    __label__ = 9;
    break;
   case 5:
    var $_0 = 4;
    __label__ = 9;
    break;
   case 6:
    var $_0 = 5;
    __label__ = 9;
    break;
   case 7:
    var $_0 = 6;
    __label__ = 9;
    break;
   case 8:
    var $_0 = -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($this, $0, $elts, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = __stackBase__ + 32;
    var $5 = __stackBase__ + 40;
    var $6 = __stackBase__ + 48;
    var $7 = __stackBase__ + 56;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $elts, $array);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = $this + 384 | 0;
    var $st$1$0 = $10 | 0;
    var $11$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $10 + 4 | 0;
    var $11$1 = HEAP32[$st$1$1 >> 2];
    var $12 = $cb | 0;
    var $st$6$0 = $12 | 0;
    HEAP32[$st$6$0 >> 2] = $11$0;
    var $st$6$1 = $12 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $11$1;
    var $13 = __ZNK2JS5Value6isNullEv($cb);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $2 | 0;
    var $st$1$0 = $15 | 0;
    HEAP32[$st$1$0 >> 2] = $11$0;
    var $st$1$1 = $15 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $11$1;
    var $_05 = $4 | 0;
    var $st$6$0 = $_05 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_05 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($3, undef, $4);
    var $16 = $array | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $5 | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $19 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $5, $pos, $dst);
    var $_0 = $19;
    __label__ = 5;
    break;
   case 4:
    var $_07 = $6 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $21 = $array | 0;
    var $st$6$0 = $21 | 0;
    var $22$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $21 + 4 | 0;
    var $22$1 = HEAP32[$st$6$1 >> 2];
    var $23 = $7 | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    var $24 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 45, $pos, STRING_TABLE._js_test_str | 0, $6, STRING_TABLE.__str1863338 | 0, $7, $dst);
    var $_0 = $24;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $4 = __stackBase__ + 8;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 24;
    var $7 = __stackBase__ + 32;
    var $8 = __stackBase__ + 40;
    var $9 = __stackBase__ + 48;
    var $10 = __stackBase__ + 56;
    var $11 = __stackBase__ + 64;
    var $_021 = $0 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $1 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $2 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $12 = $this + 392 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $cb | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value6isNullEv($cb);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = $4 | 0;
    var $st$1$0 = $17 | 0;
    HEAP32[$st$1$0 >> 2] = $13$0;
    var $st$1$1 = $17 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $13$1;
    var $_023 = $5 | 0;
    var $st$6$0 = $_023 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp22$0;
    var $st$6$1 = $_023 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp22$1;
    var $_014 = $7 | 0;
    var $st$11$0 = $_014 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp13$0;
    var $st$11$1 = $_014 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp13$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($6, undef, $7);
    var $_05 = $8 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $18 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $4, $5, $6, $8, $pos, $dst);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 3:
    var $_025 = $9 | 0;
    var $st$1$0 = $_025 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp22$0;
    var $st$1$1 = $_025 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp22$1;
    var $_016 = $10 | 0;
    var $st$6$0 = $_016 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_016 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_07 = $11 | 0;
    var $st$11$0 = $_07 | 0;
    HEAP32[$st$11$0 >> 2] = $tmp$0;
    var $st$11$1 = $_07 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $tmp$1;
    var $20 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 46, $pos, STRING_TABLE.__str2283380 | 0, $9, STRING_TABLE.__str2293381 | 0, $10, STRING_TABLE.__str1833335 | 0, $11, $dst);
    var $_0 = $20;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 40 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 2, $pos, STRING_TABLE._js_value_str | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 32 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 1, $pos, STRING_TABLE._js_name_str | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 49, STRING_TABLE.__str2183370 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 48, STRING_TABLE.__str174263 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_($this, $type, $pos, $0, $args, $1, $isGenerator, $isExpression, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 112;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $array = __stackBase__;
    var $cb = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $7 = __stackBase__ + 48;
    var $8 = __stackBase__ + 56;
    var $9 = __stackBase__ + 64;
    var $10 = __stackBase__ + 72;
    var $11 = __stackBase__ + 80;
    var $12 = __stackBase__ + 88;
    var $13 = __stackBase__ + 96;
    var $14 = __stackBase__ + 104;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $15 = __ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE($this, $args, $array);
    if ($15) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $17 = $this + 24 + ($type << 3) | 0;
    var $st$1$0 = $17 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = $cb | 0;
    var $st$6$0 = $19 | 0;
    HEAP32[$st$6$0 >> 2] = $18$0;
    var $st$6$1 = $19 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $18$1;
    var $20 = __ZNK2JS5Value6isNullEv($cb);
    if ($20) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $22 = $3 | 0;
    var $st$1$0 = $22 | 0;
    HEAP32[$st$1$0 >> 2] = $18$0;
    var $st$1$1 = $22 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $18$1;
    var $_014 = $5 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    __ZN2js11NodeBuilder3optEN2JS5ValueE($4, undef, $5);
    var $23 = $array | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $6 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $_05 = $7 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($8, $isGenerator);
    __ZN2JSL12BooleanValueEb3401($9, $isExpression);
    var $26 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $6, $7, $8, $9, $pos, $dst);
    var $_0 = $26;
    __label__ = 5;
    break;
   case 4:
    var $_016 = $10 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $28 = $array | 0;
    var $st$6$0 = $28 | 0;
    var $29$0 = HEAP32[$st$6$0 >> 2];
    var $st$6$1 = $28 + 4 | 0;
    var $29$1 = HEAP32[$st$6$1 >> 2];
    var $30 = $11 | 0;
    HEAP32[$30 >> 2] = $29$0;
    HEAP32[$30 + 4 >> 2] = $29$1;
    var $_07 = $12 | 0;
    HEAP32[$_07 >> 2] = $tmp$0;
    HEAP32[$_07 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($13, $isGenerator);
    __ZN2JSL12BooleanValueEb3401($14, $isExpression);
    var $31 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, STRING_TABLE.__str2273379 | 0, $10, STRING_TABLE.__str2313383 | 0, $11, STRING_TABLE.__str1833335 | 0, $12, STRING_TABLE.__str2323384 | 0, $13, STRING_TABLE.__str1843336 | 0, $14, $dst);
    var $_0 = $31;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_["X"] = 1;

function __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_($this, $0, $1, $2, $3, $4, $5, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $4;
  $4 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$4 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$4 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $5;
  $5 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$5 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$5 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $loc = __stackBase__ + 8;
    var $argv = __stackBase__ + 16;
    var $argv1 = __stackBase__ + 64;
    var $7 = $0 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $fun | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $_039 = $1 | 0;
    var $tmp40$0 = HEAP32[$_039 >> 2];
    var $tmp40$1 = HEAP32[$_039 + 4 >> 2];
    var $_030 = $2 | 0;
    var $tmp31$0 = HEAP32[$_030 >> 2];
    var $tmp31$1 = HEAP32[$_030 + 4 >> 2];
    var $_021 = $3 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_012 = $4 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $5 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    if ((HEAP8[$this + 4 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = __ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $loc);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $17 = $argv | 0;
    var $argv41_0 = $argv | 0;
    var $st$2$0 = $argv41_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp40$0;
    var $st$2$1 = $argv41_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp40$1;
    var $_032 = $argv + 8 | 0;
    var $st$7$0 = $_032 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp31$0;
    var $st$7$1 = $_032 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp31$1;
    var $_023 = $argv + 16 | 0;
    var $st$12$0 = $_023 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp22$0;
    var $st$12$1 = $_023 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp22$1;
    var $_014 = $argv + 24 | 0;
    var $st$17$0 = $_014 | 0;
    HEAP32[$st$17$0 >> 2] = $tmp13$0;
    var $st$17$1 = $_014 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $tmp13$1;
    var $_05 = $argv + 32 | 0;
    var $st$22$0 = $_05 | 0;
    HEAP32[$st$22$0 >> 2] = $tmp$0;
    var $st$22$1 = $_05 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $tmp$1;
    var $18 = $loc | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $argv + 40 | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $22 = HEAP32[$this >> 2];
    var $23 = $this + 576 | 0;
    var $24 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($22, $23, $fun, 6, $17, $dst);
    var $_0 = $24;
    __label__ = 5;
    break;
   case 4:
    var $26 = $argv1 | 0;
    var $argv143_0 = $argv1 | 0;
    var $st$2$0 = $argv143_0 | 0;
    HEAP32[$st$2$0 >> 2] = $tmp40$0;
    var $st$2$1 = $argv143_0 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $tmp40$1;
    var $_034 = $argv1 + 8 | 0;
    var $st$7$0 = $_034 | 0;
    HEAP32[$st$7$0 >> 2] = $tmp31$0;
    var $st$7$1 = $_034 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $tmp31$1;
    var $_025 = $argv1 + 16 | 0;
    var $st$12$0 = $_025 | 0;
    HEAP32[$st$12$0 >> 2] = $tmp22$0;
    var $st$12$1 = $_025 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $tmp22$1;
    var $_016 = $argv1 + 24 | 0;
    var $st$17$0 = $_016 | 0;
    HEAP32[$st$17$0 >> 2] = $tmp13$0;
    var $st$17$1 = $_016 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $tmp13$1;
    var $_07 = $argv1 + 32 | 0;
    var $st$22$0 = $_07 | 0;
    HEAP32[$st$22$0 >> 2] = $tmp$0;
    var $st$22$1 = $_07 + 4 | 0;
    HEAP32[$st$22$1 >> 2] = $tmp$1;
    var $28 = HEAP32[$this >> 2];
    var $29 = $this + 576 | 0;
    var $30 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($28, $29, $fun, 5, $26, $dst);
    var $_0 = $30;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_($this, $type, $pos, $childName1, $0, $childName2, $1, $childName3, $2, $childName4, $3, $childName5, $4, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $2;
  $2 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$2 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$2 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $3;
  $3 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$3 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$3 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $4;
  $4 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$4 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$4 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    var $6 = __stackBase__ + 4;
    var $7 = __stackBase__ + 12;
    var $8 = __stackBase__ + 20;
    var $9 = __stackBase__ + 28;
    var $10 = __stackBase__ + 36;
    var $_021 = $0 | 0;
    var $tmp22$0 = HEAP32[$_021 >> 2];
    var $tmp22$1 = HEAP32[$_021 + 4 >> 2];
    var $_016 = $1 | 0;
    var $tmp17$0 = HEAP32[$_016 >> 2];
    var $tmp17$1 = HEAP32[$_016 + 4 >> 2];
    var $_011 = $2 | 0;
    var $tmp12$0 = HEAP32[$_011 >> 2];
    var $tmp12$1 = HEAP32[$_011 + 4 >> 2];
    var $_06 = $3 | 0;
    var $tmp7$0 = HEAP32[$_06 >> 2];
    var $tmp7$1 = HEAP32[$_06 + 4 >> 2];
    var $_02 = $4 | 0;
    var $tmp$0 = HEAP32[$_02 >> 2];
    var $tmp$1 = HEAP32[$_02 + 4 >> 2];
    var $11 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject($this, $type, $pos, $node);
    if ($11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $13 = HEAP32[$node >> 2];
    var $_023 = $6 | 0;
    HEAP32[$_023 >> 2] = $tmp22$0;
    HEAP32[$_023 + 4 >> 2] = $tmp22$1;
    var $14 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, $childName1, $6);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $_018 = $7 | 0;
    var $st$1$0 = $_018 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp17$0;
    var $st$1$1 = $_018 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp17$1;
    var $16 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, $childName2, $7);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $_013 = $8 | 0;
    var $st$1$0 = $_013 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp12$0;
    var $st$1$1 = $_013 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp12$1;
    var $18 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, $childName3, $8);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $_08 = $9 | 0;
    var $st$1$0 = $_08 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp7$0;
    var $st$1$1 = $_08 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp7$1;
    var $20 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, $childName4, $9);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_03 = $10 | 0;
    var $st$1$0 = $_03 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_03 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $22 = __ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE($this, $13, $childName5, $10);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $26 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE(undef, $13, $dst);
    var $26 = 1;
    __label__ = 8;
    break;
   case 8:
    var $26;
    STACKTOP = __stackBase__;
    return $26;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_["X"] = 1;

function __ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE($this, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this + 432 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $cb | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = __ZNK2JS5Value6isNullEv($cb);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $3$0;
    HEAP32[$7 + 4 >> 2] = $3$1;
    var $8 = __ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_($this, $1, $pos, $dst);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE($this, 51, $pos, $dst);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 448 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 53, $pos, STRING_TABLE.__str1843336 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 456 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 54, $pos, STRING_TABLE.__str1923344 | 0, $6, STRING_TABLE.__str1933345 | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 464 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 55, $pos, STRING_TABLE._js_namespace_str | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_($this, $0, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = $this + 440 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $cb | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = __ZNK2JS5Value6isNullEv($cb);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = $2 | 0;
    var $st$1$0 = $12 | 0;
    HEAP32[$st$1$0 >> 2] = $8$0;
    var $st$1$1 = $12 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $8$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($4, $computed);
    var $13 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($6, $computed);
    var $15 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 52, $pos, STRING_TABLE.__str2343386 | 0, $5, STRING_TABLE.__str2113363 | 0, $6, $dst);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_($this, $0, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __stackBase__ + 40;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $7 = $this + 480 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $cb | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = __ZNK2JS5Value6isNullEv($cb);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $12 = $2 | 0;
    var $st$1$0 = $12 | 0;
    HEAP32[$st$1$0 >> 2] = $8$0;
    var $st$1$1 = $12 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $8$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($4, $computed);
    var $13 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $2, $3, $4, $pos, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $5 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($6, $computed);
    var $15 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 57, $pos, STRING_TABLE.__str1933345 | 0, $5, STRING_TABLE.__str2113363 | 0, $6, $dst);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_($this, $0, $1, $computed, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $8 = __stackBase__ + 48;
    var $9 = __stackBase__ + 56;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $10 = $this + 472 | 0;
    var $11$0 = HEAP32[$10 >> 2];
    var $11$1 = HEAP32[$10 + 4 >> 2];
    var $12 = $cb | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = __ZNK2JS5Value6isNullEv($cb);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $3 | 0;
    var $st$1$0 = $15 | 0;
    HEAP32[$st$1$0 >> 2] = $11$0;
    var $st$1$1 = $15 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $11$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($6, $computed);
    var $16 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $6, $pos, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $7 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $8 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    __ZN2JSL12BooleanValueEb3401($9, $computed);
    var $18 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_($this, 56, $pos, STRING_TABLE.__str1923344 | 0, $7, STRING_TABLE.__str1933345 | 0, $8, STRING_TABLE.__str2113363 | 0, $9, $dst);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 58, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 496 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 59, $pos, STRING_TABLE.__str2363388 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 60, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 61, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 62, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 63, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 536 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 64, $pos, STRING_TABLE.__str2353387 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, $elts, $pos, $dst) {
  var $1 = __ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($this, 64, STRING_TABLE.__str2353387 | 0, $elts, $pos, $dst);
  return $1;
}

function __ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 544 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 65, $pos, STRING_TABLE._js_value_str | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 552 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 66, $pos, STRING_TABLE.__str2353387 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $_04 = $0 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $5 = $this + 560 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $cb | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = __ZNK2JS5Value6isNullEv($cb);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2 | 0;
    var $st$1$0 = $10 | 0;
    HEAP32[$st$1$0 >> 2] = $6$0;
    var $st$1$1 = $10 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $6$1;
    var $_05 = $3 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $11 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 3:
    var $_07 = $4 | 0;
    var $st$1$0 = $_07 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp$0;
    var $st$1$1 = $_07 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp$1;
    var $13 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_($this, 67, $pos, STRING_TABLE.__str2353387 | 0, $4, $dst);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_($this, $0, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $2 = __stackBase__;
  var $3 = __stackBase__ + 8;
  var $_02 = $0 | 0;
  var $tmp$0 = HEAP32[$_02 >> 2];
  var $tmp$1 = HEAP32[$_02 + 4 >> 2];
  var $_03 = $2 | 0;
  HEAP32[$_03 >> 2] = $tmp$0;
  HEAP32[$_03 + 4 >> 2] = $tmp$1;
  __ZN2JSL9NullValueEv3400($3);
  var $4 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $2, $3, $pos, $dst);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($this, $0, $1, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var tempParam = $1;
  $1 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$1 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$1 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cb = __stackBase__;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 24;
    var $6 = __stackBase__ + 32;
    var $7 = __stackBase__ + 40;
    var $_012 = $0 | 0;
    var $tmp13$0 = HEAP32[$_012 >> 2];
    var $tmp13$1 = HEAP32[$_012 + 4 >> 2];
    var $_04 = $1 | 0;
    var $tmp$0 = HEAP32[$_04 >> 2];
    var $tmp$1 = HEAP32[$_04 + 4 >> 2];
    var $8 = $this + 568 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $cb | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2JS5Value6isNullEv($cb);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $3 | 0;
    var $st$1$0 = $13 | 0;
    HEAP32[$st$1$0 >> 2] = $9$0;
    var $st$1$1 = $13 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $9$1;
    var $_014 = $4 | 0;
    var $st$6$0 = $_014 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp13$0;
    var $st$6$1 = $_014 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp13$1;
    var $_05 = $5 | 0;
    HEAP32[$_05 >> 2] = $tmp$0;
    HEAP32[$_05 + 4 >> 2] = $tmp$1;
    var $14 = __ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($this, $3, $4, $5, $pos, $dst);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 3:
    var $_016 = $6 | 0;
    var $st$1$0 = $_016 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp13$0;
    var $st$1$1 = $_016 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp13$1;
    var $_07 = $7 | 0;
    var $st$6$0 = $_07 | 0;
    HEAP32[$st$6$0 >> 2] = $tmp$0;
    var $st$6$1 = $_07 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $tmp$1;
    var $16 = __ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_($this, 68, $pos, STRING_TABLE.__str2373389 | 0, $6, STRING_TABLE.__str2353387 | 0, $7, $dst);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_["X"] = 1;

function __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp($this, $tk, $op) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($tk | 0) == 12) {
      __label__ = 2;
      break;
    } else if (($tk | 0) == 13) {
      __label__ = 7;
      break;
    } else if (($tk | 0) == 14) {
      __label__ = 12;
      break;
    } else if (($tk | 0) == 16) {
      __label__ = 16;
      break;
    } else if (($tk | 0) == 17) {
      __label__ = 17;
      break;
    } else if (($tk | 0) == 18) {
      __label__ = 18;
      break;
    } else if (($tk | 0) == 9) {
      __label__ = 19;
      break;
    } else if (($tk | 0) == 10) {
      __label__ = 20;
      break;
    } else if (($tk | 0) == 11) {
      __label__ = 21;
      break;
    } else if (($tk | 0) == 45) {
      __label__ = 22;
      break;
    } else if (($tk | 0) == 57) {
      __label__ = 23;
      break;
    } else if (($tk | 0) == 73) {
      __label__ = 24;
      break;
    } else if (($tk | 0) == 15) {
      var $_0 = 11;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 2:
    if (($op | 0) == 19) {
      __label__ = 3;
      break;
    } else if (($op | 0) == 72) {
      __label__ = 4;
      break;
    } else if (($op | 0) == 73) {
      __label__ = 5;
      break;
    } else if (($op | 0) == 18) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 26;
    break;
   case 4:
    var $_0 = 2;
    __label__ = 26;
    break;
   case 5:
    var $_0 = 3;
    __label__ = 26;
    break;
   case 6:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 7:
    if (($op | 0) == 21) {
      __label__ = 8;
      break;
    } else if (($op | 0) == 22) {
      __label__ = 9;
      break;
    } else if (($op | 0) == 23) {
      __label__ = 10;
      break;
    } else if (($op | 0) == 20) {
      var $_0 = 4;
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $_0 = 5;
    __label__ = 26;
    break;
   case 9:
    var $_0 = 6;
    __label__ = 26;
    break;
   case 10:
    var $_0 = 7;
    __label__ = 26;
    break;
   case 11:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 12:
    if (($op | 0) == 25) {
      __label__ = 13;
      break;
    } else if (($op | 0) == 26) {
      __label__ = 14;
      break;
    } else if (($op | 0) == 24) {
      var $_0 = 8;
      __label__ = 26;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $_0 = 9;
    __label__ = 26;
    break;
   case 14:
    var $_0 = 10;
    __label__ = 26;
    break;
   case 15:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 16:
    var $_0 = 12;
    __label__ = 26;
    break;
   case 17:
    var $_0 = 13;
    __label__ = 26;
    break;
   case 18:
    var $19 = ($op | 0) == 31 ? 15 : 14;
    var $_0 = $19;
    __label__ = 26;
    break;
   case 19:
    var $_0 = 16;
    __label__ = 26;
    break;
   case 20:
    var $_0 = 17;
    __label__ = 26;
    break;
   case 21:
    var $_0 = 18;
    __label__ = 26;
    break;
   case 22:
    var $_0 = 19;
    __label__ = 26;
    break;
   case 23:
    var $_0 = 20;
    __label__ = 26;
    break;
   case 24:
    var $_0 = 21;
    __label__ = 26;
    break;
   case 25:
    var $_0 = -1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var $1 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
  return $1;
}

function __ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 896;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exprs = __stackBase__ + 4;
    var $test = __stackBase__ + 96;
    var $cons = __stackBase__ + 104;
    var $alt = __stackBase__ + 112;
    var $1 = __stackBase__ + 120;
    var $2 = __stackBase__ + 128;
    var $3 = __stackBase__ + 136;
    var $left = __stackBase__ + 144;
    var $right = __stackBase__ + 152;
    var $4 = __stackBase__ + 160;
    var $5 = __stackBase__ + 168;
    var $expr = __stackBase__ + 176;
    var $6 = __stackBase__ + 184;
    var $lhs = __stackBase__ + 192;
    var $rhs = __stackBase__ + 200;
    var $7 = __stackBase__ + 208;
    var $8 = __stackBase__ + 216;
    var $left2 = __stackBase__ + 224;
    var $right3 = __stackBase__ + 232;
    var $9 = __stackBase__ + 240;
    var $10 = __stackBase__ + 248;
    var $expr5 = __stackBase__ + 256;
    var $11 = __stackBase__ + 264;
    var $callee = __stackBase__ + 272;
    var $args = __stackBase__ + 280;
    var $arg = __stackBase__ + 372;
    var $12 = __stackBase__ + 380;
    var $13 = __stackBase__ + 388;
    var $expr6 = __stackBase__ + 396;
    var $id = __stackBase__ + 404;
    var $14 = __stackBase__ + 412;
    var $15 = __stackBase__ + 420;
    var $left7 = __stackBase__ + 428;
    var $right8 = __stackBase__ + 436;
    var $16 = __stackBase__ + 444;
    var $17 = __stackBase__ + 452;
    var $elts = __stackBase__ + 460;
    var $18 = __stackBase__ + 552;
    var $expr10 = __stackBase__ + 560;
    var $elts11 = __stackBase__ + 568;
    var $prop = __stackBase__ + 660;
    var $arg13 = __stackBase__ + 668;
    var $19 = __stackBase__ + 676;
    var $expr14 = __stackBase__ + 684;
    var $20 = __stackBase__ + 692;
    var $dtors = __stackBase__ + 700;
    var $expr15 = __stackBase__ + 792;
    var $21 = __stackBase__ + 800;
    var $right16 = __stackBase__ + 808;
    var $22 = __stackBase__ + 816;
    var $left18 = __stackBase__ + 824;
    var $23 = __stackBase__ + 832;
    var $24 = __stackBase__ + 840;
    var $expr19 = __stackBase__ + 848;
    var $25 = __stackBase__ + 856;
    var $left21 = __stackBase__ + 864;
    var $right22 = __stackBase__ + 872;
    var $26 = __stackBase__ + 880;
    var $27 = __stackBase__ + 888;
    var $29 = $this | 0;
    var $30 = HEAPU32[$29 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$30 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($30);
    var $_3 = 0;
    __label__ = 115;
    break;
   case 3:
    var $36 = __ZNK11JSParseNode7getKindEv($pn);
    if (($36 | 0) == 34) {
      __label__ = 4;
      break;
    } else if (($36 | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($36 | 0) == 5) {
      __label__ = 8;
      break;
    } else if (($36 | 0) == 7 || ($36 | 0) == 8) {
      __label__ = 12;
      break;
    } else if (($36 | 0) == 20 || ($36 | 0) == 21) {
      __label__ = 17;
      break;
    } else if (($36 | 0) == 4) {
      __label__ = 19;
      break;
    } else if (($36 | 0) == 12 || ($36 | 0) == 13 || ($36 | 0) == 14 || ($36 | 0) == 15 || ($36 | 0) == 16 || ($36 | 0) == 17 || ($36 | 0) == 18 || ($36 | 0) == 9 || ($36 | 0) == 10 || ($36 | 0) == 11 || ($36 | 0) == 45 || ($36 | 0) == 57 || ($36 | 0) == 73) {
      __label__ = 24;
      break;
    } else if (($36 | 0) == 50 || ($36 | 0) == 19) {
      __label__ = 31;
      break;
    } else if (($36 | 0) == 49 || ($36 | 0) == 27) {
      __label__ = 39;
      break;
    } else if (($36 | 0) == 22) {
      __label__ = 50;
      break;
    } else if (($36 | 0) == 23) {
      __label__ = 53;
      break;
    } else if (($36 | 0) == 24) {
      __label__ = 59;
      break;
    } else if (($36 | 0) == 26) {
      __label__ = 69;
      break;
    } else if (($36 | 0) == 29) {
      __label__ = 76;
      break;
    } else if (($36 | 0) == 31 || ($36 | 0) == 32 || ($36 | 0) == 30 || ($36 | 0) == 33) {
      __label__ = 77;
      break;
    } else if (($36 | 0) == 77) {
      __label__ = 80;
      break;
    } else if (($36 | 0) == 51) {
      __label__ = 82;
      break;
    } else if (($36 | 0) == 52) {
      __label__ = 84;
      break;
    } else if (($36 | 0) == 78) {
      __label__ = 85;
      break;
    } else if (($36 | 0) == 80) {
      __label__ = 90;
      break;
    } else if (($36 | 0) == 72) {
      __label__ = 94;
      break;
    } else if (($36 | 0) == 71) {
      __label__ = 95;
      break;
    } else if (($36 | 0) == 70) {
      __label__ = 105;
      break;
    } else if (($36 | 0) == 74) {
      __label__ = 111;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 4:
    var $38 = __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, 17, $dst);
    var $_3 = $38;
    __label__ = 115;
    break;
   case 5:
    __ZN2js15AutoValueVectorC1EP9JSContext($exprs, $30);
    var $40 = __ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $exprs);
    if ($40) {
      __label__ = 6;
      break;
    } else {
      var $46 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $42 = $this + 8 | 0;
    var $43 = $pn + 4 | 0;
    var $44 = __ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($42, $exprs, $43, $dst);
    var $46 = $44;
    __label__ = 7;
    break;
   case 7:
    var $46;
    __ZN2js15AutoValueVectorD1Ev($exprs);
    var $_3 = $46;
    __label__ = 115;
    break;
   case 8:
    var $49 = HEAP32[$pn + 32 >> 2];
    var $50 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $49, $test);
    if ($50) {
      __label__ = 9;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 9:
    var $54 = HEAP32[$pn + 36 >> 2];
    var $55 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $54, $cons);
    if ($55) {
      __label__ = 10;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 10:
    var $59 = HEAP32[$pn + 40 >> 2];
    var $60 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $59, $alt);
    if ($60) {
      __label__ = 11;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 11:
    var $62 = $this + 8 | 0;
    var $63 = $test | 0;
    var $st$2$0 = $63 | 0;
    var $64$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $63 + 4 | 0;
    var $64$1 = HEAP32[$st$2$1 >> 2];
    var $65 = $1 | 0;
    var $st$7$0 = $65 | 0;
    HEAP32[$st$7$0 >> 2] = $64$0;
    var $st$7$1 = $65 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $64$1;
    var $66 = $cons | 0;
    var $st$12$0 = $66 | 0;
    var $67$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $66 + 4 | 0;
    var $67$1 = HEAP32[$st$12$1 >> 2];
    var $68 = $2 | 0;
    var $st$17$0 = $68 | 0;
    HEAP32[$st$17$0 >> 2] = $67$0;
    var $st$17$1 = $68 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $67$1;
    var $69 = $alt | 0;
    var $70$0 = HEAP32[$69 >> 2];
    var $70$1 = HEAP32[$69 + 4 >> 2];
    var $71 = $3 | 0;
    HEAP32[$71 >> 2] = $70$0;
    HEAP32[$71 + 4 >> 2] = $70$1;
    var $72 = $pn + 4 | 0;
    var $73 = __ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($62, $1, $2, $3, $72, $dst);
    var $_3 = $73;
    __label__ = 115;
    break;
   case 12:
    var $75 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($75) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $78 = HEAP32[$pn + 32 >> 2];
    var $79 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $78, $left);
    if ($79) {
      __label__ = 14;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 14:
    var $83 = HEAP32[$pn + 36 >> 2];
    var $84 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $83, $right);
    if ($84) {
      __label__ = 15;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 15:
    var $86 = $this + 8 | 0;
    var $87 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 7);
    var $88 = $left | 0;
    var $st$3$0 = $88 | 0;
    var $89$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $88 + 4 | 0;
    var $89$1 = HEAP32[$st$3$1 >> 2];
    var $90 = $4 | 0;
    HEAP32[$90 >> 2] = $89$0;
    HEAP32[$90 + 4 >> 2] = $89$1;
    var $91 = $right | 0;
    var $92$0 = HEAP32[$91 >> 2];
    var $92$1 = HEAP32[$91 + 4 >> 2];
    var $93 = $5 | 0;
    HEAP32[$93 >> 2] = $92$0;
    HEAP32[$93 + 4 >> 2] = $92$1;
    var $94 = $pn + 4 | 0;
    var $95 = __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($86, $87, $4, $5, $94, $dst);
    var $_3 = $95;
    __label__ = 115;
    break;
   case 16:
    var $97 = __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $97;
    __label__ = 115;
    break;
   case 17:
    var $99 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 20);
    var $100 = __ZNK11JSParseNode5getOpEv($pn);
    var $102 = HEAP32[$pn + 32 >> 2];
    var $103 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $102, $expr);
    if ($103) {
      __label__ = 18;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 18:
    var $105 = ($100 - 41 | 0) >>> 0 < 6;
    var $106 = $this + 8 | 0;
    var $107 = $expr | 0;
    var $108$0 = HEAP32[$107 >> 2];
    var $108$1 = HEAP32[$107 + 4 >> 2];
    var $109 = $6 | 0;
    HEAP32[$109 >> 2] = $108$0;
    HEAP32[$109 + 4 >> 2] = $108$1;
    var $110 = $pn + 4 | 0;
    var $111 = __ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_($106, $6, $99, $105, $110, $dst);
    var $_3 = $111;
    __label__ = 115;
    break;
   case 19:
    var $113 = __ZNK11JSParseNode5getOpEv($pn);
    var $114 = __ZN2js13ASTSerializer3aopE4JSOp(undef, $113);
    if ($114 >>> 0 < 12) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 21:
    var $119 = HEAP32[$pn + 32 >> 2];
    var $120 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $119, 0, $lhs);
    if ($120) {
      __label__ = 22;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 22:
    var $124 = HEAP32[$pn + 36 >> 2];
    var $125 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $124, $rhs);
    if ($125) {
      __label__ = 23;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 23:
    var $127 = $this + 8 | 0;
    var $128 = $lhs | 0;
    var $st$2$0 = $128 | 0;
    var $129$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $128 + 4 | 0;
    var $129$1 = HEAP32[$st$2$1 >> 2];
    var $130 = $7 | 0;
    var $st$7$0 = $130 | 0;
    HEAP32[$st$7$0 >> 2] = $129$0;
    var $st$7$1 = $130 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $129$1;
    var $131 = $rhs | 0;
    var $st$12$0 = $131 | 0;
    var $132$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $131 + 4 | 0;
    var $132$1 = HEAP32[$st$12$1 >> 2];
    var $133 = $8 | 0;
    var $st$17$0 = $133 | 0;
    HEAP32[$st$17$0 >> 2] = $132$0;
    var $st$17$1 = $133 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $132$1;
    var $134 = $pn + 4 | 0;
    var $135 = __ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($127, $114, $7, $8, $134, $dst);
    var $_3 = $135;
    __label__ = 115;
    break;
   case 24:
    var $137 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($137) {
      __label__ = 25;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 25:
    var $139 = __ZNK11JSParseNode5getOpEv($pn);
    var $140 = __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp(undef, $36, $139);
    if ($140 >>> 0 < 22) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 27:
    var $145 = HEAP32[$pn + 32 >> 2];
    var $146 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $145, $left2);
    if ($146) {
      __label__ = 28;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 28:
    var $150 = HEAP32[$pn + 36 >> 2];
    var $151 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $150, $right3);
    if ($151) {
      __label__ = 29;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 29:
    var $153 = $this + 8 | 0;
    var $154 = $left2 | 0;
    var $st$2$0 = $154 | 0;
    var $155$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $154 + 4 | 0;
    var $155$1 = HEAP32[$st$2$1 >> 2];
    var $156 = $9 | 0;
    var $st$7$0 = $156 | 0;
    HEAP32[$st$7$0 >> 2] = $155$0;
    var $st$7$1 = $156 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $155$1;
    var $157 = $right3 | 0;
    var $st$12$0 = $157 | 0;
    var $158$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $157 + 4 | 0;
    var $158$1 = HEAP32[$st$12$1 >> 2];
    var $159 = $10 | 0;
    var $st$17$0 = $159 | 0;
    HEAP32[$st$17$0 >> 2] = $158$0;
    var $st$17$1 = $159 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $158$1;
    var $160 = $pn + 4 | 0;
    var $161 = __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($153, $140, $9, $10, $160, $dst);
    var $_3 = $161;
    __label__ = 115;
    break;
   case 30:
    var $163 = __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $163;
    __label__ = 115;
    break;
   case 31:
    var $165 = __ZNK11JSParseNode4isOpE4JSOp($pn, 174);
    if ($165) {
      __label__ = 34;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $167 = __ZNK11JSParseNode4isOpE4JSOp($pn, 173);
    if ($167) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $169 = __ZNK11JSParseNode4isOpE4JSOp($pn, 172);
    if ($169) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $172 = HEAP32[$pn + 32 >> 2];
    var $173 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $172, $dst);
    var $_3 = $173;
    __label__ = 115;
    break;
   case 35:
    var $175 = __ZNK11JSParseNode5getOpEv($pn);
    var $176 = __ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp(undef, $36, $175);
    if ($176 >>> 0 < 7) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 37:
    var $181 = HEAP32[$pn + 32 >> 2];
    var $182 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $181, $expr5);
    if ($182) {
      __label__ = 38;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 38:
    var $184 = $this + 8 | 0;
    var $185 = $expr5 | 0;
    var $st$2$0 = $185 | 0;
    var $186$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $185 + 4 | 0;
    var $186$1 = HEAP32[$st$2$1 >> 2];
    var $187 = $11 | 0;
    var $st$7$0 = $187 | 0;
    HEAP32[$st$7$0 >> 2] = $186$0;
    var $st$7$1 = $187 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $186$1;
    var $188 = $pn + 4 | 0;
    var $189 = __ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_($184, $176, $11, $188, $dst);
    var $_3 = $189;
    __label__ = 115;
    break;
   case 39:
    var $191 = __ZNK11JSParseNode15isGeneratorExprEv($pn);
    if ($191) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $193 = __ZNK11JSParseNode13generatorExprEv($pn);
    var $194 = __ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE($this, $193, $dst);
    var $_3 = $194;
    __label__ = 115;
    break;
   case 41:
    var $197 = HEAP32[$pn + 32 >> 2];
    var $198 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $197, $callee);
    if ($198) {
      __label__ = 42;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 42:
    var $200 = HEAP32[$29 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($args, $200);
    var $201 = $args | 0;
    var $204 = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $205 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($201, $204);
    if ($205) {
      var $_pn = $197;
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 43:
    var $_pn;
    var $next_0 = HEAP32[$_pn + 24 >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $208 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $arg);
    if ($208) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 49;
      break;
    }
   case 45:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($201, $arg);
    var $_pn = $next_0;
    __label__ = 43;
    break;
   case 46:
    var $211 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 49);
    var $212 = $this + 8 | 0;
    var $213 = $callee | 0;
    var $st$3$0 = $213 | 0;
    var $214$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $213 + 4 | 0;
    var $214$1 = HEAP32[$st$3$1 >> 2];
    if ($211) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $216 = $12 | 0;
    var $st$1$0 = $216 | 0;
    HEAP32[$st$1$0 >> 2] = $214$0;
    var $st$1$1 = $216 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $214$1;
    var $217 = $pn + 4 | 0;
    var $218 = __ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($212, $12, $args, $217, $dst);
    var $_0 = $218;
    __label__ = 49;
    break;
   case 48:
    var $220 = $13 | 0;
    var $st$1$0 = $220 | 0;
    HEAP32[$st$1$0 >> 2] = $214$0;
    var $st$1$1 = $220 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $214$1;
    var $221 = $pn + 4 | 0;
    var $222 = __ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($212, $13, $args, $221, $dst);
    var $_0 = $222;
    __label__ = 49;
    break;
   case 49:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($args);
    var $_3 = $_0;
    __label__ = 115;
    break;
   case 50:
    var $226 = HEAP32[$pn + 36 >> 2];
    var $227 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $226, $expr6);
    if ($227) {
      __label__ = 51;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 51:
    var $231 = HEAP32[$pn + 32 >> 2];
    var $232 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $231, 0, $id);
    if ($232) {
      __label__ = 52;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 52:
    var $234 = $this + 8 | 0;
    var $235 = $expr6 | 0;
    var $st$2$0 = $235 | 0;
    var $236$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $235 + 4 | 0;
    var $236$1 = HEAP32[$st$2$1 >> 2];
    var $237 = $14 | 0;
    var $st$7$0 = $237 | 0;
    HEAP32[$st$7$0 >> 2] = $236$0;
    var $st$7$1 = $237 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $236$1;
    var $238 = $id | 0;
    var $st$12$0 = $238 | 0;
    var $239$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $238 + 4 | 0;
    var $239$1 = HEAP32[$st$12$1 >> 2];
    var $240 = $15 | 0;
    var $st$17$0 = $240 | 0;
    HEAP32[$st$17$0 >> 2] = $239$0;
    var $st$17$1 = $240 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $239$1;
    var $241 = $pn + 4 | 0;
    var $242 = __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($234, 0, $14, $15, $241, $dst);
    var $_3 = $242;
    __label__ = 115;
    break;
   case 53:
    var $244 = $pn + 36 | 0;
    var $246 = HEAP32[$244 >> 2];
    var $247 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($246, 71);
    if ($247) {
      var $254 = 0;
      __label__ = 56;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $249 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($246, 72);
    if ($249) {
      var $254 = 0;
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $251 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($246, 70);
    var $254 = $251 ^ 1;
    __label__ = 56;
    break;
   case 56:
    var $254;
    var $256 = HEAP32[$pn + 32 >> 2];
    var $257 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $256, $left7);
    if ($257) {
      __label__ = 57;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 57:
    var $260 = HEAP32[$244 >> 2];
    var $261 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $260, $right8);
    if ($261) {
      __label__ = 58;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 58:
    var $263 = $this + 8 | 0;
    var $264 = $left7 | 0;
    var $st$2$0 = $264 | 0;
    var $265$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $264 + 4 | 0;
    var $265$1 = HEAP32[$st$2$1 >> 2];
    var $266 = $16 | 0;
    var $st$7$0 = $266 | 0;
    HEAP32[$st$7$0 >> 2] = $265$0;
    var $st$7$1 = $266 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $265$1;
    var $267 = $right8 | 0;
    var $st$12$0 = $267 | 0;
    var $268$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $267 + 4 | 0;
    var $268$1 = HEAP32[$st$12$1 >> 2];
    var $269 = $17 | 0;
    var $st$17$0 = $269 | 0;
    HEAP32[$st$17$0 >> 2] = $268$0;
    var $st$17$1 = $269 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $268$1;
    var $270 = $pn + 4 | 0;
    var $271 = __ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($263, $254, $16, $17, $270, $dst);
    var $_3 = $271;
    __label__ = 115;
    break;
   case 59:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $30);
    var $273 = $elts | 0;
    var $275 = HEAP32[$pn + 40 >> 2];
    var $276 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($273, $275);
    if ($276) {
      __label__ = 60;
      break;
    } else {
      var $_1 = 0;
      __label__ = 68;
      break;
    }
   case 60:
    var $next9_0_in = $pn + 32 | 0;
    __label__ = 61;
    break;
   case 61:
    var $next9_0_in;
    var $next9_0 = HEAP32[$next9_0_in >> 2];
    if (($next9_0 | 0) == 0) {
      __label__ = 67;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $282 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next9_0, 3);
    if ($282) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($18);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($273, $18);
    __label__ = 66;
    break;
   case 64:
    var $285 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next9_0, $expr10);
    if ($285) {
      __label__ = 65;
      break;
    } else {
      var $_1 = 0;
      __label__ = 68;
      break;
    }
   case 65:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($273, $expr10);
    __label__ = 66;
    break;
   case 66:
    var $next9_0_in = $next9_0 + 24 | 0;
    __label__ = 61;
    break;
   case 67:
    var $290 = $this + 8 | 0;
    var $291 = $pn + 4 | 0;
    var $292 = __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($290, $elts, $291, $dst);
    var $_1 = $292;
    __label__ = 68;
    break;
   case 68:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($elts);
    var $_3 = $_1;
    __label__ = 115;
    break;
   case 69:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts11, $30);
    var $294 = $elts11 | 0;
    var $296 = HEAP32[$pn + 40 >> 2];
    var $297 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($294, $296);
    if ($297) {
      __label__ = 70;
      break;
    } else {
      var $_2 = 0;
      __label__ = 75;
      break;
    }
   case 70:
    var $next12_0_in = $pn + 32 | 0;
    __label__ = 71;
    break;
   case 71:
    var $next12_0_in;
    var $next12_0 = HEAP32[$next12_0_in >> 2];
    if (($next12_0 | 0) == 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $303 = __ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE($this, $next12_0, $prop);
    if ($303) {
      __label__ = 73;
      break;
    } else {
      var $_2 = 0;
      __label__ = 75;
      break;
    }
   case 73:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($294, $prop);
    var $next12_0_in = $next12_0 + 24 | 0;
    __label__ = 71;
    break;
   case 74:
    var $307 = $this + 8 | 0;
    var $308 = $pn + 4 | 0;
    var $309 = __ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($307, $elts11, $308, $dst);
    var $_2 = $309;
    __label__ = 75;
    break;
   case 75:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($elts11);
    var $_3 = $_2;
    __label__ = 115;
    break;
   case 76:
    var $311 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $311;
    __label__ = 115;
    break;
   case 77:
    var $313 = __ZNK11JSParseNode4isOpE4JSOp($pn, 65);
    if ($313) {
      __label__ = 78;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 78:
    var $315 = $this + 8 | 0;
    var $316 = $pn + 4 | 0;
    var $317 = __ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE($315, $316, $dst);
    var $_3 = $317;
    __label__ = 115;
    break;
   case 79:
    var $319 = __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $319;
    __label__ = 115;
    break;
   case 80:
    var $322 = HEAP32[$pn + 32 >> 2];
    var $323 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $322, $arg13);
    if ($323) {
      __label__ = 81;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 81:
    var $325 = $this + 8 | 0;
    var $326 = $arg13 | 0;
    var $st$2$0 = $326 | 0;
    var $327$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $326 + 4 | 0;
    var $327$1 = HEAP32[$st$2$1 >> 2];
    var $328 = $19 | 0;
    var $st$7$0 = $328 | 0;
    HEAP32[$st$7$0 >> 2] = $327$0;
    var $st$7$1 = $328 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $327$1;
    var $329 = $pn + 4 | 0;
    var $330 = __ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($325, $19, $329, $dst);
    var $_3 = $330;
    __label__ = 115;
    break;
   case 82:
    var $333 = HEAP32[$pn + 32 >> 2];
    var $334 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $333, $expr14);
    if ($334) {
      __label__ = 83;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 83:
    var $336 = $this + 8 | 0;
    var $339 = HEAP32[$pn + 36 >> 2];
    var $340 = $expr14 | 0;
    var $341$0 = HEAP32[$340 >> 2];
    var $341$1 = HEAP32[$340 + 4 >> 2];
    var $342 = $20 | 0;
    HEAP32[$342 >> 2] = $341$0;
    HEAP32[$342 + 4 >> 2] = $341$1;
    var $343 = $pn + 4 | 0;
    var $344 = __ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_($336, $339, $20, $343, $dst);
    var $_3 = $344;
    __label__ = 115;
    break;
   case 84:
    var $346 = $this + 8 | 0;
    var $349 = HEAP32[$pn + 36 >> 2];
    var $350 = $pn + 4 | 0;
    var $351 = __ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE($346, $349, $350, $dst);
    var $_3 = $351;
    __label__ = 115;
    break;
   case 85:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 1) {
      __label__ = 87;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 87:
    var $359 = HEAP32[$pn + 32 >> 2];
    var $360 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($359, 80);
    if ($360) {
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 89:
    var $365 = HEAP32[$359 + 36 >> 2];
    var $366 = __ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE($this, $365, $dst);
    var $_3 = $366;
    __label__ = 115;
    break;
   case 90:
    var $369 = HEAP32[$pn + 36 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $30);
    var $371 = HEAP32[$369 + 32 >> 2];
    var $372 = __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $371, $dtors);
    if ($372) {
      __label__ = 91;
      break;
    } else {
      var $386 = 0;
      __label__ = 93;
      break;
    }
   case 91:
    var $375 = HEAP32[$369 + 36 >> 2];
    var $376 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $375, $expr15);
    if ($376) {
      __label__ = 92;
      break;
    } else {
      var $386 = 0;
      __label__ = 93;
      break;
    }
   case 92:
    var $378 = $this + 8 | 0;
    var $379 = $expr15 | 0;
    var $st$2$0 = $379 | 0;
    var $380$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $379 + 4 | 0;
    var $380$1 = HEAP32[$st$2$1 >> 2];
    var $381 = $21 | 0;
    var $st$7$0 = $381 | 0;
    HEAP32[$st$7$0 >> 2] = $380$0;
    var $st$7$1 = $381 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $380$1;
    var $383 = $369 + 4 | 0;
    var $384 = __ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($378, $dtors, $21, $383, $dst);
    var $386 = $384;
    __label__ = 93;
    break;
   case 93:
    var $386;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    var $_3 = $386;
    __label__ = 115;
    break;
   case 94:
    var $388 = $this + 8 | 0;
    var $389 = $pn + 4 | 0;
    var $390 = __ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE($388, $389, $dst);
    var $_3 = $390;
    __label__ = 115;
    break;
   case 95:
    var $392 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($392) {
      __label__ = 98;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $394 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($394) {
      __label__ = 98;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    _JS_ReportErrorNumber($30, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_3 = 0;
    __label__ = 115;
    break;
   case 98:
    var $397 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($397) {
      __label__ = 99;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 99:
    var $400 = HEAP32[$pn + 32 >> 2];
    var $403 = HEAP32[$pn + 36 >> 2];
    var $404 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $403, $right16);
    if ($404) {
      var $computed17_0 = 1;
      var $pnleft_0 = $400;
      __label__ = 101;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 100:
    var $409 = HEAP32[$pn + 36 >> 2];
    var $411 = HEAP32[$pn + 32 >> 2];
    var $412 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $411, 0, $right16);
    if ($412) {
      var $computed17_0 = 0;
      var $pnleft_0 = $409;
      __label__ = 101;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 101:
    var $pnleft_0;
    var $computed17_0;
    var $414 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pnleft_0, 34);
    if ($414) {
      __label__ = 102;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 102:
    var $416 = $this + 8 | 0;
    var $417 = $right16 | 0;
    var $st$2$0 = $417 | 0;
    var $418$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $417 + 4 | 0;
    var $418$1 = HEAP32[$st$2$1 >> 2];
    var $419 = $22 | 0;
    var $st$7$0 = $419 | 0;
    HEAP32[$st$7$0 >> 2] = $418$0;
    var $st$7$1 = $419 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $418$1;
    var $420 = $pn + 4 | 0;
    var $421 = __ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_($416, $22, $computed17_0, $420, $dst);
    var $_3 = $421;
    __label__ = 115;
    break;
   case 103:
    var $423 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pnleft_0, $left18);
    if ($423) {
      __label__ = 104;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 104:
    var $425 = $this + 8 | 0;
    var $426 = $left18 | 0;
    var $st$2$0 = $426 | 0;
    var $427$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $426 + 4 | 0;
    var $427$1 = HEAP32[$st$2$1 >> 2];
    var $428 = $23 | 0;
    var $st$7$0 = $428 | 0;
    HEAP32[$st$7$0 >> 2] = $427$0;
    var $st$7$1 = $428 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $427$1;
    var $429 = $right16 | 0;
    var $st$12$0 = $429 | 0;
    var $430$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $429 + 4 | 0;
    var $430$1 = HEAP32[$st$12$1 >> 2];
    var $431 = $24 | 0;
    var $st$17$0 = $431 | 0;
    HEAP32[$st$17$0 >> 2] = $430$0;
    var $st$17$1 = $431 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $430$1;
    var $432 = $pn + 4 | 0;
    var $433 = __ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_($425, $23, $24, $computed17_0, $432, $dst);
    var $_3 = $433;
    __label__ = 115;
    break;
   case 105:
    var $436 = HEAP32[$pn + 32 >> 2];
    var $437 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($436, 29);
    if ($437) {
      __label__ = 106;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 106:
    var $439 = __ZNK11JSParseNode4isOpE4JSOp($436, 165);
    if ($439) {
      var $446 = 0;
      __label__ = 109;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $441 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($436, 71);
    if ($441) {
      var $446 = 0;
      __label__ = 109;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $443 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($436, 72);
    var $446 = $443 ^ 1;
    __label__ = 109;
    break;
   case 109:
    var $446;
    var $447 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $436, $expr19);
    if ($447) {
      __label__ = 110;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 110:
    var $449 = $this + 8 | 0;
    var $450 = $expr19 | 0;
    var $st$2$0 = $450 | 0;
    var $451$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $450 + 4 | 0;
    var $451$1 = HEAP32[$st$2$1 >> 2];
    var $452 = $25 | 0;
    var $st$7$0 = $452 | 0;
    HEAP32[$st$7$0 >> 2] = $451$0;
    var $st$7$1 = $452 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $451$1;
    var $453 = $pn + 4 | 0;
    var $454 = __ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_($449, $25, $446, $453, $dst);
    var $_3 = $454;
    __label__ = 115;
    break;
   case 111:
    var $457 = HEAP32[$pn + 32 >> 2];
    var $458 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $457, $left21);
    if ($458) {
      __label__ = 112;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 112:
    var $462 = HEAP32[$pn + 36 >> 2];
    var $463 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $462, $right22);
    if ($463) {
      __label__ = 113;
      break;
    } else {
      var $_3 = 0;
      __label__ = 115;
      break;
    }
   case 113:
    var $465 = $this + 8 | 0;
    var $466 = $left21 | 0;
    var $st$2$0 = $466 | 0;
    var $467$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $466 + 4 | 0;
    var $467$1 = HEAP32[$st$2$1 >> 2];
    var $468 = $26 | 0;
    var $st$7$0 = $468 | 0;
    HEAP32[$st$7$0 >> 2] = $467$0;
    var $st$7$1 = $468 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $467$1;
    var $469 = $right22 | 0;
    var $st$12$0 = $469 | 0;
    var $470$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $469 + 4 | 0;
    var $470$1 = HEAP32[$st$12$1 >> 2];
    var $471 = $27 | 0;
    var $st$17$0 = $471 | 0;
    HEAP32[$st$17$0 >> 2] = $470$0;
    var $st$17$1 = $471 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $470$1;
    var $472 = $pn + 4 | 0;
    var $473 = __ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_($465, $26, $27, $472, $dst);
    var $_3 = $473;
    __label__ = 115;
    break;
   case 114:
    var $475 = __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_3 = $475;
    __label__ = 115;
    break;
   case 115:
    var $_3;
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elt = __stackBase__;
    var $1 = $elts | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $next_0, $elt);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $elt);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 636;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $expr = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $elts = __stackBase__ + 20;
    var $elts1 = __stackBase__ + 112;
    var $elts2 = __stackBase__ + 204;
    var $elts3 = __stackBase__ + 296;
    var $elts4 = __stackBase__ + 388;
    var $2 = __stackBase__ + 480;
    var $3 = __stackBase__ + 488;
    var $elts5 = __stackBase__ + 496;
    var $4 = __stackBase__ + 588;
    var $5 = __stackBase__ + 596;
    var $6 = __stackBase__ + 604;
    var $7 = __stackBase__ + 612;
    var $8 = __stackBase__ + 620;
    var $9 = __stackBase__ + 628;
    var $12 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$12 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($12);
    var $_5 = 0;
    __label__ = 36;
    break;
   case 3:
    var $18 = __ZNK11JSParseNode7getKindEv($pn);
    if (($18 | 0) == 25) {
      __label__ = 4;
      break;
    } else if (($18 | 0) == 75) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 76) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 59) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 60) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 61) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 66 || ($18 | 0) == 65) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 63) {
      __label__ = 22;
      break;
    } else if (($18 | 0) == 64) {
      __label__ = 29;
      break;
    } else if (($18 | 0) == 68) {
      __label__ = 30;
      break;
    } else if (($18 | 0) == 67) {
      __label__ = 31;
      break;
    } else if (($18 | 0) == 69) {
      __label__ = 32;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 4:
    var $21 = HEAP32[$pn + 32 >> 2];
    var $22 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $21, $expr);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      var $_5 = 0;
      __label__ = 36;
      break;
    }
   case 5:
    var $24 = $this + 8 | 0;
    var $25 = $expr | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $1 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = $pn + 4 | 0;
    var $29 = __ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_($24, $1, $28, $dst);
    var $_5 = $29;
    __label__ = 36;
    break;
   case 6:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $12);
    var $31 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = $this + 8 | 0;
    var $34 = $pn + 4 | 0;
    var $35 = __ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($33, $elts, $34, $dst);
    var $_0 = $35;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    var $_5 = $_0;
    __label__ = 36;
    break;
   case 9:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts1, $12);
    var $38 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts1);
    if ($38) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $40 = $this + 8 | 0;
    var $41 = $pn + 4 | 0;
    var $42 = __ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($40, $elts1, $41, $dst);
    var $_1 = $42;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    __ZN2js15AutoValueVectorD1Ev($elts1);
    var $_5 = $_1;
    __label__ = 36;
    break;
   case 12:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts2, $12);
    var $45 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts2);
    if ($45) {
      __label__ = 13;
      break;
    } else {
      var $_2 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $47 = $this + 8 | 0;
    var $48 = $pn + 4 | 0;
    var $49 = __ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($47, $elts2, $48, $dst);
    var $_2 = $49;
    __label__ = 14;
    break;
   case 14:
    var $_2;
    __ZN2js15AutoValueVectorD1Ev($elts2);
    var $_5 = $_2;
    __label__ = 36;
    break;
   case 15:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts3, $12);
    var $52 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts3);
    if ($52) {
      __label__ = 16;
      break;
    } else {
      var $_3 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $54 = $this + 8 | 0;
    var $55 = $pn + 4 | 0;
    var $56 = __ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($54, $elts3, $55, $dst);
    var $_3 = $56;
    __label__ = 17;
    break;
   case 17:
    var $_3;
    __ZN2js15AutoValueVectorD1Ev($elts3);
    var $_5 = $_3;
    __label__ = 36;
    break;
   case 18:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts4, $12);
    var $59 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts4);
    if ($59) {
      __label__ = 19;
      break;
    } else {
      var $_4 = 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $61 = $this + 8 | 0;
    var $62 = $pn + 4 | 0;
    var $63 = __ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($61, $elts4, $62, $dst);
    var $_4 = $63;
    __label__ = 20;
    break;
   case 20:
    var $_4;
    __ZN2js15AutoValueVectorD1Ev($elts4);
    var $_5 = $_4;
    __label__ = 36;
    break;
   case 21:
    var $66 = $this + 8 | 0;
    var $69 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($2, $this, $69);
    var $70 = $pn + 4 | 0;
    var $71 = __ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_($66, $2, $70, $dst);
    var $_5 = $71;
    __label__ = 36;
    break;
   case 22:
    var $73 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($73) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $75 = $this + 8 | 0;
    var $78 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($3, $this, $78);
    var $79 = $pn + 4 | 0;
    var $80 = __ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_($75, $3, $79, $dst);
    var $_5 = $80;
    __label__ = 36;
    break;
   case 24:
    var $82 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 5);
    if ($82) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    _JS_ReportErrorNumber($12, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 36;
    break;
   case 26:
    __ZN2js15AutoValueVectorC1EP9JSContext($elts5, $12);
    var $85 = __ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $elts5);
    if ($85) {
      __label__ = 27;
      break;
    } else {
      var $91 = 0;
      __label__ = 28;
      break;
    }
   case 27:
    var $87 = $this + 8 | 0;
    var $88 = $pn + 4 | 0;
    var $89 = __ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($87, $elts5, $88, $dst);
    var $91 = $89;
    __label__ = 28;
    break;
   case 28:
    var $91;
    __ZN2js15AutoValueVectorD1Ev($elts5);
    var $_5 = $91;
    __label__ = 36;
    break;
   case 29:
    var $93 = $this + 8 | 0;
    var $96 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($4, $this, $96);
    var $97 = $pn + 4 | 0;
    var $98 = __ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_($93, $4, $97, $dst);
    var $_5 = $98;
    __label__ = 36;
    break;
   case 30:
    var $100 = $this + 8 | 0;
    var $103 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($5, $this, $103);
    var $104 = $pn + 4 | 0;
    var $105 = __ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_($100, $5, $104, $dst);
    var $_5 = $105;
    __label__ = 36;
    break;
   case 31:
    var $107 = $this + 8 | 0;
    var $110 = HEAP32[$pn + 32 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($6, $this, $110);
    var $111 = $pn + 4 | 0;
    var $112 = __ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_($107, $6, $111, $dst);
    var $_5 = $112;
    __label__ = 36;
    break;
   case 32:
    var $115 = $pn + 36 | 0;
    var $118 = $this + 8 | 0;
    var $120 = HEAP32[$pn + 32 >> 2];
    if ((HEAP32[$115 >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($7, $this, $120);
    var $122 = $pn + 4 | 0;
    var $123 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_($118, $7, $122, $dst);
    var $_5 = $123;
    __label__ = 36;
    break;
   case 34:
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($8, $this, $120);
    var $126 = HEAP32[$115 >> 2];
    __ZN2js13ASTSerializer12atomContentsEP6JSAtom($9, $this, $126);
    var $127 = $pn + 4 | 0;
    var $128 = __ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_($118, $8, $9, $127, $dst);
    var $_5 = $128;
    __label__ = 36;
    break;
   case 35:
    _JS_ReportErrorNumber($12, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_5 = 0;
    __label__ = 36;
    break;
   case 36:
    var $_5;
    STACKTOP = __stackBase__;
    return $_5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $2);
    var $3 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $stmts);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = $pn + 4 | 0;
    var $7 = __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($5, $stmts, $6, $dst);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $2);
    var $3 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $stmts);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = $pn + 4 | 0;
    var $7 = __ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($5, $stmts, $6, $dst);
    var $9 = $7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 504;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $expr = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $dtors = __stackBase__ + 20;
    var $stmt = __stackBase__ + 112;
    var $2 = __stackBase__ + 120;
    var $test = __stackBase__ + 128;
    var $cons = __stackBase__ + 136;
    var $alt = __stackBase__ + 144;
    var $3 = __stackBase__ + 152;
    var $4 = __stackBase__ + 160;
    var $5 = __stackBase__ + 168;
    var $expr1 = __stackBase__ + 176;
    var $stmt2 = __stackBase__ + 184;
    var $6 = __stackBase__ + 192;
    var $7 = __stackBase__ + 200;
    var $8 = __stackBase__ + 208;
    var $9 = __stackBase__ + 216;
    var $stmt3 = __stackBase__ + 224;
    var $test4 = __stackBase__ + 232;
    var $10 = __stackBase__ + 240;
    var $11 = __stackBase__ + 248;
    var $stmt5 = __stackBase__ + 256;
    var $var = __stackBase__ + 264;
    var $expr6 = __stackBase__ + 272;
    var $12 = __stackBase__ + 280;
    var $13 = __stackBase__ + 288;
    var $14 = __stackBase__ + 296;
    var $init = __stackBase__ + 304;
    var $test7 = __stackBase__ + 312;
    var $update = __stackBase__ + 320;
    var $15 = __stackBase__ + 328;
    var $16 = __stackBase__ + 336;
    var $17 = __stackBase__ + 344;
    var $18 = __stackBase__ + 352;
    var $var8 = __stackBase__ + 360;
    var $expr11 = __stackBase__ + 368;
    var $stmt12 = __stackBase__ + 376;
    var $19 = __stackBase__ + 384;
    var $20 = __stackBase__ + 392;
    var $21 = __stackBase__ + 400;
    var $label = __stackBase__ + 408;
    var $22 = __stackBase__ + 416;
    var $23 = __stackBase__ + 424;
    var $label13 = __stackBase__ + 432;
    var $stmt14 = __stackBase__ + 440;
    var $24 = __stackBase__ + 448;
    var $25 = __stackBase__ + 456;
    var $arg = __stackBase__ + 464;
    var $26 = __stackBase__ + 472;
    var $27 = __stackBase__ + 480;
    var $ns = __stackBase__ + 488;
    var $28 = __stackBase__ + 496;
    var $31 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$31 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($31);
    var $_0 = 0;
    __label__ = 71;
    break;
   case 3:
    var $37 = __ZNK11JSParseNode7getKindEv($pn);
    if (($37 | 0) == 34 || ($37 | 0) == 46 || ($37 | 0) == 81) {
      __label__ = 4;
      break;
    } else if (($37 | 0) == 29) {
      __label__ = 5;
      break;
    } else if (($37 | 0) == 2) {
      __label__ = 8;
      break;
    } else if (($37 | 0) == 80) {
      __label__ = 12;
      break;
    } else if (($37 | 0) == 25) {
      var $_01 = $pn;
      __label__ = 19;
      break;
    } else if (($37 | 0) == 35) {
      __label__ = 20;
      break;
    } else if (($37 | 0) == 37) {
      __label__ = 24;
      break;
    } else if (($37 | 0) == 53) {
      __label__ = 25;
      break;
    } else if (($37 | 0) == 47 || ($37 | 0) == 40) {
      __label__ = 26;
      break;
    } else if (($37 | 0) == 41) {
      __label__ = 31;
      break;
    } else if (($37 | 0) == 42) {
      __label__ = 34;
      break;
    } else if (($37 | 0) == 82) {
      __label__ = 45;
      break;
    } else if (($37 | 0) == 43 || ($37 | 0) == 44) {
      __label__ = 54;
      break;
    } else if (($37 | 0) == 6) {
      __label__ = 58;
      break;
    } else if (($37 | 0) == 56 || ($37 | 0) == 48) {
      __label__ = 61;
      break;
    } else if (($37 | 0) == 58) {
      __label__ = 65;
      break;
    } else if (($37 | 0) == 39) {
      __label__ = 66;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 4:
    var $39 = __ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $39;
    __label__ = 71;
    break;
   case 5:
    var $41 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($41) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($31, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 7:
    var $46 = HEAP32[$pn + 36 >> 2];
    var $47 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $46, $dst);
    var $_0 = $47;
    __label__ = 71;
    break;
   case 8:
    var $50 = HEAP32[$pn + 32 >> 2];
    if (($50 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $53 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $50, $expr);
    if ($53) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 10:
    var $55 = $this + 8 | 0;
    var $56 = $expr | 0;
    var $st$2$0 = $56 | 0;
    var $57$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $56 + 4 | 0;
    var $57$1 = HEAP32[$st$2$1 >> 2];
    var $58 = $1 | 0;
    var $st$7$0 = $58 | 0;
    HEAP32[$st$7$0 >> 2] = $57$0;
    var $st$7$1 = $58 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $57$1;
    var $59 = $pn + 4 | 0;
    var $60 = __ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_($55, $1, $59, $dst);
    var $_0 = $60;
    __label__ = 71;
    break;
   case 11:
    var $62 = $this + 8 | 0;
    var $63 = $pn + 4 | 0;
    var $64 = __ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE($62, $63, $dst);
    var $_0 = $64;
    __label__ = 71;
    break;
   case 12:
    var $67 = HEAP32[$pn + 36 >> 2];
    var $68 = $67;
    var $69 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($68, 81);
    if ($69) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $31);
    var $72 = HEAP32[$67 + 32 >> 2];
    var $73 = __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $72, $dtors);
    if ($73) {
      __label__ = 14;
      break;
    } else {
      var $87 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    var $76 = HEAP32[$67 + 36 >> 2];
    var $77 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $76, $stmt);
    if ($77) {
      __label__ = 15;
      break;
    } else {
      var $87 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $79 = $this + 8 | 0;
    var $80 = $stmt | 0;
    var $st$2$0 = $80 | 0;
    var $81$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $80 + 4 | 0;
    var $81$1 = HEAP32[$st$2$1 >> 2];
    var $82 = $2 | 0;
    var $st$7$0 = $82 | 0;
    HEAP32[$st$7$0 >> 2] = $81$0;
    var $st$7$1 = $82 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $81$1;
    var $84 = $67 + 4 | 0;
    var $85 = __ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_($79, $dtors, $2, $84, $dst);
    var $87 = $85;
    __label__ = 16;
    break;
   case 16:
    var $87;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    var $_0 = $87;
    __label__ = 71;
    break;
   case 17:
    var $89 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($68, 25);
    if ($89) {
      var $_01 = $68;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $91 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $68, $dst);
    var $_0 = $91;
    __label__ = 71;
    break;
   case 19:
    var $_01;
    var $93 = __ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE($this, $_01, $dst);
    var $_0 = $93;
    __label__ = 71;
    break;
   case 20:
    var $96 = HEAP32[$pn + 32 >> 2];
    var $97 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $96, $test);
    if ($97) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 21:
    var $101 = HEAP32[$pn + 36 >> 2];
    var $102 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $101, $cons);
    if ($102) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 22:
    var $106 = HEAP32[$pn + 40 >> 2];
    var $107 = __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $106, $alt);
    if ($107) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 23:
    var $109 = $this + 8 | 0;
    var $110 = $test | 0;
    var $st$2$0 = $110 | 0;
    var $111$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $110 + 4 | 0;
    var $111$1 = HEAP32[$st$2$1 >> 2];
    var $112 = $3 | 0;
    var $st$7$0 = $112 | 0;
    HEAP32[$st$7$0 >> 2] = $111$0;
    var $st$7$1 = $112 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $111$1;
    var $113 = $cons | 0;
    var $st$12$0 = $113 | 0;
    var $114$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $113 + 4 | 0;
    var $114$1 = HEAP32[$st$12$1 >> 2];
    var $115 = $4 | 0;
    var $st$17$0 = $115 | 0;
    HEAP32[$st$17$0 >> 2] = $114$0;
    var $st$17$1 = $115 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $114$1;
    var $116 = $alt | 0;
    var $st$22$0 = $116 | 0;
    var $117$0 = HEAP32[$st$22$0 >> 2];
    var $st$22$1 = $116 + 4 | 0;
    var $117$1 = HEAP32[$st$22$1 >> 2];
    var $118 = $5 | 0;
    var $st$27$0 = $118 | 0;
    HEAP32[$st$27$0 >> 2] = $117$0;
    var $st$27$1 = $118 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $117$1;
    var $119 = $pn + 4 | 0;
    var $120 = __ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($109, $3, $4, $5, $119, $dst);
    var $_0 = $120;
    __label__ = 71;
    break;
   case 24:
    var $122 = __ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $122;
    __label__ = 71;
    break;
   case 25:
    var $124 = __ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $124;
    __label__ = 71;
    break;
   case 26:
    var $127 = HEAP32[$pn + 32 >> 2];
    var $128 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $127, $expr1);
    if ($128) {
      __label__ = 27;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 27:
    var $132 = HEAP32[$pn + 36 >> 2];
    var $133 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $132, $stmt2);
    if ($133) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    var $135 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 47);
    if ($135) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $137 = $this + 8 | 0;
    var $138 = $expr1 | 0;
    var $st$2$0 = $138 | 0;
    var $139$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $138 + 4 | 0;
    var $139$1 = HEAP32[$st$2$1 >> 2];
    var $140 = $6 | 0;
    var $st$7$0 = $140 | 0;
    HEAP32[$st$7$0 >> 2] = $139$0;
    var $st$7$1 = $140 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $139$1;
    var $141 = $stmt2 | 0;
    var $st$12$0 = $141 | 0;
    var $142$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $141 + 4 | 0;
    var $142$1 = HEAP32[$st$12$1 >> 2];
    var $143 = $7 | 0;
    var $st$17$0 = $143 | 0;
    HEAP32[$st$17$0 >> 2] = $142$0;
    var $st$17$1 = $143 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $142$1;
    var $144 = $pn + 4 | 0;
    var $145 = __ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($137, $6, $7, $144, $dst);
    var $_0 = $145;
    __label__ = 71;
    break;
   case 30:
    var $147 = $this + 8 | 0;
    var $148 = $expr1 | 0;
    var $st$2$0 = $148 | 0;
    var $149$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $148 + 4 | 0;
    var $149$1 = HEAP32[$st$2$1 >> 2];
    var $150 = $8 | 0;
    var $st$7$0 = $150 | 0;
    HEAP32[$st$7$0 >> 2] = $149$0;
    var $st$7$1 = $150 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $149$1;
    var $151 = $stmt2 | 0;
    var $st$12$0 = $151 | 0;
    var $152$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $151 + 4 | 0;
    var $152$1 = HEAP32[$st$12$1 >> 2];
    var $153 = $9 | 0;
    var $st$17$0 = $153 | 0;
    HEAP32[$st$17$0 >> 2] = $152$0;
    var $st$17$1 = $153 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $152$1;
    var $154 = $pn + 4 | 0;
    var $155 = __ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($147, $8, $9, $154, $dst);
    var $_0 = $155;
    __label__ = 71;
    break;
   case 31:
    var $158 = HEAP32[$pn + 32 >> 2];
    var $159 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $158, $stmt3);
    if ($159) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 32:
    var $163 = HEAP32[$pn + 36 >> 2];
    var $164 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $163, $test4);
    if ($164) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 33:
    var $166 = $this + 8 | 0;
    var $167 = $stmt3 | 0;
    var $st$2$0 = $167 | 0;
    var $168$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $167 + 4 | 0;
    var $168$1 = HEAP32[$st$2$1 >> 2];
    var $169 = $10 | 0;
    var $st$7$0 = $169 | 0;
    HEAP32[$st$7$0 >> 2] = $168$0;
    var $st$7$1 = $169 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $168$1;
    var $170 = $test4 | 0;
    var $st$12$0 = $170 | 0;
    var $171$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $170 + 4 | 0;
    var $171$1 = HEAP32[$st$12$1 >> 2];
    var $172 = $11 | 0;
    var $st$17$0 = $172 | 0;
    HEAP32[$st$17$0 >> 2] = $171$0;
    var $st$17$1 = $172 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $171$1;
    var $173 = $pn + 4 | 0;
    var $174 = __ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($166, $10, $11, $173, $dst);
    var $_0 = $174;
    __label__ = 71;
    break;
   case 34:
    var $177 = HEAP32[$pn + 32 >> 2];
    var $180 = HEAP32[$pn + 36 >> 2];
    var $181 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $180, $stmt5);
    if ($181) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 35:
    var $187 = (HEAP32[$pn + 44 >> 2] & 2 | 0) != 0;
    var $188 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($177, 45);
    var $190 = HEAP32[$177 + 32 >> 2];
    if ($188) {
      __label__ = 36;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 36:
    if (($190 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    var $196 = HEAP32[$177 + 36 >> 2];
    var $197 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $196, 0, $var);
    if ($197) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 38:
    var $199 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($190, 81);
    var $200 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $190, $199, $var);
    if ($200) {
      __label__ = 39;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 39:
    var $204 = HEAP32[$177 + 40 >> 2];
    var $205 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $204, $expr6);
    if ($205) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 40:
    var $207 = $this + 8 | 0;
    var $208 = $var | 0;
    var $st$2$0 = $208 | 0;
    var $209$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $208 + 4 | 0;
    var $209$1 = HEAP32[$st$2$1 >> 2];
    var $210 = $12 | 0;
    var $st$7$0 = $210 | 0;
    HEAP32[$st$7$0 >> 2] = $209$0;
    var $st$7$1 = $210 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $209$1;
    var $211 = $expr6 | 0;
    var $st$12$0 = $211 | 0;
    var $212$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $211 + 4 | 0;
    var $212$1 = HEAP32[$st$12$1 >> 2];
    var $213 = $13 | 0;
    var $st$17$0 = $213 | 0;
    HEAP32[$st$17$0 >> 2] = $212$0;
    var $st$17$1 = $213 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $212$1;
    var $214 = $stmt5 | 0;
    var $st$22$0 = $214 | 0;
    var $215$0 = HEAP32[$st$22$0 >> 2];
    var $st$22$1 = $214 + 4 | 0;
    var $215$1 = HEAP32[$st$22$1 >> 2];
    var $216 = $14 | 0;
    var $st$27$0 = $216 | 0;
    HEAP32[$st$27$0 >> 2] = $215$0;
    var $st$27$1 = $216 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $215$1;
    var $217 = $pn + 4 | 0;
    var $218 = __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($207, $12, $13, $14, $187, $217, $dst);
    var $_0 = $218;
    __label__ = 71;
    break;
   case 41:
    var $220 = __ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE($this, $190, $init);
    if ($220) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 42:
    var $224 = HEAP32[$177 + 36 >> 2];
    var $225 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $224, $test7);
    if ($225) {
      __label__ = 43;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 43:
    var $229 = HEAP32[$177 + 40 >> 2];
    var $230 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $229, $update);
    if ($230) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 44:
    var $232 = $this + 8 | 0;
    var $233 = $init | 0;
    var $st$2$0 = $233 | 0;
    var $234$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $233 + 4 | 0;
    var $234$1 = HEAP32[$st$2$1 >> 2];
    var $235 = $15 | 0;
    var $st$7$0 = $235 | 0;
    HEAP32[$st$7$0 >> 2] = $234$0;
    var $st$7$1 = $235 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $234$1;
    var $236 = $test7 | 0;
    var $st$12$0 = $236 | 0;
    var $237$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $236 + 4 | 0;
    var $237$1 = HEAP32[$st$12$1 >> 2];
    var $238 = $16 | 0;
    var $st$17$0 = $238 | 0;
    HEAP32[$st$17$0 >> 2] = $237$0;
    var $st$17$1 = $238 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $237$1;
    var $239 = $update | 0;
    var $st$22$0 = $239 | 0;
    var $240$0 = HEAP32[$st$22$0 >> 2];
    var $st$22$1 = $239 + 4 | 0;
    var $240$1 = HEAP32[$st$22$1 >> 2];
    var $241 = $17 | 0;
    var $st$27$0 = $241 | 0;
    HEAP32[$st$27$0 >> 2] = $240$0;
    var $st$27$1 = $241 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $240$1;
    var $242 = $stmt5 | 0;
    var $243$0 = HEAP32[$242 >> 2];
    var $243$1 = HEAP32[$242 + 4 >> 2];
    var $244 = $18 | 0;
    HEAP32[$244 >> 2] = $243$0;
    HEAP32[$244 + 4 >> 2] = $243$1;
    var $245 = $pn + 4 | 0;
    var $246 = __ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_($232, $15, $16, $17, $18, $245, $dst);
    var $_0 = $246;
    __label__ = 71;
    break;
   case 45:
    if ((HEAP32[$pn + 40 >> 2] | 0) == 2) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    _JS_ReportErrorNumber($31, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 47:
    var $254 = HEAP32[$pn + 32 >> 2];
    var $256 = HEAP32[$254 + 24 >> 2];
    var $257 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($254, 46);
    if ($257) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $259 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($256, 42);
    if ($259) {
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    _JS_ReportErrorNumber($31, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 50:
    var $262 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $254, 0, $var8);
    if ($262) {
      __label__ = 51;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 51:
    var $270 = (HEAP32[$256 + 44 >> 2] & 2 | 0) != 0;
    var $273 = HEAP32[HEAP32[$256 + 32 >> 2] + 40 >> 2];
    var $274 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $273, $expr11);
    if ($274) {
      __label__ = 52;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 52:
    var $278 = HEAP32[$256 + 36 >> 2];
    var $279 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $278, $stmt12);
    if ($279) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 53:
    var $281 = $this + 8 | 0;
    var $282 = $var8 | 0;
    var $st$2$0 = $282 | 0;
    var $283$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $282 + 4 | 0;
    var $283$1 = HEAP32[$st$2$1 >> 2];
    var $284 = $19 | 0;
    var $st$7$0 = $284 | 0;
    HEAP32[$st$7$0 >> 2] = $283$0;
    var $st$7$1 = $284 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $283$1;
    var $285 = $expr11 | 0;
    var $st$12$0 = $285 | 0;
    var $286$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $285 + 4 | 0;
    var $286$1 = HEAP32[$st$12$1 >> 2];
    var $287 = $20 | 0;
    var $st$17$0 = $287 | 0;
    HEAP32[$st$17$0 >> 2] = $286$0;
    var $st$17$1 = $287 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $286$1;
    var $288 = $stmt12 | 0;
    var $st$22$0 = $288 | 0;
    var $289$0 = HEAP32[$st$22$0 >> 2];
    var $st$22$1 = $288 + 4 | 0;
    var $289$1 = HEAP32[$st$22$1 >> 2];
    var $290 = $21 | 0;
    var $st$27$0 = $290 | 0;
    HEAP32[$st$27$0 >> 2] = $289$0;
    var $st$27$1 = $290 + 4 | 0;
    HEAP32[$st$27$1 >> 2] = $289$1;
    var $291 = $pn + 4 | 0;
    var $292 = __ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_($281, $19, $20, $21, $270, $291, $dst);
    var $_0 = $292;
    __label__ = 71;
    break;
   case 54:
    var $296 = HEAP32[$pn + 32 >> 2];
    var $297 = __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $296, 0, $label);
    if ($297) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 55:
    var $299 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 43);
    var $300 = $this + 8 | 0;
    var $301 = $label | 0;
    var $st$3$0 = $301 | 0;
    var $302$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $301 + 4 | 0;
    var $302$1 = HEAP32[$st$3$1 >> 2];
    if ($299) {
      __label__ = 56;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 56:
    var $304 = $22 | 0;
    var $st$1$0 = $304 | 0;
    HEAP32[$st$1$0 >> 2] = $302$0;
    var $st$1$1 = $304 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $302$1;
    var $305 = $pn + 4 | 0;
    var $306 = __ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_($300, $22, $305, $dst);
    var $_0 = $306;
    __label__ = 71;
    break;
   case 57:
    var $308 = $23 | 0;
    var $st$1$0 = $308 | 0;
    HEAP32[$st$1$0 >> 2] = $302$0;
    var $st$1$1 = $308 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $302$1;
    var $309 = $pn + 4 | 0;
    var $310 = __ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_($300, $23, $309, $dst);
    var $_0 = $310;
    __label__ = 71;
    break;
   case 58:
    var $314 = HEAP32[$pn + 32 >> 2];
    var $315 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $314, 0, $label13);
    if ($315) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 59:
    var $319 = HEAP32[$pn + 36 >> 2];
    var $320 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $319, $stmt14);
    if ($320) {
      __label__ = 60;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 60:
    var $322 = $this + 8 | 0;
    var $323 = $label13 | 0;
    var $st$2$0 = $323 | 0;
    var $324$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $323 + 4 | 0;
    var $324$1 = HEAP32[$st$2$1 >> 2];
    var $325 = $24 | 0;
    var $st$7$0 = $325 | 0;
    HEAP32[$st$7$0 >> 2] = $324$0;
    var $st$7$1 = $325 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $324$1;
    var $326 = $stmt14 | 0;
    var $st$12$0 = $326 | 0;
    var $327$0 = HEAP32[$st$12$0 >> 2];
    var $st$12$1 = $326 + 4 | 0;
    var $327$1 = HEAP32[$st$12$1 >> 2];
    var $328 = $25 | 0;
    var $st$17$0 = $328 | 0;
    HEAP32[$st$17$0 >> 2] = $327$0;
    var $st$17$1 = $328 + 4 | 0;
    HEAP32[$st$17$1 >> 2] = $327$1;
    var $329 = $pn + 4 | 0;
    var $330 = __ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_($322, $24, $25, $329, $dst);
    var $_0 = $330;
    __label__ = 71;
    break;
   case 61:
    var $333 = HEAP32[$pn + 32 >> 2];
    var $334 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $333, $arg);
    if ($334) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 62:
    var $336 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 56);
    var $337 = $this + 8 | 0;
    var $338 = $arg | 0;
    var $st$3$0 = $338 | 0;
    var $339$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $338 + 4 | 0;
    var $339$1 = HEAP32[$st$3$1 >> 2];
    if ($336) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $341 = $26 | 0;
    var $st$1$0 = $341 | 0;
    HEAP32[$st$1$0 >> 2] = $339$0;
    var $st$1$1 = $341 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $339$1;
    var $342 = $pn + 4 | 0;
    var $343 = __ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_($337, $26, $342, $dst);
    var $_0 = $343;
    __label__ = 71;
    break;
   case 64:
    var $345 = $27 | 0;
    var $st$1$0 = $345 | 0;
    HEAP32[$st$1$0 >> 2] = $339$0;
    var $st$1$1 = $345 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $339$1;
    var $346 = $pn + 4 | 0;
    var $347 = __ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_($337, $27, $346, $dst);
    var $_0 = $347;
    __label__ = 71;
    break;
   case 65:
    var $349 = $this + 8 | 0;
    var $350 = $pn + 4 | 0;
    var $351 = __ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE($349, $350, $dst);
    var $_0 = $351;
    __label__ = 71;
    break;
   case 66:
    var $353 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 1);
    if ($353) {
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    _JS_ReportErrorNumber($31, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 68:
    var $357 = HEAP32[$pn + 32 >> 2];
    var $358 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $357, $ns);
    if ($358) {
      __label__ = 69;
      break;
    } else {
      var $_0 = 0;
      __label__ = 71;
      break;
    }
   case 69:
    var $360 = $this + 8 | 0;
    var $361 = $ns | 0;
    var $st$2$0 = $361 | 0;
    var $362$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $361 + 4 | 0;
    var $362$1 = HEAP32[$st$2$1 >> 2];
    var $363 = $28 | 0;
    var $st$7$0 = $363 | 0;
    HEAP32[$st$7$0 >> 2] = $362$0;
    var $st$7$1 = $363 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $362$1;
    var $364 = $pn + 4 | 0;
    var $365 = __ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_($360, $28, $364, $dst);
    var $_0 = $365;
    __label__ = 71;
    break;
   case 70:
    _JS_ReportErrorNumber($31, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 71;
    break;
   case 71:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($pn);
    if (($1 | 0) == 34) {
      __label__ = 2;
      break;
    } else if (($1 | 0) == 46) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, 4, $dst);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 0, $dst);
    var $_0 = $5;
    __label__ = 5;
    break;
   case 4:
    var $7 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 1, $dst);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE($this, $pn, $type, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $args = __stackBase__ + 8;
    var $body = __stackBase__ + 100;
    var $1 = __stackBase__ + 108;
    var $2 = __stackBase__ + 116;
    var $5 = HEAP32[$pn + 32 >> 2];
    var $7 = HEAP32[$5 + 8 >> 2];
    var $12 = (HEAP32[$5 + 60 >> 2] & 512 | 0) != 0;
    var $16 = (HEAP16[$7 + 58 >> 1] & 4096) << 16 >> 16 != 0;
    var $19 = HEAP32[$7 + 72 >> 2];
    var $20 = __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $19, 0, $id);
    if ($20) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $23 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($args, $23);
    var $25 = HEAP32[$pn + 36 >> 2];
    var $26 = $25;
    var $27 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($26, 85);
    if ($27) {
      __label__ = 3;
      break;
    } else {
      var $32 = $26;
      __label__ = 4;
      break;
    }
   case 3:
    var $32 = HEAP32[$25 + 36 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $32;
    var $33 = __ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE($this, $32, $args, $body);
    if ($33) {
      __label__ = 5;
      break;
    } else {
      var $45 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $35 = $this + 8 | 0;
    var $36 = $pn + 4 | 0;
    var $37 = $id | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $1 | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = $body | 0;
    var $41$0 = HEAP32[$40 >> 2];
    var $41$1 = HEAP32[$40 + 4 >> 2];
    var $42 = $2 | 0;
    HEAP32[$42 >> 2] = $41$0;
    HEAP32[$42 + 4 >> 2] = $41$1;
    var $43 = __ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_($35, $type, $36, $1, $args, $2, $12, $16, $dst);
    var $45 = $43;
    __label__ = 6;
    break;
   case 6:
    var $45;
    __ZN2js15AutoValueVectorD1Ev($args);
    var $_0 = $45;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, $let, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 136;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $dtors = __stackBase__ + 4;
    var $patt = __stackBase__ + 96;
    var $child = __stackBase__ + 104;
    var $1 = __stackBase__ + 112;
    var $2 = __stackBase__ + 120;
    var $child1 = __stackBase__ + 128;
    var $3 = $let ? 2 : 0;
    HEAP32[$kind >> 2] = $3;
    var $5 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($dtors, $5);
    var $6 = $pn + 32 | 0;
    if ((HEAP32[$pn + 44 >> 2] & 8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $6 | 0;
    var $14 = HEAP32[$13 >> 2];
    var $15 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $14, $kind, $patt);
    if ($15) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $17 = $this + 8 | 0;
    var $18 = $patt | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $1 | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __ZN2JSL9NullValueEv3400($2);
    var $22 = HEAP32[$13 >> 2] + 4 | 0;
    var $23 = __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($17, $1, $2, $22, $child);
    if ($23) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $25 = $dtors | 0;
    var $26 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($25, $child);
    if ($26) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $28 = HEAP32[$kind >> 2];
    var $29 = $pn + 4 | 0;
    var $30 = __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($17, $dtors, $28, $29, $dst);
    var $_0 = $30;
    __label__ = 12;
    break;
   case 6:
    var $32 = $dtors | 0;
    var $34 = HEAP32[$pn + 40 >> 2];
    var $35 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($32, $34);
    if ($35) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $next_0_in = $6 | 0;
    __label__ = 8;
    break;
   case 8:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $41 = __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $kind, $child1);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 10:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($32, $child1);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 8;
    break;
   case 11:
    var $45 = $this + 8 | 0;
    var $46 = HEAP32[$kind >> 2];
    var $47 = $pn + 4 | 0;
    var $48 = __ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE($45, $dtors, $46, $47, $dst);
    var $_0 = $48;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($dtors);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[$this >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$3 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __Z21js_ReportOverRecursedP9JSContext($3);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 3:
    var $9 = __ZNK11JSParseNode7getKindEv($pn);
    if (($9 | 0) == 26) {
      __label__ = 4;
      break;
    } else if (($9 | 0) == 24) {
      __label__ = 5;
      break;
    } else if (($9 | 0) == 29) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = __ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst);
    var $_0 = $11;
    __label__ = 10;
    break;
   case 5:
    var $13 = __ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst);
    var $_0 = $13;
    __label__ = 10;
    break;
   case 6:
    if (($pkind | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$pn + 44 >> 2] & 2 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$pkind >> 2] = 1;
    __label__ = 9;
    break;
   case 9:
    var $24 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $24;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $left = __stackBase__;
    var $right = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZNK11JSParseNode6isUsedEv($pn);
    if ($5) {
      var $pnright_0 = 0;
      var $pnleft_0 = $pn;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $pnright_0 = HEAP32[$pn + 36 >> 2];
    var $pnleft_0 = $pn;
    __label__ = 5;
    break;
   case 4:
    var $pnright_0 = HEAP32[$pn + 36 >> 2];
    var $pnleft_0 = HEAP32[$pn + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $pnleft_0;
    var $pnright_0;
    var $17 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pnleft_0, $pkind, $left);
    if ($17) {
      __label__ = 6;
      break;
    } else {
      var $31 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $19 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $pnright_0, $right);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      var $31 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $this + 8 | 0;
    var $22 = $left | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $1 | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $25 = $right | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $2 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = $pn + 4 | 0;
    var $29 = __ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_($21, $1, $2, $28, $dst);
    var $31 = $29;
    __label__ = 8;
    break;
   case 8:
    var $31;
    STACKTOP = __stackBase__;
    return $31;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE($this, $pn, $dtors) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $kind = __stackBase__;
    var $child = __stackBase__ + 4;
    var $1 = $dtors | 0;
    var $3 = HEAP32[$pn + 40 >> 2];
    var $4 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($1, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    HEAP32[$kind >> 2] = 3;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $kind, $child);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($1, $child);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stmts = __stackBase__;
    var $expr = __stackBase__ + 92;
    var $1 = __stackBase__ + 100;
    var $3 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($stmts, $3);
    var $5 = HEAP32[$pn + 32 >> 2];
    var $6 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $5, $expr);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $20 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $10 = HEAP32[$pn + 36 >> 2];
    var $11 = __ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE($this, $10, $stmts);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $20 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = $this + 8 | 0;
    var $14 = $expr | 0;
    var $15$0 = HEAP32[$14 >> 2];
    var $15$1 = HEAP32[$14 + 4 >> 2];
    var $16 = $1 | 0;
    HEAP32[$16 >> 2] = $15$0;
    HEAP32[$16 + 4 >> 2] = $15$1;
    var $17 = $pn + 4 | 0;
    var $18 = __ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_($13, $1, $stmts, $17, $dst);
    var $20 = $18;
    __label__ = 4;
    break;
   case 4:
    var $20;
    __ZN2js15AutoValueVectorD1Ev($stmts);
    STACKTOP = __stackBase__;
    return $20;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 116;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $disc = __stackBase__;
    var $cases = __stackBase__ + 8;
    var $child = __stackBase__ + 100;
    var $1 = __stackBase__ + 108;
    var $3 = HEAP32[$pn + 32 >> 2];
    var $4 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $3, $disc);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $7 = HEAP32[$pn + 36 >> 2];
    var $8 = $7;
    var $9 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($8, 80);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $lexical_0 = 0;
      var $listNode_0 = $8;
      __label__ = 4;
      break;
    }
   case 3:
    var $lexical_0 = 1;
    var $listNode_0 = HEAP32[$7 + 36 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $listNode_0;
    var $lexical_0;
    var $15 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($cases, $15);
    var $16 = $cases | 0;
    var $18 = HEAP32[$listNode_0 + 40 >> 2];
    var $19 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($16, $18);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $next_0_in = $listNode_0 + 32 | 0;
    __label__ = 6;
    break;
   case 6:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JSL14UndefinedValueEv3403($child);
    var $25 = __ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE($this, $next_0, $child);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($16, $child);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 6;
    break;
   case 9:
    var $29 = $this + 8 | 0;
    var $30 = $disc | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $1 | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $33 = $pn + 4 | 0;
    var $34 = __ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_($29, $1, $cases, $lexical_0, $33, $dst);
    var $_0 = $34;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($cases);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2JSL14UndefinedValueEv3403($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $var = __stackBase__;
    var $guard = __stackBase__ + 8;
    var $body = __stackBase__ + 16;
    var $1 = __stackBase__ + 24;
    var $2 = __stackBase__ + 32;
    var $3 = __stackBase__ + 40;
    var $5 = HEAP32[$pn + 32 >> 2];
    var $6 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $5, 0, $var);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      var $31 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = HEAP32[$pn + 36 >> 2];
    var $11 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $10, $guard);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $31 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $15 = HEAP32[$pn + 40 >> 2];
    var $16 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $15, $body);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      var $31 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = $this + 8 | 0;
    var $19 = $var | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $1 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $22 = $guard | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $2 | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $25 = $body | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = $3 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $28 = $pn + 4 | 0;
    var $29 = __ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_($18, $1, $2, $3, $28, $dst);
    var $31 = $29;
    __label__ = 5;
    break;
   case 5:
    var $31;
    STACKTOP = __stackBase__;
    return $31;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $body = __stackBase__;
    var $clauses = __stackBase__ + 8;
    var $clause = __stackBase__ + 100;
    var $finally = __stackBase__ + 108;
    var $1 = __stackBase__ + 116;
    var $2 = __stackBase__ + 124;
    var $4 = HEAP32[$pn + 32 >> 2];
    var $5 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $4, $body);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $8 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($clauses, $8);
    var $9 = $pn + 36 | 0;
    var $10 = HEAP32[$9 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $clauses | 0;
    var $16 = HEAP32[$10 + 40 >> 2];
    var $17 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($13, $16);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $next_0_in = HEAP32[$9 >> 2] + 32 | 0;
    __label__ = 5;
    break;
   case 5:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $26 = HEAP32[$next_0 + 36 >> 2];
    var $27 = __ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE($this, $26, $clause);
    if ($27) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($13, $clause);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 5;
    break;
   case 8:
    var $32 = HEAP32[$pn + 40 >> 2];
    var $33 = __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $32, $finally);
    if ($33) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $35 = $this + 8 | 0;
    var $36 = $body | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $1 | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    var $39 = $finally | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $41 = $2 | 0;
    HEAP32[$41 >> 2] = $40$0;
    HEAP32[$41 + 4 >> 2] = $40$1;
    var $42 = $pn + 4 | 0;
    var $43 = __ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($35, $1, $clauses, $2, $42, $dst);
    var $_0 = $43;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($clauses);
    var $_1 = $_0;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pn | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $4 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 46);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $6 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 0, $dst);
    var $_0 = $6;
    __label__ = 8;
    break;
   case 5:
    var $8 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 81);
    if ($8) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $10 = __ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE($this, $pn, 1, $dst);
    var $_0 = $10;
    __label__ = 8;
    break;
   case 7:
    var $12 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $12;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, $pos, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atom | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setMagicE10JSWhyMagic($dst, 8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, $pos, $dst);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $atom, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js13ASTSerializer12atomContentsEP6JSAtom($1, $this, $atom);
  var $3 = __ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_($2, $1, $pos, $dst);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $left = __stackBase__;
    var $right = __stackBase__ + 8;
    var $subpos = __stackBase__ + 16;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = __stackBase__ + 48;
    var $4 = __stackBase__ + 56;
    var $5 = __ZNK11JSParseNode7getKindEv($pn);
    var $6 = ($5 | 0) == 7;
    var $7 = ($5 - 7 | 0) >>> 0 < 2;
    var $9 = HEAPU32[$pn + 32 >> 2];
    var $10 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $9, $left);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $12 = $pn + 4 | 0;
    var $13 = $subpos;
    var $15 = $subpos + 8 | 0;
    var $16 = $this + 8 | 0;
    var $17 = $left | 0;
    var $18 = $1 | 0;
    var $19 = $right | 0;
    var $20 = $2 | 0;
    var $21 = $3 | 0;
    var $22 = $4 | 0;
    var $_pn = $9;
    __label__ = 3;
    break;
   case 3:
    var $_pn;
    var $next_0 = HEAP32[$_pn + 24 >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $25 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $next_0, $right);
    if ($25) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 5:
    var $st$0$0 = $12 | 0;
    var $27$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $12 + 4 | 0;
    var $27$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $13 | 0;
    HEAP32[$st$4$0 >> 2] = $27$0;
    var $st$4$1 = $13 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $27$1;
    var $29 = $next_0 + 12 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    HEAP32[$15 >> 2] = $30$0;
    HEAP32[$15 + 4 >> 2] = $30$1;
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $st$0$0 = $17 | 0;
    var $32$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $32$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $18 | 0;
    HEAP32[$st$4$0 >> 2] = $32$0;
    var $st$4$1 = $18 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $32$1;
    var $st$8$0 = $19 | 0;
    var $33$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $19 + 4 | 0;
    var $33$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $20 | 0;
    HEAP32[$st$12$0 >> 2] = $33$0;
    var $st$12$1 = $20 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $33$1;
    var $34 = __ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_($16, $6, $1, $2, $subpos, $left);
    if ($34) {
      var $_pn = $next_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $36 = __ZNK11JSParseNode7getKindEv($pn);
    var $37 = __ZNK11JSParseNode5getOpEv($pn);
    var $38 = __ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp(undef, $36, $37);
    if ($38 >>> 0 < 22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $42 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($42, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    var $st$0$0 = $17 | 0;
    var $44$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $44$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $21 | 0;
    HEAP32[$st$4$0 >> 2] = $44$0;
    var $st$4$1 = $21 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $44$1;
    var $st$8$0 = $19 | 0;
    var $45$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $19 + 4 | 0;
    var $45$1 = HEAP32[$st$8$1 >> 2];
    var $st$12$0 = $22 | 0;
    HEAP32[$st$12$0 >> 2] = $45$0;
    var $st$12$1 = $22 + 4 | 0;
    HEAP32[$st$12$1 >> 2] = $45$1;
    var $46 = __ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_($16, $38, $3, $4, $subpos, $left);
    if ($46) {
      var $_pn = $next_0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $st$0$0 = $17 | 0;
    var $48$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $17 + 4 | 0;
    var $48$1 = HEAP32[$st$0$1 >> 2];
    var $49 = $dst | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $patt = __stackBase__;
    var $src = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 3:
    var $9 = HEAP32[$pn + 32 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($9, 45);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($15, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 6:
    var $21 = (HEAP32[$pn + 44 >> 2] & 2 | 0) != 0;
    var $24 = HEAP32[$9 + 36 >> 2];
    var $25 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $24, 0, $patt);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $29 = HEAP32[$9 + 40 >> 2];
    var $30 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $29, $src);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $32 = $this + 8 | 0;
    var $33 = $patt | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $1 | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $36 = $src | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    var $38 = $2 | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    var $39 = $9 + 4 | 0;
    var $40 = __ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_($32, $1, $2, $21, $39, $dst);
    var $_0 = $40;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 224;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blocks = __stackBase__;
    var $block = __stackBase__ + 92;
    var $filter = __stackBase__ + 100;
    var $empty = __stackBase__ + 108;
    var $body = __stackBase__ + 200;
    var $1 = __stackBase__ + 208;
    var $2 = __stackBase__ + 216;
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 42);
    var $4 = $this | 0;
    var $5 = HEAP32[$4 >> 2];
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($5, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 19;
    break;
   case 3:
    __ZN2js15AutoValueVectorC1EP9JSContext($blocks, $5);
    var $8 = $blocks | 0;
    var $next_0 = $pn;
    __label__ = 4;
    break;
   case 4:
    var $next_0;
    var $10 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 42);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $next_0, $block);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 6:
    var $14 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($8, $block);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 7:
    var $next_0 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 4;
    break;
   case 8:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($filter);
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 35);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $23 = HEAP32[$next_0 + 32 >> 2];
    var $24 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $23, $filter);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $next_1 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 14;
    break;
   case 11:
    var $30 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 25);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$next_0 + 40 >> 2] | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 14;
      break;
    }
   case 13:
    var $36 = HEAP32[$4 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($empty, $36);
    var $37 = $this + 8 | 0;
    var $38 = $pn + 4 | 0;
    var $39 = __ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($37, $empty, $38, $dst);
    __ZN2js15AutoValueVectorD1Ev($empty);
    var $_0 = $39;
    __label__ = 18;
    break;
   case 14:
    var $next_1;
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_1, 79);
    if ($41) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $43 = HEAP32[$4 >> 2];
    _JS_ReportErrorNumber($43, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $46 = HEAP32[$next_1 + 32 >> 2];
    var $47 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $46, $body);
    if ($47) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $49 = $this + 8 | 0;
    var $50 = $body | 0;
    var $51$0 = HEAP32[$50 >> 2];
    var $51$1 = HEAP32[$50 + 4 >> 2];
    var $52 = $1 | 0;
    HEAP32[$52 >> 2] = $51$0;
    HEAP32[$52 + 4 >> 2] = $51$1;
    var $53 = $filter | 0;
    var $54$0 = HEAP32[$53 >> 2];
    var $54$1 = HEAP32[$53 + 4 >> 2];
    var $55 = $2 | 0;
    HEAP32[$55 >> 2] = $54$0;
    HEAP32[$55 + 4 >> 2] = $54$1;
    var $56 = $pn + 4 | 0;
    var $57 = __ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($49, $1, $blocks, $2, $56, $dst);
    var $_0 = $57;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($blocks);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2JSL10MagicValueE10JSWhyMagic3404($agg_result) {
  __ZN2JS5Value8setMagicE10JSWhyMagic($agg_result, 8);
  return;
}

function __ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $blocks = __stackBase__;
    var $block = __stackBase__ + 92;
    var $filter = __stackBase__ + 100;
    var $body = __stackBase__ + 108;
    var $1 = __stackBase__ + 116;
    var $2 = __stackBase__ + 124;
    var $3 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 42);
    var $4 = $this | 0;
    var $5 = HEAP32[$4 >> 2];
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($5, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 18;
    break;
   case 3:
    __ZN2js15AutoValueVectorC1EP9JSContext($blocks, $5);
    var $8 = $blocks | 0;
    var $next_0 = $pn;
    __label__ = 4;
    break;
   case 4:
    var $next_0;
    var $10 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 42);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $12 = __ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE($this, $next_0, $block);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 6:
    var $14 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($8, $block);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 7:
    var $next_0 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 4;
    break;
   case 8:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($filter);
    var $20 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 35);
    if ($20) {
      __label__ = 9;
      break;
    } else {
      var $next_1 = $next_0;
      __label__ = 11;
      break;
    }
   case 9:
    var $23 = HEAP32[$next_0 + 32 >> 2];
    var $24 = __ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE($this, $23, $filter);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 10:
    var $next_1 = HEAP32[$next_0 + 36 >> 2];
    __label__ = 11;
    break;
   case 11:
    var $next_1;
    var $30 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_1, 2);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $33 = HEAP32[$next_1 + 32 >> 2];
    var $34 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($33, 77);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $37 = HEAP32[$33 + 32 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $40 = HEAP32[$4 >> 2];
    _JS_ReportErrorNumber($40, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 17;
    break;
   case 15:
    var $42 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $37, $body);
    if ($42) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $44 = $this + 8 | 0;
    var $45 = $body | 0;
    var $46$0 = HEAP32[$45 >> 2];
    var $46$1 = HEAP32[$45 + 4 >> 2];
    var $47 = $1 | 0;
    HEAP32[$47 >> 2] = $46$0;
    HEAP32[$47 + 4 >> 2] = $46$1;
    var $48 = $filter | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50 = $2 | 0;
    HEAP32[$50 >> 2] = $49$0;
    HEAP32[$50 + 4 >> 2] = $49$1;
    var $51 = $pn + 4 | 0;
    var $52 = __ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_($44, $1, $blocks, $2, $51, $dst);
    var $_0 = $52;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($blocks);
    var $_1 = $_0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZNK11JSParseNode15isGeneratorExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7getKindEv($this);
    if (($1 | 0) == 27) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = HEAP32[$this + 32 >> 2];
    var $6 = __ZNK11JSParseNode7getKindEv($5);
    if (($6 | 0) == 34) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$5 + 36 >> 2];
    var $11 = $10;
    var $12 = __ZNK11JSParseNode7getKindEv($11);
    if (($12 | 0) == 85) {
      __label__ = 4;
      break;
    } else {
      var $18 = $11;
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$10 + 36 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = __ZNK11JSParseNode7getKindEv($18);
    if (($19 | 0) == 80) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js2gcL15GetGCObjectKindEjb3408($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK11JSParseNode13generatorExprEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$this + 32 >> 2] + 36 >> 2];
    var $5 = $4;
    var $6 = __ZNK11JSParseNode7getKindEv($5);
    if (($6 | 0) == 85) {
      __label__ = 2;
      break;
    } else {
      var $12 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[$4 + 36 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    return HEAP32[$12 + 36 >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $val = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __ZNK11JSParseNode5getOpEv($pn);
    if (($3 | 0) == 125) {
      __label__ = 2;
      break;
    } else if (($3 | 0) == 126) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 93) {
      var $kind_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $kind_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $kind_0 = 2;
    __label__ = 5;
    break;
   case 4:
    var $8 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($8, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 8;
    break;
   case 5:
    var $kind_0;
    var $11 = HEAP32[$pn + 32 >> 2];
    var $12 = __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $11, $key);
    if ($12) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $16 = HEAP32[$pn + 36 >> 2];
    var $17 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $16, $val);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $19 = $this + 8 | 0;
    var $20 = $key | 0;
    var $21$0 = HEAP32[$20 >> 2];
    var $21$1 = HEAP32[$20 + 4 >> 2];
    var $22 = $1 | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $23 = $val | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $2 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $26 = $pn + 4 | 0;
    var $27 = __ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_($19, $1, $2, $kind_0, $26, $dst);
    var $_0 = $27;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 6);
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pn, 0);
    if ($3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($6, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = HEAP32[$pn + 32 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($14, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $16 = $pn + 4 | 0;
    var $17 = __ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE($this, $10, $16, $dst);
    var $_0 = $17;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $val = __stackBase__;
    var $proto = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __ZNK11JSParseNode7getKindEv($pn);
    if (($2 | 0) == 31) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 32) {
      __label__ = 3;
      break;
    } else if (($2 | 0) == 30) {
      __label__ = 10;
      break;
    } else if (($2 | 0) == 33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 2:
    var $7 = HEAP32[$pn + 32 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($val, $7);
    __label__ = 15;
    break;
   case 3:
    var $11 = HEAP32[$pn + 32 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$11 + 8 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK8JSObject8isRegExpEv($15);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($20, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 7:
    var $22 = $this | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZNK9JSContext2fpEv($23);
    var $25 = __ZNK2js10StackFrame10scopeChainEv($24);
    var $26 = $23;
    var $27 = $25;
    var $28 = $proto;
    var $29 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($26, $27, 10, $28, 0);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = HEAP32[$22 >> 2];
    var $35 = $15;
    var $36 = HEAP32[$proto >> 2];
    var $37 = __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($34, $35, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = $37;
    __ZN2JS5Value9setObjectER8JSObject($val, $40);
    __label__ = 15;
    break;
   case 10:
    var $43 = $pn + 32 | 0;
    var $44 = (tempDoubleI32[0] = HEAP32[$43 >> 2], tempDoubleI32[1] = HEAP32[$43 + 4 >> 2], tempDoubleF64[0]);
    var $45 = __ZN2JS5Value9setNumberEd($val, $44);
    __label__ = 15;
    break;
   case 11:
    var $47 = __ZNK11JSParseNode4isOpE4JSOp($pn, 64);
    if ($47) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN2JS5Value7setNullEv($val);
    __label__ = 15;
    break;
   case 13:
    var $50 = __ZNK11JSParseNode4isOpE4JSOp($pn, 67);
    __ZN2JS5Value10setBooleanEb($val, $50);
    __label__ = 15;
    break;
   case 14:
    var $53 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($53, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 15:
    var $55 = $this + 8 | 0;
    var $56 = $val | 0;
    var $57$0 = HEAP32[$56 >> 2];
    var $57$1 = HEAP32[$56 + 4 >> 2];
    var $58 = $1 | 0;
    HEAP32[$58 >> 2] = $57$0;
    HEAP32[$58 + 4 >> 2] = $57$1;
    var $59 = $pn + 4 | 0;
    var $60 = __ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_($55, $1, $59, $dst);
    var $_0 = $60;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12atomContentsEP6JSAtom($agg_result, $this, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atom | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $atom;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    __ZN2JSL11StringValueEP8JSString3435($agg_result, $11 | 0);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $pn, $dst) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 29);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $3;
    __label__ = 7;
    break;
   case 3:
    var $5 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 31);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $7 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 30);
    if ($7) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($10, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $12 = __ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE($this, $pn, $dst);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 108;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $1 = __stackBase__ + 92;
    var $patt = __stackBase__ + 100;
    var $3 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $3);
    var $4 = $elts | 0;
    var $6 = HEAP32[$pn + 40 >> 2];
    var $7 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($4, $6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($next_0, 3);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JSL10MagicValueE10JSWhyMagic3404($1);
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($4, $1);
    __label__ = 8;
    break;
   case 6:
    var $16 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $next_0, $pkind, $patt);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($4, $patt);
    __label__ = 8;
    break;
   case 8:
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 9:
    var $21 = $this + 8 | 0;
    var $22 = $pn + 4 | 0;
    var $23 = __ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($21, $elts, $22, $dst);
    var $_0 = $23;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $pn, $pkind, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 132;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $key = __stackBase__ + 92;
    var $patt = __stackBase__ + 100;
    var $prop = __stackBase__ + 108;
    var $1 = __stackBase__ + 116;
    var $2 = __stackBase__ + 124;
    var $3 = $this | 0;
    var $4 = HEAP32[$3 >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $4);
    var $5 = $elts | 0;
    var $7 = HEAP32[$pn + 40 >> 2];
    var $8 = __ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj($5, $7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $11 = $this + 8 | 0;
    var $12 = $key | 0;
    var $13 = $1 | 0;
    var $14 = $patt | 0;
    var $15 = $2 | 0;
    var $next_0_in = $pn + 32 | 0;
    __label__ = 3;
    break;
   case 3:
    var $next_0_in;
    var $next_0 = HEAP32[$next_0_in >> 2];
    if (($next_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = __ZNK11JSParseNode4isOpE4JSOp($next_0, 93);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = HEAP32[$3 >> 2];
    _JS_ReportErrorNumber($21, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $24 = HEAP32[$next_0 + 32 >> 2];
    var $25 = __ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE($this, $24, $key);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $29 = HEAP32[$next_0 + 36 >> 2];
    var $30 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $29, $pkind, $patt);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $32$0 = HEAP32[$12 >> 2];
    var $32$1 = HEAP32[$12 + 4 >> 2];
    HEAP32[$13 >> 2] = $32$0;
    HEAP32[$13 + 4 >> 2] = $32$1;
    var $33$0 = HEAP32[$14 >> 2];
    var $33$1 = HEAP32[$14 + 4 >> 2];
    HEAP32[$15 >> 2] = $33$0;
    HEAP32[$15 + 4 >> 2] = $33$1;
    var $34 = $next_0 + 4 | 0;
    var $35 = __ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_($11, $1, $2, $34, $prop);
    if ($35) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    __ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_($5, $prop);
    var $next_0_in = $next_0 + 24 | 0;
    __label__ = 3;
    break;
   case 10:
    var $39 = $pn + 4 | 0;
    var $40 = __ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($11, $elts, $39, $dst);
    var $_0 = $40;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE($this, $pn, $args, $body) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 84);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $pnbody_0 = $pn;
      var $pnargs_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK11JSParseNode4lastEv($pn);
    var $pnbody_0 = $3;
    var $pnargs_0 = $pn;
    __label__ = 3;
    break;
   case 3:
    var $pnargs_0;
    var $pnbody_0;
    var $5 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($pnbody_0, 5);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $pndestruct_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    if ((HEAP32[$pnbody_0 + 44 >> 2] & 512 | 0) == 0) {
      var $pndestruct_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP32[$pnbody_0 + 32 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($14, 2);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($20, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 8:
    var $23 = HEAP32[$14 + 32 >> 2];
    if (($23 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($23, 46);
    if ($26) {
      var $pndestruct_0 = $23;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $29 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($29, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $pndestruct_0;
    var $31 = __ZNK11JSParseNode7getKindEv($pnbody_0);
    if (($31 | 0) == 48) {
      __label__ = 12;
      break;
    } else if (($31 | 0) == 82) {
      __label__ = 14;
      break;
    } else if (($31 | 0) == 25) {
      __label__ = 19;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 12:
    var $33 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, undef, $pnargs_0, 0, $pnbody_0, $args);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 13:
    var $36 = HEAP32[$pnbody_0 + 32 >> 2];
    var $37 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $36, $body);
    var $_0 = $37;
    __label__ = 24;
    break;
   case 14:
    var $42 = HEAP32[HEAP32[$pnbody_0 + 32 >> 2] + 24 >> 2];
    if (($42 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($42, 48);
    if ($45) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($48, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 17:
    var $50 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, undef, $pnargs_0, $pndestruct_0, $pnbody_0, $args);
    if ($50) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 18:
    var $53 = HEAP32[$42 + 32 >> 2];
    var $54 = __ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE($this, $53, $body);
    var $_0 = $54;
    __label__ = 24;
    break;
   case 19:
    var $62 = HEAP32[$pnbody_0 + 32 >> 2];
    if ((HEAP32[$pnbody_0 + 44 >> 2] & 512 | 0) == 0) {
      var $67 = $62;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $67 = HEAP32[$62 + 24 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $67;
    var $68 = __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, undef, $pnargs_0, $pndestruct_0, $pnbody_0, $args);
    if ($68) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 22:
    var $71 = __ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE($this, $67, $pnbody_0 + 4 | 0, $body);
    var $_0 = $71;
    __label__ = 24;
    break;
   case 23:
    var $74 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($74, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE["X"] = 1;

function __ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE($this, $pn, $pnargs, $pndestruct, $pnbody, $args) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $node = __stackBase__;
    if (($pnargs | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$pnargs + 32 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $6;
    if (($pndestruct | 0) == 0) {
      var $destruct_0_ph = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $destruct_0_ph = HEAP32[$pndestruct + 32 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $destruct_0_ph;
    var $11 = $args | 0;
    var $destruct_0 = $destruct_0_ph;
    var $arg_0 = $6;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $arg_0;
    var $destruct_0;
    var $or_cond = ($arg_0 | 0) == 0 | ($arg_0 | 0) == ($pnbody | 0);
    var $14 = ($destruct_0 | 0) == 0;
    if ($or_cond & $14) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($14) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = HEAP32[$destruct_0 + 36 >> 2];
    var $19 = __ZNK11JSParseNode9frameSlotEv($18);
    if (($19 | 0) == ($i_0 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $23 = HEAP32[$destruct_0 + 32 >> 2];
    var $24 = __ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE($this, $23, 0, $node);
    if ($24) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $26 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($11, $node);
    if ($26) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $destruct_1 = HEAP32[$destruct_0 + 24 >> 2];
    var $arg_1 = $arg_0;
    __label__ = 17;
    break;
   case 12:
    if ($or_cond) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $32 = __ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE($this, $arg_0, $node);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 14:
    var $34 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($11, $node);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 15:
    var $destruct_1 = $destruct_0;
    var $arg_1 = HEAP32[$arg_0 + 24 >> 2];
    __label__ = 17;
    break;
   case 16:
    var $40 = HEAP32[$this >> 2];
    _JS_ReportErrorNumber($40, 2, 0, 254, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 17:
    var $arg_1;
    var $destruct_1;
    var $destruct_0 = $destruct_1;
    var $arg_0 = $arg_1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE["X"] = 1;

function __ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE($this, $pn, $pos, $dst) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 100;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $elts = __stackBase__;
    var $child = __stackBase__ + 92;
    var $2 = HEAP32[$this >> 2];
    __ZN2js15AutoValueVectorC1EP9JSContext($elts, $2);
    var $3 = $elts | 0;
    var $next_0 = $pn;
    __label__ = 2;
    break;
   case 2:
    var $next_0;
    if (($next_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE($this, $next_0, $child);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $9 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($3, $child);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $next_0 = HEAP32[$next_0 + 24 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $14 = $this + 8 | 0;
    var $15 = __ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE($14, $elts, $pos, $dst);
    var $_0 = $15;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($elts);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13reflect_parseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1660;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filenamep = __stackBase__;
    var $lineno = __stackBase__ + 8;
    var $arg = __stackBase__ + 12;
    var $prop = __stackBase__ + 20;
    var $1 = __stackBase__ + 28;
    var $2 = __stackBase__ + 36;
    var $3 = __stackBase__ + 44;
    var $4 = __stackBase__ + 52;
    var $serialize = __stackBase__ + 60;
    var $parser = __stackBase__ + 660;
    var $val = __stackBase__ + 1652;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str2403393 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_2 = 0;
    __label__ = 34;
    break;
   case 3:
    var $8 = $vp + 16 | 0;
    var $9 = $cx;
    var $10 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($9, $8);
    if (($10 | 0) == 0) {
      var $_2 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv($filenamep, $cx, 0);
    HEAP32[$lineno >> 2] = 1;
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = $vp + 24 | 0;
    var $st$1$0 = $15 | 0;
    var $16$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$1$1 >> 2];
    var $17 = $arg | 0;
    var $st$6$0 = $17 | 0;
    HEAP32[$st$6$0 >> 2] = $16$0;
    var $st$6$1 = $17 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $16$1;
    __label__ = 7;
    break;
   case 6:
    __ZN2JSL14UndefinedValueEv3403($arg);
    __label__ = 7;
    break;
   case 7:
    var $20 = __ZNK2JS5Value17isNullOrUndefinedEv($arg);
    if ($20) {
      var $builder_0 = 0;
      var $loc_0 = 1;
      var $filename_2 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZNK2JS5Value8isObjectEv($arg);
    if ($22) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $24 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 222, 1, $arg, 0, STRING_TABLE.__str2433396 | 0, 0);
    var $_1 = 0;
    __label__ = 33;
    break;
   case 10:
    var $26 = __ZNK2JS5Value8toObjectEv($arg);
    var $27 = $cx + 52 | 0;
    var $31 = HEAP32[HEAP32[$27 >> 2] + 210368 >> 2] | 0;
    var $32 = __ZL12ATOM_TO_JSIDP6JSAtom3421($31);
    __ZN2JSL12BooleanValueEb3401($1, 1);
    var $33 = $cx;
    var $34 = $26;
    var $35 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($33, $34, $32, $1, $prop);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __Z17js_ValueToBooleanRKN2JS5ValueE($prop);
    var $39 = ($38 | 0) != 0;
    var $40 = $39 & 1;
    if ($39) {
      __label__ = 12;
      break;
    } else {
      var $filename_1 = 0;
      __label__ = 20;
      break;
    }
   case 12:
    var $45 = HEAP32[HEAP32[$27 >> 2] + 210300 >> 2] | 0;
    var $46 = __ZL12ATOM_TO_JSIDP6JSAtom3421($45);
    __ZN2JSL9NullValueEv3400($2);
    var $47 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($33, $34, $46, $2, $prop);
    if (($47 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = __ZNK2JS5Value17isNullOrUndefinedEv($prop);
    if ($50) {
      var $filename_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($9, $prop);
    if (($52 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZNK8JSString6lengthEv($52);
    var $56 = __ZN8JSString8getCharsEP9JSContext($52, $cx);
    if (($56 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $59 = __ZN2js13DeflateStringEP9JSContextPKtj($9, $56, $55);
    if (($59 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js22AutoReleaseNullablePtr5resetEPv($filenamep, $59);
    var $filename_0 = $59;
    __label__ = 18;
    break;
   case 18:
    var $filename_0;
    var $66 = HEAP32[HEAP32[$27 >> 2] + 210372 >> 2] | 0;
    var $67 = __ZL12ATOM_TO_JSIDP6JSAtom3421($66);
    __ZN2JSL10Int32ValueEi3422($3);
    var $68 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($33, $34, $67, $3, $prop);
    if (($68 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $71 = __ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj($cx, $prop, $lineno);
    if ($71) {
      var $filename_1 = $filename_0;
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 20:
    var $filename_1;
    var $76 = HEAP32[HEAP32[$27 >> 2] + 210384 >> 2] | 0;
    var $77 = __ZL12ATOM_TO_JSIDP6JSAtom3421($76);
    __ZN2JSL9NullValueEv3400($4);
    var $78 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($33, $34, $77, $4, $prop);
    if (($78 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $81 = __ZNK2JS5Value17isNullOrUndefinedEv($prop);
    if ($81) {
      var $builder_0 = 0;
      var $loc_0 = $40;
      var $filename_2 = $filename_1;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $83 = __ZNK2JS5Value8isObjectEv($prop);
    if ($83) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $85 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($cx, 0, 222, 1, $prop, 0, STRING_TABLE.__str2433396 | 0, 0);
    var $_1 = 0;
    __label__ = 33;
    break;
   case 24:
    var $87 = __ZNK2JS5Value8toObjectEv($prop);
    var $builder_0 = $87;
    var $loc_0 = $40;
    var $filename_2 = $filename_1;
    __label__ = 25;
    break;
   case 25:
    var $filename_2;
    var $loc_0;
    var $builder_0;
    var $89 = HEAP32[$lineno >> 2];
    __ZN2js13ASTSerializerC1EP9JSContextbPKcj($serialize, $cx, $loc_0 << 24 >> 24 != 0, $filename_2, $89);
    var $90 = __ZN2js13ASTSerializer4initEP8JSObject($serialize, $builder_0);
    if ($90) {
      __label__ = 26;
      break;
    } else {
      var $_1 = 0;
      __label__ = 33;
      break;
    }
   case 26:
    var $92 = __ZNK8JSString6lengthEv($10);
    var $93 = __ZN8JSString8getCharsEP9JSContext($10, $cx);
    if (($93 | 0) == 0) {
      var $_1 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($parser, $cx, 0, 0, 0);
    var $96 = __ZNK9JSContext11findVersionEv($cx);
    var $97 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($parser, $93, $92, $filename_2, $89, $96);
    if ($97) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 28:
    var $99 = __ZN2js6Parser5parseEP8JSObject($parser, 0);
    if (($99 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $102 = __ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE($serialize, $99, $val);
    if ($102) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $104$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $104$1 = HEAP32[$st$1$1 >> 2];
    var $105 = $vp | 0;
    var $st$6$0 = $105 | 0;
    HEAP32[$st$6$0 >> 2] = $104$0;
    var $st$6$1 = $105 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $104$1;
    var $_0 = 0;
    __label__ = 32;
    break;
   case 31:
    var $107 = $val | 0;
    var $st$1$0 = $107 | 0;
    var $108$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $107 + 4 | 0;
    var $108$1 = HEAP32[$st$1$1 >> 2];
    var $109 = $vp | 0;
    var $st$6$0 = $109 | 0;
    HEAP32[$st$6$0 >> 2] = $108$0;
    var $st$6$1 = $109 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $108$1;
    var $_0 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    __ZN2js6ParserD2Ev($parser);
    var $_1 = $_0;
    __label__ = 33;
    break;
   case 33:
    var $_1;
    __ZN2js22AutoReleaseNullablePtrD1Ev($filenamep);
    var $_2 = $_1;
    __label__ = 34;
    break;
   case 34:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13reflect_parseP9JSContextjPN2JS5ValueE["X"] = 1;

function _JS_InitReflect($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397($cx, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $cx;
    var $7 = __ZN8JSObject16setSingletonTypeEP9JSContext($5, $6);
    _OBJECT_TO_JSVAL3405($1, $2);
    var $8 = _JS_DefineProperty($cx, $obj, STRING_TABLE.__str2393392 | 0, $1, 10, 12, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_DefineFunctions($cx, $2, __ZL14static_methods3391 | 0);
    var $_ = ($11 | 0) == 0 ? 0 : $2;
    var $_0 = $_;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _OBJECT_TO_JSVAL3405($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL3420($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout3419($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      var $9 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($4, $cx, 0, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $9 = $7;
      __label__ = 4;
      break;
    }
   case 4:
    var $9;
    var $10 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $17 = $parent_mux;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZNK8JSObject9getParentEv($4);
    var $17 = $15;
    __label__ = 7;
    break;
   case 7:
    var $17;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($10, undef, __ZN2js11ObjectClassE, $9, $17, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $18 = __ZNK2js5Class8isNativeEv(__ZN2js11ObjectClassE);
    if ($18) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $20 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413($cx, $10, $9, $kind);
    if ($20) {
      var $_0 = $10;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 0;
    __label__ = 11;
    break;
   case 10:
    __ZN8JSObject21setSharedNonNativeMapEv($10);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj3426($bits) {
  return $bits;
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3419($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _OBJECT_TO_JSVAL_IMPL3420($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZN2js11NodeBuilderC2EP9JSContextbPKc($this, $c, $l, $s) {
  HEAP32[$this >> 2] = $c;
  HEAP8[$this + 4 | 0] = $l & 1;
  HEAP32[$this + 8 >> 2] = $s;
  return;
}

function __ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv($this, $cx, $ptr) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $ptr;
  return;
}

function __ZN2js6RegExp6increfEP9JSContext($this, $cx) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] + 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js11ObjectClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
    var $4 = __ZNK8JSObject8numSlotsEv($obj);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js11ObjectClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js11ObjectClassE, $kind);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js11ObjectClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv($this, $cx, $ptr) {
  __ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv($this, $cx, $ptr);
  return;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3421($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3426($1);
  return $2;
}

function __ZN2js22AutoReleaseNullablePtr5resetEPv($this, $ptr2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv(undef, $2);
    __label__ = 3;
    break;
   case 3:
    HEAP32[$1 >> 2] = $ptr2;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi3422($agg_result) {
  __ZN2JS5Value8setInt32Ei($agg_result, 1);
  return;
}

function __ZN2js13ASTSerializerC1EP9JSContextbPKcj($this, $c, $l, $src, $ln) {
  __ZN2js13ASTSerializerC2EP9JSContextbPKcj($this, $c, $l, $src, $ln);
  return;
}

function __ZN2js13ASTSerializer4initEP8JSObject($this, $userobj) {
  var $1 = $this + 8 | 0;
  var $2 = __ZN2js11NodeBuilder4initEP8JSObject($1, $userobj);
  return $2;
}

function __ZN2js22AutoReleaseNullablePtrD1Ev($this) {
  __ZN2js22AutoReleaseNullablePtrD2Ev($this);
  return;
}

function __ZN2js22AutoReleaseNullablePtrD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN9JSContext5free_EPv(undef, $2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11NodeBuilder4initEP8JSObject($this, $userobj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funv = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $3 = HEAP32[$this + 8 >> 2];
    var $5 = $this + 16 | 0;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE($this, $3, $5);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 3:
    __ZN2JS5Value7setNullEv($5);
    __label__ = 4;
    break;
   case 4:
    var $11 = $this + 576 | 0;
    if (($userobj | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    __ZN2JS5Value7setNullEv($11);
    var $i_02 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_02;
    var $14 = $this + 24 + ($i_02 << 3) | 0;
    __ZN2JS5Value7setNullEv($14);
    var $15 = $i_02 + 1 | 0;
    if (($15 | 0) == 69) {
      var $_0 = 1;
      __label__ = 18;
      break;
    } else {
      var $i_02 = $15;
      __label__ = 6;
      break;
    }
   case 7:
    __ZN2JS5Value9setObjectER8JSObject($11, $userobj);
    var $17 = $this | 0;
    var $18 = $userobj;
    var $19 = $funv | 0;
    var $i1_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i1_0;
    if ($i1_0 >>> 0 < 69) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 1;
      __label__ = 18;
      break;
    }
   case 9:
    var $24 = HEAPU32[__ZN2js13callbackNamesE + ($i1_0 << 2) >> 2];
    var $25 = HEAP32[$17 >> 2];
    var $26 = _strlen($24);
    var $27 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($25, $24, $26, 0, 0);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = HEAP32[$17 >> 2];
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom3421($27);
    __ZN2JSL9NullValueEv3400($1);
    var $32 = $30;
    var $33 = __ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_($32, $18, $31, $1, $funv);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = __ZNK2JS5Value17isNullOrUndefinedEv($funv);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $38 = $this + 24 + ($i1_0 << 3) | 0;
    __ZN2JS5Value7setNullEv($38);
    __label__ = 17;
    break;
   case 13:
    var $40 = __ZNK2JS5Value8isObjectEv($funv);
    if ($40) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $42 = __ZNK2JS5Value8toObjectEv($funv);
    var $43 = __ZNK8JSObject10isFunctionEv($42);
    if ($43) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $45 = HEAP32[$17 >> 2];
    var $46 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($45, 0, 22, 1, $funv, 0, 0, 0);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 16:
    var $48$0 = HEAP32[$19 >> 2];
    var $48$1 = HEAP32[$19 + 4 >> 2];
    var $49 = $this + 24 + ($i1_0 << 3) | 0;
    HEAP32[$49 >> 2] = $48$0;
    HEAP32[$49 + 4 >> 2] = $48$1;
    __label__ = 17;
    break;
   case 17:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 8;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11NodeBuilder4initEP8JSObject["X"] = 1;

function __ZN2js13ASTSerializerC2EP9JSContextbPKcj($this, $c, $l, $src, $ln) {
  HEAP32[$this >> 2] = $c;
  var $2 = $this + 8 | 0;
  __ZN2js11NodeBuilderC1EP9JSContextbPKc($2, $c, $l, $src);
  HEAP32[$this + 592 >> 2] = $ln;
  return;
}

function __ZN2js11NodeBuilderC1EP9JSContextbPKc($this, $c, $l, $s) {
  __ZN2js11NodeBuilderC2EP9JSContextbPKc($this, $c, $l, $s);
  return;
}

function __ZN2JSL11StringValueEP8JSString3435($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE($this, $obj, $dst) {
  __ZN2JS5Value9setObjectER8JSObject($dst, $obj);
  return 1;
}

function __ZL13resc_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  var $3 = $2;
  __ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_($cx, $3);
  return;
}

function __ZL10resc_traceP8JSTracerP8JSObject($trc, $obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject10getPrivateEv($1);
  var $3 = $2;
  __ZNK2js13RegExpStatics4markEP8JSTracer($3, $trc);
  return;
}

function __Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_($cx, $obj, $proto) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $clone1 = __stackBase__;
    var $1 = $proto;
    var $2 = __ZNK8JSObject9getParentEv($1);
    var $3 = $2;
    var $4 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476($cx, $proto, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = $obj;
    var $9 = $4;
    var $10 = __ZN9JSContext13regExpStaticsEv($7);
    var $11 = __ZN2js6RegExp11extractFromEP8JSObject($8);
    var $12 = __ZNK2js6RegExp8getFlagsEv($11);
    var $13 = HEAP32[$12 >> 2];
    var $14 = __ZNK2js13RegExpStatics8getFlagsEv($10);
    if (($14 & $13 | 0) == ($14 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZNK2js6RegExp9getSourceEv($11);
    var $19 = $18 | 0;
    var $20 = $14 | $13;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($clone1, $7, $19, $20, 0);
    var $21 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($clone1);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($clone1);
    var $re_0 = $24;
    __label__ = 6;
    break;
   case 5:
    __ZN2js6RegExp6increfEP9JSContext($11, undef);
    var $re_0 = $11;
    __label__ = 6;
    break;
   case 6:
    var $re_0;
    var $27 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($9, $7, $re_0);
    var $_ = $27 ? $4 : 0;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476($cx, $proto, $parent) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3527($3);
  var $5 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $proto, $parent, $4);
  return $5;
}

function __Z17js_ObjectIsRegExpP8JSObject($obj) {
  var $1 = $obj;
  var $2 = __ZNK8JSObject8isRegExpEv($1);
  return $2 & 1;
}

function __ZN2js6RegExp15reportPCREErrorEP9JSContexti($this, $cx, $error) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($error | 0) == -2) {
      __label__ = 2;
      break;
    } else if (($error | 0) == 0 || ($error | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($error | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($error | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($error | 0) == 4) {
      __label__ = 6;
      break;
    } else if (($error | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($error | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($error | 0) == 7) {
      __label__ = 9;
      break;
    } else if (($error | 0) == 8) {
      __label__ = 10;
      break;
    } else if (($error | 0) == 9) {
      __label__ = 11;
      break;
    } else if (($error | 0) == 10) {
      __label__ = 12;
      break;
    } else if (($error | 0) == 11) {
      __label__ = 13;
      break;
    } else if (($error | 0) == 12) {
      __label__ = 14;
      break;
    } else if (($error | 0) == 13) {
      __label__ = 15;
      break;
    } else if (($error | 0) == 14) {
      __label__ = 16;
      break;
    } else if (($error | 0) == 15) {
      __label__ = 17;
      break;
    } else if (($error | 0) == 16) {
      __label__ = 18;
      break;
    } else if (($error | 0) == 17) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 2:
    var $2 = $cx;
    var $3 = _JS_ReportErrorFlagsAndNumberUC($2, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 3:
    var $5 = $cx;
    var $6 = _JS_ReportErrorFlagsAndNumberUC($5, 0, 2, 0, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 4:
    var $8 = $cx;
    var $9 = _JS_ReportErrorFlagsAndNumberUC($8, 0, 2, 0, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 5:
    var $11 = $cx;
    var $12 = _JS_ReportErrorFlagsAndNumberUC($11, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 6:
    var $14 = $cx;
    var $15 = _JS_ReportErrorFlagsAndNumberUC($14, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 7:
    var $17 = $cx;
    var $18 = _JS_ReportErrorFlagsAndNumberUC($17, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 8:
    var $20 = $cx;
    var $21 = _JS_ReportErrorFlagsAndNumberUC($20, 0, 2, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 9:
    var $23 = $cx;
    var $24 = _JS_ReportErrorFlagsAndNumberUC($23, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 10:
    var $26 = $cx;
    var $27 = _JS_ReportErrorFlagsAndNumberUC($26, 0, 2, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 11:
    var $29 = $cx;
    var $30 = _JS_ReportErrorFlagsAndNumberUC($29, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 12:
    var $32 = $cx;
    var $33 = _JS_ReportErrorFlagsAndNumberUC($32, 0, 2, 0, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 13:
    var $35 = $cx;
    var $36 = _JS_ReportErrorFlagsAndNumberUC($35, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 14:
    var $38 = $cx;
    var $39 = _JS_ReportErrorFlagsAndNumberUC($38, 0, 2, 0, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 15:
    var $41 = $cx;
    var $42 = _JS_ReportErrorFlagsAndNumberUC($41, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 16:
    var $44 = $cx;
    var $45 = _JS_ReportErrorFlagsAndNumberUC($44, 0, 2, 0, 54, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 17:
    var $47 = $cx;
    var $48 = _JS_ReportErrorFlagsAndNumberUC($47, 0, 2, 0, 149, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 18:
    var $50 = $cx;
    var $51 = _JS_ReportErrorFlagsAndNumberUC($50, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 19:
    var $53 = $cx;
    var $54 = _JS_ReportErrorFlagsAndNumberUC($53, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 20;
    break;
   case 20:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp15reportPCREErrorEP9JSContexti["X"] = 1;

function __ZN2js6RegExp15reportYarrErrorEP9JSContextPNS_11TokenStreamEN3JSC4Yarr9ErrorCodeE($this, $cx, $ts, $error) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($error | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($error | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($error | 0) == 3) {
      __label__ = 8;
      break;
    } else if (($error | 0) == 4) {
      __label__ = 11;
      break;
    } else if (($error | 0) == 5) {
      __label__ = 14;
      break;
    } else if (($error | 0) == 6) {
      __label__ = 17;
      break;
    } else if (($error | 0) == 7) {
      __label__ = 20;
      break;
    } else if (($error | 0) == 8) {
      __label__ = 23;
      break;
    } else if (($error | 0) == 9) {
      __label__ = 26;
      break;
    } else if (($error | 0) == 11) {
      __label__ = 29;
      break;
    } else if (($error | 0) == 10) {
      __label__ = 32;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 2:
    if (($ts | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = $ts;
    var $5 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $4, 0, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 4:
    var $7 = $cx;
    var $8 = _JS_ReportErrorFlagsAndNumberUC($7, 0, 2, 0, 201, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 5:
    if (($ts | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = $ts;
    var $13 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $12, 0, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 7:
    var $15 = $cx;
    var $16 = _JS_ReportErrorFlagsAndNumberUC($15, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 8:
    if (($ts | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $20 = $ts;
    var $21 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $20, 0, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 10:
    var $23 = $cx;
    var $24 = _JS_ReportErrorFlagsAndNumberUC($23, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 11:
    if (($ts | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $28 = $ts;
    var $29 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $28, 0, 0, 54, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 13:
    var $31 = $cx;
    var $32 = _JS_ReportErrorFlagsAndNumberUC($31, 0, 2, 0, 54, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 14:
    if (($ts | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $36 = $ts;
    var $37 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $36, 0, 0, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 16:
    var $39 = $cx;
    var $40 = _JS_ReportErrorFlagsAndNumberUC($39, 0, 2, 0, 62, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 17:
    if (($ts | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $44 = $ts;
    var $45 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $44, 0, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 19:
    var $47 = $cx;
    var $48 = _JS_ReportErrorFlagsAndNumberUC($47, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 20:
    if (($ts | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $52 = $ts;
    var $53 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $52, 0, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 22:
    var $55 = $cx;
    var $56 = _JS_ReportErrorFlagsAndNumberUC($55, 0, 2, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 23:
    if (($ts | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $60 = $ts;
    var $61 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $60, 0, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 25:
    var $63 = $cx;
    var $64 = _JS_ReportErrorFlagsAndNumberUC($63, 0, 2, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 26:
    if (($ts | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $68 = $ts;
    var $69 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $68, 0, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 28:
    var $71 = $cx;
    var $72 = _JS_ReportErrorFlagsAndNumberUC($71, 0, 2, 0, 57, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 29:
    if (($ts | 0) == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $76 = $ts;
    var $77 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $76, 0, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 31:
    var $79 = $cx;
    var $80 = _JS_ReportErrorFlagsAndNumberUC($79, 0, 2, 0, 46, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 32:
    if (($ts | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $84 = $ts;
    var $85 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $84, 0, 0, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 34:
    var $87 = $cx;
    var $88 = _JS_ReportErrorFlagsAndNumberUC($87, 0, 2, 0, 56, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 35;
    break;
   case 35:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp15reportYarrErrorEP9JSContextPNS_11TokenStreamEN3JSC4Yarr9ErrorCodeE["X"] = 1;

function __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $flagStr, $flagsOut) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $charBuf = __stackBase__;
    var $1 = __ZNK8JSString6lengthEv($flagStr);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($flagStr, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$flagsOut >> 2] = 0;
    var $i_0 = 0;
    var $7 = 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $i_0;
    if ($i_0 >>> 0 < $1 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 15;
      break;
    }
   case 4:
    var $11 = HEAPU16[$3 + ($i_0 << 1) >> 1];
    var $12 = $11 & 65535;
    if (($12 | 0) == 105) {
      __label__ = 5;
      break;
    } else if (($12 | 0) == 103) {
      __label__ = 7;
      break;
    } else if (($12 | 0) == 109) {
      __label__ = 9;
      break;
    } else if (($12 | 0) == 121) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 5:
    if (($7 & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 6:
    var $17 = $7 | 1;
    HEAP32[$flagsOut >> 2] = $17;
    var $39 = $17;
    __label__ = 14;
    break;
   case 7:
    if (($7 & 2 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $22 = $7 | 2;
    HEAP32[$flagsOut >> 2] = $22;
    var $39 = $22;
    __label__ = 14;
    break;
   case 9:
    if (($7 & 4 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $27 = $7 | 4;
    HEAP32[$flagsOut >> 2] = $27;
    var $39 = $27;
    __label__ = 14;
    break;
   case 11:
    if (($7 & 8 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $32 = $7 | 8;
    HEAP32[$flagsOut >> 2] = $32;
    var $39 = $32;
    __label__ = 14;
    break;
   case 13:
    var $35 = $charBuf | 0;
    HEAP8[$35] = $11 & 255;
    HEAP8[$charBuf + 1 | 0] = 0;
    var $37 = _JS_ReportErrorFlagsAndNumber($2, 0, 2, 0, 58, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $35, tempInt));
    var $_0 = 0;
    __label__ = 15;
    break;
   case 14:
    var $39;
    var $i_0 = $i_0 + 1 | 0;
    var $7 = $39;
    __label__ = 3;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj["X"] = 1;

function __ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE($agg_result, $cx, $str, $opt, $ts) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    if (($opt | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    var $4 = $ts;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $3, $str, 0, $4);
    __label__ = 6;
    break;
   case 3:
    HEAP32[$flags >> 2] = 0;
    var $6 = __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $opt, $flags);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($agg_result, 0);
    __label__ = 6;
    break;
   case 5:
    var $9 = HEAP32[$flags >> 2];
    var $10 = $cx;
    var $11 = $ts;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($agg_result, $10, $str, $9, $11);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject24assignInitialRegExpShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 52 | 0;
    var $5 = HEAP32[HEAP32[$1 >> 2] + 210252 >> 2] | 0;
    var $6 = __ZL12ATOM_TO_JSIDP6JSAtom3481($5);
    var $7 = $this;
    var $8 = $cx;
    var $9 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $6, 0, 4);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = HEAP32[HEAP32[$1 >> 2] + 210300 >> 2] | 0;
    var $16 = __ZL12ATOM_TO_JSIDP6JSAtom3481($15);
    var $17 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $16, 1, 6);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = HEAP32[HEAP32[$1 >> 2] + 210224 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom3481($23);
    var $25 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $24, 2, 6);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $31 = HEAP32[HEAP32[$1 >> 2] + 210228 >> 2] | 0;
    var $32 = __ZL12ATOM_TO_JSIDP6JSAtom3481($31);
    var $33 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $32, 3, 6);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $39 = HEAP32[HEAP32[$1 >> 2] + 210268 >> 2] | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom3481($39);
    var $41 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $40, 4, 6);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $47 = HEAP32[HEAP32[$1 >> 2] + 210308 >> 2] | 0;
    var $48 = __ZL12ATOM_TO_JSIDP6JSAtom3481($47);
    var $49 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $48, 5, 6);
    var $_0 = $49;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject24assignInitialRegExpShapeEP9JSContext["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom3481($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3545($1);
  return $2;
}

function __ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return 1;
}

function __ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = __ZN9JSContext13regExpStaticsEv($2);
    var $4 = $vp | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_IS_STRING3541($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $4 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = $1 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = _JS_ConvertValue($2, $1, 3, $vp);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $4 | 0;
    var $14$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4 + 4 | 0;
    var $14$1 = HEAP32[$st$0$1 >> 2];
    var $15 = _JSVAL_TO_STRING3542($14$0, $14$1);
    __ZN2js13RegExpStatics15setPendingInputEP8JSString($3, $15);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $cx;
  var $3 = __ZN9JSContext13regExpStaticsEv($2);
  var $4 = __ZNK2js13RegExpStatics9multilineEv($3);
  var $5 = $4 & 1;
  _BOOLEAN_TO_JSVAL3539($1, $5);
  var $6 = $1 | 0;
  var $7$0 = HEAP32[$6 >> 2];
  var $7$1 = HEAP32[$6 + 4 >> 2];
  var $8 = $vp | 0;
  HEAP32[$8 >> 2] = $7$0;
  HEAP32[$8 + 4 >> 2] = $7$1;
  STACKTOP = __stackBase__;
  return 1;
}

function __ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = __ZN9JSContext13regExpStaticsEv($2);
    var $4 = $vp | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_IS_BOOLEAN($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $4 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = $1 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = _JS_ConvertValue($2, $1, 5, $vp);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $4 | 0;
    var $14$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $4 + 4 | 0;
    var $14$1 = HEAP32[$st$0$1 >> 2];
    var $15 = _JSVAL_TO_BOOLEAN($14$0, $14$1);
    var $16 = ($15 | 0) != 0;
    __ZN2js13RegExpStatics12setMultilineEb($3, $16);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE($2, $cx, $vp);
  return $3 & 1;
}

function __ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 1, $vp);
  return $3 & 1;
}

function __ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 2, $vp);
  return $3 & 1;
}

function __ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 3, $vp);
  return $3 & 1;
}

function __ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 4, $vp);
  return $3 & 1;
}

function __ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 5, $vp);
  return $3 & 1;
}

function __ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 6, $vp);
  return $3 & 1;
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 7, $vp);
  return $3 & 1;
}

function __ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 8, $vp);
  return $3 & 1;
}

function __ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = $cx;
  var $2 = __ZN9JSContext13regExpStaticsEv($1);
  var $3 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($2, $cx, 9, $vp);
  return $3 & 1;
}

function __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject($xdr, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $source = __stackBase__;
    var $flagsword = __stackBase__ + 4;
    var $anchor = __stackBase__ + 8;
    var $re1 = __stackBase__ + 12;
    HEAP32[$source >> 2] = 0;
    HEAP32[$flagsword >> 2] = 0;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$objp >> 2];
    var $7 = __ZN2js6RegExp11extractFromEP8JSObject($6);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZNK2js6RegExp9getSourceEv($7);
    var $11 = $10 | 0;
    HEAP32[$source >> 2] = $11;
    var $12 = __ZNK2js6RegExp8getFlagsEv($7);
    var $13 = HEAP32[$12 >> 2];
    HEAP32[$flagsword >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    var $15 = $xdr;
    var $16 = _JS_XDRString($15, $source);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = _JS_XDRUint32($15, $flagsword);
    if (($19 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 1;
      __label__ = 11;
      break;
    }
   case 7:
    var $25 = $xdr + 8 | 0;
    var $26 = HEAP32[$25 >> 2];
    var $27 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($26);
    if (($27 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $27;
    __ZN8JSObject11clearParentEv($30);
    __ZN8JSObject9clearTypeEv($30);
    var $31 = HEAP32[$source >> 2];
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $31);
    var $33 = HEAP32[$flagsword >> 2];
    var $34 = HEAP32[$25 >> 2];
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re1, $34, $31, $33, 0);
    var $35 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re1);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = HEAP32[$25 >> 2];
    var $39 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re1);
    var $40 = $38;
    var $41 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($30, $40, $39);
    if ($41) {
      __label__ = 10;
      break;
    } else {
      var $_1 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$objp >> 2] = $27;
    var $_1 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject["X"] = 1;

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($cx) {
  var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3527($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528($cx, $4);
  return $5;
}

function __ZL15regexp_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN2js6RegExp11extractFromEP8JSObject($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    __ZN2js6RegExp6decrefEP9JSContext($2, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($cx, $obj, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $sb = __stackBase__ + 8;
    var $2 = __stackBase__ + 88;
    var $3 = $obj;
    var $4 = __ZNK8JSObject8isRegExpEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($6, $vp, __ZN2js11RegExpClassE);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 3:
    var $8 = __ZN2js6RegExp11extractFromEP8JSObject($3);
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString3485($1, $15);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $vp | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_1 = 1;
    __label__ = 20;
    break;
   case 5:
    var $20 = __ZNK2js6RegExp9getSourceEv($8);
    var $21 = $sb;
    var $22 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($21, $22);
    var $23 = $20 | 0;
    var $24 = __ZNK8JSString6lengthEv($23);
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = $24 + 2 | 0;
    var $28 = __ZN2js12StringBuffer7reserveEj($21, $27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 7:
    __ZN2js12StringBuffer16infallibleAppendEt($sb, 47);
    var $30 = __ZNK14JSLinearString5charsEv($20);
    __ZN2js12StringBuffer16infallibleAppendEPKtj($21, $30, $24);
    __ZN2js12StringBuffer16infallibleAppendEt($sb, 47);
    __label__ = 9;
    break;
   case 8:
    var $32 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__str223465);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 9:
    var $34 = __ZNK2js6RegExp6globalEv($8);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = __ZN2js12StringBuffer6appendEt($21, 103);
    if ($36) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 11:
    var $38 = __ZNK2js6RegExp10ignoreCaseEv($8);
    if ($38) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $40 = __ZN2js12StringBuffer6appendEt($21, 105);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $42 = __ZNK2js6RegExp9multilineEv($8);
    if ($42) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $44 = __ZN2js12StringBuffer6appendEt($21, 109);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 15:
    var $46 = __ZNK2js6RegExp6stickyEv($8);
    if ($46) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $48 = __ZN2js12StringBuffer6appendEt($21, 121);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 17:
    var $50 = $sb;
    var $51 = __ZN2js12StringBuffer12finishStringEv($50);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $54 = $51 | 0;
    __ZN2JSL11StringValueEP8JSString3485($2, $54);
    var $55 = $2 | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = $vp | 0;
    HEAP32[$57 >> 2] = $56$0;
    HEAP32[$57 + 4 >> 2] = $56$1;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN2js12StringBufferD1Ev($21);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE["X"] = 1;

function __ZN2JSL11StringValueEP8JSString3485($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2js12StringBuffer16infallibleAppendEt($this, $c) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP16[$1 >> 1] = $c;
  var $2 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($this, $array) {
  var $1 = $array | 0;
  var $2 = $array + 6 | 0;
  var $3 = $this;
  var $4 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_($3, $1, $2);
  return $4;
}

function __Z14js_regexp_execP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, 0, $argc, $vp);
  return $1;
}

function __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, $execType, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $arc = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $i = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $lastIndexInt = __stackBase__ + 36;
    var $4 = $vp + 8 | 0;
    var $5 = $cx;
    var $6 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $4);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK8JSObject8isRegExpEv($6);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js11RegExpClassE);
    var $_1 = 0;
    __label__ = 24;
    break;
   case 4:
    var $13 = __ZN2js6RegExp11extractFromEP8JSObject($6);
    if (($13 | 0) == 0) {
      var $_1 = 1;
      __label__ = 24;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($1, $13);
    __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE($arc, $cx, $1);
    var $16 = __ZN9JSContext13regExpStaticsEv($5);
    if (($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $vp + 16 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $2 | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv3491($2);
    __label__ = 8;
    break;
   case 8:
    var $24 = $cx;
    var $25 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($24, $2);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = __ZNK8JSString6lengthEv($25);
    var $29 = __ZNK8JSObject18getRegExpLastIndexEv($7);
    var $30 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509($cx, $29, $i);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 10:
    var $32 = __ZNK2js6RegExp6globalEv($13);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = __ZNK2js6RegExp6stickyEv($13);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    tempDoubleF64[0] = 0, HEAP32[$i >> 2] = tempDoubleI32[0], HEAP32[$i + 4 >> 2] = tempDoubleI32[1];
    var $38 = 0;
    __label__ = 14;
    break;
   case 13:
    var $_pr = (tempDoubleI32[0] = HEAP32[$i >> 2], tempDoubleI32[1] = HEAP32[$i + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 15;
      break;
    } else {
      var $38 = $_pr;
      __label__ = 14;
      break;
    }
   case 14:
    var $38;
    if ($38 > $28 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN8JSObject19zeroRegExpLastIndexEv($6);
    __ZN2JSL9NullValueEv3510($3);
    var $42 = $3 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $vp | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 23;
    break;
   case 16:
    var $46 = $38 >= 0 ? Math.floor($38) : Math.ceil($38);
    HEAP32[$lastIndexInt >> 2] = $46;
    var $47 = ($execType | 0) == 1;
    var $48 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($13, $5, $16, $25, $lastIndexInt, $47, $vp);
    if ($48) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 17:
    var $50 = __ZNK2js6RegExp6globalEv($13);
    if ($50) {
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $52 = __ZNK2JS5Value6isNullEv($vp);
    if ($52) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $54 = __ZNK2js6RegExp6stickyEv($13);
    if ($54) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 1;
      __label__ = 23;
      break;
    }
   case 20:
    var $56 = __ZNK2JS5Value6isNullEv($vp);
    if ($56) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN8JSObject19zeroRegExpLastIndexEv($6);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 22:
    var $60 = HEAPU32[$lastIndexInt >> 2] >>> 0;
    __ZN8JSObject18setRegExpLastIndexEd($7, $60);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    __ZN2js12AutoRefCountINS_6RegExpEED1Ev($arc);
    var $_1 = $_0;
    __label__ = 24;
    break;
   case 24:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE["X"] = 1;

function __Z14js_regexp_testP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE($cx, 1, $argc, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value6isTrueEv($vp);
    if ($4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value10setBooleanEb($vp, 0);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15regexp_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $7 = __Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE($cx, $6, $vp);
    var $_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14regexp_compileP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject8isRegExpEv($3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js11RegExpClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $10 = $vp + 16 | 0;
    var $11 = __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $4, $argc, $10, $vp);
    var $_0 = $11 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_InitRegExpClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 12;
    var $4 = __stackBase__ + 16;
    var $5 = __stackBase__ + 20;
    var $6 = __stackBase__ + 24;
    var $7 = $obj;
    var $8 = __ZN8JSObject8asGlobalEv($7);
    var $9 = $cx;
    var $10 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($8, $9, __ZN2js11RegExpClassE);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $14 = $cx + 52 | 0;
    var $18 = HEAP32[HEAP32[$14 >> 2] + 144136 >> 2] | 0;
    var $19 = $cx;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $19, $18, 0, 0);
    var $20 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $23 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($re);
    var $24 = $10;
    var $25 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($24, $19, $23);
    if ($25) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $27 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($9, $10, 0, __ZL14regexp_methods);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$14 >> 2] + 210060 >> 2];
    var $33 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($8, $9, 224, __ZN2js11RegExpClassE, $32, 2);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $36 = $33 | 0;
    var $37 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($9, $36, $10);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $39 = $33;
    var $40 = _JS_DefineProperties($19, $39, __ZL19regexp_static_props);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $43 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($24, $19, 0, 0);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js5types4Type10StringTypeEv($1);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_source_str | 0, $1);
    __ZN2js5types4Type11BooleanTypeEv($2);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_global_str | 0, $2);
    __ZN2js5types4Type11BooleanTypeEv($3);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_ignoreCase_str | 0, $3);
    __ZN2js5types4Type11BooleanTypeEv($4);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_multiline_str | 0, $4);
    __ZN2js5types4Type11BooleanTypeEv($5);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_sticky_str | 0, $5);
    __ZN2js5types4Type9Int32TypeEv($6);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $44, STRING_TABLE._js_lastIndex_str | 0, $6);
    var $47 = $8;
    var $48 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($19, $47, 10, $39, $24);
    var $_ = $48 ? $11 : 0;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitRegExpClassP9JSContextP8JSObject["X"] = 1;

function __ZL16regexp_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN2jsL14IsConstructingEPKN2JS5ValueE3500($vp);
    if ($2 | ($argc | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8isObjectEv($1);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = __ZNK2JS5Value8toObjectEv($1);
    var $8 = __ZNK8JSObject8isRegExpEv($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    if (($argc | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $vp + 24 | 0;
    var $13 = __ZNK2JS5Value11isUndefinedEv($12);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $19 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482($cx);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $19, $argc, $1, $vp);
    var $_0 = $22 & 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($cx, $obj, $name, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $type;
  $type = STACKTOP;
  STACKTOP += 4;
  HEAP32[$type >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = __ZN9JSContext20typeInferenceEnabledEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = __ZN2js5types10TypeObject17unknownPropertiesEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$type >> 2];
    HEAP32[$1 >> 2] = $9;
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE($5, $2, $name, $1);
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3490($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2JSL14UndefinedValueEv3491($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE3500($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sourceValue = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $flags = __stackBase__ + 20;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $10 = __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $9, 0);
    var $_0 = $10;
    __label__ = 19;
    break;
   case 3:
    var $12 = $argv | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $sourceValue | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $15 = __ZNK2JS5Value8isObjectEv($sourceValue);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $17 = __ZNK2JS5Value8toObjectEv($sourceValue);
    var $18 = __ZNK8JSObject8isRegExpEv($17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $argv + 8 | 0;
    var $23 = __ZNK2JS5Value11isUndefinedEv($22);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $cx;
    _JS_ReportErrorNumber($25, 2, 0, 165, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 19;
    break;
   case 8:
    var $27 = __ZN2js6RegExp11extractFromEP8JSObject($17);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2js6RegExp6increfEP9JSContext($27, undef);
    __ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_($1, $27);
    var $_01_val = HEAP32[$1 >> 2];
    __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $_01_val);
    __ZN2JSL11ObjectValueER8JSObject3490($2, $obj);
    var $30 = $2 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $rval | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 10:
    var $34 = __ZNK2JS5Value11isUndefinedEv($sourceValue);
    if ($34) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $sourceStr_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 13;
    break;
   case 12:
    var $42 = $cx;
    var $43 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($42, $sourceValue);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $sourceStr_0 = $43;
      __label__ = 13;
      break;
    }
   case 13:
    var $sourceStr_0;
    HEAP32[$flags >> 2] = 0;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $48 = $argv + 8 | 0;
    var $49 = __ZNK2JS5Value11isUndefinedEv($48);
    if ($49) {
      __label__ = 17;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $51 = $cx;
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($51, $48);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2JS5Value9setStringEP8JSString($48, $52);
    var $55 = __ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj($cx, $52, $flags);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 17:
    var $57 = __ZL25EscapeNakedForwardSlashesP9JSContextP8JSString($cx, $sourceStr_0);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $60 = HEAP32[$flags >> 2];
    var $61 = __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $57, $60);
    var $_0 = $61;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_["X"] = 1;

function __ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj($cx, $obj, $rval, $str, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $cx;
    var $3 = __ZN9JSContext13regExpStaticsEv($2);
    var $4 = __ZNK2js13RegExpStatics8getFlagsEv($3);
    var $5 = $4 | $flags;
    __ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE($re, $2, $str, $5, 0);
    var $6 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$re >> 2];
    __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $10);
    __ZN2JSL11ObjectValueER8JSObject3490($1, $obj);
    var $11 = $1 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $rval | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE($cx, $obj, $newRegExp_0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newRegExp = __stackBase__;
    HEAP32[$newRegExp >> 2] = $newRegExp_0;
    var $1 = $obj;
    var $2 = __ZN2js6RegExp11extractFromEP8JSObject($1);
    var $3 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($newRegExp);
    var $4 = $cx;
    var $5 = __ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE($1, $4, $3);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6decrefEP9JSContext($2, $4);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL25EscapeNakedForwardSlashesP9JSContextP8JSString($cx, $unescaped) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 280;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $newChars = __stackBase__ + 4;
    var $1 = __stackBase__ + 276;
    var $2 = __ZNK8JSString6lengthEv($unescaped);
    var $3 = $cx;
    var $4 = __ZN8JSString8getCharsEP9JSContext($unescaped, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $unescaped);
    var $7 = $1;
    __ZN2js15TempAllocPolicyC1EP9JSContext($7, $3);
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_($newChars, $1);
    var $8 = $4 + ($2 << 1) | 0;
    var $9 = $2 + 1 | 0;
    var $10 = $4;
    var $it_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $it_0;
    if ($it_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 4:
    if (HEAP16[$it_0 >> 1] << 16 >> 16 == 47) {
      __label__ = 5;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 5:
    if (($it_0 | 0) == ($4 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (HEAP16[$it_0 - 2 >> 1] << 16 >> 16 == 92) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($newChars);
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $26 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj($newChars, $9);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $30 = $it_0 - $10 >> 1;
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j($newChars, $4, $30);
    __label__ = 10;
    break;
   case 10:
    var $32 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($newChars, 92);
    if ($32) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $34 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($newChars);
    if ($34) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = HEAP16[$it_0 >> 1];
    var $37 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_($newChars, $36);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $it_0 = $it_0 + 2 | 0;
    __label__ = 3;
    break;
   case 14:
    var $41 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv($newChars);
    if ($41) {
      var $_0 = $unescaped;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $43 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv($newChars);
    var $44 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($newChars, 0);
    if ($44) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 16:
    var $46 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv($newChars);
    var $47 = $cx;
    var $48 = __Z12js_NewStringP9JSContextPtj($47, $46, $43);
    var $49 = $48 | 0;
    if (($48 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $49;
      __label__ = 18;
      break;
    }
   case 17:
    var $52 = $46;
    __ZN9JSContext5free_EPv(undef, $52);
    var $_0 = $49;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev($newChars);
    var $_1 = $_0;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25EscapeNakedForwardSlashesP9JSContextP8JSString["X"] = 1;

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 12 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 8 >> 2] | 0;
    var $8 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j($this, $begin, $length) {
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j($this, $begin, $length);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_BOOLEAN_IMPL3536($l_0$0, $l_0$1) {
  return $l_0$0;
}

function __ZL14JSID_FROM_BITSj3545($bits) {
  return $bits;
}

function _JSVAL_IS_BOOLEAN_IMPL3538($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function _JSVAL_TO_STRING_IMPL3543($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL3544($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function __ZNK7mozilla14AlignedStorageILj256EE4addrEv($this) {
  return $this;
}

function __ZN7mozilla14AlignedStorageILj256EE4addrEv($this) {
  return $this;
}

function __ZL18JSDOUBLE_IS_FINITEd3520($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZL15JSDOUBLE_IS_NaNd3521($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 1) | 0;
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _BOOLEAN_TO_JSVAL_IMPL3507($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function __ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_($this, $obj) {
  HEAP32[$this >> 2] = $obj;
  return;
}

function __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js2gcL15GetGCObjectKindEjb3527($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZNK2js13RegExpStatics9multilineEv($this) {
  return (HEAP32[$this + 100 >> 2] & 4 | 0) != 0;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout3540($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $5 = HEAP32[$3 >> 2] << 1;
    var $6 = $this;
    var $7 = __ZN2js15TempAllocPolicy7malloc_Ej($6, $5);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($8, $11, $12);
    HEAP32[$3 >> 2] = 0;
    var $_0 = $8;
    __label__ = 5;
    break;
   case 4:
    var $14 = $this + 4 | 0;
    var $15 = HEAP32[$14 >> 2];
    var $16 = $this + 16 | 0;
    var $17 = __ZN7mozilla14AlignedStorageILj256EE4addrEv($16);
    HEAP32[$14 >> 2] = $17;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 128;
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj256EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 1;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t << 24 >> 24;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j($this, $insBegin, $length) {
  var $1 = __ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv($this);
  var $2 = $insBegin + ($length << 1) | 0;
  __ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($1, $insBegin, $2);
  var $3 = $this + 8 | 0;
  var $5 = HEAP32[$3 >> 2] + $length | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj256EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 128;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj) {
  var __stackBase__ = STACKTOP;
  var tempParam = $aobj;
  $aobj = STACKTOP;
  STACKTOP += 4;
  HEAP32[$aobj >> 2] = HEAP32[tempParam >> 2];
  __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($this, $obj) {
  __ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_($this, $obj);
  return;
}

function __ZNK8JSObject18getRegExpLastIndexEv($this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  return $2;
}

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509($cx, $v, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value7isInt32Ev($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value7toInt32Ev($v);
    tempDoubleF64[0] = $4 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $17 = $9;
    __label__ = 7;
    break;
   case 5:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = $cx;
    var $15 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($14, $1, $dp);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $17 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $17;
    var $18 = __ZL18js_DoubleToIntegerd3519($17);
    tempDoubleF64[0] = $18, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv3510($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN8JSObject18setRegExpLastIndexEd($this, $d) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL11NumberValueEd3511($1, $d);
  var $2 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEED1Ev($this) {
  __ZN2js12AutoRefCountINS_6RegExpEED2Ev($this);
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this >> 2];
    __ZN2js6RegExp6decrefEP9JSContext($2, $7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11NumberValueEd3511($agg_result, $dbl) {
  var $1 = __ZN2JS5Value9setNumberEd($agg_result, $dbl);
  return;
}

function __ZL18js_DoubleToIntegerd3519($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd3520($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd3521($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE($this, $cx, $aobj) {
  var __stackBase__ = STACKTOP;
  var tempParam = $aobj;
  $aobj = STACKTOP;
  STACKTOP += 4;
  HEAP32[$aobj >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $cx;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($aobj);
    HEAP32[$2 >> 2] = $3;
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6RegExp6increfEP9JSContext($3, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt($this, $t) {
  var $1 = HEAP16[$t >> 1];
  var $2 = $this;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_($2, $1);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js11RegExpClassE + 4 >> 2] >>> 24;
    var $4 = $cx;
    var $5 = __ZNK9JSContext5hasfpEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($4);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $22 = __ZNK2JS5Value8isObjectEv($1);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $24 = __ZNK2JS5Value8toObjectEv($1);
    var $25 = $24;
    HEAP32[$proto >> 2] = $25;
    var $32 = $25;
    __label__ = 9;
    break;
   case 7:
    var $27 = $cx;
    var $29 = $proto;
    var $30 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($27, $19, $3, $29, __ZN2js11RegExpClassE);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $32 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $32;
    var $33 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $32, $19, $kind);
    var $_0 = $33;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js11RegExpClassE, $3, $10, 0, (__ZN2js11RegExpClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $11 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, __ZN2js11RegExpClassE, $kind);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $11 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $14);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($this, $cx, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 > $pairNum >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $8);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $10 = $pairNum << 1;
    var $11 = __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, $10, $pairNum, $out);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics9pairCountEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($1);
  return $2 >>> 1;
}

function __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, $checkValidIndex, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $checkValidIndex >>> 1;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < $2 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($5, $checkValidIndex);
    if ((HEAP32[$6 >> 2] | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $14);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $16 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
    var $17 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 1);
    var $18 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this, $cx, $16, $17, $out);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv($this);
  return $1 + ($i << 2) | 0;
}

function __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this, $cx, $start, $end, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $4 = HEAP32[$this + 92 >> 2] | 0;
    var $5 = $end - $start | 0;
    var $6 = $cx;
    var $7 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($6, $4, $start, $5);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $7 | 0;
    __ZN2JSL11StringValueEP8JSString3485($1, $10);
    var $11 = $1 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $out | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics3getEjb($this, $pairNum, $which) {
  var $1 = $this | 0;
  var $4 = $which & 1 | $pairNum << 1;
  var $5 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($1, $4);
  return HEAP32[$5 >> 2];
}

function __ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($11, 1);
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv3491($1);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $out | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $22 = HEAP32[$this + 92 >> 2] | 0;
    var $23 = __ZNK8JSString6lengthEv($22);
    var $24 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this, $cx, $13, $23, $out);
    var $_0 = $24;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $11 = $this | 0;
    var $12 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj($11, 0);
    var $13 = HEAP32[$12 >> 2];
    if (($13 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JSL14UndefinedValueEv3491($1);
    var $16 = $1 | 0;
    var $17$0 = HEAP32[$16 >> 2];
    var $17$1 = HEAP32[$16 + 4 >> 2];
    var $18 = $out | 0;
    HEAP32[$18 >> 2] = $17$0;
    HEAP32[$18 + 4 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $20 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this, $cx, 0, $13, $out);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $8);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $10 = $1 - 1 | 0;
    var $11 = __ZNK2js13RegExpStatics3getEjb($this, $10, 0);
    if (($11 | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($out, $18);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $20 = __ZNK2js13RegExpStatics3getEjb($this, $10, 1);
    var $21 = __ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE($this, $cx, $11, $20, $out);
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var $1 = __ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE($this, $cx, 0, 0, $out);
  return $1;
}

function _JSVAL_IS_BOOLEAN($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_BOOLEAN_IMPL3538($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_BOOLEAN($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_BOOLEAN_IMPL3536($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _BOOLEAN_TO_JSVAL3539($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL3507($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout3540($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_STRING3541($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL3544($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js13RegExpStatics15setPendingInputEP8JSString($this, $newInput) {
  var $1 = $this;
  __ZN2js13RegExpStatics12aboutToWriteEv($1);
  HEAP32[$this + 96 >> 2] = $newInput;
  return;
}

function _JSVAL_TO_STRING3542($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE3537($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL3543($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE($this, $cx, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 96 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    __ZN2JS5Value9setStringEP8JSString($out, $11);
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics4markEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 96 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $trc;
    _JS_CallTracer($6, $5, 1);
    __label__ = 3;
    break;
   case 3:
    var $9 = HEAP32[$this + 92 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = $trc;
    _JS_CallTracer($13, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13RegExpStaticsD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStaticsD1Ev($this) {
  __ZN2js13RegExpStaticsD2Ev($this);
  return;
}

function __ZN2js13RegExpStaticsD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev($1);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL13VersionHasXMLE9JSVersion3598($version) {
  return ($version & 4096 | 0) != 0;
}

function __ZN2js11FindKeywordEPKtj($s, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 2) {
      __label__ = 2;
      break;
    } else if (($length | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($length | 0) == 4) {
      __label__ = 16;
      break;
    } else if (($length | 0) == 5) {
      __label__ = 38;
      break;
    } else if (($length | 0) == 6) {
      __label__ = 71;
      break;
    } else if (($length | 0) == 7) {
      __label__ = 86;
      break;
    } else if (($length | 0) == 8) {
      __label__ = 91;
      break;
    } else if (($length | 0) == 9) {
      __label__ = 94;
      break;
    } else if (($length | 0) == 10) {
      __label__ = 96;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 2:
    var $2 = HEAP16[$s >> 1];
    if ($2 << 16 >> 16 == 100) {
      __label__ = 3;
      break;
    } else if ($2 << 16 >> 16 == 105) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 3:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 10;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 4:
    var $9 = HEAP16[$s + 2 >> 1];
    if ($9 << 16 >> 16 == 110) {
      __label__ = 5;
      break;
    } else if ($9 << 16 >> 16 == 102) {
      var $i_0 = 15;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 5:
    var $i_0 = 16;
    __label__ = 98;
    break;
   case 6:
    var $14 = HEAPU16[$s + 4 >> 1] & 65535;
    if (($14 | 0) == 114) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 116) {
      __label__ = 10;
      break;
    } else if (($14 | 0) == 119) {
      __label__ = 12;
      break;
    } else if (($14 | 0) == 121) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 7:
    var $16 = HEAP16[$s >> 1];
    if ($16 << 16 >> 16 == 102) {
      __label__ = 8;
      break;
    } else if ($16 << 16 >> 16 == 118) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 8:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 13;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 9:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      var $i_0 = 25;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 10:
    if (HEAP16[$s >> 1] << 16 >> 16 == 108) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 11:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 36;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 12:
    if (HEAP16[$s >> 1] << 16 >> 16 == 110) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 13:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 18;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 14:
    if (HEAP16[$s >> 1] << 16 >> 16 == 116) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 15:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 23;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 16:
    var $49 = HEAPU16[$s + 4 >> 1] & 65535;
    if (($49 | 0) == 105) {
      __label__ = 17;
      break;
    } else if (($49 | 0) == 108) {
      __label__ = 22;
      break;
    } else if (($49 | 0) == 115) {
      __label__ = 25;
      break;
    } else if (($49 | 0) == 116) {
      __label__ = 30;
      break;
    } else if (($49 | 0) == 117) {
      __label__ = 33;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 17:
    var $51 = HEAP16[$s >> 1];
    if ($51 << 16 >> 16 == 116) {
      __label__ = 18;
      break;
    } else if ($51 << 16 >> 16 == 118) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 18:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 115) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 19:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 21;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 20:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 100) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 21:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 26;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 22:
    if (HEAP16[$s >> 1] << 16 >> 16 == 110) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 23:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 117) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 24:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 2;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 25:
    var $81 = HEAP16[$s + 2 >> 1];
    if ($81 << 16 >> 16 == 97) {
      __label__ = 26;
      break;
    } else if ($81 << 16 >> 16 == 108) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 26:
    if (HEAP16[$s >> 1] << 16 >> 16 == 99) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 27:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 4;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 28:
    if (HEAP16[$s >> 1] << 16 >> 16 == 101) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 29:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 11;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 30:
    if (HEAP16[$s >> 1] << 16 >> 16 == 119) {
      __label__ = 31;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 31:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 105) {
      __label__ = 32;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 32:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 28;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 33:
    var $108 = HEAP16[$s >> 1];
    if ($108 << 16 >> 16 == 101) {
      __label__ = 34;
      break;
    } else if ($108 << 16 >> 16 == 116) {
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 34:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 109) {
      __label__ = 35;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 35:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 110) {
      var $i_0 = 30;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 36:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 101) {
      __label__ = 37;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 37:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 1;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 38:
    var $128 = HEAPU16[$s + 6 >> 1] & 65535;
    if (($128 | 0) == 97) {
      __label__ = 39;
      break;
    } else if (($128 | 0) == 99) {
      __label__ = 43;
      break;
    } else if (($128 | 0) == 101) {
      __label__ = 47;
      break;
    } else if (($128 | 0) == 108) {
      __label__ = 51;
      break;
    } else if (($128 | 0) == 111) {
      __label__ = 58;
      break;
    } else if (($128 | 0) == 115) {
      __label__ = 62;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 39:
    if (HEAP16[$s >> 1] << 16 >> 16 == 98) {
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 40:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 114) {
      __label__ = 41;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 41:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 101) {
      __label__ = 42;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 42:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 107) {
      var $i_0 = 3;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 43:
    if (HEAP16[$s >> 1] << 16 >> 16 == 99) {
      __label__ = 44;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 44:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      __label__ = 45;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 45:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 116) {
      __label__ = 46;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 46:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 104) {
      var $i_0 = 5;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 47:
    if (HEAP16[$s >> 1] << 16 >> 16 == 115) {
      __label__ = 48;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 48:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 117) {
      __label__ = 49;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 49:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 112) {
      __label__ = 50;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 50:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 114) {
      var $i_0 = 34;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 51:
    var $175 = HEAP16[$s >> 1];
    if ($175 << 16 >> 16 == 119) {
      __label__ = 52;
      break;
    } else if ($175 << 16 >> 16 == 121) {
      __label__ = 55;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 52:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 101) {
      __label__ = 53;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 53:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      __label__ = 54;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 54:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 105) {
      var $i_0 = 27;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 55:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 100) {
      __label__ = 56;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 56:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 105) {
      __label__ = 57;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 57:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 101) {
      var $i_0 = 37;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 58:
    if (HEAP16[$s >> 1] << 16 >> 16 == 116) {
      __label__ = 59;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 59:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 104) {
      __label__ = 60;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 60:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 114) {
      __label__ = 61;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 61:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 119) {
      var $i_0 = 22;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 62:
    var $216 = HEAP16[$s >> 1];
    if ($216 << 16 >> 16 == 99) {
      __label__ = 63;
      break;
    } else if ($216 << 16 >> 16 == 102) {
      __label__ = 68;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 63:
    var $219 = HEAP16[$s + 8 >> 1];
    if ($219 << 16 >> 16 == 115) {
      __label__ = 64;
      break;
    } else if ($219 << 16 >> 16 == 116) {
      __label__ = 66;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 64:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 97) {
      __label__ = 65;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 65:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 29;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 66:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 110) {
      __label__ = 67;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 67:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 111) {
      var $i_0 = 35;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 68:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 101) {
      __label__ = 69;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 69:
    if (HEAP16[$s + 2 >> 1] << 16 >> 16 == 97) {
      __label__ = 70;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 70:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 108) {
      var $i_0 = 0;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 71:
    var $250 = HEAPU16[$s >> 1] & 65535;
    if (($250 | 0) == 101) {
      __label__ = 72;
      break;
    } else if (($250 | 0) == 105) {
      __label__ = 73;
      break;
    } else if (($250 | 0) == 112) {
      __label__ = 74;
      break;
    } else if (($250 | 0) == 114) {
      __label__ = 75;
      break;
    } else if (($250 | 0) == 115) {
      __label__ = 76;
      break;
    } else if (($250 | 0) == 116) {
      __label__ = 85;
      break;
    } else if (($250 | 0) == 100) {
      var $i_1 = 9;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 72:
    var $i_1 = 31;
    __label__ = 99;
    break;
   case 73:
    var $i_1 = 33;
    __label__ = 99;
    break;
   case 74:
    var $i_1 = 43;
    __label__ = 99;
    break;
   case 75:
    var $i_1 = 19;
    __label__ = 99;
    break;
   case 76:
    var $257 = HEAP16[$s + 2 >> 1];
    if ($257 << 16 >> 16 == 116) {
      __label__ = 77;
      break;
    } else if ($257 << 16 >> 16 == 119) {
      __label__ = 81;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 77:
    if (HEAP16[$s + 10 >> 1] << 16 >> 16 == 99) {
      __label__ = 78;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 78:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 105) {
      __label__ = 79;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 79:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 97) {
      __label__ = 80;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 80:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 116) {
      var $i_0 = 44;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 81:
    if (HEAP16[$s + 10 >> 1] << 16 >> 16 == 104) {
      __label__ = 82;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 82:
    if (HEAP16[$s + 8 >> 1] << 16 >> 16 == 99) {
      __label__ = 83;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 83:
    if (HEAP16[$s + 4 >> 1] << 16 >> 16 == 105) {
      __label__ = 84;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 84:
    if (HEAP16[$s + 6 >> 1] << 16 >> 16 == 116) {
      var $i_0 = 20;
      __label__ = 98;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 85:
    var $i_1 = 24;
    __label__ = 99;
    break;
   case 86:
    var $293 = HEAPU16[$s >> 1] & 65535;
    if (($293 | 0) == 101) {
      __label__ = 87;
      break;
    } else if (($293 | 0) == 102) {
      __label__ = 88;
      break;
    } else if (($293 | 0) == 112) {
      __label__ = 89;
      break;
    } else if (($293 | 0) == 100) {
      var $i_1 = 8;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 87:
    var $i_1 = 32;
    __label__ = 99;
    break;
   case 88:
    var $i_1 = 12;
    __label__ = 99;
    break;
   case 89:
    var $298 = HEAP16[$s + 2 >> 1];
    if ($298 << 16 >> 16 == 114) {
      __label__ = 90;
      break;
    } else if ($298 << 16 >> 16 == 97) {
      var $i_1 = 40;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 90:
    var $i_1 = 41;
    __label__ = 99;
    break;
   case 91:
    var $302 = HEAP16[$s + 4 >> 1];
    if ($302 << 16 >> 16 == 110) {
      __label__ = 92;
      break;
    } else if ($302 << 16 >> 16 == 98) {
      var $i_1 = 7;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 92:
    var $304 = HEAP16[$s >> 1];
    if ($304 << 16 >> 16 == 102) {
      __label__ = 93;
      break;
    } else if ($304 << 16 >> 16 == 99) {
      var $i_1 = 6;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 93:
    var $i_1 = 14;
    __label__ = 99;
    break;
   case 94:
    var $307 = HEAP16[$s >> 1];
    if ($307 << 16 >> 16 == 112) {
      __label__ = 95;
      break;
    } else if ($307 << 16 >> 16 == 105) {
      var $i_1 = 39;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 95:
    var $i_1 = 42;
    __label__ = 99;
    break;
   case 96:
    var $311 = HEAP16[$s + 2 >> 1];
    if ($311 << 16 >> 16 == 109) {
      __label__ = 97;
      break;
    } else if ($311 << 16 >> 16 == 110) {
      var $i_1 = 17;
      __label__ = 99;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 97:
    var $i_1 = 38;
    __label__ = 99;
    break;
   case 98:
    var $i_0;
    var $_0 = __ZL8keywords + ($i_0 << 4) | 0;
    __label__ = 103;
    break;
   case 99:
    var $i_1;
    var $316 = __ZL8keywords + ($i_1 << 4) | 0;
    var $_01 = $s;
    var $_02 = $length;
    var $chars_0 = HEAP32[$316 >> 2];
    __label__ = 100;
    break;
   case 100:
    var $chars_0;
    var $_02;
    var $_01;
    if ((HEAPU16[$_01 >> 1] & 65535 | 0) == (HEAPU8[$chars_0] & 255 | 0)) {
      __label__ = 101;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 101:
    var $326 = $_02 - 1 | 0;
    if (($326 | 0) == 0) {
      var $_0 = $316;
      __label__ = 103;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $_01 = $_01 + 2 | 0;
    var $_02 = $326;
    var $chars_0 = $chars_0 + 1 | 0;
    __label__ = 100;
    break;
   case 103:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11FindKeywordEPKtj["X"] = 1;

function __ZN2js11TokenStream8TokenBuf4initEPKtj($this, $buf, $length) {
  HEAP32[$this + 8 >> 2] = $buf;
  HEAP32[$this >> 2] = $buf;
  HEAP32[$this + 4 >> 2] = $buf + ($length << 1) | 0;
  return;
}

function __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($this) {
  return HEAPU32[$this + 8 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 0;
}

function __ZN2js11TokenStream8TokenBuf10getRawCharEv($this) {
  var $1 = $this + 8 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $2 + 2 | 0;
  HEAP32[$1 >> 2] = $3;
  return HEAP16[$2 >> 1];
}

function __ZN2js11TokenStream8TokenBuf12matchRawCharEt($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (HEAP16[$2 >> 1] << 16 >> 16 == $c << 16 >> 16) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = $2 + 2 | 0;
    HEAP32[$1 >> 2] = $6;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_IsIdentifierP14JSLinearString($str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK14JSLinearString5charsEv($str);
    var $2 = $str | 0;
    var $3 = __ZNK8JSString6lengthEv($2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP16[$1 >> 1];
    var $7 = __ZN2js7unicode17IsIdentifierStartEt($6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = $1 + ($3 << 1) | 0;
    var $chars_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $chars_0;
    var $11 = $chars_0 + 2 | 0;
    if (($11 | 0) == ($9 | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP16[$11 >> 1];
    var $15 = __ZN2js7unicode16IsIdentifierPartEt($14);
    if ($15) {
      var $chars_0 = $11;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode17IsIdentifierStartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isidstart + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js7unicode8CharInfoEt($ch);
    var $10 = __ZNK2js7unicode13CharacterInfo8isLetterEv($9);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode16IsIdentifierPartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isident + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZN2js7unicode8CharInfoEt($ch);
    var $10 = __ZNK2js7unicode13CharacterInfo16isIdentifierPartEv($9);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStreamC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $cx;
  var $3 = $this + 4 | 0;
  HEAP32[$this + 144 >> 2] = 0;
  var $5 = $this + 156 | 0;
  var $6 = $3;
  for (var $$dest = $6 >> 2, $$stop = $$dest + 34; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = 0;
  }
  __ZN2js11TokenStream8TokenBufC1Ev($5);
  HEAP32[$this + 180 >> 2] = 0;
  var $8 = $this + 184 | 0;
  __ZN2js15TempAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_($8, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream8TokenBufC1Ev($this) {
  __ZN2js11TokenStream8TokenBufC2Ev($this);
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11TokenStream4initEPKtjPKcj9JSVersion($this, $base, $length, $fn, $ln, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this + 172 >> 2] = $fn;
    HEAP32[$this + 140 >> 2] = $ln;
    HEAP32[$this + 904 >> 2] = $v;
    var $4 = __ZN2jsL13VersionHasXMLE9JSVersion3598($v);
    HEAP8[$this + 908 | 0] = $4 & 1;
    var $7 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf4initEPKtj($7, $base, $length);
    HEAP32[$this + 148 >> 2] = $base;
    HEAP32[$this + 152 >> 2] = 0;
    HEAP32[$this + 176 >> 2] = 0;
    var $14 = HEAP32[HEAP32[$this >> 2] + 200 >> 2];
    var $16 = HEAP32[$14 + 32 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $20 = HEAP32[$14 + 36 >> 2];
    var $21 = $this + 180 | 0;
    FUNCTION_TABLE[$16]($fn, $ln, $base, $length, $21, $20);
    __label__ = 3;
    break;
   case 3:
    var $23 = $this + 264 | 0;
    _memset($23, 0, 128, 1);
    HEAP8[$this + 323 | 0] = 2;
    HEAP8[$this + 308 | 0] = 3;
    HEAP8[$this + 327 | 0] = 5;
    HEAP8[$this + 355 | 0] = 23;
    HEAP8[$this + 357 | 0] = 24;
    HEAP8[$this + 387 | 0] = 25;
    HEAP8[$this + 389 | 0] = 26;
    HEAP8[$this + 304 | 0] = 27;
    HEAP8[$this + 305 | 0] = 28;
    var $33 = $this + 392 | 0;
    _memset($33, 0, 256, 1);
    HEAP8[$this + 402 | 0] = 1;
    HEAP8[$this + 405 | 0] = 1;
    HEAP8[$this + 432 | 0] = 1;
    HEAP8[$this + 433 | 0] = 1;
    var $38 = $this + 648 | 0;
    _memset($38, 0, 256, 1);
    HEAP8[$this + 682 | 0] = 1;
    HEAP8[$this + 687 | 0] = 1;
    HEAP8[$this + 740 | 0] = 1;
    HEAP8[$this + 658 | 0] = 1;
    HEAP8[$this + 661 | 0] = 1;
    HEAP8[$this + 688 | 0] = 1;
    HEAP8[$this + 689 | 0] = 1;
    HEAP8[$this + 903 | 0] = 1;
    HEAP32[$this + 20 >> 2] = $ln;
    HEAP32[$this + 12 >> 2] = $ln;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream4initEPKtjPKcj9JSVersion["X"] = 1;

function __ZN2js11TokenStreamD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 144 >> 2] & 256 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 172 >> 2];
    __ZN9JSContext5free_EPv(undef, $7);
    __label__ = 3;
    break;
   case 3:
    var $10 = HEAP32[$this + 176 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $10;
    __ZN9JSContext5free_EPv(undef, $13);
    __label__ = 5;
    break;
   case 5:
    var $15 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev($15);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __Z8js_fgetsPciP7__sFILE($buf, $size, $file) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $size - 1 | 0;
    if (($1 | 0) < 0) {
      var $_0 = -1;
      __label__ = 10;
      break;
    } else {
      var $crflag_0 = 0;
      var $i_0 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_0;
    var $crflag_0;
    if (($i_0 | 0) < ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_1 = $i_0;
      __label__ = 9;
      break;
    }
   case 3:
    var $5 = _getc_unlocked($file);
    if (($5 | 0) == -1) {
      var $i_1 = $i_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$buf + $i_0 | 0] = $5 & 255;
    if (($5 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $i_1 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 6:
    if (($crflag_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = _ungetc($5, $file);
    var $i_1 = $i_0;
    __label__ = 9;
    break;
   case 8:
    var $crflag_0 = ($5 | 0) == 13 & 1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $i_1;
    HEAP8[$buf + $i_1 | 0] = 0;
    var $_0 = $i_1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream7getCharEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 156 | 0;
    var $2 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($1);
    var $5 = $4 & 65535;
    if (HEAP8[$this + 392 + ($5 & 255) | 0] << 24 >> 24 == 0) {
      var $_0 = $5;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($4 << 16 >> 16 == 13) {
      __label__ = 4;
      break;
    } else if ($4 << 16 >> 16 == 10) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($1);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $14 = __ZN2js11TokenStream8TokenBuf12matchRawCharEt($1, 10);
    __label__ = 8;
    break;
   case 6:
    if (($4 - 8232 & 65535 & 65535) < 2) {
      __label__ = 8;
      break;
    } else {
      var $_0 = $5;
      __label__ = 9;
      break;
    }
   case 7:
    var $18 = $this + 144 | 0;
    var $20 = HEAP32[$18 >> 2] | 2;
    HEAP32[$18 >> 2] = $20;
    var $_0 = -1;
    __label__ = 9;
    break;
   case 8:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    var $_0 = 10;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == 8232 || ($c | 0) == 13 || ($c | 0) == 10 || ($c | 0) == 8233) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 2 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js11TokenStream8TokenBuf7atStartEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this >> 2] | 0);
}

function __ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 8 | 0;
    var $3 = HEAP32[$1 >> 2] - 2 | 0;
    if (HEAP16[$3 >> 1] << 16 >> 16 == $c << 16 >> 16) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream12isStrictModeEv($this) {
  return (HEAP32[$this + 144 >> 2] & 64 | 0) != 0;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($this, $incr) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - $incr | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 1) | 0;
}

function __ZN2js11TokenStream20updateLineInfoForEOLEv($this) {
  var $1 = $this + 148 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$this + 152 >> 2] = $2;
  var $4 = $this + 156 | 0;
  var $5 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($4);
  HEAP32[$1 >> 2] = $5;
  var $6 = $this + 140 | 0;
  var $8 = HEAP32[$6 >> 2] + 1 | 0;
  HEAP32[$6 >> 2] = $8;
  return;
}

function __ZN2js11TokenStream16getCharIgnoreEOLEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 156 | 0;
    var $2 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($1);
    var $_0 = $4 & 65535;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 144 | 0;
    var $9 = HEAP32[$7 >> 2] | 2;
    HEAP32[$7 >> 2] = $9;
    var $_0 = -1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream9ungetCharEi($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($3);
    if (($c | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = __ZNK2js11TokenStream8TokenBuf7atStartEv($3);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt($3, 13);
    __label__ = 5;
    break;
   case 5:
    var $10 = $this + 152 | 0;
    var $11 = HEAP32[$10 >> 2];
    HEAP32[$this + 148 >> 2] = $11;
    HEAP32[$10 >> 2] = 0;
    var $13 = $this + 140 | 0;
    var $15 = HEAP32[$13 >> 2] - 1 | 0;
    HEAP32[$13 >> 2] = $15;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c | 0) == -1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $this + 156 | 0;
    __ZN2js11TokenStream8TokenBuf12ungetRawCharEv($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream9peekCharsEiPt($this, $n, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) < ($n | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($i_0 | 0) > 0) {
      var $j_02_in = $i_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $5 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($5 | 0) == -1) {
      __label__ = 3;
      break;
    } else if (($5 | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, 10);
    __label__ = 3;
    break;
   case 6:
    HEAP16[$cp + ($i_0 << 1) >> 1] = $5 & 65535;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 7:
    var $j_02_in;
    var $j_02 = $j_02_in - 1 | 0;
    var $13 = HEAPU16[$cp + ($j_02 << 1) >> 1] & 65535;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $13);
    if (($j_02 | 0) > 0) {
      var $j_02_in = $j_02;
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    return ($i_0 | 0) == ($n | 0);
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf7findEOLEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$this + 4 >> 2];
    var $tmp_0 = HEAP32[$this + 8 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $tmp_0;
    if ($tmp_0 >>> 0 < $4 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $tmp_1 = $tmp_0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $tmp_0 + 2 | 0;
    var $10 = HEAPU16[$tmp_0 >> 1] & 65535;
    var $11 = __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($10);
    if ($11) {
      var $tmp_1 = $8;
      __label__ = 4;
      break;
    } else {
      var $tmp_0 = $8;
      __label__ = 2;
      break;
    }
   case 4:
    var $tmp_1;
    return $tmp_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($this, $pn, $flags, $errorNumber, $ap) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $report = __stackBase__;
    var $message = __stackBase__ + 40;
    if (($flags & 4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$this >> 2];
    var $6 = __ZNK9JSContext15hasStrictOptionEv($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 34;
      break;
    }
   case 3:
    var $8 = $flags & 255 & 1;
    var $_pre = HEAP32[$this >> 2];
    if (($flags & 1 | 0) == 0) {
      var $_01 = $flags;
      var $warning_0 = $8;
      var $15 = $_pre;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $flags & -2;
    var $13 = __ZNK9JSContext15hasWErrorOptionEv($_pre);
    var $_flags = $13 ? $12 : $flags;
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $_flags;
      var $warning_0 = $8;
      var $15 = $_pre;
      __label__ = 6;
      break;
    }
   case 5:
    var $_01 = $_flags;
    var $warning_0 = 0;
    var $15 = $_pre;
    __label__ = 6;
    break;
   case 6:
    var $15;
    var $warning_0;
    var $_01;
    __ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601($report);
    HEAP32[$report + 24 >> 2] = $_01;
    HEAP32[$report + 28 >> 2] = $errorNumber;
    HEAP32[$message >> 2] = 0;
    var $18 = $this | 0;
    var $20 = ($_01 & 256 | 0) != 0;
    var $22 = __Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_($15, 2, 0, $errorNumber, $message, $report, $20 ^ 1, $ap);
    if (($22 | 0) == 0) {
      var $warning_134 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = HEAP32[$this + 172 >> 2];
    HEAP32[$report >> 2] = $26;
    if (($pn | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $35 = $pn + 4 | 0;
    __label__ = 10;
    break;
   case 9:
    var $32 = __ZNK2js11TokenStream12currentTokenEv($this);
    var $35 = $32 + 4 | 0;
    __label__ = 10;
    break;
   case 10:
    var $35;
    var $37 = HEAP32[$35 + 4 >> 2];
    HEAP32[$report + 4 >> 2] = $37;
    if (($37 | 0) == (HEAP32[$this + 140 >> 2] | 0)) {
      __label__ = 11;
      break;
    } else {
      var $linebytes_0 = 0;
      var $linechars_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $43 = $this + 156 | 0;
    var $44 = __ZN2js11TokenStream8TokenBuf7findEOLEv($43);
    var $45 = $this + 148 | 0;
    var $49 = $44 - HEAP32[$45 >> 2] | 0;
    var $50 = $49 >> 1;
    var $51 = HEAP32[$18 >> 2];
    var $52 = $49 + 2 | 0;
    var $53 = __ZN9JSContext7malloc_Ej($51, $52);
    var $54 = $53;
    if (($53 | 0) == 0) {
      var $linechars_12 = $54;
      var $warning_13 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $58 = HEAP32[$45 >> 2];
    _memcpy($53, $58, $49, 1);
    HEAP16[$54 + ($50 << 1) >> 1] = 0;
    var $61 = HEAP32[$18 >> 2];
    var $62 = __ZN2js13DeflateStringEP9JSContextPKtj($61, $54, $50);
    if (($62 | 0) == 0) {
      var $linechars_12 = $54;
      var $warning_13 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$report + 8 >> 2] = $62;
    HEAP32[$report + 16 >> 2] = $54;
    var $67 = $35 | 0;
    var $69 = $62 + HEAP32[$67 >> 2] | 0;
    HEAP32[$report + 12 >> 2] = $69;
    var $72 = $54 + (HEAP32[$67 >> 2] << 1) | 0;
    HEAP32[$report + 20 >> 2] = $72;
    var $linebytes_0 = $62;
    var $linechars_0 = $54;
    __label__ = 14;
    break;
   case 14:
    var $linechars_0;
    var $linebytes_0;
    var $76 = HEAP32[$message >> 2];
    var $77 = HEAP32[$18 >> 2];
    var $78 = $report;
    var $79 = __Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_($77, $76, $78, 0, 0);
    if (($79 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 15:
    var $82 = HEAP32[$18 >> 2];
    var $84 = HEAP32[$82 + 200 >> 2];
    var $86 = HEAP32[$84 + 64 >> 2];
    if (($86 | 0) == 0) {
      var $93 = $82;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $90 = HEAP32[$84 + 68 >> 2];
    var $91 = FUNCTION_TABLE[$86]($82, $76, $report, $90);
    if (($91 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $93 = HEAP32[$18 >> 2];
    __label__ = 18;
    break;
   case 18:
    var $93;
    var $95 = HEAP32[$93 + 180 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    FUNCTION_TABLE[$95]($93, $76, $report);
    __label__ = 20;
    break;
   case 20:
    if (($linebytes_0 | 0) == 0) {
      var $linechars_12 = $linechars_0;
      var $warning_13 = $warning_0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    __ZN9JSContext5free_EPv(undef, $linebytes_0);
    var $linechars_12 = $linechars_0;
    var $warning_13 = $warning_0;
    __label__ = 22;
    break;
   case 22:
    var $warning_13;
    var $linechars_12;
    if (($linechars_12 | 0) == 0) {
      var $warning_134 = $warning_13;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN9JSContext5free_EPv(undef, $linechars_12);
    var $warning_134 = $warning_13;
    __label__ = 24;
    break;
   case 24:
    var $warning_134;
    var $104 = HEAP32[$message >> 2];
    if (($104 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    __ZN9JSContext5free_EPv(undef, $104);
    __label__ = 26;
    break;
   case 26:
    var $109 = HEAP32[$report + 32 >> 2];
    if (($109 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $112 = $109;
    __ZN9JSContext5free_EPv(undef, $112);
    __label__ = 28;
    break;
   case 28:
    var $114 = $report + 36 | 0;
    var $115 = HEAP32[$114 >> 2];
    if (($115 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ($20) {
      var $127 = $115;
      __label__ = 32;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $118 = HEAP32[$115 >> 2];
    if (($118 | 0) == 0) {
      var $127 = $115;
      __label__ = 32;
      break;
    } else {
      var $i_05 = 0;
      var $120 = $118;
      __label__ = 31;
      break;
    }
   case 31:
    var $120;
    var $i_05;
    var $121 = $i_05 + 1 | 0;
    __ZN9JSContext5free_EPv(undef, $120);
    var $123 = HEAP32[$114 >> 2];
    var $125 = HEAP32[$123 + ($121 << 2) >> 2];
    if (($125 | 0) == 0) {
      var $127 = $123;
      __label__ = 32;
      break;
    } else {
      var $i_05 = $121;
      var $120 = $125;
      __label__ = 31;
      break;
    }
   case 32:
    var $127;
    __ZN9JSContext5free_EPv(undef, $127);
    __label__ = 33;
    break;
   case 33:
    var $_0 = ($warning_134 & 1) << 24 >> 24 != 0;
    __label__ = 34;
    break;
   case 34:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc["X"] = 1;

function __ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601($t) {
  var $1 = $t;
  _memset($1, 0, 40, 1);
  return;
}

function __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($cx, $ts, $tc, $pn, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ap = __stackBase__;
    if (($ts | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js11TokenStream12isStrictModeEv($ts);
    if ($3) {
      var $flags_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($tc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$tc >> 2] & 262144 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $flags_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK9JSContext15hasStrictOptionEv($cx);
    if ($12) {
      var $flags_0 = 1;
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $flags_0;
    HEAP32[$ap >> 2] = arguments[__ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz.length];
    var $15 = HEAP32[$ap >> 2];
    var $16 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($ts, $pn, $flags_0, $errorNumber, $15);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz($cx, $ts, $pn, $flags, $errorNumber) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $ap = __stackBase__;
  HEAP32[$ap >> 2] = arguments[__ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz.length];
  var $2 = HEAP32[$ap >> 2];
  var $3 = __ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc($ts, $pn, $flags, $errorNumber, $2);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js11TokenStream12getXMLEntityEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 184 | 0;
    var $2 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($1);
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_($1, 38);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 39;
      break;
    }
   case 2:
    var $4 = __ZN2js11TokenStream7getCharEv($this);
    if (($4 | 0) == -1 || ($4 | 0) == 10) {
      __label__ = 3;
      break;
    } else if (($4 | 0) == 59) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 191, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 39;
    break;
   case 4:
    var $8 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($1, $4);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 39;
      break;
    }
   case 5:
    var $10 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($1);
    var $11 = $10 - $2 | 0;
    var $12 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($1);
    var $13 = $12 + ($2 << 1) | 0;
    if (($11 | 0) > 2) {
      __label__ = 6;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 6:
    var $16 = $12 + ($2 + 1 << 1) | 0;
    if (HEAP16[$16 >> 1] << 16 >> 16 == 35) {
      __label__ = 7;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 7:
    if (($11 | 0) > 3) {
      __label__ = 8;
      break;
    } else {
      var $i_1 = 2;
      var $c_1 = 0;
      __label__ = 16;
      break;
    }
   case 8:
    var $23 = HEAP16[$12 + ($2 + 2 << 1) >> 1];
    if ($23 << 16 >> 16 == 120 || $23 << 16 >> 16 == 88) {
      __label__ = 9;
      break;
    } else {
      var $i_1 = 2;
      var $c_1 = 0;
      __label__ = 16;
      break;
    }
   case 9:
    if (($11 | 0) > 9) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      var $i_0 = 3;
      var $c_0 = 0;
      __label__ = 10;
      break;
    }
   case 10:
    var $c_0;
    var $i_0;
    if (($i_0 | 0) < ($11 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $c_2 = $c_0;
      __label__ = 19;
      break;
    }
   case 11:
    var $29 = HEAPU16[$12 + ($i_0 + $2 << 1) >> 1];
    var $30 = $29 & 65535;
    if (($29 & 65535) < 128) {
      __label__ = 12;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 12:
    var $33 = _isxdigit($30);
    if (($33 | 0) == 0) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = $c_0 << 4;
    var $37 = $30 - 48 | 0;
    if ($37 >>> 0 < 10) {
      var $43 = $37;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $40 = _tolower($30);
    var $43 = $40 - 87 | 0;
    __label__ = 15;
    break;
   case 15:
    var $43;
    var $i_0 = $i_0 + 1 | 0;
    var $c_0 = $43 + $36 | 0;
    __label__ = 10;
    break;
   case 16:
    var $c_1;
    var $i_1;
    if (($i_1 | 0) < ($11 | 0)) {
      __label__ = 17;
      break;
    } else {
      var $c_2 = $c_1;
      __label__ = 19;
      break;
    }
   case 17:
    var $49 = HEAPU16[$12 + ($i_1 + $2 << 1) >> 1] & 65535;
    if (($49 - 48 | 0) >>> 0 < 10) {
      __label__ = 18;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 18:
    var $56 = $c_1 * 10 - 48 + $49 | 0;
    if (($56 | 0) < 0) {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    } else {
      var $i_1 = $i_1 + 1 | 0;
      var $c_1 = $56;
      __label__ = 16;
      break;
    }
   case 19:
    var $c_2;
    if (($c_2 - 65536 | 0) >>> 0 < 1048576) {
      __label__ = 35;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($c_2 | 0) == 13 | ($c_2 - 9 | 0) >>> 0 < 2 | ($c_2 - 32 | 0) >>> 0 < 55264 | ($c_2 - 57344 | 0) >>> 0 < 8190) {
      var $c_4_ph = $c_2;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 196;
      __label__ = 37;
      break;
    }
   case 21:
    if (($11 | 0) == 3) {
      __label__ = 22;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 25;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 28;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 22:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 116) {
      __label__ = 23;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 23:
    var $69 = HEAP16[$12 + ($2 + 1 << 1) >> 1];
    if ($69 << 16 >> 16 == 108) {
      var $c_4_ph = 60;
      __label__ = 34;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ($69 << 16 >> 16 == 103) {
      var $c_4_ph = 62;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 25:
    if (HEAP16[$12 + ($2 + 1 << 1) >> 1] << 16 >> 16 == 97) {
      __label__ = 26;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 26:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 109) {
      __label__ = 27;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 27:
    if (HEAP16[$12 + ($2 + 3 << 1) >> 1] << 16 >> 16 == 112) {
      var $c_4_ph = 38;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 28:
    if (HEAP16[$12 + ($2 + 3 << 1) >> 1] << 16 >> 16 == 111) {
      __label__ = 29;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 29:
    var $91 = HEAP16[$12 + ($2 + 1 << 1) >> 1];
    if ($91 << 16 >> 16 == 97) {
      __label__ = 30;
      break;
    } else if ($91 << 16 >> 16 == 113) {
      __label__ = 32;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 30:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 112) {
      __label__ = 31;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 31:
    if (HEAP16[$12 + ($2 + 4 << 1) >> 1] << 16 >> 16 == 115) {
      var $c_4_ph = 39;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 32:
    if (HEAP16[$12 + ($2 + 2 << 1) >> 1] << 16 >> 16 == 117) {
      __label__ = 33;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 33:
    if (HEAP16[$12 + ($2 + 4 << 1) >> 1] << 16 >> 16 == 116) {
      var $c_4_ph = 34;
      __label__ = 34;
      break;
    } else {
      var $msg_0 = 195;
      __label__ = 37;
      break;
    }
   case 34:
    var $c_4_ph;
    var $_sum1240 = $2 + 1 | 0;
    HEAP16[$13 >> 1] = $c_4_ph & 65535;
    var $_sum13_pn = $_sum1240;
    __label__ = 36;
    break;
   case 35:
    HEAP16[$13 >> 1] = ($c_2 >>> 10) + 55232 & 65535;
    var $_sum13 = $2 + 2 | 0;
    HEAP16[$16 >> 1] = ($c_2 & 1023 | 56320) & 65535;
    var $_sum13_pn = $_sum13;
    __label__ = 36;
    break;
   case 36:
    var $_sum13_pn;
    var $bp_0 = $12 + ($_sum13_pn << 1) | 0;
    var $116 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($1);
    var $120 = $116 - $bp_0 >> 1;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($1, $120);
    var $_0 = 1;
    __label__ = 39;
    break;
   case 37:
    var $msg_0;
    var $122 = HEAP32[$this >> 2];
    var $123 = $12 + ($2 + 1 << 1) | 0;
    var $124 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv($1);
    var $129 = ($124 - $13 >> 1) - 1 | 0;
    var $130 = $122;
    var $131 = __ZN2js13DeflateStringEP9JSContextPKtj($130, $123, $129);
    if (($131 | 0) == 0) {
      var $_0 = 0;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $134 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, $msg_0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $131, tempInt));
    __ZN9JSContext5free_EPv(undef, $131);
    var $_0 = 0;
    __label__ = 39;
    break;
   case 39:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream12getXMLEntityEv["X"] = 1;

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode10IsXMLSpaceEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 32 || $ch << 16 >> 16 == 9 || $ch << 16 >> 16 == 13 || $ch << 16 >> 16 == 10) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE($this, $ttp, $tpp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 144 | 0;
    var $4 = (HEAP32[$1 >> 2] & 1024 | 0) == 0;
    var $5 = __ZN2js11TokenStream8newTokenEi($this, 0);
    if ($4) {
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($7);
    var $10 = (HEAP32[$1 >> 2] & 2048 | 0) != 0;
    var $11 = $10 ? 60 : 123;
    var $tt_0 = 65;
    __label__ = 3;
    break;
   case 3:
    var $tt_0;
    var $12 = __ZN2js11TokenStream7getCharEv($this);
    if (($12 | 0) == ($11 | 0) | ($12 | 0) == 60) {
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($12 | 0) == 38) {
      __label__ = 5;
      break;
    } else if (($12 | 0) == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZN2js11TokenStream12getXMLEntityEv($this);
    if ($18) {
      var $tt_0 = 66;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 7:
    var $20 = $12 & 65535;
    var $21 = __ZN2js7unicode10IsXMLSpaceEt($20);
    var $tt_1 = $21 ? $tt_0 : 66;
    var $22 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($7, $12);
    if ($22) {
      var $tt_0 = $tt_1;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 8:
    __ZN2js11TokenStream9ungetCharEi($this, $12);
    var $23 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($7);
    if ($23) {
      var $atom_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = HEAP32[$this >> 2];
    var $27 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($26, $7);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      var $atom_0 = $27;
      __label__ = 10;
      break;
    }
   case 10:
    var $atom_0;
    var $31 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $31;
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $atom_0;
    var $_0 = 1;
    var $storemerge1 = $tt_0;
    __label__ = 43;
    break;
   case 11:
    var $36 = __ZN2js11TokenStream7getCharEv($this);
    if (($36 | 0) == -1) {
      var $_0 = 1;
      var $storemerge1 = 0;
      __label__ = 43;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = $36 & 65535;
    var $39 = __ZN2js7unicode10IsXMLSpaceEt($38);
    if ($39) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $40 = __ZN2js11TokenStream7getCharEv($this);
    if (($40 | 0) == -1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = $40 & 65535;
    var $44 = __ZN2js7unicode10IsXMLSpaceEt($43);
    if ($44) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN2js11TokenStream9ungetCharEi($this, $40);
    var $47 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $47;
    var $_0 = 1;
    var $storemerge1 = 65;
    __label__ = 43;
    break;
   case 16:
    var $50 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($50);
    var $51 = __ZN2js7unicode19IsXMLNamespaceStartEt($38);
    if ($51) {
      __label__ = 17;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    var $53 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $36);
    if ($53) {
      var $sawColon_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 18:
    var $sawColon_0;
    var $54 = __ZN2js11TokenStream7getCharEv($this);
    if (($54 | 0) == -1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $57 = $54 & 65535;
    var $58 = __ZN2js7unicode13IsXMLNamePartEt($57);
    if ($58) {
      __label__ = 20;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 20:
    if (($54 | 0) == 58) {
      __label__ = 21;
      break;
    } else {
      var $sawColon_1 = $sawColon_0;
      __label__ = 25;
      break;
    }
   case 21:
    if (($sawColon_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $64 = __ZN2js11TokenStream8peekCharEv($this);
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0 & ($64 | 0) == 123) {
      var $sawColon_1 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $70 = $64 & 65535;
    var $71 = __ZN2js7unicode13IsXMLNamePartEt($70);
    if ($71) {
      var $sawColon_1 = 1;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $73 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 192, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 25:
    var $sawColon_1;
    var $74 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $54);
    if ($74) {
      var $sawColon_0 = $sawColon_1;
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 26:
    __ZN2js11TokenStream9ungetCharEi($this, $54);
    var $76 = HEAP32[$this >> 2];
    var $77 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($76, $50);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $77;
    var $_0 = 1;
    var $storemerge1 = 63;
    __label__ = 43;
    break;
   case 28:
    if (($36 | 0) == 123) {
      __label__ = 29;
      break;
    } else if (($36 | 0) == 34 || ($36 | 0) == 39) {
      __label__ = 30;
      break;
    } else if (($36 | 0) == 62) {
      __label__ = 40;
      break;
    } else if (($36 | 0) == 47) {
      __label__ = 41;
      break;
    } else if (($36 | 0) == 61) {
      var $_0 = 1;
      var $storemerge1 = 4;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 29:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      var $_0 = 1;
      var $storemerge1 = 25;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 30:
    var $87 = __ZN2js11TokenStream7getCharEv($this);
    if (($87 | 0) == ($36 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if (($87 | 0) == -1) {
      __label__ = 32;
      break;
    } else if (($87 | 0) == 34) {
      __label__ = 33;
      break;
    } else if (($87 | 0) == 38) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 32:
    var $91 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 138, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 33:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 34:
    var $97 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j($50, STRING_TABLE._js_quot_entity_str | 0, 6);
    if ($97) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 35:
    if ((HEAP32[$1 >> 2] & 2048 | 0) == 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $103 = __ZN2js11TokenStream12getXMLEntityEv($this);
    if ($103) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 37:
    var $105 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($50, $87);
    if ($105) {
      __label__ = 30;
      break;
    } else {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    }
   case 38:
    var $108 = HEAP32[$this >> 2];
    var $109 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($108, $50);
    if (($109 | 0) == 0) {
      var $_0 = 0;
      var $storemerge1 = -1;
      __label__ = 43;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $113 = HEAP32[$this + 140 >> 2];
    HEAP32[$5 + 16 >> 2] = $113;
    HEAP32[$5 + 24 >> 2] = 61;
    HEAP32[$5 + 28 >> 2] = $109;
    var $_0 = 1;
    var $storemerge1 = 64;
    __label__ = 43;
    break;
   case 40:
    var $_0 = 1;
    var $storemerge1 = 62;
    __label__ = 43;
    break;
   case 41:
    var $119 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($119) {
      var $_0 = 1;
      var $storemerge1 = 61;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $121 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 171, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge1 = -1;
    __label__ = 43;
    break;
   case 43:
    var $storemerge1;
    var $_0;
    HEAP32[$ttp >> 2] = $storemerge1;
    HEAP32[$tpp >> 2] = $5;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE["X"] = 1;

function __ZN2js11TokenStream8newTokenEi($this, $adjust) {
  var $1 = $this + 132 | 0;
  var $4 = HEAP32[$1 >> 2] + 1 & 3;
  HEAP32[$1 >> 2] = $4;
  var $5 = $this + 4 + ($4 << 5) | 0;
  var $6 = $this + 156 | 0;
  var $7 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($6);
  var $8 = $7 + ($adjust << 1) | 0;
  var $9 = $this + 4 + ($4 << 5) + 20 | 0;
  HEAP32[$9 >> 2] = $8;
  var $15 = $8 - HEAP32[$this + 148 >> 2] >> 1;
  var $16 = $this + 4 + ($4 << 5) + 4 | 0;
  HEAP32[$16 >> 2] = $15;
  var $18 = HEAP32[$this + 140 >> 2];
  var $19 = $this + 4 + ($4 << 5) + 16 | 0;
  HEAP32[$19 >> 2] = $18;
  var $20 = $this + 4 + ($4 << 5) + 8 | 0;
  HEAP32[$20 >> 2] = $18;
  return $5;
}

function __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($cx, $cb) {
  var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($cb);
  var $2 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($cb);
  var $3 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($cx, $1, $2, 0);
  return $3;
}

function __ZN2js7unicode19IsXMLNamespaceStartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 95) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZN2js7unicode8CharInfoEt($ch);
    var $4 = __ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv($3);
    if ($4) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js7unicode17IsIdentifierStartEt($ch);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode13IsXMLNamePartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 46 || $ch << 16 >> 16 == 45 || $ch << 16 >> 16 == 95 || $ch << 16 >> 16 == 58) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js7unicode8CharInfoEt($ch);
    var $3 = __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($2);
    if ($3) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($ch);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8peekCharEv($this) {
  var $1 = __ZN2js11TokenStream7getCharEv($this);
  __ZN2js11TokenStream9ungetCharEi($this, $1);
  return $1;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j($this, $insBegin, $length) {
  var $1 = $insBegin + $length | 0;
  var $2 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_($this, $insBegin, $1);
  return $2;
}

function __ZN2js11TokenStream9matchCharEi($this, $expect) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream7getCharEv($this);
    if (($1 | 0) == ($expect | 0)) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js11TokenStream9ungetCharEi($this, $1);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE($this, $ttp, $tpp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = HEAP32[$tpp >> 2];
    var $2 = __ZN2js11TokenStream9matchCharEi($this, 33);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 2:
    var $4 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($4);
    var $5 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 3:
    var $7 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 4:
    var $8 = __ZN2js11TokenStream7getCharEv($this);
    if (($8 | 0) == 45) {
      __label__ = 5;
      break;
    } else if (($8 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($4, $8);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 7:
    var $13 = $1 + 24 | 0;
    HEAP32[$13 >> 2] = 184;
    var $tt_0 = 67;
    __label__ = 41;
    break;
   case 8:
    var $15 = __ZN2js11TokenStream9matchCharEi($this, 91);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $17 = $cp | 0;
    var $18 = __ZN2js11TokenStream9peekCharsEiPt($this, 6, $17);
    if ($18 & HEAP16[$17 >> 1] << 16 >> 16 == 67) {
      __label__ = 10;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 10:
    var $22 = $cp + 2 | 0;
    if (HEAP16[$22 >> 1] << 16 >> 16 == 68) {
      __label__ = 11;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 11:
    if (HEAP16[$cp + 4 >> 1] << 16 >> 16 == 65) {
      __label__ = 12;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 12:
    if (HEAP16[$cp + 6 >> 1] << 16 >> 16 == 84) {
      __label__ = 13;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 13:
    if (HEAP16[$cp + 8 >> 1] << 16 >> 16 == 65) {
      __label__ = 14;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 14:
    if (HEAP16[$cp + 10 >> 1] << 16 >> 16 == 91) {
      __label__ = 15;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 15:
    __ZN2js11TokenStream9skipCharsEi($this, 6);
    __label__ = 16;
    break;
   case 16:
    var $43 = __ZN2js11TokenStream7getCharEv($this);
    if (($43 | 0) == 93) {
      __label__ = 17;
      break;
    } else if (($43 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $45 = __ZN2js11TokenStream9peekCharsEiPt($this, 2, $17);
    if ($45 & HEAP16[$17 >> 1] << 16 >> 16 == 93) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    if (HEAP16[$22 >> 1] << 16 >> 16 == 62) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $51 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($4, $43);
    if ($51) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 20:
    var $53 = __ZN2js11TokenStream7getCharEv($this);
    var $54 = $1 + 24 | 0;
    HEAP32[$54 >> 2] = 183;
    var $tt_0 = 68;
    __label__ = 41;
    break;
   case 21:
    var $56 = __ZN2js11TokenStream9matchCharEi($this, 63);
    if ($56) {
      __label__ = 22;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 22:
    var $58 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($58);
    var $contentIndex_0 = -1;
    var $targetLength_0 = 0;
    var $inTarget_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $inTarget_0;
    var $targetLength_0;
    var $contentIndex_0;
    var $60 = __ZN2js11TokenStream7getCharEv($this);
    if (($60 | 0) == 63) {
      __label__ = 24;
      break;
    } else if (($60 | 0) == -1) {
      __label__ = 45;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $62 = __ZN2js11TokenStream8peekCharEv($this);
    if (($62 | 0) == 62) {
      __label__ = 36;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($inTarget_0 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $66 = $60 & 65535;
    var $67 = __ZN2js7unicode10IsXMLSpaceEt($66);
    var $68 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($58);
    if ($67) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    if ($68) {
      __label__ = 45;
      break;
    } else {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    }
   case 28:
    if ($68) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    var $72 = __ZN2js7unicode19IsXMLNamespaceStartEt($66);
    if ($72) {
      __label__ = 31;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 30:
    var $74 = __ZN2js7unicode18IsXMLNamespacePartEt($66);
    if ($74) {
      __label__ = 31;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 31:
    var $contentIndex_1 = $contentIndex_0;
    var $targetLength_1 = $targetLength_0 + 1 | 0;
    var $inTarget_1 = $inTarget_0;
    __label__ = 35;
    break;
   case 32:
    if (($contentIndex_0 | 0) < 0) {
      __label__ = 33;
      break;
    } else {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    }
   case 33:
    var $80 = $60 & 65535;
    var $81 = __ZN2js7unicode10IsXMLSpaceEt($80);
    if ($81) {
      var $contentIndex_1 = $contentIndex_0;
      var $targetLength_1 = $targetLength_0;
      var $inTarget_1 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $83 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($58);
    var $contentIndex_1 = $83;
    var $targetLength_1 = $targetLength_0;
    var $inTarget_1 = $inTarget_0;
    __label__ = 35;
    break;
   case 35:
    var $inTarget_1;
    var $targetLength_1;
    var $contentIndex_1;
    var $85 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($58, $60);
    if ($85) {
      var $contentIndex_0 = $contentIndex_1;
      var $targetLength_0 = $targetLength_1;
      var $inTarget_0 = $inTarget_1;
      __label__ = 23;
      break;
    } else {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    }
   case 36:
    if (($targetLength_0 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $91 = HEAP32[$this >> 2];
    if (($contentIndex_0 | 0) < 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 38:
    var $atom_0 = HEAP32[HEAP32[$91 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 40;
    break;
   case 39:
    var $99 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($58);
    var $100 = $99 + ($contentIndex_0 << 1) | 0;
    var $101 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($58);
    var $102 = $101 - $contentIndex_0 | 0;
    var $103 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($91, $100, $102, 0);
    if (($103 | 0) == 0) {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    } else {
      var $atom_0 = $103;
      __label__ = 40;
      break;
    }
   case 40:
    var $atom_0;
    var $106 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($58);
    var $107 = $106 - $targetLength_0 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj($58, $107);
    var $108 = $1 + 24 | 0;
    HEAP32[$108 >> 2] = $atom_0;
    var $tt_0 = 69;
    __label__ = 41;
    break;
   case 41:
    var $tt_0;
    var $110 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($110) {
      __label__ = 42;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 42:
    var $113 = HEAP32[$this >> 2];
    var $114 = $this + 184 | 0;
    var $115 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($113, $114);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      var $storemerge = -1;
      __label__ = 46;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $118 = $1 + 28 | 0;
    HEAP32[$118 >> 2] = $115;
    var $120 = HEAP32[$this + 140 >> 2];
    var $121 = $1 + 16 | 0;
    HEAP32[$121 >> 2] = $120;
    var $_0 = 1;
    var $storemerge = $tt_0;
    __label__ = 46;
    break;
   case 44:
    var $123 = __ZN2js11TokenStream9matchCharEi($this, 47);
    var $124 = $123 ? 60 : 59;
    var $_0 = 1;
    var $storemerge = $124;
    __label__ = 46;
    break;
   case 45:
    var $125 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    var $storemerge = -1;
    __label__ = 46;
    break;
   case 46:
    var $storemerge;
    var $_0;
    HEAP32[$ttp >> 2] = $storemerge;
    HEAP32[$tpp >> 2] = $1;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE["X"] = 1;

function __ZN2js11TokenStream9skipCharsEi($this, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($n | 0) > 0) {
      var $_01 = $n;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $2 = $_01 - 1 | 0;
    var $3 = __ZN2js11TokenStream7getCharEv($this);
    if (($2 | 0) > 0) {
      var $_01 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode18IsXMLNamespacePartEt($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ch << 16 >> 16 == 46 || $ch << 16 >> 16 == 45 || $ch << 16 >> 16 == 95) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = __ZN2js7unicode8CharInfoEt($ch);
    var $3 = __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($2);
    if ($3) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($ch);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cp = __stackBase__;
    var $1 = $cp | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 5, $1);
    if ($2 & HEAP16[$1 >> 1] << 16 >> 16 == 117) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 2:
    var $7 = HEAPU16[$cp + 2 >> 1];
    if (($7 & 65535) < 128) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 3:
    var $10 = $7 & 65535;
    var $11 = _isxdigit($10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAPU16[$cp + 4 >> 1];
    if (($15 & 65535) < 128) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 5:
    var $18 = $15 & 65535;
    var $19 = _isxdigit($18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAPU16[$cp + 6 >> 1];
    if (($23 & 65535) < 128) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 7:
    var $26 = $23 & 65535;
    var $27 = _isxdigit($26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAPU16[$cp + 8 >> 1];
    if (($31 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 9:
    var $34 = $31 & 65535;
    var $35 = _isxdigit($34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $10 - 48 | 0;
    if ($38 >>> 0 < 10) {
      var $44 = $38;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = _tolower($10);
    var $44 = $41 - 87 | 0;
    __label__ = 12;
    break;
   case 12:
    var $44;
    var $45 = $44 << 4;
    var $46 = $18 - 48 | 0;
    if ($46 >>> 0 < 10) {
      var $52 = $46;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = _tolower($18);
    var $52 = $49 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $52;
    var $54 = $52 + $45 << 4;
    var $55 = $26 - 48 | 0;
    if ($55 >>> 0 < 10) {
      var $61 = $55;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = _tolower($26);
    var $61 = $58 - 87 | 0;
    __label__ = 16;
    break;
   case 16:
    var $61;
    var $63 = $61 + $54 << 4;
    var $64 = $34 - 48 | 0;
    if ($64 >>> 0 < 10) {
      var $70 = $64;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $67 = _tolower($34);
    var $70 = $67 - 87 | 0;
    __label__ = 18;
    break;
   case 18:
    var $70;
    HEAP32[$result >> 2] = $70 + $63 | 0;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream17peekUnicodeEscapeEPi["X"] = 1;

function __ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi($this, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $cp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$cp >> 2] & 65535;
    var $5 = __ZN2js7unicode17IsIdentifierStartEt($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $cp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11TokenStream17peekUnicodeEscapeEPi($this, $cp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$cp >> 2] & 65535;
    var $5 = __ZN2js7unicode16IsIdentifierPartEt($4);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream9getAtLineEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1036;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $filenameBuf = __stackBase__ + 12;
    var $1 = __stackBase__ | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 5, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 2:
    var $4 = __ZL10CharsMatchPKtPKc($1, STRING_TABLE.__str3585 | 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 28;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 5);
    __label__ = 4;
    break;
   case 4:
    var $7 = __ZN2js11TokenStream7getCharEv($this);
    if (($7 | 0) == 10 || ($7 | 0) == -1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = $7 & 65535;
    var $10 = __ZN2js7unicode13IsSpaceOrBOM2Et($9);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = $7 - 48 | 0;
    if ($11 >>> 0 < 10) {
      var $line_0 = $11;
      __label__ = 7;
      break;
    } else {
      var $c_2 = $7;
      __label__ = 27;
      break;
    }
   case 7:
    var $line_0;
    var $14 = __ZN2js11TokenStream7getCharEv($this);
    if (($14 | 0) != -1 & ($14 - 48 | 0) >>> 0 < 10) {
      __label__ = 8;
      break;
    } else {
      var $c_0 = $14;
      __label__ = 9;
      break;
    }
   case 8:
    var $21 = $line_0 * 10 - 48 + $14 | 0;
    if ($21 >>> 0 < $line_0 >>> 0) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      var $line_0 = $21;
      __label__ = 7;
      break;
    }
   case 9:
    var $c_0;
    if (($c_0 | 0) == 10 || ($c_0 | 0) == -1) {
      var $c_1 = $c_0;
      var $i_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = __ZN2js7unicode13IsSpaceOrBOM2Et($c_0 & 65535);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $27 = __ZN2js11TokenStream7getCharEv($this);
    var $c_0 = $27;
    __label__ = 9;
    break;
   case 12:
    if (($c_0 | 0) == 34) {
      var $i_0 = 0;
      __label__ = 13;
      break;
    } else {
      var $c_1 = $c_0;
      var $i_1 = 0;
      __label__ = 20;
      break;
    }
   case 13:
    var $i_0;
    var $29 = __ZN2js11TokenStream7getCharEv($this);
    if (($29 | 0) == -1) {
      __label__ = 14;
      break;
    } else if (($29 | 0) == 10) {
      __label__ = 15;
      break;
    } else if (($29 | 0) == 34) {
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    HEAP8[$filenameBuf + $i_0 | 0] = 0;
    var $i_139 = $i_0;
    var $c_140 = -1;
    __label__ = 21;
    break;
   case 15:
    __ZN2js11TokenStream9ungetCharEi($this, 10);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 16:
    if ($29 >>> 0 > 255 | $i_0 >>> 0 > 1022) {
      var $_0 = 1;
      __label__ = 28;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP8[$filenameBuf + $i_0 | 0] = $29 & 255;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 18:
    var $39 = __ZN2js11TokenStream7getCharEv($this);
    if (($39 | 0) == 10 || ($39 | 0) == -1) {
      var $c_1 = $39;
      var $i_1 = $i_0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $41 = $39 & 65535;
    var $42 = __ZN2js7unicode13IsSpaceOrBOM2Et($41);
    if ($42) {
      __label__ = 18;
      break;
    } else {
      var $c_1 = $39;
      var $i_1 = $i_0;
      __label__ = 20;
      break;
    }
   case 20:
    var $i_1;
    var $c_1;
    HEAP8[$filenameBuf + $i_1 | 0] = 0;
    if (($c_1 | 0) == -1 || ($c_1 | 0) == 10) {
      var $i_139 = $i_1;
      var $c_140 = $c_1;
      __label__ = 21;
      break;
    } else {
      var $c_2 = $c_1;
      __label__ = 27;
      break;
    }
   case 21:
    var $c_140;
    var $i_139;
    if (($i_139 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $47 = $this + 144 | 0;
    var $_pre = $this + 172 | 0;
    if ((HEAP32[$47 >> 2] & 256 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $52 = HEAP32[$_pre >> 2];
    __ZN9JSContext5free_EPv(undef, $52);
    __label__ = 24;
    break;
   case 24:
    var $54 = HEAP32[$this >> 2];
    var $55 = $filenameBuf | 0;
    var $56 = _JS_strdup($54, $55);
    HEAP32[$_pre >> 2] = $56;
    if (($56 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $60 = HEAP32[$47 >> 2] | 256;
    HEAP32[$47 >> 2] = $60;
    __label__ = 26;
    break;
   case 26:
    HEAP32[$this + 140 >> 2] = $line_0;
    var $c_2 = $c_140;
    __label__ = 27;
    break;
   case 27:
    var $c_2;
    __ZN2js11TokenStream9ungetCharEi($this, $c_2);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream9getAtLineEv["X"] = 1;

function __ZL10CharsMatchPKtPKc($p, $q) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $p;
    var $_02 = $q;
    __label__ = 2;
    break;
   case 2:
    var $_02;
    var $_01;
    var $2 = HEAPU8[$_02];
    if ($2 << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAPU16[$_01 >> 1] & 65535 | 0) == ($2 << 24 >> 24 | 0)) {
      var $_01 = $_01 + 2 | 0;
      var $_02 = $_02 + 1 | 0;
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($this, $a) {
  HEAP32[$this + 8 >> 2] = $a;
  return;
}

function __ZN2js7unicode13IsSpaceOrBOM2Et($ch) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ch & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = STRING_TABLE._js_isspace + ($ch & 65535) | 0;
    var $_0 = (HEAP8[$4] & 1) << 24 >> 24 != 0;
    __label__ = 5;
    break;
   case 3:
    if ($ch << 16 >> 16 == 160 || $ch << 16 >> 16 == -2) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN2js7unicode8CharInfoEt($ch);
    var $11 = __ZNK2js7unicode13CharacterInfo7isSpaceEv($10);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream21getAtSourceMappingURLEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__ | 0;
    var $2 = __ZN2js11TokenStream9peekCharsEiPt($this, 18, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 2:
    var $4 = __ZL10CharsMatchPKtPKc($1, STRING_TABLE.__str13586 | 0);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 3:
    __ZN2js11TokenStream9skipCharsEi($this, 18);
    var $6 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($6);
    __label__ = 4;
    break;
   case 4:
    var $8 = __ZN2js11TokenStream7getCharEv($this);
    var $9 = $8 & 65535;
    var $10 = __ZN2js7unicode13IsSpaceOrBOM2Et($9);
    if ($10) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $8 << 24 >> 24;
    if (($12 | 0) == 0 || ($12 | 0) == -1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_($6, $9);
    __label__ = 4;
    break;
   case 7:
    var $15 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv($6);
    if ($15) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($6);
    var $18 = $this + 176 | 0;
    var $19 = HEAP32[$18 >> 2];
    if (($19 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = $19;
    __ZN9JSContext5free_EPv(undef, $22);
    __label__ = 10;
    break;
   case 10:
    var $25 = HEAP32[$this >> 2];
    var $27 = ($17 << 1) + 2 | 0;
    var $28 = __ZN9JSContext7malloc_Ej($25, $27);
    var $29 = $28;
    HEAP32[$18 >> 2] = $29;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if (($17 | 0) > 0) {
      var $i_02 = 0;
      var $32 = $29;
      __label__ = 12;
      break;
    } else {
      var $37 = $29;
      __label__ = 13;
      break;
    }
   case 12:
    var $32;
    var $i_02;
    var $33 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj($6, $i_02);
    var $34 = HEAP16[$33 >> 1];
    HEAP16[$32 + ($i_02 << 1) >> 1] = $34;
    var $36 = $i_02 + 1 | 0;
    var $_pre = HEAP32[$18 >> 2];
    if (($36 | 0) == ($17 | 0)) {
      var $37 = $_pre;
      __label__ = 13;
      break;
    } else {
      var $i_02 = $36;
      var $32 = $_pre;
      __label__ = 12;
      break;
    }
   case 13:
    var $37;
    HEAP16[$37 + ($17 << 1) >> 1] = 0;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream21getAtSourceMappingURLEv["X"] = 1;

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv($this);
  return $1 + ($i << 1) | 0;
}

function __ZN2js11TokenStream18putIdentInTokenbufEPKt($this, $identStart) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $qc = __stackBase__;
    var $1 = $this + 156 | 0;
    var $2 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($1);
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $identStart);
    var $3 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($3);
    __label__ = 2;
    break;
   case 2:
    var $5 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $6 = $5 & 65535;
    var $7 = __ZN2js7unicode16IsIdentifierPartEt($6);
    if ($7) {
      var $c_0 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($5 | 0) == 92) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $11 = __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $qc);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $c_0 = HEAP32[$qc >> 2];
    __label__ = 6;
    break;
   case 6:
    var $c_0;
    var $15 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($3, $c_0);
    if ($15) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $2);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    __ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt($1, $2);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11TokenStream16getTokenInternalEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tt = __stackBase__;
    var $qc = __stackBase__ + 4;
    var $tp = __stackBase__ + 8;
    var $cp = __stackBase__ + 12;
    var $cp1 = __stackBase__ + 20;
    var $dval = __stackBase__ + 24;
    var $dummy = __stackBase__ + 32;
    var $dval3 = __stackBase__ + 36;
    var $dummy4 = __stackBase__ + 44;
    var $buf = __stackBase__ + 48;
    var $buf5 = __stackBase__ + 52;
    var $1 = $this + 144 | 0;
    if ((HEAP32[$1 >> 2] & 1536 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 156 | 0;
    var $6 = $this + 132 | 0;
    var $7 = $this | 0;
    var $8 = $this + 140 | 0;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE($this, $tt, $tp);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 4:
    var $_pre_phi = $this + 156 | 0;
    __label__ = 263;
    break;
   case 5:
    var $11 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($5);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = __ZN2js11TokenStream8newTokenEi($this, 0);
    HEAP32[$tp >> 2] = $13;
    HEAP32[$tt >> 2] = 0;
    var $15 = HEAP32[$1 >> 2] | 2;
    HEAP32[$1 >> 2] = $15;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 7:
    var $17 = __ZN2js11TokenStream8TokenBuf10getRawCharEv($5);
    var $18 = $17 & 65535;
    if (($17 & 65535) > 127) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $21 = __ZN2js7unicode13IsSpaceOrBOM2Et($17);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($17 - 8232 & 65535 & 65535) < 2) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 10:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 5;
    break;
   case 11:
    var $26 = __ZN2js11TokenStream8newTokenEi($this, -1);
    HEAP32[$tp >> 2] = $26;
    var $27 = __ZN2js7unicode8IsLetterEt($17);
    if ($27) {
      __label__ = 12;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 12:
    var $29 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $identStart_0_ph = $29 - 2 | 0;
    var $hadUnicodeEscape_0_ph = 0;
    __label__ = 21;
    break;
   case 13:
    var $32 = STRING_TABLE.__ZL14firstCharKinds + $18 | 0;
    var $33 = HEAPU8[$32];
    if (($33 & 255) > 9) {
      __label__ = 14;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 14:
    if ($17 << 16 >> 16 == 13) {
      __label__ = 15;
      break;
    } else if ($17 << 16 >> 16 == 10) {
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 15:
    var $37 = __ZNK2js11TokenStream8TokenBuf11hasRawCharsEv($5);
    if ($37) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $39 = __ZN2js11TokenStream8TokenBuf12matchRawCharEt($5, 10);
    __label__ = 17;
    break;
   case 17:
    __ZN2js11TokenStream20updateLineInfoForEOLEv($this);
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 5;
    break;
   case 18:
    var $42 = __ZN2js11TokenStream8newTokenEi($this, -1);
    HEAP32[$tp >> 2] = $42;
    if ($33 << 24 >> 24 == 1) {
      __label__ = 19;
      break;
    } else if ($33 << 24 >> 24 == 2) {
      __label__ = 20;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 19:
    HEAP32[$tt >> 2] = HEAP8[$this + ($18 + 264) | 0] << 24 >> 24;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 20:
    var $48 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $identStart_0_ph = $48 - 2 | 0;
    var $hadUnicodeEscape_0_ph = 0;
    __label__ = 21;
    break;
   case 21:
    var $hadUnicodeEscape_0_ph;
    var $identStart_0_ph;
    var $hadUnicodeEscape_0_ph56 = $hadUnicodeEscape_0_ph;
    __label__ = 22;
    break;
   case 22:
    var $hadUnicodeEscape_0_ph56;
    __label__ = 23;
    break;
   case 23:
    var $51 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($51 | 0) == -1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $54 = $51 & 65535;
    var $55 = __ZN2js7unicode16IsIdentifierPartEt($54);
    if ($55) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    if (($51 | 0) == 92) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $59 = __ZN2js11TokenStream23matchUnicodeEscapeIdentEPi($this, $qc);
    if ($59) {
      var $hadUnicodeEscape_0_ph56 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $51);
    if ($hadUnicodeEscape_0_ph56 << 24 >> 24 == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 28:
    if ((HEAP32[$1 >> 2] & 32 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $_pre_phi12 = $identStart_0_ph;
    __label__ = 40;
    break;
   case 30:
    var $66 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $68 = $identStart_0_ph;
    var $70 = $66 - $68 >> 1;
    var $71 = __ZN2js11FindKeywordEPKtj($identStart_0_ph, $70);
    if (($71 | 0) == 0) {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $75 = HEAP32[$71 + 4 >> 2];
    if (($75 | 0) == 86) {
      __label__ = 32;
      break;
    } else if (($75 | 0) == 87) {
      __label__ = 33;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 32:
    var $78 = HEAP32[$71 >> 2];
    var $79 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $78, tempInt));
    if ($79) {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 33:
    var $81 = __ZN2js11TokenStream12isStrictModeEv($this);
    var $83 = HEAP32[$71 >> 2];
    if ($81) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $85 = HEAP32[$7 >> 2];
    var $86 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($85, $this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $83, tempInt));
    if ($86) {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 35:
    var $88 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 5, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $83, tempInt));
    if ($88) {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 36:
    var $91 = HEAP32[$71 + 12 >> 2];
    var $92 = __ZNK2js11TokenStream13versionNumberEv($this);
    if (($91 | 0) > ($92 | 0)) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    HEAP32[$tt >> 2] = $75;
    var $96 = HEAP32[$71 + 8 >> 2];
    var $98 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$98 >> 2] = $96;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 38:
    if (($75 | 0) == 81 || ($75 | 0) == 77) {
      __label__ = 39;
      break;
    } else {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    }
   case 39:
    var $101 = HEAP32[$7 >> 2];
    var $103 = HEAP32[$71 >> 2];
    var $104 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($101, $this, 0, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $103, tempInt));
    if ($104) {
      var $_pre_phi12 = $68;
      __label__ = 40;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 40:
    var $_pre_phi12;
    var $105 = HEAP32[$7 >> 2];
    var $106 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $109 = $106 - $_pre_phi12 >> 1;
    var $110 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($105, $identStart_0_ph, $109, 0);
    var $atom_0 = $110;
    __label__ = 43;
    break;
   case 41:
    var $111 = __ZN2js11TokenStream18putIdentInTokenbufEPKt($this, $identStart_0_ph);
    if ($111) {
      __label__ = 42;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 42:
    var $113 = HEAP32[$7 >> 2];
    var $114 = $this + 184 | 0;
    var $115 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($113, $114);
    var $atom_0 = $115;
    __label__ = 43;
    break;
   case 43:
    var $atom_0;
    if (($atom_0 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $120 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$120 >> 2] = 59;
    var $122 = HEAP32[$tp >> 2] + 28 | 0;
    HEAP32[$122 >> 2] = $atom_0;
    HEAP32[$tt >> 2] = 29;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 45:
    if ($17 << 16 >> 16 == 46) {
      __label__ = 46;
      break;
    } else if ($17 << 16 >> 16 == 61) {
      __label__ = 51;
      break;
    } else if ($17 << 16 >> 16 == 39 || $17 << 16 >> 16 == 34) {
      __label__ = 54;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 46:
    var $125 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($125 - 48 | 0) >>> 0 < 10) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $129 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $numStart_1 = $129 - 4 | 0;
    __label__ = 114;
    break;
   case 48:
    if (($125 | 0) == 46) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    HEAP32[$tt >> 2] = 73;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 50:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $125);
    HEAP32[$tt >> 2] = 22;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 51:
    var $136 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($136) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $138 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $139 = $138 ? 72 : 18;
    var $141 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$141 >> 2] = $139;
    HEAP32[$tt >> 2] = 12;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 53:
    var $144 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$144 >> 2] = 0;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 54:
    HEAP32[$qc >> 2] = $18;
    var $146 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($146);
    var $147 = $cp | 0;
    var $148 = $cp + 2 | 0;
    var $149 = $cp + 4 | 0;
    var $150 = $cp + 6 | 0;
    var $151 = $cp1 | 0;
    var $152 = $cp1 + 2 | 0;
    __label__ = 55;
    break;
   case 55:
    var $153 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (HEAP8[$this + 648 + ($153 & 255) | 0] << 24 >> 24 == 0) {
      var $c_0 = $153;
      __label__ = 106;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (($153 | 0) == ($18 | 0)) {
      __label__ = 107;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    if (($153 | 0) == 92) {
      __label__ = 58;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 58:
    var $163 = __ZN2js11TokenStream7getCharEv($this);
    if (($163 | 0) == 102) {
      __label__ = 59;
      break;
    } else if (($163 | 0) == 110) {
      __label__ = 60;
      break;
    } else if (($163 | 0) == 114) {
      __label__ = 61;
      break;
    } else if (($163 | 0) == 116) {
      __label__ = 62;
      break;
    } else if (($163 | 0) == 118) {
      __label__ = 63;
      break;
    } else if (($163 | 0) == 98) {
      var $c_0 = 8;
      __label__ = 106;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 59:
    var $c_0 = 12;
    __label__ = 106;
    break;
   case 60:
    var $c_0 = 10;
    __label__ = 106;
    break;
   case 61:
    var $c_0 = 13;
    __label__ = 106;
    break;
   case 62:
    var $c_0 = 9;
    __label__ = 106;
    break;
   case 63:
    var $c_0 = 11;
    __label__ = 106;
    break;
   case 64:
    var $_off = $163 - 48 | 0;
    if ($_off >>> 0 < 8) {
      __label__ = 65;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 65:
    var $172 = __ZN2js11TokenStream8peekCharEv($this);
    if (($_off | 0) == 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 66:
    if (($172 - 48 | 0) >>> 0 < 10) {
      __label__ = 67;
      break;
    } else {
      var $val_0 = $_off;
      __label__ = 72;
      break;
    }
   case 67:
    var $178 = HEAP32[$7 >> 2];
    var $179 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($178, $this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($179) {
      __label__ = 68;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 68:
    __ZN2js11TokenStream23setOctalCharacterEscapeEb($this, 1);
    if (($172 - 48 | 0) >>> 0 < 8) {
      __label__ = 69;
      break;
    } else {
      var $val_0 = $_off;
      __label__ = 72;
      break;
    }
   case 69:
    var $185 = ($_off << 3) - 48 + $172 | 0;
    var $186 = __ZN2js11TokenStream7getCharEv($this);
    var $187 = __ZN2js11TokenStream8peekCharEv($this);
    if (($187 - 48 | 0) >>> 0 < 8) {
      __label__ = 70;
      break;
    } else {
      var $val_0 = $185;
      __label__ = 72;
      break;
    }
   case 70:
    var $192 = ($185 << 3) - 48 + $187 | 0;
    if (($192 | 0) < 256) {
      __label__ = 71;
      break;
    } else {
      var $val_0 = $185;
      __label__ = 72;
      break;
    }
   case 71:
    var $195 = __ZN2js11TokenStream7getCharEv($this);
    var $val_0 = $192;
    __label__ = 72;
    break;
   case 72:
    var $val_0;
    var $c_0 = $val_0 & 65535;
    __label__ = 106;
    break;
   case 73:
    if (($163 | 0) == 10) {
      __label__ = 55;
      break;
    } else if (($163 | 0) == 117) {
      __label__ = 74;
      break;
    } else if (($163 | 0) == 120) {
      __label__ = 93;
      break;
    } else {
      var $c_0 = $163;
      __label__ = 106;
      break;
    }
   case 74:
    var $199 = __ZN2js11TokenStream9peekCharsEiPt($this, 4, $147);
    if ($199) {
      __label__ = 75;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 75:
    var $201 = HEAPU16[$147 >> 1];
    if (($201 & 65535) < 128) {
      __label__ = 76;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 76:
    var $204 = $201 & 65535;
    var $205 = _isxdigit($204);
    if (($205 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $208 = HEAPU16[$148 >> 1];
    if (($208 & 65535) < 128) {
      __label__ = 78;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 78:
    var $211 = $208 & 65535;
    var $212 = _isxdigit($211);
    if (($212 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $215 = HEAPU16[$149 >> 1];
    if (($215 & 65535) < 128) {
      __label__ = 80;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 80:
    var $218 = $215 & 65535;
    var $219 = _isxdigit($218);
    if (($219 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 81:
    var $222 = HEAPU16[$150 >> 1];
    if (($222 & 65535) < 128) {
      __label__ = 82;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 82:
    var $225 = $222 & 65535;
    var $226 = _isxdigit($225);
    if (($226 | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $229 = $204 - 48 | 0;
    if ($229 >>> 0 < 10) {
      var $235 = $229;
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $232 = _tolower($204);
    var $235 = $232 - 87 | 0;
    __label__ = 85;
    break;
   case 85:
    var $235;
    var $236 = $235 << 4;
    var $237 = $211 - 48 | 0;
    if ($237 >>> 0 < 10) {
      var $243 = $237;
      __label__ = 87;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $240 = _tolower($211);
    var $243 = $240 - 87 | 0;
    __label__ = 87;
    break;
   case 87:
    var $243;
    var $245 = $243 + $236 << 4;
    var $246 = $218 - 48 | 0;
    if ($246 >>> 0 < 10) {
      var $252 = $246;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $249 = _tolower($218);
    var $252 = $249 - 87 | 0;
    __label__ = 89;
    break;
   case 89:
    var $252;
    var $254 = $252 + $245 << 4;
    var $255 = $225 - 48 | 0;
    if ($255 >>> 0 < 10) {
      var $261 = $255;
      __label__ = 91;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $258 = _tolower($225);
    var $261 = $258 - 87 | 0;
    __label__ = 91;
    break;
   case 91:
    var $261;
    var $262 = $261 + $254 | 0;
    __ZN2js11TokenStream9skipCharsEi($this, 4);
    var $c_0 = $262;
    __label__ = 106;
    break;
   case 92:
    var $264 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 270, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str23587 | 0, tempInt));
    __label__ = 264;
    break;
   case 93:
    var $266 = __ZN2js11TokenStream9peekCharsEiPt($this, 2, $151);
    if ($266) {
      __label__ = 94;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 94:
    var $268 = HEAPU16[$151 >> 1];
    if (($268 & 65535) < 128) {
      __label__ = 95;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 95:
    var $271 = $268 & 65535;
    var $272 = _isxdigit($271);
    if (($272 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $275 = HEAPU16[$152 >> 1];
    if (($275 & 65535) < 128) {
      __label__ = 97;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 97:
    var $278 = $275 & 65535;
    var $279 = _isxdigit($278);
    if (($279 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $282 = $271 - 48 | 0;
    if ($282 >>> 0 < 10) {
      var $288 = $282;
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $285 = _tolower($271);
    var $288 = $285 - 87 | 0;
    __label__ = 100;
    break;
   case 100:
    var $288;
    var $289 = $288 << 4;
    var $290 = $278 - 48 | 0;
    if ($290 >>> 0 < 10) {
      var $296 = $290;
      __label__ = 102;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 101:
    var $293 = _tolower($278);
    var $296 = $293 - 87 | 0;
    __label__ = 102;
    break;
   case 102:
    var $296;
    var $297 = $296 + $289 | 0;
    __ZN2js11TokenStream9skipCharsEi($this, 2);
    var $c_0 = $297;
    __label__ = 106;
    break;
   case 103:
    var $299 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 270, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str33588 | 0, tempInt));
    __label__ = 264;
    break;
   case 104:
    var $301 = __ZN2js11TokenStream8TokenBuf12isRawEOLCharEi($153);
    if ($301 | ($153 | 0) == -1) {
      __label__ = 105;
      break;
    } else {
      var $c_0 = $153;
      __label__ = 106;
      break;
    }
   case 105:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $153);
    var $304 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 138, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 106:
    var $c_0;
    var $306 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($146, $c_0);
    if ($306) {
      __label__ = 55;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 107:
    var $308 = HEAP32[$7 >> 2];
    var $309 = __ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE($308, $146);
    if (($309 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $312 = HEAP32[$8 >> 2];
    var $314 = HEAP32[$tp >> 2] + 16 | 0;
    HEAP32[$314 >> 2] = $312;
    var $316 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$316 >> 2] = 61;
    var $318 = HEAP32[$tp >> 2] + 28 | 0;
    HEAP32[$318 >> 2] = $309;
    HEAP32[$tt >> 2] = 31;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 109:
    if (($18 - 49 | 0) >>> 0 < 9) {
      __label__ = 110;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 110:
    var $323 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $c_1 = $18;
    var $numStart_0 = $323 - 2 | 0;
    __label__ = 111;
    break;
   case 111:
    var $numStart_0;
    var $c_1;
    if (($c_1 - 48 | 0) >>> 0 < 10) {
      __label__ = 112;
      break;
    } else {
      var $c_2_lcssa = $c_1;
      __label__ = 113;
      break;
    }
   case 112:
    var $328 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($328 - 48 | 0) >>> 0 < 10) {
      __label__ = 112;
      break;
    } else {
      var $c_2_lcssa = $328;
      __label__ = 113;
      break;
    }
   case 113:
    var $c_2_lcssa;
    if (($c_2_lcssa | 0) == 46) {
      var $numStart_1 = $numStart_0;
      __label__ = 114;
      break;
    } else {
      var $c_3 = $c_2_lcssa;
      var $numStart_2 = $numStart_0;
      var $hasFracOrExp_0 = 0;
      __label__ = 116;
      break;
    }
   case 114:
    var $numStart_1;
    __label__ = 115;
    break;
   case 115:
    var $334 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($334 - 48 | 0) >>> 0 < 10) {
      __label__ = 115;
      break;
    } else {
      var $c_3 = $334;
      var $numStart_2 = $numStart_1;
      var $hasFracOrExp_0 = 1;
      __label__ = 116;
      break;
    }
   case 116:
    var $hasFracOrExp_0;
    var $numStart_2;
    var $c_3;
    if (($c_3 | 0) == 101 || ($c_3 | 0) == 69) {
      __label__ = 117;
      break;
    } else {
      var $c_5 = $c_3;
      var $hasFracOrExp_1 = $hasFracOrExp_0;
      __label__ = 122;
      break;
    }
   case 117:
    var $338 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($338 | 0) == 45 || ($338 | 0) == 43) {
      __label__ = 118;
      break;
    } else {
      var $c_4 = $338;
      __label__ = 119;
      break;
    }
   case 118:
    var $340 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_4 = $340;
    __label__ = 119;
    break;
   case 119:
    var $c_4;
    if (($c_4 - 48 | 0) >>> 0 < 10) {
      __label__ = 121;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 120:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_4);
    var $345 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 136, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 121:
    var $346 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($346 - 48 | 0) >>> 0 < 10) {
      __label__ = 121;
      break;
    } else {
      var $c_5 = $346;
      var $hasFracOrExp_1 = 1;
      __label__ = 122;
      break;
    }
   case 122:
    var $hasFracOrExp_1;
    var $c_5;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_5);
    if (($c_5 | 0) == -1) {
      __label__ = 125;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    var $352 = __ZN2js7unicode17IsIdentifierStartEt($c_5 & 65535);
    if ($352) {
      __label__ = 124;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 124:
    var $354 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 161, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 125:
    var $357 = ($hasFracOrExp_1 & 1) << 24 >> 24 == 0;
    var $358 = HEAP32[$7 >> 2];
    var $359 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    if ($357) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    var $361 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($358, $numStart_2, $359, 10, $dummy, $dval);
    if ($361) {
      __label__ = 128;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 127:
    var $363 = __Z9js_strtodP9JSContextPKtS2_PS2_Pd($358, $numStart_2, $359, $dummy, $dval);
    if (($363 | 0) == 0) {
      __label__ = 264;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 128:
    var $366 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $369 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $366, HEAP32[$369 >> 2] = tempDoubleI32[0], HEAP32[$369 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tt >> 2] = 30;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 129:
    if ($17 << 16 >> 16 == 58) {
      __label__ = 130;
      break;
    } else if ($17 << 16 >> 16 == 43) {
      __label__ = 133;
      break;
    } else if ($17 << 16 >> 16 == 48) {
      __label__ = 138;
      break;
    } else {
      __label__ = 158;
      break;
    }
   case 130:
    var $372 = __ZN2js11TokenStream9matchCharEi($this, 58);
    if ($372) {
      __label__ = 131;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    HEAP32[$tt >> 2] = 71;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 132:
    var $376 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$376 >> 2] = 0;
    HEAP32[$tt >> 2] = 6;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 133:
    var $378 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($378) {
      __label__ = 134;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 134:
    var $381 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$381 >> 2] = 27;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 135:
    var $383 = __ZN2js11TokenStream9matchCharEi($this, 43);
    if ($383) {
      __label__ = 136;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 136:
    HEAP32[$tt >> 2] = 20;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 137:
    var $387 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$387 >> 2] = 35;
    HEAP32[$tt >> 2] = 15;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 138:
    var $389 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($389 | 0) == 120 || ($389 | 0) == 88) {
      __label__ = 139;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 139:
    var $391 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    if (($391 | 0) < 128) {
      __label__ = 140;
      break;
    } else {
      __label__ = 141;
      break;
    }
   case 140:
    var $394 = _isxdigit($391);
    if (($394 | 0) == 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $391);
    var $397 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 7, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 142:
    var $399 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $400 = $399 - 2 | 0;
    var $c_6 = $391;
    __label__ = 143;
    break;
   case 143:
    var $c_6;
    if (($c_6 | 0) < 128) {
      __label__ = 145;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_6);
    var $radix_029 = 16;
    var $numStart_331 = $400;
    var $c_833 = $c_6;
    __label__ = 154;
    break;
   case 145:
    var $404 = _isxdigit($c_6);
    if (($404 | 0) == 0) {
      var $c_8 = $c_6;
      var $numStart_3 = $400;
      var $radix_0 = 16;
      __label__ = 153;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $407 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_6 = $407;
    __label__ = 143;
    break;
   case 147:
    var $410 = ($389 - 48 | 0) >>> 0 < 10;
    var $411 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $412 = $411 - 2 | 0;
    if ($410) {
      var $c_7 = $389;
      __label__ = 148;
      break;
    } else {
      var $c_1 = $389;
      var $numStart_0 = $412;
      __label__ = 111;
      break;
    }
   case 148:
    var $c_7;
    if (($c_7 - 48 | 0) >>> 0 < 10) {
      __label__ = 149;
      break;
    } else {
      var $c_8 = $c_7;
      var $numStart_3 = $412;
      var $radix_0 = 8;
      __label__ = 153;
      break;
    }
   case 149:
    var $416 = HEAP32[$7 >> 2];
    var $417 = __ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz($416, $this, 0, 0, 232, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    if ($417) {
      __label__ = 150;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 150:
    if (($c_7 | 0) > 55) {
      __label__ = 151;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 151:
    var $_str43589__str53590 = ($c_7 | 0) == 56 ? STRING_TABLE.__str43589 : STRING_TABLE.__str53590;
    var $422 = $_str43589__str53590 | 0;
    var $423 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 1, 145, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $422, tempInt));
    if ($423) {
      var $c_1 = $c_7;
      var $numStart_0 = $412;
      __label__ = 111;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 152:
    var $425 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $c_7 = $425;
    __label__ = 148;
    break;
   case 153:
    var $radix_0;
    var $numStart_3;
    var $c_8;
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $c_8);
    if (($c_8 | 0) == -1) {
      var $radix_030 = $radix_0;
      var $numStart_332 = $numStart_3;
      __label__ = 156;
      break;
    } else {
      var $radix_029 = $radix_0;
      var $numStart_331 = $numStart_3;
      var $c_833 = $c_8;
      __label__ = 154;
      break;
    }
   case 154:
    var $c_833;
    var $numStart_331;
    var $radix_029;
    var $429 = __ZN2js7unicode17IsIdentifierStartEt($c_833 & 65535);
    if ($429) {
      __label__ = 155;
      break;
    } else {
      var $radix_030 = $radix_029;
      var $numStart_332 = $numStart_331;
      __label__ = 156;
      break;
    }
   case 155:
    var $431 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 161, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 156:
    var $numStart_332;
    var $radix_030;
    var $433 = HEAP32[$7 >> 2];
    var $434 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $435 = __ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd($433, $numStart_332, $434, $radix_030, $dummy4, $dval3);
    if ($435) {
      __label__ = 157;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 157:
    var $437 = (tempDoubleI32[0] = HEAP32[$dval3 >> 2], tempDoubleI32[1] = HEAP32[$dval3 + 4 >> 2], tempDoubleF64[0]);
    var $440 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $437, HEAP32[$440 >> 2] = tempDoubleI32[0], HEAP32[$440 + 4 >> 2] = tempDoubleI32[1];
    HEAP32[$tt >> 2] = 30;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 158:
    if (($18 | 0) == 92) {
      __label__ = 159;
      break;
    } else if (($18 | 0) == 124) {
      __label__ = 161;
      break;
    } else if (($18 | 0) == 94) {
      __label__ = 166;
      break;
    } else if (($18 | 0) == 38) {
      __label__ = 169;
      break;
    } else if (($18 | 0) == 33) {
      __label__ = 174;
      break;
    } else if (($18 | 0) == 64) {
      __label__ = 177;
      break;
    } else if (($18 | 0) == 60) {
      __label__ = 178;
      break;
    } else if (($18 | 0) == 62) {
      __label__ = 191;
      break;
    } else if (($18 | 0) == 42) {
      __label__ = 194;
      break;
    } else if (($18 | 0) == 47) {
      __label__ = 195;
      break;
    } else if (($18 | 0) == 37) {
      __label__ = 241;
      break;
    } else if (($18 | 0) == 126) {
      __label__ = 242;
      break;
    } else if (($18 | 0) == 45) {
      __label__ = 243;
      break;
    } else if (($18 | 0) == 35) {
      __label__ = 251;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 159:
    var $443 = __ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi($this, $qc);
    if ($443) {
      __label__ = 160;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 160:
    var $445 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($5);
    var $identStart_0_ph = $445 - 12 | 0;
    var $hadUnicodeEscape_0_ph = 1;
    __label__ = 21;
    break;
   case 161:
    var $448 = __ZN2js11TokenStream9matchCharEi($this, 124);
    if ($448) {
      __label__ = 162;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 162:
    HEAP32[$tt >> 2] = 7;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 163:
    var $451 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($451) {
      __label__ = 164;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 164:
    var $454 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$454 >> 2] = 15;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 165:
    HEAP32[$tt >> 2] = 9;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 166:
    var $457 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($457) {
      __label__ = 167;
      break;
    } else {
      __label__ = 168;
      break;
    }
   case 167:
    var $460 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$460 >> 2] = 16;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 168:
    HEAP32[$tt >> 2] = 10;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 169:
    var $463 = __ZN2js11TokenStream9matchCharEi($this, 38);
    if ($463) {
      __label__ = 170;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 170:
    HEAP32[$tt >> 2] = 8;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 171:
    var $466 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($466) {
      __label__ = 172;
      break;
    } else {
      __label__ = 173;
      break;
    }
   case 172:
    var $469 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$469 >> 2] = 17;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 173:
    HEAP32[$tt >> 2] = 11;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 174:
    var $472 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($472) {
      __label__ = 175;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 175:
    var $474 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $475 = $474 ? 73 : 19;
    var $477 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$477 >> 2] = $475;
    HEAP32[$tt >> 2] = 12;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 176:
    var $480 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$480 >> 2] = 32;
    HEAP32[$tt >> 2] = 19;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 177:
    HEAP32[$tt >> 2] = 70;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 178:
    if ((HEAP32[$1 >> 2] & 8 | 0) == 0) {
      __label__ = 182;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 179:
    var $487 = __ZNK2js11TokenStream6hasXMLEv($this);
    if ($487) {
      __label__ = 181;
      break;
    } else {
      __label__ = 180;
      break;
    }
   case 180:
    var $489 = __ZN2js11TokenStream8peekCharEv($this);
    if (($489 | 0) == 33) {
      __label__ = 182;
      break;
    } else {
      __label__ = 181;
      break;
    }
   case 181:
    var $492 = __ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE($this, $tt, $tp);
    if ($492) {
      var $_pre_phi = $5;
      __label__ = 263;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 182:
    var $494 = __ZN2js11TokenStream9matchCharEi($this, 33);
    if ($494) {
      __label__ = 183;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 183:
    var $496 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($496) {
      __label__ = 184;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 184:
    var $498 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($498) {
      __label__ = 185;
      break;
    } else {
      __label__ = 186;
      break;
    }
   case 185:
    var $501 = HEAP32[$1 >> 2] | 8192;
    HEAP32[$1 >> 2] = $501;
    var $542 = $501;
    __label__ = 200;
    break;
   case 186:
    __ZN2js11TokenStream9ungetCharEi($this, 45);
    __label__ = 187;
    break;
   case 187:
    __ZN2js11TokenStream9ungetCharEi($this, 33);
    __label__ = 188;
    break;
   case 188:
    var $503 = __ZN2js11TokenStream9matchCharEi($this, 60);
    if ($503) {
      __label__ = 189;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 189:
    var $506 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$506 >> 2] = 24;
    var $507 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $508 = $507 ? 4 : 14;
    HEAP32[$tt >> 2] = $508;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 190:
    var $510 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $511 = $510 ? 21 : 20;
    var $513 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$513 >> 2] = $511;
    HEAP32[$tt >> 2] = 13;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 191:
    var $515 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($515) {
      __label__ = 192;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 192:
    var $517 = __ZN2js11TokenStream9matchCharEi($this, 62);
    var $518 = $517 ? 26 : 25;
    var $520 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$520 >> 2] = $518;
    var $521 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $522 = $521 ? 4 : 14;
    HEAP32[$tt >> 2] = $522;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 193:
    var $524 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $525 = $524 ? 23 : 22;
    var $527 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$527 >> 2] = $525;
    HEAP32[$tt >> 2] = 13;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 194:
    HEAP32[$42 + 24 >> 2] = 29;
    var $530 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $531 = $530 ? 4 : 17;
    HEAP32[$tt >> 2] = $531;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 195:
    var $533 = __ZN2js11TokenStream9matchCharEi($this, 47);
    if ($533) {
      __label__ = 196;
      break;
    } else {
      __label__ = 207;
      break;
    }
   case 196:
    var $535 = HEAP32[$7 >> 2];
    var $536 = __ZNK9JSContext15hasAtLineOptionEv($535);
    if ($536) {
      __label__ = 197;
      break;
    } else {
      __label__ = 198;
      break;
    }
   case 197:
    var $538 = __ZN2js11TokenStream9getAtLineEv($this);
    if ($538) {
      __label__ = 198;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 198:
    var $540 = __ZN2js11TokenStream21getAtSourceMappingURLEv($this);
    if ($540) {
      __label__ = 199;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 199:
    var $542 = HEAP32[$1 >> 2];
    __label__ = 200;
    break;
   case 200:
    var $542;
    if (($542 & 8192 | 0) == 0) {
      __label__ = 205;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 201:
    var $545 = __ZN2js11TokenStream7getCharEv($this);
    if (($545 | 0) == 45) {
      __label__ = 202;
      break;
    } else if (($545 | 0) == -1 || ($545 | 0) == 10) {
      var $c_9 = $545;
      __label__ = 206;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 202:
    var $547 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($547) {
      __label__ = 203;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 203:
    var $549 = __ZN2js11TokenStream9matchCharEi($this, 62);
    if ($549) {
      __label__ = 204;
      break;
    } else {
      __label__ = 201;
      break;
    }
   case 204:
    var $552 = HEAP32[$1 >> 2] & -8193;
    HEAP32[$1 >> 2] = $552;
    __label__ = 201;
    break;
   case 205:
    var $553 = __ZN2js11TokenStream7getCharEv($this);
    if (($553 | 0) == -1 || ($553 | 0) == 10) {
      var $c_9 = $553;
      __label__ = 206;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 206:
    var $c_9;
    __ZN2js11TokenStream9ungetCharEi($this, $c_9);
    var $556 = HEAP32[$6 >> 2] + 3 & 3;
    HEAP32[$6 >> 2] = $556;
    __label__ = 5;
    break;
   case 207:
    var $558 = __ZN2js11TokenStream9matchCharEi($this, 42);
    if ($558) {
      __label__ = 208;
      break;
    } else {
      __label__ = 215;
      break;
    }
   case 208:
    var $560 = HEAP32[$8 >> 2];
    __label__ = 209;
    break;
   case 209:
    var $561 = __ZN2js11TokenStream7getCharEv($this);
    if (($561 | 0) == 42) {
      __label__ = 210;
      break;
    } else if (($561 | 0) == -1) {
      __label__ = 211;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 210:
    var $563 = __ZN2js11TokenStream9matchCharEi($this, 47);
    if ($563) {
      __label__ = 212;
      break;
    } else {
      __label__ = 209;
      break;
    }
   case 211:
    var $565 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 140, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 212:
    if (($560 | 0) == (HEAP32[$8 >> 2] | 0)) {
      __label__ = 214;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    __ZN2js11TokenStream17updateFlagsForEOLEv($this);
    __label__ = 214;
    break;
   case 214:
    var $573 = HEAP32[$6 >> 2] + 3 & 3;
    HEAP32[$6 >> 2] = $573;
    __label__ = 5;
    break;
   case 215:
    if ((HEAP32[$1 >> 2] & 8 | 0) == 0) {
      __label__ = 240;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    var $579 = $this + 184 | 0;
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv($579);
    var $inCharClass_0 = 0;
    __label__ = 217;
    break;
   case 217:
    var $inCharClass_0;
    var $581 = __ZN2js11TokenStream7getCharEv($this);
    if (($581 | 0) == 92) {
      __label__ = 218;
      break;
    } else if (($581 | 0) == 93) {
      __label__ = 220;
      break;
    } else if (($581 | 0) == 91) {
      var $inCharClass_135 = 1;
      var $c_1036 = 91;
      __label__ = 224;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 218:
    var $583 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($579, 92);
    if ($583) {
      __label__ = 219;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 219:
    var $585 = __ZN2js11TokenStream7getCharEv($this);
    var $c_10 = $585;
    __label__ = 222;
    break;
   case 220:
    var $inCharClass_135 = 0;
    var $c_1036 = 93;
    __label__ = 224;
    break;
   case 221:
    if (($581 | 0) == 47 & ($inCharClass_0 | 0) == 0) {
      __label__ = 225;
      break;
    } else {
      var $c_10 = $581;
      __label__ = 222;
      break;
    }
   case 222:
    var $c_10;
    if (($c_10 | 0) == -1 || ($c_10 | 0) == 10) {
      __label__ = 223;
      break;
    } else {
      var $inCharClass_135 = $inCharClass_0;
      var $c_1036 = $c_10;
      __label__ = 224;
      break;
    }
   case 223:
    __ZN2js11TokenStream9ungetCharEi($this, $c_10);
    var $592 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 141, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 224:
    var $c_1036;
    var $inCharClass_135;
    var $593 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_($579, $c_1036);
    if ($593) {
      var $inCharClass_0 = $inCharClass_135;
      __label__ = 217;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 225:
    var $595 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv($579);
    var $length_0_in = $595;
    var $reflags_0 = 0;
    __label__ = 226;
    break;
   case 226:
    var $reflags_0;
    var $length_0_in;
    var $length_0 = $length_0_in + 1 | 0;
    var $597 = __ZN2js11TokenStream8peekCharEv($this);
    if (($597 | 0) == 103) {
      __label__ = 227;
      break;
    } else if (($597 | 0) == 105) {
      __label__ = 229;
      break;
    } else if (($597 | 0) == 109) {
      __label__ = 231;
      break;
    } else if (($597 | 0) == 121) {
      __label__ = 233;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 227:
    if (($reflags_0 & 2 | 0) == 0) {
      __label__ = 228;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 228:
    var $reflags_1 = $reflags_0 | 2;
    __label__ = 235;
    break;
   case 229:
    if (($reflags_0 & 1 | 0) == 0) {
      __label__ = 230;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 230:
    var $reflags_1 = $reflags_0 | 1;
    __label__ = 235;
    break;
   case 231:
    if (($reflags_0 & 4 | 0) == 0) {
      __label__ = 232;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 232:
    var $reflags_1 = $reflags_0 | 4;
    __label__ = 235;
    break;
   case 233:
    if (($reflags_0 & 8 | 0) == 0) {
      __label__ = 234;
      break;
    } else {
      __label__ = 236;
      break;
    }
   case 234:
    var $reflags_1 = $reflags_0 | 8;
    __label__ = 235;
    break;
   case 235:
    var $reflags_1;
    var $619 = __ZN2js11TokenStream7getCharEv($this);
    var $length_0_in = $length_0;
    var $reflags_0 = $reflags_1;
    __label__ = 226;
    break;
   case 236:
    var $620 = __ZN2js11TokenStream8peekCharEv($this);
    if (($620 | 0) < 128) {
      __label__ = 237;
      break;
    } else {
      __label__ = 239;
      break;
    }
   case 237:
    var $623 = _isalpha($620);
    if (($623 | 0) == 0) {
      __label__ = 239;
      break;
    } else {
      __label__ = 238;
      break;
    }
   case 238:
    HEAP16[$buf >> 1] = 0;
    var $627 = HEAP32[$tp >> 2] + 4 | 0;
    var $630 = $length_0_in + 2 + HEAP32[$627 >> 2] | 0;
    HEAP32[$627 >> 2] = $630;
    HEAP8[$buf] = $620 & 255;
    var $633 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 58, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $buf, tempInt));
    var $634 = __ZN2js11TokenStream7getCharEv($this);
    __label__ = 264;
    break;
   case 239:
    var $637 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$637 >> 2] = $reflags_0;
    HEAP32[$tt >> 2] = 32;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 240:
    var $640 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$640 >> 2] = 30;
    var $641 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $642 = $641 ? 4 : 18;
    HEAP32[$tt >> 2] = $642;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 241:
    HEAP32[$42 + 24 >> 2] = 31;
    var $645 = __ZN2js11TokenStream9matchCharEi($this, 61);
    var $646 = $645 ? 4 : 18;
    HEAP32[$tt >> 2] = $646;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 242:
    HEAP32[$42 + 24 >> 2] = 33;
    HEAP32[$tt >> 2] = 19;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 243:
    var $650 = __ZN2js11TokenStream9matchCharEi($this, 61);
    if ($650) {
      __label__ = 244;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 244:
    var $653 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$653 >> 2] = 28;
    HEAP32[$tt >> 2] = 4;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 245:
    var $655 = __ZN2js11TokenStream9matchCharEi($this, 45);
    if ($655) {
      __label__ = 246;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 246:
    var $657 = __ZN2js11TokenStream8peekCharEv($this);
    if (($657 | 0) == 62) {
      __label__ = 247;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 247:
    var $660 = HEAP32[$1 >> 2];
    if (($660 & 128 | 0) == 0) {
      __label__ = 248;
      break;
    } else {
      __label__ = 249;
      break;
    }
   case 248:
    var $664 = $660 & -8193;
    HEAP32[$1 >> 2] = $664;
    var $542 = $664;
    __label__ = 200;
    break;
   case 249:
    HEAP32[$tt >> 2] = 21;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 250:
    var $668 = HEAP32[$tp >> 2] + 24 | 0;
    HEAP32[$668 >> 2] = 34;
    HEAP32[$tt >> 2] = 16;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 251:
    var $670 = __ZN2js11TokenStream16getCharIgnoreEOLEv($this);
    var $671 = $670 - 48 | 0;
    if ($671 >>> 0 < 10) {
      var $n_0 = $671;
      __label__ = 253;
      break;
    } else {
      __label__ = 252;
      break;
    }
   case 252:
    __ZN2js11TokenStream18ungetCharIgnoreEOLEi($this, $670);
    __label__ = 262;
    break;
   case 253:
    var $n_0;
    var $675 = __ZN2js11TokenStream7getCharEv($this);
    if (($675 - 48 | 0) >>> 0 < 10) {
      __label__ = 254;
      break;
    } else {
      __label__ = 256;
      break;
    }
   case 254:
    var $681 = $n_0 * 10 - 48 + $675 | 0;
    if ($681 >>> 0 > 65535) {
      __label__ = 255;
      break;
    } else {
      var $n_0 = $681;
      __label__ = 253;
      break;
    }
   case 255:
    var $684 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 143, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 256:
    var $689 = HEAP32[$tp >> 2] + 24 | 0;
    tempDoubleF64[0] = $n_0 >>> 0, HEAP32[$689 >> 2] = tempDoubleI32[0], HEAP32[$689 + 4 >> 2] = tempDoubleI32[1];
    var $690 = HEAP32[$7 >> 2];
    var $691 = __ZNK9JSContext15hasStrictOptionEv($690);
    if ($691) {
      __label__ = 257;
      break;
    } else {
      __label__ = 259;
      break;
    }
   case 257:
    if (($675 | 0) == 61 || ($675 | 0) == 35) {
      __label__ = 258;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 258:
    var $694 = $buf5 | 0;
    var $695 = _JS_snprintf($694, 20, STRING_TABLE.__str63591 | 0, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $n_0, HEAP32[tempInt + 4 >> 2] = $675, tempInt));
    var $696 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 5, 158, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $694, tempInt));
    if ($696) {
      __label__ = 259;
      break;
    } else {
      __label__ = 264;
      break;
    }
   case 259:
    if (($675 | 0) == 61) {
      __label__ = 260;
      break;
    } else if (($675 | 0) == 35) {
      __label__ = 261;
      break;
    } else {
      __label__ = 262;
      break;
    }
   case 260:
    HEAP32[$tt >> 2] = 51;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 261:
    HEAP32[$tt >> 2] = 52;
    var $_pre_phi = $5;
    __label__ = 263;
    break;
   case 262:
    var $700 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $this, 0, 0, 144, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 264;
    break;
   case 263:
    var $_pre_phi;
    var $702 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $702;
    var $703 = __ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv($_pre_phi);
    var $709 = $703 - HEAP32[$this + 148 >> 2] >> 1;
    var $711 = HEAP32[$tp >> 2] + 12 | 0;
    HEAP32[$711 >> 2] = $709;
    var $712 = HEAP32[$tt >> 2];
    var $714 = HEAP32[$tp >> 2] | 0;
    HEAP32[$714 >> 2] = $712;
    var $_0 = HEAP32[$tt >> 2];
    __label__ = 265;
    break;
   case 264:
    var $717 = HEAP32[$1 >> 2] | 128;
    HEAP32[$1 >> 2] = $717;
    var $718 = HEAP32[$tp >> 2];
    var $721 = HEAP32[$718 + 4 >> 2] + 1 | 0;
    var $722 = $718 + 12 | 0;
    HEAP32[$722 >> 2] = $721;
    var $724 = HEAP32[$tp >> 2] | 0;
    HEAP32[$724 >> 2] = -1;
    var $_0 = -1;
    __label__ = 265;
    break;
   case 265:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11TokenStream16getTokenInternalEv["X"] = 1;

function __ZN2js13PropertyTable13sizeOfEntriesEj($cap) {
  return $cap << 2;
}

function __ZN2jsL6HashIdEi($id) {
  return $id * -1640531527 | 0;
}

function __ZN2js11TokenStream17updateFlagsForEOLEv($this) {
  var $1 = $this + 144 | 0;
  var $4 = HEAP32[$1 >> 2] & -133 | 4;
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 1) | 0;
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP16[$p_01 >> 1];
    HEAP16[$_02 >> 1] = $2;
    var $3 = $p_01 + 2 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    HEAP16[$_02 >> 1] = HEAP8[$p_01] << 24 >> 24;
    var $4 = $p_01 + 1 | 0;
    if (($4 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $4;
      var $_02 = $_02 + 2 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7unicode13CharacterInfo8isLetterEv($this) {
  return (HEAP8[$this + 4 | 0] & 2) << 24 >> 24 != 0;
}

function __ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv($this) {
  return (HEAP8[$this + 4 | 0] & 16) << 24 >> 24 != 0;
}

function __ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv($this) {
  return (HEAP8[$this + 4 | 0] & 32) << 24 >> 24 != 0;
}

function __ZN2js11TokenStream8TokenBufC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZNK2js7unicode13CharacterInfo16isIdentifierPartEv($this) {
  return (HEAP8[$this + 4 | 0] & 6) << 24 >> 24 != 0;
}

function __ZNK2js13PropertyTable8capacityEv($this) {
  return 1 << 32 - HEAP32[$this >> 2];
}

function __ZNK2js5Shape6frozenEv($this) {
  return (HEAP8[$this + 29 | 0] & 4) << 24 >> 24 != 0;
}

function __ZN2js7unicode8IsLetterEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $2 = __ZNK2js7unicode13CharacterInfo8isLetterEv($1);
  return $2;
}

function __ZNK9JSContext15hasAtLineOptionEv($this) {
  var $1 = __ZNK9JSContext12hasRunOptionEj($this, 32);
  return $1;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $4 = $this + 16 | 0;
  var $5 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($4);
  return ($2 | 0) == ($5 | 0);
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = $this | 0;
    var $6 = HEAP32[$newCap >> 2];
    var $7 = $6 << 1;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($5, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $6;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 1073741823) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 1073741823) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this | 0;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 1;
    var $2 = $v | 0;
    var $3 = $v + 4 | 0;
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($2, $5, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    var $10 = $v + 12 | 0;
    HEAP32[$3 >> 2] = $9;
    HEAP32[$10 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_($this, $insBegin, $insEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $insEnd - $insBegin | 0;
    if ((HEAP32[$this + 8 >> 2] + $3 | 0) >>> 0 > HEAPU32[$this + 12 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, $3);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $3);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j($this, $insBegin, $length) {
  var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
  var $2 = $insBegin + $length | 0;
  __ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_($1, $insBegin, $2);
  var $3 = $this + 8 | 0;
  var $5 = HEAP32[$3 >> 2] + $length | 0;
  HEAP32[$3 >> 2] = $5;
  return;
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t & 65535;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$1 >> 1] = $t << 24 >> 24;
    __label__ = 3;
    break;
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $6 = $this + 16 | 0;
  var $7 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($6);
  HEAP32[$4 >> 2] = $7;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  STACKTOP = __stackBase__;
  return;
}

function __Z16js_GenerateShapeP9JSRuntime($rt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $rt + 209944 | 0;
    var $3 = HEAP32[$1 >> 2] + 1 | 0;
    HEAP32[$1 >> 2] = $3;
    if ($3 >>> 0 > 16777215) {
      __label__ = 2;
      break;
    } else {
      var $shape_0 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = 16777216;
    if ((HEAP32[__ZN2js8gcReasonE >> 2] | 0) == 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[__ZN2js8gcReasonE >> 2] = 9;
    __label__ = 5;
    break;
   case 4:
    var $10 = HEAP32[__ZN2js8gcReasonE >> 2];
    HEAP32[__ZN2js8gcReasonE >> 2] = $10;
    __label__ = 5;
    break;
   case 5:
    __ZN2js9TriggerGCEP9JSRuntime($rt);
    var $shape_0 = 16777216;
    __label__ = 6;
    break;
   case 6:
    var $shape_0;
    return $shape_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_GenerateShapeP9JSContext($cx) {
  var $2 = HEAP32[$cx + 52 >> 2];
  var $3 = __Z16js_GenerateShapeP9JSRuntime($2);
  return $3;
}

function __ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8getClassEv($this);
    var $5 = HEAPU32[$1 + 4 >> 2] >>> 8 & 255;
    var $6 = __ZNK8JSObject8numSlotsEv($this);
    if ($5 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $this;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $5);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE($this, $rt, $lastProp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $3 = HEAP32[$this + 4 >> 2] << 1;
    var $4 = _JS_CeilingLog2($3);
    var $sizeLog2_0 = $4 >>> 0 < 4 ? 4 : $4;
    var $6 = 1 << $sizeLog2_0;
    var $7 = __ZN2js13PropertyTable13sizeOfEntriesEj($6);
    var $8 = __ZN9JSRuntime7calloc_EjP9JSContext($rt, $7, 0);
    var $9 = $8;
    HEAP32[$this + 16 >> 2] = $9;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = 32 - $sizeLog2_0 | 0;
    HEAP32[$this >> 2] = $13;
    var $15 = $r;
    var $16 = $lastProp;
    __ZNK2js5Shape3allEv($15, $16);
    var $17 = __ZNK2js5Shape5Range5emptyEv($15);
    if ($17) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $18 = __ZNK2js5Shape5Range5frontEv($r);
    var $20 = HEAP32[$18 + 12 >> 2];
    var $21 = __ZN2js13PropertyTable6searchEib($this, $20, 1);
    var $22 = HEAPU32[$21 >> 2];
    if ($22 >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $29 = $22 & 1 | $18;
    HEAP32[$21 >> 2] = $29;
    __label__ = 5;
    break;
   case 5:
    __ZN2js5Shape5Range8popFrontEv($r);
    var $31 = __ZNK2js5Shape5Range5emptyEv($15);
    if ($31) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable6searchEib($this, $id, $adding) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL6HashIdEi($id);
    var $3 = HEAPU32[$this >> 2];
    var $4 = $1 >>> ($3 >>> 0);
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] + ($4 << 2) | 0;
    var $8 = HEAPU32[$7 >> 2];
    if (($8 | 0) == 0) {
      var $_0 = $7;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = $8;
    var $12 = $11 & -2;
    if (($12 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$12 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $7;
      __label__ = 18;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = 32 - $3 | 0;
    var $23 = $1 << $20 >>> ($3 >>> 0) | 1;
    var $25 = (1 << $20) - 1 | 0;
    var $26 = ($8 | 0) == 1;
    var $_mux = $26 ? $7 : 0;
    if ($26 | $adding ^ 1) {
      var $firstRemoved_0_ph1 = $_mux;
      var $hash1_0_ph = $4;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($11 & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $firstRemoved_0_ph1 = 0;
      var $hash1_0_ph = $4;
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = $11 | 1;
    HEAP32[$7 >> 2] = $32;
    var $firstRemoved_0_ph1 = 0;
    var $hash1_0_ph = $4;
    __label__ = 7;
    break;
   case 7:
    var $hash1_0_ph;
    var $firstRemoved_0_ph1;
    var $33 = ($firstRemoved_0_ph1 | 0) == 0;
    var $hash1_0 = $hash1_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $hash1_0;
    var $35 = $hash1_0 - $23 & $25;
    var $37 = HEAP32[$5 >> 2] + ($35 << 2) | 0;
    var $38 = HEAP32[$37 >> 2];
    if (($38 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if ($adding) {
      __label__ = 10;
      break;
    } else {
      var $_0 = $37;
      __label__ = 18;
      break;
    }
   case 10:
    var $phitmp = ($firstRemoved_0_ph1 | 0) != 0 ? $firstRemoved_0_ph1 : $37;
    var $_0 = $phitmp;
    __label__ = 18;
    break;
   case 11:
    var $44 = $38;
    var $45 = $44 & -2;
    if (($45 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$45 + 12 >> 2] | 0) == ($id | 0)) {
      var $_0 = $37;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($38 | 0) == 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if ($33) {
      var $firstRemoved_0_ph1 = $37;
      var $hash1_0_ph = $35;
      __label__ = 7;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 15:
    if ($adding) {
      __label__ = 16;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 16:
    if (($44 & 1 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $hash1_0 = $35;
      __label__ = 8;
      break;
    }
   case 17:
    var $61 = $44 | 1;
    HEAP32[$37 >> 2] = $61;
    var $hash1_0 = $35;
    __label__ = 8;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13PropertyTable6searchEib["X"] = 1;

function __ZN2js5Shape7hashifyEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $3 = $this;
    var $4 = __ZNK2js5Shape10entryCountEv($3);
    var $5 = __ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_($2, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE($5, $2, $this);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $5;
    __ZN9JSRuntime5free_EPv(undef, $10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $12 = $this;
    var $13 = $5;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($12, $13);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSRuntime7malloc_EjP9JSContext($this, 20, 0);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js13PropertyTableC1Ej($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable6changeEiP9JSContext($this, $log2Delta, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = 32 - HEAP32[$1 >> 2] | 0;
    var $4 = $3 + $log2Delta | 0;
    var $5 = 1 << $4;
    var $6 = __ZN2js13PropertyTable13sizeOfEntriesEj($5);
    var $7 = __ZN9JSContext7calloc_Ej($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $7;
    var $11 = 1 << $3;
    var $12 = 32 - $4 | 0;
    HEAP32[$1 >> 2] = $12;
    HEAP32[$this + 8 >> 2] = 0;
    var $14 = $this + 16 | 0;
    var $15 = HEAP32[$14 >> 2];
    HEAP32[$14 >> 2] = $10;
    var $oldsize_01 = $11;
    var $oldspp_02 = $15;
    __label__ = 3;
    break;
   case 3:
    var $oldspp_02;
    var $oldsize_01;
    var $19 = HEAP32[$oldspp_02 >> 2] & -2;
    var $20 = $19;
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAP32[$20 + 12 >> 2];
    var $25 = __ZN2js13PropertyTable6searchEib($this, $24, 1);
    HEAP32[$25 >> 2] = $20;
    __label__ = 5;
    break;
   case 5:
    var $27 = $oldsize_01 - 1 | 0;
    if (($27 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $oldsize_01 = $27;
      var $oldspp_02 = $oldspp_02 + 4 | 0;
      __label__ = 3;
      break;
    }
   case 6:
    var $31 = $15;
    __ZN9JSContext5free_EPv(undef, $31);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13PropertyTable4growEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13PropertyTable8capacityEv($this);
    var $2 = $this + 8 | 0;
    var $6 = HEAPU32[$2 >> 2] >>> 0 < $1 >>> 2 >>> 0 & 1;
    var $7 = __ZN2js13PropertyTable6changeEiP9JSContext($this, $6, $cx);
    if ($7) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 >> 2] + HEAP32[$this + 4 >> 2] | 0) == ($1 - 1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_($this, $cx, $child, $listp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $this_tr = $this;
    __label__ = 2;
    break;
   case 2:
    var $this_tr;
    var $1 = __ZNK2js5Shape12inDictionaryEv($this_tr);
    var $2 = HEAPU32[$listp >> 2];
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    if (($2 | 0) == 0) {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $6 = __ZNK2js5Shape8hasTableEv($2);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $8 = __ZNK2js5Shape8getTableEv($2);
    if (($8 | 0) == 0) {
      var $15 = 0;
      var $14 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $11 = __ZNK2js13PropertyTable11needsToGrowEv($8);
    if ($11) {
      __label__ = 7;
      break;
    } else {
      var $15 = $8;
      var $14 = 1;
      __label__ = 8;
      break;
    }
   case 7:
    var $13 = __ZN2js13PropertyTable4growEP9JSContext($8, $cx);
    if ($13) {
      var $15 = $8;
      var $14 = 1;
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 8:
    var $14;
    var $15;
    var $16 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $listp);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $19 = HEAPU32[$listp >> 2];
    if ($14) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $22 = HEAP32[$19 + 12 >> 2];
    var $23 = __ZN2js13PropertyTable6searchEib($15, $22, 1);
    var $24 = HEAPU32[$23 >> 2];
    if ($24 >>> 0 > 1) {
      var $31 = $24;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $27 = $15 + 4 | 0;
    var $29 = HEAP32[$27 >> 2] + 1 | 0;
    HEAP32[$27 >> 2] = $29;
    var $31 = HEAP32[$23 >> 2];
    __label__ = 12;
    break;
   case 12:
    var $31;
    HEAP32[$23 >> 2] = $31 & 1 | $19;
    var $37 = $2;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($37, 0);
    var $38 = $19;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($38, $15);
    var $_0 = $19;
    __label__ = 19;
    break;
   case 13:
    var $41 = __ZNK2js5Shape8hasTableEv($19);
    if ($41) {
      var $_0 = $19;
      __label__ = 19;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = __ZN2js5Shape7hashifyEP9JSContext($19, $cx);
    var $_0 = $19;
    __label__ = 19;
    break;
   case 15:
    var $45 = $2;
    var $46 = __ZNK2js5Shape10entryCountEv($45);
    if ($46 >>> 0 > 127) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $49 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $listp);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $this_tr = $49;
      __label__ = 2;
      break;
    }
   case 17:
    var $52 = $cx;
    var $54 = $child;
    var $55 = __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_(undef, $52, $this_tr, $54);
    var $56 = $55;
    if (($55 | 0) == 0) {
      var $_0 = $56;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    HEAP32[$listp >> 2] = $56;
    var $_0 = $56;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_["X"] = 1;

function __ZNK2js13PropertyTable11needsToGrowEv($this) {
  var $1 = __ZNK2js13PropertyTable8capacityEv($this);
  return (HEAP32[$this + 8 >> 2] + HEAP32[$this + 4 >> 2] | 0) >>> 0 >= ($1 - ($1 >>> 2) | 0) >>> 0;
}

function __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $listp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN2js12PropertyTree8newShapeEP9JSContext(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$child + 12 >> 2];
    var $9 = HEAP32[$child + 16 >> 2];
    var $11 = HEAP32[$child + 20 >> 2];
    var $13 = HEAP32[$child + 24 >> 2];
    var $16 = HEAPU8[$child + 28 | 0] & 255;
    var $21 = HEAPU8[$child + 29 | 0] & 255 & 249 | 2;
    var $24 = HEAP16[$child + 30 >> 1] << 16 >> 16;
    var $25 = __Z16js_GenerateShapeP9JSContext($cx);
    var $27 = HEAP32[$child + 4 >> 2];
    var $28 = $9;
    var $29 = $11;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($2, $7, $28, $29, $13, $16, $21, $24, $25, $27);
    HEAP32[$2 + 36 >> 2] = 0;
    __ZN2js5Shape20insertIntoDictionaryEPPS0_($3, $listp);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $listp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $root = __stackBase__;
    var $1 = HEAP32[$listp >> 2];
    HEAP32[$root >> 2] = 0;
    var $childp_0 = $root;
    var $shape_0 = $1;
    __label__ = 2;
    break;
   case 2:
    var $shape_0;
    var $childp_0;
    if (($shape_0 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $shape_0, $childp_0);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$listp >> 2] = $1;
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $childp_0 = $5 + 32 | 0;
    var $shape_0 = HEAP32[$shape_0 + 32 >> 2];
    __label__ = 2;
    break;
   case 6:
    var $13 = HEAP32[$root >> 2];
    HEAP32[$listp >> 2] = $13;
    var $14 = $13 + 36 | 0;
    HEAP32[$14 >> 2] = $listp;
    var $15 = HEAP32[$root >> 2];
    var $16 = __ZN2js5Shape7hashifyEP9JSContext($15, $cx);
    var $_0 = HEAP32[$root >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $parent, $child) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = $child + 24 | 0;
    if ((HEAP8[$child + 28 | 0] & 64) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$5 >> 2] = -1;
    __label__ = 5;
    break;
   case 3:
    if ((HEAP32[$5 >> 2] | 0) == -1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = $this;
    var $12 = $cx;
    var $13 = __ZN8JSObject9allocSlotEP9JSContextPj($11, $12, $5);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $15 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $17 = __ZNK2js5Shape6frozenEv($parent);
    var $18 = $this | 0;
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_pre_phi = $18;
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $18);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $_pre_phi = $18;
      __label__ = 8;
      break;
    }
   case 8:
    var $_pre_phi;
    var $22 = __ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_($cx, $child, $_pre_phi);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $shape_0 = $22;
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = $cx;
    var $26 = $parent;
    var $27 = $child;
    var $28 = __ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_(undef, $25, $26, $27);
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $29);
    var $shape_0 = $29;
    __label__ = 11;
    break;
   case 11:
    var $shape_0;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape_0, 0);
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    var $_0 = $shape_0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $getter, $setter) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$setter >> 2] | 0) == 12) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$setter >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    if (($flags & 128 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ((HEAP32[$getter >> 2] | 0) == 10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$getter >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13clearOwnShapeEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] & -129;
  HEAP32[$1 >> 2] = $3;
  var $7 = HEAP32[HEAP32[$this >> 2] >> 2];
  HEAP32[$this + 12 >> 2] = $7;
  return;
}

function __ZN8JSObject18removeLastPropertyEv($this) {
  var $1 = $this | 0;
  var $4 = HEAP32[HEAP32[$1 >> 2] + 32 >> 2];
  HEAP32[$1 >> 2] = $4;
  return;
}

function __ZNK2js5Shape20removeFromDictionaryEP8JSObject($this, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 32 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $_pre1 = $this + 36 | 0;
    var $_pre2 = $_pre1;
    if (($2 | 0) == 0) {
      var $7 = $2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $2 + 36 | 0;
    var $_c = HEAP32[$_pre2 >> 2];
    HEAP32[$6 >> 2] = $_c;
    var $7 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = HEAP32[$_pre2 >> 2];
    HEAP32[$8 >> 2] = $7;
    HEAP32[$_pre1 >> 2] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5Shape20insertIntoDictionaryEPPS0_($this, $dictp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $this;
    var $3 = HEAP32[$dictp >> 2];
    __ZN2js5Shape9setParentEPS0_($2, $3);
    var $4 = $this + 32 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5 + 36 | 0;
    HEAP32[$8 >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$this + 36 >> 2] = $dictp;
    HEAP32[$dictp >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject13clearOwnShapeEv($this);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $getter;
    HEAP32[$2 >> 2] = $setter;
    var $3 = __ZNK8JSObject12isExtensibleEv($this);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this;
    var $6 = $cx;
    var $7 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($5, $6, 0);
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $1, $2);
    var $9 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $10 = HEAP32[$1 >> 2];
    var $11 = HEAP32[$2 >> 2];
    var $12 = __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $10, $11, $slot, $attrs, $flags, $shortid, $9);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid, $spp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $child = __stackBase__;
    var $1 = __ZNK8JSObject16inDictionaryModeEv($this);
    var $2 = $this | 0;
    var $3 = HEAPU32[$2 >> 2];
    if ($1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $3;
    var $6 = __ZNK2js5Shape10entryCountEv($5);
    if ($6 >>> 0 > 127) {
      __label__ = 3;
      break;
    } else {
      var $table_0 = 0;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 3:
    var $9 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $12 = HEAP32[$2 >> 2];
    var $13 = __ZNK2js5Shape8getTableEv($12);
    var $table_0 = $13;
    var $_01 = $11;
    __label__ = 9;
    break;
   case 5:
    var $15 = __ZNK2js5Shape8hasTableEv($3);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $table_0 = 0;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 6:
    var $17 = __ZNK2js5Shape8getTableEv($3);
    var $18 = __ZNK2js13PropertyTable11needsToGrowEv($17);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $table_0 = $17;
      var $_01 = $spp;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = __ZN2js13PropertyTable4growEP9JSContext($17, $cx);
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $22 = __ZN2js13PropertyTable6searchEib($17, $id, 1);
    var $table_0 = $17;
    var $_01 = $22;
    __label__ = 9;
    break;
   case 9:
    var $_01;
    var $table_0;
    var $24 = $child;
    var $25 = $getter;
    var $26 = $setter;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($24, $id, $25, $26, $slot, $attrs, $flags, $shortid, -1879048193, 0);
    var $27 = HEAP32[$2 >> 2];
    var $28 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $27, $child);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($table_0 | 0) == 0) {
      var $_0 = $28;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = HEAP32[$_01 >> 2] & 1 | $28;
    HEAP32[$_01 >> 2] = $38;
    var $39 = $table_0 + 4 | 0;
    var $41 = HEAP32[$39 >> 2] + 1 | 0;
    HEAP32[$39 >> 2] = $41;
    var $44 = HEAP32[$28 + 32 >> 2];
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($44, 0);
    var $45 = $28;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($45, $table_0);
    var $_0 = $28;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE["X"] = 1;

function __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $id, $getter, $setter, $slot, $attrs, $flags, $shortid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $child = __stackBase__ + 16;
    var $5 = __stackBase__ + 56;
    HEAP32[$1 >> 2] = $getter;
    HEAP32[$2 >> 2] = $setter;
    HEAP32[$3 >> 2] = $slot;
    HEAP32[$4 >> 2] = $attrs;
    var $6 = $this | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZNK2js5Shape6frozenEv($7);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = __ZN2js5Shape17newDictionaryListEP9JSContextPPS0_($cx, $6);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E($flags, $1, $2);
    var $13 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 1);
    var $16 = HEAP32[$13 >> 2] & -2;
    var $17 = $16;
    if (($16 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $20 = __ZNK8JSObject12isExtensibleEv($this);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $this;
    var $23 = $cx;
    var $24 = __ZN8JSObject19reportNotExtensibleEP9JSContextj($22, $23, 0);
    var $_0 = 0;
    __label__ = 36;
    break;
   case 6:
    var $26 = HEAP32[$1 >> 2];
    var $27 = HEAP32[$2 >> 2];
    var $28 = __ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE($this, $cx, $id, $26, $27, $slot, $attrs, $flags, $shortid, $13);
    var $_0 = $28;
    __label__ = 36;
    break;
   case 7:
    var $30 = __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $this, $17, $4);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 8:
    var $32 = __ZNK2js5Shape7hasSlotEv($17);
    var $34 = HEAPU32[$17 + 24 >> 2];
    var $35 = HEAPU32[$4 >> 2];
    var $37 = ($35 & 64 | 0) == 0;
    var $38 = HEAP32[$3 >> 2];
    if ($37) {
      __label__ = 9;
      break;
    } else {
      var $41 = $38;
      __label__ = 11;
      break;
    }
   case 9:
    if (($38 | 0) != -1 | $32 ^ 1) {
      var $41 = $38;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = $34;
    var $41 = $34;
    __label__ = 11;
    break;
   case 11:
    var $41;
    var $44 = $16;
    var $45 = HEAP32[$1 >> 2];
    var $46 = HEAP32[$2 >> 2];
    var $47 = __ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji($44, $45, $46, $41, $35, $flags, $shortid);
    if ($47) {
      var $_0 = $17;
      __label__ = 36;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($17 | 0) == (HEAP32[$6 >> 2] | 0)) {
      var $shape_0 = $17;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($52) {
      var $shape_0 = $17;
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $54 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($54) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 15:
    var $57 = HEAP32[$17 + 12 >> 2];
    var $58 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $57, 0);
    var $shape_0 = HEAP32[$58 >> 2] & -2;
    __label__ = 16;
    break;
   case 16:
    var $shape_0;
    var $64 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($64) {
      __label__ = 17;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 17:
    if (($41 | 0) == -1 ^ 1 | $37 ^ 1) {
      var $72 = $41;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $68 = $this;
    var $69 = $cx;
    var $70 = __ZN8JSObject9allocSlotEP9JSContextPj($68, $69, $3);
    if ($70) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 36;
      break;
    }
   case 19:
    var $72 = HEAP32[$3 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $72;
    HEAP32[$shape_0 + 24 >> 2] = $72;
    var $74 = HEAPU32[$3 >> 2];
    if (($74 | 0) == -1) {
      __label__ = 27;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $77 = $shape_0 + 4 | 0;
    if ($74 >>> 0 < HEAPU32[$77 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP32[$77 >> 2] = $74 + 1 | 0;
    var $temp_02 = HEAPU32[$6 >> 2];
    if (($temp_02 | 0) == ($shape_0 | 0)) {
      __label__ = 27;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $83 = HEAPU32[$3 >> 2];
    var $84 = $83 + 1 | 0;
    var $temp_03 = $temp_02;
    __label__ = 24;
    break;
   case 24:
    var $temp_03;
    var $86 = $temp_03 + 4 | 0;
    if (HEAPU32[$86 >> 2] >>> 0 > $83 >>> 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    HEAP32[$86 >> 2] = $84;
    __label__ = 26;
    break;
   case 26:
    var $temp_0 = HEAPU32[$temp_03 + 32 >> 2];
    if (($temp_0 | 0) == ($shape_0 | 0)) {
      __label__ = 27;
      break;
    } else {
      var $temp_03 = $temp_0;
      __label__ = 24;
      break;
    }
   case 27:
    var $93 = HEAP32[$1 >> 2];
    HEAP32[$shape_0 + 16 >> 2] = $93;
    var $95 = HEAP32[$2 >> 2];
    HEAP32[$shape_0 + 20 >> 2] = $95;
    HEAP8[$shape_0 + 28 | 0] = HEAP32[$4 >> 2] & 255;
    HEAP8[$shape_0 + 29 | 0] = ($flags | 2) & 255;
    HEAP16[$shape_0 + 30 >> 1] = $shortid & 65535;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape_0, 0);
    var $105 = __Z16js_GenerateShapeP9JSContext($cx);
    var $107 = HEAP32[$6 >> 2] | 0;
    HEAP32[$107 >> 2] = $105;
    __ZN8JSObject13clearOwnShapeEv($this);
    var $shape_1 = $shape_0;
    __label__ = 30;
    break;
   case 28:
    __ZN8JSObject18removeLastPropertyEv($this);
    var $109 = $child;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($109, $id, $45, $46, $41, $35, $flags, $shortid, -1879048193, 0);
    var $110 = HEAP32[$6 >> 2];
    var $111 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $110, $child);
    if (($111 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $shape_1 = $111;
      __label__ = 30;
      break;
    }
   case 29:
    __ZN8JSObject15setLastPropertyEPKN2js5ShapeE($this, $shape_0);
    var $_0 = 0;
    __label__ = 36;
    break;
   case 30:
    var $shape_1;
    if ($32) {
      __label__ = 31;
      break;
    } else {
      var $_0 = $shape_1;
      __label__ = 36;
      break;
    }
   case 31:
    var $116 = __ZNK2js5Shape7hasSlotEv($shape_1);
    if ($116) {
      var $_0 = $shape_1;
      __label__ = 36;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ($34 >>> 0 < HEAPU32[$shape_1 + 4 >> 2] >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    var $122 = $this;
    var $123 = __ZN8JSObject8freeSlotEP9JSContextj($122, undef, $34);
    __label__ = 35;
    break;
   case 34:
    __ZN2JSL14UndefinedValueEv3631($5);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $34, $5);
    __label__ = 35;
    break;
   case 35:
    var $128 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $130 = HEAP32[$128 >> 2] + 1 | 0;
    HEAP32[$128 >> 2] = $130;
    var $_0 = $shape_1;
    __label__ = 36;
    break;
   case 36:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji["X"] = 1;

function __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $obj, $shape, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $shape;
    var $2 = __ZNK2js5Shape12configurableEv($1);
    if ($2) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$attrsp >> 2];
    var $5 = $4 | 4;
    HEAP32[$attrsp >> 2] = $5;
    var $6 = __ZNK2js5Shape16isDataDescriptorEv($shape);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $8 = __ZNK2js5Shape7hasSlotEv($shape);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 4:
    if (($4 & 112 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = HEAP32[$shape + 12 >> 2];
    var $15 = $cx;
    var $16 = __ZN8JSObject21reportNotConfigurableEP9JSContextij(undef, $15, $14, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3631($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E($this, $cx, $shape, $attrs, $mask, $getter, $setter) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $slot = __stackBase__ + 8;
    var $child = __stackBase__ + 12;
    var $child1 = __stackBase__ + 52;
    var $3 = $shape + 28 | 0;
    var $7 = HEAPU8[$3] & 255 & $mask | $attrs;
    HEAP32[$1 >> 2] = $7;
    var $8 = $shape + 12 | 0;
    var $9 = HEAP32[$8 >> 2];
    __ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti($cx, $this, $9);
    if (($7 & 48 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = HEAP32[$8 >> 2];
    __ZN2js5types4Type11UnknownTypeEv($2);
    __ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE($cx, $this, $13, $2);
    __label__ = 3;
    break;
   case 3:
    var $_02 = ($getter | 0) == 10 ? 0 : $getter;
    var $_01 = ($setter | 0) == 12 ? 0 : $setter;
    var $17 = __Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj($cx, $this, $shape, $1);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 4:
    var $21 = HEAPU32[$1 >> 2];
    if ((HEAPU8[$3] & 255 | 0) == ($21 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $24 = __ZNK2js5Shape6getterEv($shape);
    if (($24 | 0) == ($_02 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $27 = __ZNK2js5Shape6setterEv($shape);
    if (($27 | 0) == ($_01 | 0)) {
      var $_0 = $shape;
      __label__ = 23;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($30) {
      __label__ = 8;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 8:
    var $32 = $shape + 24 | 0;
    var $33 = HEAPU32[$32 >> 2];
    HEAP32[$slot >> 2] = $33;
    if (($33 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$32 >> 2] = $33;
    var $45 = $33;
    __label__ = 14;
    break;
   case 10:
    if (($21 & 64 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$32 >> 2] = $33;
    __label__ = 19;
    break;
   case 12:
    var $39 = $this;
    var $40 = $cx;
    var $41 = __ZN8JSObject9allocSlotEP9JSContextPj($39, $40, $slot);
    if ($41) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 13:
    var $_pre = HEAP32[$slot >> 2];
    HEAP32[$32 >> 2] = $_pre;
    if (($_pre | 0) == -1) {
      __label__ = 19;
      break;
    } else {
      var $45 = $_pre;
      __label__ = 14;
      break;
    }
   case 14:
    var $45;
    var $46 = $shape + 4 | 0;
    if ($45 >>> 0 < HEAPU32[$46 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = $45 + 1 | 0;
    HEAP32[$46 >> 2] = $50;
    var $temp_03 = HEAP32[$this >> 2];
    if (($temp_03 | 0) == ($shape | 0)) {
      __label__ = 19;
      break;
    } else {
      var $temp_04 = $temp_03;
      __label__ = 16;
      break;
    }
   case 16:
    var $temp_04;
    var $53 = $temp_04 + 4 | 0;
    if (HEAPU32[$53 >> 2] >>> 0 > $45 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$53 >> 2] = $50;
    __label__ = 18;
    break;
   case 18:
    var $temp_0 = HEAPU32[$temp_04 + 32 >> 2];
    if (($temp_0 | 0) == ($shape | 0)) {
      __label__ = 19;
      break;
    } else {
      var $temp_04 = $temp_0;
      __label__ = 16;
      break;
    }
   case 19:
    HEAP32[$shape + 16 >> 2] = $_02;
    HEAP32[$shape + 20 >> 2] = $_01;
    HEAP8[$3] = $21 & 255;
    __ZN8JSObject11updateFlagsEPKN2js5ShapeEb($this, $shape, 0);
    var $63 = __Z16js_GenerateShapeP9JSContext($cx);
    var $66 = HEAP32[$this >> 2] | 0;
    HEAP32[$66 >> 2] = $63;
    __ZN8JSObject13clearOwnShapeEv($this);
    var $_0 = $shape;
    __label__ = 23;
    break;
   case 20:
    var $71 = HEAP32[$8 >> 2];
    var $73 = HEAP32[$shape + 24 >> 2];
    var $76 = HEAPU8[$shape + 29 | 0] & 255;
    var $79 = HEAP16[$shape + 30 >> 1] << 16 >> 16;
    if ((HEAP32[$this >> 2] | 0) == ($shape | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $81 = $child;
    var $82 = $_02;
    var $83 = $_01;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($81, $71, $82, $83, $73, $21, $76, $79, -1879048193, 0);
    var $85 = HEAP32[$shape + 32 >> 2];
    var $86 = __ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_($this, $cx, $85, $child);
    var $_0 = $86;
    __label__ = 23;
    break;
   case 22:
    var $88 = $child1;
    var $89 = $_02;
    var $90 = $_01;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($88, $71, $89, $90, $73, $21, $76, $79, -1879048193, 0);
    var $92 = HEAP32[$child1 + 12 >> 2];
    var $94 = HEAP32[$child1 + 16 >> 2];
    var $96 = HEAP32[$child1 + 20 >> 2];
    var $98 = HEAP32[$child1 + 24 >> 2];
    var $101 = HEAPU32[$child1 + 28 >> 2];
    var $102 = $101 & 255;
    var $104 = $101 >>> 8 & 255;
    var $105 = $101 >> 16;
    var $106 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $92, $94, $96, $98, $102, $104, $105);
    var $_0 = $106;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E["X"] = 1;

function __ZN8JSObject14removePropertyEP9JSContexti($this, $cx, $id) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $id, 0);
    var $5 = HEAP32[$2 >> 2] & -2;
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK2js5Shape7hasSlotEv($6);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $addedToFreelist_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$6 + 24 >> 2];
    var $13 = $this;
    var $14 = __ZN8JSObject8freeSlotEP9JSContextj($13, undef, $12);
    var $17 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    var $addedToFreelist_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $addedToFreelist_0;
    var $21 = $this | 0;
    if (($6 | 0) == (HEAP32[$21 >> 2] | 0)) {
      var $shape_0 = $6;
      var $spp_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $25 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($25) {
      var $shape_0 = $6;
      var $spp_0 = $2;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = __ZN8JSObject16toDictionaryModeEP9JSContext($this, $cx);
    if ($27) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 30;
      break;
    }
   case 7:
    var $30 = HEAP32[$6 + 12 >> 2];
    var $31 = __ZN8JSObject12nativeSearchEP9JSContextib($this, $cx, $30, 0);
    var $shape_0 = HEAP32[$31 >> 2] & -2;
    var $spp_0 = $31;
    __label__ = 8;
    break;
   case 8:
    var $spp_0;
    var $shape_0;
    var $37 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($37) {
      __label__ = 9;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 9:
    var $39 = HEAP32[$21 >> 2];
    var $40 = __ZNK2js5Shape8hasTableEv($39);
    if ($40) {
      __label__ = 10;
      break;
    } else {
      var $43 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $42 = __ZNK2js5Shape8getTableEv($39);
    var $43 = $42;
    __label__ = 11;
    break;
   case 11:
    var $43;
    if ((HEAP32[$spp_0 >> 2] & 1 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$spp_0 >> 2] = 1;
    var $49 = $43 + 8 | 0;
    var $51 = HEAP32[$49 >> 2] + 1 | 0;
    HEAP32[$49 >> 2] = $51;
    var $52 = $43 + 4 | 0;
    var $54 = HEAP32[$52 >> 2] - 1 | 0;
    HEAP32[$52 >> 2] = $54;
    var $_pre_phi = ($43 | 0) == 0;
    __label__ = 15;
    break;
   case 13:
    var $56 = ($43 | 0) == 0;
    if ($56) {
      var $_pre_phi = $56;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$spp_0 >> 2] = 0;
    var $58 = $43 + 4 | 0;
    var $60 = HEAP32[$58 >> 2] - 1 | 0;
    HEAP32[$58 >> 2] = $60;
    var $_pre_phi = 0;
    __label__ = 15;
    break;
   case 15:
    var $_pre_phi;
    var $62 = $this + 8 | 0;
    var $64 = HEAP32[$62 >> 2] | 128;
    HEAP32[$62 >> 2] = $64;
    var $65 = HEAPU32[$21 >> 2];
    __ZNK2js5Shape20removeFromDictionaryEP8JSObject($shape_0, undef);
    if ($_pre_phi) {
      __label__ = 23;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($shape_0 | 0) == ($65 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    var $69 = $43 + 12 | 0;
    if ((HEAP32[$69 >> 2] | 0) == -1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $74 = HEAP32[$shape_0 + 4 >> 2];
    var $76 = HEAP32[$21 >> 2] + 4 | 0;
    HEAP32[$76 >> 2] = $74;
    if ($addedToFreelist_0 | $9 ^ 1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $84 = $shape_0 + 24 | 0;
    var $85 = HEAPU32[$84 >> 2];
    if ((HEAPU32[HEAP32[$this + 4 >> 2] + 4 >> 2] >>> 8 & 255) >>> 0 > $85 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $88 = HEAP32[$69 >> 2];
    __ZN2JSL18PrivateUint32ValueEj3636($1, $88);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($this, $85, $1);
    var $89 = HEAP32[$84 >> 2];
    HEAP32[$69 >> 2] = $89;
    __label__ = 21;
    break;
   case 21:
    var $91 = $65;
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($91, 0);
    var $93 = HEAP32[$21 >> 2];
    __ZNK2js5Shape8setTableEPNS_13PropertyTableE($93, $43);
    __label__ = 23;
    break;
   case 22:
    __ZN8JSObject18removeLastPropertyEv($this);
    __label__ = 23;
    break;
   case 23:
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    var $97 = HEAP32[$21 >> 2];
    var $98 = __ZNK2js5Shape8hasTableEv($97);
    if ($98) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $100 = __ZNK2js5Shape8getTableEv($97);
    var $101 = __ZNK2js13PropertyTable8capacityEv($100);
    if ($101 >>> 0 > 16) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    if (HEAPU32[$100 + 4 >> 2] >>> 0 > $101 >>> 2 >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $109 = __ZN2js13PropertyTable6changeEiP9JSContext($100, -1, $cx);
    __label__ = 27;
    break;
   case 27:
    var $111 = __ZNK8JSObject13hasSlotsArrayEv($this);
    if ($111) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 28:
    var $113 = __ZNK8JSObject8slotSpanEv($this);
    var $115 = ($113 >>> 2) + $113 | 0;
    var $116 = __ZNK8JSObject8numSlotsEv($this);
    if ($115 >>> 0 < $116 >>> 0) {
      __label__ = 29;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 29:
    var $119 = $this;
    var $120 = $cx;
    __ZN8JSObject11shrinkSlotsEP9JSContextj($119, $120, $113);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSObject14removePropertyEP9JSContexti["X"] = 1;

function __ZN2JSL18PrivateUint32ValueEj3636($agg_result, $ui) {
  __ZN2JS5Value16setPrivateUint32Ej($agg_result, $ui);
  return;
}

function __ZN8JSObject5clearEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $shape_0 = HEAP32[$this >> 2];
    __label__ = 2;
    break;
   case 2:
    var $shape_0;
    var $5 = HEAP32[$shape_0 + 32 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $shape_0 = $5;
      __label__ = 2;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject16inDictionaryModeEv($this);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$shape_0 + 36 >> 2] = $this;
    __label__ = 5;
    break;
   case 5:
    __ZN8JSObject13clearOwnShapeEv($this);
    __ZN8JSObject6setMapEPN2js5ShapeE($this, $shape_0);
    var $14 = HEAP32[$cx + 52 >> 2] + 144252 | 0;
    var $16 = HEAP32[$14 >> 2] + 1 | 0;
    HEAP32[$14 >> 2] = $16;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject18rollbackPropertiesEP9JSContextj($this, $cx, $slotSpan) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject8slotSpanEv($this);
    if (($1 | 0) == ($slotSpan | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject18removeLastPropertyEv($this);
    var $3 = __ZNK8JSObject8slotSpanEv($this);
    if (($3 | 0) == ($slotSpan | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    __ZN8JSObject11updateShapeEP9JSContext($this, $cx);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx) {
  var $1 = __Z16js_GenerateShapeP9JSContext($cx);
  __ZN8JSObject11setOwnShapeEj($this, $1);
  return;
}

function __ZN8JSObject19deletingShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
  return;
}

function _INT_TO_JSID3676($i) {
  return $i << 1 | 1;
}

function __ZNK2js5Shape8getFlagsEv($this) {
  return HEAPU8[$this + 29 | 0] & 255 & 192;
}

function __ZNK8JSObject20getMethodThrashCountEv($this) {
  return HEAPU32[$this + 8 >> 2] >>> 8 & 3;
}

function __ZN8JSObject20setMethodThrashCountEj($this, $count) {
  var $1 = $this + 8 | 0;
  var $5 = HEAP32[$1 >> 2] & -769 | $count << 8;
  HEAP32[$1 >> 2] = $5;
  return;
}

function __ZL26js_IsPropertyCacheDisabledP9JSContext3652($cx_0_11_val) {
  return HEAPU32[$cx_0_11_val + 209944 >> 2] >>> 0 > 16777215 & 1;
}

function __ZN2js13PropertyTableC2Ej($this, $nentries) {
  HEAP32[$this >> 2] = 28;
  HEAP32[$this + 4 >> 2] = $nentries;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = -1;
  return;
}

function __ZNK2js8Bindings9lastUpvarEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js5Shape9setFrozenEv($this) {
  var $1 = $this + 29 | 0;
  var $3 = HEAP8[$1] | 4;
  HEAP8[$1] = $3;
  return;
}

function __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js5Shape8isMethodEv($shape);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $result_0 = $shape;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$shape + 12 >> 2];
    var $6 = HEAP32[$shape + 20 >> 2];
    var $8 = HEAP32[$shape + 24 >> 2];
    var $11 = HEAPU8[$shape + 28 | 0] & 255;
    var $12 = __ZNK2js5Shape8getFlagsEv($shape);
    var $13 = $12 & -129;
    var $16 = HEAP16[$shape + 30 >> 1] << 16 >> 16;
    var $17 = __ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji($this, $cx, $4, 0, $6, $8, $11, $13, $16);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $result_0 = $17;
      __label__ = 3;
      break;
    }
   case 3:
    var $result_0;
    var $20 = $this;
    var $21 = __ZN8JSObject7brandedEv($20);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $23 = __ZNK8JSObject20getMethodThrashCountEv($this);
    if ($23 >>> 0 < 3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $26 = $23 + 1 | 0;
    __ZN8JSObject20setMethodThrashCountEj($this, $26);
    if (($26 | 0) == 3) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = $cx;
    var $30 = __ZN8JSObject7unbrandEP9JSContext($20, $29);
    var $_0 = $result_0;
    __label__ = 8;
    break;
   case 7:
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
    var $_0 = $result_0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject17methodShapeChangeEP9JSContextj($this, $cx, $slot) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = __ZN8JSObject16hasMethodBarrierEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $6 = $r;
    var $7 = HEAP32[$this >> 2];
    __ZNK2js5Shape3allEv($6, $7);
    __label__ = 4;
    break;
   case 4:
    var $9 = __ZNK2js5Shape5Range5emptyEv($6);
    if ($9) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZNK2js5Shape5Range5frontEv($r);
    if ((HEAP32[$11 + 24 >> 2] | 0) == ($slot | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = __ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $11);
    var $_0 = ($16 | 0) != 0;
    __label__ = 8;
    break;
   case 7:
    __ZN2js5Shape5Range8popFrontEv($r);
    __label__ = 4;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject16protoShapeChangeEP9JSContext($this, $cx) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE($this, $cx, $shape) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
  return;
}

function __ZN8JSObject26globalObjectOwnShapeChangeEP9JSContext($this, $cx) {
  __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
  var $cx_idx_val = HEAP32[$cx + 52 >> 2];
  var $1 = __ZL26js_IsPropertyCacheDisabledP9JSContext3652($cx_idx_val);
  return ($1 | 0) == 0;
}

function __ZN2js13PropertyTableC1Ej($this, $nentries) {
  __ZN2js13PropertyTableC2Ej($this, $nentries);
  return;
}

function __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($this, $cx, $name, $indexp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZL12ATOM_TO_JSIDP6JSAtom3673($name);
    var $6 = $cx;
    var $7 = $this;
    var $8 = __ZN2js5Shape6searchEP9JSContextPPS0_ib($6, $7, $5, 0);
    var $11 = HEAP32[$8 >> 2] & -2;
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($indexp | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP16[$12 + 30 >> 1] << 16 >> 16;
    HEAP32[$indexp >> 2] = $19;
    __label__ = 5;
    break;
   case 5:
    var $21 = $11;
    var $22 = __ZNK2js5Shape6getterEv($21);
    if (($22 | 0) == 92) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($22 | 0) == 228) {
      var $_0 = 4;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $27 = $11;
    var $28 = __ZNK2js5Shape8writableEv($27);
    var $29 = $28 ? 2 : 3;
    var $_0 = $29;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ATOM_TO_JSIDP6JSAtom3673($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3746($1);
  return $2;
}

function __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($this, $cx, $name, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $child = __stackBase__;
    var $1 = __ZN2js8Bindings11ensureShapeEP9JSContext($this, $cx);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $3 = ($kind | 0) == 1;
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $5 = $this + 4 | 0;
    var $6 = HEAPU16[$5 >> 1];
    var $slot_0 = ($6 & 65535) + 2 | 0;
    var $setter_0 = 226;
    var $getter_0 = 92;
    var $attrs_1 = 69;
    var $indexp_0 = $5;
    var $24 = $6;
    __label__ = 7;
    break;
   case 4:
    if (($kind | 0) == 4) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $this + 8 | 0;
    var $slot_0 = -1;
    var $setter_0 = 230;
    var $getter_0 = 228;
    var $attrs_1 = 69;
    var $indexp_0 = $12;
    var $24 = HEAP16[$12 >> 1];
    __label__ = 7;
    break;
   case 6:
    var $14 = $this + 6 | 0;
    var $attrs_0 = ($kind | 0) == 3 ? 71 : 69;
    var $19 = HEAPU16[$14 >> 1];
    var $slot_0 = (HEAPU16[$this + 4 >> 1] & 65535) + 2 + ($19 & 65535) | 0;
    var $setter_0 = 232;
    var $getter_0 = 94;
    var $attrs_1 = $attrs_0;
    var $indexp_0 = $14;
    var $24 = $19;
    __label__ = 7;
    break;
   case 7:
    var $24;
    var $indexp_0;
    var $attrs_1;
    var $getter_0;
    var $setter_0;
    var $slot_0;
    if ($24 << 16 >> 16 == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $27 = $3 ? 45 : 199;
    var $28 = $cx;
    _JS_ReportErrorNumber($28, 2, 0, $27, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 9:
    if (($name | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAPU16[$this + 4 >> 1] & 65535;
    var $35 = _INT_TO_JSID3676($34);
    var $id_0 = $35;
    __label__ = 12;
    break;
   case 11:
    var $37 = __ZL12ATOM_TO_JSIDP6JSAtom3673($name);
    var $id_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $id_0;
    var $40 = $child;
    __ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj($40, $id_0, $getter_0, $setter_0, $slot_0, $attrs_1, 64, $24 & 65535, -1879048193, 0);
    var $45 = HEAP32[$this >> 2];
    var $46 = $cx;
    var $47 = $child;
    var $48 = $this;
    var $49 = __ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_($45, $46, $47, $48);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = HEAP16[$indexp_0 >> 1] + 1 & 65535;
    HEAP16[$indexp_0 >> 1] = $53;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE["X"] = 1;

function __ZN2js8Bindings11ensureShapeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext($cx);
    HEAP32[$1 >> 2] = $5 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($this, $cx, $namesp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this;
    var $2 = __ZNK2js8Bindings15countLocalNamesEv($1);
    var $3 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($namesp, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $7 = $r;
    var $8 = HEAP32[$this >> 2];
    __ZN2js5Shape5RangeC1EPKS0_($7, $8);
    var $9 = $r;
    var $10 = __ZNK2js5Shape5Range5emptyEv($9);
    if ($10) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $namesp;
    var $12 = $this + 4 | 0;
    var $13 = $this + 6 | 0;
    __label__ = 4;
    break;
   case 4:
    var $15 = __ZNK2js5Shape5Range5frontEv($7);
    var $18 = HEAPU16[$15 + 30 >> 1] & 65535;
    var $19 = __ZNK2js5Shape6getterEv($15);
    if (($19 | 0) == 92) {
      var $index_0 = $18;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = HEAPU16[$12 >> 1] & 65535;
    if (($19 | 0) == 228) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $index_0 = $24 + $18 + (HEAPU16[$13 >> 1] & 65535) | 0;
    __label__ = 8;
    break;
   case 7:
    var $index_0 = $24 + $18 | 0;
    __label__ = 8;
    break;
   case 8:
    var $index_0;
    var $34 = HEAP32[$15 + 12 >> 2];
    var $35 = __ZL12JSID_IS_ATOMi3679($34);
    if (($35 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = __ZL12JSID_TO_ATOMi3680($34);
    var $39 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($11, $index_0);
    HEAP32[$39 >> 2] = $38;
    __label__ = 11;
    break;
   case 10:
    var $41 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($11, $index_0);
    HEAP32[$41 >> 2] = 0;
    __label__ = 11;
    break;
   case 11:
    __ZN2js5Shape5Range8popFrontEv($7);
    var $43 = __ZNK2js5Shape5Range5emptyEv($9);
    if ($43) {
      var $_0 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE["X"] = 1;

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj($this, $incr) {
  var $1 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr);
  return $1;
}

function __ZL12JSID_IS_ATOMi3679($id) {
  var $1 = _JSID_IS_STRING3745($id);
  return $1;
}

function __ZL12JSID_TO_ATOMi3680($id) {
  var $1 = _JSID_TO_STRING3744($id);
  return $1;
}

function __ZNK2js8Bindings12lastArgumentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8Bindings12lastVariableEv($this);
    if (HEAP16[$this + 6 >> 1] << 16 >> 16 == 0) {
      var $shape_1 = $1;
      __label__ = 5;
      break;
    } else {
      var $shape_0 = $1;
      __label__ = 2;
      break;
    }
   case 2:
    var $shape_0;
    var $5 = $shape_0;
    var $6 = __ZNK2js5Shape8previousEv($5);
    if (($6 | 0) == 0) {
      var $shape_1 = $shape_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK2js5Shape6getterEv($5);
    if (($9 | 0) == 92) {
      var $shape_1 = $shape_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $shape_0 = $6;
    __label__ = 2;
    break;
   case 5:
    var $shape_1;
    return $shape_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js8Bindings12lastVariableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js8Bindings9lastUpvarEv($this);
    if (HEAP16[$this + 8 >> 1] << 16 >> 16 == 0) {
      var $shape_1 = $1;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $1;
    var $6 = __ZNK2js5Shape6getterEv($5);
    if (($6 | 0) == 228) {
      var $8 = $5;
      __label__ = 3;
      break;
    } else {
      var $shape_1 = $1;
      __label__ = 5;
      break;
    }
   case 3:
    var $8;
    var $9 = __ZNK2js5Shape8previousEv($8);
    var $10 = __ZNK2js5Shape6getterEv($9);
    if (($10 | 0) == 228) {
      var $8 = $9;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $shape_1 = $9;
    __label__ = 5;
    break;
   case 5:
    var $shape_1;
    return $shape_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings13sharpSlotBaseEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = $cx;
    var $2 = __Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE($1, STRING_TABLE.__str3667 | 0, 6, 0, 0);
    if (($2 | 0) == 0) {
      var $_0 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$index >> 2] = -1;
    var $5 = __ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj($this, $cx, $2, $index);
    var $_0 = HEAP32[$index >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings13makeImmutableEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = $2;
    var $4 = __ZNK2js5Shape12inDictionaryEv($3);
    if ($4) {
      var $shape_0 = $2;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $shape_0;
    __ZN2js5Shape9setFrozenEv($shape_0);
    var $6 = HEAP32[$shape_0 + 32 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $shape_0 = $6;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Bindings5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $trc;
    var $6 = $2;
    __ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc($5, $6, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_XDRScriptP10JSXDRStatePP8JSScript($xdr, $scriptp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 136;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $length = __stackBase__;
    var $lineno = __stackBase__ + 4;
    var $nslots = __stackBase__ + 8;
    var $natoms = __stackBase__ + 12;
    var $nsrcnotes = __stackBase__ + 16;
    var $ntrynotes = __stackBase__ + 20;
    var $nobjects = __stackBase__ + 24;
    var $nregexps = __stackBase__ + 28;
    var $nconsts = __stackBase__ + 32;
    var $prologLength = __stackBase__ + 36;
    var $version = __stackBase__ + 40;
    var $encodedClosedCount = __stackBase__ + 44;
    var $nTypeSets = __stackBase__ + 48;
    var $principals = __stackBase__ + 52;
    var $encodeable = __stackBase__ + 56;
    var $scriptBits = __stackBase__ + 60;
    var $argsVars = __stackBase__ + 64;
    var $paddingUpvars = __stackBase__ + 68;
    var $bindings = __stackBase__ + 72;
    var $automark = __stackBase__ + 84;
    var $names = __stackBase__ + 92;
    var $1 = __stackBase__ + 116;
    var $dummy = __stackBase__ + 120;
    var $name = __stackBase__ + 124;
    var $isBlock = __stackBase__ + 128;
    var $kindAndDepth = __stackBase__ + 132;
    HEAP32[$nTypeSets >> 2] = 0;
    HEAP32[$scriptBits >> 2] = 0;
    var $2 = $xdr + 8 | 0;
    var $3 = HEAPU32[$2 >> 2];
    var $4 = HEAPU32[$scriptp >> 2];
    HEAP32[$nconsts >> 2] = 0;
    HEAP32[$nregexps >> 2] = 0;
    HEAP32[$nobjects >> 2] = 0;
    HEAP32[$natoms >> 2] = 0;
    HEAP32[$ntrynotes >> 2] = 0;
    HEAP32[$nsrcnotes >> 2] = 0;
    var $6 = HEAP32[$xdr + 36 >> 2];
    var $7 = $xdr | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $nupvars_0 = -1;
      var $nargs_0 = -1;
      var $nvars_0 = -1;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = $4 + 64 | 0;
    var $13 = __ZNK2js8Bindings9countArgsEv($12);
    var $14 = __ZNK2js8Bindings9countVarsEv($12);
    var $15 = __ZNK2js8Bindings11countUpvarsEv($12);
    HEAP32[$argsVars >> 2] = ($13 & 65535) << 16 | $14 & 65535;
    HEAP32[$paddingUpvars >> 2] = $15 & 65535;
    var $nupvars_0 = $15;
    var $nargs_0 = $13;
    var $nvars_0 = $14;
    __label__ = 3;
    break;
   case 3:
    var $nvars_0;
    var $nargs_0;
    var $nupvars_0;
    var $22 = $xdr;
    var $23 = _JS_XDRUint32($22, $argsVars);
    if (($23 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = _JS_XDRUint32($22, $paddingUpvars);
    if (($26 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $29 = HEAPU32[$7 >> 2];
    if (($29 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $nupvars_1 = $nupvars_0;
      var $nargs_1 = $nargs_0;
      var $nvars_1 = $nvars_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $32 = HEAPU32[$argsVars >> 2];
    var $nupvars_1 = HEAP32[$paddingUpvars >> 2] & 65535;
    var $nargs_1 = $32 >>> 16 & 65535;
    var $nvars_1 = $32 & 65535;
    __label__ = 7;
    break;
   case 7:
    var $nvars_1;
    var $nargs_1;
    var $nupvars_1;
    var $39 = $bindings;
    var $40 = $3;
    __ZN2js8BindingsC1EP9JSContext($39, undef);
    var $41 = $nargs_1 & 65535;
    var $43 = $41 + ($nvars_1 & 65535) | 0;
    var $44 = $nupvars_1 & 65535;
    var $45 = $43 + $44 | 0;
    if (($45 | 0) == 0) {
      var $153 = $29;
      __label__ = 39;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $48 = $3 + 72 | 0;
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool($automark, $48);
    var $49 = $45 + 31 | 0;
    var $50 = $49 >>> 5;
    var $52 = HEAPU32[$3 + 88 >> 2];
    var $56 = HEAP32[$3 + 96 >> 2];
    var $59 = $56 + ($49 >>> 3 & 536870908) & ($56 ^ -1);
    var $60 = $52 + 12 | 0;
    var $61 = HEAPU32[$60 >> 2];
    var $63 = HEAPU32[$52 + 8 >> 2];
    if ($59 >>> 0 > $63 >>> 0 | $61 >>> 0 > ($63 - $59 | 0) >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $68 = _JS_ArenaAllocate($48, $59);
    var $_p_0 = $68;
    __label__ = 11;
    break;
   case 10:
    var $71 = $59 + $61 | 0;
    HEAP32[$60 >> 2] = $71;
    var $_p_0 = $61;
    __label__ = 11;
    break;
   case 11:
    var $_p_0;
    var $73 = $_p_0;
    if (($_p_0 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __Z20js_ReportOutOfMemoryP9JSContext($40);
    var $automark_idx12_val = HEAP32[$automark >> 2];
    var $automark_idx13_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx12_val, $automark_idx13_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 13:
    __ZN2js15TempAllocPolicyC1EP9JSContext($1, $40);
    var $76 = $names;
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_($76, $1);
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      var $i2_0 = 0;
      __label__ = 20;
      break;
    }
   case 14:
    var $80 = $4 + 64 | 0;
    var $81 = __ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE($80, undef, $names);
    if ($81) {
      __label__ = 15;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 15:
    __ZN2jsL7PodZeroIjEEvPT_j($73, $50);
    var $i1_011 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i1_011;
    if ($i1_011 >>> 0 < $41 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $85 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($76, $i1_011);
    if ((HEAP32[$85 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $92 = $73 + ($i1_011 >>> 5 << 2) | 0;
    var $94 = HEAP32[$92 >> 2] | 1 << ($i1_011 & 31);
    HEAP32[$92 >> 2] = $94;
    __label__ = 19;
    break;
   case 19:
    var $96 = $i1_011 + 1 | 0;
    if (($96 | 0) == ($45 | 0)) {
      var $i2_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $i1_011 = $96;
      __label__ = 16;
      break;
    }
   case 20:
    var $i2_0;
    if ($i2_0 >>> 0 < $50 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $98 = $name;
    var $i3_0 = 0;
    __label__ = 24;
    break;
   case 22:
    var $101 = _JS_XDRUint32($22, $73 + ($i2_0 << 2) | 0);
    if (($101 | 0) == 0) {
      __label__ = 166;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 20;
    break;
   case 24:
    var $i3_0;
    if ($i3_0 >>> 0 < $45 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 25:
    var $108 = $i3_0 >>> 0 < $41 >>> 0;
    if ($108) {
      __label__ = 26;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 26:
    if ((HEAP32[$73 + ($i3_0 >>> 5 << 2) >> 2] & 1 << ($i3_0 & 31) | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 27:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 28;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 28:
    var $121 = __ZN2js8Bindings16addDestructuringEP9JSContextPt($39, $40, $dummy);
    if ($121) {
      __label__ = 37;
      break;
    } else {
      __label__ = 167;
      break;
    }
   case 29:
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $125 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj($76, $i3_0);
    var $126 = HEAP32[$125 >> 2];
    HEAP32[$name >> 2] = $126;
    __label__ = 31;
    break;
   case 31:
    var $128 = _js_XDRAtom($22, $98);
    if (($128 | 0) == 0) {
      __label__ = 168;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 33;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 33:
    if ($108) {
      var $146 = 1;
      __label__ = 36;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    if ($i3_0 >>> 0 < $43 >>> 0) {
      __label__ = 35;
      break;
    } else {
      var $146 = 4;
      __label__ = 36;
      break;
    }
   case 35:
    var $144 = (HEAP32[$73 + ($i3_0 >>> 5 << 2) >> 2] & 1 << ($i3_0 & 31) | 0) != 0 ? 3 : 2;
    var $146 = $144;
    __label__ = 36;
    break;
   case 36:
    var $146;
    var $147 = HEAP32[$name >> 2];
    var $148 = __ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE($bindings, $3, $147, $146);
    if ($148) {
      __label__ = 37;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 37:
    var $i3_0 = $i3_0 + 1 | 0;
    __label__ = 24;
    break;
   case 38:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx10_val = HEAP32[$automark >> 2];
    var $automark_idx11_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx10_val, $automark_idx11_val);
    var $153 = HEAP32[$7 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $153;
    if (($153 | 0) == 1) {
      __label__ = 40;
      break;
    } else {
      var $159 = $153;
      __label__ = 42;
      break;
    }
   case 40:
    var $156 = __ZN2js8Bindings11ensureShapeEP9JSContext($bindings, $3);
    if ($156) {
      __label__ = 41;
      break;
    } else {
      var $_2 = 0;
      __label__ = 170;
      break;
    }
   case 41:
    __ZN2js8Bindings13makeImmutableEv($bindings);
    var $159 = HEAP32[$7 >> 2];
    __label__ = 42;
    break;
   case 42:
    var $159;
    if (($159 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    var $163 = HEAP32[$4 + 8 >> 2];
    HEAP32[$length >> 2] = $163;
    __label__ = 44;
    break;
   case 44:
    var $165 = _JS_XDRUint32($22, $length);
    if (($165 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      var $nClosedArgs_0 = 0;
      var $nClosedVars_0 = 0;
      var $notes_0 = 0;
      __label__ = 66;
      break;
    }
   case 46:
    var $172 = HEAP32[$4 + 32 >> 2];
    HEAP32[$prologLength >> 2] = $172;
    var $173 = $4;
    var $174 = __ZNK8JSScript10getVersionEv($173);
    HEAP32[$version >> 2] = (HEAPU16[$4 + 14 >> 1] & 65535) << 16 | $174;
    var $181 = HEAP32[$4 + 28 >> 2];
    HEAP32[$lineno >> 2] = $181;
    var $182 = $4 + 44 | 0;
    HEAP32[$nslots >> 2] = HEAPU16[$182 >> 1] & 65535;
    HEAP32[$nslots >> 2] = (HEAPU16[$4 + 46 >> 1] & 65535) << 16 | HEAPU16[$182 >> 1] & 65535;
    var $193 = HEAP32[$4 + 40 >> 2];
    HEAP32[$natoms >> 2] = $193;
    var $194 = __ZN8JSScript5notesEv($173);
    var $195 = __ZN8JSScript8numNotesEv($4);
    HEAP32[$nsrcnotes >> 2] = $195;
    var $197 = HEAP8[$4 + 16 | 0];
    var $198 = __ZN8JSScript13isValidOffsetEh($197);
    if ($198) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $200 = __ZN8JSScript7objectsEv($173);
    var $202 = HEAP32[$200 + 4 >> 2];
    HEAP32[$nobjects >> 2] = $202;
    __label__ = 48;
    break;
   case 48:
    var $205 = HEAP8[$4 + 18 | 0];
    var $206 = __ZN8JSScript13isValidOffsetEh($205);
    if ($206) {
      __label__ = 49;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 49:
    var $208 = $4;
    var $209 = __ZN8JSScript7regexpsEv($208);
    var $211 = HEAP32[$209 + 4 >> 2];
    HEAP32[$nregexps >> 2] = $211;
    __label__ = 50;
    break;
   case 50:
    var $214 = HEAP8[$4 + 19 | 0];
    var $215 = __ZN8JSScript13isValidOffsetEh($214);
    if ($215) {
      __label__ = 51;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 51:
    var $217 = __ZN8JSScript8trynotesEv($173);
    var $219 = HEAP32[$217 + 4 >> 2];
    HEAP32[$ntrynotes >> 2] = $219;
    __label__ = 52;
    break;
   case 52:
    var $222 = HEAP8[$4 + 21 | 0];
    var $223 = __ZN8JSScript13isValidOffsetEh($222);
    if ($223) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $225 = __ZN8JSScript6constsEv($173);
    var $227 = HEAP32[$225 + 4 >> 2];
    HEAP32[$nconsts >> 2] = $227;
    __label__ = 54;
    break;
   case 54:
    var $230 = HEAPU16[$4 + 48 >> 1];
    var $232 = HEAPU16[$4 + 50 >> 1];
    HEAP32[$encodedClosedCount >> 2] = ($230 & 65535) << 16 | $232 & 65535;
    HEAP32[$nTypeSets >> 2] = HEAPU16[$4 + 22 >> 1] & 65535;
    var $240 = $4 + 36 | 0;
    var $241 = HEAPU8[$240];
    if (($241 & 1) << 24 >> 24 == 0) {
      var $248 = $241;
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $246 = HEAP32[$scriptBits >> 2] | 1;
    HEAP32[$scriptBits >> 2] = $246;
    var $248 = HEAP8[$240];
    __label__ = 56;
    break;
   case 56:
    var $248;
    if (($248 & 2) << 24 >> 24 == 0) {
      var $255 = $248;
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $253 = HEAP32[$scriptBits >> 2] | 2;
    HEAP32[$scriptBits >> 2] = $253;
    var $255 = HEAP8[$240];
    __label__ = 58;
    break;
   case 58:
    var $255;
    if (($255 & 4) << 24 >> 24 == 0) {
      var $262 = $255;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $260 = HEAP32[$scriptBits >> 2] | 4;
    HEAP32[$scriptBits >> 2] = $260;
    var $262 = HEAP8[$240];
    __label__ = 60;
    break;
   case 60:
    var $262;
    if (($262 & 8) << 24 >> 24 == 0) {
      var $269 = $262;
      __label__ = 62;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $267 = HEAP32[$scriptBits >> 2] | 8;
    HEAP32[$scriptBits >> 2] = $267;
    var $269 = HEAP8[$240];
    __label__ = 62;
    break;
   case 62:
    var $269;
    if (($269 & 32) << 24 >> 24 == 0) {
      var $276 = $269;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $274 = HEAP32[$scriptBits >> 2] | 16;
    HEAP32[$scriptBits >> 2] = $274;
    var $276 = HEAP8[$240];
    __label__ = 64;
    break;
   case 64:
    var $276;
    if (($276 & 64) << 24 >> 24 == 0) {
      var $nClosedArgs_0 = $230;
      var $nClosedVars_0 = $232;
      var $notes_0 = $194;
      __label__ = 66;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $281 = HEAP32[$scriptBits >> 2] | 32;
    HEAP32[$scriptBits >> 2] = $281;
    var $nClosedArgs_0 = $230;
    var $nClosedVars_0 = $232;
    var $notes_0 = $194;
    __label__ = 66;
    break;
   case 66:
    var $notes_0;
    var $nClosedVars_0;
    var $nClosedArgs_0;
    var $283 = _JS_XDRUint32($22, $prologLength);
    if (($283 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $286 = _JS_XDRUint32($22, $version);
    if (($286 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $289 = _JS_XDRUint32($22, $natoms);
    if (($289 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $292 = _JS_XDRUint32($22, $nsrcnotes);
    if (($292 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $295 = _JS_XDRUint32($22, $ntrynotes);
    if (($295 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $298 = _JS_XDRUint32($22, $nobjects);
    if (($298 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    var $301 = _JS_XDRUint32($22, $nregexps);
    if (($301 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    var $304 = _JS_XDRUint32($22, $nconsts);
    if (($304 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $307 = _JS_XDRUint32($22, $encodedClosedCount);
    if (($307 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $310 = _JS_XDRUint32($22, $nTypeSets);
    if (($310 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    var $313 = _JS_XDRUint32($22, $scriptBits);
    if (($313 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 78;
      break;
    } else {
      var $nClosedArgs_1 = $nClosedArgs_0;
      var $nClosedVars_1 = $nClosedVars_0;
      var $script_0 = $4;
      var $notes_1 = $notes_0;
      __label__ = 91;
      break;
    }
   case 78:
    var $319 = HEAPU32[$encodedClosedCount >> 2];
    var $321 = $319 >>> 16 & 65535;
    var $322 = $319 & 65535;
    var $324 = HEAP32[$version >> 2] & 65535;
    var $325 = HEAP32[$length >> 2];
    var $326 = HEAP32[$nsrcnotes >> 2];
    var $327 = HEAP32[$natoms >> 2];
    var $328 = HEAP32[$nobjects >> 2];
    var $329 = HEAP32[$nregexps >> 2];
    var $330 = HEAP32[$ntrynotes >> 2];
    var $331 = HEAP32[$nconsts >> 2];
    var $332 = HEAP32[$nTypeSets >> 2];
    var $333 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($3, $325, $326, $327, $328, $44, $329, $330, $331, 0, $321, $322, $332, $324);
    if (($333 | 0) == 0) {
      var $_2 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $337 = $333 + 64 | 0;
    __ZN2js8Bindings8transferEP9JSContextPS0_($337, undef, $39);
    var $338 = HEAP32[$prologLength >> 2];
    var $339 = $333 + 32 | 0;
    HEAP32[$339 >> 2] = $338;
    HEAP16[$333 + 14 >> 1] = HEAPU32[$version >> 2] >>> 16 & 65535;
    var $344 = $333;
    var $345 = __ZN8JSScript5notesEv($344);
    HEAP32[$scriptp >> 2] = $333;
    var $346 = HEAPU32[$scriptBits >> 2];
    if (($346 & 1 | 0) == 0) {
      var $354 = $346;
      __label__ = 81;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    var $350 = $333 + 36 | 0;
    var $352 = HEAP8[$350] | 1;
    HEAP8[$350] = $352;
    var $354 = HEAP32[$scriptBits >> 2];
    __label__ = 81;
    break;
   case 81:
    var $354;
    if (($354 & 2 | 0) == 0) {
      var $362 = $354;
      __label__ = 83;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $358 = $333 + 36 | 0;
    var $360 = HEAP8[$358] | 2;
    HEAP8[$358] = $360;
    var $362 = HEAP32[$scriptBits >> 2];
    __label__ = 83;
    break;
   case 83:
    var $362;
    if (($362 & 4 | 0) == 0) {
      var $370 = $362;
      __label__ = 85;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 84:
    var $366 = $333 + 36 | 0;
    var $368 = HEAP8[$366] | 4;
    HEAP8[$366] = $368;
    var $370 = HEAP32[$scriptBits >> 2];
    __label__ = 85;
    break;
   case 85:
    var $370;
    if (($370 & 8 | 0) == 0) {
      var $378 = $370;
      __label__ = 87;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $374 = $333 + 36 | 0;
    var $376 = HEAP8[$374] | 8;
    HEAP8[$374] = $376;
    var $378 = HEAP32[$scriptBits >> 2];
    __label__ = 87;
    break;
   case 87:
    var $378;
    if (($378 & 16 | 0) == 0) {
      var $386 = $378;
      __label__ = 89;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $382 = $333 + 36 | 0;
    var $384 = HEAP8[$382] | 32;
    HEAP8[$382] = $384;
    var $386 = HEAP32[$scriptBits >> 2];
    __label__ = 89;
    break;
   case 89:
    var $386;
    if (($386 & 32 | 0) == 0) {
      var $nClosedArgs_1 = $321;
      var $nClosedVars_1 = $322;
      var $script_0 = $333;
      var $notes_1 = $345;
      __label__ = 91;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $390 = $333 + 36 | 0;
    var $392 = HEAP8[$390] | 64;
    HEAP8[$390] = $392;
    var $nClosedArgs_1 = $321;
    var $nClosedVars_1 = $322;
    var $script_0 = $333;
    var $notes_1 = $345;
    __label__ = 91;
    break;
   case 91:
    var $notes_1;
    var $script_0;
    var $nClosedVars_1;
    var $nClosedArgs_1;
    var $393 = $xdr + 32 | 0;
    var $394 = HEAP32[$393 >> 2];
    var $395 = $script_0 | 0;
    var $396 = HEAP32[$395 >> 2];
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 92;
      break;
    } else {
      var $code_0 = $396;
      __label__ = 93;
      break;
    }
   case 92:
    var $400 = $3;
    var $402 = _js_UntrapScriptCode($400, $script_0);
    if (($402 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      var $code_0 = $402;
      __label__ = 93;
      break;
    }
   case 93:
    var $code_0;
    HEAP32[$393 >> 2] = $script_0;
    var $405 = HEAP32[$length >> 2];
    var $406 = _JS_XDRBytes($22, $code_0, $405);
    if (($code_0 | 0) == (HEAP32[$395 >> 2] | 0)) {
      __label__ = 95;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    __ZN9JSContext5free_EPv(undef, $code_0);
    __label__ = 95;
    break;
   case 95:
    if (($406 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    var $413 = HEAP32[$nsrcnotes >> 2];
    var $414 = _JS_XDRBytes($22, $notes_1, $413);
    if (($414 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $417 = _JS_XDRUint32($22, $lineno);
    if (($417 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $420 = _JS_XDRUint32($22, $nslots);
    if (($420 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $423 = HEAP32[$7 >> 2];
    if (($423 | 0) == 1) {
      __label__ = 100;
      break;
    } else {
      var $443 = $423;
      __label__ = 105;
      break;
    }
   case 100:
    var $426 = $6 + 4 | 0;
    var $427 = HEAP32[$426 >> 2];
    if (($427 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 101:
    var $429 = _JS_GetSecurityCallbacks($40);
    var $469 = $429;
    __label__ = 111;
    break;
   case 102:
    var $431 = $6 + 8 | 0;
    if ((HEAP8[$431] & 1) << 24 >> 24 == 0) {
      __label__ = 103;
      break;
    } else {
      var $441 = $427;
      __label__ = 104;
      break;
    }
   case 103:
    var $436 = HEAP32[$2 >> 2];
    var $437 = __ZL18SaveScriptFilenameP9JSContextPKc($436, $427);
    var $438 = HEAP32[$426 >> 2];
    __ZN9JSContext5free_EPv(undef, $438);
    HEAP32[$426 >> 2] = $437;
    HEAP8[$431] = 1;
    if (($437 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      var $441 = $437;
      __label__ = 104;
      break;
    }
   case 104:
    var $441;
    HEAP32[$script_0 + 52 >> 2] = $441;
    var $443 = HEAP32[$7 >> 2];
    __label__ = 105;
    break;
   case 105:
    var $443;
    var $444 = _JS_GetSecurityCallbacks($40);
    if (($443 | 0) == 0) {
      __label__ = 106;
      break;
    } else {
      var $469 = $444;
      __label__ = 111;
      break;
    }
   case 106:
    var $448 = HEAP32[$script_0 + 76 >> 2];
    HEAP32[$principals >> 2] = $448;
    if (($444 | 0) == 0) {
      var $455 = 0;
      __label__ = 108;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $455 = (HEAP32[$444 + 4 >> 2] | 0) != 0;
    __label__ = 108;
    break;
   case 108:
    var $455;
    HEAP32[$encodeable >> 2] = $455 & 1;
    var $457 = _JS_XDRUint32($22, $encodeable);
    if (($457 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    if ((HEAP32[$encodeable >> 2] | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $465 = HEAP32[$444 + 4 >> 2];
    var $466 = FUNCTION_TABLE[$465]($xdr, $principals);
    if (($466 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 111:
    var $469;
    var $470 = _JS_XDRUint32($22, $encodeable);
    if (($470 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    if ((HEAP32[$encodeable >> 2] | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    if (($469 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $479 = HEAP32[$469 + 4 >> 2];
    if (($479 | 0) == 0) {
      __label__ = 115;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 115:
    _JS_ReportErrorNumber($40, 2, 0, 167, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __label__ = 162;
    break;
   case 116:
    var $483 = $479;
    var $484 = FUNCTION_TABLE[$483]($xdr, $principals);
    if (($484 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $487 = HEAP32[$principals >> 2];
    HEAP32[$script_0 + 76 >> 2] = $487;
    __label__ = 118;
    break;
   case 118:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 119;
      break;
    } else {
      __label__ = 120;
      break;
    }
   case 119:
    var $493 = HEAP32[$lineno >> 2];
    HEAP32[$script_0 + 28 >> 2] = $493;
    HEAP16[$script_0 + 44 >> 1] = HEAP32[$nslots >> 2] & 65535;
    HEAP16[$script_0 + 46 >> 1] = HEAPU32[$nslots >> 2] >>> 16 & 65535;
    __label__ = 120;
    break;
   case 120:
    var $502 = $script_0 + 56 | 0;
    var $i_0 = 0;
    __label__ = 121;
    break;
   case 121:
    var $i_0;
    if (($i_0 | 0) == (HEAP32[$natoms >> 2] | 0)) {
      __label__ = 122;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 122:
    var $506 = $script_0;
    var $507 = $xdr;
    var $i_1 = 0;
    __label__ = 125;
    break;
   case 123:
    var $511 = HEAP32[$502 >> 2] + ($i_0 << 2) | 0;
    var $512 = _js_XDRAtom($22, $511);
    if (($512 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 121;
    break;
   case 125:
    var $i_1;
    if (($i_1 | 0) == (HEAP32[$nobjects >> 2] | 0)) {
      var $i_2 = 0;
      __label__ = 133;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $520 = __ZN8JSScript7objectsEv($506);
    var $523 = HEAP32[$520 >> 2] + ($i_1 << 2) | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 127:
    var $528 = HEAP32[$523 >> 2];
    var $529 = __ZNK8JSObject8getClassEv($528);
    var $531 = ($529 | 0) == (__ZN2js10BlockClassE | 0) & 1;
    HEAP32[$isBlock >> 2] = $531;
    __label__ = 128;
    break;
   case 128:
    var $533 = _JS_XDRUint32($22, $isBlock);
    if (($533 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 129:
    if ((HEAP32[$isBlock >> 2] | 0) == 0) {
      __label__ = 130;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 130:
    var $539 = $523;
    var $540 = __Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject($507, $539);
    if (($540 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 131:
    var $543 = __Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject($xdr, $523);
    if (($543 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 132:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 125;
    break;
   case 133:
    var $i_2;
    if (($i_2 | 0) == ($44 | 0)) {
      __label__ = 134;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 134:
    var $548 = $script_0;
    var $549 = $xdr;
    var $i_3 = 0;
    __label__ = 137;
    break;
   case 135:
    var $551 = __ZN8JSScript6upvarsEv($506);
    var $554 = HEAP32[$551 >> 2] + ($i_2 << 2) | 0;
    var $555 = _JS_XDRUint32($22, $554);
    if (($555 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 136:
    var $i_2 = $i_2 + 1 | 0;
    __label__ = 133;
    break;
   case 137:
    var $i_3;
    if (($i_3 | 0) == (HEAP32[$nregexps >> 2] | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $562 = $nClosedArgs_1 & 65535;
    var $563 = $script_0 + 88 | 0;
    var $i_4 = 0;
    __label__ = 141;
    break;
   case 139:
    var $565 = __ZN8JSScript7regexpsEv($548);
    var $569 = HEAP32[$565 >> 2] + ($i_3 << 2) | 0;
    var $570 = __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject($549, $569);
    if (($570 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 140:
    var $i_3 = $i_3 + 1 | 0;
    __label__ = 137;
    break;
   case 141:
    var $i_4;
    if (($i_4 | 0) == ($562 | 0)) {
      __label__ = 142;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 142:
    var $576 = $nClosedVars_1 & 65535;
    var $i_5 = 0;
    __label__ = 145;
    break;
   case 143:
    var $579 = HEAP32[$563 >> 2] + ($i_4 << 2) | 0;
    var $580 = _JS_XDRUint32($22, $579);
    if (($580 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 144:
    var $i_4 = $i_4 + 1 | 0;
    __label__ = 141;
    break;
   case 145:
    var $i_5;
    if (($i_5 | 0) == ($576 | 0)) {
      __label__ = 148;
      break;
    } else {
      __label__ = 146;
      break;
    }
   case 146:
    var $589 = HEAP32[$563 >> 2] + ($i_5 + $562 << 2) | 0;
    var $590 = _JS_XDRUint32($22, $589);
    if (($590 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $i_5 = $i_5 + 1 | 0;
    __label__ = 145;
    break;
   case 148:
    var $595 = HEAP32[$ntrynotes >> 2];
    if (($595 | 0) == 0) {
      var $i_6 = 0;
      __label__ = 158;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    var $598 = __ZN8JSScript8trynotesEv($506);
    var $600 = HEAPU32[$598 >> 2];
    var $tn_0 = $600 + $595 * 12 | 0;
    __label__ = 150;
    break;
   case 150:
    var $tn_0;
    var $602 = $tn_0 - 12 | 0;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      __label__ = 151;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 151:
    HEAP32[$kindAndDepth >> 2] = (HEAPU8[$602 | 0] & 255) << 16 | HEAPU16[$tn_0 - 12 + 2 >> 1] & 65535;
    __label__ = 152;
    break;
   case 152:
    var $615 = _JS_XDRUint32($22, $kindAndDepth);
    if (($615 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 153:
    var $619 = _JS_XDRUint32($22, $tn_0 - 12 + 4 | 0);
    if (($619 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 154;
      break;
    }
   case 154:
    var $623 = _JS_XDRUint32($22, $tn_0 - 12 + 8 | 0);
    if (($623 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 156;
      break;
    } else {
      __label__ = 157;
      break;
    }
   case 156:
    HEAP8[$602 | 0] = HEAPU32[$kindAndDepth >> 2] >>> 16 & 255;
    HEAP16[$tn_0 - 12 + 2 >> 1] = HEAP32[$kindAndDepth >> 2] & 65535;
    __label__ = 157;
    break;
   case 157:
    if (($602 | 0) == ($600 | 0)) {
      var $i_6 = 0;
      __label__ = 158;
      break;
    } else {
      var $tn_0 = $602;
      __label__ = 150;
      break;
    }
   case 158:
    var $i_6;
    if (($i_6 | 0) == (HEAP32[$nconsts >> 2] | 0)) {
      __label__ = 161;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    var $641 = __ZN8JSScript6constsEv($506);
    var $644 = HEAP32[$641 >> 2] + ($i_6 << 3) | 0;
    var $645 = _JS_XDRValue($22, $644);
    if (($645 | 0) == 0) {
      __label__ = 162;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 160:
    var $i_6 = $i_6 + 1 | 0;
    __label__ = 158;
    break;
   case 161:
    HEAP32[$393 >> 2] = $394;
    var $_2 = 1;
    __label__ = 170;
    break;
   case 162:
    if ((HEAP32[$7 >> 2] | 0) == 1) {
      __label__ = 163;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 163:
    HEAP32[$scriptp >> 2] = 0;
    __label__ = 164;
    break;
   case 164:
    HEAP32[$393 >> 2] = $394;
    var $_2 = 0;
    __label__ = 170;
    break;
   case 165:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx8_val = HEAP32[$automark >> 2];
    var $automark_idx9_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx8_val, $automark_idx9_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 166:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx6_val = HEAP32[$automark >> 2];
    var $automark_idx7_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx6_val, $automark_idx7_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 167:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx4_val = HEAP32[$automark >> 2];
    var $automark_idx5_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx4_val, $automark_idx5_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 168:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx2_val = HEAP32[$automark >> 2];
    var $automark_idx3_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx2_val, $automark_idx3_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 169:
    __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev($76);
    var $automark_idx_val = HEAP32[$automark >> 2];
    var $automark_idx1_val = HEAP32[$automark + 4 >> 2];
    __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($automark_idx_val, $automark_idx1_val);
    var $_2 = 0;
    __label__ = 170;
    break;
   case 170:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z12js_XDRScriptP10JSXDRStatePP8JSScript["X"] = 1;

function __Z21js_MarkScriptFilenamePKc($filename) {
  HEAP8[$filename - 1 | 0] = 1;
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN2jsL7PodZeroIjEEvPT_j($t, $nelem) {
  var $1 = $t;
  var $2 = $nelem << 2;
  _memset($1, 0, $2, 1);
  return;
}

function __ZN8JSScript8numNotesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN8JSScript5notesEv($1);
    var $3 = HEAP8[$2];
    if ($3 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $2;
      __label__ = 7;
      break;
    } else {
      var $sn_01 = $2;
      var $5 = $3;
      __label__ = 2;
      break;
    }
   case 2:
    var $5;
    var $sn_01;
    if (($5 & 255) > 191) {
      var $11 = 24;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($5 & 255) >>> 3;
    __label__ = 4;
    break;
   case 4:
    var $11;
    if (HEAP8[_js_SrcNoteSpec + ($11 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $18 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = _js_SrcNoteLength($sn_01);
    var $18 = $16;
    __label__ = 6;
    break;
   case 6:
    var $18;
    var $19 = $sn_01 + $18 | 0;
    var $20 = HEAPU8[$19];
    if ($20 << 24 >> 24 == 0) {
      var $sn_0_lcssa = $19;
      __label__ = 7;
      break;
    } else {
      var $sn_01 = $19;
      var $5 = $20;
      __label__ = 2;
      break;
    }
   case 7:
    var $sn_0_lcssa;
    return 1 - $2 + $sn_0_lcssa | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($cx, $length, $nsrcnotes, $natoms, $nobjects, $nupvars, $nregexps, $ntrynotes, $nconsts, $nglobals, $nClosedArgs, $nClosedVars, $nTypeSets, $version) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $natoms << 2;
    var $2 = ($nobjects | 0) != 0;
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $size_0 = $1;
      __label__ = 3;
      break;
    }
   case 2:
    var $size_0 = $1 + 8 + ($nobjects << 2) | 0;
    __label__ = 3;
    break;
   case 3:
    var $size_0;
    var $8 = ($nupvars | 0) != 0;
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $size_1 = $size_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $size_1 = ($nupvars << 2) + 8 + $size_0 | 0;
    __label__ = 5;
    break;
   case 5:
    var $size_1;
    var $14 = ($nregexps | 0) != 0;
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $size_2 = $size_1;
      __label__ = 7;
      break;
    }
   case 6:
    var $size_2 = ($nregexps << 2) + 8 + $size_1 | 0;
    __label__ = 7;
    break;
   case 7:
    var $size_2;
    var $20 = ($ntrynotes | 0) != 0;
    if ($20) {
      __label__ = 8;
      break;
    } else {
      var $size_3 = $size_2;
      __label__ = 9;
      break;
    }
   case 8:
    var $size_3 = $ntrynotes * 12 + 8 + $size_2 | 0;
    __label__ = 9;
    break;
   case 9:
    var $size_3;
    var $26 = ($nglobals | 0) != 0;
    if ($26) {
      __label__ = 10;
      break;
    } else {
      var $size_4 = $size_3;
      __label__ = 11;
      break;
    }
   case 10:
    var $size_4 = ($nglobals << 3) + 8 + $size_3 | 0;
    __label__ = 11;
    break;
   case 11:
    var $size_4;
    var $34 = ($nClosedVars & 65535) + ($nClosedArgs & 65535) | 0;
    var $35 = ($34 | 0) != 0;
    if ($35) {
      __label__ = 12;
      break;
    } else {
      var $size_5 = $size_4;
      __label__ = 13;
      break;
    }
   case 12:
    var $size_5 = $size_4 + ($34 << 2) | 0;
    __label__ = 13;
    break;
   case 13:
    var $size_5;
    var $40 = ($nconsts | 0) != 0;
    if ($40) {
      __label__ = 14;
      break;
    } else {
      var $size_6 = $size_5;
      __label__ = 15;
      break;
    }
   case 14:
    var $size_6 = ($nconsts << 3) + 8 + $size_5 | 0;
    __label__ = 15;
    break;
   case 15:
    var $size_6;
    var $49 = $size_6 + ($nsrcnotes + ($length + 7)) & -8;
    var $50 = $cx;
    var $51 = __ZN9JSContext7calloc_Ej($50, $49);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 55;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $54 = __Z14js_NewGCScriptP9JSContext($cx);
    if (($54 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2js10Foreground5free_EPv($51);
    var $_0 = 0;
    __label__ = 55;
    break;
   case 18:
    __ZN2jsL7PodZeroI8JSScriptEEvPT_($54);
    HEAP32[$54 + 4 >> 2] = $51;
    HEAP32[$54 + 8 >> 2] = $length;
    HEAP16[$54 + 12 >> 1] = $version & 65535;
    var $62 = $54 + 64 | 0;
    if (($62 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $65 = $62;
    __ZN2js8BindingsC1EP9JSContext($65, undef);
    __label__ = 20;
    break;
   case 20:
    var $67 = __ZNK9JSContext12hasRunOptionEj($50, 131072);
    if ($67) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $69 = $54 + 92 | 0;
    var $70 = __ZN12JSPCCounters4initEP9JSContextj($69, $cx, $length);
    __label__ = 22;
    break;
   case 22:
    var $72 = $54 + 16 | 0;
    if ($2) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    HEAP8[$72] = 0;
    var $cursor_0 = $51 + 8 | 0;
    __label__ = 25;
    break;
   case 24:
    HEAP8[$72] = -1;
    var $cursor_0 = $51;
    __label__ = 25;
    break;
   case 25:
    var $cursor_0;
    if ($8) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    HEAP8[$54 + 17 | 0] = $cursor_0 - $51 & 255;
    var $cursor_1 = $cursor_0 + 8 | 0;
    __label__ = 28;
    break;
   case 27:
    HEAP8[$54 + 17 | 0] = -1;
    var $cursor_1 = $cursor_0;
    __label__ = 28;
    break;
   case 28:
    var $cursor_1;
    if ($14) {
      __label__ = 29;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 29:
    HEAP8[$54 + 18 | 0] = $cursor_1 - $51 & 255;
    var $cursor_2 = $cursor_1 + 8 | 0;
    __label__ = 31;
    break;
   case 30:
    HEAP8[$54 + 18 | 0] = -1;
    var $cursor_2 = $cursor_1;
    __label__ = 31;
    break;
   case 31:
    var $cursor_2;
    if ($20) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    HEAP8[$54 + 19 | 0] = $cursor_2 - $51 & 255;
    var $cursor_3 = $cursor_2 + 8 | 0;
    __label__ = 34;
    break;
   case 33:
    HEAP8[$54 + 19 | 0] = -1;
    var $cursor_3 = $cursor_2;
    __label__ = 34;
    break;
   case 34:
    var $cursor_3;
    if ($26) {
      __label__ = 35;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 35:
    HEAP8[$54 + 20 | 0] = $cursor_3 - $51 & 255;
    var $cursor_4 = $cursor_3 + 8 | 0;
    __label__ = 37;
    break;
   case 36:
    HEAP8[$54 + 20 | 0] = -1;
    var $cursor_4 = $cursor_3;
    __label__ = 37;
    break;
   case 37:
    var $cursor_4;
    if ($40) {
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    HEAP8[$54 + 21 | 0] = -1;
    var $cursor_6 = $cursor_4;
    __label__ = 40;
    break;
   case 39:
    HEAP8[$54 + 21 | 0] = $cursor_4 - $51 & 255;
    var $125 = $cursor_4 + 8 | 0;
    var $126 = $54;
    var $127 = __ZN8JSScript6constsEv($126);
    HEAP32[$127 + 4 >> 2] = $nconsts;
    var $129 = $125;
    var $130 = __ZN8JSScript6constsEv($126);
    HEAP32[$130 >> 2] = $129;
    var $cursor_6 = $cursor_4 + (($nconsts << 3) + 8) | 0;
    __label__ = 40;
    break;
   case 40:
    var $cursor_6;
    if (($natoms | 0) == 0) {
      var $cursor_7 = $cursor_6;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$54 + 40 >> 2] = $natoms;
    HEAP32[$54 + 56 >> 2] = $cursor_6;
    var $cursor_7 = $cursor_6 + $1 | 0;
    __label__ = 42;
    break;
   case 42:
    var $cursor_7;
    if ($2) {
      __label__ = 43;
      break;
    } else {
      var $cursor_8 = $cursor_7;
      __label__ = 44;
      break;
    }
   case 43:
    var $143 = $54;
    var $144 = __ZN8JSScript7objectsEv($143);
    HEAP32[$144 + 4 >> 2] = $nobjects;
    var $146 = __ZN8JSScript7objectsEv($143);
    HEAP32[$146 >> 2] = $cursor_7;
    var $cursor_8 = $cursor_7 + ($nobjects << 2) | 0;
    __label__ = 44;
    break;
   case 44:
    var $cursor_8;
    if ($14) {
      __label__ = 45;
      break;
    } else {
      var $cursor_9 = $cursor_8;
      __label__ = 46;
      break;
    }
   case 45:
    var $152 = $54;
    var $153 = __ZN8JSScript7regexpsEv($152);
    HEAP32[$153 + 4 >> 2] = $nregexps;
    var $155 = __ZN8JSScript7regexpsEv($152);
    HEAP32[$155 >> 2] = $cursor_8;
    var $cursor_9 = $cursor_8 + ($nregexps << 2) | 0;
    __label__ = 46;
    break;
   case 46:
    var $cursor_9;
    if ($20) {
      __label__ = 47;
      break;
    } else {
      var $cursor_10 = $cursor_9;
      __label__ = 48;
      break;
    }
   case 47:
    var $161 = $54;
    var $162 = __ZN8JSScript8trynotesEv($161);
    HEAP32[$162 + 4 >> 2] = $ntrynotes;
    var $164 = __ZN8JSScript8trynotesEv($161);
    HEAP32[$164 >> 2] = $cursor_9;
    var $cursor_10 = $cursor_9 + $ntrynotes * 12 | 0;
    __label__ = 48;
    break;
   case 48:
    var $cursor_10;
    if ($26) {
      __label__ = 49;
      break;
    } else {
      var $cursor_11 = $cursor_10;
      __label__ = 50;
      break;
    }
   case 49:
    var $170 = $54;
    var $171 = __ZN8JSScript7globalsEv($170);
    HEAP32[$171 + 4 >> 2] = $nglobals;
    var $173 = __ZN8JSScript7globalsEv($170);
    HEAP32[$173 >> 2] = $cursor_10;
    var $cursor_11 = $cursor_10 + ($nglobals << 3) | 0;
    __label__ = 50;
    break;
   case 50:
    var $cursor_11;
    if ($35) {
      __label__ = 51;
      break;
    } else {
      var $cursor_12 = $cursor_11;
      __label__ = 52;
      break;
    }
   case 51:
    HEAP16[$54 + 48 >> 1] = $nClosedArgs;
    HEAP16[$54 + 50 >> 1] = $nClosedVars;
    HEAP32[$54 + 88 >> 2] = $cursor_11;
    var $cursor_12 = $cursor_11 + ($34 << 2) | 0;
    __label__ = 52;
    break;
   case 52:
    var $cursor_12;
    HEAP16[$54 + 22 >> 1] = $nTypeSets & 65535;
    if ($8) {
      __label__ = 53;
      break;
    } else {
      var $cursor_13 = $cursor_12;
      __label__ = 54;
      break;
    }
   case 53:
    var $189 = $54;
    var $190 = __ZN8JSScript6upvarsEv($189);
    HEAP32[$190 + 4 >> 2] = $nupvars;
    var $192 = $cursor_12;
    var $193 = __ZN8JSScript6upvarsEv($189);
    HEAP32[$193 >> 2] = $192;
    var $cursor_13 = $cursor_12 + ($nupvars << 2) | 0;
    __label__ = 54;
    break;
   case 54:
    var $cursor_13;
    HEAP32[$54 >> 2] = $cursor_13;
    var $_0 = $54;
    __label__ = 55;
    break;
   case 55:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion["X"] = 1;

function __ZL18SaveScriptFilenameP9JSContextPKc($cx, $filename) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $entry = __stackBase__ + 20;
    HEAP32[$1 >> 2] = $filename;
    var $5 = HEAP32[$cx + 56 >> 2] + 1864 | 0;
    __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc($p, $5, $1);
    var $6 = $p | 0;
    __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($2, $6);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $11 = HEAP32[$1 >> 2];
    var $12 = _strlen($11);
    var $13 = $12 + 2 | 0;
    var $14 = $cx;
    var $15 = __ZN9JSContext7malloc_Ej($14, $13);
    var $16 = $15;
    HEAP32[$entry >> 2] = $16;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP8[$15] = 0;
    var $19 = $15 + 1 | 0;
    var $20 = _strcpy($19, $11);
    var $21 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($5, $p, $entry);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = HEAP32[$entry >> 2] | 0;
    __ZN2js10Foreground5free_EPv($24);
    _JS_ReportOutOfMemory($14);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 5:
    var $26 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($6);
    var $_0 = HEAP32[$26 >> 2] + 1 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN12JSPCCounters4initEP9JSContextj($this, $cx, $numBytecodes) {
  HEAP32[$this >> 2] = $numBytecodes;
  var $2 = $numBytecodes * 48 | 0;
  var $3 = $cx;
  var $4 = __ZN9JSContext7calloc_Ej($3, $2);
  HEAP32[$this + 4 >> 2] = $4;
  return ($4 | 0) != 0;
}

function __ZN12JSPCCounters7destroyEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext5free_EPv(undef, $5);
    HEAP32[$1 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12script_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    var $6 = $trc;
    __ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc($6, $5, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z23js_SweepScriptFilenamesP13JSCompartment($comp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $e = __stackBase__;
    var $1 = $comp + 1864 | 0;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_($e, $1);
    var $2 = $e | 0;
    var $3 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $comp | 0;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 4:
    var $6 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv($2);
    var $8 = HEAP32[$6 >> 2] | 0;
    if ((HEAP8[$8] & 1) << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP8[$8] = 0;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[HEAP32[$4 >> 2] + 136 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js10Foreground5free_EPv($8);
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv($e);
    __label__ = 8;
    break;
   case 8:
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv($2);
    var $20 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv($2);
    if ($20) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_($this, $map) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev($this);
  return;
}

function __Z14js_NewGCScriptP9JSContext($cx) {
  var $1 = __Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj($cx, 13, 104);
  return $1;
}

function __ZN2jsL7PodZeroI8JSScriptEEvPT_($t) {
  var $1 = $t;
  _memset($1, 0, 104, 1);
  return;
}

function __ZN8JSScript14setOwnerObjectEP8JSObject($this, $owner) {
  return;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($this) {
  return (HEAP32[$this >> 2] | 0) != 0;
}

function __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js11TokenStream16releaseSourceMapEv($this) {
  var $1 = $this + 176 | 0;
  var $2 = HEAP32[$1 >> 2];
  HEAP32[$1 >> 2] = 0;
  return $2;
}

function __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator($cx, $cg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cg + 172 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $9 = HEAP32[$2 + 8 >> 2] - HEAP32[$2 >> 2] | 0;
    var $10 = $cg + 116 | 0;
    var $12 = $cg + 108 | 0;
    var $16 = HEAP32[$10 >> 2] - HEAP32[$12 >> 2] | 0;
    var $17 = $cg + 92 | 0;
    var $18 = __ZN2js8Bindings11ensureShapeEP9JSContext($17, $cx);
    if ($18) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 78;
      break;
    }
   case 2:
    var $27 = HEAP32[$10 >> 2] - HEAP32[$12 >> 2] - HEAP32[$cg + 132 >> 2] | 0;
    var $29 = HEAP32[$cg + 124 >> 2];
    var $31 = HEAPU32[$cg + 156 >> 2];
    var $33 = $31 + ($29 + 1) | 0;
    if (($29 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $39 = HEAPU32[$cg + 188 >> 2];
    if ((HEAP32[$cg + 136 >> 2] | 0) == ($39 | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($27 | 0) > 7) {
      __label__ = 5;
      break;
    } else {
      var $nsrcnotes_0 = $33;
      __label__ = 6;
      break;
    }
   case 5:
    var $nsrcnotes_0 = (($27 + 55 | 0) / 63 & -1) + $33 | 0;
    __label__ = 6;
    break;
   case 6:
    var $nsrcnotes_0;
    var $nsrcnotes_1 = $nsrcnotes_0 + 2 + (($39 >>> 0 > 127 & 1) << 1) | 0;
    __label__ = 15;
    break;
   case 7:
    if (($27 | 0) > 0) {
      __label__ = 8;
      break;
    } else {
      var $nsrcnotes_1 = $33;
      __label__ = 15;
      break;
    }
   case 8:
    if (($31 | 0) == 0) {
      var $diff__0 = $27;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $60 = HEAPU8[HEAP32[$cg + 152 >> 2]];
    var $61 = $60 & 255;
    if (($60 & 255) > 191) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $68 = $61 & 63 ^ 63;
    __label__ = 12;
    break;
   case 11:
    var $68 = $61 & 7 ^ 7;
    __label__ = 12;
    break;
   case 12:
    var $68;
    var $diff__0 = $27 - $68 | 0;
    __label__ = 13;
    break;
   case 13:
    var $diff__0;
    if (($diff__0 | 0) > 0) {
      __label__ = 14;
      break;
    } else {
      var $nsrcnotes_1 = $33;
      __label__ = 15;
      break;
    }
   case 14:
    var $nsrcnotes_1 = (($diff__0 + 62 | 0) / 63 & -1) + $33 | 0;
    __label__ = 15;
    break;
   case 15:
    var $nsrcnotes_1;
    var $77 = $cg + 516 | 0;
    var $78 = $77;
    var $79 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($78);
    var $80 = $79 & 65535;
    var $81 = $cg + 564 | 0;
    var $82 = $81;
    var $83 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv($82);
    var $84 = $83 & 65535;
    var $85 = $cg + 308 | 0;
    var $86 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($85);
    if ($86) {
      __label__ = 16;
      break;
    } else {
      var $92 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $88 = $85;
    var $89 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($88);
    var $90 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($89);
    var $92 = $90;
    __label__ = 17;
    break;
   case 17:
    var $92;
    var $93 = $16 + $9 | 0;
    var $94 = $cg + 176 | 0;
    var $95 = $94;
    var $96 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($95);
    var $97 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($96);
    var $98 = $cg + 292 | 0;
    var $99 = $98 | 0;
    var $100 = HEAP32[$99 >> 2];
    var $101 = $cg + 300 | 0;
    var $102 = $101 | 0;
    var $103 = HEAP32[$102 >> 2];
    var $104 = $cg + 200 | 0;
    var $105 = HEAP32[$104 >> 2];
    var $107 = $cg + 268 | 0;
    var $108 = __ZNK13JSGCConstList6lengthEv($107);
    var $110 = $cg + 364 | 0;
    var $111 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($110);
    var $114 = HEAPU16[$cg + 614 >> 1] & 65535;
    var $115 = __ZNK15JSCodeGenerator7versionEv($cg);
    var $116 = __ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion($cx, $93, $nsrcnotes_1, $97, $100, $92, $103, $105, $108, $111, $80, $84, $114, $115);
    if (($116 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN2js8Bindings13makeImmutableEv($17);
    var $119 = $116 + 32 | 0;
    HEAP32[$119 >> 2] = $16;
    var $121 = HEAP32[$116 >> 2];
    var $122 = HEAP32[$12 >> 2];
    _memcpy($121, $122, $16, 1);
    var $123 = $116;
    var $124 = __ZN8JSScript4mainEv($123);
    var $127 = HEAP32[HEAP32[$1 >> 2] >> 2];
    _memcpy($124, $127, $9, 1);
    var $128 = $cg;
    var $129 = __ZNK13JSTreeContext10inFunctionEv($128);
    if ($129) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $131 = $17;
    var $132 = __ZNK2js8Bindings9countVarsEv($131);
    var $138 = $132 & 65535;
    __label__ = 21;
    break;
   case 20:
    var $135 = $cg;
    var $136 = __ZNK15JSCodeGenerator10sharpSlotsEv($135);
    var $138 = $136;
    __label__ = 21;
    break;
   case 21:
    var $138;
    var $140 = $116 + 14 | 0;
    HEAP16[$140 >> 1] = $138 & 65535;
    var $141 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv($94);
    var $143 = HEAP32[$116 + 56 >> 2];
    var $144 = $cx;
    var $145 = $141;
    __Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_(undef, $145, $143);
    var $146 = $cg + 48 | 0;
    var $149 = HEAP32[$146 >> 2] + 40 | 0;
    var $150 = __ZNK2js11TokenStream11getFilenameEv($149);
    if (($150 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $153 = __ZL18SaveScriptFilenameP9JSContextPKc($cx, $150);
    var $154 = $116 + 52 | 0;
    HEAP32[$154 >> 2] = $153;
    if (($153 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $158 = HEAP32[$cg + 188 >> 2];
    var $159 = $116 + 28 | 0;
    HEAP32[$159 >> 2] = $158;
    var $164 = (HEAPU16[$140 >> 1] & 65535) + HEAP32[$cg + 196 >> 2] | 0;
    if ($164 >>> 0 > 65535) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $169 = HEAP32[$146 >> 2] + 40 | 0;
    var $170 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $169, 0, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str33670 | 0, tempInt));
    var $_0 = 0;
    __label__ = 78;
    break;
   case 25:
    HEAP16[$116 + 44 >> 1] = $164 & 65535;
    HEAP16[$116 + 46 >> 1] = HEAP32[$cg + 76 >> 2] & 65535;
    var $180 = HEAP32[HEAP32[$146 >> 2] + 956 >> 2];
    var $181 = $116 + 76 | 0;
    HEAP32[$181 >> 2] = $180;
    if (($180 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $184 = $180 + 12 | 0;
    var $186 = HEAP32[$184 >> 2] + 1 | 0;
    HEAP32[$184 >> 2] = $186;
    __label__ = 27;
    break;
   case 27:
    var $189 = HEAP32[$146 >> 2] + 40 | 0;
    var $190 = __ZN2js11TokenStream16releaseSourceMapEv($189);
    var $191 = $116 + 80 | 0;
    HEAP32[$191 >> 2] = $190;
    var $192 = __ZN8JSScript5notesEv($123);
    var $193 = $cg;
    var $194 = _js_FinishTakingSrcNotes($144, $193, $192);
    if (($194 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    if ((HEAP32[$104 >> 2] | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $200 = __ZN8JSScript8trynotesEv($123);
    var $201 = $200;
    _js_FinishTakingTryNotes($193, $201);
    __label__ = 30;
    break;
   case 30:
    if ((HEAP32[$99 >> 2] | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $206 = __ZN8JSScript7objectsEv($123);
    var $207 = $98;
    var $208 = $206;
    __ZN14JSCGObjectList6finishEP13JSObjectArray($207, $208);
    __label__ = 32;
    break;
   case 32:
    if ((HEAP32[$102 >> 2] | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $213 = $116;
    var $214 = __ZN8JSScript7regexpsEv($213);
    var $215 = $101;
    var $216 = $214;
    __ZN14JSCGObjectList6finishEP13JSObjectArray($215, $216);
    __label__ = 34;
    break;
   case 34:
    var $218 = __ZNK13JSGCConstList6lengthEv($107);
    if (($218 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $221 = __ZN8JSScript6constsEv($123);
    var $222 = $221;
    __ZN13JSGCConstList6finishEP12JSConstArray($107, $222);
    __label__ = 36;
    break;
   case 36:
    var $224 = $cg | 0;
    if ((HEAP32[$224 >> 2] & 16384 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $229 = $116 + 36 | 0;
    var $231 = HEAP8[$229] | 1;
    HEAP8[$229] = $231;
    __label__ = 38;
    break;
   case 38:
    var $233 = __ZNK15JSCodeGenerator9hasSharpsEv($193);
    if ($233) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    var $235 = $116 + 36 | 0;
    var $237 = HEAP8[$235] | 4;
    HEAP8[$235] = $237;
    __label__ = 40;
    break;
   case 40:
    var $238 = HEAP32[$224 >> 2];
    if (($238 & 262144 | 0) == 0) {
      var $246 = $238;
      __label__ = 42;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    var $242 = $116 + 36 | 0;
    var $244 = HEAP8[$242] | 8;
    HEAP8[$242] = $244;
    var $246 = HEAP32[$224 >> 2];
    __label__ = 42;
    break;
   case 42:
    var $246;
    if (($246 & 8192 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $250 = $116 + 36 | 0;
    var $251 = HEAP8[$250];
    var $252 = $251 | 16;
    HEAP8[$250] = $252;
    var $255 = HEAP32[HEAP32[$146 >> 2] + 960 >> 2];
    if (($255 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $258 = $255;
    var $259 = __ZNK2js10StackFrame15isFunctionFrameEv($258);
    if ($259) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    var $261 = $251 | 18;
    HEAP8[$250] = $261;
    __label__ = 46;
    break;
   case 46:
    var $263 = __ZNK13JSTreeContext9callsEvalEv($128);
    if ($263) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $265 = $116 + 36 | 0;
    var $267 = HEAP8[$265] | 32;
    HEAP8[$265] = $267;
    __label__ = 48;
    break;
   case 48:
    var $268 = HEAP32[$224 >> 2];
    if (($268 & 128 | 0) == 0) {
      var $276 = $268;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    var $272 = $116 + 36 | 0;
    var $274 = HEAP8[$272] | 64;
    HEAP8[$272] = $274;
    var $276 = HEAP32[$224 >> 2];
    __label__ = 50;
    break;
   case 50:
    var $276;
    if (($276 & 134217728 | 0) == 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $280 = $116 + 37 | 0;
    var $282 = HEAP8[$280] | 2;
    HEAP8[$280] = $282;
    __label__ = 52;
    break;
   case 52:
    var $284 = __ZNK15JSCodeGenerator15hasUpvarIndicesEv($cg);
    if ($284) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    var $286 = __ZN8JSScript6upvarsEv($123);
    var $289 = HEAP32[$286 >> 2];
    var $290 = $cg + 316 | 0;
    var $291 = $290;
    var $292 = __ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv($291);
    var $293 = $292;
    var $294 = $85;
    var $295 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($294);
    var $296 = __ZN2js9InlineMapIP6JSAtomjLj24EE5countEv($295);
    var $297 = $296 << 2;
    _memcpy($289, $293, $297, 1);
    var $298 = __ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($294);
    __ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv($298);
    __ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv($290);
    __label__ = 54;
    break;
   case 54:
    var $300 = __ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv($110);
    if (($300 | 0) == 0) {
      __label__ = 56;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    var $303 = __ZN8JSScript7globalsEv($123);
    var $306 = HEAP32[$303 >> 2];
    var $307 = __ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj($110, 0);
    var $308 = $307;
    var $309 = $300 << 3;
    _memcpy($306, $308, $309, 1);
    __label__ = 56;
    break;
   case 56:
    var $311 = $116 + 48 | 0;
    var $312 = HEAPU16[$311 >> 1];
    if ($312 << 16 >> 16 == 0) {
      __label__ = 58;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $317 = HEAP32[$116 + 88 >> 2];
    var $318 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($77, 0);
    var $319 = $318;
    var $321 = ($312 & 65535) << 2;
    _memcpy($317, $319, $321, 1);
    __label__ = 58;
    break;
   case 58:
    var $324 = HEAPU16[$116 + 50 >> 1];
    if ($324 << 16 >> 16 == 0) {
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $332 = HEAP32[$116 + 88 >> 2] + ((HEAPU16[$311 >> 1] & 65535) << 2) | 0;
    var $333 = __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($81, 0);
    var $334 = $333;
    var $336 = ($324 & 65535) << 2;
    _memcpy($332, $334, $336, 1);
    __label__ = 60;
    break;
   case 60:
    var $339 = $116 + 64 | 0;
    var $340 = $17;
    __ZN2js8Bindings8transferEP9JSContextPS0_($339, undef, $340);
    var $341 = __ZNK13JSTreeContext10inFunctionEv($128);
    if ($341) {
      __label__ = 61;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 61:
    var $343 = __ZNK13JSTreeContext3funEv($128);
    var $344 = $343;
    if ((HEAP32[$224 >> 2] & 256 | 0) == 0) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $349 = $343 + 58 | 0;
    var $351 = HEAP16[$349 >> 1] | 128;
    HEAP16[$349 >> 1] = $351;
    __label__ = 63;
    break;
   case 63:
    var $353 = __ZN9JSContext20typeInferenceEnabledEv($144);
    if ($353) {
      __label__ = 64;
      break;
    } else {
      var $366 = 0;
      __label__ = 67;
      break;
    }
   case 64:
    var $356 = HEAP32[$cg + 72 >> 2];
    if (($356 | 0) == 0) {
      var $366 = 0;
      __label__ = 67;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $359 = $356;
    var $360 = __ZNK13JSTreeContext9compilingEv($359);
    if ($360) {
      __label__ = 66;
      break;
    } else {
      var $366 = 0;
      __label__ = 67;
      break;
    }
   case 66:
    var $362 = $356;
    var $363 = __ZN13JSTreeContext15asCodeGeneratorEv($362);
    var $364 = __ZN15JSCodeGenerator21checkSingletonContextEv($363);
    var $366 = $364;
    __label__ = 67;
    break;
   case 67:
    var $366;
    var $367 = __ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb($123, $144, $343, $366);
    if ($367) {
      __label__ = 68;
      break;
    } else {
      var $_0 = 0;
      __label__ = 78;
      break;
    }
   case 68:
    var $_c = $116;
    HEAP32[$343 + 60 >> 2] = $_c;
    var $fun_0 = $344;
    __label__ = 71;
    break;
   case 69:
    if ((HEAP32[$224 >> 2] & 1073741824 | 0) == 0) {
      var $fun_0 = 0;
      __label__ = 71;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $375 = __Z18js_NewScriptObjectP9JSContextP8JSScript($cx, $116);
    if (($375 | 0) == 0) {
      var $_0 = 0;
      __label__ = 78;
      break;
    } else {
      var $fun_0 = 0;
      __label__ = 71;
      break;
    }
   case 71:
    var $fun_0;
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($cx, $116, $fun_0);
    if ((HEAP32[$cg + 72 >> 2] | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $_0 = $116;
      __label__ = 78;
      break;
    }
   case 72:
    if (($fun_0 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 73:
    var $385 = HEAP32[$116 + 84 >> 2];
    if (($385 | 0) == 0) {
      __label__ = 74;
      break;
    } else {
      var $_ph = $385;
      __label__ = 76;
      break;
    }
   case 74:
    var $388 = __ZNK13JSTreeContext10scopeChainEv($128);
    var $_ph = $388;
    __label__ = 76;
    break;
   case 75:
    var $396 = 1;
    var $395 = $fun_0 | 0;
    __label__ = 77;
    break;
   case 76:
    var $_ph;
    var $396 = ($385 | 0) != 0;
    var $395 = $_ph;
    __label__ = 77;
    break;
   case 77:
    var $395;
    var $396;
    __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($144, $123, $395, $396 & 1);
    var $_0 = $116;
    __label__ = 78;
    break;
   case 78:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator["X"] = 1;

function __ZNK15JSCodeGenerator7versionEv($this) {
  var $2 = HEAP32[$this + 48 >> 2];
  var $3 = __ZNK2js6Parser16versionWithFlagsEv($2);
  return $3;
}

function __ZNK15JSCodeGenerator15hasUpvarIndicesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 308 | 0;
    var $2 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($1);
    var $5 = __ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv($4);
    var $8 = $5 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj($this, $i) {
  var $1 = $this;
  var $2 = __ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv($1);
  return $2 + ($i << 2) | 0;
}

function __Z18js_NewScriptObjectP9JSContextP8JSScript($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $script;
    var $5 = $1;
    __ZN8JSObject10setPrivateEPv($5, $4);
    HEAP32[$script + 84 >> 2] = $1;
    __ZN8JSObject9clearTypeEv($5);
    var $_0 = $1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($cx, $script, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $keep = __stackBase__;
    var $1 = $cx + 200 | 0;
    var $4 = HEAP32[HEAP32[$1 >> 2] + 8 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 52 >> 2];
    __ZN2js13AutoKeepAtomsC1EP9JSRuntime($keep, $9);
    var $11 = HEAP32[$script + 52 >> 2];
    var $13 = HEAP32[$script + 28 >> 2];
    var $16 = HEAP32[HEAP32[$1 >> 2] + 12 >> 2];
    FUNCTION_TABLE[$4]($cx, $11, $13, $script, $fun, $16);
    __ZN2js13AutoKeepAtomsD1Ev($keep);
    __label__ = 3;
    break;
   case 3:
    var $18 = $script + 38 | 0;
    var $20 = HEAP8[$18] | 32;
    HEAP8[$18] = $20;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript8dataSizeEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $4 = HEAP32[$this + 8 >> 2];
  var $5 = __ZN8JSScript8numNotesEv($this);
  return $2 + ($5 + $4) - HEAP32[$this + 4 >> 2] | 0;
}

function __ZN8JSScript8dataSizeEPFjPvE($this, $usf) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = FUNCTION_TABLE[$usf]($2);
    if (($3 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $8 = $3;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN8JSScript8dataSizeEv($this);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($cx, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script + 38 | 0;
    var $2 = HEAP8[$1];
    if (($2 & 32) << 24 >> 24 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 200 >> 2];
    var $9 = HEAP32[$7 + 16 >> 2];
    if (($9 | 0) == 0) {
      var $15 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = HEAP32[$7 + 20 >> 2];
    FUNCTION_TABLE[$9]($cx, $script, $13);
    var $15 = HEAP8[$1];
    __label__ = 4;
    break;
   case 4:
    var $15;
    HEAP8[$1] = $15 & -33;
    __ZN2js8Debugger15onDestroyScriptEP8JSScript($script);
    var $17 = $cx;
    var $18 = $script;
    _JS_ClearScriptTraps($17, $18);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8Debugger15onDestroyScriptEP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $script;
    var $2 = __ZNK2js2gc4Cell11compartmentEv($1);
    var $3 = __ZN13JSCompartment12getDebuggeesEv($2);
    var $4 = __ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $script;
    __ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript8finalizeEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    __Z24js_CallDestroyScriptHookP9JSContextP8JSScript($cx, $this);
    var $1 = $this + 76 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2 + 12 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $9 = HEAP32[$1 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[$9 + 16 >> 2];
    FUNCTION_TABLE[$12]($cx, $9);
    __label__ = 4;
    break;
   case 4:
    var $15 = HEAP32[$this + 100 >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $15;
    __ZN2js5types10TypeScript7destroyEv($18);
    __label__ = 6;
    break;
   case 6:
    var $20 = $this + 92 | 0;
    __ZN12JSPCCounters7destroyEP9JSContext($20, $cx);
    var $22 = HEAP32[$this + 80 >> 2];
    if (($22 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $22;
    __ZN9JSContext5free_EPv(undef, $25);
    __label__ = 8;
    break;
   case 8:
    var $28 = HEAP32[$this + 4 >> 2];
    __ZN9JSContext5free_EPv(undef, $28);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707($cx) {
  var $3 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb3731($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732($cx, $4);
  return $5;
}

function __ZN2js8GSNCache5purgeEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = 0;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($2);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv($1);
  return $2;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv($1);
  return;
}

function __ZN8JSScript20recompileForStepModeEP9JSContext($this, $cx) {
  return 1;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $p = __stackBase__ + 4;
    var $2 = __stackBase__ + 8;
    var $sn2 = __stackBase__ + 16;
    HEAP32[$1 >> 2] = $pc;
    var $3 = $script | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $7 = $pc - $4 | 0;
    var $9 = HEAPU32[$script + 8 >> 2];
    if ($7 >>> 0 < $9 >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 2:
    var $12 = $cx;
    var $13 = __ZN2js11GetGSNCacheEP9JSContext($12);
    var $14 = $13 | 0;
    var $15 = HEAPU32[$14 >> 2];
    if (($15 | 0) == ($4 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $19 = $13 + 4 | 0;
    __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_($p, $19, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($p);
    var $_0 = HEAP32[$24 + 4 >> 2];
    __label__ = 33;
    break;
   case 5:
    var $28 = $script;
    var $29 = __ZN8JSScript5notesEv($28);
    var $sn_0 = $29;
    var $offset_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $offset_0;
    var $sn_0;
    var $31 = HEAPU8[$sn_0];
    if ($31 << 24 >> 24 == 0) {
      var $result_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $34 = $31 & 255;
    var $35 = ($31 & 255) > 191;
    var $_v = $35 ? 63 : 7;
    var $37 = ($_v & $34) + $offset_0 | 0;
    if (($37 | 0) == ($7 | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    if (($31 & 255) < 176 & ($35 ^ 1)) {
      var $result_0 = $sn_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_ = $35 ? 24 : $34 >>> 3;
    if (HEAP8[_js_SrcNoteSpec + ($_ << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $49 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $47 = _js_SrcNoteLength($sn_0);
    var $49 = $47;
    __label__ = 11;
    break;
   case 11:
    var $49;
    var $sn_0 = $sn_0 + $49 | 0;
    var $offset_0 = $37;
    __label__ = 6;
    break;
   case 12:
    var $result_0;
    if ($9 >>> 0 > 99) {
      __label__ = 13;
      break;
    } else {
      var $_0 = $result_0;
      __label__ = 33;
      break;
    }
   case 13:
    var $54 = __ZN8JSScript5notesEv($28);
    var $55 = HEAPU8[$54];
    if ($55 << 24 >> 24 == 0) {
      var $nsrcnotes_0_lcssa = 0;
      __label__ = 19;
      break;
    } else {
      var $nsrcnotes_06 = 0;
      var $sn1_07 = $54;
      var $57 = $55;
      __label__ = 14;
      break;
    }
   case 14:
    var $57;
    var $sn1_07;
    var $nsrcnotes_06;
    var $58 = ($57 & 255) > 191;
    var $_nsrcnotes_0 = (($57 & 255) < 176 & ($58 ^ 1) & 1) + $nsrcnotes_06 | 0;
    if ($58) {
      var $65 = 24;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $65 = ($57 & 255) >>> 3;
    __label__ = 16;
    break;
   case 16:
    var $65;
    if (HEAP8[_js_SrcNoteSpec + ($65 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $72 = 1;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $70 = _js_SrcNoteLength($sn1_07);
    var $72 = $70;
    __label__ = 18;
    break;
   case 18:
    var $72;
    var $73 = $sn1_07 + $72 | 0;
    var $74 = HEAPU8[$73];
    if ($74 << 24 >> 24 == 0) {
      var $nsrcnotes_0_lcssa = $_nsrcnotes_0;
      __label__ = 19;
      break;
    } else {
      var $nsrcnotes_06 = $_nsrcnotes_0;
      var $sn1_07 = $73;
      var $57 = $74;
      __label__ = 14;
      break;
    }
   case 19:
    var $nsrcnotes_0_lcssa;
    var $_pre4 = $13 + 4 | 0;
    if (($15 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv($_pre4);
    HEAP32[$14 >> 2] = 0;
    __label__ = 21;
    break;
   case 21:
    var $78 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj($_pre4, $nsrcnotes_0_lcssa);
    if ($78) {
      __label__ = 22;
      break;
    } else {
      var $_0 = $result_0;
      __label__ = 33;
      break;
    }
   case 22:
    var $80 = HEAPU32[$3 >> 2];
    HEAP32[$1 >> 2] = $80;
    var $81 = __ZN8JSScript5notesEv($28);
    HEAP32[$sn2 >> 2] = $81;
    var $82 = HEAP8[$81];
    if ($82 << 24 >> 24 == 0) {
      var $112 = $80;
      __label__ = 32;
      break;
    } else {
      var $86 = $82;
      var $85 = $81;
      var $84 = $80;
      __label__ = 23;
      break;
    }
   case 23:
    var $84;
    var $85;
    var $86;
    var $_v1 = ($86 & 255) > 191 ? 63 : 7;
    HEAP32[$1 >> 2] = $84 + ($_v1 & ($86 & 255)) | 0;
    if (($86 & 255) < 176) {
      __label__ = 24;
      break;
    } else {
      var $94 = $85;
      __label__ = 25;
      break;
    }
   case 24:
    var $92 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_($_pre4, $1, $sn2);
    var $94 = HEAP32[$sn2 >> 2];
    __label__ = 25;
    break;
   case 25:
    var $94;
    var $95 = HEAPU8[$94];
    if (($95 & 255) > 191) {
      var $101 = 24;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $101 = ($95 & 255) >>> 3;
    __label__ = 27;
    break;
   case 27:
    var $101;
    if (HEAP8[_js_SrcNoteSpec + ($101 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $108 = 1;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $106 = _js_SrcNoteLength($94);
    var $108 = $106;
    __label__ = 29;
    break;
   case 29:
    var $108;
    var $109 = $94 + $108 | 0;
    HEAP32[$sn2 >> 2] = $109;
    var $110 = HEAPU8[$109];
    if ($110 << 24 >> 24 == 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $86 = $110;
    var $85 = $109;
    var $84 = HEAP32[$1 >> 2];
    __label__ = 23;
    break;
   case 31:
    var $112 = HEAP32[$3 >> 2];
    __label__ = 32;
    break;
   case 32:
    var $112;
    HEAP32[$14 >> 2] = $112;
    var $_0 = $result_0;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh["X"] = 1;

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 234,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($1, $len);
  return $2;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$v >> 2];
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv($2);
    HEAP32[$8 + 4 >> 2] = $7;
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($2);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_($this, $p, $k, $v);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv($2);
    var $_0 = $14;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($cx, $fp, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $fp;
    var $2 = __ZNK2js10StackFrame6scriptEv($1);
    var $3 = $2;
    var $4 = __ZNK2js10StackFrame11hasImacropcEv($1);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $8 = $pc;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZNK2js10StackFrame8imacropcEv($1);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    var $9 = __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($cx, $3, $8);
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_PCToLineNumberP9JSContextP8JSScriptPh($cx, $script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($pc | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716($script, $pc);
    if ((HEAP32[_js_CodeSpec + ($3 << 3) + 4 >> 2] & 262144 | 0) == 0) {
      var $_01 = $pc;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = $pc + (HEAP8[_js_CodeSpec + ($3 << 3) | 0] << 24 >> 24) | 0;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if (HEAP8[$_01] << 24 >> 24 == 127) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $cx;
    var $18 = $script;
    var $19 = _js_GetIndexFromBytecode($17, $18, $_01, 0);
    var $20 = __ZN8JSScript11getFunctionEj($18, $19);
    var $21 = __ZNK10JSFunction6scriptEv($20);
    var $_0 = HEAP32[$21 + 28 >> 2];
    __label__ = 16;
    break;
   case 6:
    var $26 = HEAP32[$script + 28 >> 2];
    var $31 = $_01 - HEAP32[$script >> 2] | 0;
    var $32 = $script;
    var $33 = __ZN8JSScript5notesEv($32);
    var $sn_0 = $33;
    var $offset_0 = 0;
    var $lineno_0 = $26;
    __label__ = 7;
    break;
   case 7:
    var $lineno_0;
    var $offset_0;
    var $sn_0;
    var $35 = HEAPU8[$sn_0];
    var $36 = $35 & 255;
    if ($35 << 24 >> 24 == 0) {
      var $_0 = $lineno_0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $39 = ($35 & 255) > 191;
    var $_v = $39 ? 63 : 7;
    var $41 = ($_v & $36) + $offset_0 | 0;
    var $42 = $36 >>> 3;
    var $_ = $39 ? 24 : $42;
    if (($_ | 0) == 23) {
      __label__ = 9;
      break;
    } else if (($_ | 0) == 22) {
      __label__ = 11;
      break;
    } else {
      var $lineno_1 = $lineno_0;
      __label__ = 12;
      break;
    }
   case 9:
    if (($41 | 0) > ($31 | 0)) {
      var $lineno_1 = $lineno_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $46 = _js_GetSrcNoteOffset($sn_0, 0);
    var $lineno_1 = $46;
    __label__ = 12;
    break;
   case 11:
    var $lineno_1 = (($41 | 0) <= ($31 | 0) & 1) + $lineno_0 | 0;
    __label__ = 12;
    break;
   case 12:
    var $lineno_1;
    if (($41 | 0) > ($31 | 0)) {
      var $_0 = $lineno_1;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = $39 ? 24 : $42;
    if (HEAP8[_js_SrcNoteSpec + ($52 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $59 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = _js_SrcNoteLength($sn_0);
    var $59 = $57;
    __label__ = 15;
    break;
   case 15:
    var $59;
    var $sn_0 = $sn_0 + $59 | 0;
    var $offset_0 = $41;
    var $lineno_0 = $lineno_1;
    __label__ = 7;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_PCToLineNumberP9JSContextP8JSScriptPh["X"] = 1;

function __ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716($script, $pc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU8[$pc];
    var $2 = $1 & 255;
    if ($1 << 24 >> 24 == 83) {
      __label__ = 2;
      break;
    } else {
      var $op_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $script;
    var $6 = _JS_GetTrapOpcode(undef, $5, $pc);
    var $op_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $op_0;
    return $op_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_LineNumberToPCP8JSScriptj($script, $target) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$script + 28 >> 2];
    var $3 = $script;
    var $4 = __ZN8JSScript5notesEv($3);
    var $5 = $script + 32 | 0;
    var $sn_0 = $4;
    var $bestdiff_0 = 8388608;
    var $offset_0 = 0;
    var $best_0 = -1;
    var $lineno_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $lineno_0;
    var $best_0;
    var $offset_0;
    var $bestdiff_0;
    var $sn_0;
    var $7 = HEAPU8[$sn_0];
    if ($7 << 24 >> 24 == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($lineno_0 | 0) == ($target | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if (($offset_0 | 0) < (HEAP32[$5 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      var $offset_1 = $offset_0;
      __label__ = 16;
      break;
    }
   case 5:
    if ($lineno_0 >>> 0 < $target >>> 0) {
      var $bestdiff_1 = $bestdiff_0;
      var $best_1 = $best_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $lineno_0 - $target | 0;
    if ($17 >>> 0 < $bestdiff_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $bestdiff_1 = $bestdiff_0;
      var $best_1 = $best_0;
      __label__ = 8;
      break;
    }
   case 7:
    var $bestdiff_1 = $17;
    var $best_1 = $offset_0;
    __label__ = 8;
    break;
   case 8:
    var $best_1;
    var $bestdiff_1;
    var $21 = $7 & 255;
    var $22 = ($7 & 255) > 191;
    var $_v = $22 ? 63 : 7;
    var $24 = ($_v & $21) + $offset_0 | 0;
    var $25 = $21 >>> 3;
    var $_ = $22 ? 24 : $25;
    if (($_ | 0) == 23) {
      __label__ = 9;
      break;
    } else if (($_ | 0) == 22) {
      __label__ = 10;
      break;
    } else {
      var $lineno_1 = $lineno_0;
      __label__ = 11;
      break;
    }
   case 9:
    var $27 = _js_GetSrcNoteOffset($sn_0, 0);
    var $lineno_1 = $27;
    __label__ = 11;
    break;
   case 10:
    var $lineno_1 = $lineno_0 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $lineno_1;
    var $31 = $22 ? 24 : $25;
    if (HEAP8[_js_SrcNoteSpec + ($31 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $38 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = _js_SrcNoteLength($sn_0);
    var $38 = $36;
    __label__ = 13;
    break;
   case 13:
    var $38;
    var $sn_0 = $sn_0 + $38 | 0;
    var $bestdiff_0 = $bestdiff_1;
    var $offset_0 = $24;
    var $best_0 = $best_1;
    var $lineno_0 = $lineno_1;
    __label__ = 2;
    break;
   case 14:
    if (($best_0 | 0) > -1) {
      __label__ = 15;
      break;
    } else {
      var $offset_1 = $offset_0;
      __label__ = 16;
      break;
    }
   case 15:
    var $offset_1 = $best_0;
    __label__ = 16;
    break;
   case 16:
    var $offset_1;
    return HEAP32[$script >> 2] + $offset_1 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z17js_LineNumberToPCP8JSScriptj["X"] = 1;

function __Z22js_GetScriptLineExtentP8JSScript($script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$script + 28 >> 2];
    var $3 = $script;
    var $4 = __ZN8JSScript5notesEv($3);
    var $5 = HEAP8[$4];
    if ($5 << 24 >> 24 == 0) {
      var $maxLineNo_0_lcssa = 0;
      var $lineno_0_lcssa = $2;
      __label__ = 10;
      break;
    } else {
      var $maxLineNo_01 = 0;
      var $lineno_02 = $2;
      var $counting_03 = 1;
      var $sn_04 = $4;
      var $7 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $7;
    var $sn_04;
    var $counting_03;
    var $lineno_02;
    var $maxLineNo_01;
    if (($7 & 255) > 191) {
      var $20 = 24;
      var $maxLineNo_22 = $maxLineNo_01;
      var $lineno_14 = $lineno_02;
      var $counting_16 = $counting_03;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($7 & 255) >>> 3;
    if (($11 | 0) == 22) {
      __label__ = 4;
      break;
    } else if (($11 | 0) == 23) {
      __label__ = 5;
      break;
    } else {
      var $maxLineNo_21 = $maxLineNo_01;
      var $lineno_13 = $lineno_02;
      var $counting_15 = $counting_03;
      __label__ = 6;
      break;
    }
   case 4:
    var $maxLineNo_21 = $maxLineNo_01;
    var $lineno_13 = ($counting_03 & 1 & 255) + $lineno_02 | 0;
    var $counting_15 = $counting_03;
    __label__ = 6;
    break;
   case 5:
    var $maxLineNo_1 = $maxLineNo_01 >>> 0 < $lineno_02 >>> 0 ? $lineno_02 : $maxLineNo_01;
    var $16 = _js_GetSrcNoteOffset($sn_04, 0);
    var $17 = $maxLineNo_1 >>> 0 < $16 >>> 0;
    var $_maxLineNo_1 = $17 ? $16 : $maxLineNo_1;
    var $maxLineNo_21 = $_maxLineNo_1;
    var $lineno_13 = $16;
    var $counting_15 = $17 & 1;
    __label__ = 6;
    break;
   case 6:
    var $counting_15;
    var $lineno_13;
    var $maxLineNo_21;
    var $20 = ($7 & 255) >>> 3;
    var $maxLineNo_22 = $maxLineNo_21;
    var $lineno_14 = $lineno_13;
    var $counting_16 = $counting_15;
    __label__ = 7;
    break;
   case 7:
    var $counting_16;
    var $lineno_14;
    var $maxLineNo_22;
    var $20;
    if (HEAP8[_js_SrcNoteSpec + ($20 << 3) + 4 | 0] << 24 >> 24 == 0) {
      var $27 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = _js_SrcNoteLength($sn_04);
    var $27 = $25;
    __label__ = 9;
    break;
   case 9:
    var $27;
    var $28 = $sn_04 + $27 | 0;
    var $29 = HEAPU8[$28];
    if ($29 << 24 >> 24 == 0) {
      var $maxLineNo_0_lcssa = $maxLineNo_22;
      var $lineno_0_lcssa = $lineno_14;
      __label__ = 10;
      break;
    } else {
      var $maxLineNo_01 = $maxLineNo_22;
      var $lineno_02 = $lineno_14;
      var $counting_03 = $counting_16;
      var $sn_04 = $28;
      var $7 = $29;
      __label__ = 2;
      break;
    }
   case 10:
    var $lineno_0_lcssa;
    var $maxLineNo_0_lcssa;
    var $lineno_2 = $maxLineNo_0_lcssa >>> 0 > $lineno_0_lcssa >>> 0 ? $maxLineNo_0_lcssa : $lineno_0_lcssa;
    return $lineno_2 + 1 - $2 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z22js_GetScriptLineExtentP8JSScript["X"] = 1;

function __ZN2js11CurrentLineEP9JSContext($cx) {
  var $1 = $cx;
  var $2 = __ZNK9JSContext2fpEv($1);
  var $3 = $2;
  var $4 = __ZNK9JSContext4regsEv($1);
  var $6 = HEAP32[$4 + 4 >> 2];
  var $7 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($cx, $3, $6);
  return $7;
}

function __ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj($cx, $linenop) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $iter = __stackBase__;
    var $1 = $cx;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($iter, $1, 0);
    __label__ = 2;
    break;
   case 2:
    var $3 = __ZNK2js13FrameRegsIter4doneEv($iter);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $6 = __ZNK2js10StackFrame13isScriptFrameEv($5);
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZN2js13FrameRegsIterppEv($iter);
    __label__ = 2;
    break;
   case 5:
    HEAP32[$linenop >> 2] = 0;
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $11 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $12 = $11;
    var $13 = __ZNK2js13FrameRegsIter2pcEv($iter);
    var $14 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($cx, $12, $13);
    HEAP32[$linenop >> 2] = $14;
    var $15 = __ZNK2js13FrameRegsIter2fpEv($iter);
    var $16 = __ZNK2js10StackFrame6scriptEv($15);
    var $_0 = HEAP32[$16 + 52 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_CloneScriptP9JSContextP8JSScript($cx, $script) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $w = __stackBase__ + 4;
    var $disable = __stackBase__ + 8;
    var $wstate = __stackBase__ + 16;
    var $nbytes = __stackBase__ + 28;
    var $r = __stackBase__ + 32;
    var $rstate = __stackBase__ + 36;
    HEAP32[$1 >> 2] = $script;
    var $2 = $cx;
    var $3 = _JS_XDRNewMem($2, 0);
    var $4 = $3;
    __ZN14AutoJSXDRStateC1EP10JSXDRState($w, $4);
    var $5 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w);
    if (($5 | 0) == 0) {
      var $_3 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN28DisablePrincipalsTranscodingC1EP9JSContext($disable, $cx);
    var $8 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w);
    var $9 = $8;
    __ZN2js14XDRScriptStateC2EP10JSXDRState($wstate, $9);
    var $10 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w);
    var $11 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($10, $1);
    if (($11 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w);
    var $15 = $14;
    var $16 = _JS_XDRMemGetData($15, $nbytes);
    if (($16 | 0) == 0) {
      var $_2 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = _JS_XDRNewMem($2, 1);
    var $20 = $19;
    __ZN14AutoJSXDRStateC1EP10JSXDRState($r, $20);
    var $21 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($r);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = HEAP32[$nbytes >> 2];
    var $25 = $21;
    _JS_XDRMemSetData($25, $16, $24);
    var $26 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($w);
    var $27 = $26;
    _JS_XDRMemSetData($27, 0, 0);
    var $28 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($r);
    var $29 = $rstate;
    var $30 = $28;
    __ZN2js14XDRScriptStateC2EP10JSXDRState($29, $30);
    var $33 = HEAP32[HEAP32[$1 >> 2] + 52 >> 2];
    HEAP32[$rstate + 4 >> 2] = $33;
    HEAP8[$rstate + 8 | 0] = 1;
    var $36 = __ZNK14AutoJSXDRStatecvP10JSXDRStateEv($r);
    var $37 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($36, $1);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $40 = HEAP32[$1 >> 2];
    var $41 = $40;
    var $42 = __ZNK2js2gc4Cell11compartmentEv($41);
    var $44 = HEAP32[$42 + 4 >> 2];
    var $45 = $44;
    var $46 = $40 + 76 | 0;
    HEAP32[$46 >> 2] = $45;
    if (($44 | 0) == 0) {
      var $_0 = $40;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $49 = $44 + 12 | 0;
    var $51 = HEAP32[$49 >> 2] + 1 | 0;
    HEAP32[$49 >> 2] = $51;
    var $_0 = $40;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js14XDRScriptStateD2Ev($29);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    __ZN14AutoJSXDRStateD1Ev($r);
    var $_2 = $_1;
    __label__ = 10;
    break;
   case 10:
    var $_2;
    __ZN2js14XDRScriptStateD2Ev($wstate);
    __ZN28DisablePrincipalsTranscodingD1Ev($disable);
    var $_3 = $_2;
    __label__ = 11;
    break;
   case 11:
    var $_3;
    __ZN14AutoJSXDRStateD1Ev($w);
    STACKTOP = __stackBase__;
    return $_3;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z14js_CloneScriptP9JSContextP8JSScript["X"] = 1;

function __ZN14AutoJSXDRStateC1EP10JSXDRState($this, $x) {
  __ZN14AutoJSXDRStateC2EP10JSXDRState($this, $x);
  return;
}

function __ZN28DisablePrincipalsTranscodingC1EP9JSContext($this, $cx) {
  __ZN28DisablePrincipalsTranscodingC2EP9JSContext($this, $cx);
  return;
}

function __ZN14AutoJSXDRStateD1Ev($this) {
  __ZN14AutoJSXDRStateD2Ev($this);
  return;
}

function __ZN28DisablePrincipalsTranscodingD1Ev($this) {
  __ZN28DisablePrincipalsTranscodingD2Ev($this);
  return;
}

function __ZN8JSScript17copyClosedSlotsToEPS_($this, $other) {
  var $3 = HEAP32[$other + 88 >> 2];
  var $6 = HEAP32[$this + 88 >> 2];
  var $13 = (HEAPU16[$this + 50 >> 1] & 65535) + (HEAPU16[$this + 48 >> 1] & 65535) | 0;
  _memcpy($3, $6, $13, 1);
  return;
}

function __ZN8JSScript14tryNewStepModeEP9JSContextj($this, $cx, $newValue) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 24 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$1 >> 2] = $newValue;
    var $5 = ($newValue | 0) != 0;
    if ((($2 | 0) == 0 & 1 | 0) == ($5 & 1 ^ 1 | 0) | $5 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $frames_01 = HEAP32[HEAP32[$cx + 52 >> 2] + 209936 >> 2];
    if (($frames_01 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $frames_02 = $frames_01;
      __label__ = 3;
      break;
    }
   case 3:
    var $frames_02;
    __ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript($frames_02, $this);
    var $frames_0 = HEAP32[$frames_02 >> 2];
    if (($frames_0 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $frames_02 = $frames_0;
      __label__ = 3;
      break;
    }
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript($this, $script) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 8 >> 2];
    var $4 = __ZNK2js9FrameRegs2fpEv($3);
    var $5 = __ZNK2js10StackFrame6scriptEv($4);
    if (($5 | 0) == ($script | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 12 >> 2];
    var $13 = HEAP32[HEAP32[$10 >> 2] >> 2];
    FUNCTION_TABLE[$13]($10);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSScript15setStepModeFlagEP9JSContextb($this, $cx, $step) {
  var $4 = $step ? -2147483648 : 0;
  var $5 = HEAP32[$this + 24 >> 2] & 2147483647 | $4;
  var $6 = __ZN8JSScript14tryNewStepModeEP9JSContextj($this, $cx, $5);
  return 1;
}

function __ZN8JSScript19changeStepModeCountEP9JSContexti($this, $cx, $delta) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $6 = $2 + $delta & 2147483647 | $2 & -2147483648;
  var $7 = __ZN8JSScript14tryNewStepModeEP9JSContextj($this, $cx, $6);
  return 1;
}

function __ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = HEAP32[$v >> 2];
    var $8 = $5 + 4 | 0;
    HEAP32[$8 >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_($k, $l) {
  return (HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0);
}

function __ZN2js13PointerHasherIPhLj0EE4hashERKS1_($l) {
  return HEAP32[$l >> 2];
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIPhS1_EC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv($this) {
  return (HEAP32[$this + 20 >> 2] | 0) != 0;
}

function __ZN2js2gcL15GetGCObjectKindEjb3731($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv($this) {
  HEAP32[$this >> 2] = 1;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 12 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 12 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    var $29 = $3;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $29, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 12 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 12 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 12 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 12 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_($1, $8);
  __ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefIPhEcvRS1_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv($rhs);
  var $9 = $8 + 4 | 0;
  __ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_($2, $9);
  var $10 = __ZNK2js7MoveRefIPhEcvRS1_Ev($2);
  var $11 = HEAP32[$10 >> 2];
  HEAP32[$this + 4 >> 2] = $11;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_($this, $t);
  return;
}

function __ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefIPhEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryIPhS1_EC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIPhS1_EC1Ev($this) {
  __ZN2js12HashMapEntryIPhS1_EC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l) {
  var $1 = __ZN2js13PointerHasherIPhLj0EE4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 12 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 12 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE($1);
  var $3 = __ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 20 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj(undef, $5, undef);
    HEAP32[$1 >> 2] = 0;
    var $6 = $this + 12 | 0;
    var $8 = HEAP32[$6 >> 2] + 1 | 0;
    HEAP32[$6 >> 2] = $8;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 16 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733($cx, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($5) {
      var $21 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $4;
    var $19 = __ZNK8JSObject9getParentEv($18);
    var $21 = $19;
    __label__ = 8;
    break;
   case 8:
    var $21;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, undef, __ZN2js11ScriptClassE, $12, $21, 0, (__ZN2js11ScriptClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $23 = __ZNK2js5Class8isNativeEv(__ZN2js11ScriptClassE);
    if ($23) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $25 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736($cx, $14, $12, $kind);
    if ($25) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733($cx, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741();
    var $2 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, 0, $1, $proto, __ZN2js11ScriptClassE);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($cx, 0, 1, $proto, 0);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ScriptClassE + 4 >> 2] >>> 8 & 255;
    var $4 = $obj;
    var $5 = __ZNK8JSObject8numSlotsEv($4);
    if ($3 >>> 0 > $5 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN8JSObject10allocSlotsEP9JSContextj($obj, $cx, $3);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $10 = $type;
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($10, __ZN2js11ScriptClassE);
    var $12 = $cx;
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($10, $12, __ZN2js11ScriptClassE, $kind);
    var $empty_0_in = $14;
    __label__ = 6;
    break;
   case 5:
    var $16 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($12, __ZN2js11ScriptClassE);
    var $empty_0_in = $16;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $13;
    var $17 = $this;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej($17, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $19 = $this + 12 | 0;
    var $21 = HEAP32[$19 >> 2] + 1 | 0;
    HEAP32[$19 >> 2] = $21;
    HEAP32[$2 >> 2] = $16;
    var $22 = $3 + ($5 << 3) | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $24 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($src_01);
    if ($24) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv($src_01);
    var $26 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv($src_01);
    var $27 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $26);
    __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_($1, $src_01);
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE($27, $1);
    __label__ = 6;
    break;
   case 6:
    var $29 = $src_01 + 8 | 0;
    if (($29 | 0) == ($22 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $29;
      __label__ = 4;
      break;
    }
   case 7:
    var $31 = $3;
    __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj(undef, $31, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + ($15 << 3) | 0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = __ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv($rhs);
  var $7 = $6 + 4 | 0;
  __ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_($1, $7);
  var $8 = __ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev($1);
  var $9 = HEAP32[$8 >> 2];
  HEAP32[$this + 4 >> 2] = $9;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_($agg_result, $t) {
  __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_($this, $t) {
  __ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_($this, $t);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv($agg_result, $1);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + (HEAP32[$this + 4 >> 2] << 3) | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 8 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($t) {
  return $t;
}

function __ZL14JSID_FROM_BITSj3746($bits) {
  return $bits;
}

function _JSID_TO_STRING3744($iden) {
  return $iden;
}

function _JSID_IS_STRING3745($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN28DisablePrincipalsTranscodingD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $2 + 4 | 0;
    HEAP32[$7 >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14AutoJSXDRStateC2EP10JSXDRState($this, $x) {
  HEAP32[$this >> 2] = $x;
  return;
}

function __ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv($this) {
  return (HEAP32[$this + 12 >> 2] | 0) == 0;
}

function __ZNK2js11TokenStream16versionWithFlagsEv($this) {
  return HEAP32[$this + 904 >> 2];
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool($this, $pool) {
  HEAP32[$this >> 2] = $pool;
  var $7 = HEAP32[HEAP32[$pool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 8 | 0;
    var $4 = HEAPU32[$3 >> 2];
    if ((HEAP32[$this + 12 >> 2] - $4 | 0) >>> 0 < $incr >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $10 = $4;
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $10 = HEAP32[$3 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$3 >> 2] = $10 + $incr | 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $8 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $this;
    var $13 = __ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv($12);
    var $14 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv($12);
    __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $13, $14);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN14AutoJSXDRStateD2Ev($this) {
  var $3 = HEAP32[$this >> 2];
  _JS_XDRDestroy($3);
  return;
}

function __ZN28DisablePrincipalsTranscodingC2EP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $4 = HEAP32[$cx + 52 >> 2];
    var $5 = _JS_GetRuntimeSecurityCallbacks($4);
    var $6 = $5;
    HEAP32[$1 >> 2] = $6;
    var $7 = $this + 4 | 0;
    HEAP32[$7 >> 2] = 0;
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $5 + 4 | 0;
    var $12 = HEAP32[$10 >> 2];
    HEAP32[$7 >> 2] = $12;
    HEAP32[$10 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $this + 200 | 0;
    var $5 = __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv($4);
    var $11 = $5;
    __label__ = 4;
    break;
   case 3:
    var $11 = (HEAP32[$this + 4 >> 2] | 0) == 0;
    __label__ = 4;
    break;
   case 4:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv($1);
  return $2;
}

function __ZNK2js6Parser16versionWithFlagsEv($this) {
  var $1 = $this + 40 | 0;
  var $2 = __ZNK2js11TokenStream16versionWithFlagsEv($1);
  return $2;
}

function __Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj($cx, $kind, $thingSize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[$cx + 56 >> 2] + 8 | 0;
    var $5 = __ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj($4, $kind, $thingSize);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $11 = $5;
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $cx;
    var $9 = __ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE($8, $kind);
    var $11 = $9;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 236,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_($this, $p, $t) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($1, $p, $t);
  return $2;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_($this, $p, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$t >> 2];
    var $6 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$6 >> 2] = $3;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc($l);
  var $2 = __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj($this, $l, $1, 1);
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc($l) {
  var $1 = HEAP32[$l >> 2];
  var $2 = __ZN2js20ScriptFilenameHasher4hashEPKc($1);
  var $3 = $2 * -1640531527 | 0;
  var $4 = $3 - 2 | 0;
  var $5 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($3);
  var $_ = $5 ? $3 : $4;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + ($3 << 3) | 0;
    var $7 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + ($26 << 3) | 0;
    var $28 = __ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_($1);
  var $3 = HEAP32[$2 >> 2];
  var $4 = HEAP32[$l >> 2];
  var $5 = __ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc($3, $4);
  return $5;
}

function __ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc($e, $l) {
  var $1 = $e + 1 | 0;
  var $2 = _strcmp($1, $l);
  return ($2 | 0) == 0;
}

function __ZN2js20ScriptFilenameHasher4hashEPKc($l) {
  var $1 = _JS_HashString($l);
  return $1;
}

function __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj($hash);
  return $1;
}

function __ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev($this_0_0_val, $this_0_1_val) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this_0_0_val + 16 >> 2];
    if (($2 | 0) == ($this_0_0_val | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $this_0_1_val;
    var $8 = HEAP32[$2 + 4 >> 2];
    var $10 = $2 + 12 | 0;
    if (($6 - $8 | 0) >>> 0 > (HEAP32[$10 >> 2] - $8 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = HEAP32[$this_0_0_val + 24 >> 2];
    var $19 = $16 + $6 & ($16 ^ -1);
    HEAP32[$10 >> 2] = $19;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($this_0_0_val, $this_0_1_val);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext($cx) {
  var $4 = $cx;
  var $5 = HEAP32[$cx + 56 >> 2] + 756 | 0;
  var $6 = __ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_($4, __ZN2js9CallClassE, $5);
  return $6;
}

function __ZL10str_escapeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZNK8JSString6lengthEv($4);
    var $6 = __ZNK14JSLinearString5charsEv($1);
    var $i_0 = 0;
    var $newlength_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $newlength_0;
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $11 = HEAPU16[$6 + ($i_0 << 1) >> 1];
    if (($11 & 65535) < 128) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough + ($11 & 65535) | 0;
    if (HEAP8[$15] << 24 >> 24 == 0) {
      __label__ = 6;
      break;
    } else {
      var $newlength_1 = $newlength_0;
      __label__ = 8;
      break;
    }
   case 6:
    var $20 = ($11 & 65535) < 256 ? 2 : 5;
    var $21 = $20 + $newlength_0 | 0;
    if ($21 >>> 0 < $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $newlength_1 = $21;
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($24);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 8:
    var $newlength_1;
    var $i_0 = $i_0 + 1 | 0;
    var $newlength_0 = $newlength_1;
    __label__ = 3;
    break;
   case 9:
    if ($newlength_0 >>> 0 > 2147483646) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $30 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($30);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $34 = $cx;
    var $35 = __ZN9JSContext7malloc_Ej($34, ($newlength_0 << 1) + 2 | 0);
    var $36 = $35;
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($5 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $i1_01 = 0;
      var $ni_02 = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $ni_02;
    var $i1_01;
    var $40 = HEAPU16[$6 + ($i1_01 << 1) >> 1];
    var $41 = $40 & 65535;
    if (($40 & 65535) < 128) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    var $44 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough + $41 | 0;
    var $47 = $ni_02 + 1 | 0;
    var $48 = $36 + ($ni_02 << 1) | 0;
    if (HEAP8[$44] << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP16[$48 >> 1] = 37;
    var $55 = $47;
    __label__ = 18;
    break;
   case 16:
    HEAP16[$48 >> 1] = $40;
    var $ni_1 = $47;
    __label__ = 20;
    break;
   case 17:
    var $51 = ($40 & 65535) < 256;
    var $52 = $ni_02 + 1 | 0;
    HEAP16[$36 + ($ni_02 << 1) >> 1] = 37;
    if ($51) {
      var $55 = $52;
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $55;
    var $57 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 >>> 4) | 0;
    HEAP16[$36 + ($55 << 1) >> 1] = HEAP8[$57] << 24 >> 24;
    var $63 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 & 15) | 0;
    HEAP16[$36 + ($ni_02 + 2 << 1) >> 1] = HEAP8[$63] << 24 >> 24;
    var $ni_1 = $ni_02 + 3 | 0;
    __label__ = 20;
    break;
   case 19:
    HEAP16[$36 + ($52 << 1) >> 1] = 117;
    var $72 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 >>> 12) | 0;
    HEAP16[$36 + ($ni_02 + 2 << 1) >> 1] = HEAP8[$72] << 24 >> 24;
    var $79 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 >>> 8 & 15) | 0;
    HEAP16[$36 + ($ni_02 + 3 << 1) >> 1] = HEAP8[$79] << 24 >> 24;
    var $86 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 >>> 4 & 15) | 0;
    HEAP16[$36 + ($ni_02 + 4 << 1) >> 1] = HEAP8[$86] << 24 >> 24;
    var $92 = STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits + ($41 & 15) | 0;
    HEAP16[$36 + ($ni_02 + 5 << 1) >> 1] = HEAP8[$92] << 24 >> 24;
    var $ni_1 = $ni_02 + 6 | 0;
    __label__ = 20;
    break;
   case 20:
    var $ni_1;
    var $98 = $i1_01 + 1 | 0;
    if (($98 | 0) == ($5 | 0)) {
      __label__ = 21;
      break;
    } else {
      var $i1_01 = $98;
      var $ni_02 = $ni_1;
      __label__ = 13;
      break;
    }
   case 21:
    HEAP16[$36 + ($newlength_0 << 1) >> 1] = 0;
    var $100 = __Z12js_NewStringP9JSContextPtj($cx, $36, $newlength_0);
    if (($100 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    __ZN9JSContext5free_EPv(undef, $35);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 23:
    var $104 = $100 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $104);
    var $_0 = 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10str_escapeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12str_unescapeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZNK8JSString6lengthEv($4);
    var $6 = __ZNK14JSLinearString5charsEv($1);
    var $8 = ($5 << 1) + 2 | 0;
    var $9 = $cx;
    var $10 = __ZN9JSContext7malloc_Ej($9, $8);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 38;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($5 | 0) == 0) {
      var $ni_0_lcssa = 0;
      __label__ = 35;
      break;
    } else {
      var $ni_01 = 0;
      var $i_02 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_02;
    var $ni_01;
    var $14 = $i_02 + 1 | 0;
    var $16 = HEAPU16[$6 + ($i_02 << 1) >> 1];
    if ($16 << 16 >> 16 == 37) {
      __label__ = 5;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 5:
    var $19 = $i_02 + 2 | 0;
    if ($19 >>> 0 < $5 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 6:
    var $22 = $6 + ($14 << 1) | 0;
    var $23 = HEAPU16[$22 >> 1];
    if (($23 & 65535) < 128) {
      __label__ = 7;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 7:
    var $26 = $23 & 65535;
    var $27 = _isxdigit($26);
    if (($27 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $6 + ($19 << 1) | 0;
    var $31 = HEAPU16[$30 >> 1];
    if (($31 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    var $34 = $31 & 65535;
    var $35 = _isxdigit($34);
    if (($35 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $39 = HEAPU16[$22 >> 1] & 65535;
    var $40 = $39 - 48 | 0;
    if ($40 >>> 0 < 10) {
      var $46 = $40;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = _tolower($39);
    var $46 = $43 - 87 | 0;
    __label__ = 12;
    break;
   case 12:
    var $46;
    var $47 = $46 << 4;
    var $49 = HEAPU16[$30 >> 1] & 65535;
    var $50 = $49 - 48 | 0;
    if ($50 >>> 0 < 10) {
      var $56 = $50;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = _tolower($49);
    var $56 = $53 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $56;
    var $ch_0 = $56 + $47 & 65535;
    var $i_1 = $i_02 + 3 | 0;
    __label__ = 34;
    break;
   case 15:
    var $61 = $i_02 + 5 | 0;
    if ($61 >>> 0 < $5 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 16:
    if (HEAP16[$6 + ($14 << 1) >> 1] << 16 >> 16 == 117) {
      __label__ = 17;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 17:
    var $68 = $6 + ($19 << 1) | 0;
    var $69 = HEAPU16[$68 >> 1];
    if (($69 & 65535) < 128) {
      __label__ = 18;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 18:
    var $72 = $69 & 65535;
    var $73 = _isxdigit($72);
    if (($73 | 0) == 0) {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $77 = $6 + ($i_02 + 3 << 1) | 0;
    var $78 = HEAPU16[$77 >> 1];
    if (($78 & 65535) < 128) {
      __label__ = 20;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 20:
    var $81 = $78 & 65535;
    var $82 = _isxdigit($81);
    if (($82 | 0) == 0) {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $86 = $6 + ($i_02 + 4 << 1) | 0;
    var $87 = HEAPU16[$86 >> 1];
    if (($87 & 65535) < 128) {
      __label__ = 22;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 22:
    var $90 = $87 & 65535;
    var $91 = _isxdigit($90);
    if (($91 | 0) == 0) {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $94 = $6 + ($61 << 1) | 0;
    var $95 = HEAPU16[$94 >> 1];
    if (($95 & 65535) < 128) {
      __label__ = 24;
      break;
    } else {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    }
   case 24:
    var $98 = $95 & 65535;
    var $99 = _isxdigit($98);
    if (($99 | 0) == 0) {
      var $ch_0 = $16;
      var $i_1 = $14;
      __label__ = 34;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $103 = HEAPU16[$68 >> 1] & 65535;
    var $104 = $103 - 48 | 0;
    if ($104 >>> 0 < 10) {
      var $110 = $104;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $107 = _tolower($103);
    var $110 = $107 - 87 | 0;
    __label__ = 27;
    break;
   case 27:
    var $110;
    var $111 = $110 << 4;
    var $113 = HEAPU16[$77 >> 1] & 65535;
    var $114 = $113 - 48 | 0;
    if ($114 >>> 0 < 10) {
      var $120 = $114;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $117 = _tolower($113);
    var $120 = $117 - 87 | 0;
    __label__ = 29;
    break;
   case 29:
    var $120;
    var $122 = $120 + $111 << 4;
    var $124 = HEAPU16[$86 >> 1] & 65535;
    var $125 = $124 - 48 | 0;
    if ($125 >>> 0 < 10) {
      var $131 = $125;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $128 = _tolower($124);
    var $131 = $128 - 87 | 0;
    __label__ = 31;
    break;
   case 31:
    var $131;
    var $133 = $131 + $122 << 4;
    var $135 = HEAPU16[$94 >> 1] & 65535;
    var $136 = $135 - 48 | 0;
    if ($136 >>> 0 < 10) {
      var $142 = $136;
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $139 = _tolower($135);
    var $142 = $139 - 87 | 0;
    __label__ = 33;
    break;
   case 33:
    var $142;
    var $ch_0 = $142 + $133 & 65535;
    var $i_1 = $i_02 + 6 | 0;
    __label__ = 34;
    break;
   case 34:
    var $i_1;
    var $ch_0;
    var $147 = $ni_01 + 1 | 0;
    HEAP16[$11 + ($ni_01 << 1) >> 1] = $ch_0;
    if ($i_1 >>> 0 < $5 >>> 0) {
      var $ni_01 = $147;
      var $i_02 = $i_1;
      __label__ = 4;
      break;
    } else {
      var $ni_0_lcssa = $147;
      __label__ = 35;
      break;
    }
   case 35:
    var $ni_0_lcssa;
    HEAP16[$11 + ($ni_0_lcssa << 1) >> 1] = 0;
    var $151 = __Z12js_NewStringP9JSContextPtj($cx, $11, $ni_0_lcssa);
    if (($151 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    __ZN9JSContext5free_EPv(undef, $10);
    var $_0 = 0;
    __label__ = 38;
    break;
   case 37:
    var $155 = $151 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $155);
    var $_0 = 1;
    __label__ = 38;
    break;
   case 38:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12str_unescapeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_unevalP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $vp + 16 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $1 | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv3828($1);
    __label__ = 4;
    break;
   case 4:
    var $9 = __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($cx, $1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $9);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_decodeURIP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $4, __ZL29js_uriReservedPlusPound_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_encodeURIP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $4, __ZL29js_uriReservedPlusPound_ucstr | 0, __ZL21js_uriUnescaped_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $4, _js_empty_ucstr | 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    var $5 = __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $4, __ZL21js_uriUnescaped_ucstr | 0, 0, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13str_enumerateP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject16getPrimitiveThisEv($2);
    var $4 = __ZNK2JS5Value8toStringEv($3);
    var $5 = __ZNK8JSString6lengthEv($4);
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $9 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $4, $i_0, 1);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $12);
    var $13 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $i_0, $1, 10, 12, 7);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11str_resolveP9JSContextP8JSObjectijPS2_($cx, $obj, $id, $flags, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = _JSID_IS_INT3906($id);
    if (($2 | 0) == 0) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = __ZNK8JSObject16getPrimitiveThisEv($5);
    var $7 = __ZNK2JS5Value8toStringEv($6);
    var $8 = _JSID_TO_INT3948($id);
    var $9 = __ZNK8JSString6lengthEv($7);
    if ($8 >>> 0 < $9 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 3:
    var $14 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $15 = $cx;
    var $16 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($14, $15, $7, $8);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = $16 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $19);
    var $20 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj, $cx, $8, $1, 0, 0, 7);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_str_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $1 = __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = HEAP32[$str >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $3);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($1);
    HEAP32[$v >> 2] = $4;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isObjectEv($1);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toObjectEv($1);
    var $9 = __ZNK8JSObject8getClassEv($8);
    if (($9 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = $8;
    var $13 = __ZNK8JSObject16getPrimitiveThisEv($12);
    var $14 = __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($13);
    HEAP32[$v >> 2] = $14;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 6:
    var $16 = $cx;
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($16, $vp, __ZN2js11StringClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_toLowerCaseP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 << 1) + 2 | 0;
    var $8 = __ZN9JSContext7malloc_Ej($2, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_01;
    var $13 = HEAP16[$3 + ($i_01 << 1) >> 1];
    var $14 = __ZN2js7unicode11ToLowerCaseEt($13);
    HEAP16[$9 + ($i_01 << 1) >> 1] = $14;
    var $16 = $i_01 + 1 | 0;
    if (($16 | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP16[$9 + ($1 << 1) >> 1] = 0;
    var $18 = __Z12js_NewStringP9JSContextPtj($cx, $9, $1);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $_0 = $18 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_NewStringP9JSContextPtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL17CheckStringLengthEP9JSContextj3839($cx, $length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN13JSFixedString4new_EP9JSContextPKtj($cx, $chars, $length);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z14js_toUpperCaseP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = ($1 << 1) + 2 | 0;
    var $8 = __ZN9JSContext7malloc_Ej($2, $7);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $i_01;
    var $13 = HEAP16[$3 + ($i_01 << 1) >> 1];
    var $14 = __ZN2js7unicode11ToUpperCaseEt($13);
    HEAP16[$9 + ($i_01 << 1) >> 1] = $14;
    var $16 = $i_01 + 1 | 0;
    if (($16 | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $i_01 = $16;
      __label__ = 4;
      break;
    }
   case 5:
    HEAP16[$9 + ($1 << 1) >> 1] = 0;
    var $18 = __Z12js_NewStringP9JSContextPtj($cx, $9, $1);
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    var $_0 = $18 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7unicode11ToUpperCaseEt($ch) {
  var $1 = __ZN2js7unicode8CharInfoEt($ch);
  var $8 = (HEAP8[$1 + 4 | 0] & 8) << 24 >> 24 == 0 ? $ch : 0;
  return $8 + HEAP16[$1 >> 1] & 65535;
}

function __Z13js_str_charAtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = __ZNK2JS5Value8isStringEv($1);
    var $3 = ($argc | 0) == 0;
    if ($3 | $2 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value7isInt32Ev($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toStringEv($1);
    var $9 = __ZNK2JS5Value7toInt32Ev($5);
    var $10 = __ZNK8JSString6lengthEv($8);
    if ($9 >>> 0 < $10 >>> 0) {
      var $i_0 = $9;
      var $str_0 = $8;
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($3) {
      var $21 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $vp + 16 | 0;
    var $18 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $17, $d);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 12;
      break;
    } else {
      var $21 = $_pr;
      __label__ = 8;
      break;
    }
   case 8:
    var $21;
    var $22 = __ZNK8JSString6lengthEv($13);
    if ($22 >>> 0 > $21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $i_0 = $21 & -1;
    var $str_0 = $13;
    __label__ = 10;
    break;
   case 10:
    var $str_0;
    var $i_0;
    var $30 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $31 = $cx;
    var $32 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($30, $31, $str_0, $i_0);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = $32 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $35);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $41 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $41);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z13js_str_charAtP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 3:
    var $8 = $vp + 8 | 0;
    var $9 = __ZNK2JS5Value8isStringEv($8);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK2JS5Value8toStringEv($8);
    var $_0 = $11;
    __label__ = 13;
    break;
   case 5:
    var $13 = __ZNK2JS5Value8isObjectEv($8);
    if ($13) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $15 = __ZNK2JS5Value8toObjectEv($8);
    var $16 = __ZNK8JSObject8isStringEv($15);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $18 = $15;
    var $23 = HEAP32[HEAP32[$cx + 52 >> 2] + 210324 >> 2] | 0;
    var $24 = __ZL12ATOM_TO_JSIDP6JSAtom3836($23);
    var $25 = __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938($cx, $18, $24);
    if ($25) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $27 = $15;
    var $28 = __ZNK8JSObject16getPrimitiveThisEv($27);
    var $29 = $28 | 0;
    var $30$0 = HEAP32[$29 >> 2];
    var $30$1 = HEAP32[$29 + 4 >> 2];
    var $31 = $8 | 0;
    HEAP32[$31 >> 2] = $30$0;
    HEAP32[$31 + 4 >> 2] = $30$1;
    var $32 = __ZNK2JS5Value8toStringEv($8);
    var $_0 = $32;
    __label__ = 13;
    break;
   case 9:
    var $34 = __ZNK2JS5Value17isNullOrUndefinedEv($8);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = __ZNK2JS5Value6isNullEv($8);
    var $37 = $36 ? STRING_TABLE._js_null_str | 0 : STRING_TABLE._js_undefined_str | 0;
    var $38 = $cx;
    _JS_ReportErrorNumber($38, 2, 0, 38, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $37, HEAP32[tempInt + 4 >> 2] = STRING_TABLE._js_object_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 13;
    break;
   case 11:
    var $40 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $8);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JS5Value9setStringEP8JSString($8, $40);
    var $_0 = $40;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $v, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK2JS5Value7isInt32Ev($v);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value7toInt32Ev($v);
    tempDoubleF64[0] = $4 | 0, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    tempDoubleF64[0] = $9, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $17 = $9;
    __label__ = 7;
    break;
   case 5:
    var $11 = $v | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $1 | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $14 = $cx;
    var $15 = __ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd($14, $1, $dp);
    if ($15) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $_pre = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $17 = $_pre;
    __label__ = 7;
    break;
   case 7:
    var $17;
    var $18 = __ZL18js_DoubleToIntegerd3931($17);
    tempDoubleF64[0] = $18, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = __ZNK2JS5Value8isStringEv($1);
    var $3 = ($argc | 0) == 0;
    if ($3 | $2 ^ 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $vp + 16 | 0;
    var $6 = __ZNK2JS5Value7isInt32Ev($5);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toStringEv($1);
    var $9 = __ZNK2JS5Value7toInt32Ev($5);
    var $10 = __ZNK8JSString6lengthEv($8);
    if ($9 >>> 0 < $10 >>> 0) {
      var $i_0 = $9;
      var $str_0 = $8;
      __label__ = 10;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($3) {
      var $21 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = $vp + 16 | 0;
    var $18 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $17, $d);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $_pr = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($_pr < 0) {
      __label__ = 12;
      break;
    } else {
      var $21 = $_pr;
      __label__ = 8;
      break;
    }
   case 8:
    var $21;
    var $22 = __ZNK8JSString6lengthEv($13);
    if ($22 >>> 0 > $21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    var $i_0 = $21 & -1;
    var $str_0 = $13;
    __label__ = 10;
    break;
   case 10:
    var $str_0;
    var $i_0;
    var $28 = $cx;
    var $29 = __ZN8JSString8getCharsEP9JSContext($str_0, $28);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = HEAPU16[$29 + ($i_0 << 1) >> 1] & 65535;
    __ZN2JS5Value8setInt32Ei($vp, $34);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 12:
    var $36 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    __ZN2JS5Value9setDoubleEd($vp, $36);
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_BoyerMooreHorspoolPKtjS0_j($text, $textlen, $pat, $patlen) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 256;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $skip = __stackBase__;
    var $skip7 = $skip | 0;
    var $1 = $patlen & 255;
    _memset($skip7, $1, 256, 1);
    var $2 = $patlen - 1 | 0;
    var $i1_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i1_0;
    if ($i1_0 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $k_0 = $2;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAPU16[$pat + ($i1_0 << 1) >> 1];
    if (($7 & 65535) > 255) {
      var $_0 = -2;
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP8[$skip + ($7 & 65535) | 0] = $2 - $i1_0 & 255;
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $textlen >>> 0) {
      var $j_0 = $2;
      var $i3_0 = $k_0;
      __label__ = 6;
      break;
    } else {
      var $_0 = -1;
      __label__ = 12;
      break;
    }
   case 6:
    var $i3_0;
    var $j_0;
    if (HEAP16[$text + ($i3_0 << 1) >> 1] << 16 >> 16 == HEAP16[$pat + ($j_0 << 1) >> 1] << 16 >> 16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if (($j_0 | 0) == 0) {
      var $_0 = $i3_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $j_0 = $j_0 - 1 | 0;
    var $i3_0 = $i3_0 - 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $28 = HEAPU16[$text + ($k_0 << 1) >> 1];
    if (($28 & 65535) > 255) {
      var $36 = $patlen;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = HEAPU8[$skip + ($28 & 65535) | 0] & 255;
    __label__ = 11;
    break;
   case 11:
    var $36;
    var $k_0 = $36 + $k_0 | 0;
    __label__ = 5;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z21js_BoyerMooreHorspoolPKtjS0_j["X"] = 1;

function __Z15js_strchr_limitPKttS0_($s, $c, $limit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if ($_01 >>> 0 < $limit >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == $c << 16 >> 16) {
      var $_0 = $_01;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK9FlatMatch5matchEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js11str_replaceEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 184;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rdata = __stackBase__;
    var $table = __stackBase__ + 176;
    __ZN11ReplaceDataC1EP9JSContext($rdata, $cx);
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    var $2 = $rdata | 0;
    HEAP32[$2 >> 2] = $1;
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $rdata + 4 | 0;
    var $6 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($5, $argc, $vp, 0);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 31;
      break;
    }
   case 3:
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 4:
    var $10 = $vp + 24 | 0;
    var $11 = __ZL13js_IsCallableRKN2JS5ValueE3827($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 5:
    var $13 = __ZNK2JS5Value8toObjectEv($10);
    var $15 = $rdata + 36 | 0;
    HEAP32[$15 >> 2] = $13;
    var $16 = $rdata + 40 | 0;
    HEAP32[$16 >> 2] = 0;
    HEAP32[$rdata + 44 >> 2] = 0;
    HEAP32[$rdata + 52 >> 2] = 0;
    HEAP32[$rdata + 48 >> 2] = 0;
    var $20 = __ZNK8JSObject10isFunctionEv($13);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 6:
    var $22 = __ZNK8JSObject18getFunctionPrivateEv($13);
    var $23 = __ZNK10JSFunction13isInterpretedEv($22);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 7:
    var $25 = __ZNK10JSFunction6scriptEv($22);
    var $27 = HEAPU32[$25 >> 2];
    __ZN2JSL14UndefinedValueEv3828($table);
    if (HEAP8[$27] << 24 >> 24 == -120) {
      __label__ = 8;
      break;
    } else {
      var $pc_0 = $27;
      __label__ = 9;
      break;
    }
   case 8:
    var $39 = (HEAPU8[$27 + 1 | 0] & 255) << 8 | HEAPU8[$27 + 2 | 0] & 255;
    var $40 = HEAP32[$15 >> 2];
    var $41 = __ZN8JSObject19getFlatClosureUpvarEj($40, $39);
    var $42 = $41 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $table | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $pc_0 = $27 + 3 | 0;
    __label__ = 9;
    break;
   case 9:
    var $pc_0;
    var $47 = __ZNK2JS5Value8isObjectEv($table);
    if ($47) {
      __label__ = 10;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 10:
    if (HEAP8[$pc_0] << 24 >> 24 == 84) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 11:
    if (((HEAPU8[$pc_0 + 1 | 0] & 255) << 8 | HEAPU8[$pc_0 + 2 | 0] & 255 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 12:
    if (HEAP8[$pc_0 + 3 | 0] << 24 >> 24 == 55) {
      __label__ = 13;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 13:
    if (HEAP8[$pc_0 + 4 | 0] << 24 >> 24 == 5) {
      __label__ = 14;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 14:
    var $70 = __ZNK2JS5Value8toObjectEv($table);
    var $71 = __ZNK8JSObject8getClassEv($70);
    var $72 = __ZNK2js5Class8isNativeEv($71);
    if ($72) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    if ((HEAP32[$71 + 96 >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 16:
    if ((HEAP32[$71 + 128 >> 2] | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 17:
    HEAP32[$16 >> 2] = $70;
    __label__ = 21;
    break;
   case 18:
    HEAP32[$rdata + 36 >> 2] = 0;
    HEAP32[$rdata + 40 >> 2] = 0;
    var $86 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 1);
    HEAP32[$rdata + 44 >> 2] = $86;
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $90 = $86 | 0;
    var $91 = $cx;
    var $92 = __ZN8JSString11ensureFixedEP9JSContext($90, $91);
    if (($92 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $95 = $92 | 0;
    var $96 = __ZNK14JSLinearString5charsEv($95);
    var $97 = $92 | 0;
    var $98 = __ZNK8JSString6lengthEv($97);
    var $99 = $96 + ($98 << 1) | 0;
    HEAP32[$rdata + 52 >> 2] = $99;
    var $101 = __ZNK14JSLinearString5charsEv($95);
    var $102 = __Z15js_strchr_limitPKttS0_($101, 36, $99);
    HEAP32[$rdata + 48 >> 2] = $102;
    __label__ = 21;
    break;
   case 21:
    var $105 = HEAP32[$2 >> 2];
    var $106 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($5, $cx, $105, 2, $argc, 0);
    if (($106 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $109 = $cx;
    var $110 = __ZN9JSContext18isExceptionPendingEv($109);
    if ($110) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $112 = __ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData($cx, $argc, $vp, $rdata);
    var $_0 = $112 & 1;
    __label__ = 31;
    break;
   case 24:
    var $115 = __ZNK9FlatMatch5matchEv($106);
    if (($115 | 0) < 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $118 = HEAP32[$2 >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $118);
    var $_0 = 1;
    __label__ = 31;
    break;
   case 26:
    if ((HEAP32[$rdata + 36 >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $124 = __ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch($cx, $vp, $rdata, $106);
    var $_0 = $124 & 1;
    __label__ = 31;
    break;
   case 28:
    var $128 = HEAPU32[$rdata + 48 >> 2];
    var $130 = HEAPU32[$2 >> 2];
    var $132 = HEAPU32[$rdata + 44 >> 2];
    if (($128 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $134 = __ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE($cx, $130, $132, $128, $106, $vp);
    var $_0 = $134 & 1;
    __label__ = 31;
    break;
   case 30:
    var $137 = $132 | 0;
    var $138 = __ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE($cx, $130, $137, $106, $vp);
    var $_0 = $138 & 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    __ZN11ReplaceDataD1Ev($rdata);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js11str_replaceEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN11ReplaceDataC1EP9JSContext($this, $cx) {
  __ZN11ReplaceDataC2EP9JSContext($this, $cx);
  return;
}

function __ZN11RegExpGuard4initEjPN2JS5ValueEb($this, $argc, $vp, $convertVoid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($argc | 0) == 0;
    if ($1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = $3 | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($5$0, $5$1);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = $this + 4 | 0;
    var $9 = __ZNK2JS5Value8toObjectEv($3);
    var $10 = $9;
    __ZN10RegExpPair5resetER8JSObject($8, $10);
    __label__ = 9;
    break;
   case 4:
    if ($convertVoid) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    if ($1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = $vp + 16 | 0;
    var $15 = __ZNK2JS5Value11isUndefinedEv($14);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = HEAP32[HEAP32[HEAP32[$this >> 2] + 52 >> 2] + 144136 >> 2] | 0;
    HEAP32[$this + 16 >> 2] = $23;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 8:
    var $27 = HEAP32[$this >> 2];
    var $28 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($27, $argc, $vp, 0);
    HEAP32[$this + 16 >> 2] = $28;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13js_IsCallableRKN2JS5ValueE3827($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZN8JSObject10isCallableEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv3828($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, $arg) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($arg >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    __label__ = 14;
    break;
   case 3:
    var $10 = $vp + ($arg + 2 << 3) | 0;
    var $11 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $13 = __ZNK2JS5Value8isStringEv($10);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = __ZNK2JS5Value8toStringEv($10);
    var $16 = $cx;
    var $17 = __ZN8JSString12ensureLinearEP9JSContext($15, $16);
    var $_0 = $17;
    __label__ = 14;
    break;
   case 6:
    var $19 = __ZNK2JS5Value9isBooleanEv($10);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = __ZNK2JS5Value9toBooleanEv($10);
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209976 + (($21 & 1) << 2) >> 2] | 0;
    __label__ = 14;
    break;
   case 8:
    var $29 = __ZNK2JS5Value6isNullEv($10);
    if ($29) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210016 >> 2] | 0;
    __label__ = 14;
    break;
   case 10:
    var $37 = __ZNK2JS5Value11isUndefinedEv($10);
    if ($37) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    __label__ = 14;
    break;
   case 12:
    var $45 = __ZNK2JS5Value8toNumberEv($10);
    var $46 = $cx;
    var $47 = __ZN2js14NumberToStringEP9JSContextd($46, $45);
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = $47 | 0;
    var $51 = $47 | 0;
    __ZN2JS5Value9setStringEP8JSString($10, $51);
    var $_0 = $50;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj["X"] = 1;

function __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($this, $cx, $textstr, $optarg, $argc, $checkMetaChars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = __ZNK10RegExpPair9hasRegExpEv($1);
    if ($2) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 16 | 0;
    var $6 = HEAP32[$4 >> 2];
    var $7 = __ZNK14JSLinearString5charsEv($6);
    HEAP32[$this + 20 >> 2] = $7;
    var $9 = $6 | 0;
    var $10 = __ZNK8JSString6lengthEv($9);
    HEAP32[$this + 24 >> 2] = $10;
    if ($optarg >>> 0 < $argc >>> 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($checkMetaChars) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if ($10 >>> 0 > 256) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZN2js6RegExp12hasMetaCharsEPKtj($7, $10);
    if ($17) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK8JSString6isRopeEv($textstr);
    if ($19) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $21 = $this + 28 | 0;
    var $22 = __ZL9RopeMatchP9JSContextP8JSStringPKtjPi($cx, $textstr, $7, $10, $21);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $24 = __ZN8JSString8asLinearEv($textstr);
    var $25 = __ZNK14JSLinearString5charsEv($24);
    var $26 = __ZNK8JSString6lengthEv($textstr);
    var $27 = __ZL11StringMatchPKtjS0_j($25, $26, $7, $10);
    HEAP32[$this + 28 >> 2] = $27;
    __label__ = 9;
    break;
   case 9:
    var $_0 = $4;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData($cx, $argc, $vp, $rdata) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $sub = __stackBase__ + 8;
    var $1 = $rdata + 4 | 0;
    var $2 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($1, 1, 2, $argc, $vp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$rdata + 56 >> 2] = 0;
    var $6 = $rdata + 68 | 0;
    HEAP8[$6] = 0;
    var $7 = $cx;
    var $8 = __ZN9JSContext13regExpStaticsEv($7);
    var $9 = $rdata | 0;
    var $10 = HEAP32[$9 >> 2];
    var $11 = $rdata;
    var $12 = __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $8, $10, $2, 238, $11, 7, $tmp);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    if ((HEAP8[$6] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$9 >> 2];
    __ZN2JS5Value9setStringEP8JSString($vp, $18);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($8, $sub);
    var $20 = $rdata + 96 | 0;
    var $22 = HEAP32[$sub + 4 >> 2];
    var $24 = HEAP32[$sub >> 2];
    var $25 = $20;
    var $26 = __ZN2js12StringBuffer6appendEPKtj($25, $22, $24);
    if ($26) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $28 = __ZN2js12StringBuffer12finishStringEv($20);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $28 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $31);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch($cx, $vp, $rdata, $fm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $1 = $rdata | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZNK9FlatMatch5matchEv($fm);
    var $4 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $5 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $2, $3, $4);
    var $6 = $5 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $rdata + 72 | 0;
    var $11 = $cx + 60 | 0;
    var $12 = $cx;
    var $13 = $10;
    var $14 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($11, $12, 3, $13);
    if ($14) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $16 = $10 | 0;
    var $17 = $10 | 0;
    var $18 = __ZNK2js12CallReceiver7calleevEv($17);
    var $21 = HEAP32[$rdata + 36 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($18, $21);
    var $22 = __ZNK2js12CallReceiver5thisvEv($17);
    __ZN2JS5Value12setUndefinedEv($22);
    var $23 = __ZNK2js8CallArgs4argvEv($16);
    __ZN2JS5Value9setStringEP8JSString($23, $6);
    var $24 = $23 + 8 | 0;
    var $25 = __ZNK9FlatMatch5matchEv($fm);
    __ZN2JS5Value8setInt32Ei($24, $25);
    var $26 = $23 + 16 | 0;
    var $27 = HEAP32[$1 >> 2];
    __ZN2JS5Value9setStringEP8JSString($26, $27);
    var $28 = $cx;
    var $29 = $10;
    var $30 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($28, $29, 0);
    if ($30) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 4:
    var $32 = __ZNK2js12CallReceiver4rvalEv($17);
    var $33 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $32);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $36 = HEAP32[$1 >> 2];
    var $37 = __ZNK9FlatMatch5matchEv($fm);
    var $38 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $36, 0, $37);
    var $39 = $38 | 0;
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $42 = __ZNK9FlatMatch5matchEv($fm);
    var $43 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $44 = $43 + $42 | 0;
    var $45 = HEAP32[$1 >> 2];
    var $46 = __ZNK8JSString6lengthEv($45);
    var $47 = $46 - $44 | 0;
    var $48 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $45, $44, $47);
    var $49 = $48 | 0;
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $52 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $39);
    if ($52) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $54 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $33);
    if ($54) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $56 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $49);
    if ($56) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $58 = __ZN2js11RopeBuilder6resultEv($builder);
    __ZN2JS5Value9setStringEP8JSString($vp, $58);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch["X"] = 1;

function __ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE($cx, $textstrArg, $repstr, $firstDollar, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 88;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newReplaceChars = __stackBase__;
    var $builder = __stackBase__ + 80;
    var $1 = $cx;
    var $2 = __ZN8JSString12ensureLinearEP9JSContext($textstrArg, $1);
    if (($2 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK9FlatMatch5matchEv($fm);
    var $6 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $7 = $6 + $5 | 0;
    var $8 = $newReplaceChars;
    __ZN2js12StringBufferC1EP9JSContext($8, $1);
    var $9 = $2 | 0;
    var $10 = __ZNK8JSString6lengthEv($9);
    var $11 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $12 = $repstr | 0;
    var $13 = __ZNK8JSString6lengthEv($12);
    var $15 = $10 - $11 + $13 | 0;
    var $16 = __ZN2js12StringBuffer7reserveEj($8, $15);
    if ($16) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 3:
    var $18 = __ZNK14JSLinearString5charsEv($repstr);
    __ZN2js12StringBuffer16infallibleAppendEPKtS2_($newReplaceChars, $18, $firstDollar);
    var $19 = __ZNK14JSLinearString5charsEv($repstr);
    var $20 = __ZNK8JSString6lengthEv($12);
    var $21 = $19 + ($20 << 1) | 0;
    var $22 = $19 + ($20 - 1 << 1) | 0;
    var $23 = $newReplaceChars;
    var $it_0 = $firstDollar;
    __label__ = 4;
    break;
   case 4:
    var $it_0;
    if ($it_0 >>> 0 < $21 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 5:
    var $27 = HEAPU16[$it_0 >> 1];
    if ($27 << 16 >> 16 != 36 | ($it_0 | 0) == ($22 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $31 = __ZN2js12StringBuffer6appendEt($8, $27);
    if ($31) {
      var $it_1 = $it_0;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 7:
    var $33 = $it_0 + 2 | 0;
    var $35 = HEAPU16[$33 >> 1] & 65535;
    if (($35 | 0) == 36) {
      __label__ = 8;
      break;
    } else if (($35 | 0) == 38) {
      __label__ = 9;
      break;
    } else if (($35 | 0) == 96) {
      __label__ = 10;
      break;
    } else if (($35 | 0) == 39) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $37 = __ZN2js12StringBuffer6appendEt($8, 36);
    if ($37) {
      var $it_1 = $33;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 9:
    var $39 = __ZNK14JSLinearString5charsEv($2);
    var $40 = $39 + ($5 << 1) | 0;
    var $41 = $39 + ($7 << 1) | 0;
    var $42 = __ZN2js12StringBuffer6appendEPKtS2_($23, $40, $41);
    if ($42) {
      var $it_1 = $33;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 10:
    var $44 = __ZNK14JSLinearString5charsEv($2);
    var $45 = $44 + ($5 << 1) | 0;
    var $46 = __ZN2js12StringBuffer6appendEPKtS2_($23, $44, $45);
    if ($46) {
      var $it_1 = $33;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 11:
    var $48 = __ZNK14JSLinearString5charsEv($2);
    var $49 = $48 + ($7 << 1) | 0;
    var $50 = __ZNK8JSString6lengthEv($9);
    var $51 = $48 + ($50 << 1) | 0;
    var $52 = __ZN2js12StringBuffer6appendEPKtS2_($23, $49, $51);
    if ($52) {
      var $it_1 = $33;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 12:
    var $54 = __ZN2js12StringBuffer6appendEt($8, 36);
    if ($54) {
      var $it_1 = $it_0;
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 13:
    var $it_1;
    var $it_0 = $it_1 + 2 | 0;
    __label__ = 4;
    break;
   case 14:
    var $58 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $9, 0, $5);
    var $59 = $58 | 0;
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $62 = __ZN2js12StringBuffer12finishStringEv($newReplaceChars);
    var $63 = $62 | 0;
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $66 = __ZNK8JSString6lengthEv($9);
    var $67 = $66 - $7 | 0;
    var $68 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $9, $7, $67);
    var $69 = $68 | 0;
    if (($68 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $72 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $59);
    if ($72) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 18:
    var $74 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $63);
    if ($74) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 19:
    var $76 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $69);
    if ($76) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 21;
      break;
    }
   case 20:
    var $78 = __ZN2js11RopeBuilder6resultEv($builder);
    __ZN2JS5Value9setStringEP8JSString($vp, $78);
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js12StringBufferD1Ev($8);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE["X"] = 1;

function __ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE($cx, $textstr, $repstr, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 156;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $builder = __stackBase__;
    var $r = __stackBase__ + 8;
    __ZN2js11RopeBuilderC1EP9JSContext($builder, $cx);
    var $1 = __ZNK9FlatMatch5matchEv($fm);
    var $2 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $3 = $2 + $1 | 0;
    var $4 = __ZNK8JSString6isRopeEv($textstr);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 2:
    __ZN2js18StringSegmentRangeC1EP9JSContext($r, $cx);
    var $6 = __ZN2js18StringSegmentRange4initEP8JSString($r, $textstr);
    if ($6) {
      var $pos_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 3:
    var $pos_0;
    var $7 = __ZNK2js18StringSegmentRange5emptyEv($r);
    if ($7) {
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK2js18StringSegmentRange5frontEv($r);
    var $10 = $9 | 0;
    var $11 = __ZNK8JSString6lengthEv($10);
    var $12 = $11 + $pos_0 | 0;
    if ($pos_0 >>> 0 < $3 >>> 0 & $12 >>> 0 > $1 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    if ($1 >>> 0 < $pos_0 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $1 - $pos_0 | 0;
    var $19 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $10, 0, $18);
    if (($19 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = $19 | 0;
    var $23 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $22);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 8:
    var $25 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $repstr);
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 9:
    if ($12 >>> 0 > $3 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 10:
    var $29 = $3 - $pos_0 | 0;
    var $30 = $12 - $3 | 0;
    var $31 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $10, $29, $30);
    if (($31 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = $31 | 0;
    var $35 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $34);
    if ($35) {
      __label__ = 13;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 12:
    var $37 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $10);
    if ($37) {
      __label__ = 13;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 13:
    var $39 = __ZNK8JSString6lengthEv($10);
    var $40 = $39 + $pos_0 | 0;
    var $41 = __ZN2js18StringSegmentRange8popFrontEv($r);
    if ($41) {
      var $pos_0 = $40;
      __label__ = 3;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 14:
    __ZN2js18StringSegmentRangeD1Ev($r);
    __label__ = 20;
    break;
   case 15:
    var $44 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $textstr, 0, $1);
    var $45 = $44 | 0;
    if (($44 | 0) == 0) {
      var $_1 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZNK9FlatMatch13patternLengthEv($fm);
    var $49 = $48 + $1 | 0;
    var $50 = __ZNK8JSString6lengthEv($textstr);
    var $51 = $50 - $49 | 0;
    var $52 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $textstr, $49, $51);
    var $53 = $52 | 0;
    if (($52 | 0) == 0) {
      var $_1 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $56 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $45);
    if ($56) {
      __label__ = 18;
      break;
    } else {
      var $_1 = 0;
      __label__ = 29;
      break;
    }
   case 18:
    var $58 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $repstr);
    if ($58) {
      __label__ = 19;
      break;
    } else {
      var $_1 = 0;
      __label__ = 29;
      break;
    }
   case 19:
    var $60 = __ZN2js11RopeBuilder6appendEP8JSString($builder, $53);
    if ($60) {
      __label__ = 20;
      break;
    } else {
      var $_1 = 0;
      __label__ = 29;
      break;
    }
   case 20:
    var $62 = __ZN2js11RopeBuilder6resultEv($builder);
    __ZN2JS5Value9setStringEP8JSString($vp, $62);
    var $_1 = 1;
    __label__ = 29;
    break;
   case 21:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 22:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 23:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 24:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 25:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 26:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 27:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 28:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = 0;
    __label__ = 29;
    break;
   case 29:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE["X"] = 1;

function __ZN11ReplaceDataD1Ev($this) {
  __ZN11ReplaceDataD2Ev($this);
  return;
}

function __ZL9str_quoteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $1, 34);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $5);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12str_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $buf = __stackBase__ + 4;
    var $anchor = __stackBase__ + 20;
    var $1 = __ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_($cx, $vp, $str);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $3 = HEAP32[$str >> 2];
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $3, 34);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $buf | 0;
    var $9 = _JS_snprintf($8, 16, STRING_TABLE.__str473816 | 0, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $5);
    var $10 = __ZNK8JSString6lengthEv($5);
    var $11 = __ZN8JSString8getCharsEP9JSContext($5, $4);
    if (($11 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $10 + $9 | 0;
    var $15 = $14 + 2 | 0;
    var $17 = ($14 << 1) + 6 | 0;
    var $18 = __ZN9JSContext7malloc_Ej($4, $17);
    var $19 = $18;
    if (($18 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($9 | 0) == 0) {
      var $i_0_lcssa = 0;
      __label__ = 6;
      break;
    } else {
      var $i_04 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $i_0_lcssa;
    if (($10 | 0) == 0) {
      var $i_1_lcssa = $i_0_lcssa;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = $10 + $i_0_lcssa | 0;
    var $j_01 = 0;
    var $i_12 = $i_0_lcssa;
    __label__ = 9;
    break;
   case 8:
    var $i_04;
    HEAP16[$19 + ($i_04 << 1) >> 1] = HEAP8[$buf + $i_04 | 0] << 24 >> 24;
    var $28 = $i_04 + 1 | 0;
    if (($28 | 0) == ($9 | 0)) {
      var $i_0_lcssa = $9;
      __label__ = 6;
      break;
    } else {
      var $i_04 = $28;
      __label__ = 8;
      break;
    }
   case 9:
    var $i_12;
    var $j_01;
    var $31 = HEAP16[$11 + ($j_01 << 1) >> 1];
    HEAP16[$19 + ($i_12 << 1) >> 1] = $31;
    var $33 = $i_12 + 1 | 0;
    if (($33 | 0) == ($23 | 0)) {
      var $i_1_lcssa = $23;
      __label__ = 10;
      break;
    } else {
      var $j_01 = $j_01 + 1 | 0;
      var $i_12 = $33;
      __label__ = 9;
      break;
    }
   case 10:
    var $i_1_lcssa;
    HEAP16[$19 + ($i_1_lcssa << 1) >> 1] = 41;
    HEAP16[$19 + ($i_1_lcssa + 1 << 1) >> 1] = 41;
    HEAP16[$19 + ($i_1_lcssa + 2 << 1) >> 1] = 0;
    var $40 = __Z12js_NewStringP9JSContextPtj($cx, $19, $15);
    var $41 = $40 | 0;
    HEAP32[$str >> 2] = $41;
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN9JSContext5free_EPv(undef, $18);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 12:
    __ZN2JS5Value9setStringEP8JSString($vp, $41);
    var $_1 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12str_toSourceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13str_substringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $str_0 = $1;
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSString6lengthEv($1);
    HEAP32[$end >> 2] = $6;
    var $7 = $vp + 16 | 0;
    var $8 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $7, $begin);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = HEAP32[$begin >> 2];
    if (($10 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $17 = 0;
    __label__ = 8;
    break;
   case 6:
    if (($10 | 0) > ($6 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $17 = $10;
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$begin >> 2] = $6;
    var $17 = $6;
    __label__ = 8;
    break;
   case 8:
    var $17;
    if ($argc >>> 0 > 1) {
      __label__ = 9;
      break;
    } else {
      var $37 = $17;
      var $36 = $6;
      __label__ = 17;
      break;
    }
   case 9:
    var $20 = $vp + 24 | 0;
    var $21 = __ZNK2JS5Value11isUndefinedEv($20);
    if ($21) {
      var $37 = $17;
      var $36 = $6;
      __label__ = 17;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $20, $end);
    if ($23) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 11:
    var $25 = HEAPU32[$end >> 2];
    if (($25 | 0) > ($6 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$end >> 2] = $6;
    var $37 = $17;
    var $36 = $6;
    __label__ = 17;
    break;
   case 13:
    if (($25 | 0) < 0) {
      __label__ = 14;
      break;
    } else {
      var $32 = $25;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$end >> 2] = 0;
    var $32 = 0;
    __label__ = 15;
    break;
   case 15:
    var $32;
    if (($32 | 0) < ($17 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $37 = $17;
      var $36 = $32;
      __label__ = 17;
      break;
    }
   case 16:
    HEAP32[$begin >> 2] = $32;
    HEAP32[$end >> 2] = $17;
    var $37 = $32;
    var $36 = $17;
    __label__ = 17;
    break;
   case 17:
    var $36;
    var $37;
    var $39 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $37, $36 - $37 | 0);
    var $40 = $39 | 0;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $str_0 = $40;
      __label__ = 18;
      break;
    }
   case 18:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13str_substringP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_toLowerCaseP9JSContextP8JSString($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_toUpperCaseP9JSContextP8JSString($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2JS5Value9setStringEP8JSString($vp, $4);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11str_indexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK8JSString6lengthEv($1);
    var $8 = $cx;
    var $9 = __ZN8JSString8getCharsEP9JSContext($1, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $4 | 0;
    var $13 = __ZNK8JSString6lengthEv($12);
    var $14 = __ZNK14JSLinearString5charsEv($4);
    if ($argc >>> 0 > 1) {
      __label__ = 5;
      break;
    } else {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    }
   case 5:
    var $17 = $vp + 24 | 0;
    var $18 = __ZNK2JS5Value7isInt32Ev($17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = __ZNK2JS5Value7toInt32Ev($17);
    if (($20 | 0) < 1) {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($20 >>> 0 > $7 >>> 0) {
      var $start_0 = $7;
      var $text_0 = $9;
      var $textlen_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $start_0 = $20;
    var $text_0 = $9 + ($20 << 1) | 0;
    var $textlen_0 = $7 - $20 | 0;
    __label__ = 13;
    break;
   case 9:
    var $28 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $17, $d);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 10:
    var $30 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($30 > 0) {
      __label__ = 11;
      break;
    } else {
      var $start_0 = 0;
      var $text_0 = $9;
      var $textlen_0 = $7;
      __label__ = 13;
      break;
    }
   case 11:
    if ($30 > $7 >>> 0) {
      var $start_0 = $7;
      var $text_0 = $9;
      var $textlen_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $36 = $30 & -1;
    var $start_0 = $36;
    var $text_0 = $9 + ($36 << 1) | 0;
    var $textlen_0 = $7 - $36 | 0;
    __label__ = 13;
    break;
   case 13:
    var $textlen_0;
    var $text_0;
    var $start_0;
    var $40 = __ZL11StringMatchPKtjS0_j($text_0, $textlen_0, $14, $13);
    var $43 = ($40 | 0) == -1 ? -1 : $40 + $start_0 | 0;
    __ZN2JS5Value8setInt32Ei($vp, $43);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11str_indexOfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($1);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9 | 0;
    var $13 = __ZNK8JSString6lengthEv($12);
    var $14 = __ZNK14JSLinearString5charsEv($9);
    var $15 = $4 - $13 | 0;
    if (($15 | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 6:
    if ($argc >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      var $i_0 = $15;
      __label__ = 16;
      break;
    }
   case 7:
    var $21 = $vp + 24 | 0;
    var $22 = __ZNK2JS5Value7isInt32Ev($21);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = __ZNK2JS5Value7toInt32Ev($21);
    if (($24 | 0) < 1) {
      var $i_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($24 | 0) < ($15 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $i_0 = $15;
      __label__ = 16;
      break;
    }
   case 10:
    var $i_0 = $24;
    __label__ = 16;
    break;
   case 11:
    var $30 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($5, $21, $d);
    if ($30) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 26;
      break;
    }
   case 12:
    var $32 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $33 = __ZL15JSDOUBLE_IS_NaNd3930($32);
    if (($33 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $i_0 = $15;
      __label__ = 16;
      break;
    }
   case 13:
    var $36 = __ZL18js_DoubleToIntegerd3931($32);
    tempDoubleF64[0] = $36, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    if ($36 > 0) {
      __label__ = 14;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 16;
      break;
    }
   case 14:
    if ($36 < ($15 | 0)) {
      __label__ = 15;
      break;
    } else {
      var $i_0 = $15;
      __label__ = 16;
      break;
    }
   case 15:
    var $i_0 = $36 & -1;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if (($13 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    __ZN2JS5Value8setInt32Ei($vp, $i_0);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 18:
    var $48 = $6 - 2 | 0;
    var $49 = HEAP16[$14 >> 1];
    var $50 = $14 + ($13 << 1) | 0;
    var $t_0 = $6 + ($i_0 << 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $t_0;
    if (($t_0 | 0) == ($48 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $49 << 16 >> 16) {
      var $_pn = $14;
      var $t_0_pn = $t_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 21:
    var $t_0_pn;
    var $_pn;
    var $p1_0 = $_pn + 2 | 0;
    var $t1_0 = $t_0_pn + 2 | 0;
    if (($p1_0 | 0) == ($50 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if (HEAP16[$t1_0 >> 1] << 16 >> 16 == HEAP16[$p1_0 >> 1] << 16 >> 16) {
      var $_pn = $p1_0;
      var $t_0_pn = $t1_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $65 = $t_0 - $6 >> 1;
    __ZN2JS5Value8setInt32Ei($vp, $65);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 24:
    var $t_0 = $t_0 - 2 | 0;
    __label__ = 19;
    break;
   case 25:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8str_trimP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 1, 1);
  return $1;
}

function __ZL12str_trimLeftP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 1, 0);
  return $1;
}

function __ZL13str_trimRightP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, 0, 1);
  return $1;
}

function __ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 36 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 4 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$1 >> 2] + 4 >> 2];
    var $15 = FUNCTION_TABLE[$14]($cx, $9, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx + 36 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[HEAP32[$1 >> 2] >> 2];
    var $15 = FUNCTION_TABLE[$14]($cx, $9, $vp);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 5:
    var $17 = __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE($cx, 0, $vp);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17str_localeCompareP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $result = __stackBase__;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 4:
    var $7 = $vp + 16 | 0;
    var $8 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $7);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $cx + 36 | 0;
    var $12 = HEAP32[$11 >> 2];
    if (($12 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$12 + 8 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN2JS5Value9setStringEP8JSString($7, $8);
    var $21 = HEAP32[HEAP32[$11 >> 2] + 8 >> 2];
    var $22 = FUNCTION_TABLE[$21]($cx, $1, $8, $vp);
    var $_0 = $22;
    __label__ = 10;
    break;
   case 8:
    var $24 = __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($cx, $1, $8, $result);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $26 = HEAP32[$result >> 2];
    __ZN2JS5Value8setInt32Ei($vp, $26);
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_matchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $g = __stackBase__;
    var $array = __stackBase__ + 32;
    var $rval = __stackBase__ + 48;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11RegExpGuardC1EP9JSContext($g, $cx);
    var $4 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($g, $argc, $vp, 1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $6 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($g, $cx, $1, 1, $argc, 1);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE($cx, $1, $6, $vp);
    var $_1 = $9 & 1;
    __label__ = 12;
    break;
   case 5:
    var $12 = $cx;
    var $13 = __ZN9JSContext18isExceptionPendingEv($12);
    if ($13) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($g, 0, 1, $argc, $vp);
    if (($15 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $array;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($18, $12, 0);
    var $19 = $array;
    var $20 = __ZN2js16AutoObjectRooter4addrEv($19);
    var $21 = __ZN9JSContext13regExpStaticsEv($12);
    var $22 = $20;
    var $23 = __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $21, $1, $15, 240, $22, 1, $rval);
    if ($23) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $25 = __ZNK10RegExpPair2reEv($15);
    var $26 = __ZNK2js6RegExp6globalEv($25);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $28 = __ZNK2js16AutoObjectRooter6objectEv($19);
    var $29 = $28;
    __ZN2JS5Value15setObjectOrNullEP8JSObject($vp, $29);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $31 = $rval | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    var $33 = $vp | 0;
    HEAP32[$33 >> 2] = $32$0;
    HEAP32[$33 + 4 >> 2] = $32$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($18);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    __ZN11RegExpGuardD1Ev($g);
    var $_2 = $_1;
    __label__ = 13;
    break;
   case 13:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_matchP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_searchP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $g = __stackBase__;
    var $i = __stackBase__ + 32;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11RegExpGuardC1EP9JSContext($g, $cx);
    var $4 = __ZN11RegExpGuard4initEjPN2JS5ValueEb($g, $argc, $vp, 1);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 3:
    var $6 = __ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb($g, $cx, $1, 1, $argc, 1);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK9FlatMatch5matchEv($6);
    __ZN2JS5Value8setInt32Ei($vp, $9);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 5:
    var $11 = $cx;
    var $12 = __ZN9JSContext18isExceptionPendingEv($11);
    if ($12) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($g, 0, 1, $argc, $vp);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZN9JSContext13regExpStaticsEv($11);
    HEAP32[$i >> 2] = 0;
    var $18 = __ZNK10RegExpPair2reEv($14);
    var $19 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($18, $11, $17, $1, $i, 1, $vp);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $21 = __ZNK2JS5Value6isTrueEv($vp);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $23 = __ZNK2js13RegExpStatics10matchStartEv($17);
    __ZN2JS5Value8setInt32Ei($vp, $23);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JS5Value8setInt32Ei($vp, -1);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN11RegExpGuardD1Ev($g);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_splitP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $d = __stackBase__ + 4;
    var $v = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __stackBase__ + 28;
    var $4 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($7, 3);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types4Type10StringTypeEv($1);
    var $12 = $cx;
    var $13 = $8;
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($12, $13, 0, $1);
    if ($argc >>> 0 > 1) {
      __label__ = 4;
      break;
    } else {
      var $limit_0 = -1;
      __label__ = 7;
      break;
    }
   case 4:
    var $16 = $vp + 24 | 0;
    var $17 = __ZNK2JS5Value11isUndefinedEv($16);
    if ($17) {
      var $limit_01 = -1;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($7, $16, $d);
    if ($19) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 25;
      break;
    }
   case 6:
    var $21 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $22 = __Z21js_DoubleToECMAUint32d($21);
    var $limit_0 = $22;
    __label__ = 7;
    break;
   case 7:
    var $limit_0;
    if (($argc | 0) == 0) {
      var $sepstr_0 = 0;
      var $re_0 = 0;
      var $limit_024 = $limit_0;
      var $41 = 1;
      __label__ = 13;
      break;
    } else {
      var $limit_01 = $limit_0;
      __label__ = 8;
      break;
    }
   case 8:
    var $limit_01;
    var $25 = $vp + 16 | 0;
    var $26 = __ZNK2JS5Value11isUndefinedEv($25);
    if ($26) {
      var $sepstr_0 = 0;
      var $re_0 = 0;
      var $limit_024 = $limit_01;
      var $41 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $25 | 0;
    var $29$0 = HEAP32[$28 >> 2];
    var $29$1 = HEAP32[$28 + 4 >> 2];
    var $30 = __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($29$0, $29$1);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $32 = __ZNK2JS5Value8toObjectEv($25);
    var $33 = __ZNK8JSObject10getPrivateEv($32);
    var $sepstr_0 = 0;
    var $re_0 = $33;
    var $limit_024 = $limit_01;
    var $41 = 0;
    __label__ = 13;
    break;
   case 11:
    var $36 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $25);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN2JS5Value9setStringEP8JSString($25, $36);
    var $39 = __ZN8JSString12ensureLinearEP9JSContext($36, $7);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      var $sepstr_0 = $39;
      var $re_0 = 0;
      var $limit_024 = $limit_01;
      var $41 = $26;
      __label__ = 13;
      break;
    }
   case 13:
    var $41;
    var $limit_024;
    var $re_0;
    var $sepstr_0;
    if (($limit_024 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 14:
    var $44 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($7, 0);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($44, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $44);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 16:
    if ($41) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    __ZN2JSL11StringValueEP8JSString3909($v, $4);
    var $49 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($7, 1, $v, 0);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($49, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $49);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 19:
    var $53 = __ZN8JSString12ensureLinearEP9JSContext($4, $7);
    if (($53 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if (($re_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $58 = __ZN9JSContext13regExpStaticsEv($7);
    __ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE($2, $re_0, $58);
    var $_01_val = HEAP32[$2 >> 2];
    var $_1_val = HEAP32[$2 + 4 >> 2];
    var $59 = __ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $53, $limit_024, $_01_val, $_1_val, $9);
    var $aobj2_0 = $59;
    __label__ = 23;
    break;
   case 22:
    __ZN18SplitStringMatcherC1EP14JSLinearString($3, $sepstr_0);
    var $_02_val = HEAP32[$3 >> 2];
    var $_13_val = HEAP32[$3 + 4 >> 2];
    var $61 = __ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $53, $limit_024, $_02_val, $_13_val);
    var $aobj2_0 = $61;
    __label__ = 23;
    break;
   case 23:
    var $aobj2_0;
    if (($aobj2_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $65 = $aobj2_0;
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($65, $8);
    __ZN2JS5Value9setObjectER8JSObject($vp, $65);
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_splitP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10str_substrP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $begin = __stackBase__ + 4;
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $str_0 = $1;
      __label__ = 18;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZNK8JSString6lengthEv($1);
    var $7 = $vp + 16 | 0;
    var $8 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $7, $begin);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 4:
    var $10 = HEAP32[$begin >> 2];
    if (($10 | 0) < ($6 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 18;
    break;
   case 6:
    if (($10 | 0) < 0) {
      __label__ = 7;
      break;
    } else {
      var $25 = $10;
      __label__ = 9;
      break;
    }
   case 7:
    var $21 = $10 + $6 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      var $25 = $21;
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$begin >> 2] = 0;
    var $25 = 0;
    __label__ = 9;
    break;
   case 9:
    var $25;
    if (($argc | 0) == 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $28 = $vp + 24 | 0;
    var $29 = __ZNK2JS5Value11isUndefinedEv($28);
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $31 = $6 - $25 | 0;
    HEAP32[$len >> 2] = $31;
    var $49 = $31;
    __label__ = 17;
    break;
   case 12:
    var $33 = __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $28, $len);
    if ($33) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 13:
    var $35 = HEAPU32[$len >> 2];
    if (($35 | 0) < 1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 18;
    break;
   case 15:
    if ($6 >>> 0 < ($25 + $35 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $49 = $35;
      __label__ = 17;
      break;
    }
   case 16:
    var $47 = $6 - $25 | 0;
    HEAP32[$len >> 2] = $47;
    var $49 = $47;
    __label__ = 17;
    break;
   case 17:
    var $49;
    var $50 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $25, $49);
    var $51 = $50 | 0;
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $str_0 = $51;
      __label__ = 18;
      break;
    }
   case 18:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10str_substrP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv($this) {
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZL10str_concatP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $i_0 = 0;
    var $str_0 = $2;
    __label__ = 3;
    break;
   case 3:
    var $str_0;
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $8 = $vp + ($i_0 + 2 << 3) | 0;
    var $9 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($4, $str_0, $9);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $i_0 = $i_0 + 1 | 0;
    var $str_0 = $12;
    __label__ = 3;
    break;
   case 7:
    __ZN2JSL11StringValueEP8JSString3909($1, $str_0);
    var $17 = $1 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9str_sliceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin2 = __stackBase__;
    var $end3 = __stackBase__ + 8;
    var $1 = ($argc | 0) == 1;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $3 = $vp + 8 | 0;
    var $4 = __ZNK2JS5Value8isStringEv($3);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 3:
    var $6 = $vp + 16 | 0;
    var $7 = __ZNK2JS5Value7isInt32Ev($6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toStringEv($3);
    var $10 = __ZNK2JS5Value7toInt32Ev($6);
    var $11 = __ZNK8JSString6lengthEv($9);
    if ($10 >>> 0 > $11 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11 - $10 | 0;
    if (($11 | 0) == ($10 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 11;
    break;
   case 7:
    if (($14 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $27 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $28 = $cx;
    var $29 = __ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj($27, $28, $9, $10);
    var $33 = $29;
    __label__ = 10;
    break;
   case 9:
    var $31 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $9, $10, $14);
    var $33 = $31;
    __label__ = 10;
    break;
   case 10:
    var $33;
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $str_0 = $33 | 0;
      __label__ = 11;
      break;
    }
   case 11:
    var $str_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 12:
    var $38 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (($argc | 0) == 0) {
      var $str1_0 = $38;
      __label__ = 32;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = $vp + 16 | 0;
    var $44 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $43, $begin2);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 15:
    var $46 = __ZNK8JSString6lengthEv($38);
    var $47 = $46 >>> 0;
    var $48 = (tempDoubleI32[0] = HEAP32[$begin2 >> 2], tempDoubleI32[1] = HEAP32[$begin2 + 4 >> 2], tempDoubleF64[0]);
    if ($48 < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    var $51 = $48 + $47;
    tempDoubleF64[0] = $51, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    if ($51 < 0) {
      __label__ = 17;
      break;
    } else {
      var $58 = $51;
      __label__ = 20;
      break;
    }
   case 17:
    tempDoubleF64[0] = 0, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    var $58 = 0;
    __label__ = 20;
    break;
   case 18:
    if ($48 > $47) {
      __label__ = 19;
      break;
    } else {
      var $58 = $48;
      __label__ = 20;
      break;
    }
   case 19:
    tempDoubleF64[0] = $47, HEAP32[$begin2 >> 2] = tempDoubleI32[0], HEAP32[$begin2 + 4 >> 2] = tempDoubleI32[1];
    var $58 = $47;
    __label__ = 20;
    break;
   case 20:
    var $58;
    if ($1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $60 = $vp + 24 | 0;
    var $61 = __ZNK2JS5Value11isUndefinedEv($60);
    if ($61) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    tempDoubleF64[0] = $47, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $80 = $47;
    __label__ = 31;
    break;
   case 23:
    var $64 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $60, $end3);
    if ($64) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 33;
      break;
    }
   case 24:
    var $66 = (tempDoubleI32[0] = HEAP32[$end3 >> 2], tempDoubleI32[1] = HEAP32[$end3 + 4 >> 2], tempDoubleF64[0]);
    if ($66 < 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $69 = $66 + $47;
    tempDoubleF64[0] = $69, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    if ($69 < 0) {
      __label__ = 26;
      break;
    } else {
      var $76 = $69;
      __label__ = 29;
      break;
    }
   case 26:
    tempDoubleF64[0] = 0, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $76 = 0;
    __label__ = 29;
    break;
   case 27:
    if ($66 > $47) {
      __label__ = 28;
      break;
    } else {
      var $76 = $66;
      __label__ = 29;
      break;
    }
   case 28:
    tempDoubleF64[0] = $47, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $76 = $47;
    __label__ = 29;
    break;
   case 29:
    var $76;
    if ($76 < $58) {
      __label__ = 30;
      break;
    } else {
      var $80 = $76;
      __label__ = 31;
      break;
    }
   case 30:
    tempDoubleF64[0] = $58, HEAP32[$end3 >> 2] = tempDoubleI32[0], HEAP32[$end3 + 4 >> 2] = tempDoubleI32[1];
    var $80 = $58;
    __label__ = 31;
    break;
   case 31:
    var $80;
    var $81 = $58 >= 0 ? Math.floor($58) : Math.ceil($58);
    var $82 = $80 - $58;
    var $83 = $82 >= 0 ? Math.floor($82) : Math.ceil($82);
    var $84 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $38, $81, $83);
    var $85 = $84 | 0;
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 33;
      break;
    } else {
      var $str1_0 = $85;
      __label__ = 32;
      break;
    }
   case 32:
    var $str1_0;
    __ZN2JS5Value9setStringEP8JSString($vp, $str1_0);
    var $_0 = 1;
    __label__ = 33;
    break;
   case 33:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9str_sliceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8str_boldP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str463815 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL11str_italicsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str453814 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_fixedP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str443813 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL12str_fontsizeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str433812 | 0, STRING_TABLE.__str423811 | 0);
  return $1;
}

function __ZL13str_fontcolorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str413810 | 0, STRING_TABLE.__str423811 | 0);
  return $1;
}

function __ZL8str_linkP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str403809 | 0, STRING_TABLE.__str494295 | 0);
  return $1;
}

function __ZL10str_anchorP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, STRING_TABLE.__str383807 | 0, STRING_TABLE.__str494295 | 0);
  return $1;
}

function __ZL10str_strikeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str283791 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_smallP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str293792 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_bigP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str303793 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL9str_blinkP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str313794 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_supP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str323795 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __ZL7str_subP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var $1 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, STRING_TABLE.__str333796 | 0, 0, 0, $vp);
  return $1 & 1;
}

function __Z9js_StringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      var $str_0 = $4;
      __label__ = 4;
      break;
    }
   case 3:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 4;
    break;
   case 4:
    var $str_0;
    var $13 = __ZN2jsL14IsConstructingEPKN2JS5ValueE3833($vp);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $15 = $cx;
    var $16 = __ZN2js12StringObject6createEP9JSContextP8JSString($15, $str_0);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $16;
    __ZN2JS5Value9setObjectER8JSObject($vp, $19);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    __ZN2JS5Value9setStringEP8JSString($vp, $str_0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $arg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $arg | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $v | 0;
    HEAP32[$3 >> 2] = $2$0;
    HEAP32[$3 + 4 >> 2] = $2$1;
    var $4 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $v);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $6 = __ZNK2JS5Value8isStringEv($v);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toStringEv($v);
    var $_0 = $8;
    __label__ = 13;
    break;
   case 4:
    var $10 = __ZNK2JS5Value7isInt32Ev($v);
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $12 = __ZNK2JS5Value7toInt32Ev($v);
    var $13 = $cx;
    var $14 = __Z14js_IntToStringP9JSContexti($13, $12);
    var $_0 = $14;
    __label__ = 13;
    break;
   case 6:
    var $16 = __ZNK2JS5Value8isDoubleEv($v);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $18 = __ZNK2JS5Value8toDoubleEv($v);
    var $19 = $cx;
    var $20 = __Z17js_NumberToStringP9JSContextd($19, $18);
    var $_0 = $20;
    __label__ = 13;
    break;
   case 8:
    var $22 = __ZNK2JS5Value9isBooleanEv($v);
    if ($22) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $24 = __ZNK2JS5Value9toBooleanEv($v);
    var $25 = $24 & 1;
    var $26 = $cx;
    var $27 = __Z18js_BooleanToStringP9JSContexti($26, $25);
    var $_0 = $27;
    __label__ = 13;
    break;
   case 10:
    var $29 = __ZNK2JS5Value6isNullEv($v);
    var $31 = HEAPU32[$cx + 52 >> 2];
    if ($29) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_0 = HEAP32[$31 + 210016 >> 2] | 0;
    __label__ = 13;
    break;
   case 12:
    var $_0 = HEAP32[$31 + 209984 >> 2] | 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_ValueToStringP9JSContextRKN2JS5ValueE["X"] = 1;

function __ZN2jsL14IsConstructingEPKN2JS5ValueE3833($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function __ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $code = __stackBase__;
    var $code1 = __stackBase__ + 4;
    var $1 = $vp + 16 | 0;
    var $3 = $cx;
    if (($argc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $_pre_phi = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($3, $1, $code);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $7 = HEAPU16[$code >> 1];
    var $8 = __ZN2js13StaticStrings7hasUnitEt($7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $12 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $13 = __ZN2js13StaticStrings7getUnitEt($12, $7);
    var $14 = $13 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $14);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 5:
    var $16 = $7 & 65535;
    __ZN2JS5Value8setInt32Ei($1, $16);
    var $_pre_phi = $3;
    __label__ = 6;
    break;
   case 6:
    var $_pre_phi;
    var $18 = ($argc << 1) + 2 | 0;
    var $19 = __ZN9JSContext7malloc_Ej($_pre_phi, $18);
    var $20 = $19;
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $argc >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $24 = $vp + ($i_0 + 2 << 3) | 0;
    var $25 = __ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt($_pre_phi, $24, $code1);
    if ($25) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN9JSContext5free_EPv(undef, $19);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAP16[$code1 >> 1];
    HEAP16[$20 + ($i_0 << 1) >> 1] = $28;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 11:
    HEAP16[$20 + ($argc << 1) >> 1] = 0;
    var $33 = __Z12js_NewStringP9JSContextPtj($cx, $20, $argc);
    if (($33 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv(undef, $19);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 13:
    var $37 = $33 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $37);
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js12StringObject18assignInitialShapeEP9JSContext($this, $cx) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12ATOM_TO_JSIDP6JSAtom3836($5);
  var $7 = $this;
  var $8 = $cx;
  var $9 = __ZN8JSObject15addDataPropertyEP9JSContextijj($7, $8, $6, 1, 6);
  return $9;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3836($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj3911($1);
  return $2;
}

function __Z18js_InitStringClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js11StringClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $5;
    var $10 = __ZN8JSObject8asStringEv($9);
    var $11 = $cx + 52 | 0;
    var $15 = HEAP32[HEAP32[$11 >> 2] + 144136 >> 2] | 0;
    var $16 = $cx;
    var $17 = __ZN2js12StringObject4initEP9JSContextP8JSString($10, $16, $15);
    if ($17) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $22 = HEAP32[HEAP32[$11 >> 2] + 210056 >> 2];
    var $23 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 242, __ZN2js11StringClassE, $22, 1);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $23 | 0;
    var $27 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $26, $5);
    if ($27) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 5:
    var $29 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL14string_methods);
    if ($29) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $31 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $26, 0, __ZL21string_static_methods);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $33 = $5;
    var $34 = $cx;
    var $35 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($33, $34, 0, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    __ZN2js5types4Type9Int32TypeEv($1);
    var $38 = $cx;
    var $39 = $35;
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE($38, $39, STRING_TABLE._js_length_str | 0, $1);
    var $40 = $3;
    var $41 = $23;
    var $42 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($34, $40, 9, $41, $33);
    if ($42) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $44 = $3;
    var $45 = _JS_DefineFunctions($34, $44, __ZL16string_functions);
    var $_ = ($45 | 0) == 0 ? 0 : $6;
    var $_0 = $_;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_InitStringClassP9JSContextP8JSObject["X"] = 1;

function __ZN2jsL17CheckStringLengthEP9JSContextj3839($cx, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 268435455) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $cx;
    __Z27js_ReportAllocationOverflowP9JSContext($3);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSFixedString4new_EP9JSContextPKtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCStringP9JSContext($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN13JSFixedString4initEPKtj($3, $chars, $length);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer16extractWellSizedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv($1);
    var $3 = $this;
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($3);
    var $5 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv($1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($4 >>> 0 > 32) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 3:
    if (($2 - $4 | 0) >>> 0 > $4 >>> 2 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $5;
      __label__ = 7;
      break;
    }
   case 4:
    var $15 = ($4 << 1) + 2 | 0;
    var $16 = $this;
    var $17 = __ZNK2js12StringBuffer7contextEv($16);
    var $18 = $5;
    var $19 = __ZN9JSContext8realloc_EPvj($17, $18, $15);
    if (($19 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv(undef, $18);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $_0 = $19;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] << 1;
    var $7 = $this;
    var $8 = __ZN2js18ContextAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv($1);
    var $13 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($1);
    __ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_($9, $12, $13);
    HEAP32[$4 >> 2] = 0;
    var $_0 = $9;
    __label__ = 5;
    break;
   case 4:
    var $15 = $this + 4 | 0;
    var $16 = HEAP32[$15 >> 2];
    var $17 = $this + 16 | 0;
    var $18 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($17);
    HEAP32[$15 >> 2] = $18;
    HEAP32[$this + 8 >> 2] = 0;
    HEAP32[$this + 12 >> 2] = 32;
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer12finishStringEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12StringBuffer7contextEv($1);
    var $3 = $2;
    var $4 = $this | 0;
    var $5 = $this;
    var $6 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv($5);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 10;
    break;
   case 3:
    var $14 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($5);
    var $15 = __ZN2js12StringBuffer11checkLengthEj($1, $14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 4:
    var $17 = __ZN13JSShortString10lengthFitsEj($14);
    if ($17) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $19 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($5);
    var $20 = __ZL14NewShortStringP9JSContextPKtj($3, $19, $14);
    var $_0 = $20;
    __label__ = 10;
    break;
   case 6:
    var $22 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_($4, 0);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $24 = __ZN2js12StringBuffer16extractWellSizedEv($this);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $27 = __Z12js_NewStringP9JSContextPtj($3, $24, $14);
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = $27;
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = $24;
    __ZN9JSContext5free_EPv(undef, $30);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NewShortStringP9JSContextPKtj($cx, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN14JSInlineString10lengthFitsEj($length);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN14JSInlineString4new_EP9JSContext($cx);
    var $8 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN13JSShortString4new_EP9JSContext($cx);
    var $8 = $5 | 0;
    __label__ = 4;
    break;
   case 4:
    var $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN14JSInlineString4initEj($8, $length);
    __ZN2jsL7PodCopyItEEvPT_PKS1_j3900($11, $chars, $length);
    HEAP16[$11 + ($length << 1) >> 1] = 0;
    var $_0 = $8 | 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $this;
    var $8 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj($7, 1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer10finishAtomEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK2js12StringBuffer7contextEv($1);
    var $3 = $this;
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($3);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$2 + 52 >> 2] + 209972 >> 2] | 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = $this | 0;
    var $14 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv($3);
    var $15 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($2, $14, $4, 0);
    __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv($13);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $baseArg, $start, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($length | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 9;
    break;
   case 3:
    var $9 = $cx;
    var $10 = __ZN8JSString12ensureLinearEP9JSContext($baseArg, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($start | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = $10 | 0;
    var $16 = __ZNK8JSString6lengthEv($15);
    if (($16 | 0) == ($length | 0)) {
      var $_0 = $10;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = __ZNK14JSLinearString5charsEv($10);
    var $20 = $19 + ($start << 1) | 0;
    var $23 = HEAP32[$cx + 52 >> 2] + 210584 | 0;
    var $24 = __ZN2js13StaticStrings6lookupEPKtj($23, $20, $length);
    if (($24 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_0 = $24 | 0;
    __label__ = 9;
    break;
   case 8:
    var $29 = __ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj($cx, $10, $20, $length);
    var $_0 = $29 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj($cx, $base, $chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $base | 0;
    var $2 = __ZNK8JSString11isDependentEv($1);
    if ($2) {
      var $3 = $1;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $base;
      __label__ = 3;
      break;
    }
   case 2:
    var $3;
    var $4 = __ZN8JSString11asDependentEv($3);
    var $5 = __ZNK17JSDependentString4baseEv($4);
    var $6 = $5 | 0;
    var $7 = __ZNK8JSString11isDependentEv($6);
    if ($7) {
      var $3 = $6;
      __label__ = 2;
      break;
    } else {
      var $_01_lcssa = $5;
      __label__ = 3;
      break;
    }
   case 3:
    var $_01_lcssa;
    var $8 = $cx;
    var $9 = __Z14js_NewGCStringP9JSContext($8);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN17JSDependentString4initEP14JSLinearStringPKtj($10, $_01_lcssa, $chars, $length);
    var $_0 = $10;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyNP9JSContextPKtj($cx, $s, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN13JSShortString10lengthFitsEj($n);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL14NewShortStringP9JSContextPKtj($cx, $s, $n);
    var $_0 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = $n << 1;
    var $6 = $5 + 2 | 0;
    var $7 = $cx;
    var $8 = __ZN9JSContext7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $s;
    _memcpy($8, $12, $5, 1);
    HEAP16[$9 + ($n << 1) >> 1] = 0;
    var $14 = __Z12js_NewStringP9JSContextPtj($cx, $9, $n);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $14;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv(undef, $8);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyNP9JSContextPKcj($cx, $s, $n) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $n;
    var $2 = __ZN13JSShortString10lengthFitsEj($n);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL14NewShortStringP9JSContextPKcj($cx, $s, $n);
    var $_0 = $4 | 0;
    __label__ = 6;
    break;
   case 3:
    var $7 = __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($cx, $s, $1, 0);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = HEAP32[$1 >> 2];
    var $11 = __Z12js_NewStringP9JSContextPtj($cx, $7, $10);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $11;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $7;
    __ZN9JSContext5free_EPv(undef, $14);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSDOUBLE_IS_NEGZERO3865($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d != 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $_0 = tempDoubleI32[1] >>> 31 | 0 << 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_strlenPKt($s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP16[$s >> 1] << 16 >> 16 == 0) {
      var $t_0_lcssa = $s;
      __label__ = 3;
      break;
    } else {
      var $t_01 = $s;
      __label__ = 2;
      break;
    }
   case 2:
    var $t_01;
    var $3 = $t_01 + 2 | 0;
    if (HEAP16[$3 >> 1] << 16 >> 16 == 0) {
      var $t_0_lcssa = $3;
      __label__ = 3;
      break;
    } else {
      var $t_01 = $3;
      __label__ = 2;
      break;
    }
   case 3:
    var $t_0_lcssa;
    return $t_0_lcssa - $s >> 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_strchrPKtt($s, $c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $s;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $2 = HEAP16[$_01 >> 1];
    if ($2 << 16 >> 16 == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($2 << 16 >> 16 == $c << 16 >> 16) {
      var $_0 = $_01;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NewShortStringP9JSContextPKcj($cx, $chars, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $length;
    var $2 = __ZN14JSInlineString10lengthFitsEj($length);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZN14JSInlineString4new_EP9JSContext($cx);
    var $9 = $4;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN13JSShortString4new_EP9JSContext($cx);
    var $9 = $6 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = __ZN14JSInlineString4initEj($9, $length);
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    if (($length | 0) == 0) {
      var $p_0_lcssa = $12;
      __label__ = 11;
      break;
    } else {
      var $n_02 = $length;
      var $_013 = $chars;
      var $p_04 = $12;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $chars, $length, $12, $1, 0);
    if ($17) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    var $19 = HEAP32[$1 >> 2];
    HEAP16[$12 + ($19 << 1) >> 1] = 0;
    __ZN14JSInlineString11resetLengthEj($9, $19);
    var $_0 = $9;
    __label__ = 12;
    break;
   case 9:
    var $p_04;
    var $_013;
    var $n_02;
    var $21 = $n_02 - 1 | 0;
    HEAP16[$p_04 >> 1] = HEAPU8[$_013] & 255;
    if (($21 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $n_02 = $21;
      var $_013 = $_013 + 1 | 0;
      var $p_04 = $p_04 + 2 | 0;
      __label__ = 9;
      break;
    }
   case 10:
    var $p_0_lcssa = $12 + ($length << 1) | 0;
    __label__ = 11;
    break;
   case 11:
    var $p_0_lcssa;
    HEAP16[$p_0_lcssa >> 1] = 0;
    var $_0 = $9;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE($cx, $bytes, $lengthp, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nchars = __stackBase__;
    var $1 = HEAPU32[$lengthp >> 2];
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) != 0 | ($fc | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $bytes, $1, 0, $nchars, $fc);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    var $10 = (HEAP32[$nchars >> 2] << 1) + 2 | 0;
    var $11 = $cx;
    var $12 = __ZN9JSContext7malloc_Ej($11, $10);
    var $13 = $12;
    if (($12 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $bytes, $1, $13, $nchars, $fc);
    var $chars_0 = $13;
    var $31 = HEAP32[$nchars >> 2];
    __label__ = 8;
    break;
   case 5:
    HEAP32[$nchars >> 2] = $1;
    var $19 = ($1 << 1) + 2 | 0;
    var $20 = $cx;
    var $21 = __ZN9JSContext7malloc_Ej($20, $19);
    var $22 = $21;
    if (($21 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($1 | 0) == 0) {
      var $chars_0 = $22;
      var $31 = $1;
      __label__ = 8;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $i_01;
    HEAP16[$22 + ($i_01 << 1) >> 1] = HEAPU8[$bytes + $i_01 | 0] & 255;
    var $29 = $i_01 + 1 | 0;
    if ($29 >>> 0 < $1 >>> 0) {
      var $i_01 = $29;
      __label__ = 7;
      break;
    } else {
      var $chars_0 = $22;
      var $31 = $1;
      __label__ = 8;
      break;
    }
   case 8:
    var $31;
    var $chars_0;
    HEAP32[$lengthp >> 2] = $31;
    HEAP16[$chars_0 + ($31 << 1) >> 1] = 0;
    var $_0 = $chars_0;
    __label__ = 10;
    break;
   case 9:
    HEAP32[$lengthp >> 2] = 0;
    var $_0 = 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyZP9JSContextPKt($cx, $s) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z9js_strlenPKt($s);
    var $2 = __ZN13JSShortString10lengthFitsEj($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZL14NewShortStringP9JSContextPKtj($cx, $s, $1);
    var $_0 = $4;
    __label__ = 6;
    break;
   case 3:
    var $7 = ($1 << 1) + 2 | 0;
    var $8 = $cx;
    var $9 = __ZN9JSContext7malloc_Ej($8, $7);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    var $13 = $s;
    _memcpy($9, $13, $7, 1);
    var $14 = __Z12js_NewStringP9JSContextPtj($cx, $12, $1);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $14;
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv(undef, $9);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_NewStringCopyZP9JSContextPKc($cx, $s) {
  var $1 = _strlen($s);
  var $2 = __Z17js_NewStringCopyNP9JSContextPKcj($cx, $s, $1);
  return $2;
}

function __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($cx, $v, $bytes, $asSource) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_Z16js_ValueToSourceP9JSContextRKN2JS5ValueE__Z16js_ValueToStringP9JSContextRKN2JS5ValueE = $asSource ? 244 : 246;
    var $1 = FUNCTION_TABLE[$_Z16js_ValueToSourceP9JSContextRKN2JS5ValueE__Z16js_ValueToStringP9JSContextRKN2JS5ValueE]($cx, $v);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = _js_QuoteString($4, $1, 0);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $bytes;
    var $9 = __ZN16JSAutoByteString6encodeEP9JSContextP8JSString($8, $4, $5);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rval = __stackBase__ + 4;
    var $fval = __stackBase__ + 12;
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 3:
    var $8 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210340 >> 2] | 0;
    __label__ = 16;
    break;
   case 5:
    var $16 = __ZNK2JS5Value8isStringEv($v);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZNK2JS5Value8toStringEv($v);
    var $19 = $cx;
    var $20 = _js_QuoteString($19, $18, 34);
    var $_0 = $20;
    __label__ = 16;
    break;
   case 7:
    var $22 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($22) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $24 = __ZNK2JS5Value8isDoubleEv($v);
    if ($24) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $26 = __ZNK2JS5Value8toDoubleEv($v);
    var $27 = _JSDOUBLE_IS_NEGZERO3865($26);
    if (($27 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __Z17js_NewStringCopyNP9JSContextPKtj($cx, __ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr | 0, 2);
    var $_0 = $30 | 0;
    __label__ = 16;
    break;
   case 11:
    var $33 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $v);
    var $_0 = $33;
    __label__ = 16;
    break;
   case 12:
    __ZN2JSL9NullValueEv3866($rval);
    var $39 = HEAP32[HEAP32[$cx + 52 >> 2] + 210320 >> 2] | 0;
    var $40 = __ZL12ATOM_TO_JSIDP6JSAtom3836($39);
    var $41 = __ZNK2JS5Value8toObjectEv($v);
    var $42 = $cx;
    var $43 = $41;
    var $44 = __Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE($42, $43, $40, 2, $fval);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $47 = __ZL13js_IsCallableRKN2JS5ValueE3827($fval);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $49 = $cx;
    var $50 = __ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_($49, $v, $fval, 0, 0, $rval);
    if ($50) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $52 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $rval);
    var $_0 = $52;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z16js_ValueToSourceP9JSContextRKN2JS5ValueE["X"] = 1;

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 3, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE($cx, $arg, $sb) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $arg | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = $v | 0;
    HEAP32[$3 >> 2] = $2$0;
    HEAP32[$3 + 4 >> 2] = $2$1;
    var $4 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862($cx, $v);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $6 = __ZNK2JS5Value8isStringEv($v);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK2JS5Value8toStringEv($v);
    var $9 = $sb;
    var $10 = __ZN2js12StringBuffer6appendEP8JSString($9, $8);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 4:
    var $12 = __ZNK2JS5Value8isNumberEv($v);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = $cx;
    var $15 = $sb;
    var $16 = __ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE($14, $v, $15);
    var $_0 = $16;
    __label__ = 11;
    break;
   case 6:
    var $18 = __ZNK2JS5Value9isBooleanEv($v);
    if ($18) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = __ZNK2JS5Value9toBooleanEv($v);
    var $21 = $20 & 1;
    var $22 = $sb;
    var $23 = __ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE(undef, $21, $22);
    var $_0 = $23;
    __label__ = 11;
    break;
   case 8:
    var $25 = __ZNK2JS5Value6isNullEv($v);
    var $27 = HEAPU32[$cx + 52 >> 2];
    if ($25) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = HEAP32[$27 + 210016 >> 2] | 0;
    var $32 = __ZN2js12StringBuffer6appendEP6JSAtom($sb, $31);
    var $_0 = $32;
    __label__ = 11;
    break;
   case 10:
    var $36 = HEAP32[$27 + 209984 >> 2] | 0;
    var $37 = __ZN2js12StringBuffer6appendEP6JSAtom($sb, $36);
    var $_0 = $37;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12StringBuffer6appendEP6JSAtom($this, $atom) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $atom | 0;
    var $2 = __ZNK8JSString6lengthEv($1);
    var $3 = $this;
    var $4 = __ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv($3);
    var $5 = $4 + $2 | 0;
    var $6 = $this;
    var $7 = __ZN2js12StringBuffer11checkLengthEj($6, $5);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $atom | 0;
    var $10 = __ZNK14JSLinearString5charsEv($9);
    var $11 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j($3, $10, $2);
    var $_0 = $11;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL9NullValueEv3866($agg_result) {
  __ZN2JS5Value7setNullEv($agg_result);
  return;
}

function __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$result >> 2] = 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 3:
    var $4 = __ZNK8JSString6lengthEv($str1);
    var $5 = __ZNK8JSString6lengthEv($str2);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 5:
    var $9 = $cx;
    var $10 = __ZN8JSString12ensureLinearEP9JSContext($str1, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $13 = __ZN8JSString12ensureLinearEP9JSContext($str2, $9);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $16 = __ZNK14JSLinearString5charsEv($10);
    var $17 = __ZNK14JSLinearString5charsEv($13);
    var $18 = __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($16, $17, $4);
    HEAP32[$result >> 2] = $18 & 1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($one, $two, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($len >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $3 = $one + ($len << 1) | 0;
    var $p2_0 = $two;
    var $p1_0 = $one;
    __label__ = 3;
    break;
   case 3:
    var $p1_0;
    var $p2_0;
    if (($p1_0 | 0) == ($3 | 0)) {
      var $_0 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (HEAP16[$p1_0 >> 1] << 16 >> 16 == HEAP16[$p2_0 >> 1] << 16 >> 16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $p2_0 = $p2_0 + 2 | 0;
    var $p1_0 = $p1_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $14 = $one;
    var $15 = $two;
    var $16 = $len << 1;
    var $17 = _memcmp($14, $15, $16);
    var $_0 = ($17 | 0) == 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12EqualStringsEP14JSLinearStringS1_($str1, $str2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $str1 | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    var $5 = $str2 | 0;
    var $6 = __ZNK8JSString6lengthEv($5);
    if (($4 | 0) == ($6 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZNK14JSLinearString5charsEv($str1);
    var $10 = __ZNK14JSLinearString5charsEv($str2);
    var $11 = __ZN2jsL8PodEqualIKtEEbPT_S3_j3869($9, $10, $4);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22js_EqualStringsOnTraceP9JSContextP8JSStringS2_($cx, $str1, $str2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $result = __stackBase__;
  var $1 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result);
  var $3 = $1 ? HEAP32[$result >> 2] : 2;
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var $1 = __ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result);
  return $1;
}

function __ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($str1 | 0) == ($str2 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $4 = __ZNK8JSString6lengthEv($str1);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($str1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZNK8JSString6lengthEv($str2);
    var $10 = __ZN8JSString8getCharsEP9JSContext($str2, $5);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $4 >>> 0 < $9 >>> 0 ? $4 : $9;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $14 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $19 = HEAPU16[$6 + ($i_0 << 1) >> 1];
    var $21 = HEAPU16[$10 + ($i_0 << 1) >> 1];
    if ($19 << 16 >> 16 == $21 << 16 >> 16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$result >> 2] = ($19 & 65535) - ($21 & 65535) | 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 10:
    HEAP32[$result >> 2] = $4 - $9 | 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_CompareStringsOnTraceP9JSContextP8JSStringS2_($cx, $str1, $str2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $result = __stackBase__;
  var $1 = __ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi($cx, $str1, $str2, $result);
  var $_0 = $1 ? HEAP32[$result >> 2] : -2147483648;
  STACKTOP = __stackBase__;
  return $_0;
}

function __ZN2js17StringEqualsAsciiEP14JSLinearStringPKc($str, $asciiBytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _strlen($asciiBytes);
    var $2 = $str | 0;
    var $3 = __ZNK8JSString6lengthEv($2);
    if (($1 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = __ZNK14JSLinearString5charsEv($str);
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if (($i_0 | 0) == ($1 | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP8[$asciiBytes + $i_0 | 0] << 24 >> 24 | 0) == (HEAPU16[$6 + ($i_0 << 1) >> 1] & 65535 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buffer = __stackBase__;
    var $buffer1 = __stackBase__ + 12;
    if (($dst | 0) == 0) {
      var $5 = -1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$dstlenp >> 2];
    __label__ = 3;
    break;
   case 3:
    var $5;
    var $6 = ($fc | 0) == 1;
    var $_02 = $src;
    var $_03 = $srclen;
    var $_04 = $dst;
    var $dstlen_0 = $5;
    var $offset_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $offset_0;
    var $dstlen_0;
    var $_04;
    var $_03;
    var $_02;
    if (($_03 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = HEAPU8[$_02] & 255;
    if (($11 & 128 | 0) == 0) {
      var $v_1 = $11;
      var $_2 = $_04;
      var $n_1 = 1;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($11 & 64 | 0) == 0) {
      var $n_0_lcssa = 1;
      __label__ = 8;
      break;
    } else {
      var $n_06 = 1;
      __label__ = 7;
      break;
    }
   case 7:
    var $n_06;
    var $16 = $n_06 + 1 | 0;
    if ((128 >>> ($16 >>> 0) & $11 | 0) == 0) {
      var $n_0_lcssa = $16;
      __label__ = 8;
      break;
    } else {
      var $n_06 = $16;
      __label__ = 7;
      break;
    }
   case 8:
    var $n_0_lcssa;
    if ($n_0_lcssa >>> 0 > $_03 >>> 0) {
      var $dstlen_2 = $dstlen_0;
      __label__ = 28;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($n_0_lcssa | 0) == 1 | $n_0_lcssa >>> 0 > 4) {
      __label__ = 26;
      break;
    } else {
      var $j_0 = 1;
      __label__ = 10;
      break;
    }
   case 10:
    var $j_0;
    if ($j_0 >>> 0 < $n_0_lcssa >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if ((HEAP8[$_02 + $j_0 | 0] & -64) << 24 >> 24 == -128) {
      __label__ = 12;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 12:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $33 = __ZL17Utf8ToOneUcs4CharPKhi($_02, $n_0_lcssa);
    if ($33 >>> 0 > 65535) {
      __label__ = 14;
      break;
    } else {
      var $v_1 = $33;
      var $_2 = $_04;
      var $n_1 = $n_0_lcssa;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    }
   case 14:
    if ($6) {
      var $v_1 = $33;
      var $_2 = $_04;
      var $n_1 = $n_0_lcssa;
      var $dstlen_1 = $dstlen_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = $33 - 65536 | 0;
    if ($37 >>> 0 > 1048575 | $dstlen_0 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 16:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $44 = $buffer | 0;
    var $45 = _JS_snprintf($44, 10, STRING_TABLE.__str363799 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $33, tempInt));
    var $46 = $cx;
    var $47 = _JS_ReportErrorFlagsAndNumber($46, 0, 2, 0, 204, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $44, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 18:
    if (($_04 | 0) == 0) {
      var $v_0 = $37;
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP16[$_04 >> 1] = ($37 >>> 10) + 55296 & 65535;
    var $v_0 = $37 & 1023 | 56320;
    var $_1 = $_04 + 2 | 0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    var $v_0;
    var $v_1 = $v_0;
    var $_2 = $_1;
    var $n_1 = $n_0_lcssa;
    var $dstlen_1 = $dstlen_0 - 1 | 0;
    __label__ = 21;
    break;
   case 21:
    var $dstlen_1;
    var $n_1;
    var $_2;
    var $v_1;
    if (($dstlen_1 | 0) == 0) {
      var $dstlen_2 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if (($_2 | 0) == 0) {
      var $_3 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    HEAP16[$_2 >> 1] = $v_1 & 65535;
    var $_3 = $_2 + 2 | 0;
    __label__ = 24;
    break;
   case 24:
    var $_3;
    var $_02 = $_02 + $n_1 | 0;
    var $_03 = $_03 - $n_1 | 0;
    var $_04 = $_3;
    var $dstlen_0 = $dstlen_1 - 1 | 0;
    var $offset_0 = $n_1 + $offset_0 | 0;
    __label__ = 4;
    break;
   case 25:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    var $_0 = 1;
    __label__ = 30;
    break;
   case 26:
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $76 = $buffer1 | 0;
    var $77 = _JS_snprintf($76, 10, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $offset_0, tempInt));
    var $78 = $cx;
    var $79 = _JS_ReportErrorFlagsAndNumber($78, 0, 2, 0, 205, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $76, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 28:
    var $dstlen_2;
    HEAP32[$dstlenp >> 2] = $5 - $dstlen_2 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $84 = $cx;
    _JS_ReportErrorNumber($84, 2, 0, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE["X"] = 1;

function __ZN2js13DeflateStringEP9JSContextPKtj($cx, $chars, $nchars) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nbytes = __stackBase__;
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $chars, $nchars);
    HEAP32[$nbytes >> 2] = $4;
    if (($4 | 0) == -1) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $4 + 1 | 0;
    if (($cx | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $cx;
    var $11 = __ZN9JSContext7malloc_Ej($10, $8);
    var $15 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZN2js11OffTheBooks7malloc_Ej($8);
    var $15 = $13;
    __label__ = 6;
    break;
   case 6:
    var $15;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($cx, $chars, $nchars, $15, $nbytes);
    var $bytes_0 = $15;
    var $37 = HEAP32[$nbytes >> 2];
    __label__ = 14;
    break;
   case 8:
    HEAP32[$nbytes >> 2] = $nchars;
    var $21 = $nchars + 1 | 0;
    if (($cx | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = $cx;
    var $24 = __ZN9JSContext7malloc_Ej($23, $21);
    var $28 = $24;
    __label__ = 11;
    break;
   case 10:
    var $26 = __ZN2js11OffTheBooks7malloc_Ej($21);
    var $28 = $26;
    __label__ = 11;
    break;
   case 11:
    var $28;
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($nchars | 0) == 0) {
      var $bytes_0 = $28;
      var $37 = $nchars;
      __label__ = 14;
      break;
    } else {
      var $i_01 = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $i_01;
    HEAP8[$28 + $i_01 | 0] = HEAP16[$chars + ($i_01 << 1) >> 1] & 255;
    var $35 = $i_01 + 1 | 0;
    if ($35 >>> 0 < $nchars >>> 0) {
      var $i_01 = $35;
      __label__ = 13;
      break;
    } else {
      var $bytes_0 = $28;
      var $37 = $nchars;
      __label__ = 14;
      break;
    }
   case 14:
    var $37;
    var $bytes_0;
    HEAP8[$bytes_0 + $37 | 0] = 0;
    var $_0 = $bytes_0;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13DeflateStringEP9JSContextPKtj["X"] = 1;

function __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $chars, $nchars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      var $_0 = $nchars;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE($cx, $chars, $nchars, 0);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj($cx, $src, $srclen, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$dstlenp >> 2];
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    if ($1 >>> 0 < $srclen >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    if (($1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    if (($srclen | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $i_03;
    HEAP8[$dst + $i_03 | 0] = HEAP16[$src + ($i_03 << 1) >> 1] & 255;
    var $12 = $i_03 + 1 | 0;
    if (($12 | 0) == ($1 | 0)) {
      __label__ = 6;
      break;
    } else {
      var $i_03 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = $cx;
    _JS_ReportErrorNumber($15, 2, 0, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 8:
    var $i_11;
    HEAP8[$dst + $i_11 | 0] = HEAP16[$src + ($i_11 << 1) >> 1] & 255;
    var $20 = $i_11 + 1 | 0;
    if (($20 | 0) == ($srclen | 0)) {
      __label__ = 9;
      break;
    } else {
      var $i_11 = $20;
      __label__ = 8;
      break;
    }
   case 9:
    HEAP32[$dstlenp >> 2] = $srclen;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $22 = __ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, 0);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_OneUcs4ToUtf8CharPhj($utf8Buffer, $ucs4Char) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($ucs4Char >>> 0 < 128) {
      var $utf8Length_1 = 1;
      var $storemerge_in = $ucs4Char;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $ucs4Char >>> 11;
    if (($3 | 0) == 0) {
      var $utf8Length_0_lcssa8 = 2;
      var $6 = 1;
      __label__ = 4;
      break;
    } else {
      var $utf8Length_02 = 2;
      var $a_03 = $3;
      __label__ = 5;
      break;
    }
   case 3:
    if (($utf8Length_02 | 0) == 0) {
      var $_0_lcssa = $ucs4Char;
      var $utf8Length_0_lcssa9 = $8;
      __label__ = 7;
      break;
    } else {
      var $utf8Length_0_lcssa8 = $8;
      var $6 = $utf8Length_02;
      __label__ = 4;
      break;
    }
   case 4:
    var $6;
    var $utf8Length_0_lcssa8;
    var $_01 = $ucs4Char;
    var $11 = $6;
    __label__ = 6;
    break;
   case 5:
    var $a_03;
    var $utf8Length_02;
    var $7 = $a_03 >>> 5;
    var $8 = $utf8Length_02 + 1 | 0;
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $utf8Length_02 = $8;
      var $a_03 = $7;
      __label__ = 5;
      break;
    }
   case 6:
    var $11;
    var $_01;
    HEAP8[$utf8Buffer + $11 | 0] = ($_01 & 63 | 128) & 255;
    var $16 = $_01 >>> 6;
    var $17 = $11 - 1 | 0;
    if (($17 | 0) == 0) {
      var $_0_lcssa = $16;
      var $utf8Length_0_lcssa9 = $utf8Length_0_lcssa8;
      __label__ = 7;
      break;
    } else {
      var $_01 = $16;
      var $11 = $17;
      __label__ = 6;
      break;
    }
   case 7:
    var $utf8Length_0_lcssa9;
    var $_0_lcssa;
    var $utf8Length_1 = $utf8Length_0_lcssa9;
    var $storemerge_in = (-1 << 8 - $utf8Length_0_lcssa9) + 256 + $_0_lcssa | 0;
    __label__ = 8;
    break;
   case 8:
    var $storemerge_in;
    var $utf8Length_1;
    HEAP8[$utf8Buffer] = $storemerge_in & 255;
    return $utf8Length_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17Utf8ToOneUcs4CharPKhi($utf8Buffer, $utf8Length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU8[$utf8Buffer] & 255;
    if (($utf8Length | 0) == 1) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $3 & (1 << 7 - $utf8Length) - 1;
    var $11 = HEAPU32[__ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table + ($utf8Length - 2 << 2) >> 2];
    var $12 = $utf8Length - 1 | 0;
    if (($12 | 0) == 0) {
      var $ucs4Char_0_lcssa = $8;
      __label__ = 4;
      break;
    } else {
      var $ucs4Char_06 = $8;
      var $utf8Buffer_pn = $utf8Buffer;
      var $14 = $12;
      __label__ = 3;
      break;
    }
   case 3:
    var $14;
    var $utf8Buffer_pn;
    var $ucs4Char_06;
    var $_027 = $utf8Buffer_pn + 1 | 0;
    var $19 = HEAPU8[$_027] & 255 & 63 | $ucs4Char_06 << 6;
    var $20 = $14 - 1 | 0;
    if (($20 | 0) == 0) {
      var $ucs4Char_0_lcssa = $19;
      __label__ = 4;
      break;
    } else {
      var $ucs4Char_06 = $19;
      var $utf8Buffer_pn = $_027;
      var $14 = $20;
      __label__ = 3;
      break;
    }
   case 4:
    var $ucs4Char_0_lcssa;
    if ($ucs4Char_0_lcssa >>> 0 < $11 >>> 0 | ($ucs4Char_0_lcssa - 55296 | 0) >>> 0 < 2048) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = $ucs4Char_0_lcssa;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE($cx, $chars, $nchars, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $buffer = __stackBase__;
    var $1 = ($fc | 0) == 1;
    var $2 = $chars + ($nchars << 1) | 0;
    var $_04 = $chars;
    var $nbytes_0 = $nchars;
    __label__ = 2;
    break;
   case 2:
    var $nbytes_0;
    var $_04;
    if (($_04 | 0) == ($2 | 0)) {
      var $_0 = $nbytes_0;
      __label__ = 13;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = HEAPU16[$_04 >> 1];
    var $7 = $6 & 65535;
    if (($6 & 65535) < 128) {
      var $_2 = $_04;
      var $nbytes_3 = $nbytes_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($6 + 10240 & 65535 & 65535) > 2047 | $1) {
      var $c_0 = $7;
      var $_1 = $_04;
      var $nbytes_1 = $nbytes_0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $_04 + 2 | 0;
    var $12 = $nbytes_0 - 1 | 0;
    if (($6 & 65535) > 56319 | ($11 | 0) == ($2 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAPU16[$11 >> 1];
    if (($16 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $c_0 = ($7 << 10) - 56613888 + ($16 & 65535) | 0;
    var $_1 = $11;
    var $nbytes_1 = $12;
    __label__ = 8;
    break;
   case 8:
    var $nbytes_1;
    var $_1;
    var $c_0;
    var $24 = $c_0 >>> 11;
    var $nbytes_26 = $nbytes_1 + 1 | 0;
    if (($24 | 0) == 0) {
      var $_2 = $_1;
      var $nbytes_3 = $nbytes_26;
      __label__ = 10;
      break;
    } else {
      var $c_17 = $24;
      var $nbytes_28 = $nbytes_26;
      __label__ = 9;
      break;
    }
   case 9:
    var $nbytes_28;
    var $c_17;
    var $26 = $c_17 >>> 5;
    var $nbytes_2 = $nbytes_28 + 1 | 0;
    if (($26 | 0) == 0) {
      var $_2 = $_1;
      var $nbytes_3 = $nbytes_2;
      __label__ = 10;
      break;
    } else {
      var $c_17 = $26;
      var $nbytes_28 = $nbytes_2;
      __label__ = 9;
      break;
    }
   case 10:
    var $nbytes_3;
    var $_2;
    var $_04 = $_2 + 2 | 0;
    var $nbytes_0 = $nbytes_3;
    __label__ = 2;
    break;
   case 11:
    if (($cx | 0) == 0) {
      var $_0 = -1;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = $buffer | 0;
    var $33 = _JS_snprintf($32, 10, STRING_TABLE.__str363799 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $7, tempInt));
    var $34 = $cx;
    var $35 = _JS_ReportErrorFlagsAndNumber($34, 0, 2, 0, 203, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $32, tempInt));
    var $_0 = -1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE["X"] = 1;

function __ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, $fc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $utf8buf = __stackBase__;
    var $1 = ($fc | 0) == 1;
    var $2 = HEAPU32[$dstlenp >> 2];
    var $3 = $utf8buf | 0;
    var $dstlen_0 = $2;
    var $_01 = $src;
    var $_02 = $srclen;
    var $_04 = $dst;
    __label__ = 2;
    break;
   case 2:
    var $_04;
    var $_02;
    var $_01;
    var $dstlen_0;
    if (($_02 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $_01 + 2 | 0;
    var $8 = HEAPU16[$_01 >> 1];
    var $9 = $_02 - 1 | 0;
    var $10 = $8 & 65535;
    if (($8 + 9216 & 65535 & 65535) > 1023 | $1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 4:
    if (($8 + 10240 & 65535 & 65535) > 1023 | $1) {
      var $_1 = $7;
      var $_13 = $9;
      var $v_0 = $10;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($9 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $16 = HEAPU16[$7 >> 1];
    if (($16 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_1 = $_01 + 4 | 0;
    var $_13 = $_02 - 2 | 0;
    var $v_0 = ($10 << 10) - 56613888 + ($16 & 65535) | 0;
    __label__ = 8;
    break;
   case 8:
    var $v_0;
    var $_13;
    var $_1;
    if ($v_0 >>> 0 < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($dstlen_0 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP8[$_04] = $v_0 & 255;
    var $_2 = $_04 + 1 | 0;
    var $utf8Len_0 = 1;
    __label__ = 15;
    break;
   case 11:
    var $33 = __Z20js_OneUcs4ToUtf8CharPhj($3, $v_0);
    if ($33 >>> 0 > $dstlen_0 >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($33 | 0) == 0) {
      var $_2 = $_04;
      var $utf8Len_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $lftr_limit = $_04 + $33 | 0;
    var $i_011 = 0;
    var $_1512 = $_04;
    __label__ = 14;
    break;
   case 14:
    var $_1512;
    var $i_011;
    var $38 = HEAP8[$utf8buf + $i_011 | 0];
    var $39 = $_1512 + 1 | 0;
    HEAP8[$_1512] = $38;
    if (($39 | 0) == ($lftr_limit | 0)) {
      var $_2 = $lftr_limit;
      var $utf8Len_0 = $33;
      __label__ = 15;
      break;
    } else {
      var $i_011 = $i_011 + 1 | 0;
      var $_1512 = $39;
      __label__ = 14;
      break;
    }
   case 15:
    var $utf8Len_0;
    var $_2;
    var $dstlen_0 = $dstlen_0 - $utf8Len_0 | 0;
    var $_01 = $_1;
    var $_02 = $_13;
    var $_04 = $_2;
    __label__ = 2;
    break;
   case 16:
    HEAP32[$dstlenp >> 2] = $2 - $dstlen_0 | 0;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 17:
    HEAP32[$dstlenp >> 2] = $2 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $48 = __ZN2js23GetDeflatedStringLengthEP9JSContextPKtj($cx, $_01, $_02);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 19:
    HEAP32[$dstlenp >> 2] = $2 - $dstlen_0 | 0;
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $53 = $cx;
    _JS_ReportErrorNumber($53, 2, 0, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE["X"] = 1;

function __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($cx, $src, $srclen, $dst, $dstlenp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_js_CStringsAreUTF8 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE($cx, $src, $srclen, $dst, $dstlenp, 0);
    var $_0 = $4;
    __label__ = 12;
    break;
   case 3:
    if (($dst | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAPU32[$dstlenp >> 2];
    if ($8 >>> 0 < $srclen >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    if (($srclen | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $i_03;
    HEAP16[$dst + ($i_03 << 1) >> 1] = HEAPU8[$src + $i_03 | 0] & 255;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($8 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = $16;
      __label__ = 7;
      break;
    }
   case 8:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $19 = $cx;
    _JS_ReportErrorNumber($19, 2, 0, 202, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 12;
    break;
   case 10:
    var $i_11;
    HEAP16[$dst + ($i_11 << 1) >> 1] = HEAPU8[$src + $i_11 | 0] & 255;
    var $24 = $i_11 + 1 | 0;
    if (($24 | 0) == ($srclen | 0)) {
      __label__ = 11;
      break;
    } else {
      var $i_11 = $24;
      __label__ = 10;
      break;
    }
   case 11:
    HEAP32[$dstlenp >> 2] = $srclen;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj($buffer, $bufferSize, $fp, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($bufferSize | 0) == 0;
    var $_03 = $1 ? 0 : $bufferSize - 1 | 0;
    var $_02 = $1 ? 0 : $buffer;
    var $3 = __ZNK14JSLinearString5charsEv($str);
    var $4 = $str | 0;
    var $5 = __ZNK8JSString6lengthEv($4);
    var $6 = $3 + ($5 << 1) | 0;
    var $7 = ($quote | 0) == 0;
    var $8 = ($fp | 0) == 0;
    var $9 = $quote & 255;
    var $_1_ph = $_02;
    var $c_0_ph = 0;
    var $u_0_ph = 0;
    var $hex_0_ph = 0;
    var $state_0_ph = 1;
    var $chars_0_ph = $3;
    var $shift_0_ph = 0;
    var $n_0_ph = 0;
    __label__ = 2;
    break;
   case 2:
    var $n_0_ph;
    var $shift_0_ph;
    var $chars_0_ph;
    var $state_0_ph;
    var $hex_0_ph;
    var $u_0_ph;
    var $c_0_ph;
    var $_1_ph;
    var $10 = ($chars_0_ph | 0) == ($6 | 0);
    var $state_0_ph8 = $state_0_ph;
    var $shift_0_ph6 = $shift_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $shift_0_ph6;
    var $state_0_ph8;
    var $state_0 = $state_0_ph8;
    __label__ = 4;
    break;
   case 4:
    var $state_0;
    if (($state_0 | 0) == 2) {
      __label__ = 5;
      break;
    } else if (($state_0 | 0) == 1) {
      var $state_1 = 3;
      __label__ = 6;
      break;
    } else if (($state_0 | 0) == 3) {
      __label__ = 7;
      break;
    } else if (($state_0 | 0) == 4) {
      __label__ = 17;
      break;
    } else if (($state_0 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($state_0 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $c_1 = $c_0_ph;
      var $u_2 = $u_0_ph;
      var $hex_2 = $hex_0_ph;
      var $state_2 = $state_0;
      var $chars_1 = $chars_0_ph;
      var $shift_2 = $shift_0_ph6;
      __label__ = 20;
      break;
    }
   case 5:
    var $state_1 = 0;
    __label__ = 6;
    break;
   case 6:
    var $state_1;
    if ($7) {
      var $state_0 = $state_1;
      __label__ = 4;
      break;
    } else {
      var $c_1 = $9;
      var $u_2 = $u_0_ph;
      var $hex_2 = $hex_0_ph;
      var $state_2 = $state_1;
      var $chars_1 = $chars_0_ph;
      var $shift_2 = $shift_0_ph6;
      __label__ = 20;
      break;
    }
   case 7:
    if ($10) {
      var $state_0 = 2;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = $chars_0_ph + 2 | 0;
    var $16 = HEAPU16[$chars_0_ph >> 1];
    var $17 = $16 & 65535;
    if (($16 & 65535) < 32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 9:
    if ($16 << 16 >> 16 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $memchr = _memchr(STRING_TABLE._js_EscapeMap | 0, $17, 19);
    if (($memchr | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $c_1 = 92;
    var $u_2 = HEAP8[$memchr + 1 | 0] << 24 >> 24;
    var $hex_2 = $hex_0_ph;
    var $state_2 = 4;
    var $chars_1 = $15;
    var $shift_2 = $shift_0_ph6;
    __label__ = 20;
    break;
   case 12:
    if (($16 & 65535) < 127) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    if (($17 | 0) == ($quote | 0) | $16 << 16 >> 16 == 92) {
      var $c_1 = 92;
      var $u_2 = $17;
      var $hex_2 = $hex_0_ph;
      var $state_2 = 4;
      var $chars_1 = $15;
      var $shift_2 = $shift_0_ph6;
      __label__ = 20;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $c_1 = $16 & 255;
    var $u_2 = $17;
    var $hex_2 = $hex_0_ph;
    var $state_2 = $state_0;
    var $chars_1 = $15;
    var $shift_2 = $shift_0_ph6;
    __label__ = 20;
    break;
   case 15:
    if (($16 & 65535) < 256) {
      __label__ = 16;
      break;
    } else {
      var $c_1 = 92;
      var $u_2 = 117;
      var $hex_2 = $17;
      var $state_2 = 4;
      var $chars_1 = $15;
      var $shift_2 = 16;
      __label__ = 20;
      break;
    }
   case 16:
    var $c_1 = 92;
    var $u_2 = 120;
    var $hex_2 = $17;
    var $state_2 = 4;
    var $chars_1 = $15;
    var $shift_2 = 8;
    __label__ = 20;
    break;
   case 17:
    var $c_1 = $u_0_ph & 255;
    var $u_2 = $u_0_ph;
    var $hex_2 = $hex_0_ph;
    var $state_2 = 5;
    var $chars_1 = $chars_0_ph;
    var $shift_2 = $shift_0_ph6;
    __label__ = 20;
    break;
   case 18:
    if (($shift_0_ph6 | 0) == 0) {
      var $state_0_ph8 = 3;
      var $shift_0_ph6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $42 = $shift_0_ph6 - 4 | 0;
    var $44 = $hex_0_ph >>> ($42 >>> 0) & 15;
    var $46 = $44 >>> 0 < 10 ? 48 : 55;
    var $c_1 = $46 + $44 & 255;
    var $u_2 = $44;
    var $hex_2 = $hex_0_ph;
    var $state_2 = $state_0;
    var $chars_1 = $chars_0_ph;
    var $shift_2 = $42;
    __label__ = 20;
    break;
   case 20:
    var $shift_2;
    var $chars_1;
    var $state_2;
    var $hex_2;
    var $u_2;
    var $c_1;
    if (($_1_ph | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $52 = $_1_ph + $n_0_ph | 0;
    if (($n_0_ph | 0) == ($_03 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    HEAP8[$52] = $c_1;
    var $_2 = $_1_ph;
    __label__ = 26;
    break;
   case 23:
    HEAP8[$52] = 0;
    var $_2 = 0;
    __label__ = 26;
    break;
   case 24:
    if ($8) {
      var $_2 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $58 = _fputc($c_1 << 24 >> 24, $fp);
    if (($58 | 0) < 0) {
      var $_0 = -1;
      __label__ = 29;
      break;
    } else {
      var $_2 = 0;
      __label__ = 26;
      break;
    }
   case 26:
    var $_2;
    var $_1_ph = $_2;
    var $c_0_ph = $c_1;
    var $u_0_ph = $u_2;
    var $hex_0_ph = $hex_2;
    var $state_0_ph = $state_2;
    var $chars_0_ph = $chars_1;
    var $shift_0_ph = $shift_2;
    var $n_0_ph = $n_0_ph + 1 | 0;
    __label__ = 2;
    break;
   case 27:
    if (($_1_ph | 0) == 0) {
      var $_0 = $n_0_ph;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP8[$_1_ph + $n_0_ph | 0] = 0;
    var $_0 = $n_0_ph;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj["X"] = 1;

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$2 >> 1] = $t << 24 >> 24;
    __label__ = 3;
    break;
   case 3:
    var $7 = $this + 8 | 0;
    var $9 = HEAP32[$7 >> 2] + 1 | 0;
    HEAP32[$7 >> 2] = $9;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value8isStringEv($v);
  return $1;
}

function __ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE($v) {
  var $1 = __ZNK2JS5Value8toStringEv($v);
  return $1;
}

function __ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE($cx, $str, $unescapedSet, $unescapedSet2, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 92;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $hexBuf = __stackBase__ + 80;
    var $utf8buf = __stackBase__ + 88;
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $12);
    var $_1 = 1;
    __label__ = 25;
    break;
   case 4:
    var $14 = $sb;
    __ZN2js12StringBufferC1EP9JSContext($14, $2);
    var $15 = $hexBuf | 0;
    HEAP16[$15 >> 1] = 37;
    HEAP16[$hexBuf + 6 >> 1] = 0;
    var $17 = ($unescapedSet2 | 0) == 0;
    var $18 = $utf8buf | 0;
    var $19 = $hexBuf + 2 | 0;
    var $20 = $hexBuf + 4 | 0;
    var $k_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $1 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 6:
    var $25 = HEAPU16[$3 + ($k_0 << 1) >> 1];
    var $26 = __Z9js_strchrPKtt($unescapedSet, $25);
    if (($26 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ($17) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = __Z9js_strchrPKtt($unescapedSet2, $25);
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $33 = __ZN2js12StringBuffer6appendEt($14, $25);
    if ($33) {
      var $k_2 = $k_0;
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 10:
    var $35 = $25 & 65535;
    if (($25 + 9216 & 65535 & 65535) < 1024) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($2, 2, 0, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 12:
    if (($25 + 10240 & 65535 & 65535) > 1023) {
      var $v_0 = $35;
      var $k_1 = $k_0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = $k_0 + 1 | 0;
    if (($41 | 0) == ($1 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    _JS_ReportErrorNumber($2, 2, 0, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 15:
    var $46 = HEAPU16[$3 + ($41 << 1) >> 1];
    if (($46 + 9216 & 65535 & 65535) > 1023) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($2, 2, 0, 159, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 24;
    break;
   case 17:
    var $v_0 = ($35 << 10) - 56613888 + ($46 & 65535) | 0;
    var $k_1 = $41;
    __label__ = 18;
    break;
   case 18:
    var $k_1;
    var $v_0;
    var $55 = __Z20js_OneUcs4ToUtf8CharPhj($18, $v_0);
    var $j_0 = 0;
    __label__ = 19;
    break;
   case 19:
    var $j_0;
    if ($j_0 >>> 0 < $55 >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $k_2 = $k_1;
      __label__ = 22;
      break;
    }
   case 20:
    var $61 = HEAPU8[$utf8buf + $j_0 | 0] & 255;
    var $63 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits + ($61 >>> 4) | 0;
    HEAP16[$19 >> 1] = HEAP8[$63] << 24 >> 24;
    var $67 = STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits + ($61 & 15) | 0;
    HEAP16[$20 >> 1] = HEAP8[$67] << 24 >> 24;
    var $70 = __ZN2js12StringBuffer6appendEPKtj($14, $15, 3);
    if ($70) {
      __label__ = 21;
      break;
    } else {
      var $_0 = 0;
      __label__ = 24;
      break;
    }
   case 21:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 19;
    break;
   case 22:
    var $k_2;
    var $k_0 = $k_2 + 1 | 0;
    __label__ = 5;
    break;
   case 23:
    var $75 = __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval);
    var $_0 = $75 & 1;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    __ZN2js12StringBufferD1Ev($14);
    var $_1 = $_0;
    __label__ = 25;
    break;
   case 25:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE["X"] = 1;

function __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js12StringBuffer12finishStringEv($sb);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $4);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14JSID_FROM_BITSj3911($bits) {
  return $bits;
}

function __ZN14JSInlineString10lengthFitsEj($length) {
  return $length >>> 0 < 4;
}

function _JSID_IS_INT3906($iden) {
  return $iden & 1;
}

function __ZN2js13StaticStrings7hasUnitEt($c) {
  return ($c & 65535) < 256;
}

function __ZNK16SplitMatchResult9isFailureEv($this) {
  return (HEAP32[$this >> 2] | 0) == -1;
}

function __ZNK16SplitMatchResult6lengthEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK16SplitMatchResult8endIndexEv($this) {
  return HEAP32[$this >> 2];
}

function __ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE($cx, $str, $reservedSet, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $octets = __stackBase__ + 80;
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 44;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($rval, $12);
    var $_1 = 1;
    __label__ = 44;
    break;
   case 4:
    var $14 = $sb;
    __ZN2js12StringBufferC1EP9JSContext($14, $2);
    var $15 = $octets | 0;
    var $k_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $k_0;
    if ($k_0 >>> 0 < $1 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 6:
    var $19 = $3 + ($k_0 << 1) | 0;
    var $20 = HEAPU16[$19 >> 1];
    if ($20 << 16 >> 16 == 37) {
      __label__ = 7;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 7:
    var $23 = $k_0 + 2 | 0;
    if ($23 >>> 0 < $1 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 8:
    var $27 = $3 + ($k_0 + 1 << 1) | 0;
    var $28 = HEAPU16[$27 >> 1];
    if (($28 & 65535) < 128) {
      __label__ = 9;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 9:
    var $31 = $28 & 65535;
    var $32 = _isxdigit($31);
    if (($32 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $3 + ($23 << 1) | 0;
    var $36 = HEAPU16[$35 >> 1];
    if (($36 & 65535) < 128) {
      __label__ = 11;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 11:
    var $39 = $36 & 65535;
    var $40 = _isxdigit($39);
    if (($40 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $44 = HEAPU16[$27 >> 1] & 65535;
    var $45 = $44 - 48 | 0;
    if ($45 >>> 0 < 10) {
      var $51 = $45;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = _tolower($44);
    var $51 = $48 - 87 | 0;
    __label__ = 14;
    break;
   case 14:
    var $51;
    var $52 = $51 << 4;
    var $54 = HEAPU16[$35 >> 1] & 65535;
    var $55 = $54 - 48 | 0;
    if ($55 >>> 0 < 10) {
      var $61 = $55;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $58 = _tolower($54);
    var $61 = $58 - 87 | 0;
    __label__ = 16;
    break;
   case 16:
    var $61;
    var $62 = $61 + $52 | 0;
    if (($62 & 128 | 0) == 0) {
      var $c_0_in = $62;
      var $k_2 = $23;
      __label__ = 36;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if (($62 & 64 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      var $n_02 = 1;
      __label__ = 18;
      break;
    }
   case 18:
    var $n_02;
    var $67 = $n_02 + 1 | 0;
    if ((128 >>> ($67 >>> 0) & $62 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      var $n_02 = $67;
      __label__ = 18;
      break;
    }
   case 19:
    if (($n_02 | 0) == 0 | ($67 | 0) > 4) {
      __label__ = 42;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP8[$15] = $62 & 255;
    if (($k_0 - 1 + $67 * 3 | 0) >>> 0 < $1 >>> 0) {
      var $j_0 = 1;
      var $k_1 = $23;
      __label__ = 21;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 21:
    var $k_1;
    var $j_0;
    if (($j_0 | 0) < ($67 | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 22:
    if (HEAP16[$3 + ($k_1 + 1 << 1) >> 1] << 16 >> 16 == 37) {
      __label__ = 23;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 23:
    var $87 = $3 + ($k_1 + 2 << 1) | 0;
    var $88 = HEAPU16[$87 >> 1];
    if (($88 & 65535) < 128) {
      __label__ = 24;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 24:
    var $91 = $88 & 65535;
    var $92 = _isxdigit($91);
    if (($92 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $95 = $k_1 + 3 | 0;
    var $96 = $3 + ($95 << 1) | 0;
    var $97 = HEAPU16[$96 >> 1];
    if (($97 & 65535) < 128) {
      __label__ = 26;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 26:
    var $100 = $97 & 65535;
    var $101 = _isxdigit($100);
    if (($101 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $105 = HEAPU16[$87 >> 1] & 65535;
    var $106 = $105 - 48 | 0;
    if ($106 >>> 0 < 10) {
      var $112 = $106;
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $109 = _tolower($105);
    var $112 = $109 - 87 | 0;
    __label__ = 29;
    break;
   case 29:
    var $112;
    var $113 = $112 << 4;
    var $115 = HEAPU16[$96 >> 1] & 65535;
    var $116 = $115 - 48 | 0;
    if ($116 >>> 0 < 10) {
      var $122 = $116;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $119 = _tolower($115);
    var $122 = $119 - 87 | 0;
    __label__ = 31;
    break;
   case 31:
    var $122;
    var $123 = $122 + $113 | 0;
    if (($123 & 192 | 0) == 128) {
      __label__ = 32;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 32:
    HEAP8[$octets + $j_0 | 0] = $123 & 255;
    var $j_0 = $j_0 + 1 | 0;
    var $k_1 = $95;
    __label__ = 21;
    break;
   case 33:
    var $131 = __ZL17Utf8ToOneUcs4CharPKhi($15, $67);
    if ($131 >>> 0 > 65535) {
      __label__ = 34;
      break;
    } else {
      var $c_0_in = $131;
      var $k_2 = $k_1;
      __label__ = 36;
      break;
    }
   case 34:
    var $134 = $131 - 65536 | 0;
    if ($134 >>> 0 > 1048575) {
      __label__ = 42;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $138 = $134 & 1023 | 56320;
    var $141 = ($134 >>> 10) + 55296 & 65535;
    var $142 = __ZN2js12StringBuffer6appendEt($14, $141);
    if ($142) {
      var $c_0_in = $138;
      var $k_2 = $k_1;
      __label__ = 36;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 36:
    var $k_2;
    var $c_0_in;
    var $c_0 = $c_0_in & 65535;
    var $144 = __Z9js_strchrPKtt($reservedSet, $c_0);
    if (($144 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $149 = __ZN2js12StringBuffer6appendEPKtj($14, $19, 1 - $k_0 + $k_2 | 0);
    if ($149) {
      var $k_3 = $k_2;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 38:
    var $151 = __ZN2js12StringBuffer6appendEt($14, $c_0);
    if ($151) {
      var $k_3 = $k_2;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 39:
    var $153 = __ZN2js12StringBuffer6appendEt($14, $20);
    if ($153) {
      var $k_3 = $k_0;
      __label__ = 40;
      break;
    } else {
      var $_0 = 0;
      __label__ = 43;
      break;
    }
   case 40:
    var $k_3;
    var $k_0 = $k_3 + 1 | 0;
    __label__ = 5;
    break;
   case 41:
    var $157 = __ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE($sb, $rval);
    var $_0 = $157 & 1;
    __label__ = 43;
    break;
   case 42:
    _JS_ReportErrorNumber($2, 2, 0, 159, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 43;
    break;
   case 43:
    var $_0;
    __ZN2js12StringBufferD1Ev($14);
    var $_1 = $_0;
    __label__ = 44;
    break;
   case 44:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE["X"] = 1;

function __ZN14JSInlineString4new_EP9JSContext($cx) {
  var $1 = $cx;
  var $2 = __Z14js_NewGCStringP9JSContext($1);
  return $2;
}

function __ZN13JSShortString4new_EP9JSContext($cx) {
  var $1 = $cx;
  var $2 = __Z19js_NewGCShortStringP9JSContext($1);
  return $2;
}

function __ZN14JSInlineString11resetLengthEj($this, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 4);
  HEAP32[$this >> 2] = $1;
  return;
}

function __ZN17JSDependentString4initEP14JSLinearStringPKtj($this, $base, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 2);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  HEAP32[$this + 8 >> 2] = $base;
  return;
}

function __ZN2jsL7PodCopyItEEvPT_PKS1_j3900($dst, $src, $nelem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nelem >>> 0 < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $src + ($nelem << 1) | 0;
    if (($nelem | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $src;
      var $_03 = $dst;
      __label__ = 3;
      break;
    }
   case 3:
    var $_03;
    var $_012;
    var $5 = HEAP16[$_012 >> 1];
    HEAP16[$_03 >> 1] = $5;
    var $6 = $_012 + 2 | 0;
    if (($6 | 0) == ($3 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_012 = $6;
      var $_03 = $_03 + 2 | 0;
      __label__ = 3;
      break;
    }
   case 4:
    var $10 = $dst;
    var $11 = $src;
    var $12 = $nelem << 1;
    _memcpy($10, $11, $12, 1);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13JSFixedString4initEPKtj($this, $chars, $length) {
  var $1 = __ZN8JSString19buildLengthAndFlagsEjj(undef, $length, 4);
  HEAP32[$this >> 2] = $1;
  HEAP32[$this + 4 >> 2] = $chars;
  return;
}

function __ZN2JSL11ObjectValueER8JSObject3902($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZN2JSL11StringValueEP8JSString3909($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __ZN2JSL10Int32ValueEi3910($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, $begin, $param, $end, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = __ZN8JSString12ensureLinearEP9JSContext($1, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_01 = ($end | 0) == 0 ? $begin : $end;
    var $9 = _strlen($begin);
    var $10 = $9 + 2 | 0;
    var $11 = ($param | 0) != 0;
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $parlen_0 = 0;
      var $taglen_0 = $10;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $param | 0;
    var $14 = __ZNK8JSString6lengthEv($13);
    var $parlen_0 = $14;
    var $taglen_0 = $14 + ($9 + 5) | 0;
    __label__ = 5;
    break;
   case 5:
    var $taglen_0;
    var $parlen_0;
    var $18 = _strlen($_01);
    var $19 = $5 | 0;
    var $20 = __ZNK8JSString6lengthEv($19);
    var $23 = $20 + ($18 + ($taglen_0 + 3)) | 0;
    if ($23 >>> 0 > 2147483646) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    __Z27js_ReportAllocationOverflowP9JSContext($4);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 7:
    var $28 = ($23 << 1) + 2 | 0;
    var $29 = __ZN9JSContext7malloc_Ej($4, $28);
    var $30 = $29;
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP16[$30 >> 1] = 60;
    if (($9 | 0) == 0) {
      var $j_0_lcssa = 1;
      __label__ = 11;
      break;
    } else {
      var $j_04 = 1;
      var $i_05 = 0;
      __label__ = 9;
      break;
    }
   case 9:
    var $i_05;
    var $j_04;
    HEAP16[$30 + ($j_04 << 1) >> 1] = HEAP8[$begin + $i_05 | 0] << 24 >> 24;
    var $39 = $i_05 + 1 | 0;
    if (($39 | 0) == ($9 | 0)) {
      __label__ = 10;
      break;
    } else {
      var $j_04 = $j_04 + 1 | 0;
      var $i_05 = $39;
      __label__ = 9;
      break;
    }
   case 10:
    var $j_0_lcssa = $9 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $j_0_lcssa;
    if ($11) {
      __label__ = 12;
      break;
    } else {
      var $j_1 = $j_0_lcssa;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP16[$30 + ($j_0_lcssa << 1) >> 1] = 61;
    var $45 = $j_0_lcssa + 2 | 0;
    HEAP16[$30 + ($j_0_lcssa + 1 << 1) >> 1] = 34;
    var $48 = $30 + ($45 << 1) | 0;
    var $49 = __ZNK14JSLinearString5charsEv($param);
    var $50 = $49;
    _memcpy($48, $50, $parlen_0 << 1, 1);
    var $52 = $45 + $parlen_0 | 0;
    HEAP16[$30 + ($52 << 1) >> 1] = 34;
    var $j_1 = $52 + 1 | 0;
    __label__ = 13;
    break;
   case 13:
    var $j_1;
    var $56 = $j_1 + 1 | 0;
    HEAP16[$30 + ($j_1 << 1) >> 1] = 62;
    var $59 = $30 + ($56 << 1) | 0;
    var $60 = __ZNK14JSLinearString5charsEv($5);
    var $61 = $60;
    var $62 = __ZNK8JSString6lengthEv($19);
    var $63 = $62 << 1;
    _memcpy($59, $61, $63, 1);
    var $64 = __ZNK8JSString6lengthEv($19);
    var $65 = $64 + $56 | 0;
    var $66 = $65 + 1 | 0;
    HEAP16[$30 + ($65 << 1) >> 1] = 60;
    var $68 = $65 + 2 | 0;
    HEAP16[$30 + ($66 << 1) >> 1] = 47;
    if (($18 | 0) == 0) {
      var $j_2_lcssa = $68;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $72 = $18 + $64 + $j_1 | 0;
    var $j_22 = $68;
    var $i1_03 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i1_03;
    var $j_22;
    HEAP16[$30 + ($j_22 << 1) >> 1] = HEAP8[$_01 + $i1_03 | 0] << 24 >> 24;
    var $79 = $i1_03 + 1 | 0;
    if (($79 | 0) == ($18 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $j_22 = $j_22 + 1 | 0;
      var $i1_03 = $79;
      __label__ = 15;
      break;
    }
   case 16:
    var $j_2_lcssa = $72 + 3 | 0;
    __label__ = 17;
    break;
   case 17:
    var $j_2_lcssa;
    HEAP16[$30 + ($j_2_lcssa << 1) >> 1] = 62;
    HEAP16[$30 + ($j_2_lcssa + 1 << 1) >> 1] = 0;
    var $85 = __Z12js_NewStringP9JSContextPtj($cx, $30, $23);
    if (($85 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    __ZN2js10Foreground5free_EPv($29);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 19:
    var $89 = $85 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $89);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE["X"] = 1;

function __ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_($cx, $argc, $vp, $begin, $end) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj($cx, $argc, $vp, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE($cx, $begin, $1, $end, $vp);
    var $_0 = $4 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi($cx, $v, $out) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    HEAP32[$out >> 2] = $3;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824($cx, $v, $d);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $7 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    if ($7 > 2147483647) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$out >> 2] = 2147483647;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    if ($7 < -2147483648) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$out >> 2] = -2147483648;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    var $14 = $7 & -1;
    HEAP32[$out >> 2] = $14;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($2) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value8toObjectEv($v);
    var $5 = __ZNK8JSObject8isRegExpEv($4);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    STACKTOP = __stackBase__;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $str, $limit, $splitMatch_0, $splitMatch_1, $type) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $splitMatch = __stackBase__;
    HEAP32[$splitMatch >> 2] = $splitMatch_0;
    HEAP32[$splitMatch + 4 >> 2] = $splitMatch_1;
    var $result = STACKTOP;
    STACKTOP += 8;
    var $v = STACKTOP;
    STACKTOP += 8;
    var $splits = STACKTOP;
    STACKTOP += 92;
    var $1 = STACKTOP;
    STACKTOP += 8;
    var $parsub = STACKTOP;
    STACKTOP += 8;
    var $2 = STACKTOP;
    STACKTOP += 8;
    var $3 = STACKTOP;
    STACKTOP += 8;
    var $4 = STACKTOP;
    STACKTOP += 8;
    var $5 = STACKTOP;
    STACKTOP += 8;
    var $6 = $str | 0;
    var $7 = __ZNK8JSString6lengthEv($6);
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $10 = __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, $cx, $str, 0, $result);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 30;
      break;
    }
   case 3:
    var $12 = __ZNK16SplitMatchResult9isFailureEv($result);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($14, 0);
    var $_1 = $15;
    __label__ = 30;
    break;
   case 5:
    __ZN2JSL11StringValueEP8JSString3909($v, $6);
    var $18 = $cx;
    var $19 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($18, 1, $v, 0);
    var $_1 = $19;
    __label__ = 30;
    break;
   case 6:
    var $22 = $splits;
    var $23 = $cx;
    __ZN2js15AutoValueVectorC1EP9JSContext($22, $23);
    var $24 = $splits;
    var $25 = $parsub + 4 | 0;
    var $26 = $parsub | 0;
    var $lastEndIndex_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $lastEndIndex_0_ph;
    var $index_0 = $lastEndIndex_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $index_0;
    if ($index_0 >>> 0 < $7 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 9:
    var $30 = __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, $cx, $str, $index_0, $result);
    if ($30) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 10:
    var $32 = __ZNK16SplitMatchResult9isFailureEv($result);
    if ($32) {
      __label__ = 26;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $34 = __ZNK16SplitMatchResult6lengthEv($result);
    var $35 = __ZNK16SplitMatchResult8endIndexEv($result);
    if (($34 | 0) == 0 & ($35 | 0) == ($7 | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($35 | 0) == ($lastEndIndex_0_ph | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 8;
    break;
   case 14:
    var $43 = $35 - ($34 + $lastEndIndex_0_ph) | 0;
    var $44 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $6, $lastEndIndex_0_ph, $43);
    if (($44 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $47 = $44 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $47);
    var $48 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $1);
    if ($48) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 16:
    var $50 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    if (($50 | 0) == ($limit | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $53 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $54 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $50, $53, 0);
    var $_0 = $54;
    __label__ = 29;
    break;
   case 18:
    var $57 = __ZN9JSContext13regExpStaticsEv($23);
    var $i_0 = 0;
    __label__ = 19;
    break;
   case 19:
    var $i_0;
    var $59 = __ZNK2js13RegExpStatics10parenCountEv($57);
    if ($i_0 >>> 0 < $59 >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $lastEndIndex_0_ph = $35;
      __label__ = 7;
      break;
    }
   case 20:
    var $62 = $i_0 + 1 | 0;
    var $63 = __ZNK2js13RegExpStatics13pairIsPresentEj($57, $62);
    if ($63) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($57, $62, $parsub);
    var $65 = HEAP32[$25 >> 2];
    var $66 = HEAP32[$26 >> 2];
    var $67 = __Z17js_NewStringCopyNP9JSContextPKtj($cx, $65, $66);
    if (($67 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $70 = $67 | 0;
    __ZN2JSL11StringValueEP8JSString3909($2, $70);
    var $71 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $2);
    if ($71) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 23:
    __ZN2JSL14UndefinedValueEv3828($3);
    __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE($cx, $type, 0, $3);
    __ZN2JSL14UndefinedValueEv3828($4);
    var $73 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $4);
    if ($73) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 24:
    var $75 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    if (($75 | 0) == ($limit | 0)) {
      __label__ = 25;
      break;
    } else {
      var $i_0 = $62;
      __label__ = 19;
      break;
    }
   case 25:
    var $78 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $79 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $75, $78, 0);
    var $_0 = $79;
    __label__ = 29;
    break;
   case 26:
    var $82 = $7 - $lastEndIndex_0_ph | 0;
    var $83 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $6, $lastEndIndex_0_ph, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $86 = $83 | 0;
    __ZN2JSL11StringValueEP8JSString3909($5, $86);
    var $87 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($24, $5);
    if ($87) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 0;
      __label__ = 29;
      break;
    }
   case 28:
    var $89 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($24);
    var $90 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($24);
    var $91 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($23, $89, $90, 0);
    var $_0 = $91;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($22);
    var $_1 = $_0;
    __label__ = 30;
    break;
   case 30:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE["X"] = 1;

function __ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res) {
  __ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res);
  return;
}

function __ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE($cx, $str, $limit, $splitMatch_0, $splitMatch_1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $splitMatch = __stackBase__;
    HEAP32[$splitMatch >> 2] = $splitMatch_0;
    HEAP32[$splitMatch + 4 >> 2] = $splitMatch_1;
    var $result = STACKTOP;
    STACKTOP += 8;
    var $v = STACKTOP;
    STACKTOP += 8;
    var $splits = STACKTOP;
    STACKTOP += 92;
    var $1 = STACKTOP;
    STACKTOP += 8;
    var $2 = STACKTOP;
    STACKTOP += 8;
    var $3 = $str | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $7 = __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, undef, $str, 0, $result);
    var $8 = __ZNK16SplitMatchResult9isFailureEv($result);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    var $11 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($10, 0);
    var $_1 = $11;
    __label__ = 20;
    break;
   case 4:
    __ZN2JSL11StringValueEP8JSString3909($v, $3);
    var $14 = $cx;
    var $15 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($14, 1, $v, 0);
    var $_1 = $15;
    __label__ = 20;
    break;
   case 5:
    var $18 = $splits;
    var $19 = $cx;
    __ZN2js15AutoValueVectorC1EP9JSContext($18, $19);
    var $20 = $splits;
    var $lastEndIndex_0_ph = 0;
    __label__ = 6;
    break;
   case 6:
    var $lastEndIndex_0_ph;
    var $index_0 = $lastEndIndex_0_ph;
    __label__ = 7;
    break;
   case 7:
    var $index_0;
    if ($index_0 >>> 0 < $4 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    var $24 = __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($splitMatch, undef, $str, $index_0, $result);
    var $25 = __ZNK16SplitMatchResult9isFailureEv($result);
    if ($25) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = __ZNK16SplitMatchResult6lengthEv($result);
    var $28 = __ZNK16SplitMatchResult8endIndexEv($result);
    if (($27 | 0) == 0 & ($28 | 0) == ($4 | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if (($28 | 0) == ($lastEndIndex_0_ph | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $index_0 = $index_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $36 = $28 - ($27 + $lastEndIndex_0_ph) | 0;
    var $37 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $3, $lastEndIndex_0_ph, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $40 = $37 | 0;
    __ZN2JSL11StringValueEP8JSString3909($1, $40);
    var $41 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($20, $1);
    if ($41) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 14:
    var $43 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($20);
    if (($43 | 0) == ($limit | 0)) {
      __label__ = 15;
      break;
    } else {
      var $lastEndIndex_0_ph = $28;
      __label__ = 6;
      break;
    }
   case 15:
    var $46 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($20);
    var $47 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($19, $43, $46, 0);
    var $_0 = $47;
    __label__ = 19;
    break;
   case 16:
    var $50 = $4 - $lastEndIndex_0_ph | 0;
    var $51 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $3, $lastEndIndex_0_ph, $50);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = $51 | 0;
    __ZN2JSL11StringValueEP8JSString3909($2, $54);
    var $55 = __ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_($20, $2);
    if ($55) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 19;
      break;
    }
   case 18:
    var $57 = __ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv($20);
    var $58 = __ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv($20);
    var $59 = __ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject($19, $57, $58, 0);
    var $_0 = $59;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    __ZN2js15AutoValueVectorD1Ev($18);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE["X"] = 1;

function __ZN18SplitStringMatcherC1EP14JSLinearString($this, $sep) {
  __ZN18SplitStringMatcherC2EP14JSLinearString($this, $sep);
  return;
}

function __ZN18SplitStringMatcherC2EP14JSLinearString($this, $sep) {
  var $1 = __ZNK14JSLinearString5charsEv($sep);
  HEAP32[$this >> 2] = $1;
  var $3 = $sep | 0;
  var $4 = __ZNK8JSString6lengthEv($3);
  HEAP32[$this + 4 >> 2] = $4;
  return;
}

function __ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($this, $cx, $str, $index, $res) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK14JSLinearString5charsEv($str);
    var $2 = $1 + ($index << 1) | 0;
    var $3 = $str | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    var $5 = $4 - $index | 0;
    var $7 = HEAP32[$this >> 2];
    var $9 = HEAP32[$this + 4 >> 2];
    var $10 = __ZL11StringMatchPKtjS0_j($2, $5, $7, $9);
    if (($10 | 0) == -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN16SplitMatchResult10setFailureEv($res);
    __label__ = 4;
    break;
   case 3:
    var $15 = $9 + $index + $10 | 0;
    __ZN16SplitMatchResult9setResultEjj($res, $9, $15);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11StringMatchPKtjS0_j($text, $textlen, $pat, $patlen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($patlen | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($textlen >>> 0 < $patlen >>> 0) {
      var $_0 = -1;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($textlen >>> 0 > 511) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    if (($patlen - 11 | 0) >>> 0 < 245) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $9 = __Z21js_BoyerMooreHorspoolPKtjS0_j($text, $textlen, $pat, $patlen);
    if (($9 | 0) == -2) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $9;
      __label__ = 7;
      break;
    }
   case 6:
    var $12 = __ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j($text, $textlen, $pat, $patlen);
    var $_0 = $12;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6RegExp10isMetaCharEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $c & 65535;
    if (($1 | 0) == 94 || ($1 | 0) == 36 || ($1 | 0) == 92 || ($1 | 0) == 46 || ($1 | 0) == 42 || ($1 | 0) == 43 || ($1 | 0) == 63 || ($1 | 0) == 40 || ($1 | 0) == 41 || ($1 | 0) == 91 || ($1 | 0) == 93 || ($1 | 0) == 123 || ($1 | 0) == 125 || ($1 | 0) == 124) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd3930($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZL18JSDOUBLE_IS_FINITEd3932($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN16SplitMatchResult10setFailureEv($this) {
  HEAP32[$this >> 2] = -1;
  return;
}

function __ZN16SplitMatchResult9setResultEjj($this, $length, $endIndex) {
  HEAP32[$this + 4 >> 2] = $length;
  HEAP32[$this >> 2] = $endIndex;
  return;
}

function __ZN9ManualCmp13computeExtentEPKtj($pat, $patlen) {
  return $pat + ($patlen << 1) | 0;
}

function __ZN9ManualCmp5matchEPKtS1_S1_($p, $t, $extent) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $p;
    var $_02 = $t;
    __label__ = 2;
    break;
   case 2:
    var $_02;
    var $_01;
    if (($_01 | 0) == ($extent | 0)) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (HEAP16[$_01 >> 1] << 16 >> 16 == HEAP16[$_02 >> 1] << 16 >> 16) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_01 = $_01 + 2 | 0;
    var $_02 = $_02 + 2 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE($this, $re, $res) {
  HEAP32[$this >> 2] = $res;
  HEAP32[$this + 4 >> 2] = $re;
  return;
}

function __ZNK2js12AutoRefCountINS_6RegExpEEdeEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js12AutoRefCountINS_6RegExpEE4nullEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == 0;
}

function __ZN9FlatMatchC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZNK10RegExpPair5reobjEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK9FlatMatch7patternEv($this) {
  return HEAP32[$this >> 2] | 0;
}

function __ZNK9FlatMatch13patternLengthEv($this) {
  return HEAP32[$this + 8 >> 2];
}

function __ZNK2js18StringSegmentRange5emptyEv($this) {
  return (HEAP32[$this + 144 >> 2] | 0) == 0;
}

function __ZNK2js18StringSegmentRange5frontEv($this) {
  return HEAP32[$this + 144 >> 2];
}

function __ZN2js11RopeBuilder6resultEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j($text, $textlen, $pat, $patlen) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_sum = 1 - $patlen + $textlen | 0;
    var $2 = $text + ($_sum << 1) | 0;
    var $3 = HEAP16[$pat >> 1];
    var $4 = $pat + 2 | 0;
    var $5 = __ZN9ManualCmp13computeExtentEPKtj($pat, $patlen);
    var $6 = $text;
    var $7 = $_sum & 7;
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($7 | 0) == 7) {
      var $t_0 = $text;
      __label__ = 3;
      break;
    } else if (($7 | 0) == 6) {
      var $t_1 = $text;
      __label__ = 4;
      break;
    } else if (($7 | 0) == 5) {
      var $t_2 = $text;
      __label__ = 5;
      break;
    } else if (($7 | 0) == 4) {
      var $t_3 = $text;
      __label__ = 6;
      break;
    } else if (($7 | 0) == 3) {
      var $t_4 = $text;
      __label__ = 7;
      break;
    } else if (($7 | 0) == 2) {
      var $t_5 = $text;
      __label__ = 8;
      break;
    } else if (($7 | 0) == 1) {
      var $t_6 = $text;
      __label__ = 9;
      break;
    } else {
      var $t_7 = $text;
      __label__ = 10;
      break;
    }
   case 2:
    var $9 = $text + 2 | 0;
    if (HEAP16[$text >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $9;
      var $fixup_0 = 8;
      __label__ = 20;
      break;
    } else {
      var $t_0 = $9;
      __label__ = 3;
      break;
    }
   case 3:
    var $t_0;
    var $13 = $t_0 + 2 | 0;
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $13;
      var $fixup_0 = 7;
      __label__ = 20;
      break;
    } else {
      var $t_1 = $13;
      __label__ = 4;
      break;
    }
   case 4:
    var $t_1;
    var $17 = $t_1 + 2 | 0;
    if (HEAP16[$t_1 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $17;
      var $fixup_0 = 6;
      __label__ = 20;
      break;
    } else {
      var $t_2 = $17;
      __label__ = 5;
      break;
    }
   case 5:
    var $t_2;
    var $21 = $t_2 + 2 | 0;
    if (HEAP16[$t_2 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $21;
      var $fixup_0 = 5;
      __label__ = 20;
      break;
    } else {
      var $t_3 = $21;
      __label__ = 6;
      break;
    }
   case 6:
    var $t_3;
    var $25 = $t_3 + 2 | 0;
    if (HEAP16[$t_3 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $25;
      var $fixup_0 = 4;
      __label__ = 20;
      break;
    } else {
      var $t_4 = $25;
      __label__ = 7;
      break;
    }
   case 7:
    var $t_4;
    var $29 = $t_4 + 2 | 0;
    if (HEAP16[$t_4 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $29;
      var $fixup_0 = 3;
      __label__ = 20;
      break;
    } else {
      var $t_5 = $29;
      __label__ = 8;
      break;
    }
   case 8:
    var $t_5;
    var $33 = $t_5 + 2 | 0;
    if (HEAP16[$t_5 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $33;
      var $fixup_0 = 2;
      __label__ = 20;
      break;
    } else {
      var $t_6 = $33;
      __label__ = 9;
      break;
    }
   case 9:
    var $t_6;
    var $37 = $t_6 + 2 | 0;
    if (HEAP16[$t_6 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $37;
      var $fixup_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $t_7 = $37;
      __label__ = 10;
      break;
    }
   case 10:
    var $t_7;
    if (($t_7 | 0) == ($2 | 0)) {
      var $_0 = -1;
      __label__ = 23;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = $t_7 + 2 | 0;
    if (HEAP16[$t_7 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $44;
      var $fixup_0 = 8;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $t_7 + 4 | 0;
    if (HEAP16[$44 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $48;
      var $fixup_0 = 7;
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $52 = $t_7 + 6 | 0;
    if (HEAP16[$48 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $52;
      var $fixup_0 = 6;
      __label__ = 20;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = $t_7 + 8 | 0;
    if (HEAP16[$52 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $56;
      var $fixup_0 = 5;
      __label__ = 20;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $60 = $t_7 + 10 | 0;
    if (HEAP16[$56 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $60;
      var $fixup_0 = 4;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $64 = $t_7 + 12 | 0;
    if (HEAP16[$60 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $64;
      var $fixup_0 = 3;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $68 = $t_7 + 14 | 0;
    if (HEAP16[$64 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $68;
      var $fixup_0 = 2;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = $t_7 + 16 | 0;
    if (HEAP16[$68 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $72;
      var $fixup_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $t_7 = $72;
      __label__ = 10;
      break;
    }
   case 19:
    var $74 = $t_9 + 2 | 0;
    if (HEAP16[$t_9 >> 1] << 16 >> 16 == $3 << 16 >> 16) {
      var $t_8 = $74;
      var $fixup_0 = $83;
      __label__ = 20;
      break;
    } else {
      var $t_9 = $74;
      var $fixup_1 = $83;
      __label__ = 22;
      break;
    }
   case 20:
    var $fixup_0;
    var $t_8;
    var $77 = __ZN9ManualCmp5matchEPKtS1_S1_($4, $t_8, $5);
    if ($77) {
      __label__ = 21;
      break;
    } else {
      var $t_9 = $t_8;
      var $fixup_1 = $fixup_0;
      __label__ = 22;
      break;
    }
   case 21:
    var $_0 = ($t_8 - $6 >> 1) - 1 | 0;
    __label__ = 23;
    break;
   case 22:
    var $fixup_1;
    var $t_9;
    var $83 = $fixup_1 - 1 & 255;
    if ($83 << 24 >> 24 == 0) {
      var $t_7 = $t_9;
      __label__ = 10;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j["X"] = 1;

function __ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult($this, $cx, $str, $index, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $rval = __stackBase__ + 4;
    var $sep = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $index;
    __ZN2JSL14UndefinedValueEv3828($rval);
    var $3 = HEAP32[$this + 4 >> 2];
    var $4 = $this | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $str | 0;
    var $7 = $cx;
    var $8 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($3, $7, $5, $6, $1, 1, $rval);
    if ($8) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = __ZNK2JS5Value6isTrueEv($rval);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN16SplitMatchResult10setFailureEv($result);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $13 = HEAP32[$4 >> 2];
    __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($13, $sep);
    var $15 = HEAP32[$sep >> 2];
    var $16 = HEAP32[$1 >> 2];
    __ZN16SplitMatchResult9setResultEjj($result, $15, $16);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics10parenCountEv($this) {
  var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
  return $1 - 1 | 0;
}

function __ZNK2js13RegExpStatics13pairIsPresentEj($this, $pairNum) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
  return ($1 | 0) > -1;
}

function __ZNK2js13RegExpStatics8getParenEjP11JSSubString($this, $pairNum, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics13pairIsPresentEj($this, $pairNum);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $4$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $4$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$3 >> 2] = $4$0;
    HEAP32[$3 + 4 >> 2] = $4$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = HEAP32[$this + 92 >> 2];
    var $8 = __ZNK14JSLinearString5charsEv($7);
    var $9 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
    var $10 = $8 + ($9 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $10;
    var $12 = __ZNK2js13RegExpStatics14getParenLengthEj($this, $pairNum);
    HEAP32[$out >> 2] = $12;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE($cx, $obj, $name, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext20typeInferenceEnabledEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $obj;
    var $5 = __ZN2js5types10TypeObject17unknownPropertiesEv($4);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE($4, $1, $name, $value);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics14getParenLengthEj($this, $pairNum) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 1);
  var $2 = __ZNK2js13RegExpStatics3getEjb($this, $pairNum, 0);
  return $1 - $2 | 0;
}

function __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[$this + 92 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($8);
    var $10 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    var $11 = $9 + ($10 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $11;
    var $13 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $14 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    HEAP32[$out >> 2] = $13 - $14 | 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11RegExpGuardC1EP9JSContext($this, $cx) {
  __ZN11RegExpGuardC2EP9JSContext($this, $cx);
  return;
}

function __ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE($this, $flat, $optarg, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $re = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $this + 4 | 0;
    var $3 = __ZNK10RegExpPair9hasRegExpEv($2);
    if ($3) {
      var $_0 = $2;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($optarg >>> 0 < $argc >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $opt_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$this >> 2];
    var $10 = $vp + ($optarg + 2 << 3) | 0;
    var $11 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($8, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $opt_0 = $11;
      __label__ = 4;
      break;
    }
   case 4:
    var $opt_0;
    if ($flat) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = $this | 0;
    var $16 = HEAP32[$15 >> 2];
    var $18 = HEAP32[$this + 16 >> 2];
    var $19 = __ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString($16, $18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      var $patstr_0 = $19;
      var $_pre_phi = $15;
      __label__ = 7;
      break;
    }
   case 6:
    var $patstr_0 = HEAP32[$this + 16 >> 2] | 0;
    var $_pre_phi = $this | 0;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $patstr_0;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE($re, $27, $patstr_0, $opt_0, 0);
    var $28 = __ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev($re);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = HEAP32[$re >> 2];
    HEAP32[$1 >> 2] = $32;
    __ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE($2, $1);
    var $_0 = $2;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK10RegExpPair2reEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js12AutoRefCountINS_6RegExpEEdeEv($1);
  return $2;
}

function __ZNK2js13RegExpStatics10matchStartEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
  return $1;
}

function __ZN11RegExpGuardD1Ev($this) {
  __ZN11RegExpGuardD2Ev($this);
  return;
}

function __ZN11RegExpGuardD2Ev($this) {
  var $1 = $this + 4 | 0;
  __ZN10RegExpPairD1Ev($1);
  return;
}

function __ZN10RegExpPairD1Ev($this) {
  __ZN10RegExpPairD2Ev($this);
  return;
}

function __ZN10RegExpPairD2Ev($this) {
  var $1 = $this;
  __ZN2js12AutoRefCountINS_6RegExpEED1Ev($1);
  return;
}

function __ZNK10RegExpPair9hasRegExpEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js12AutoRefCountINS_6RegExpEE4nullEv($1);
  return $2 ^ 1;
}

function __ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString($cx, $patstr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sb = __stackBase__;
    var $1 = $sb;
    var $2 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($1, $2);
    var $3 = $patstr | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    var $5 = __ZN2js12StringBuffer7reserveEj($1, $4);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 2:
    var $7 = __ZNK14JSLinearString5charsEv($patstr);
    var $8 = __ZNK8JSString6lengthEv($3);
    var $9 = $7 + ($8 << 1) | 0;
    var $it_0 = $7;
    __label__ = 3;
    break;
   case 3:
    var $it_0;
    if (($it_0 | 0) == ($9 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP16[$it_0 >> 1];
    var $14 = __ZN2js6RegExp10isMetaCharEt($13);
    if ($14) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $16 = __ZN2js12StringBuffer6appendEt($1, 92);
    if ($16) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $18 = HEAP16[$it_0 >> 1];
    var $19 = __ZN2js12StringBuffer6appendEt($1, $18);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $21 = __ZN2js12StringBuffer6appendEt($1, $13);
    if ($21) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $it_0 = $it_0 + 2 | 0;
    __label__ = 3;
    break;
   case 9:
    var $25 = __ZN2js12StringBuffer12finishStringEv($sb);
    var $_0 = $25 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    __ZN2js12StringBufferD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE($this, $re) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $re;
  $re = STACKTOP;
  STACKTOP += 4;
  HEAP32[$re >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  HEAP32[$this + 8 >> 2] = 0;
  var $3 = $this | 0;
  var $5 = HEAP32[$re >> 2];
  HEAP32[$1 >> 2] = $5;
  __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE($this, $aobj) {
  var __stackBase__ = STACKTOP;
  var tempParam = $aobj;
  $aobj = STACKTOP;
  STACKTOP += 4;
  HEAP32[$aobj >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this >> 2];
    __ZN2js6RegExp6decrefEP9JSContext($2, $7);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv($aobj);
    HEAP32[$1 >> 2] = $9;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11RegExpGuardC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $2 = $this + 4 | 0;
  __ZN10RegExpPairC1EP9JSContext($2, $cx);
  var $3 = $this + 16 | 0;
  __ZN9FlatMatchC1Ev($3);
  return;
}

function __ZN10RegExpPairC1EP9JSContext($this, $cx) {
  __ZN10RegExpPairC2EP9JSContext($this, $cx);
  return;
}

function __ZN9FlatMatchC1Ev($this) {
  __ZN9FlatMatchC2Ev($this);
  return;
}

function __ZN10RegExpPairC2EP9JSContext($this, $cx) {
  var $1 = $this | 0;
  __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext($1, $cx);
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext($this, $cx) {
  __ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext($this, $cx);
  return;
}

function __ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE($cx, $textstr, $fm, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __ZNK9FlatMatch5matchEv($fm);
    if (($4 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value7setNullEv($vp);
    var $_0 = 1;
    __label__ = 7;
    break;
   case 3:
    var $8 = $cx;
    var $9 = __ZN2js17NewSlowEmptyArrayEP9JSContext($8);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $9;
    __ZN2JS5Value9setObjectER8JSObject($vp, $9);
    var $13 = __ZNK9FlatMatch7patternEv($fm);
    __ZN2JSL11StringValueEP8JSString3909($1, $13);
    var $14 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($12, $cx, 0, $1, 10, 12, 1);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = $cx + 52 | 0;
    var $21 = HEAP32[HEAP32[$17 >> 2] + 210232 >> 2] | 0;
    var $22 = __ZL12ATOM_TO_JSIDP6JSAtom3836($21);
    var $23 = __ZNK9FlatMatch5matchEv($fm);
    __ZN2JSL10Int32ValueEi3910($2, $23);
    var $24 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $8, $22, $2, 10, 12, 1);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $30 = HEAP32[HEAP32[$17 >> 2] + 210236 >> 2] | 0;
    var $31 = __ZL12ATOM_TO_JSIDP6JSAtom3836($30);
    __ZN2JSL11StringValueEP8JSString3909($3, $textstr);
    var $32 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($9, $8, $31, $3, 10, 12, 1);
    var $_0 = ($32 | 0) != 0;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE($cx, $res, $str, $rep, $callback, $data, $flags, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $i1 = __stackBase__ + 4;
    var $1 = __ZNK10RegExpPair2reEv($rep);
    var $2 = __ZNK2js6RegExp6globalEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $5 = ($flags & 1 | 0) != 0;
    var $6 = __ZNK10RegExpPair5reobjEv($rep);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $6;
    __ZN8JSObject19zeroRegExpLastIndexEv($9);
    __label__ = 4;
    break;
   case 4:
    HEAP32[$i >> 2] = 0;
    var $11 = __ZNK8JSString6lengthEv($str);
    var $12 = $cx;
    var $count_0 = 0;
    var $14 = 0;
    __label__ = 5;
    break;
   case 5:
    var $14;
    var $count_0;
    if ($14 >>> 0 > $11 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($1, $12, $res, $str, $i, $5, $rval);
    if ($17) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 7:
    var $19 = __ZL7MatchedbRKN2JS5ValueE($5, $rval);
    if ($19) {
      __label__ = 8;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 8:
    var $21 = FUNCTION_TABLE[$callback]($cx, $res, $count_0, $data);
    if ($21) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 9:
    var $23 = __ZNK2js13RegExpStatics7matchedEv($res);
    var $_pre_pre = HEAP32[$i >> 2];
    if ($23) {
      var $_pre = $_pre_pre;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = $_pre_pre + 1 | 0;
    HEAP32[$i >> 2] = $25;
    var $_pre = $25;
    __label__ = 11;
    break;
   case 11:
    var $_pre;
    var $count_0 = $count_0 + 1 | 0;
    var $14 = $_pre;
    __label__ = 5;
    break;
   case 12:
    var $29 = ($flags & 2 | 0) != 0;
    HEAP32[$i1 >> 2] = 0;
    var $30 = $cx;
    var $31 = __ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE($1, $30, $res, $str, $i1, $29, $rval);
    if ($31) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 13:
    if (($flags & 4 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $36 = __ZL7MatchedbRKN2JS5ValueE($29, $rval);
    if ($36) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $38 = FUNCTION_TABLE[$callback]($cx, $res, 0, $data);
    if ($38) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE["X"] = 1;

function __ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv($cx, $res, $count, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $p;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($5, 0);
    HEAP32[$1 >> 2] = $6;
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $cx;
    var $11 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $10, $v);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[$1 >> 2];
    var $14 = __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($13, $cx, $count, $v, 10, 12, 1);
    var $_0 = ($14 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($this, $cx, $index, $value, $getter, $setter, $attrs) {
  var $1 = $this;
  var $2 = __ZNK8JSObject6getOpsEv($1);
  var $4 = HEAP32[$2 + 24 >> 2];
  var $7 = ($4 | 0) != 0 ? $4 : 248;
  var $8 = FUNCTION_TABLE[$7]($cx, $this, $index, $value, $getter, $setter, $attrs);
  return $8;
}

function __ZL7MatchedbRKN2JS5ValueE($test, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($test) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $2 = __ZNK2JS5Value6isTrueEv($v);
    var $7 = $2;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZNK2JS5Value6isNullEv($v);
    var $7 = $4 ^ 1;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics7matchedEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
  var $2 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
  return ($1 - $2 | 0) > 0;
}

function __ZL13js_TrimStringP9JSContextPN2JS5ValueEii($cx, $vp, $trimLeft, $trimRight) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE($cx, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSString6lengthEv($1);
    var $5 = $cx;
    var $6 = __ZN8JSString8getCharsEP9JSContext($1, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($trimLeft | 0) == 0) {
      var $begin_1 = 0;
      __label__ = 7;
      break;
    } else {
      var $begin_0 = 0;
      __label__ = 4;
      break;
    }
   case 4:
    var $begin_0;
    if ($begin_0 >>> 0 < $4 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $begin_1 = $begin_0;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = HEAP16[$6 + ($begin_0 << 1) >> 1];
    var $14 = __ZN2js7unicode7IsSpaceEt($13);
    if ($14) {
      __label__ = 6;
      break;
    } else {
      var $begin_1 = $begin_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $begin_0 = $begin_0 + 1 | 0;
    __label__ = 4;
    break;
   case 7:
    var $begin_1;
    if (($trimRight | 0) == 0) {
      var $end_1 = $4;
      __label__ = 10;
      break;
    } else {
      var $end_0 = $4;
      __label__ = 8;
      break;
    }
   case 8:
    var $end_0;
    if ($end_0 >>> 0 > $begin_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $end_1 = $end_0;
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $end_0 - 1 | 0;
    var $22 = HEAP16[$6 + ($20 << 1) >> 1];
    var $23 = __ZN2js7unicode7IsSpaceEt($22);
    if ($23) {
      var $end_0 = $20;
      __label__ = 8;
      break;
    } else {
      var $end_1 = $end_0;
      __label__ = 10;
      break;
    }
   case 10:
    var $end_1;
    var $25 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($cx, $1, $begin_1, $end_1 - $begin_1 | 0);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = $25 | 0;
    __ZN2JS5Value9setStringEP8JSString($vp, $28);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18js_DoubleToIntegerd3931($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($d == 0) {
      var $_0 = $d;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL18JSDOUBLE_IS_FINITEd3932($d);
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $6 = __ZL15JSDOUBLE_IS_NaNd3930($d);
    var $d_ = ($6 | 0) == 0 ? $d : 0;
    var $_0 = $d_;
    __label__ = 7;
    break;
   case 4:
    if ($d < 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = _floor($d);
    var $_0 = $10;
    __label__ = 7;
    break;
   case 6:
    var $12 = -$d;
    var $13 = _floor($12);
    var $_0 = -$13;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11ReplaceDataD2Ev($this) {
  var $2 = $this + 96 | 0;
  __ZN2js12StringBufferD1Ev($2);
  var $4 = $this + 72 | 0;
  __ZN2js15InvokeArgsGuardD1Ev($4);
  var $5 = $this + 4 | 0;
  __ZN11RegExpGuardD1Ev($5);
  return;
}

function __ZN2js11RopeBuilderC1EP9JSContext($this, $cx) {
  __ZN2js11RopeBuilderC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringSegmentRangeC1EP9JSContext($this, $cx) {
  __ZN2js18StringSegmentRangeC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js18StringSegmentRange4initEP8JSString($this, $str) {
  var $1 = __ZN2js18StringSegmentRange6settleEP8JSString($this, $str);
  return $1;
}

function __ZN2js11RopeBuilder6appendEP8JSString($this, $str) {
  var $3 = $this + 4 | 0;
  var $4 = HEAP32[$3 >> 2];
  var $5 = HEAP32[$this >> 2];
  var $6 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($5, $4, $str);
  HEAP32[$3 >> 2] = $6;
  return ($6 | 0) != 0;
}

function __ZN2js18StringSegmentRange8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$this + 144 >> 2] = 0;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv($1);
    var $7 = __ZN2js18StringSegmentRange6settleEP8JSString($this, $6);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18StringSegmentRangeD1Ev($this) {
  __ZN2js18StringSegmentRangeD2Ev($this);
  return;
}

function __ZN2js18StringSegmentRangeD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev($1);
  return;
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv($this) {
  return (HEAP32[$this + 8 >> 2] | 0) == 0;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv($this) {
  var $1 = $this + 8 | 0;
  var $3 = HEAP32[$1 >> 2] - 1 | 0;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv($this) {
  return HEAP32[$this + 4 >> 2] + (HEAP32[$this + 8 >> 2] << 2) | 0;
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11RopeBuilderC2EP9JSContext($this, $cx) {
  HEAP32[$this >> 2] = $cx;
  var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
  HEAP32[$this + 4 >> 2] = $7;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js15TempAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this + 4 >> 2];
  var $3 = $this + 16 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj128EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js18StringSegmentRange6settleEP8JSString($this, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_01 = $str;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZNK8JSString6isRopeEv($_01);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = __ZN8JSString6asRopeEv($_01);
    var $6 = __ZNK6JSRope10rightChildEv($5);
    var $7 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_($1, $6);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $9 = __ZNK6JSRope9leftChildEv($5);
    var $_01 = $9;
    __label__ = 2;
    break;
   case 5:
    var $11 = __ZN8JSString8asLinearEv($_01);
    HEAP32[$this + 144 >> 2] = $11;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv($this) {
  var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv($this);
  var $2 = HEAP32[$1 >> 2];
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv($this);
  return $2;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv($this) {
  var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv($this);
  return $1 - 4 | 0;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 8 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 8 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = $this;
    var $8 = __ZN2js15TempAllocPolicy7malloc_Ej($7, $6);
    var $9 = $8;
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = __ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv($this);
    var $13 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($9, $12, $13);
    HEAP32[$this + 4 >> 2] = $9;
    HEAP32[$this + 12 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 8 >> 2];
    var $3 = __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($5);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $7 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $7;
    if ($7 >>> 0 > 536870911) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = $this;
    __ZNK2js15TempAllocPolicy19reportAllocOverflowEv($10);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v + 4 | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = $v;
    var $6 = __ZN2js15TempAllocPolicy8realloc_EPvjj($5, $4, undef, $1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $v + 12 | 0;
    var $10 = $6;
    HEAP32[$2 >> 2] = $10;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js18StringSegmentRangeC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $3 = $1;
  var $4 = $cx;
  __ZN2js15TempAllocPolicyC1EP9JSContext($3, $4);
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_($2, $1);
  HEAP32[$this + 144 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  var $4 = $this + 4 | 0;
  var $5 = $this + 16 | 0;
  var $6 = __ZN7mozilla14AlignedStorageILj128EE4addrEv($5);
  HEAP32[$4 >> 2] = $6;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 32;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12StringBuffer16infallibleAppendEPKtS2_($this, $begin, $end) {
  var $1 = $this | 0;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_($1, $begin, $end);
  return;
}

function __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_($this, $begin, $end) {
  var $4 = ($end - $begin | 0) >>> 1;
  var $5 = $this;
  __ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j($5, $begin, $4);
  return;
}

function __ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv($cx, $res, $count, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $replen = __stackBase__;
    var $1 = $p;
    HEAP8[$p + 68 | 0] = 1;
    var $4 = HEAP32[$p >> 2];
    var $5 = __ZN8JSString8asLinearEv($4);
    var $7 = $p + 56 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($5);
    var $10 = $9 + ($8 << 1) | 0;
    var $11 = __ZNK2js13RegExpStatics10matchStartEv($res);
    var $12 = $11 - $8 | 0;
    var $13 = __ZNK2js13RegExpStatics10matchLimitEv($res);
    HEAP32[$7 >> 2] = $13;
    HEAP32[$replen >> 2] = 0;
    var $14 = __ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj($cx, $res, $1, $replen);
    if ($14) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $16 = HEAP32[$replen >> 2];
    var $18 = $p + 96 | 0;
    var $19 = __ZNK2js12StringBuffer6lengthEv($18);
    var $21 = $16 + $12 + $19 | 0;
    var $22 = __ZN2js12StringBuffer7reserveEj($18, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js12StringBuffer16infallibleAppendEPKtj($18, $10, $12);
    __ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData($res, $1);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = $this + 92 | 0;
    var $8 = HEAP32[$7 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($8);
    var $10 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $11 = $9 + ($10 << 1) | 0;
    HEAP32[$out + 4 >> 2] = $11;
    var $14 = HEAP32[$7 >> 2] | 0;
    var $15 = __ZNK8JSString6lengthEv($14);
    var $16 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
    var $17 = $15 - $16 | 0;
    HEAP32[$out >> 2] = $17;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics10matchLimitEv($this) {
  var $1 = __ZNK2js13RegExpStatics3getEjb($this, 0, 1);
  return $1;
}

function __ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj($cx, $res, $rdata, $sizep) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 168;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $match = __stackBase__;
    var $holder = __stackBase__ + 8;
    var $prop = __stackBase__ + 12;
    var $value = __stackBase__ + 16;
    var $staticsGuard = __stackBase__ + 24;
    var $1 = __stackBase__ + 140;
    var $2 = __stackBase__ + 148;
    var $sub = __stackBase__ + 156;
    var $skip = __stackBase__ + 164;
    var $3 = $rdata + 40 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $cx;
    var $8 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $7, $match);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 0;
      __label__ = 35;
      break;
    }
   case 3:
    var $10 = __ZNK2JS5Value8toStringEv($match);
    var $11 = __ZNK8JSString6isAtomEv($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSString6asAtomEv($10);
    var $atom_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = $cx;
    var $16 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($15, $10, 0);
    if (($16 | 0) == 0) {
      var $_1 = 0;
      __label__ = 35;
      break;
    } else {
      var $atom_0 = $16;
      __label__ = 6;
      break;
    }
   case 6:
    var $atom_0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom3836($atom_0);
    HEAP32[$prop >> 2] = 0;
    var $20 = $cx;
    var $21 = $4;
    var $22 = $holder;
    var $23 = $prop;
    var $24 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($20, $21, $19, 1, $22, $23);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      var $_1 = 0;
      __label__ = 35;
      break;
    }
   case 7:
    var $26 = HEAP32[$prop >> 2];
    if (($26 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$holder >> 2] | 0) == ($4 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 9:
    var $34 = HEAP32[$26 + 24 >> 2];
    if (($34 | 0) == -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $37 = $26;
    var $38 = __ZNK2js5Shape16hasDefaultGetterEv($37);
    if ($38) {
      __label__ = 11;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 11:
    var $40 = $4;
    var $41 = __ZNK8JSObject7getSlotEj($40, $34);
    var $42 = $41 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $value | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $45 = __ZNK2JS5Value8isStringEv($value);
    if ($45) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $47 = __ZNK2JS5Value8toStringEv($value);
    var $48 = $cx;
    var $49 = __ZN8JSString12ensureLinearEP9JSContext($47, $48);
    HEAP32[$rdata + 44 >> 2] = $49;
    if (($49 | 0) == 0) {
      var $_1 = 0;
      __label__ = 35;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $53 = $49 | 0;
    var $54 = __ZNK8JSString6lengthEv($53);
    HEAP32[$sizep >> 2] = $54;
    var $_1 = 1;
    __label__ = 35;
    break;
   case 14:
    HEAP32[$3 >> 2] = 0;
    __label__ = 15;
    break;
   case 15:
    var $58 = HEAP32[$rdata + 36 >> 2];
    if (($58 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    __ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE($staticsGuard, $res);
    var $61 = __ZN2js21PreserveRegExpStatics4initEP9JSContext($staticsGuard, $cx);
    if ($61) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 17:
    var $63 = $rdata + 72 | 0;
    var $64 = $63;
    var $65 = __ZNK2js15InvokeArgsGuard6pushedEv($64);
    if ($65) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $67 = __ZNK2js13RegExpStatics10parenCountEv($res);
    var $68 = $67 + 3 | 0;
    var $70 = $cx + 60 | 0;
    var $71 = $cx;
    var $72 = $63;
    var $73 = __ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE($70, $71, $68, $72);
    if ($73) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 19:
    var $75 = $63 | 0;
    var $76 = __ZNK2js12CallReceiver7calleevEv($75);
    __ZN2JSL11ObjectValueER8JSObject3902($1, $58);
    var $77 = $1 | 0;
    var $78$0 = HEAP32[$77 >> 2];
    var $78$1 = HEAP32[$77 + 4 >> 2];
    var $79 = $76 | 0;
    HEAP32[$79 >> 2] = $78$0;
    HEAP32[$79 + 4 >> 2] = $78$1;
    var $80 = __ZNK2js12CallReceiver5thisvEv($75);
    __ZN2JSL14UndefinedValueEv3828($2);
    var $81 = $2 | 0;
    var $82$0 = HEAP32[$81 >> 2];
    var $82$1 = HEAP32[$81 + 4 >> 2];
    var $83 = $80 | 0;
    HEAP32[$83 >> 2] = $82$0;
    HEAP32[$83 + 4 >> 2] = $82$1;
    var $84 = $63 | 0;
    var $85 = __ZNK2js8CallArgsixEj($84, 0);
    var $86 = $cx;
    var $87 = __ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE($res, $86, $85);
    if ($87) {
      var $i_0 = 0;
      var $argi_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 20:
    var $argi_0;
    var $i_0;
    var $88 = __ZNK2js13RegExpStatics10parenCountEv($res);
    if ($i_0 >>> 0 < $88 >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $91 = $i_0 + 1 | 0;
    var $92 = __ZNK2js8CallArgsixEj($84, $argi_0);
    var $93 = __ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE($res, $86, $91, $92);
    if ($93) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 22:
    var $i_0 = $91;
    var $argi_0 = $argi_0 + 1 | 0;
    __label__ = 20;
    break;
   case 23:
    var $97 = $argi_0 + 1 | 0;
    var $98 = __ZNK2js8CallArgsixEj($84, $argi_0);
    var $99 = __ZNK2js13RegExpStatics10matchStartEv($res);
    __ZN2JS5Value8setInt32Ei($98, $99);
    var $100 = __ZNK2js8CallArgsixEj($84, $97);
    var $102 = HEAP32[$rdata >> 2];
    __ZN2JS5Value9setStringEP8JSString($100, $102);
    var $103 = $cx;
    var $104 = __ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE($103, $64, 0);
    if ($104) {
      __label__ = 24;
      break;
    } else {
      var $_0 = 0;
      __label__ = 27;
      break;
    }
   case 24:
    var $106 = __ZNK2js12CallReceiver4rvalEv($75);
    var $107 = __ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE($cx, $106);
    if (($107 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $110 = __ZN8JSString12ensureLinearEP9JSContext($107, $103);
    HEAP32[$rdata + 44 >> 2] = $110;
    if (($110 | 0) == 0) {
      var $_0 = 0;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $114 = $110 | 0;
    var $115 = __ZNK8JSString6lengthEv($114);
    HEAP32[$sizep >> 2] = $115;
    var $_0 = 1;
    __label__ = 27;
    break;
   case 27:
    var $_0;
    __ZN2js21PreserveRegExpStaticsD1Ev($staticsGuard);
    var $_1 = $_0;
    __label__ = 35;
    break;
   case 28:
    var $119 = HEAP32[$rdata + 44 >> 2] | 0;
    var $120 = __ZNK8JSString6lengthEv($119);
    var $122 = HEAP32[$rdata + 48 >> 2];
    var $124 = HEAP32[$rdata + 52 >> 2];
    if (($122 | 0) == 0) {
      var $replen_0_lcssa = $120;
      __label__ = 34;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $126 = $sub | 0;
    var $replen_02 = $120;
    var $dp_03 = $122;
    __label__ = 30;
    break;
   case 30:
    var $dp_03;
    var $replen_02;
    var $128 = __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp_03, $124, $rdata, $sub, $skip);
    if ($128) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $131 = HEAP32[$skip >> 2];
    var $dp_1 = $dp_03 + ($131 << 1) | 0;
    var $replen_1 = HEAP32[$126 >> 2] + $replen_02 - $131 | 0;
    __label__ = 33;
    break;
   case 32:
    var $dp_1 = $dp_03 + 2 | 0;
    var $replen_1 = $replen_02;
    __label__ = 33;
    break;
   case 33:
    var $replen_1;
    var $dp_1;
    var $138 = __Z15js_strchr_limitPKttS0_($dp_1, 36, $124);
    if (($138 | 0) == 0) {
      var $replen_0_lcssa = $replen_1;
      __label__ = 34;
      break;
    } else {
      var $replen_02 = $replen_1;
      var $dp_03 = $138;
      __label__ = 30;
      break;
    }
   case 34:
    var $replen_0_lcssa;
    HEAP32[$sizep >> 2] = $replen_0_lcssa;
    var $_1 = 1;
    __label__ = 35;
    break;
   case 35:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj["X"] = 1;

function __ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData($res, $rdata) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sub = __stackBase__;
    var $skip = __stackBase__ + 8;
    var $2 = HEAP32[$rdata + 44 >> 2];
    var $3 = __ZNK14JSLinearString5charsEv($2);
    var $5 = HEAP32[$rdata + 48 >> 2];
    var $7 = HEAP32[$rdata + 52 >> 2];
    var $_pre1 = $rdata + 96 | 0;
    if (($5 | 0) == 0) {
      var $cp_0_lcssa = $3;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $sub | 0;
    var $10 = $sub + 4 | 0;
    var $cp_01 = $3;
    var $dp_02 = $5;
    __label__ = 3;
    break;
   case 3:
    var $dp_02;
    var $cp_01;
    __ZN2js12StringBuffer16infallibleAppendEPKtj($_pre1, $cp_01, $dp_02 - $cp_01 >> 1);
    var $16 = __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp_02, $7, $rdata, $sub, $skip);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = HEAP32[$9 >> 2];
    var $19 = HEAP32[$10 >> 2];
    __ZN2js12StringBuffer16infallibleAppendEPKtj($_pre1, $19, $18);
    var $21 = $dp_02 + (HEAP32[$skip >> 2] << 1) | 0;
    var $dp_1 = $21;
    var $cp_1 = $21;
    __label__ = 6;
    break;
   case 5:
    var $dp_1 = $dp_02 + 2 | 0;
    var $cp_1 = $dp_02;
    __label__ = 6;
    break;
   case 6:
    var $cp_1;
    var $dp_1;
    var $25 = __Z15js_strchr_limitPKttS0_($dp_1, 36, $7);
    if (($25 | 0) == 0) {
      var $cp_0_lcssa = $cp_1;
      var $_pre_phi2 = $_pre1;
      __label__ = 7;
      break;
    } else {
      var $cp_01 = $cp_1;
      var $dp_02 = $25;
      __label__ = 3;
      break;
    }
   case 7:
    var $_pre_phi2;
    var $cp_0_lcssa;
    var $27 = $2 | 0;
    var $28 = __ZNK8JSString6lengthEv($27);
    var $33 = $28 - ($cp_0_lcssa - $3 >> 1) | 0;
    var $34 = __ZN2js12StringBuffer6appendEPKtj($_pre_phi2, $cp_0_lcssa, $33);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj($res, $dp, $ep, $rdata, $out, $skip) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $dp + 2 | 0;
    if ($1 >>> 0 < $ep >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 2:
    var $5 = HEAPU16[$1 >> 1] & 65535;
    var $6 = $5 - 48 | 0;
    if ($6 >>> 0 < 10) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $9 = __ZNK2js13RegExpStatics10parenCountEv($res);
    if ($6 >>> 0 > $9 >>> 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $dp + 4 | 0;
    if ($12 >>> 0 < $ep >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    }
   case 5:
    var $16 = HEAPU16[$12 >> 1] & 65535;
    if (($16 - 48 | 0) >>> 0 < 10) {
      __label__ = 6;
      break;
    } else {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $6 * 10 - 48 + $16 | 0;
    if ($22 >>> 0 > $9 >>> 0) {
      var $cp_0 = $12;
      var $num_0 = $6;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $cp_0 = $dp + 6 | 0;
    var $num_0 = $22;
    __label__ = 8;
    break;
   case 8:
    var $num_0;
    var $cp_0;
    if (($num_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$skip >> 2] = $cp_0 - $dp >> 1;
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($res, $num_0, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 10:
    HEAP32[$skip >> 2] = 2;
    if (($5 | 0) == 36) {
      __label__ = 11;
      break;
    } else if (($5 | 0) == 38) {
      __label__ = 12;
      break;
    } else if (($5 | 0) == 43) {
      __label__ = 13;
      break;
    } else if (($5 | 0) == 96) {
      __label__ = 14;
      break;
    } else if (($5 | 0) == 39) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 11:
    var $35 = $rdata + 60 | 0;
    HEAP32[$rdata + 64 >> 2] = $dp;
    HEAP32[$35 >> 2] = 1;
    var $38 = $35;
    var $39 = $out;
    var $40$0 = HEAP32[$38 >> 2];
    var $40$1 = HEAP32[$38 + 4 >> 2];
    HEAP32[$39 >> 2] = $40$0;
    HEAP32[$39 + 4 >> 2] = $40$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 12:
    __ZNK2js13RegExpStatics12getLastMatchEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 13:
    __ZNK2js13RegExpStatics12getLastParenEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 14:
    __ZNK2js13RegExpStatics14getLeftContextEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 15:
    __ZNK2js13RegExpStatics15getRightContextEP11JSSubString($res, $out);
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj["X"] = 1;

function __ZNK2js13RegExpStatics12getLastParenEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if ($1 >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $7 = $1 - 1 | 0;
    __ZNK2js13RegExpStatics8getParenEjP11JSSubString($this, $7, $out);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js13RegExpStatics14getLeftContextEP11JSSubString($this, $out) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js13RegExpStatics9pairCountEv($this);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $out;
    var $$emscripten$temp$0 = _js_EmptySubString;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$4 >> 2] = $5$0;
    HEAP32[$4 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 3:
    var $8 = HEAP32[$this + 92 >> 2];
    var $9 = __ZNK14JSLinearString5charsEv($8);
    HEAP32[$out + 4 >> 2] = $9;
    var $11 = __ZNK2js13RegExpStatics3getEjb($this, 0, 0);
    HEAP32[$out >> 2] = $11;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE($this, $original) {
  __ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE($this, $original);
  return;
}

function __ZN2js21PreserveRegExpStatics4initEP9JSContext($this, $cx) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 4 | 0;
  var $4 = __ZN2js13RegExpStatics4saveEP9JSContextPS0_($2, $cx, $3);
  return $4;
}

function __ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isStringEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toStringEv($v);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($cx, $v);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsD1Ev($this) {
  __ZN2js21PreserveRegExpStaticsD2Ev($this);
  return;
}

function __ZN2js21PreserveRegExpStaticsD2Ev($this) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js13RegExpStatics7restoreEv($2);
  var $3 = $this + 4 | 0;
  __ZN2js13RegExpStaticsD1Ev($3);
  return;
}

function __ZN2js13RegExpStatics7restoreEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    if ((HEAP8[$2 + 108 | 0] & 1) << 24 >> 24 == 0) {
      var $11 = $2;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $2;
    var $9 = $this;
    __ZN2js13RegExpStatics6copyToERS0_($8, $9);
    var $11 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    var $13 = HEAP32[$11 + 104 >> 2];
    HEAP32[$1 >> 2] = $13;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13RegExpStatics4saveEP9JSContextPS0_($this, $cx, $buffer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 104 | 0;
    var $2 = HEAP32[$1 >> 2];
    HEAP32[$buffer + 104 >> 2] = $2;
    HEAP32[$1 >> 2] = $buffer;
    var $4 = $buffer | 0;
    var $5 = $this | 0;
    var $6 = __ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv($5);
    var $7 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj($4, $6);
    if ($7) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx;
    __Z20js_ReportOutOfMemoryP9JSContext($9);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj($this, $request) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$this + 8 >> 2] >>> 0 < $request >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $request - HEAP32[$this + 4 >> 2] | 0;
    var $8 = __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj($this, $7);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE($this, $original) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = $original;
  var $3 = $this + 4 | 0;
  __ZN2js13RegExpStaticsC1ENS0_10InitBufferE($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js13RegExpStaticsC1ENS0_10InitBufferE($this, $0) {
  var __stackBase__ = STACKTOP;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$0] = HEAP8[tempParam];
  __ZN2js13RegExpStaticsC2ENS0_10InitBufferE($this, $0);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js13RegExpStaticsC2ENS0_10InitBufferE($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$0] = HEAP8[tempParam];
  var $2 = __stackBase__;
  var $3 = $this | 0;
  __ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_($3, $2);
  HEAP32[$this + 104 >> 2] = 0;
  HEAP8[$this + 108 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11ArrayBufferD2Ev($this) {
  return;
}

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_0_0_val) {
  return $sid_0_0_val;
}

function _JSID_TO_INT3948($iden) {
  return $iden >> 1;
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this) {
  return HEAP32[$this >> 2] + (HEAP32[$this + 4 >> 2] << 2) | 0;
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($srcbeg | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $srcbeg;
      var $_02 = $dst;
      __label__ = 2;
      break;
    }
   case 2:
    var $_02;
    var $p_01;
    var $2 = HEAP32[$p_01 >> 2];
    HEAP32[$_02 >> 2] = $2;
    var $3 = $p_01 + 4 | 0;
    if (($3 | 0) == ($srcend | 0)) {
      __label__ = 3;
      break;
    } else {
      var $p_01 = $3;
      var $_02 = $_02 + 4 | 0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject8setClassEPN2js5ClassE($this, $c) {
  HEAP32[$this + 4 >> 2] = $c;
  return;
}

function __ZN2js6RegExp12hasMetaCharsEPKtj($chars, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $length >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $5 = HEAP16[$chars + ($i_0 << 1) >> 1];
    var $6 = __ZN2js6RegExp10isMetaCharEt($5);
    if ($6) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9RopeMatchP9JSContextP8JSStringPKtjPi($cx, $textstr, $pat, $patlen, $match) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 228;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $strs = __stackBase__;
    var $1 = __stackBase__ + 76;
    var $r = __stackBase__ + 80;
    if (($patlen | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$match >> 2] = 0;
    var $_2 = 1;
    __label__ = 33;
    break;
   case 3:
    var $5 = __ZNK8JSString6lengthEv($textstr);
    if ($5 >>> 0 < $patlen >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$match >> 2] = -1;
    var $_2 = 1;
    __label__ = 33;
    break;
   case 5:
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_($strs, $1);
    var $9 = __ZNK8JSString6lengthEv($textstr);
    __ZN2js18StringSegmentRangeC1EP9JSContext($r, $cx);
    var $10 = __ZN2js18StringSegmentRange4initEP8JSString($r, $textstr);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $threshold_0 = $9 >>> 5;
    __label__ = 7;
    break;
   case 7:
    var $threshold_0;
    var $13 = __ZNK2js18StringSegmentRange5emptyEv($r);
    if ($13) {
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = $threshold_0 - 1 | 0;
    if (($threshold_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZNK2js18StringSegmentRange5frontEv($r);
    var $19 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($strs, $18);
    if ($19) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $21 = $cx;
    var $22 = __ZN8JSString8getCharsEP9JSContext($textstr, $21);
    if (($22 | 0) == 0) {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $25 = __ZL11StringMatchPKtjS0_j($22, $9, $pat, $patlen);
    HEAP32[$match >> 2] = $25;
    var $_0_ph = 1;
    __label__ = 13;
    break;
   case 12:
    var $27 = __ZN2js18StringSegmentRange8popFrontEv($r);
    if ($27) {
      var $threshold_0 = $15;
      __label__ = 7;
      break;
    } else {
      var $_0_ph = 0;
      __label__ = 13;
      break;
    }
   case 13:
    var $_0_ph;
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $_1 = $_0_ph;
    __label__ = 32;
    break;
   case 14:
    __ZN2js18StringSegmentRangeD1Ev($r);
    var $29 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv($strs);
    var $30 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv($strs);
    var $31 = $pat + ($patlen << 1) | 0;
    var $32 = 1 - $patlen | 0;
    var $outerp_0 = $29;
    var $pos_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $pos_0;
    var $outerp_0;
    if (($outerp_0 | 0) == ($30 | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $36 = HEAP32[$outerp_0 >> 2];
    var $37 = __ZNK14JSLinearString5charsEv($36);
    var $38 = $36 | 0;
    var $39 = __ZNK8JSString6lengthEv($38);
    var $40 = __ZL11StringMatchPKtjS0_j($37, $39, $pat, $patlen);
    if (($40 | 0) == -1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $43 = $40 + $pos_0 | 0;
    HEAP32[$match >> 2] = $43;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 18:
    var $_ = $39 >>> 0 < $patlen >>> 0 ? 0 : $32 + $39 | 0;
    var $48 = $37 + ($39 << 1) | 0;
    var $49 = HEAP16[$pat >> 1];
    var $t_0_ph = $37 + ($_ << 1) | 0;
    var $innerp_0_ph = $outerp_0;
    __label__ = 19;
    break;
   case 19:
    var $innerp_0_ph;
    var $t_0_ph;
    var $t_0 = $t_0_ph;
    __label__ = 20;
    break;
   case 20:
    var $t_0;
    if (($t_0 | 0) == ($48 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $53 = $t_0 + 2 | 0;
    if (HEAP16[$t_0 >> 1] << 16 >> 16 == $49 << 16 >> 16) {
      var $tt_0 = $53;
      var $pat_pn = $pat;
      var $ttend_0 = $48;
      var $innerp_1 = $innerp_0_ph;
      __label__ = 22;
      break;
    } else {
      var $t_0 = $53;
      __label__ = 20;
      break;
    }
   case 22:
    var $innerp_1;
    var $ttend_0;
    var $pat_pn;
    var $tt_0;
    var $pp_0 = $pat_pn + 2 | 0;
    if (($pp_0 | 0) == ($31 | 0)) {
      __label__ = 29;
      break;
    } else {
      var $tt_1 = $tt_0;
      var $ttend_1 = $ttend_0;
      var $innerp_2 = $innerp_1;
      __label__ = 23;
      break;
    }
   case 23:
    var $innerp_2;
    var $ttend_1;
    var $tt_1;
    if (($tt_1 | 0) == ($ttend_1 | 0)) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $59 = $innerp_2 + 4 | 0;
    var $60 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv($strs);
    if (($59 | 0) == ($60 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$match >> 2] = -1;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 26:
    var $64 = HEAP32[$59 >> 2];
    var $65 = __ZNK14JSLinearString5charsEv($64);
    var $66 = $64 | 0;
    var $67 = __ZNK8JSString6lengthEv($66);
    var $tt_1 = $65;
    var $ttend_1 = $65 + ($67 << 1) | 0;
    var $innerp_2 = $59;
    __label__ = 23;
    break;
   case 27:
    if (HEAP16[$pp_0 >> 1] << 16 >> 16 == HEAP16[$tt_1 >> 1] << 16 >> 16) {
      __label__ = 28;
      break;
    } else {
      var $t_0_ph = $53;
      var $innerp_0_ph = $innerp_2;
      __label__ = 19;
      break;
    }
   case 28:
    var $tt_0 = $tt_1 + 2 | 0;
    var $pat_pn = $pp_0;
    var $ttend_0 = $ttend_1;
    var $innerp_1 = $innerp_2;
    __label__ = 22;
    break;
   case 29:
    var $81 = $pos_0 - 1 + ($53 - $37 >> 1) | 0;
    HEAP32[$match >> 2] = $81;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 30:
    var $83 = $39 + $pos_0 | 0;
    var $outerp_0 = $outerp_0 + 4 | 0;
    var $pos_0 = $83;
    __label__ = 15;
    break;
   case 31:
    HEAP32[$match >> 2] = -1;
    var $_1 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_1;
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev($strs);
    var $_2 = $_1;
    __label__ = 33;
    break;
   case 33:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9RopeMatchP9JSContextP8JSStringPKtjPi["X"] = 1;

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 8 >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj($this, 1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev($this) {
  __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev($this);
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $4 = $3;
    __ZN2js17SystemAllocPolicy5free_EPv(undef, $4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = $this + 12 | 0;
  var $4 = __ZNK7mozilla14AlignedStorageILj64EE4addrEv($3);
  return ($2 | 0) == ($4 | 0);
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj($this, $incr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $incr);
    var $7 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $incr);
    var $7 = $5;
    __label__ = 4;
    break;
   case 4:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_($this, $t) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $t;
    __label__ = 3;
    break;
   case 3:
    var $5 = $this + 4 | 0;
    var $7 = HEAP32[$5 >> 2] + 1 | 0;
    HEAP32[$5 >> 2] = $7;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = $5 << 2;
    var $7 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $6);
    var $8 = $7;
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv($this);
    var $12 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv($this);
    __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($8, $11, $12);
    HEAP32[$this >> 2] = $8;
    HEAP32[$this + 8 >> 2] = $5;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj($this, $lengthInc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $newCap = __stackBase__;
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj(undef, $2, $lengthInc, $newCap);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$newCap >> 2];
    var $6 = __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($this, $5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj($this, $curLength, $lengthInc, $newCap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $uadd = _llvm_uadd_with_overflow_i32($curLength, $lengthInc);
    var $1 = $uadd.f0;
    var $2 = $uadd.f1;
    if ($2 | $1 >>> 0 > 536870911) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZN2js11RoundUpPow2Ej($1);
    HEAP32[$newCap >> 2] = $5;
    if ($5 >>> 0 > 536870911) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj($v, $newcap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $newcap << 2;
    var $2 = $v | 0;
    var $4 = HEAP32[$2 >> 2];
    var $5 = __ZN2js17SystemAllocPolicy8realloc_EPvjj(undef, $4, undef, $1);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    var $9 = $v + 8 | 0;
    HEAP32[$2 >> 2] = $8;
    HEAP32[$9 >> 2] = $newcap;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend) {
  __ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_($dst, $srcbeg, $srcend);
  return;
}

function __ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 1;
  STACKTOP = STACKTOP + 3 >> 2 << 2;
  HEAP8[$ap] = HEAP8[tempParam];
  var $1 = $this | 0;
  var $2 = $this + 12 | 0;
  var $3 = __ZN7mozilla14AlignedStorageILj64EE4addrEv($2);
  HEAP32[$1 >> 2] = $3;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 16;
  STACKTOP = __stackBase__;
  return;
}

function __ZN10RegExpPair5resetER8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$this + 8 >> 2] = $obj;
  var $3 = $obj;
  var $4 = __ZN2js6RegExp11extractFromEP8JSObject($3);
  var $5 = $this | 0;
  __ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_($1, $4);
  __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE($5, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE($this, $aobj) {
  var __stackBase__ = STACKTOP;
  var tempParam = $aobj;
  $aobj = STACKTOP;
  STACKTOP += 4;
  HEAP32[$aobj >> 2] = HEAP32[tempParam >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 4 | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this >> 2];
    __ZN2js6RegExp6decrefEP9JSContext($2, $7);
    __label__ = 3;
    break;
   case 3:
    var $9 = __ZNK2js11NeedsIncRefINS_6RegExpEE3getEv($aobj);
    HEAP32[$1 >> 2] = $9;
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6RegExp6increfEP9JSContext($9, undef);
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11ReplaceDataC2EP9JSContext($this, $cx) {
  var $1 = $this + 4 | 0;
  __ZN11RegExpGuardC1EP9JSContext($1, $cx);
  var $3 = $this + 72 | 0;
  __ZN2js15InvokeArgsGuardC1Ev($3);
  var $5 = $this + 96 | 0;
  var $6 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($5, $6);
  return;
}

function __ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938($cx, $obj, $methodid) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $obj;
    var $3 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($1, $2, $methodid, $v);
    if ($3) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $obj;
    var $6 = __ZNK8JSObject8getProtoEv($5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject8getClassEv($6);
    if (($9 | 0) == (__ZN2js11StringClassE | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $12 = $6;
    var $13 = __ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE($1, $12, $methodid, $v);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $15 = __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939($v);
    var $_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939($v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $fun = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940($v, $fun);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$fun >> 2];
    var $5 = __ZNK10JSFunction11maybeNativeEv($4);
    var $8 = ($5 | 0) == 192;
    __label__ = 3;
    break;
   case 3:
    var $8;
    STACKTOP = __stackBase__;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940($v, $fun) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $funobj = __stackBase__;
  var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941($v, $funobj, $fun);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941($v, $funobj, $fun) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942($v, $funobj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$funobj >> 2];
    var $5 = __ZNK8JSObject18getFunctionPrivateEv($4);
    var $6 = $5;
    HEAP32[$fun >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    return $1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942($v, $funobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    HEAP32[$funobj >> 2] = $3;
    var $5 = __ZNK8JSObject10isFunctionEv($3);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_0;
    if (($_0 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $4 = __Z16js_IsArrayBufferP8JSObject($_0);
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK8JSObject8getProtoEv($_0);
    var $_0 = $7;
    __label__ = 2;
    break;
   case 5:
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z16js_IsArrayBufferP8JSObject($obj) {
  var $1 = __ZNK8JSObject13isArrayBufferEv($obj);
  return $1 & 1;
}

function __ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value8setInt32Ei($vp, 0);
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($1);
    __ZN2JS5Value8setInt32Ei($vp, $5);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nbytes = __stackBase__;
    HEAP32[$nbytes >> 2] = 0;
    if (($argc | 0) == 0) {
      var $6 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $vp + 16 | 0;
    var $4 = __ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi($cx, $3, $nbytes);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $6 = HEAP32[$nbytes >> 2];
    __label__ = 4;
    break;
   case 4:
    var $6;
    var $7 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setObjectER8JSObject($vp, $7);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $nbytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js11ArrayBuffer9slowClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($nbytes | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 152, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    __ZN8JSObject21setSharedNonNativeMapEv($1);
    __ZN8JSObject8setClassEPN2js5ClassE($1, __ZN2js16ArrayBufferClassE);
    var $7 = __ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj($1, $cx, $nbytes);
    var $_ = $7 ? $1 : 0;
    var $_0 = $_;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj($this, $cx, $size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $size + 8 | 0;
    if ($size >>> 0 > 120) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN9JSContext7calloc_Ej($cx, $1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    HEAP32[$this + 32 >> 2] = $7;
    HEAP32[$this + 28 >> 2] = $1 >>> 3;
    var $16 = $7;
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK8JSObject10fixedSlotsEv($this);
    var $13 = $this + 32 | 0;
    HEAP32[$13 >> 2] = $12;
    var $14 = $12;
    _memset($14, 0, $1, 1);
    var $16 = HEAP32[$13 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $16;
    HEAP32[$16 >> 2] = $size;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4033($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041($cx, $clasp, $5);
  return $6;
}

function __ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $4, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    var $9 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    HEAP32[$objp >> 2] = $9;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $11 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($11, $cx, $id, $objp, $propp);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$objp >> 2] | 0) == ($11 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 7:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 8:
    var $24 = __ZNK8JSObject8getProtoEv($obj);
    if (($24 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $28 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($24, $cx, $id, $objp, $propp);
    var $_0 = $28;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $atom) {
  var $1 = __ZL12ATOM_TO_JSIDP6JSAtom3984($atom);
  return ($1 | 0) == ($id | 0) & 1;
}

function __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getPrivateEv($obj);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject8getProtoEv($obj);
    var $5 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032($cx, $4);
    var $6 = $5;
    __ZN8JSObject10setPrivateEPv($obj, $6);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($1, $cx, $index, $objp, $propp);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$propp >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$objp >> 2] | 0) == ($1 | 0)) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 6:
    var $14 = __ZNK8JSObject8getProtoEv($obj);
    if (($14 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($14, $cx, $index, $objp, $propp);
    var $_0 = $17;
    __label__ = 9;
    break;
   case 8:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $9 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $cx;
    var $13 = $9;
    var $14 = $getter;
    var $15 = $setter;
    var $16 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($12, $13, $id, $v, $14, $15, $attrs);
    var $_0 = $16;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = $getter;
    var $7 = $setter;
    var $8 = __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($4, $5, $index, $v, $6, $7, $attrs);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, $getter, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN8JSObject21arrayBufferByteLengthEv($1);
    __ZN2JS5Value8setInt32Ei($vp, $10);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $12 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $cx;
    var $16 = $12;
    var $17 = $receiver;
    var $18 = __Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE($15, $16, $17, $id, $vp);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL12ATOM_TO_JSIDP6JSAtom3984($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj4031($1);
  return $2;
}

function __ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js11ArrayBuffer14getArrayBufferEP8JSObject($obj);
    var $2 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $2;
    var $7 = $receiver;
    var $8 = __Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($5, $6, $7, $index, $vp);
    var $_0 = $8;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  HEAP32[$attrsp >> 2] = 5;
  return 1;
}

function __ZN2js10TypedArray10dataOffsetEv() {
  return 24;
}

function __ZN8JSObject18getFixedSlotOffsetEj($slot) {
  return ($slot << 3) + 40 | 0;
}

function __Z32js_TypedArray_uint8_clamp_doubled($x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x < 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($x > 255) {
      var $_0 = 255;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = $x + .5;
    var $6 = $5 >= 0 ? Math.floor($5) : Math.ceil($5);
    var $7 = $6 & 255;
    if (($7 | 0) == $5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $7;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = $7 & 254;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15JSDOUBLE_IS_NaNd3989($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) == 0 && (tempDoubleI32[1] & 2146959360) == 2146959360) & 1;
}

function __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $5 = HEAP32[$2 + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 10;
      break;
    }
   case 2:
    var $11 = HEAP32[$2 + 210292 >> 2] | 0;
    var $12 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $11);
    var $13 = ($12 | 0) == 0;
    var $14 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    var $15 = ($14 | 0) == 0;
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($15) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = __ZNK8JSObject8getProtoEv($14);
    var $19 = $cx;
    var $20 = $14;
    var $21 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($19, $20, $id, 0, $vp, $strict);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZNK8JSObject8getProtoEv($14);
    if (($24 | 0) == ($18 | 0)) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = __ZNK2JS5Value14toObjectOrNullEv($vp);
    var $28 = $obj;
    var $29 = $27;
    var $30 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($19, $28, $29, 1);
    if ($30) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = $18;
    var $33 = __ZN2js8SetProtoEP9JSContextP8JSObjectS3_b($19, $20, $32, 1);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    if ($15) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = $cx;
    var $37 = $14;
    var $38 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($36, $37, $id, 0, $vp, $strict);
    var $_0 = $38;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi($4, $5, $index, 0, $vp, $strict);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$attrsp >> 2] = 6;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z16js_GetAttributesP9JSContextP8JSObjectiPj($13, $14, $id, $attrsp);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj($4, $5, $index, $attrsp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z16js_SetAttributesP9JSContextP8JSObjectiPj($13, $14, $id, $attrsp);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj($4, $5, $index, $attrsp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210484 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 3:
    var $10 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $cx;
    var $14 = $10;
    var $15 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($13, $14, $id, $rval, $strict);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL14DelegateObjectP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $cx;
    var $5 = $1;
    var $6 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($4, $5, $index, $rval, $strict);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  __ZN2JS5Value7setNullEv($statep);
  return 1;
}

function __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z15js_IsTypedArrayP8JSObject($obj);
    if (($1 | 0) == 0) {
      var $_01 = $obj;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $obj;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $3 = __ZNK8JSObject8getProtoEv($_01);
    var $4 = __Z15js_IsTypedArrayP8JSObject($3);
    if (($4 | 0) == 0) {
      var $_01 = $3;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_0_lcssa;
    return $_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_IsTypedArrayP8JSObject($obj) {
  var $1 = __ZNK8JSObject8getClassEv($obj);
  var $2 = __ZN2js21IsFastTypedArrayClassEPKNS_5ClassE($1);
  return $2 & 1;
}

function __ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE(undef, $obj, undef, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z14getBufferValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK8JSObject8getProtoEv($_01);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE(undef, $obj, undef, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z18getByteOffsetValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK8JSObject8getProtoEv($_01);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE(undef, $obj, undef, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z18getByteLengthValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK8JSObject8getProtoEv($_01);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var $1 = __ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE(undef, $obj, undef, $vp);
  return 1;
}

function __ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $_01 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __Z15js_IsTypedArrayP8JSObject($_01);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($_01);
    if (($6 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __Z14getLengthValueP8JSObject($1, $6);
    var $9 = $1 | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $vp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZNK8JSObject8getProtoEv($_01);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_01 = $13;
      __label__ = 2;
      break;
    }
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, 0);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $5 = __ZNK8JSObject8getProtoEv($obj);
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $9 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($5, $cx, $id, $objp, $propp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj($cx, $obj, $id, $ip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __Z12js_IdIsIndexiPj($id, $index);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAPU32[$index >> 2];
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($obj);
    if ($4 >>> 0 < $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if (($ip | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$ip >> 2] = $4;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$propp >> 2] = 1;
    HEAP32[$objp >> 2] = $obj;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty($6, $cx, $index, $objp, $propp);
    var $_0 = $9;
    __label__ = 6;
    break;
   case 5:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
  var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
  var $8 = ($6 | 0) != 0 ? 6 : 5;
  HEAP32[$attrsp >> 2] = $8;
  return 1;
}

function __ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj($cx, undef, $1, $attrsp);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  _JS_ReportErrorNumber($cx, 2, 0, 225, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $1 = __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj($cx, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 0;
}

function __ZN2js10TypedArray12lengthOffsetEv() {
  var $1 = __ZN8JSObject18getFixedSlotOffsetEj(0);
  return $1;
}

function __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj($tarray, $index);
  __ZN2JS5Value8setInt32Ei($vp, $1);
  return;
}

function __ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = __ZN2JS5Value9setNumberEj($vp, $1);
  return;
}

function __ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = $1;
  var $3 = __ZL15JSDOUBLE_IS_NaNd3989($2);
  var $4 = ($3 | 0) == 0;
  var $5 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  var $dval_0 = $4 ? $2 : $5;
  __ZN2JS5Value9setDoubleEd($vp, $dval_0);
  return;
}

function __ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAPF32[$1 + ($index << 2) >> 2];
}

function __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = __ZL15JSDOUBLE_IS_NaNd3989($1);
  var $3 = ($2 | 0) == 0;
  var $4 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
  var $val_0 = $3 ? $1 : $4;
  __ZN2JS5Value9setDoubleEd($vp, $val_0);
  return;
}

function __ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  var $3 = $1 + ($index << 3) | 0;
  var $4 = (tempDoubleI32[0] = HEAP32[$3 >> 2], tempDoubleI32[1] = HEAP32[$3 + 4 >> 2], tempDoubleF64[0]);
  return $4;
}

function __ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 232 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 232 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 464 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 464 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 696 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 696 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 928 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 928 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1160 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1160 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1392 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1392 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1624 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1624 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $begin = __stackBase__;
    var $end = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1856 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$begin >> 2] = 0;
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    HEAP32[$end >> 2] = $12;
    if (($argc | 0) == 0) {
      var $45 = 0;
      var $44 = $12;
      __label__ = 19;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $begin);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAP32[$begin >> 2];
    if (($18 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $21 = $18 + $12 | 0;
    HEAP32[$begin >> 2] = $21;
    if (($21 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      var $28 = $21;
      __label__ = 12;
      break;
    }
   case 9:
    HEAP32[$begin >> 2] = 0;
    var $28 = 0;
    __label__ = 12;
    break;
   case 10:
    if (($18 | 0) > ($12 | 0)) {
      __label__ = 11;
      break;
    } else {
      var $28 = $18;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$begin >> 2] = $12;
    var $28 = $12;
    __label__ = 12;
    break;
   case 12:
    var $28;
    if ($argc >>> 0 > 1) {
      __label__ = 13;
      break;
    } else {
      var $45 = $28;
      var $44 = $12;
      __label__ = 19;
      break;
    }
   case 13:
    var $31 = $vp + 24 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $end);
    if ($32) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 14:
    var $34 = HEAPU32[$end >> 2];
    if (($34 | 0) < 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $37 = $34 + $12 | 0;
    HEAP32[$end >> 2] = $37;
    if (($37 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      var $45 = $28;
      var $44 = $37;
      __label__ = 19;
      break;
    }
   case 16:
    HEAP32[$end >> 2] = 0;
    var $45 = $28;
    var $44 = 0;
    __label__ = 19;
    break;
   case 17:
    if (($34 | 0) > ($12 | 0)) {
      __label__ = 18;
      break;
    } else {
      var $45 = $28;
      var $44 = $34;
      __label__ = 19;
      break;
    }
   case 18:
    HEAP32[$end >> 2] = $12;
    var $45 = $28;
    var $44 = $12;
    __label__ = 19;
    break;
   case 19:
    var $44;
    var $45;
    if (($45 | 0) > ($44 | 0)) {
      __label__ = 20;
      break;
    } else {
      var $49 = $45;
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$begin >> 2] = $44;
    var $49 = $44;
    __label__ = 21;
    break;
   case 21:
    var $49;
    var $50 = __ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj($cx, $9, $49, $44);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JS5Value9setObjectER8JSObject($vp, $50);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $off = __stackBase__;
    var $len = __stackBase__ + 4;
    var $1 = $vp + 8 | 0;
    var $2 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($2);
    if (($5 | 0) == (__ZN2js10TypedArray11fastClassesE + 1856 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $_0 = 0;
    __label__ = 23;
    break;
   case 4:
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($2);
    if (($9 | 0) == 0) {
      var $_0 = 1;
      __label__ = 23;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$off >> 2] = 0;
    var $12 = $vp + 16 | 0;
    if ($argc >>> 0 > 1) {
      __label__ = 6;
      break;
    } else {
      var $25 = 0;
      __label__ = 10;
      break;
    }
   case 6:
    var $15 = $vp + 24 | 0;
    var $16 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $15, $off);
    if ($16) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 7:
    var $18 = HEAPU32[$off >> 2];
    if (($18 | 0) < 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($18 >>> 0 > $21 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $25 = $18;
      __label__ = 10;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 10:
    var $25;
    if (($argc | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = __ZNK2JS5Value8isObjectEv($12);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 13:
    var $31 = __ZNK2JS5Value14toObjectOrNullEv($12);
    var $32 = __Z15js_IsTypedArrayP8JSObject($31);
    if (($32 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($31);
    if (($35 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($35);
    var $39 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($38 >>> 0 > ($39 - $25 | 0) >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 17:
    var $44 = __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $2, $35, $25);
    if ($44) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 18:
    var $46 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $31, $len);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $49 = HEAPU32[$len >> 2];
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($9);
    if ($49 >>> 0 > ($50 - $25 | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 23;
    break;
   case 21:
    var $55 = __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $2, $31, $49, $25);
    if ($55) {
      __label__ = 22;
      break;
    } else {
      var $_0 = 0;
      __label__ = 23;
      break;
    }
   case 22:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $id, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $v | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $tmp | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $12 = __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $tmp, undef);
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $index, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tmp = __stackBase__;
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = $tmp | 0;
  HEAP32[$3 >> 2] = $2$0;
  HEAP32[$3 + 4 >> 2] = $2$1;
  var $4 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $tmp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej($cx, $obj, $sid, $v, $getter, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej($cx, $obj, $1, $v, undef, undef, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $15, $vp);
    __label__ = 10;
    break;
   case 5:
    var $17 = __ZNK8JSObject8getProtoEv($obj);
    var $18 = ($17 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($18) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 208 >> 2];
    var $22 = $cx;
    var $23 = $17;
    var $24 = $obj2;
    var $25 = $prop;
    var $26 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($22, $23, $id, $21, $24, $25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = HEAP32[$prop >> 2];
    if (($28 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$obj2 >> 2];
    var $32 = __ZNK8JSObject8isNativeEv($31);
    if ($32) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = $obj;
    var $35 = $31;
    var $36 = $28;
    var $37 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($22, $34, $35, $36, 0, $vp);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom3984($1);
  var $3 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, undef, $2, $vp);
  return $3;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject($cx, $obj) {
  return 1;
}

function __ZN2js21IsFastTypedArrayClassEPKNS_5ClassE($clasp) {
  return $clasp >>> 0 < (__ZN2js10TypedArray11fastClassesE + 2088 | 0) >>> 0 & $clasp >>> 0 >= __ZN2js10TypedArray11fastClassesE >>> 0;
}

function __ZNK8JSObject13isArrayBufferEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js16ArrayBufferClassE | 0);
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $obj2 = __stackBase__ + 4;
    var $prop = __stackBase__ + 8;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $1, $index, $vp);
    var $_0 = 1;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK8JSObject8getProtoEv($obj);
    var $7 = ($6 | 0) == 0;
    __ZN2JS5Value12setUndefinedEv($vp);
    if ($7) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($cx, $index, $id);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = HEAP32[$id >> 2];
    var $13 = HEAP32[$cx + 208 >> 2];
    var $14 = $cx;
    var $15 = $6;
    var $16 = $obj2;
    var $17 = $prop;
    var $18 = __ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty($14, $15, $11, $13, $16, $17);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $20 = HEAP32[$prop >> 2];
    if (($20 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $23 = HEAP32[$obj2 >> 2];
    var $24 = __ZNK8JSObject8isNativeEv($23);
    if ($24) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 8:
    var $26 = $obj;
    var $27 = $23;
    var $28 = $20;
    var $29 = __Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE($14, $26, $27, $28, 0, $vp);
    var $_0 = $29;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE($cx, $obj, undef, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $7 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $6);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $11 = __ZN2JS5Value9setNumberEj($vp, $10);
    __label__ = 6;
    break;
   case 3:
    var $13 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $1, $id, $index);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 6;
    break;
   case 5:
    var $16 = HEAP32[$index >> 2];
    var $17 = __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $16, $vp, undef);
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    __label__ = 4;
    break;
   case 3:
    var $6 = __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $1, $index, $vp, undef);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $5 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $6 = __ZL12JSID_IS_ATOMiP6JSAtom3982($id, $5);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $11 = __ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj(undef, $10, $id, 0);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 6;
    break;
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 6;
    break;
   case 6:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    var $2 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($rval, 0);
    __label__ = 4;
    break;
   case 3:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    __label__ = 4;
    break;
   case 4:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983($sid_idx_val);
  var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, undef);
  STACKTOP = __stackBase__;
  return 1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($obj);
    if (($enum_op | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($enum_op | 0) == 0) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 6;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    __ZN2JS5Value10setBooleanEb($statep, 1);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $6 = $5 + 1 | 0;
    var $7 = _INT_TO_JSID4006($6);
    HEAP32[$idp >> 2] = $7;
    __label__ = 12;
    break;
   case 4:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    if (($idp | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    var $12 = _INT_TO_JSID4006($11);
    HEAP32[$idp >> 2] = $12;
    __label__ = 12;
    break;
   case 6:
    var $14 = __ZNK2JS5Value6isTrueEv($statep);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210256 >> 2] | 0;
    var $21 = __ZL12ATOM_TO_JSIDP6JSAtom3984($20);
    HEAP32[$idp >> 2] = $21;
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 12;
    break;
   case 8:
    var $23 = __ZNK2JS5Value7toInt32Ev($statep);
    var $24 = __ZN2js10TypedArray9getLengthEP8JSObject($1);
    if ($23 >>> 0 < $24 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $27 = _INT_TO_JSID4006($23);
    HEAP32[$idp >> 2] = $27;
    var $28 = $23 + 1 | 0;
    __ZN2JS5Value8setInt32Ei($statep, $28);
    __label__ = 12;
    break;
   case 10:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    __label__ = 12;
    break;
   case 12:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z24js_InitTypedArrayClassesP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $stop = __stackBase__;
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = $2;
    var $6 = $stop;
    var $7 = __Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_($4, $5, 24, $6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$stop >> 2];
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = $10;
      __label__ = 13;
      break;
    }
   case 3:
    var $13 = __ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = __ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = __ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = __ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($28 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $3);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $40 = __ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE($cx, $3);
    var $_0 = $40;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210120 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 250, __ZN2js10TypedArray11fastClassesE, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN9Int8Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 25, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 232 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210124 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 252, __ZN2js10TypedArray11fastClassesE + 232 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Uint8Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 26, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 464 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210128 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 254, __ZN2js10TypedArray11fastClassesE + 464 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 2);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Int16Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 27, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 696 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210132 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 256, __ZN2js10TypedArray11fastClassesE + 696 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 2);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN11Uint16Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 28, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 928 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210136 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 258, __ZN2js10TypedArray11fastClassesE + 928 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN10Int32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 29, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1160 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210140 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 260, __ZN2js10TypedArray11fastClassesE + 1160 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN11Uint32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 30, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1392 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210144 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 262, __ZN2js10TypedArray11fastClassesE + 1392 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 4);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN12Float32Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 31, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1624 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210148 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 264, __ZN2js10TypedArray11fastClassesE + 1624 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 8);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 8);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN12Float64Array7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 32, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $global;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js10TypedArray11slowClassesE + 1856 | 0);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $cx + 52 | 0;
    var $13 = HEAP32[HEAP32[$9 >> 2] + 210152 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 266, __ZN2js10TypedArray11fastClassesE + 1856 | 0, $13, 3);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $24 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $25 = __ZL12ATOM_TO_JSIDP6JSAtom3984($24);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    var $26 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($17, $cx, $25, $1, 10, 12, 6);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $32 = HEAP32[HEAP32[$9 >> 2] + 210184 >> 2] | 0;
    var $33 = __ZL12ATOM_TO_JSIDP6JSAtom3984($32);
    __ZN2JSL10Int32ValueEi3996($2, 1);
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($6, $cx, $33, $2, 10, 12, 6);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $37 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, __ZN2js10TypedArray7jspropsE, __ZN17Uint8ClampedArray7jsfuncsE);
    if ($37) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 33, $17, $6);
    var $_ = $39 ? $6 : 0;
    var $_0 = $_;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE($cx, $global) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $global;
    var $2 = $cx;
    var $3 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($1, $2, __ZN2js11ArrayBuffer9slowClassE);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210116 >> 2];
    var $12 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($1, $2, 268, __ZN2js16ArrayBufferClassE, $11, 1);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = $12;
    var $16 = $12 | 0;
    var $17 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($2, $16, $3);
    if ($17) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $19 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($2, $3, __ZN2js11ArrayBuffer7jspropsE, 0);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $21 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $global, 24, $15, $4);
    var $_ = $21 ? $4 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z27JS_GetArrayBufferByteLengthP8JSObject($obj) {
  var $1 = __ZN8JSObject21arrayBufferByteLengthEv($obj);
  return $1;
}

function __Z21JS_GetArrayBufferDataP8JSObject($obj) {
  var $1 = __ZN8JSObject21arrayBufferDataOffsetEv($obj);
  return $1;
}

function __Z20js_CreateArrayBufferP9JSContextj($cx, $nbytes) {
  var $1 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $nbytes);
  return $1;
}

function __Z19js_CreateTypedArrayP9JSContextij($cx, $atype, $nelements) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $nelems = __stackBase__;
  __ZN2JSL10Int32ValueEi3996($nelems, $nelements);
  var $1 = __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, 1, $nelems);
  STACKTOP = __stackBase__;
  return $1;
}

function __ZN2JSL10Int32ValueEi3996($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, $argc, $argv) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($atype | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($atype | 0) == 1) {
      __label__ = 3;
      break;
    } else if (($atype | 0) == 2) {
      __label__ = 4;
      break;
    } else if (($atype | 0) == 3) {
      __label__ = 5;
      break;
    } else if (($atype | 0) == 4) {
      __label__ = 6;
      break;
    } else if (($atype | 0) == 5) {
      __label__ = 7;
      break;
    } else if (($atype | 0) == 6) {
      __label__ = 8;
      break;
    } else if (($atype | 0) == 7) {
      __label__ = 9;
      break;
    } else if (($atype | 0) == 8) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 2:
    var $2 = __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $2;
    __label__ = 11;
    break;
   case 3:
    var $4 = __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $4;
    __label__ = 11;
    break;
   case 4:
    var $6 = __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $6;
    __label__ = 11;
    break;
   case 5:
    var $8 = __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $8;
    __label__ = 11;
    break;
   case 6:
    var $10 = __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $10;
    __label__ = 11;
    break;
   case 7:
    var $12 = __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $12;
    __label__ = 11;
    break;
   case 8:
    var $14 = __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $14;
    __label__ = 11;
    break;
   case 9:
    var $16 = __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $16;
    __label__ = 11;
    break;
   case 10:
    var $18 = __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv);
    var $_0 = $18;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z28js_CreateTypedArrayWithArrayP9JSContextiP8JSObject($cx, $atype, $arrayArg) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $arrval = __stackBase__;
  __ZN2JSL11ObjectValueER8JSObject3997($arrval, $arrayArg);
  var $1 = __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, 1, $arrval);
  STACKTOP = __stackBase__;
  return $1;
}

function _INT_TO_JSID4006($i) {
  return $i << 1 | 1;
}

function __ZL18JSDOUBLE_IS_FINITEd4011($d) {
  tempDoubleF64[0] = $d;
  return ((tempDoubleI32[0] & 0) != 0 || (tempDoubleI32[1] & 2146435072) != 2146435072) & 1;
}

function __ZN13uint8_clampedaSERKS_($this, $x) {
  var $2 = HEAP8[$x | 0];
  HEAP8[$this | 0] = $2;
  return $this;
}

function __ZN13uint8_clampedaSEj($this, $x) {
  var $2 = $x >>> 0 > 255 ? -1 : $x & 255;
  HEAP8[$this | 0] = $2;
  return $this;
}

function __ZN13uint8_clampedaSEi($this, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($x | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if (($x | 0) < 255) {
      __label__ = 3;
      break;
    } else {
      var $7 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $x & 255;
    __label__ = 4;
    break;
   case 4:
    var $7;
    HEAP8[$this | 0] = $7;
    return $this;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject3997($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __Z29js_CreateTypedArrayWithBufferP9JSContextiP8JSObjectii($cx, $atype, $bufArg, $byteoffset, $length) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $vals = __stackBase__;
    var $tvr = __stackBase__ + 32;
    var $1 = $vals | 0;
    __ZN2JS5Value9setObjectER8JSObject($1, $bufArg);
    if (($byteoffset | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $argc_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $vals + 8 | 0;
    __ZN2JS5Value8setInt32Ei($4, $byteoffset);
    var $argc_0 = 2;
    __label__ = 3;
    break;
   case 3:
    var $argc_0;
    if (($length | 0) > -1) {
      __label__ = 4;
      break;
    } else {
      var $argc_1 = $argc_0;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $vals + ($argc_0 << 3) | 0;
    __ZN2JS5Value8setInt32Ei($8, $length);
    var $argc_1 = $argc_0 + 1 | 0;
    __label__ = 5;
    break;
   case 5:
    var $argc_1;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $cx, 4, $1);
    var $11 = __ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE($cx, $atype, $argc_1, $1);
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z22JS_GetTypedArrayLengthP8JSObject($obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 0);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __Z26JS_GetTypedArrayByteOffsetP8JSObject($obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 1);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __Z26JS_GetTypedArrayByteLengthP8JSObject($obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 2);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __Z20JS_GetTypedArrayTypeP8JSObject($obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 3);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __Z22JS_GetTypedArrayBufferP8JSObject($obj) {
  var $1 = __ZNK8JSObject7getSlotEj($obj, 4);
  var $2 = __ZNK2JS5Value9toPrivateEv($1);
  return $2;
}

function __Z20JS_GetTypedArrayDataP8JSObject($obj) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return $1;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($v, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    if (($3 | 0) < 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$len >> 2] = $3;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 4:
    var $7 = __ZNK2JS5Value8isDoubleEv($v);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $9 = __ZNK2JS5Value8toDoubleEv($v);
    var $10 = __ZL15JSDOUBLE_IS_NaNd3989($9);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = $9 >= 0 ? Math.floor($9) : Math.ceil($9);
    if ($9 != $13 >>> 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$len >> 2] = $13;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1856 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1860 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 8);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1856 | 0);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $9 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $10 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray9getBufferEP8JSObject($9);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $14 = __ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j($cx, $9, $tarray, $offset);
    var $_0 = $14;
    __label__ = 30;
    break;
   case 3:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($9);
    var $17 = $16;
    var $18 = $17 + $offset | 0;
    var $19 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $20 = __ZN2js10TypedArray7getTypeEP8JSObject($9);
    if (($19 | 0) == ($20 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $23 = $18 | 0;
    var $24 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $25 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($23, $24, $25, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $27 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($19 | 0) == 1 || ($19 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($19 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($19 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($19 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($19 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($19 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($19 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit51 = $17 + ($27 + $offset) | 0;
    var $src_036 = $30;
    var $dest_037 = $18;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $32 = $dest_037 + 1 | 0;
    var $33 = $src_036 + 1 | 0;
    var $34 = HEAP8[$src_036];
    __ZN13uint8_clampedC1Ea($1, $34);
    var $35 = __ZN13uint8_clampedaSERKS_($dest_037, $1);
    if (($32 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $33;
      var $dest_037 = $32;
      __label__ = 8;
      break;
    }
   case 9:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit49 = $17 + ($27 + $offset) | 0;
    var $src1_031 = $38;
    var $dest_132 = $18;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $40 = $dest_132 + 1 | 0;
    var $41 = $src1_031 + 1 | 0;
    var $42 = HEAP8[$src1_031];
    __ZN13uint8_clampedC1Eh($2, $42);
    var $43 = __ZN13uint8_clampedaSERKS_($dest_132, $2);
    if (($40 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $41;
      var $dest_132 = $40;
      __label__ = 11;
      break;
    }
   case 12:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit47 = $17 + ($27 + $offset) | 0;
    var $src3_026 = $46;
    var $dest_227 = $18;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $49 = $dest_227 + 1 | 0;
    var $50 = $src3_026 + 2 | 0;
    var $51 = HEAP16[$src3_026 >> 1];
    __ZN13uint8_clampedC1Es($3, $51);
    var $52 = __ZN13uint8_clampedaSERKS_($dest_227, $3);
    if (($49 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $50;
      var $dest_227 = $49;
      __label__ = 14;
      break;
    }
   case 15:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $17 + ($27 + $offset) | 0;
    var $src5_021 = $55;
    var $dest_322 = $18;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $58 = $dest_322 + 1 | 0;
    var $59 = $src5_021 + 2 | 0;
    var $60 = HEAP16[$src5_021 >> 1];
    __ZN13uint8_clampedC1Et($4, $60);
    var $61 = __ZN13uint8_clampedaSERKS_($dest_322, $4);
    if (($58 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $59;
      var $dest_322 = $58;
      __label__ = 17;
      break;
    }
   case 18:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit43 = $17 + ($27 + $offset) | 0;
    var $src7_016 = $64;
    var $dest_417 = $18;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $67 = $dest_417 + 1 | 0;
    var $68 = $src7_016 + 4 | 0;
    var $69 = HEAP32[$src7_016 >> 2];
    __ZN13uint8_clampedC1Ei($5, $69);
    var $70 = __ZN13uint8_clampedaSERKS_($dest_417, $5);
    if (($67 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $68;
      var $dest_417 = $67;
      __label__ = 20;
      break;
    }
   case 21:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $73 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit41 = $17 + ($27 + $offset) | 0;
    var $src9_011 = $73;
    var $dest_512 = $18;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $76 = $dest_512 + 1 | 0;
    var $77 = $src9_011 + 4 | 0;
    var $78 = HEAP32[$src9_011 >> 2];
    __ZN13uint8_clampedC1Ej($6, $78);
    var $79 = __ZN13uint8_clampedaSERKS_($dest_512, $6);
    if (($76 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $77;
      var $dest_512 = $76;
      __label__ = 23;
      break;
    }
   case 24:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $82 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit39 = $17 + ($27 + $offset) | 0;
    var $src11_05 = $82;
    var $dest_66 = $18;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $85 = $dest_66 + 1 | 0;
    var $86 = $src11_05 + 4 | 0;
    var $88 = HEAPF32[$src11_05 >> 2];
    __ZN13uint8_clampedC1Ed($7, $88);
    var $89 = __ZN13uint8_clampedaSERKS_($dest_66, $7);
    if (($85 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $86;
      var $dest_66 = $85;
      __label__ = 26;
      break;
    }
   case 27:
    if (($27 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $92 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $17 + ($27 + $offset) | 0;
    var $dest_71 = $18;
    var $src13_02 = $92;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $95 = $dest_71 + 1 | 0;
    var $96 = $src13_02 + 8 | 0;
    var $97 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($8, $97);
    var $98 = __ZN13uint8_clampedaSERKS_($dest_71, $8);
    if (($95 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $95;
      var $src13_02 = $96;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $v = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $4 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($3);
    var $5 = $4;
    var $6 = $5 + $offset | 0;
    var $7 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $6;
      __label__ = 6;
      break;
    }
   case 2:
    var $9 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($9 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $6;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $lftr_limit = $5 + ($offset + $len) | 0;
    var $dest_01 = $6;
    var $src_02 = $13;
    __label__ = 5;
    break;
   case 5:
    var $src_02;
    var $dest_01;
    var $15 = $dest_01 + 1 | 0;
    var $16 = $src_02 + 8 | 0;
    __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($1, $cx, $src_02);
    var $17 = __ZN13uint8_clampedaSERKS_($dest_01, $1);
    if (($15 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $15;
      var $src_02 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $20 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $23 = $dest_1 + 1 | 0;
    __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($2, $cx, $v);
    var $24 = __ZN13uint8_clampedaSERKS_($dest_1, $2);
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $23;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE($agg_result, $cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    __ZN13uint8_clampedC1Ei($agg_result, $3);
    __label__ = 11;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN13uint8_clampedC1Ei($agg_result, 0);
    __label__ = 11;
    break;
   case 6:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($7);
    __ZN13uint8_clampedC1Ei($agg_result, $12);
    __label__ = 11;
    break;
   case 7:
    var $14 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $16 = __ZNK2JS5Value7isMagicEv($v);
    if ($16) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $19 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($agg_result, $19);
    __label__ = 11;
    break;
   case 10:
    __ZN13uint8_clampedC1Ei($agg_result, 0);
    __label__ = 11;
    break;
   case 11:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedC1Ei($this, $x) {
  __ZN13uint8_clampedC2Ei($this, $x);
  return;
}

function __ZN13uint8_clampedC1Ed($this, $x) {
  __ZN13uint8_clampedC2Ed($this, $x);
  return;
}

function __ZN13uint8_clampedC1Ej($this, $x) {
  __ZN13uint8_clampedC2Ej($this, $x);
  return;
}

function __ZL20js_DoubleToECMAInt32d4007($d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL18JSDOUBLE_IS_FINITEd4011($d);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $d & -1;
    if (($4 | 0) == $d) {
      var $_0 = $4;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = _fmod($d, 4294967296);
    if ($8 < 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = _floor($8);
    var $16 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = _ceil($8);
    var $16 = $13 + 4294967296;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if ($16 < 2147483648) {
      var $21 = $16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = $16 - 4294967296;
    __label__ = 8;
    break;
   case 8:
    var $21;
    var $_0 = $21 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedC2Ej($this, $x) {
  var $1 = __ZN13uint8_clampedaSEj($this, $x);
  return;
}

function __ZN13uint8_clampedC2Ed($this, $x) {
  var $1 = __ZN13uint8_clampedaSEd($this, $x);
  return;
}

function __ZN13uint8_clampedaSEd($this, $x) {
  var $1 = __Z32js_TypedArray_uint8_clamp_doubled($x);
  HEAP8[$this | 0] = $1 & 255;
  return $this;
}

function __ZN13uint8_clampedC2Ei($this, $x) {
  var $1 = __ZN13uint8_clampedaSEi($this, $x);
  return;
}

function __ZN2js10TypedArray9getBufferEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 4);
  var $2 = __ZNK2JS5Value8toObjectEv($1);
  return $2;
}

function __ZN13uint8_clampedaSEt($this, $x) {
  var $2 = ($x & 65535) > 255 ? -1 : $x & 255;
  HEAP8[$this | 0] = $2;
  return $this;
}

function __ZN13uint8_clampedaSEs($this, $x) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($x << 16 >> 16 > -1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    if ($x << 16 >> 16 < 255) {
      __label__ = 3;
      break;
    } else {
      var $7 = -1;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $x & 255;
    __label__ = 4;
    break;
   case 4:
    var $7;
    HEAP8[$this | 0] = $7;
    return $this;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN13uint8_clampedaSEh($this, $x) {
  HEAP8[$this | 0] = $x;
  return $this;
}

function __ZN13uint8_clampedaSEa($this, $x) {
  var $2 = $x << 24 >> 24 < 0 ? 0 : $x;
  HEAP8[$this | 0] = $2;
  return $this;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j($cx, $self, $tarray, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $3 = __stackBase__ + 8;
    var $4 = __stackBase__ + 12;
    var $5 = __stackBase__ + 16;
    var $6 = __stackBase__ + 20;
    var $7 = __stackBase__ + 24;
    var $8 = __stackBase__ + 28;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $11 = $9 + $offset | 0;
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $13 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($12 | 0) == ($13 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $16 = $11 | 0;
    var $17 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $18 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($16, $17, $18, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $20 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $21 = __ZN9JSContext7malloc_Ej($cx, $20);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $24 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $25 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($21, $24, $25, 1);
    var $26 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($26 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($26 | 0) == 1 || ($26 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($26 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($26 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($26 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($26 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($26 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($26 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $27 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($27 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $21;
      var $dest_038 = $11;
      __label__ = 7;
      break;
    }
   case 6:
    var $29 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($29 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $21;
      var $dest_132 = $11;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $31 = $dest_038 + 1 | 0;
    var $32 = $src_037 + 1 | 0;
    var $33 = HEAP8[$src_037];
    __ZN13uint8_clampedC1Ea($1, $33);
    var $34 = __ZN13uint8_clampedaSERKS_($dest_038, $1);
    var $35 = $i_036 + 1 | 0;
    var $36 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($35 >>> 0 < $36 >>> 0) {
      var $i_036 = $35;
      var $src_037 = $32;
      var $dest_038 = $31;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $38 = $dest_132 + 1 | 0;
    var $39 = $src1_031 + 1 | 0;
    var $40 = HEAP8[$src1_031];
    __ZN13uint8_clampedC1Eh($2, $40);
    var $41 = __ZN13uint8_clampedaSERKS_($dest_132, $2);
    var $42 = $i2_030 + 1 | 0;
    var $43 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($42 >>> 0 < $43 >>> 0) {
      var $i2_030 = $42;
      var $src1_031 = $39;
      var $dest_132 = $38;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($46 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $21;
    var $dest_227 = $11;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $50 = $dest_227 + 1 | 0;
    var $51 = $src3_026 + 2 | 0;
    var $52 = HEAP16[$src3_026 >> 1];
    __ZN13uint8_clampedC1Es($3, $52);
    var $53 = __ZN13uint8_clampedaSERKS_($dest_227, $3);
    var $54 = $i4_025 + 1 | 0;
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($54 >>> 0 < $55 >>> 0) {
      var $i4_025 = $54;
      var $src3_026 = $51;
      var $dest_227 = $50;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $58 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($58 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $21;
    var $dest_322 = $11;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $62 = $dest_322 + 1 | 0;
    var $63 = $src5_021 + 2 | 0;
    var $64 = HEAP16[$src5_021 >> 1];
    __ZN13uint8_clampedC1Et($4, $64);
    var $65 = __ZN13uint8_clampedaSERKS_($dest_322, $4);
    var $66 = $i6_020 + 1 | 0;
    var $67 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($66 >>> 0 < $67 >>> 0) {
      var $i6_020 = $66;
      var $src5_021 = $63;
      var $dest_322 = $62;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($70 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $21;
    var $dest_417 = $11;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $74 = $dest_417 + 1 | 0;
    var $75 = $src7_016 + 4 | 0;
    var $76 = HEAP32[$src7_016 >> 2];
    __ZN13uint8_clampedC1Ei($5, $76);
    var $77 = __ZN13uint8_clampedaSERKS_($dest_417, $5);
    var $78 = $i8_015 + 1 | 0;
    var $79 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($78 >>> 0 < $79 >>> 0) {
      var $i8_015 = $78;
      var $src7_016 = $75;
      var $dest_417 = $74;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $82 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($82 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $21;
    var $i10_011 = 0;
    var $dest_512 = $11;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $86 = $dest_512 + 1 | 0;
    var $87 = $src9_010 + 4 | 0;
    var $88 = HEAP32[$src9_010 >> 2];
    __ZN13uint8_clampedC1Ej($6, $88);
    var $89 = __ZN13uint8_clampedaSERKS_($dest_512, $6);
    var $90 = $i10_011 + 1 | 0;
    var $91 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($90 >>> 0 < $91 >>> 0) {
      var $src9_010 = $87;
      var $i10_011 = $90;
      var $dest_512 = $86;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($94 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $11;
    var $src11_06 = $21;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $98 = $dest_65 + 1 | 0;
    var $99 = $src11_06 + 4 | 0;
    var $101 = HEAPF32[$src11_06 >> 2];
    __ZN13uint8_clampedC1Ed($7, $101);
    var $102 = __ZN13uint8_clampedaSERKS_($dest_65, $7);
    var $103 = $i12_07 + 1 | 0;
    var $104 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($103 >>> 0 < $104 >>> 0) {
      var $dest_65 = $98;
      var $src11_06 = $99;
      var $i12_07 = $103;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $107 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($107 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $11;
    var $src13_02 = $21;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $111 = $dest_71 + 1 | 0;
    var $112 = $src13_02 + 8 | 0;
    var $113 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    __ZN13uint8_clampedC1Ed($8, $113);
    var $114 = __ZN13uint8_clampedaSERKS_($dest_71, $8);
    var $115 = $i14_03 + 1 | 0;
    var $116 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($115 >>> 0 < $116 >>> 0) {
      var $dest_71 = $111;
      var $src13_02 = $112;
      var $i14_03 = $115;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($21);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j["X"] = 1;

function __ZN2js10TypedArray13getByteLengthEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 2);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __ZN13uint8_clampedC1Ea($this, $x) {
  __ZN13uint8_clampedC2Ea($this, $x);
  return;
}

function __ZN13uint8_clampedC1Eh($this, $x) {
  __ZN13uint8_clampedC2Eh($this, $x);
  return;
}

function __ZN13uint8_clampedC1Es($this, $x) {
  __ZN13uint8_clampedC2Es($this, $x);
  return;
}

function __ZN13uint8_clampedC1Et($this, $x) {
  __ZN13uint8_clampedC2Et($this, $x);
  return;
}

function __ZN13uint8_clampedC2Et($this, $x) {
  var $1 = __ZN13uint8_clampedaSEt($this, $x);
  return;
}

function __ZN13uint8_clampedC2Es($this, $x) {
  var $1 = __ZN13uint8_clampedaSEs($this, $x);
  return;
}

function __ZN13uint8_clampedC2Eh($this, $x) {
  var $1 = __ZN13uint8_clampedaSEh($this, $x);
  return;
}

function __ZN13uint8_clampedC2Ea($this, $x) {
  var $1 = __ZN13uint8_clampedaSEa($this, $x);
  return;
}

function __ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 268435454) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 3;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1624 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1628 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 7);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 3;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1624 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 3) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    tempDoubleF64[0] = HEAP8[$src_036] << 24 >> 24, HEAP32[$dest_037 >> 2] = tempDoubleI32[0], HEAP32[$dest_037 + 4 >> 2] = tempDoubleI32[1];
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 8 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    tempDoubleF64[0] = HEAPU8[$src1_031] & 255, HEAP32[$dest_132 >> 2] = tempDoubleI32[0], HEAP32[$dest_132 + 4 >> 2] = tempDoubleI32[1];
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 8 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    tempDoubleF64[0] = HEAP16[$src3_026 >> 1] << 16 >> 16, HEAP32[$dest_227 >> 2] = tempDoubleI32[0], HEAP32[$dest_227 + 4 >> 2] = tempDoubleI32[1];
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 8 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    tempDoubleF64[0] = HEAPU16[$src5_021 >> 1] & 65535, HEAP32[$dest_322 >> 2] = tempDoubleI32[0], HEAP32[$dest_322 + 4 >> 2] = tempDoubleI32[1];
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 8 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    tempDoubleF64[0] = HEAP32[$src7_016 >> 2] | 0, HEAP32[$dest_417 >> 2] = tempDoubleI32[0], HEAP32[$dest_417 + 4 >> 2] = tempDoubleI32[1];
    var $65 = $i8_015 + 1 | 0;
    if (($65 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $65;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 8 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $68 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $68;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    tempDoubleF64[0] = HEAPU32[$src9_011 >> 2] >>> 0, HEAP32[$dest_512 >> 2] = tempDoubleI32[0], HEAP32[$dest_512 + 4 >> 2] = tempDoubleI32[1];
    var $75 = $i10_010 + 1 | 0;
    if (($75 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $75;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 8 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $78 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $78;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    tempDoubleF64[0] = HEAPF32[$src11_05 >> 2], HEAP32[$dest_66 >> 2] = tempDoubleI32[0], HEAP32[$dest_66 + 4 >> 2] = tempDoubleI32[1];
    var $85 = $i12_07 + 1 | 0;
    if (($85 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 8 | 0;
      var $i12_07 = $85;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $88 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $88;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $92 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $92, HEAP32[$dest_71 >> 2] = tempDoubleI32[0], HEAP32[$dest_71 + 4 >> 2] = tempDoubleI32[1];
    var $94 = $i14_03 + 1 | 0;
    if (($94 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 8 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $94;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -8 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 3;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 3;
    if ($len_0 >>> 0 > 268435454) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 3) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    tempDoubleF64[0] = $14, HEAP32[$dest_01 >> 2] = tempDoubleI32[0], HEAP32[$dest_01 + 4 >> 2] = tempDoubleI32[1];
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 8 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    tempDoubleF64[0] = $22, HEAP32[$dest_1 >> 2] = tempDoubleI32[0], HEAP32[$dest_1 + 4 >> 2] = tempDoubleI32[1];
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 8 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 | 0;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $10 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $12 = __ZNK2JS5Value7isMagicEv($v);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $14 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $15 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $15;
    __label__ = 9;
    break;
   case 8:
    var $17 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $17;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 3) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 8 | 0;
    tempDoubleF64[0] = HEAP8[$src_037] << 24 >> 24, HEAP32[$dest_038 >> 2] = tempDoubleI32[0], HEAP32[$dest_038 + 4 >> 2] = tempDoubleI32[1];
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 8 | 0;
    tempDoubleF64[0] = HEAPU8[$src1_031] & 255, HEAP32[$dest_132 >> 2] = tempDoubleI32[0], HEAP32[$dest_132 + 4 >> 2] = tempDoubleI32[1];
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 8 | 0;
    tempDoubleF64[0] = HEAP16[$src3_026 >> 1] << 16 >> 16, HEAP32[$dest_227 >> 2] = tempDoubleI32[0], HEAP32[$dest_227 + 4 >> 2] = tempDoubleI32[1];
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 8 | 0;
    tempDoubleF64[0] = HEAPU16[$src5_021 >> 1] & 65535, HEAP32[$dest_322 >> 2] = tempDoubleI32[0], HEAP32[$dest_322 + 4 >> 2] = tempDoubleI32[1];
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $69 = $dest_417 + 8 | 0;
    tempDoubleF64[0] = HEAP32[$src7_016 >> 2] | 0, HEAP32[$dest_417 >> 2] = tempDoubleI32[0], HEAP32[$dest_417 + 4 >> 2] = tempDoubleI32[1];
    var $70 = $i8_015 + 1 | 0;
    var $71 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($70 >>> 0 < $71 >>> 0) {
      var $i8_015 = $70;
      var $src7_016 = $66;
      var $dest_417 = $69;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $74 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($74 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $78 = $src9_010 + 4 | 0;
    var $81 = $dest_512 + 8 | 0;
    tempDoubleF64[0] = HEAPU32[$src9_010 >> 2] >>> 0, HEAP32[$dest_512 >> 2] = tempDoubleI32[0], HEAP32[$dest_512 + 4 >> 2] = tempDoubleI32[1];
    var $82 = $i10_011 + 1 | 0;
    var $83 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($82 >>> 0 < $83 >>> 0) {
      var $src9_010 = $78;
      var $i10_011 = $82;
      var $dest_512 = $81;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $86 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $90 = $src11_06 + 4 | 0;
    var $93 = $dest_65 + 8 | 0;
    tempDoubleF64[0] = HEAPF32[$src11_06 >> 2], HEAP32[$dest_65 >> 2] = tempDoubleI32[0], HEAP32[$dest_65 + 4 >> 2] = tempDoubleI32[1];
    var $94 = $i12_07 + 1 | 0;
    var $95 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($94 >>> 0 < $95 >>> 0) {
      var $dest_65 = $93;
      var $src11_06 = $90;
      var $i12_07 = $94;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $98 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($98 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $102 = $src13_02 + 8 | 0;
    var $103 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $104 = $dest_71 + 8 | 0;
    tempDoubleF64[0] = $103, HEAP32[$dest_71 >> 2] = tempDoubleI32[0], HEAP32[$dest_71 + 4 >> 2] = tempDoubleI32[1];
    var $105 = $i14_03 + 1 | 0;
    var $106 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($105 >>> 0 < $106 >>> 0) {
      var $dest_71 = $104;
      var $src13_02 = $102;
      var $i14_03 = $105;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1392 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1396 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 6);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1392 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAPF32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAPF32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAPF32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAPF32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAPF32[$dest_417 >> 2] = HEAP32[$src7_016 >> 2] | 0;
    var $65 = $i8_015 + 1 | 0;
    if (($65 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $65;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $68 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $68;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAPF32[$dest_512 >> 2] = HEAPU32[$src9_011 >> 2] >>> 0;
    var $75 = $i10_010 + 1 | 0;
    if (($75 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $75;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $78 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $78;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $82 = HEAPF32[$src11_05 >> 2];
    HEAPF32[$dest_66 >> 2] = $82;
    var $84 = $i12_07 + 1 | 0;
    if (($84 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $84;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $87 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $87;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $91 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    HEAPF32[$dest_71 >> 2] = $91;
    var $94 = $i14_03 + 1 | 0;
    if (($94 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $94;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 2) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAPF32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAPF32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 | 0;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $_0 = $8;
    __label__ = 9;
    break;
   case 5:
    var $11 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $13 = __ZNK2JS5Value7isMagicEv($v);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $16 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $16;
    __label__ = 9;
    break;
   case 8:
    var $19 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAPF32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAPF32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAPF32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAPF32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $69 = $dest_417 + 4 | 0;
    HEAPF32[$dest_417 >> 2] = HEAP32[$src7_016 >> 2] | 0;
    var $70 = $i8_015 + 1 | 0;
    var $71 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($70 >>> 0 < $71 >>> 0) {
      var $i8_015 = $70;
      var $src7_016 = $66;
      var $dest_417 = $69;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $74 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($74 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $78 = $src9_010 + 4 | 0;
    var $81 = $dest_512 + 4 | 0;
    HEAPF32[$dest_512 >> 2] = HEAPU32[$src9_010 >> 2] >>> 0;
    var $82 = $i10_011 + 1 | 0;
    var $83 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($82 >>> 0 < $83 >>> 0) {
      var $src9_010 = $78;
      var $i10_011 = $82;
      var $dest_512 = $81;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $86 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($86 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $90 = $src11_06 + 4 | 0;
    var $91 = HEAPF32[$src11_06 >> 2];
    var $92 = $dest_65 + 4 | 0;
    HEAPF32[$dest_65 >> 2] = $91;
    var $93 = $i12_07 + 1 | 0;
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($93 >>> 0 < $94 >>> 0) {
      var $dest_65 = $92;
      var $src11_06 = $90;
      var $i12_07 = $93;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $97 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($97 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $101 = $src13_02 + 8 | 0;
    var $102 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $104 = $dest_71 + 4 | 0;
    HEAPF32[$dest_71 >> 2] = $102;
    var $105 = $i14_03 + 1 | 0;
    var $106 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($105 >>> 0 < $106 >>> 0) {
      var $dest_71 = $104;
      var $src13_02 = $101;
      var $i14_03 = $105;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 1160 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 1164 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 5);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 1160 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = HEAP32[$src7_016 >> 2];
    HEAP32[$dest_417 >> 2] = $62;
    var $64 = $i8_015 + 1 | 0;
    if (($64 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $64;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $67 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $67;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    var $71 = HEAP32[$src9_011 >> 2];
    HEAP32[$dest_512 >> 2] = $71;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $79 = $src11_05 + 4 | 0;
    var $80 = HEAPF32[$src11_05 >> 2];
    var $81 = $80 >= 0 ? Math.floor($80) : Math.ceil($80);
    HEAP32[$dest_66 >> 2] = $81;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $79;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $89 = $src13_02 + 8 | 0;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 >= 0 ? Math.floor($90) : Math.ceil($90);
    HEAP32[$dest_71 >> 2] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $89;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 2) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = __Z21js_DoubleToECMAUint32d($7);
    var $_0 = $11;
    __label__ = 9;
    break;
   case 6:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZNK2JS5Value7isMagicEv($v);
    if ($15) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $18 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $19 = $18 >= 0 ? Math.floor($18) : Math.ceil($18);
    var $_0 = $19;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAP32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $67 = HEAP32[$src7_016 >> 2];
    var $68 = $dest_417 + 4 | 0;
    HEAP32[$dest_417 >> 2] = $67;
    var $69 = $i8_015 + 1 | 0;
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($69 >>> 0 < $70 >>> 0) {
      var $i8_015 = $69;
      var $src7_016 = $66;
      var $dest_417 = $68;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $73 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($73 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $77 = $src9_010 + 4 | 0;
    var $78 = HEAP32[$src9_010 >> 2];
    var $79 = $dest_512 + 4 | 0;
    HEAP32[$dest_512 >> 2] = $78;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $77;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $89 = HEAPF32[$src11_06 >> 2];
    var $90 = $89 >= 0 ? Math.floor($89) : Math.ceil($89);
    var $91 = $dest_65 + 4 | 0;
    HEAP32[$dest_65 >> 2] = $90;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 >= 0 ? Math.floor($101) : Math.ceil($101);
    var $103 = $dest_71 + 4 | 0;
    HEAP32[$dest_71 >> 2] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 536870910) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 2;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 928 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 932 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 4);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 2;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 928 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 2) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP32[$dest_037 >> 2] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 4 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 4 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $45 = $i4_025 + 1 | 0;
    if (($45 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $45;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 4 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $48 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $48;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $55 = $i6_020 + 1 | 0;
    if (($55 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $55;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 4 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $58 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $58;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = HEAP32[$src7_016 >> 2];
    HEAP32[$dest_417 >> 2] = $62;
    var $64 = $i8_015 + 1 | 0;
    if (($64 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $64;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 4 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $67 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $67;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    var $71 = HEAP32[$src9_011 >> 2];
    HEAP32[$dest_512 >> 2] = $71;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 4 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    HEAP32[$dest_66 >> 2] = HEAPF32[$src11_05 >> 2] & -1;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 4 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 & -1;
    HEAP32[$dest_71 >> 2] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 4 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -4 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 2;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 2;
    if ($len_0 >>> 0 > 536870910) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 2) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP32[$dest_01 >> 2] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 4 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP32[$dest_1 >> 2] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 4 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3;
    __label__ = 9;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($v);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($v);
    var $8 = __ZL15JSDOUBLE_IS_NaNd3989($7);
    if (($8 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $11 = __ZL20js_DoubleToECMAInt32d4007($7);
    var $_0 = $11;
    __label__ = 9;
    break;
   case 6:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZNK2JS5Value7isMagicEv($v);
    if ($15) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $18 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $18 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 2) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 4 | 0;
    HEAP32[$dest_038 >> 2] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 4 | 0;
    HEAP32[$dest_132 >> 2] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $45 = $dest_227 + 4 | 0;
    HEAP32[$dest_227 >> 2] = HEAP16[$src3_026 >> 1] << 16 >> 16;
    var $46 = $i4_025 + 1 | 0;
    var $47 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($46 >>> 0 < $47 >>> 0) {
      var $i4_025 = $46;
      var $src3_026 = $42;
      var $dest_227 = $45;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $50 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($50 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $54 = $src5_021 + 2 | 0;
    var $57 = $dest_322 + 4 | 0;
    HEAP32[$dest_322 >> 2] = HEAPU16[$src5_021 >> 1] & 65535;
    var $58 = $i6_020 + 1 | 0;
    var $59 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($58 >>> 0 < $59 >>> 0) {
      var $i6_020 = $58;
      var $src5_021 = $54;
      var $dest_322 = $57;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $62 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($62 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $66 = $src7_016 + 4 | 0;
    var $67 = HEAP32[$src7_016 >> 2];
    var $68 = $dest_417 + 4 | 0;
    HEAP32[$dest_417 >> 2] = $67;
    var $69 = $i8_015 + 1 | 0;
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($69 >>> 0 < $70 >>> 0) {
      var $i8_015 = $69;
      var $src7_016 = $66;
      var $dest_417 = $68;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $73 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($73 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $77 = $src9_010 + 4 | 0;
    var $78 = HEAP32[$src9_010 >> 2];
    var $79 = $dest_512 + 4 | 0;
    HEAP32[$dest_512 >> 2] = $78;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $77;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $91 = $dest_65 + 4 | 0;
    HEAP32[$dest_65 >> 2] = HEAPF32[$src11_06 >> 2] & -1;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 & -1;
    var $103 = $dest_71 + 4 | 0;
    HEAP32[$dest_71 >> 2] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 1073741822) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 1;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 696 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 700 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 3);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 1;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 696 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 1) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP16[$dest_037 >> 1] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 2 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = HEAP16[$src3_026 >> 1];
    HEAP16[$dest_227 >> 1] = $42;
    var $44 = $i4_025 + 1 | 0;
    if (($44 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $44;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 2 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $47 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $47;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $51 = HEAP16[$src5_021 >> 1];
    HEAP16[$dest_322 >> 1] = $51;
    var $53 = $i6_020 + 1 | 0;
    if (($53 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $53;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 2 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $56 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $56;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $63 = $i8_015 + 1 | 0;
    if (($63 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $63;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 2 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $66 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $66;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_011 >> 2] & 65535;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 2 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    var $79 = $src11_05 + 4 | 0;
    var $80 = HEAPF32[$src11_05 >> 2];
    var $81 = $80 >= 0 ? Math.floor($80) : Math.ceil($80);
    HEAP16[$dest_66 >> 1] = $81;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $79;
      var $dest_66 = $dest_66 + 2 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $89 = $src13_02 + 8 | 0;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $91 = $90 >= 0 ? Math.floor($90) : Math.ceil($90);
    HEAP16[$dest_71 >> 1] = $91;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 2 | 0;
      var $src13_02 = $89;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -2 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 1;
    if ($len_0 >>> 0 > 1073741822) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 1) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP16[$dest_01 >> 1] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 2 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP16[$dest_1 >> 1] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 2 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 & 65535;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __Z21js_DoubleToECMAUint32d($8);
    var $_0 = $12 & 65535;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $21 = $20 >= 0 ? Math.floor($20) : Math.ceil($20);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 1) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 2 | 0;
    HEAP16[$dest_038 >> 1] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 2 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $43 = HEAP16[$src3_026 >> 1];
    var $44 = $dest_227 + 2 | 0;
    HEAP16[$dest_227 >> 1] = $43;
    var $45 = $i4_025 + 1 | 0;
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($45 >>> 0 < $46 >>> 0) {
      var $i4_025 = $45;
      var $src3_026 = $42;
      var $dest_227 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($49 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $53 = $src5_021 + 2 | 0;
    var $54 = HEAP16[$src5_021 >> 1];
    var $55 = $dest_322 + 2 | 0;
    HEAP16[$dest_322 >> 1] = $54;
    var $56 = $i6_020 + 1 | 0;
    var $57 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($56 >>> 0 < $57 >>> 0) {
      var $i6_020 = $56;
      var $src5_021 = $53;
      var $dest_322 = $55;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $60 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($60 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $64 = $src7_016 + 4 | 0;
    var $67 = $dest_417 + 2 | 0;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $68 = $i8_015 + 1 | 0;
    var $69 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($68 >>> 0 < $69 >>> 0) {
      var $i8_015 = $68;
      var $src7_016 = $64;
      var $dest_417 = $67;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $72 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($72 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $76 = $src9_010 + 4 | 0;
    var $79 = $dest_512 + 2 | 0;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_010 >> 2] & 65535;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $76;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $89 = HEAPF32[$src11_06 >> 2];
    var $90 = $89 >= 0 ? Math.floor($89) : Math.ceil($89);
    var $91 = $dest_65 + 2 | 0;
    HEAP16[$dest_65 >> 1] = $90;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $102 = $101 >= 0 ? Math.floor($101) : Math.ceil($101);
    var $103 = $dest_71 + 2 | 0;
    HEAP16[$dest_71 >> 1] = $102;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 1073741822) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = $count << 1;
    var $5 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $4);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 464 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 468 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 2);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    var $16 = $len << 1;
    __ZN2JSL10Int32ValueEi3996($5, $16);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 464 | 0);
    var $17 = $6 + 8 | 0;
    var $19 = HEAP32[$17 >> 2] | 4;
    HEAP32[$17 >> 2] = $19;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $10 = $8 + ($offset << 1) | 0;
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $12 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($11 | 0) == ($12 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = $10;
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($15, $16, $17, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($11 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($11 | 0) == 1 || ($11 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($11 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($11 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($11 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($11 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($11 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($11 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $22 + $19 | 0;
    var $src_036 = $22;
    var $dest_037 = $10;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $24 = $src_036 + 1 | 0;
    HEAP16[$dest_037 >> 1] = HEAP8[$src_036] << 24 >> 24;
    if (($24 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $24;
      var $dest_037 = $dest_037 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 9:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $30 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $30 + $19 | 0;
    var $src1_031 = $30;
    var $dest_132 = $10;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $32 = $src1_031 + 1 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    if (($32 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $32;
      var $dest_132 = $dest_132 + 2 | 0;
      __label__ = 11;
      break;
    }
   case 12:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $38 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i4_025 = 0;
    var $src3_026 = $38;
    var $dest_227 = $10;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = HEAP16[$src3_026 >> 1];
    HEAP16[$dest_227 >> 1] = $42;
    var $44 = $i4_025 + 1 | 0;
    if (($44 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i4_025 = $44;
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $dest_227 + 2 | 0;
      __label__ = 14;
      break;
    }
   case 15:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $47 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i6_020 = 0;
    var $src5_021 = $47;
    var $dest_322 = $10;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $51 = HEAP16[$src5_021 >> 1];
    HEAP16[$dest_322 >> 1] = $51;
    var $53 = $i6_020 + 1 | 0;
    if (($53 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i6_020 = $53;
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $dest_322 + 2 | 0;
      __label__ = 17;
      break;
    }
   case 18:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $56 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i8_015 = 0;
    var $src7_016 = $56;
    var $dest_417 = $10;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $63 = $i8_015 + 1 | 0;
    if (($63 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i8_015 = $63;
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $dest_417 + 2 | 0;
      __label__ = 20;
      break;
    }
   case 21:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $66 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $i10_010 = 0;
    var $src9_011 = $66;
    var $dest_512 = $10;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $i10_010;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_011 >> 2] & 65535;
    var $73 = $i10_010 + 1 | 0;
    if (($73 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $i10_010 = $73;
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $dest_512 + 2 | 0;
      __label__ = 23;
      break;
    }
   case 24:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $76 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $src11_05 = $76;
    var $dest_66 = $10;
    var $i12_07 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i12_07;
    var $dest_66;
    var $src11_05;
    HEAP16[$dest_66 >> 1] = HEAPF32[$src11_05 >> 2] & -1;
    var $83 = $i12_07 + 1 | 0;
    if (($83 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $dest_66 + 2 | 0;
      var $i12_07 = $83;
      __label__ = 26;
      break;
    }
   case 27:
    if (($19 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $86 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $dest_71 = $10;
    var $src13_02 = $86;
    var $i14_03 = 0;
    __label__ = 29;
    break;
   case 29:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $90 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    HEAP16[$dest_71 >> 1] = $90 & -1;
    var $93 = $i14_03 + 1 | 0;
    if (($93 | 0) == ($19 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $dest_71 + 2 | 0;
      var $src13_02 = $src13_02 + 8 | 0;
      var $i14_03 = $93;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 <= $5 >>> 0 & ($4 & 1 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 4:
    if (($lengthInt | 0) < 0) {
      __label__ = 5;
      break;
    } else {
      var $len_0 = $lengthInt;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = $5 - $4 | 0;
    if (($13 & -2 | 0) == ($13 | 0)) {
      var $len_0 = $13 >>> 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 7:
    var $len_0;
    var $19 = $len_0 << 1;
    if ($len_0 >>> 0 > 1073741822) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($4 >>> 0 < (2147483647 - $19 | 0) >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 10:
    if (($19 + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 18;
    break;
   case 12:
    var $30 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $len_0);
    var $_0 = $30;
    __label__ = 18;
    break;
   case 13:
    var $32 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = HEAP32[$len1 >> 2];
    var $36 = __ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj($cx, $35);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $39 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $36, 0, $35);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $42 = __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $39, $other, $35, 0);
    if ($42) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $_0 = $39;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii["X"] = 1;

function __ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $4 = $2 + ($offset << 1) | 0;
    var $5 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    }
   case 2:
    var $7 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($7 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $4;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $dest_01 = $4;
    var $src_02 = $11;
    var $i_03 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_03;
    var $src_02;
    var $dest_01;
    var $13 = $src_02 + 8 | 0;
    var $14 = __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    HEAP16[$dest_01 >> 1] = $14;
    var $16 = $i_03 + 1 | 0;
    if (($16 | 0) == ($len | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $dest_01 + 2 | 0;
      var $src_02 = $13;
      var $i_03 = $16;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $19 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP16[$dest_1 >> 1] = $22;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 2 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 & 65535;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($8);
    var $_0 = $12 & 65535;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $20 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $3 = $1 + ($offset << 1) | 0;
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $5 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($4 | 0) == ($5 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = $3;
    var $9 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $10 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($8, $9, $10, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $12 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $13 = __ZN9JSContext7malloc_Ej($cx, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $17 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($13, $16, $17, 1);
    var $18 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($18 | 0) == 1 || ($18 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($18 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($18 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($18 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($18 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($18 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($18 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $13;
      var $dest_038 = $3;
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($21 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $13;
      var $dest_132 = $3;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $23 = $src_037 + 1 | 0;
    var $26 = $dest_038 + 2 | 0;
    HEAP16[$dest_038 >> 1] = HEAP8[$src_037] << 24 >> 24;
    var $27 = $i_036 + 1 | 0;
    var $28 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($27 >>> 0 < $28 >>> 0) {
      var $i_036 = $27;
      var $src_037 = $23;
      var $dest_038 = $26;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $30 = $src1_031 + 1 | 0;
    var $33 = $dest_132 + 2 | 0;
    HEAP16[$dest_132 >> 1] = HEAPU8[$src1_031] & 255;
    var $34 = $i2_030 + 1 | 0;
    var $35 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($34 >>> 0 < $35 >>> 0) {
      var $i2_030 = $34;
      var $src1_031 = $30;
      var $dest_132 = $33;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $38 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($38 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $13;
    var $dest_227 = $3;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $42 = $src3_026 + 2 | 0;
    var $43 = HEAP16[$src3_026 >> 1];
    var $44 = $dest_227 + 2 | 0;
    HEAP16[$dest_227 >> 1] = $43;
    var $45 = $i4_025 + 1 | 0;
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($45 >>> 0 < $46 >>> 0) {
      var $i4_025 = $45;
      var $src3_026 = $42;
      var $dest_227 = $44;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $49 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($49 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $13;
    var $dest_322 = $3;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $53 = $src5_021 + 2 | 0;
    var $54 = HEAP16[$src5_021 >> 1];
    var $55 = $dest_322 + 2 | 0;
    HEAP16[$dest_322 >> 1] = $54;
    var $56 = $i6_020 + 1 | 0;
    var $57 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($56 >>> 0 < $57 >>> 0) {
      var $i6_020 = $56;
      var $src5_021 = $53;
      var $dest_322 = $55;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $60 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($60 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $13;
    var $dest_417 = $3;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $64 = $src7_016 + 4 | 0;
    var $67 = $dest_417 + 2 | 0;
    HEAP16[$dest_417 >> 1] = HEAP32[$src7_016 >> 2] & 65535;
    var $68 = $i8_015 + 1 | 0;
    var $69 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($68 >>> 0 < $69 >>> 0) {
      var $i8_015 = $68;
      var $src7_016 = $64;
      var $dest_417 = $67;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $72 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($72 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $13;
    var $i10_011 = 0;
    var $dest_512 = $3;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $76 = $src9_010 + 4 | 0;
    var $79 = $dest_512 + 2 | 0;
    HEAP16[$dest_512 >> 1] = HEAP32[$src9_010 >> 2] & 65535;
    var $80 = $i10_011 + 1 | 0;
    var $81 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($80 >>> 0 < $81 >>> 0) {
      var $src9_010 = $76;
      var $i10_011 = $80;
      var $dest_512 = $79;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $84 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($84 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $3;
    var $src11_06 = $13;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $88 = $src11_06 + 4 | 0;
    var $91 = $dest_65 + 2 | 0;
    HEAP16[$dest_65 >> 1] = HEAPF32[$src11_06 >> 2] & -1;
    var $92 = $i12_07 + 1 | 0;
    var $93 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($92 >>> 0 < $93 >>> 0) {
      var $dest_65 = $91;
      var $src11_06 = $88;
      var $i12_07 = $92;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $96 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($96 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $3;
    var $src13_02 = $13;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $100 = $src13_02 + 8 | 0;
    var $101 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $103 = $dest_71 + 2 | 0;
    HEAP16[$dest_71 >> 1] = $101 & -1;
    var $104 = $i14_03 + 1 | 0;
    var $105 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($104 >>> 0 < $105 >>> 0) {
      var $dest_71 = $103;
      var $src13_02 = $100;
      var $i14_03 = $104;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($13);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE + 232 | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 236 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 1);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE + 232 | 0);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $9 = $8 + $offset | 0;
    var $10 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($9, $14, $15, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 1 || ($10 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($10 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($10 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($10 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($10 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit51 = $8 + ($17 + $offset) | 0;
    var $src_036 = $20;
    var $dest_037 = $9;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $23 = HEAP8[$src_036];
    var $24 = $dest_037 + 1 | 0;
    HEAP8[$dest_037] = $23;
    if (($24 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $src_036 + 1 | 0;
      var $dest_037 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit49 = $8 + ($17 + $offset) | 0;
    var $src1_031 = $27;
    var $dest_132 = $9;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $30 = HEAP8[$src1_031];
    var $31 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $30;
    if (($31 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $src1_031 + 1 | 0;
      var $dest_132 = $31;
      __label__ = 11;
      break;
    }
   case 12:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit47 = $8 + ($17 + $offset) | 0;
    var $src3_026 = $34;
    var $dest_227 = $9;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $40 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    if (($40 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $40;
      __label__ = 14;
      break;
    }
   case 15:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $43 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $8 + ($17 + $offset) | 0;
    var $src5_021 = $43;
    var $dest_322 = $9;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $49 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    if (($49 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $49;
      __label__ = 17;
      break;
    }
   case 18:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit43 = $8 + ($17 + $offset) | 0;
    var $src7_016 = $52;
    var $dest_417 = $9;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $58 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    if (($58 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $58;
      __label__ = 20;
      break;
    }
   case 21:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $61 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit41 = $8 + ($17 + $offset) | 0;
    var $src9_011 = $61;
    var $dest_512 = $9;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $67 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_011 >> 2] & 255;
    if (($67 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $67;
      __label__ = 23;
      break;
    }
   case 24:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $70 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit39 = $8 + ($17 + $offset) | 0;
    var $src11_05 = $70;
    var $dest_66 = $9;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $73 = $src11_05 + 4 | 0;
    var $74 = HEAPF32[$src11_05 >> 2];
    var $75 = $74 >= 0 ? Math.floor($74) : Math.ceil($74);
    var $76 = $dest_66 + 1 | 0;
    HEAP8[$dest_66] = $75;
    if (($76 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $73;
      var $dest_66 = $76;
      __label__ = 26;
      break;
    }
   case 27:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $79 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $8 + ($17 + $offset) | 0;
    var $dest_71 = $9;
    var $src13_02 = $79;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $82 = $src13_02 + 8 | 0;
    var $83 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $84 = $83 >= 0 ? Math.floor($83) : Math.ceil($83);
    var $85 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $84;
    if (($85 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $85;
      var $src13_02 = $82;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $3 = $2 + $offset | 0;
    var $4 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($6 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $lftr_limit = $2 + ($offset + $len) | 0;
    var $dest_01 = $3;
    var $src_02 = $10;
    __label__ = 5;
    break;
   case 5:
    var $src_02;
    var $dest_01;
    var $12 = $src_02 + 8 | 0;
    var $13 = __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    var $14 = $dest_01 + 1 | 0;
    HEAP8[$dest_01] = $13;
    if (($14 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $14;
      var $src_02 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP8[$dest_1] = $20;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 & 255;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __Z21js_DoubleToECMAUint32d($8);
    var $_0 = $12 & 255;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $21 = $20 >= 0 ? Math.floor($20) : Math.ceil($20);
    var $_0 = $21;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $2 = $1 + $offset | 0;
    var $3 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $8 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($2, $7, $8, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $11 = __ZN9JSContext7malloc_Ej($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($11, $14, $15, 1);
    var $16 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == 1 || ($16 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($16 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($16 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($16 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($16 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($17 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $11;
      var $dest_038 = $2;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $11;
      var $dest_132 = $2;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $21 = $src_037 + 1 | 0;
    var $22 = HEAP8[$src_037];
    var $23 = $dest_038 + 1 | 0;
    HEAP8[$dest_038] = $22;
    var $24 = $i_036 + 1 | 0;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($24 >>> 0 < $25 >>> 0) {
      var $i_036 = $24;
      var $src_037 = $21;
      var $dest_038 = $23;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $27 = $src1_031 + 1 | 0;
    var $28 = HEAP8[$src1_031];
    var $29 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $28;
    var $30 = $i2_030 + 1 | 0;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($30 >>> 0 < $31 >>> 0) {
      var $i2_030 = $30;
      var $src1_031 = $27;
      var $dest_132 = $29;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $34 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($34 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $11;
    var $dest_227 = $2;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $38 = $src3_026 + 2 | 0;
    var $41 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    var $42 = $i4_025 + 1 | 0;
    var $43 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($42 >>> 0 < $43 >>> 0) {
      var $i4_025 = $42;
      var $src3_026 = $38;
      var $dest_227 = $41;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($46 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $11;
    var $dest_322 = $2;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $50 = $src5_021 + 2 | 0;
    var $53 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    var $54 = $i6_020 + 1 | 0;
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($54 >>> 0 < $55 >>> 0) {
      var $i6_020 = $54;
      var $src5_021 = $50;
      var $dest_322 = $53;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $58 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($58 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $11;
    var $dest_417 = $2;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = $src7_016 + 4 | 0;
    var $65 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    var $66 = $i8_015 + 1 | 0;
    var $67 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($66 >>> 0 < $67 >>> 0) {
      var $i8_015 = $66;
      var $src7_016 = $62;
      var $dest_417 = $65;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($70 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $11;
    var $i10_011 = 0;
    var $dest_512 = $2;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $74 = $src9_010 + 4 | 0;
    var $77 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_010 >> 2] & 255;
    var $78 = $i10_011 + 1 | 0;
    var $79 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($78 >>> 0 < $79 >>> 0) {
      var $src9_010 = $74;
      var $i10_011 = $78;
      var $dest_512 = $77;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $82 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($82 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $2;
    var $src11_06 = $11;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $86 = $src11_06 + 4 | 0;
    var $87 = HEAPF32[$src11_06 >> 2];
    var $88 = $87 >= 0 ? Math.floor($87) : Math.ceil($87);
    var $89 = $dest_65 + 1 | 0;
    HEAP8[$dest_65] = $88;
    var $90 = $i12_07 + 1 | 0;
    var $91 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($90 >>> 0 < $91 >>> 0) {
      var $dest_65 = $89;
      var $src11_06 = $86;
      var $i12_07 = $90;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($94 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $2;
    var $src13_02 = $11;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $98 = $src13_02 + 8 | 0;
    var $99 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $100 = $99 >= 0 ? Math.floor($99) : Math.ceil($99);
    var $101 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $100;
    var $102 = $i14_03 + 1 | 0;
    var $103 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($102 >>> 0 < $103 >>> 0) {
      var $dest_71 = $101;
      var $src13_02 = $98;
      var $i14_03 = $102;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($11);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 16 | 0;
    var $2 = __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value9setObjectER8JSObject($vp, $2);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE($cx, $argc, $argv) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $byteOffset = __stackBase__ + 4;
    var $length = __stackBase__ + 8;
    HEAP32[$len >> 2] = 0;
    if (($argc | 0) == 0) {
      var $5 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj($argv, $len);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $5 = HEAP32[$len >> 2];
    __label__ = 4;
    break;
   case 4:
    var $5;
    var $6 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $9 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $6, 0, $5);
    var $_0 = $9;
    __label__ = 22;
    break;
   case 6:
    var $11 = __ZNK2JS5Value8isObjectEv($argv);
    if ($11) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 8:
    var $14 = __ZNK2JS5Value8toObjectEv($argv);
    var $15 = __Z15js_IsTypedArrayP8JSObject($14);
    if (($15 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $18 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($14);
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($18);
    var $20 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $23 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $20, 0, $19);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $26 = __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $23, $18, 0);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 12:
    var $_0 = $23;
    __label__ = 22;
    break;
   case 13:
    HEAP32[$byteOffset >> 2] = -1;
    HEAP32[$length >> 2] = -1;
    if ($argc >>> 0 > 1) {
      __label__ = 14;
      break;
    } else {
      var $48 = -1;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 14:
    var $31 = $argv + 8 | 0;
    var $32 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $31, $byteOffset);
    if ($32) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 15:
    var $34 = HEAPU32[$byteOffset >> 2];
    if (($34 | 0) < 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str163973 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 17:
    if ($argc >>> 0 > 2) {
      __label__ = 18;
      break;
    } else {
      var $48 = $34;
      var $47 = -1;
      __label__ = 21;
      break;
    }
   case 18:
    var $40 = $argv + 16 | 0;
    var $41 = __ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi($cx, $40, $length);
    if ($41) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 0;
      __label__ = 22;
      break;
    }
   case 19:
    var $43 = HEAPU32[$length >> 2];
    if (($43 | 0) < 0) {
      __label__ = 20;
      break;
    } else {
      var $48 = $34;
      var $47 = $43;
      __label__ = 21;
      break;
    }
   case 20:
    _JS_ReportErrorNumber($cx, 2, 0, 245, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str173974 | 0, tempInt));
    var $_0 = 0;
    __label__ = 22;
    break;
   case 21:
    var $47;
    var $48;
    var $49 = __ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $14, $48, $47);
    var $_0 = $49;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($count >>> 0 > 2147483646) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 17, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE.__str183975 | 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZN2js11ArrayBuffer6createEP9JSContexti($cx, $count);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $bufobj, $byteOffset, $len) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = __stackBase__ + 32;
    var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981($cx, __ZN2js10TypedArray11slowClassesE | 0);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAPU32[__ZN2js10TypedArray11slowClassesE + 4 >> 2] >>> 24;
    var $11 = __ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject7setTypeEPN2js5types10TypeObjectE($6, $11);
    __ZN2JSL10Int32ValueEi3996($1, 0);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 3, $1);
    __ZN2JSL11ObjectValueER8JSObject3997($2, $bufobj);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 4, $2);
    var $14 = __ZN8JSObject21arrayBufferDataOffsetEv($bufobj);
    var $15 = $14 + $byteOffset | 0;
    __ZN8JSObject10setPrivateEPv($6, $15);
    __ZN2JSL10Int32ValueEi3996($3, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 0, $3);
    __ZN2JSL10Int32ValueEi3996($4, $byteOffset);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 1, $4);
    __ZN2JSL10Int32ValueEi3996($5, $len);
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($6, 2, $5);
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    __ZN8JSObject8setClassEPN2js5ClassE($6, __ZN2js10TypedArray11fastClassesE);
    var $16 = $6 + 8 | 0;
    var $18 = HEAP32[$16 >> 2] | 4;
    HEAP32[$16 >> 2] = $18;
    var $_0 = $6;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j($cx, $thisTypedArrayObj, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
    var $3 = __ZN2js10TypedArray9getBufferEP8JSObject($1);
    if (($2 | 0) == ($3 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $1, $tarray, $offset);
    var $_0 = $6;
    __label__ = 30;
    break;
   case 3:
    var $8 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $9 = $8 + $offset | 0;
    var $10 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $11 = __ZN2js10TypedArray7getTypeEP8JSObject($1);
    if (($10 | 0) == ($11 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($9, $14, $15, 1);
    var $_0 = 1;
    __label__ = 30;
    break;
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($10 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($10 | 0) == 1 || ($10 | 0) == 8) {
      __label__ = 9;
      break;
    } else if (($10 | 0) == 2) {
      __label__ = 12;
      break;
    } else if (($10 | 0) == 3) {
      __label__ = 15;
      break;
    } else if (($10 | 0) == 4) {
      __label__ = 18;
      break;
    } else if (($10 | 0) == 5) {
      __label__ = 21;
      break;
    } else if (($10 | 0) == 6) {
      __label__ = 24;
      break;
    } else if (($10 | 0) == 7) {
      __label__ = 27;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 6:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit51 = $8 + ($17 + $offset) | 0;
    var $src_036 = $20;
    var $dest_037 = $9;
    __label__ = 8;
    break;
   case 8:
    var $dest_037;
    var $src_036;
    var $23 = HEAP8[$src_036];
    var $24 = $dest_037 + 1 | 0;
    HEAP8[$dest_037] = $23;
    if (($24 | 0) == ($lftr_limit51 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src_036 = $src_036 + 1 | 0;
      var $dest_037 = $24;
      __label__ = 8;
      break;
    }
   case 9:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit49 = $8 + ($17 + $offset) | 0;
    var $src1_031 = $27;
    var $dest_132 = $9;
    __label__ = 11;
    break;
   case 11:
    var $dest_132;
    var $src1_031;
    var $30 = HEAP8[$src1_031];
    var $31 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $30;
    if (($31 | 0) == ($lftr_limit49 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src1_031 = $src1_031 + 1 | 0;
      var $dest_132 = $31;
      __label__ = 11;
      break;
    }
   case 12:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $34 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit47 = $8 + ($17 + $offset) | 0;
    var $src3_026 = $34;
    var $dest_227 = $9;
    __label__ = 14;
    break;
   case 14:
    var $dest_227;
    var $src3_026;
    var $40 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    if (($40 | 0) == ($lftr_limit47 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src3_026 = $src3_026 + 2 | 0;
      var $dest_227 = $40;
      __label__ = 14;
      break;
    }
   case 15:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $43 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit45 = $8 + ($17 + $offset) | 0;
    var $src5_021 = $43;
    var $dest_322 = $9;
    __label__ = 17;
    break;
   case 17:
    var $dest_322;
    var $src5_021;
    var $49 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    if (($49 | 0) == ($lftr_limit45 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src5_021 = $src5_021 + 2 | 0;
      var $dest_322 = $49;
      __label__ = 17;
      break;
    }
   case 18:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $52 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit43 = $8 + ($17 + $offset) | 0;
    var $src7_016 = $52;
    var $dest_417 = $9;
    __label__ = 20;
    break;
   case 20:
    var $dest_417;
    var $src7_016;
    var $58 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    if (($58 | 0) == ($lftr_limit43 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src7_016 = $src7_016 + 4 | 0;
      var $dest_417 = $58;
      __label__ = 20;
      break;
    }
   case 21:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $61 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit41 = $8 + ($17 + $offset) | 0;
    var $src9_011 = $61;
    var $dest_512 = $9;
    __label__ = 23;
    break;
   case 23:
    var $dest_512;
    var $src9_011;
    var $67 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_011 >> 2] & 255;
    if (($67 | 0) == ($lftr_limit41 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src9_011 = $src9_011 + 4 | 0;
      var $dest_512 = $67;
      __label__ = 23;
      break;
    }
   case 24:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $70 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit39 = $8 + ($17 + $offset) | 0;
    var $src11_05 = $70;
    var $dest_66 = $9;
    __label__ = 26;
    break;
   case 26:
    var $dest_66;
    var $src11_05;
    var $76 = $dest_66 + 1 | 0;
    HEAP8[$dest_66] = HEAPF32[$src11_05 >> 2] & -1;
    if (($76 | 0) == ($lftr_limit39 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $src11_05 = $src11_05 + 4 | 0;
      var $dest_66 = $76;
      __label__ = 26;
      break;
    }
   case 27:
    if (($17 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $79 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $lftr_limit = $8 + ($17 + $offset) | 0;
    var $dest_71 = $9;
    var $src13_02 = $79;
    __label__ = 29;
    break;
   case 29:
    var $src13_02;
    var $dest_71;
    var $83 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $85 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $83 & -1;
    if (($85 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $dest_71 = $85;
      var $src13_02 = $src13_02 + 8 | 0;
      __label__ = 29;
      break;
    }
   case 30:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii($cx, $other, $byteOffsetInt, $lengthInt) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len1 = __stackBase__;
    var $1 = __ZNK8JSObject13isArrayBufferEv($other);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = ($byteOffsetInt | 0) < 0 ? 0 : $byteOffsetInt;
    var $5 = __ZN8JSObject21arrayBufferByteLengthEv($other);
    if ($4 >>> 0 > $5 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $_lengthInt = ($lengthInt | 0) < 0 ? $5 - $4 | 0 : $lengthInt;
    if ($_lengthInt >>> 0 < 2147483647 & $4 >>> 0 < (2147483647 - $_lengthInt | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    if (($_lengthInt + $4 | 0) >>> 0 > $5 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ReportErrorNumber($cx, 2, 0, 246, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 8:
    var $20 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $other, $4, $_lengthInt);
    var $_0 = $20;
    __label__ = 14;
    break;
   case 9:
    var $22 = __Z20js_GetLengthPropertyP9JSContextP8JSObjectPj($cx, $other, $len1);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $25 = HEAP32[$len1 >> 2];
    var $26 = __ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj($cx, $25);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $29 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $26, 0, $25);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $32 = __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $29, $other, $25, 0);
    if ($32) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $_0 = $29;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj($cx, $thisTypedArrayObj, $ar, $len, $offset) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZN2js10TypedArray13getTypedArrayEP8JSObject($thisTypedArrayObj);
    var $2 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($1);
    var $3 = $2 + $offset | 0;
    var $4 = __ZNK8JSObject12isDenseArrayEv($ar);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = __ZN8JSObject30getDenseArrayInitializedLengthEv($ar);
    if ($6 >>> 0 < $len >>> 0) {
      var $i1_0 = 0;
      var $dest_1 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($len | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = __ZN8JSObject21getDenseArrayElementsEv($ar);
    var $lftr_limit = $2 + ($offset + $len) | 0;
    var $dest_01 = $3;
    var $src_02 = $10;
    __label__ = 5;
    break;
   case 5:
    var $src_02;
    var $dest_01;
    var $12 = $src_02 + 8 | 0;
    var $13 = __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $src_02);
    var $14 = $dest_01 + 1 | 0;
    HEAP8[$dest_01] = $13;
    if (($14 | 0) == ($lftr_limit | 0)) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $dest_01 = $14;
      var $src_02 = $12;
      __label__ = 5;
      break;
    }
   case 6:
    var $dest_1;
    var $i1_0;
    if ($i1_0 >>> 0 < $len >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE($ar, $cx, $i1_0, $v);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v);
    HEAP8[$dest_1] = $20;
    var $i1_0 = $i1_0 + 1 | 0;
    var $dest_1 = $dest_1 + 1 | 0;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $dval = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($v);
    var $_0 = $3 & 255;
    __label__ = 9;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($v);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($v);
    var $9 = __ZL15JSDOUBLE_IS_NaNd3989($8);
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    var $12 = __ZL20js_DoubleToECMAInt32d4007($8);
    var $_0 = $12 & 255;
    __label__ = 9;
    break;
   case 6:
    var $15 = __ZNK2JS5Value11isPrimitiveEv($v);
    if ($15) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $17 = __ZNK2JS5Value7isMagicEv($v);
    if ($17) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $v, $dval);
    var $20 = (tempDoubleI32[0] = HEAP32[$dval >> 2], tempDoubleI32[1] = HEAP32[$dval + 4 >> 2], tempDoubleF64[0]);
    var $_0 = $20 & -1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK13uint8_clampedcvhEv($this) {
  return HEAP8[$this | 0];
}

function __ZN13uint8_clampedC2ERKS_($this, $other) {
  var $3 = HEAP8[$other | 0];
  HEAP8[$this | 0] = $3;
  return;
}

function __ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j($cx, $self, $tarray, $offset) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($self);
    var $2 = $1 + $offset | 0;
    var $3 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    var $4 = __ZN2js10TypedArray7getTypeEP8JSObject($self);
    if (($3 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $8 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _llvm_memmove_p0i8_p0i8_i32($2, $7, $8, 1, 0);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 3:
    var $10 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    var $11 = __ZN9JSContext7malloc_Ej($cx, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 28;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($tarray);
    var $15 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
    _memcpy($11, $14, $15, 1);
    var $16 = __ZN2js10TypedArray7getTypeEP8JSObject($tarray);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($16 | 0) == 1 || ($16 | 0) == 8) {
      __label__ = 6;
      break;
    } else if (($16 | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 3) {
      __label__ = 12;
      break;
    } else if (($16 | 0) == 4) {
      __label__ = 15;
      break;
    } else if (($16 | 0) == 5) {
      __label__ = 18;
      break;
    } else if (($16 | 0) == 6) {
      __label__ = 21;
      break;
    } else if (($16 | 0) == 7) {
      __label__ = 24;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 5:
    var $17 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($17 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i_036 = 0;
      var $src_037 = $11;
      var $dest_038 = $2;
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($19 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $i2_030 = 0;
      var $src1_031 = $11;
      var $dest_132 = $2;
      __label__ = 8;
      break;
    }
   case 7:
    var $dest_038;
    var $src_037;
    var $i_036;
    var $21 = $src_037 + 1 | 0;
    var $22 = HEAP8[$src_037];
    var $23 = $dest_038 + 1 | 0;
    HEAP8[$dest_038] = $22;
    var $24 = $i_036 + 1 | 0;
    var $25 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($24 >>> 0 < $25 >>> 0) {
      var $i_036 = $24;
      var $src_037 = $21;
      var $dest_038 = $23;
      __label__ = 7;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 8:
    var $dest_132;
    var $src1_031;
    var $i2_030;
    var $27 = $src1_031 + 1 | 0;
    var $28 = HEAP8[$src1_031];
    var $29 = $dest_132 + 1 | 0;
    HEAP8[$dest_132] = $28;
    var $30 = $i2_030 + 1 | 0;
    var $31 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($30 >>> 0 < $31 >>> 0) {
      var $i2_030 = $30;
      var $src1_031 = $27;
      var $dest_132 = $29;
      __label__ = 8;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 9:
    var $34 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($34 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $i4_025 = 0;
    var $src3_026 = $11;
    var $dest_227 = $2;
    __label__ = 11;
    break;
   case 11:
    var $dest_227;
    var $src3_026;
    var $i4_025;
    var $38 = $src3_026 + 2 | 0;
    var $41 = $dest_227 + 1 | 0;
    HEAP8[$dest_227] = HEAP16[$src3_026 >> 1] & 255;
    var $42 = $i4_025 + 1 | 0;
    var $43 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($42 >>> 0 < $43 >>> 0) {
      var $i4_025 = $42;
      var $src3_026 = $38;
      var $dest_227 = $41;
      __label__ = 11;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 12:
    var $46 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($46 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i6_020 = 0;
    var $src5_021 = $11;
    var $dest_322 = $2;
    __label__ = 14;
    break;
   case 14:
    var $dest_322;
    var $src5_021;
    var $i6_020;
    var $50 = $src5_021 + 2 | 0;
    var $53 = $dest_322 + 1 | 0;
    HEAP8[$dest_322] = HEAP16[$src5_021 >> 1] & 255;
    var $54 = $i6_020 + 1 | 0;
    var $55 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($54 >>> 0 < $55 >>> 0) {
      var $i6_020 = $54;
      var $src5_021 = $50;
      var $dest_322 = $53;
      __label__ = 14;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 15:
    var $58 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($58 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i8_015 = 0;
    var $src7_016 = $11;
    var $dest_417 = $2;
    __label__ = 17;
    break;
   case 17:
    var $dest_417;
    var $src7_016;
    var $i8_015;
    var $62 = $src7_016 + 4 | 0;
    var $65 = $dest_417 + 1 | 0;
    HEAP8[$dest_417] = HEAP32[$src7_016 >> 2] & 255;
    var $66 = $i8_015 + 1 | 0;
    var $67 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($66 >>> 0 < $67 >>> 0) {
      var $i8_015 = $66;
      var $src7_016 = $62;
      var $dest_417 = $65;
      __label__ = 17;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 18:
    var $70 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($70 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $src9_010 = $11;
    var $i10_011 = 0;
    var $dest_512 = $2;
    __label__ = 20;
    break;
   case 20:
    var $dest_512;
    var $i10_011;
    var $src9_010;
    var $74 = $src9_010 + 4 | 0;
    var $77 = $dest_512 + 1 | 0;
    HEAP8[$dest_512] = HEAP32[$src9_010 >> 2] & 255;
    var $78 = $i10_011 + 1 | 0;
    var $79 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($78 >>> 0 < $79 >>> 0) {
      var $src9_010 = $74;
      var $i10_011 = $78;
      var $dest_512 = $77;
      __label__ = 20;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 21:
    var $82 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($82 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $dest_65 = $2;
    var $src11_06 = $11;
    var $i12_07 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i12_07;
    var $src11_06;
    var $dest_65;
    var $86 = $src11_06 + 4 | 0;
    var $89 = $dest_65 + 1 | 0;
    HEAP8[$dest_65] = HEAPF32[$src11_06 >> 2] & -1;
    var $90 = $i12_07 + 1 | 0;
    var $91 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($90 >>> 0 < $91 >>> 0) {
      var $dest_65 = $89;
      var $src11_06 = $86;
      var $i12_07 = $90;
      __label__ = 23;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 24:
    var $94 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if (($94 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $dest_71 = $2;
    var $src13_02 = $11;
    var $i14_03 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i14_03;
    var $src13_02;
    var $dest_71;
    var $98 = $src13_02 + 8 | 0;
    var $99 = (tempDoubleI32[0] = HEAP32[$src13_02 >> 2], tempDoubleI32[1] = HEAP32[$src13_02 + 4 >> 2], tempDoubleF64[0]);
    var $101 = $dest_71 + 1 | 0;
    HEAP8[$dest_71] = $99 & -1;
    var $102 = $i14_03 + 1 | 0;
    var $103 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
    if ($102 >>> 0 < $103 >>> 0) {
      var $dest_71 = $101;
      var $src13_02 = $98;
      var $i14_03 = $102;
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2js10Foreground5free_EPv($11);
    var $_0 = 1;
    __label__ = 28;
    break;
   case 28:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j["X"] = 1;

function __ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $d = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value7toInt32Ev($vp);
    __ZN13uint8_clampedC1Ei($1, $5);
    __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($tarray, $index, $1);
    __label__ = 15;
    break;
   case 3:
    var $7 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $9 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $9, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $9;
    __label__ = 14;
    break;
   case 5:
    var $11 = __ZNK2JS5Value6isNullEv($vp);
    if ($11) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = 0;
    __label__ = 14;
    break;
   case 7:
    var $14 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $16 = __ZNK2JS5Value8isStringEv($vp);
    if ($16) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $18 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $29 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $20 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $22 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $22, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $22;
    __label__ = 14;
    break;
   case 12:
    var $24 = __ZNK2JS5Value9toBooleanEv($vp);
    var $25 = $24 & 1;
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $25;
    __label__ = 14;
    break;
   case 13:
    var $27 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $27, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $29 = $27;
    __label__ = 14;
    break;
   case 14:
    var $29;
    __ZN13uint8_clampedC1Ed($2, $29);
    __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($tarray, $index, $2);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  var $3 = $1 + $index | 0;
  var $4 = __ZN13uint8_clampedaSERKS_($3, $val);
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  __ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj($1, $tarray, $index);
  var $2 = __ZNK13uint8_clampedcvhEv($1);
  var $3 = $2 & 255;
  __ZN2JS5Value8setInt32Ei($vp, $3);
  STACKTOP = __stackBase__;
  return;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj($agg_result, $obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  var $3 = $1 + $index | 0;
  __ZN13uint8_clampedC1ERKS_($agg_result, $3);
  return;
}

function __ZN13uint8_clampedC1ERKS_($this, $other) {
  __ZN13uint8_clampedC2ERKS_($this, $other);
  return;
}

function __ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 | 0;
    __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($tarray, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  var $3 = $1 + ($index << 3) | 0;
  tempDoubleF64[0] = $val, HEAP32[$3 >> 2] = tempDoubleI32[0], HEAP32[$3 + 4 >> 2] = tempDoubleI32[1];
  return;
}

function __ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 | 0;
    __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($tarray, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAPF32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($tarray, $index, $3);
    __label__ = 15;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $7;
    __label__ = 14;
    break;
   case 5:
    var $9 = __ZNK2JS5Value6isNullEv($vp);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = 0;
    __label__ = 14;
    break;
   case 7:
    var $12 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $14 = __ZNK2JS5Value8isStringEv($vp);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $16 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $27 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $18 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $20 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $20;
    __label__ = 14;
    break;
   case 12:
    var $22 = __ZNK2JS5Value9toBooleanEv($vp);
    var $23 = $22 & 1;
    tempDoubleF64[0] = $23, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $23;
    __label__ = 14;
    break;
   case 13:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $25;
    __label__ = 14;
    break;
   case 14:
    var $27;
    var $28 = __Z21js_DoubleToECMAUint32d($27);
    __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($tarray, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($tarray, $index, $3);
    __label__ = 15;
    break;
   case 3:
    var $5 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $7 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $7;
    __label__ = 14;
    break;
   case 5:
    var $9 = __ZNK2JS5Value6isNullEv($vp);
    if ($9) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = 0;
    __label__ = 14;
    break;
   case 7:
    var $12 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($12) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $14 = __ZNK2JS5Value8isStringEv($vp);
    if ($14) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $16 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $27 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $18 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $20 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $20;
    __label__ = 14;
    break;
   case 12:
    var $22 = __ZNK2JS5Value9toBooleanEv($vp);
    var $23 = $22 & 1;
    tempDoubleF64[0] = $23, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $23;
    __label__ = 14;
    break;
   case 13:
    var $25 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $25, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $27 = $25;
    __label__ = 14;
    break;
   case 14:
    var $27;
    var $28 = __ZL20js_DoubleToECMAInt32d4007($27);
    __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($tarray, $index, $28);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP32[$1 + ($index << 2) >> 2] = $val;
  return;
}

function __ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 & 65535;
    __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __Z21js_DoubleToECMAUint32d($28);
    var $30 = $29 & 65535;
    __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($tarray, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP16[$1 + ($index << 1) >> 1] = $val;
  return;
}

function __ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = $1 & 65535;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP16[$1 + ($index << 1) >> 1];
}

function __ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 & 65535;
    __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __ZL20js_DoubleToECMAInt32d4007($28);
    var $30 = $29 & 65535;
    __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($tarray, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP16[$1 + ($index << 1) >> 1] = $val;
  return;
}

function __ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = $1 << 16 >> 16;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP16[$1 + ($index << 1) >> 1];
}

function __ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 & 255;
    __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __Z21js_DoubleToECMAUint32d($28);
    var $30 = $29 & 255;
    __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($tarray, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP8[$1 + $index | 0] = $val;
  return;
}

function __ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = $1 & 255;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP8[$1 + $index | 0];
}

function __ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $tarray, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = __ZNK2JS5Value7isInt32Ev($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value7toInt32Ev($vp);
    var $4 = $3 & 255;
    __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($tarray, $index, $4);
    __label__ = 15;
    break;
   case 3:
    var $6 = __ZNK2JS5Value8isDoubleEv($vp);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = __ZNK2JS5Value8toDoubleEv($vp);
    tempDoubleF64[0] = $8, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $8;
    __label__ = 14;
    break;
   case 5:
    var $10 = __ZNK2JS5Value6isNullEv($vp);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    tempDoubleF64[0] = 0, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = 0;
    __label__ = 14;
    break;
   case 7:
    var $13 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($13) {
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 8:
    var $15 = __ZNK2JS5Value8isStringEv($vp);
    if ($15) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $17 = __ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd($cx, $vp, $d);
    var $_pre = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $28 = $_pre;
    __label__ = 14;
    break;
   case 10:
    var $19 = __ZNK2JS5Value11isUndefinedEv($vp);
    if ($19) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $21 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $21, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $21;
    __label__ = 14;
    break;
   case 12:
    var $23 = __ZNK2JS5Value9toBooleanEv($vp);
    var $24 = $23 & 1;
    tempDoubleF64[0] = $24, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $24;
    __label__ = 14;
    break;
   case 13:
    var $26 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $26, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $28 = $26;
    __label__ = 14;
    break;
   case 14:
    var $28;
    var $29 = __ZL20js_DoubleToECMAInt32d4007($28);
    var $30 = $29 & 255;
    __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($tarray, $index, $30);
    __label__ = 15;
    break;
   case 15:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja($obj, $index, $val) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  HEAP8[$1 + $index | 0] = $val;
  return;
}

function __ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE($cx, $tarray, $index, $vp) {
  var $1 = __ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj($tarray, $index);
  var $2 = $1 << 24 >> 24;
  __ZN2JS5Value8setInt32Ei($vp, $2);
  return;
}

function __ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj($obj, $index) {
  var $1 = __ZN2js10TypedArray13getDataOffsetEP8JSObject($obj);
  return HEAP8[$1 + $index | 0];
}

function __ZL14JSID_FROM_BITSj4031($bits) {
  return $bits;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js2gcL15GetGCObjectKindEjb4033($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __ZN2js10TypedArray13getByteOffsetEP8JSObject($obj) {
  var $1 = __ZNK8JSObject12getFixedSlotEj($obj, 1);
  var $2 = __ZNK2JS5Value7toInt32Ev($1);
  return $2;
}

function __ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 3) | 0;
  var $6 = __ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 2) | 0;
  var $6 = __ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 1) | 0;
  var $6 = __ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $5 = $3 + ($begin << 1) | 0;
  var $6 = __ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $5, $2);
  return $6;
}

function __ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj($cx, $tarray, $begin, $end) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  var $2 = $end - $begin | 0;
  var $3 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  var $4 = $3 + $begin | 0;
  var $5 = __ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj($cx, $1, $4, $2);
  return $5;
}

function __Z14getLengthValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray9getLengthEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z18getByteLengthValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray13getByteLengthEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z18getByteOffsetValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray13getByteOffsetEP8JSObject($tarray);
  __ZN2JSL10Int32ValueEi3996($agg_result, $1);
  return;
}

function __Z14getBufferValueP8JSObject($agg_result, $tarray) {
  var $1 = __ZN2js10TypedArray9getBufferEP8JSObject($tarray);
  __ZN2JSL11ObjectValueER8JSObject3997($agg_result, $1);
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032($cx, $proto) {
  var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4033($3);
  var $5 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034($cx, $proto, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034($cx, $proto, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = ($proto | 0) != 0;
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $5 = __ZN2js5types15emptyTypeObjectE;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $5 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $5;
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($1) {
      __label__ = 5;
      break;
    } else {
      var $12 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $10 = __ZNK8JSObject9getParentEv($proto);
    var $12 = $10;
    __label__ = 6;
    break;
   case 6:
    var $12;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, __ZN2js11ObjectClassE, $5, $12, 0, (__ZN2js11ObjectClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $13 = __ZNK2js5Class8isNativeEv(__ZN2js11ObjectClassE);
    if ($13) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $15 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037($cx, $6, $5, $kind);
    if ($15) {
      var $_0 = $6;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 0;
    __label__ = 10;
    break;
   case 9:
    __ZN8JSObject21setSharedNonNativeMapEv($6);
    var $_0 = $6;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037($cx, $obj, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAPU32[__ZN2js11ObjectClassE + 4 >> 2] >>> 8 & 255;
    var $4 = __ZNK8JSObject8numSlotsEv($obj);
    if ($3 >>> 0 > $4 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = $obj;
    var $8 = $cx;
    var $9 = __ZN8JSObject10allocSlotsEP9JSContextj($7, $8, $3);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $11 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($type, __ZN2js11ObjectClassE);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($type, $cx, __ZN2js11ObjectClassE, $kind);
    var $empty_0 = $13;
    __label__ = 6;
    break;
   case 5:
    var $15 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($cx, __ZN2js11ObjectClassE);
    var $empty_0 = $15;
    __label__ = 6;
    break;
   case 6:
    var $empty_0;
    if (($empty_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($obj, $empty_0 | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = __ZNK9JSContext5hasfpEv($cx);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $8;
    var $9 = $cx;
    var $10 = $global;
    var $11 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($9, $10);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $19 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZNK9JSContext2fpEv($cx);
    var $14 = __ZNK2js10StackFrame10scopeChainEv($13);
    var $15 = $14;
    var $16 = __ZNK8JSObject9getGlobalEv($15);
    var $17 = $16;
    HEAP32[$global >> 2] = $17;
    var $19 = $17;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $19, $20);
    var $21 = __ZNK2JS5Value8isObjectEv($1);
    if ($21) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $23 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $23;
    var $31 = $23;
    __label__ = 9;
    break;
   case 7:
    var $25 = $cx;
    var $27 = $proto;
    var $28 = $clasp;
    var $29 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($25, $19, $4, $27, $28);
    if ($29) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $31 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $31;
    var $32 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042($cx, $clasp, $31, $19, $kind);
    var $_0 = $32;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, $clasp, $1, $parent, 0, $7);
    var $8 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, $clasp, $kind);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $11);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_Assert($s, $file, $ln) {
  var __stackBase__ = STACKTOP;
  var $1 = HEAP32[_stderr >> 2];
  var $2 = _fprintf($1, STRING_TABLE.__str4046 | 0, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = $s, HEAP32[tempInt + 4 >> 2] = $file, HEAP32[tempInt + 8 >> 2] = $ln, tempInt));
  var $3 = HEAP32[_stderr >> 2];
  var $4 = _fflush($3);
  __ZL9CrashInJSv();
  STACKTOP = __stackBase__;
  return;
}

function __ZL9CrashInJSv() {
  var $1 = _raise(6);
  return;
}

function __ZN2js13WatchpointMap4initEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($1, 0);
  return $2;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($1, $len);
  return $2;
}

function __ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_($this, $cx, $obj, $id, $handler, $closure) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $w = __stackBase__;
    var $1 = __stackBase__ + 12;
    __ZN8JSObject10setWatchedEP9JSContext($obj, $cx);
    HEAP32[$w >> 2] = $handler;
    HEAP32[$w + 4 >> 2] = $closure;
    HEAP8[$w + 8 | 0] = 0;
    var $5 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    var $6 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($5, $1, $w);
    if (($6 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    __Z20js_ReportOutOfMemoryP9JSContext($cx);
    var $_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setWatchedEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7watchedEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $this + 8 | 0;
    var $6 = HEAP32[$4 >> 2] | 8192;
    HEAP32[$4 >> 2] = $6;
    __ZN8JSObject16generateOwnShapeEP9JSContext($this, $cx);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($2);
    var $9 = $7 + 8 | 0;
    var $10 = $v;
    HEAP32[$9 >> 2] = HEAP32[$10 >> 2];
    HEAP32[$9 + 4 >> 2] = HEAP32[$10 + 4 >> 2];
    HEAP32[$9 + 8 >> 2] = HEAP32[$10 + 8 >> 2];
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($2);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($2);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js8WatchKeyC1EP8JSObjecti($this, $obj, $id) {
  __ZN2js8WatchKeyC2EP8JSObjecti($this, $obj, $id);
  return;
}

function __ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_($this, $obj, $id, $handlerp, $closurep) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $4 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $4, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($handlerp | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
    var $13 = HEAP32[$11 + 8 >> 2];
    HEAP32[$handlerp >> 2] = $13;
    __label__ = 4;
    break;
   case 4:
    if (($closurep | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
    var $19 = HEAP32[$17 + 12 >> 2];
    HEAP32[$closurep >> 2] = $19;
    __label__ = 6;
    break;
   case 6:
    var $22 = HEAP32[$p >> 2];
    HEAP32[$3 >> 2] = $22;
    __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($4, $3);
    __label__ = 7;
    break;
   case 7:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 270,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js13WatchpointMap13unwatchObjectEP8JSObject($this, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($r, $1);
    var $2 = $r | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($r);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($2);
    if ((HEAP32[$4 >> 2] | 0) == ($obj | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($r);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($2);
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($2);
    if ($10) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this);
  return;
}

function __ZN2js13WatchpointMap5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($1);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($1);
  return;
}

function __ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE($this, $cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 68;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $holder = __stackBase__ + 20;
    var $3 = __stackBase__ + 40;
    var $old = __stackBase__ + 44;
    var $method = __stackBase__ + 52;
    var $4 = __stackBase__ + 60;
    var $5 = $this | 0;
    __ZN2js8WatchKeyC1EP8JSObjecti($1, $obj, $id);
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($p, $5, $1);
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $p);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      var $_1 = 1;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
    if ((HEAP8[$10 + 16 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      var $_1 = 1;
      __label__ = 12;
      break;
    }
   case 3:
    var $17 = HEAP32[$p >> 2];
    HEAP32[$3 >> 2] = $17;
    __ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($holder, $5, $3);
    var $19 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
    var $21 = HEAP32[$19 + 8 >> 2];
    var $23 = HEAP32[$19 + 12 >> 2];
    __ZN2JS5Value12setUndefinedEv($old);
    var $24 = __ZNK8JSObject8isNativeEv($obj);
    if ($24) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $26 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    if (($26 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $30 = HEAP32[$26 + 24 >> 2];
    var $31 = __ZNK8JSObject12containsSlotEj($obj, $30);
    if ($31) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $33 = __ZNK2js5Shape8isMethodEv($26);
    if ($33) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $35 = __ZNK2js5Shape12methodObjectEv($26);
    __ZN2JSL11ObjectValueER8JSObject4064($method, $35);
    var $36 = __ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE($obj, $cx, $26, $method);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $39 = __ZN8JSObject12nativeLookupEP9JSContexti($obj, $cx, $id);
    var $40 = $method | 0;
    var $st$2$0 = $40 | 0;
    var $41$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $40 + 4 | 0;
    var $41$1 = HEAP32[$st$2$1 >> 2];
    var $42 = $old | 0;
    var $st$7$0 = $42 | 0;
    HEAP32[$st$7$0 >> 2] = $41$0;
    var $st$7$1 = $42 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $41$1;
    __label__ = 10;
    break;
   case 9:
    var $44 = __ZNK8JSObject13nativeGetSlotEj($obj, $30);
    var $45 = $44 | 0;
    var $st$2$0 = $45 | 0;
    var $46$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $45 + 4 | 0;
    var $46$1 = HEAP32[$st$2$1 >> 2];
    var $47 = $old | 0;
    var $st$7$0 = $47 | 0;
    HEAP32[$st$7$0 >> 2] = $46$0;
    var $st$7$1 = $47 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $46$1;
    __label__ = 10;
    break;
   case 10:
    var $48 = $old | 0;
    var $49$0 = HEAP32[$48 >> 2];
    var $49$1 = HEAP32[$48 + 4 >> 2];
    var $50 = $4 | 0;
    HEAP32[$50 >> 2] = $49$0;
    HEAP32[$50 + 4 >> 2] = $49$1;
    var $51 = $23;
    var $52 = FUNCTION_TABLE[$21]($cx, $obj, $id, $4, $vp, $51);
    var $_0 = ($52 | 0) != 0;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN15AutoEntryHolderD1Ev($holder);
    var $_1 = $_0;
    __label__ = 12;
    break;
   case 12:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  __ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL11ObjectValueER8JSObject4064($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN15AutoEntryHolderD1Ev($this) {
  __ZN15AutoEntryHolderD2Ev($this);
  return;
}

function __ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer($trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$trc >> 2] + 52 >> 2];
    var $6 = HEAP32[$4 + 144080 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = HEAP32[$6 + 1984 >> 2];
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($10, $trc);
    var $_0 = $13;
    __label__ = 9;
    break;
   case 4:
    var $15 = $4 + 4 | 0;
    var $16 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($15);
    var $17 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($15);
    if (($16 | 0) == ($17 | 0)) {
      var $mutated_0_lcssa = 0;
      __label__ = 8;
      break;
    } else {
      var $mutated_01 = 0;
      var $c_02 = $16;
      __label__ = 5;
      break;
    }
   case 5:
    var $c_02;
    var $mutated_01;
    var $21 = HEAP32[HEAP32[$c_02 >> 2] + 1984 >> 2];
    if (($21 | 0) == 0) {
      var $mutated_1 = $mutated_01;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($21, $trc);
    var $mutated_1 = $24 & 1 | $mutated_01 & 1;
    __label__ = 7;
    break;
   case 7:
    var $mutated_1;
    var $29 = $c_02 + 4 | 0;
    var $30 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($15);
    if (($29 | 0) == ($30 | 0)) {
      var $mutated_0_lcssa = $mutated_1;
      __label__ = 8;
      break;
    } else {
      var $mutated_01 = $mutated_1;
      var $c_02 = $29;
      __label__ = 5;
      break;
    }
   case 8:
    var $mutated_0_lcssa;
    var $_0 = ($mutated_0_lcssa & 1) << 24 >> 24 != 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13WatchpointMap15markIterativelyEP8JSTracer($this, $trc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $2 = HEAP32[$trc >> 2];
    var $3 = $this | 0;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($r, $3);
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($4) {
      var $marked_0_lcssa = 0;
      __label__ = 9;
      break;
    } else {
      var $marked_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $marked_01;
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($r);
    var $6 = $5 | 0;
    var $8 = HEAP32[$6 >> 2];
    var $9 = __Z20IsAboutToBeFinalizedP9JSContextPKv($2, $8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $marked_1 = $marked_01;
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP8[$5 + 16 | 0] & 1) << 24 >> 24 == 0) {
      var $marked_2 = $marked_01;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = HEAP32[$6 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $16, undef);
    var $marked_1 = 1;
    __label__ = 5;
    break;
   case 5:
    var $marked_1;
    var $18 = HEAP32[$5 + 4 >> 2];
    __ZN2js2gc6MarkIdEP8JSTraceriPKc($trc, $18, undef);
    var $19 = $5 + 12 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      var $marked_2 = $marked_1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = $20;
    var $24 = __Z20IsAboutToBeFinalizedP9JSContextPKv($2, $23);
    if ($24) {
      __label__ = 7;
      break;
    } else {
      var $marked_2 = $marked_1;
      __label__ = 8;
      break;
    }
   case 7:
    var $26 = HEAP32[$19 >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $26, undef);
    var $marked_2 = 1;
    __label__ = 8;
    break;
   case 8:
    var $marked_2;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($r);
    var $28 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($r);
    if ($28) {
      var $marked_0_lcssa = $marked_2;
      __label__ = 9;
      break;
    } else {
      var $marked_01 = $marked_2;
      __label__ = 2;
      break;
    }
   case 9:
    var $marked_0_lcssa;
    STACKTOP = __stackBase__;
    return ($marked_0_lcssa & 1) << 24 >> 24 != 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $1);
  return;
}

function __ZN2js13WatchpointMap8sweepAllEP9JSContext($cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$cx + 52 >> 2];
    var $4 = HEAP32[$2 + 144080 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$4 + 1984 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js13WatchpointMap5sweepEP9JSContext($8, $cx);
    __label__ = 8;
    break;
   case 4:
    var $12 = $2 + 4 | 0;
    var $13 = __ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv($12);
    var $14 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($12);
    if (($13 | 0) == ($14 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $c_01 = $13;
      __label__ = 5;
      break;
    }
   case 5:
    var $c_01;
    var $18 = HEAP32[HEAP32[$c_01 >> 2] + 1984 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2js13WatchpointMap5sweepEP9JSContext($18, $cx);
    __label__ = 7;
    break;
   case 7:
    var $22 = $c_01 + 4 | 0;
    var $23 = __ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv($12);
    if (($22 | 0) == ($23 | 0)) {
      __label__ = 8;
      break;
    } else {
      var $c_01 = $22;
      __label__ = 5;
      break;
    }
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13WatchpointMap5sweepEP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $r = __stackBase__;
    var $1 = $this | 0;
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_($r, $1);
    var $2 = $r | 0;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev($r);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $4 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv($2);
    var $7 = HEAP32[$4 >> 2];
    var $8 = __Z20IsAboutToBeFinalizedP9JSContextPKv($cx, $7);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv($r);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv($2);
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv($2);
    if ($11) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 20 >> 2];
  var $5 = $2 + HEAP32[$this + 4 >> 2] * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 20 >> 2];
    var $6 = HEAP32[$this + 4 >> 2];
    var $7 = $4 + $6 * 24 | 0;
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $4;
      __label__ = 2;
      break;
    }
   case 2:
    var $e_01;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($2);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_($1, $2);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($e_01, $1);
    var $9 = $e_01 + 24 | 0;
    if (($9 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $e_01 = $9;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[$this + 16 >> 2] = 0;
    HEAP32[$this + 8 >> 2] = 0;
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 4 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv($rhs);
  var $8 = $7 + 4 | 0;
  __ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_($1, $8);
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($this) {
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev($this);
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev($this) {
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  HEAP32[$2 + 8 >> 2] = 0;
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2jsL6HashIdEi4071($id) {
  return $id * -1640531527 | 0;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_10WatchpointEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 8 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 4 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 4 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this) {
  return (HEAP32[$this + 16 >> 2] + HEAP32[$this + 8 >> 2] | 0) >>> 0 >= (HEAP32[$this + 4 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_($k, $l) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$k >> 2] | 0) == (HEAP32[$l >> 2] | 0)) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $13 = (HEAP32[$k + 4 >> 2] | 0) == (HEAP32[$l + 4 >> 2] | 0);
    __label__ = 3;
    break;
   case 3:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZN2js8WatchKeyC2EP8JSObjecti($this, $obj, $id) {
  HEAP32[$this >> 2] = $obj;
  HEAP32[$this + 4 >> 2] = $id;
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_($1, $4);
  var $5 = __ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev($1);
  var $6 = $5;
  var $7 = $this;
  var $8$0 = HEAP32[$6 >> 2];
  var $8$1 = HEAP32[$6 + 4 >> 2];
  HEAP32[$7 >> 2] = $8$0;
  HEAP32[$7 + 4 >> 2] = $8$1;
  var $9 = $this + 8 | 0;
  var $10 = __ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv($rhs);
  var $11 = $10 + 8 | 0;
  __ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_($2, $11);
  var $12 = __ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev($2);
  var $13 = $9;
  var $14 = $12;
  HEAP32[$13 >> 2] = HEAP32[$14 >> 2];
  HEAP32[$13 + 4 >> 2] = HEAP32[$14 + 4 >> 2];
  HEAP32[$13 + 8 >> 2] = HEAP32[$14 + 8 >> 2];
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_($this, $t);
  return;
}

function __ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_($agg_result, $t) {
  __ZN2js7MoveRefINS_10WatchpointEEC1ERS1_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_10WatchpointEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_10WatchpointEEC2ERS1_($this, $t);
  return;
}

function __ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_($this, $t) {
  __ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv($e);
    var $3 = $this + 16 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 8 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($1);
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 4 | 0;
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev($1);
  __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_($this, $rhs) {
  var $1 = $rhs;
  var $2 = $this;
  var $3$0 = HEAP32[$1 >> 2];
  var $3$1 = HEAP32[$1 + 4 >> 2];
  HEAP32[$2 >> 2] = $3$0;
  HEAP32[$2 + 4 >> 2] = $3$1;
  var $6 = $this + 8 | 0;
  var $7 = $rhs + 8 | 0;
  HEAP32[$6 >> 2] = HEAP32[$7 >> 2];
  HEAP32[$6 + 4 >> 2] = HEAP32[$7 + 4 >> 2];
  HEAP32[$6 + 8 >> 2] = HEAP32[$7 + 8 >> 2];
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 20 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 4 >> 2];
    var $9 = 32 - HEAP32[$this >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $10);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 16 >> 2] = 0;
    var $17 = $this + 12 | 0;
    var $19 = HEAP32[$17 >> 2] + 1 | 0;
    HEAP32[$17 >> 2] = $19;
    HEAP32[$2 >> 2] = $13;
    var $20 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $22 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($src_01);
    if ($22) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv($src_01);
    var $24 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv($src_01);
    var $25 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $24);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE($25, $1);
    __label__ = 6;
    break;
   case 6:
    var $27 = $src_01 + 24 | 0;
    if (($27 | 0) == ($20 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $27;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js17SystemAllocPolicy7malloc_Ej(undef, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv($1, $map);
  var $2 = $1;
  var $3 = $this;
  var $4$0 = HEAP32[$2 >> 2];
  var $4$1 = HEAP32[$2 + 4 >> 2];
  HEAP32[$3 >> 2] = $4$0;
  HEAP32[$3 + 4 >> 2] = $4$1;
  HEAP32[$this + 8 >> 2] = $map | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$pentry >> 2];
    var $5 = $k;
    var $6 = $4;
    var $7$0 = HEAP32[$5 >> 2];
    var $7$1 = HEAP32[$5 + 4 >> 2];
    var $st$7$0 = $6 | 0;
    HEAP32[$st$7$0 >> 2] = $7$0;
    var $st$7$1 = $6 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $7$1;
    var $9 = $4 + 8 | 0;
    var $10 = $v;
    HEAP32[$9 >> 2] = HEAP32[$10 >> 2];
    HEAP32[$9 + 4 >> 2] = HEAP32[$10 + 4 >> 2];
    HEAP32[$9 + 8 >> 2] = HEAP32[$10 + 8 >> 2];
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 4 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 16 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 16 >> 2] >>> 0 < HEAPU32[$this + 4 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj($26, $27);
    var $28 = $this + 8 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l) {
  var $1 = __ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 20 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_($e, $l) {
  var $1 = $e + 4 | 0;
  var $2 = __ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE($1);
  var $3 = __ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_($2, $l);
  return $3;
}

function __ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_($key) {
  var $1 = $key | 0;
  var $2 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($1);
  var $4 = HEAP32[$key + 4 >> 2];
  var $5 = __ZN2jsL6HashIdEi4071($4);
  return $5 ^ $2;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j(undef, $roundUp_0_lcssa);
    HEAP32[$this + 20 >> 2] = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE($this, $entry);
  return;
}

function __ZN15AutoEntryHolderD2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $4 = HEAP32[$this + 8 >> 2];
    var $6 = HEAP32[$this >> 2];
    var $7 = __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($6);
    if (($4 | 0) == ($7 | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $this + 12 | 0;
    __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_($1, $6, $10);
    var $12 = HEAP32[$1 >> 2];
    HEAP32[$this + 4 >> 2] = $12;
    __label__ = 3;
    break;
   case 3:
    var $15 = $this + 4 | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv($2, $15);
    if ((HEAP32[$2 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($15);
    HEAP8[$20 + 16 | 0] = 0;
    __label__ = 5;
    break;
   case 5:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($this) {
  var $1 = $this | 0;
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv($1);
  return $2;
}

function __ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE($this, $map, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$this >> 2] = $map;
  var $3 = HEAP32[$p >> 2];
  HEAP32[$this + 4 >> 2] = $3;
  var $5 = $this + 8 | 0;
  var $6 = __ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv($map);
  HEAP32[$5 >> 2] = $6;
  var $7 = $this + 12 | 0;
  var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
  var $9 = $8;
  var $10 = $7;
  var $11$0 = HEAP32[$9 >> 2];
  var $11$1 = HEAP32[$9 + 4 >> 2];
  HEAP32[$10 >> 2] = $11$0;
  HEAP32[$10 + 4 >> 2] = $11$1;
  var $12 = __ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv($p);
  HEAP8[$12 + 16 | 0] = 1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $m_01 = HEAP32[HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 >> 2];
    if (($m_01 | 0) == 0) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_02 = 0;
      var $m_03 = $m_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $m_03;
    var $markedAny_02;
    var $10 = HEAP32[HEAP32[$m_03 >> 2] + 4 >> 2];
    var $11 = FUNCTION_TABLE[$10]($m_03, $tracer);
    var $markedAny_1 = $11 ? 1 : $markedAny_02;
    var $m_0 = HEAP32[$m_03 + 4 >> 2];
    if (($m_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_02 = $markedAny_1;
      var $m_03 = $m_0;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11WeakMapBase8sweepAllEP8JSTracer($tracer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $m_01 = HEAP32[HEAP32[HEAP32[$tracer >> 2] + 52 >> 2] + 200 >> 2];
    if (($m_01 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $m_02 = $m_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $m_02;
    var $10 = HEAP32[HEAP32[$m_02 >> 2] + 8 >> 2];
    FUNCTION_TABLE[$10]($m_02, $tracer);
    var $m_0 = HEAP32[$m_02 + 4 >> 2];
    if (($m_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $m_02 = $m_0;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16WeakMap_finalizeP9JSContextP8JSObject($cx, $obj) {
  var $1 = __ZL12GetObjectMapP8JSObject($obj);
  __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_(undef, $1);
  return;
}

function __ZL12WeakMap_markP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL12GetObjectMapP8JSObject($obj);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1 | 0;
    __ZN2js11WeakMapBase5traceEP8JSTracer($4, $trc);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11WeakMap_hasP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $4 = $vp + 8 | 0;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject9isWeakMapEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str124089 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $14 = $vp + 16 | 0;
    var $15 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $14);
    HEAP32[$key >> 2] = $15;
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZL12GetObjectMapP8JSObject($5);
    if (($18 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = $18 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $21, $key);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZN2JSL12BooleanValueEb4125($2, 1);
    var $26 = $2 | 0;
    var $st$2$0 = $26 | 0;
    var $27$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$2$1 >> 2];
    var $28 = $vp | 0;
    var $st$7$0 = $28 | 0;
    HEAP32[$st$7$0 >> 2] = $27$0;
    var $st$7$1 = $28 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $27$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL12BooleanValueEb4125($3, 0);
    var $30 = $3 | 0;
    var $st$2$0 = $30 | 0;
    var $31$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $30 + 4 | 0;
    var $31$1 = HEAP32[$st$2$1 >> 2];
    var $32 = $vp | 0;
    var $st$7$0 = $32 | 0;
    HEAP32[$st$7$0 >> 2] = $31$0;
    var $st$7$1 = $32 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_hasP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($hash0, $shift) {
  return $hash0 >>> ($shift >>> 0);
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($hash0, $log2, $shift) {
  return $hash0 << $log2 >>> ($shift >>> 0) | 1;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($hash) {
  return $hash >>> 0 > 1;
}

function __ZN2js2gcL15GetGCObjectKindEjb4109($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject9isWeakMapEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js12WeakMapClassE | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($this) {
  return (HEAP32[$this >> 2] | 0) == 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this) {
  return (HEAP32[$this + 20 >> 2] + HEAP32[$this + 12 >> 2] | 0) >>> 0 >= (HEAP32[$this + 8 >> 2] * 192 | 0) >>> 8 >>> 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj($this, $hn) {
  HEAP32[$this >> 2] = $hn;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($this) {
  return (HEAP32[$this >> 2] | 0) == 0;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $sizeLog2) {
  HEAP32[$this + 4 >> 2] = 32 - $sizeLog2 | 0;
  HEAP32[$this + 8 >> 2] = 1 << $sizeLog2;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv($this) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] & -2;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv($this) {
  return HEAP32[$this >> 2];
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  HEAP32[$2 >> 2] = 0;
  HEAP32[$2 + 4 >> 2] = 0;
  return;
}

function __ZL11WeakMap_getP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = $vp + 8 | 0;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $3);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject9isWeakMapEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str114088 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 6:
    var $13 = $vp + 16 | 0;
    var $14 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $13);
    HEAP32[$key >> 2] = $14;
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $17 = __ZL12GetObjectMapP8JSObject($4);
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $20 = $17 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $20, $key);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($ptr);
    var $26 = $25 + 8 | 0;
    var $st$2$0 = $26 | 0;
    var $27$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$2$1 >> 2];
    var $28 = $vp | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 10:
    if ($argc >>> 0 > 1) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $32 = $vp + 24 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAPU32[$32 + 4 >> 2];
    var $34 = $2 | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $37$1 = $33$1;
    var $37$0 = $33$0;
    __label__ = 13;
    break;
   case 12:
    __ZN2JSL14UndefinedValueEv4098($2);
    var $_phi_trans_insert = $2 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $37$1 = HEAP32[$st$2$1 >> 2];
    var $37$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $37$0;
    var $37$1;
    var $38 = $vp | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_getP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $ptr = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 20;
    var $4 = __stackBase__ + 28;
    var $5 = $vp + 8 | 0;
    var $6 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject9isWeakMapEv($6);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str104087 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 11;
    break;
   case 6:
    var $15 = $vp + 16 | 0;
    var $16 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $15);
    HEAP32[$key >> 2] = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = __ZL12GetObjectMapP8JSObject($6);
    if (($19 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $19 + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($ptr, $22, $key);
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $ptr);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = HEAP32[$ptr >> 2];
    HEAP32[$2 >> 2] = $28;
    __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($22, $2);
    __ZN2JSL12BooleanValueEb4125($3, 1);
    var $30 = $3 | 0;
    var $st$7$0 = $30 | 0;
    var $31$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $30 + 4 | 0;
    var $31$1 = HEAP32[$st$7$1 >> 2];
    var $32 = $vp | 0;
    HEAP32[$32 >> 2] = $31$0;
    HEAP32[$32 + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    __ZN2JSL12BooleanValueEb4125($4, 0);
    var $34 = $4 | 0;
    var $35$0 = HEAP32[$34 >> 2];
    var $35$1 = HEAP32[$34 + 4 >> 2];
    var $36 = $vp | 0;
    var $st$7$0 = $36 | 0;
    HEAP32[$st$7$0 >> 2] = $35$0;
    var $st$7$1 = $36 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $35$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11WeakMap_setP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $key = __stackBase__;
    var $value = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    var $2 = $vp + 8 | 0;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject9isWeakMapEv($3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($cx, $vp, __ZN2js12WeakMapClassE);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    _JS_ReportErrorNumber($cx, 2, 0, 3, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE.__str54082 | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str64083 | 0, HEAP32[tempInt + 8 >> 2] = STRING_TABLE.__str74084 | 0, tempInt));
    var $_0 = 0;
    __label__ = 16;
    break;
   case 6:
    var $12 = $vp + 16 | 0;
    var $13 = __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $12);
    HEAP32[$key >> 2] = $13;
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ($argc >>> 0 > 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $18 = $vp + 24 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $value | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __label__ = 10;
    break;
   case 9:
    __ZN2JSL14UndefinedValueEv4098($value);
    __label__ = 10;
    break;
   case 10:
    var $23 = __ZL12GetObjectMapP8JSObject($3);
    if (($23 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $map_0 = $23;
      __label__ = 14;
      break;
    }
   case 11:
    var $26 = __ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_($cx, $cx);
    var $27 = $26 + 8 | 0;
    var $28 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($27, 0);
    if ($28) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_(undef, $26);
    __label__ = 15;
    break;
   case 13:
    var $31 = $26;
    __ZN8JSObject10setPrivateEPv($3, $31);
    var $map_0 = $26;
    __label__ = 14;
    break;
   case 14:
    var $map_0;
    __ZN2JSL14UndefinedValueEv4098($1);
    var $33 = $1 | 0;
    var $34$0 = HEAP32[$33 >> 2];
    var $34$1 = HEAP32[$33 + 4 >> 2];
    var $35 = $vp | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    var $37 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_($map_0 + 8 | 0, $key, $value);
    if (($37 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 15:
    _JS_ReportOutOfMemory($cx);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11WeakMap_setP9JSContextjPN2JS5ValueE["X"] = 1;

function __Z19js_InitWeakMapClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $2;
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $4, __ZN2js12WeakMapClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject10setPrivateEPv($6, 0);
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 210164 >> 2];
    var $14 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $4, 274, __ZN2js12WeakMapClassE, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = $14;
    var $18 = $14 | 0;
    var $19 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $18, $5);
    if ($19) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $21 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL16weak_map_methods);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $23 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($cx, $3, 36, $17, $6);
    var $_ = $23 ? $6 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17WeakMap_constructP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108($cx);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN8JSObject10setPrivateEPv($1, 0);
    __ZN2JS5Value9setObjectER8JSObject($vp, $1);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL14UndefinedValueEv4098($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108($cx) {
  var $3 = HEAPU32[__ZN2js12WeakMapClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4109($3);
  var $5 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110($cx, $4);
  return $5;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110($cx, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $3 = HEAPU32[__ZN2js12WeakMapClassE + 4 >> 2] >>> 24;
    var $4 = __ZNK9JSContext5hasfpEv($cx);
    if ($4) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $7;
    var $8 = $cx;
    var $9 = $global;
    var $10 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($8, $9);
    if ($10) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $18 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $12 = __ZNK9JSContext2fpEv($cx);
    var $13 = __ZNK2js10StackFrame10scopeChainEv($12);
    var $14 = $13;
    var $15 = __ZNK8JSObject9getGlobalEv($14);
    var $16 = $15;
    HEAP32[$global >> 2] = $16;
    var $18 = $16;
    __label__ = 5;
    break;
   case 5:
    var $18;
    var $19 = $3 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $18, $19);
    var $20 = __ZNK2JS5Value8isObjectEv($1);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $22 = __ZNK2JS5Value8toObjectEv($1);
    HEAP32[$proto >> 2] = $22;
    var $29 = $22;
    __label__ = 9;
    break;
   case 7:
    var $24 = $cx;
    var $26 = $proto;
    var $27 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($24, $18, $3, $26, __ZN2js12WeakMapClassE);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $29 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $29;
    var $30 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111($cx, $29, $18, $kind);
    var $_0 = $30;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111($cx, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($proto, $cx, 0, 0);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($cx, $kind);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($4, undef, __ZN2js12WeakMapClassE, $1, $parent, 0, (__ZN2js12WeakMapClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $7 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($1, $cx, __ZN2js12WeakMapClassE, $kind);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($4, $10);
    var $_0 = $4;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13NonNullObjectP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 231, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $4 = __ZNK2JS5Value8toObjectEv($vp);
    var $_0 = $4;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12GetObjectMapP8JSObject($obj) {
  var $1 = __ZNK8JSObject10getPrivateEv($obj);
  return $1;
}

function __ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 36);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext($4, $p1);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj($this, $len) {
  var $1 = $this | 0;
  var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($1, $len);
  return $2;
}

function __ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_($this, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $p = __stackBase__;
    var $1 = __stackBase__ + 8;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($p, $this, $k);
    var $2 = $p | 0;
    __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($1, $2);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv($2);
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $7 + 8 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 3:
    var $13 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v);
    if ($13) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv($2);
    var $_0 = $15;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $1, $l);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv($agg_result, $this) {
  var $1 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this);
  var $_ = $1 ? {
    f0: 272,
    f1: 0
  } : {
    f0: 0,
    f1: 0
  };
  HEAP32[$agg_result >> 2] = $_.f0;
  HEAP32[$agg_result + 4 >> 2] = $_.f1;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_($this, $p, $k, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pentry = __stackBase__;
    var $1 = $this | 0;
    var $2 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($1, $p, $pentry);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$k >> 2];
    var $5 = HEAP32[$pentry >> 2];
    var $6 = $5 | 0;
    HEAP32[$6 >> 2] = $4;
    var $7 = $v | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $5 + 8 | 0;
    var $st$10$0 = $9 | 0;
    HEAP32[$st$10$0 >> 2] = $8$0;
    var $st$10$1 = $9 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_($this, $p, $pentry) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$p >> 2] + 8 | 0;
    HEAP32[$pentry >> 2] = $5;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $this + 20 | 0;
    var $7 = HEAP32[$5 >> 2] - 1 | 0;
    HEAP32[$5 >> 2] = $7;
    var $8 = $p + 4 | 0;
    var $10 = HEAP32[$8 >> 2] | 1;
    HEAP32[$8 >> 2] = $10;
    var $26 = HEAP32[$1 >> 2];
    var $_pre_phi = $8;
    __label__ = 7;
    break;
   case 3:
    var $12 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv($this);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $26 = $2;
    var $_pre_phi = $p + 4 | 0;
    __label__ = 7;
    break;
   case 5:
    var $_ = HEAPU32[$this + 20 >> 2] >>> 0 < HEAPU32[$this + 8 >> 2] >>> 2 >>> 0 & 1;
    var $20 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $_);
    if ($20) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $22 = $p + 4 | 0;
    var $23 = HEAP32[$22 >> 2];
    var $24 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $23);
    HEAP32[$1 >> 2] = $24;
    var $26 = $24;
    var $_pre_phi = $22;
    __label__ = 7;
    break;
   case 7:
    var $_pre_phi;
    var $26;
    var $27 = HEAP32[$_pre_phi >> 2];
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj($26, $27);
    var $28 = $this + 12 | 0;
    var $30 = HEAP32[$28 >> 2] + 1 | 0;
    HEAP32[$28 >> 2] = $30;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, $deltaLog2) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $this + 24 | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$this + 8 >> 2];
    var $9 = 32 - HEAP32[$this + 4 >> 2] + $deltaLog2 | 0;
    var $10 = 1 << $9;
    if ($10 >>> 0 > 16777216) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $13 = $this | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($13, $10);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $9);
    HEAP32[$this + 20 >> 2] = 0;
    var $18 = $this + 16 | 0;
    var $20 = HEAP32[$18 >> 2] + 1 | 0;
    HEAP32[$18 >> 2] = $20;
    HEAP32[$2 >> 2] = $14;
    var $21 = $3 + $5 * 24 | 0;
    if (($5 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $3;
      __label__ = 4;
      break;
    }
   case 4:
    var $src_01;
    var $23 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($src_01);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv($src_01);
    var $25 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv($src_01);
    var $26 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $25);
    __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($1, $src_01);
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($26, $1);
    __label__ = 6;
    break;
   case 6:
    var $28 = $src_01 + 24 | 0;
    if (($28 | 0) == ($21 | 0)) {
      __label__ = 7;
      break;
    } else {
      var $src_01 = $28;
      __label__ = 4;
      break;
    }
   case 7:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $3, undef);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj($this, $keyHash) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $6 = HEAP32[$4 >> 2] + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = 32 - $2 | 0;
    var $10 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $9, $2);
    var $12 = (1 << $9) - 1 | 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $h1_0;
    var $entry_0;
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv($entry_0);
    var $15 = $h1_0 - $10 & $12;
    var $17 = HEAP32[$4 >> 2] + $15 * 24 | 0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($17);
    if ($18) {
      var $_0 = $17;
      __label__ = 4;
      break;
    } else {
      var $entry_0 = $17;
      var $h1_0 = $15;
      __label__ = 3;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($alloc, $capacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $capacity * 24 | 0;
    var $2 = __ZN2js18RuntimeAllocPolicy7malloc_Ej($alloc, $1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + $capacity * 24 | 0;
    if (($3 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $e_01;
    if (($e_01 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev($e_01);
    __label__ = 5;
    break;
   case 5:
    var $11 = $e_01 + 24 | 0;
    if (($11 | 0) == ($6 | 0)) {
      var $_0 = $3;
      __label__ = 6;
      break;
    } else {
      var $e_01 = $11;
      __label__ = 3;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($2);
  return $3;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv($rhs);
  var $4 = HEAP32[$2 >> 2];
  HEAP32[$this >> 2] = $4;
  var $6 = $this + 8 | 0;
  var $7 = __ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv($rhs);
  var $8 = $7 + 8 | 0;
  __ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($1, $8);
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE($6, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_($agg_result, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_($agg_result, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj($alloc, $oldTable, $capacity) {
  var $0 = $oldTable;
  __ZN2js18RuntimeAllocPolicy5free_EPv(undef, $0);
  return;
}

function __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_($this, $t) {
  __ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_($this, $t);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE($this, $rhs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $rhs;
  $rhs = STACKTOP;
  STACKTOP += 4;
  HEAP32[$rhs >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = __stackBase__ + 4;
  var $3 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv($rhs);
  var $4 = $3 | 0;
  __ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_($1, $4);
  var $5 = __ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev($1);
  var $6 = HEAP32[$5 >> 2];
  HEAP32[$this >> 2] = $6;
  var $8 = __ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv($rhs);
  var $9 = $8 + 8 | 0;
  __ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_($2, $9);
  var $10 = __ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev($2);
  var $11 = $10 | 0;
  var $12$0 = HEAP32[$11 >> 2];
  var $12$1 = HEAP32[$11 + 4 >> 2];
  var $13 = $this + 8 | 0;
  HEAP32[$13 >> 2] = $12$0;
  HEAP32[$13 + 4 >> 2] = $12$1;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_($agg_result, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_($agg_result, $t);
  return;
}

function __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_($this, $t) {
  __ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_($this, $t);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev($this) {
  __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev($this);
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  var $2 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($2);
  return;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($this) {
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev($this);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv($this) {
  var $2 = HEAP32[$this >> 2];
  var $3 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($2);
  return $3;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 1);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($agg_result, $2, $1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l) {
  var $1 = __ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_($l);
  var $2 = $1 * -1640531527 | 0;
  var $3 = $2 - 2 | 0;
  var $4 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($2);
  var $_ = $4 ? $2 : $3;
  return $_ & -2;
}

function __ZN9JSWrapper16getWrapperFamilyEv() {
  return __ZL14sWrapperFamily;
}

function __ZN9JSWrapperD2Ev($this) {
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  HEAP32[$this >> 2] = $entry;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($this, $hn) {
  return (HEAP32[$this >> 2] & -2 | 0) == ($hn | 0);
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj($this, $collisionBit) {
  var $1 = $this | 0;
  var $3 = HEAP32[$1 >> 2] | $collisionBit;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($e) {
  return $e | 0;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($this) {
  return (HEAP32[$this >> 2] | 0) == (HEAP32[$this + 4 >> 2] | 0);
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($this) {
  return HEAP32[$this >> 2] + 8 | 0;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 8 >> 2];
    if ($2 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $11 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $11 = HEAPU32[$this + 12 >> 2] >>> 0 <= ($2 >>> 2 & 16777215) >>> 0;
    __label__ = 3;
    break;
   case 3:
    var $11;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv($this) {
  return (HEAP32[$this >> 2] & 1 | 0) != 0;
}

function __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($this, $rhs) {
  var $2 = HEAP32[$rhs >> 2];
  HEAP32[$this >> 2] = $2;
  var $4 = $rhs + 8 | 0;
  var $5$0 = HEAP32[$4 >> 2];
  var $5$1 = HEAP32[$4 + 4 >> 2];
  var $6 = $this + 8 | 0;
  HEAP32[$6 >> 2] = $5$0;
  HEAP32[$6 + 4 >> 2] = $5$1;
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  var $_c = HEAP32[$ap >> 2];
  HEAP32[$this >> 2] = $_c;
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  HEAP32[$this + 20 >> 2] = 0;
  HEAP32[$this + 24 >> 2] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js14JSProxyHandler6familyEv($this) {
  return HEAP32[$this + 4 >> 2];
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $keyHash, $collisionBit) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj($keyHash, $2);
    var $4 = $this + 24 | 0;
    var $5 = HEAP32[$4 >> 2];
    var $6 = $5 + $3 * 24 | 0;
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($6);
    if ($7) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($6, $keyHash);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($6, $l);
    if ($11) {
      var $_0 = $6;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = 32 - $2 | 0;
    var $14 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj($keyHash, $13, $2);
    var $16 = (1 << $13) - 1 | 0;
    var $firstRemoved_0 = 0;
    var $entry_0 = $6;
    var $h1_0 = $3;
    var $17 = $5;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $h1_0;
    var $entry_0;
    var $firstRemoved_0;
    var $18 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv($entry_0);
    if ($18) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    if (($firstRemoved_0 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $firstRemoved_1 = $firstRemoved_0;
      var $24 = $17;
      __label__ = 9;
      break;
    }
   case 7:
    var $firstRemoved_1 = $entry_0;
    var $24 = $17;
    __label__ = 9;
    break;
   case 8:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj($entry_0, $collisionBit);
    var $firstRemoved_1 = $firstRemoved_0;
    var $24 = HEAP32[$4 >> 2];
    __label__ = 9;
    break;
   case 9:
    var $24;
    var $firstRemoved_1;
    var $26 = $h1_0 - $14 & $16;
    var $27 = $24 + $26 * 24 | 0;
    var $28 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv($27);
    if ($28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = ($firstRemoved_1 | 0) != 0 ? $firstRemoved_1 : $27;
    var $_0 = $31;
    __label__ = 13;
    break;
   case 11:
    var $33 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj($27, $keyHash);
    if ($33) {
      __label__ = 12;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 12:
    var $35 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($27, $l);
    if ($35) {
      var $_0 = $27;
      __label__ = 13;
      break;
    } else {
      var $firstRemoved_0 = $firstRemoved_1;
      var $entry_0 = $27;
      var $h1_0 = $26;
      var $17 = $24;
      __label__ = 5;
      break;
    }
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj($this, $entry, $hn) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($1, $entry);
  HEAP32[$this + 4 >> 2] = $hn;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_($e, $l) {
  var $1 = $e + 8 | 0;
  var $2 = __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE($1);
  var $3 = __ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_($2, $l);
  return $3;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj($hash) {
  var $1 = __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj($hash);
  return $1;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev($this) {
  __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev($this);
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev($this) {
  var $1 = $this + 8 | 0;
  __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($1);
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev($this) {
  var $1 = $this | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($1);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 24 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj(undef, $2, undef);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj($this, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($length >>> 0 > 8388608) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $length * 171 | 0;
    var $capacity_0 = $3 >>> 0 < 2048 ? 16 : $3 >>> 7;
    if ($capacity_0 >>> 0 > 16) {
      var $roundUp_01 = 16;
      var $roundUpLog2_02 = 4;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = 16;
      var $roundUpLog2_0_lcssa = 4;
      __label__ = 4;
      break;
    }
   case 3:
    var $roundUpLog2_02;
    var $roundUp_01;
    var $7 = $roundUp_01 << 1;
    var $8 = $roundUpLog2_02 + 1 | 0;
    if ($7 >>> 0 < $capacity_0 >>> 0) {
      var $roundUp_01 = $7;
      var $roundUpLog2_02 = $8;
      __label__ = 3;
      break;
    } else {
      var $roundUp_0_lcssa = $7;
      var $roundUpLog2_0_lcssa = $8;
      __label__ = 4;
      break;
    }
   case 4:
    var $roundUpLog2_0_lcssa;
    var $roundUp_0_lcssa;
    var $10 = $this | 0;
    var $11 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j($10, $roundUp_0_lcssa);
    HEAP32[$this + 24 >> 2] = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej($this, $roundUpLog2_0_lcssa);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext($this, $cx) {
  __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext($this, $cx);
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext($this, $cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  var $2 = $this + 8 | 0;
  __ZN2js18RuntimeAllocPolicyC1EP9JSContext($1, $cx);
  __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($2, $1);
  var $3 = $this | 0;
  __ZN2js11WeakMapBaseC2Ev($3);
  HEAP32[$this >> 2] = __ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE + 8 | 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_($this, $a) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $a;
  $a = STACKTOP;
  STACKTOP += 4;
  HEAP32[$a >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$a >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r);
    var $4 = $3 + 8 | 0;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_($t, $4);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $5 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $r = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    var $1 = $this + 8 | 0;
    __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($r, $1);
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($2) {
      var $markedAny_0_lcssa = 0;
      __label__ = 4;
      break;
    } else {
      var $markedAny_01 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $markedAny_01;
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($r);
    var $5 = HEAP32[$3 >> 2];
    var $6 = $3 + 8 | 0;
    var $7 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_($t, $5, $6);
    var $markedAny_1 = $7 ? 1 : $markedAny_01;
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($r);
    var $8 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($r);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $markedAny_01 = $markedAny_1;
      __label__ = 2;
      break;
    }
   case 3:
    var $markedAny_0_lcssa = ($markedAny_1 & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 4:
    var $markedAny_0_lcssa;
    STACKTOP = __stackBase__;
    return $markedAny_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer($this, $tracer) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $t = __stackBase__;
    var $e = __stackBase__ + 4;
    __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($t, $tracer);
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($e, $this);
    var $1 = $e | 0;
    var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($e);
    STACKTOP = __stackBase__;
    return;
   case 3:
    var $3 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv($1);
    var $5 = HEAP32[$3 >> 2];
    var $6 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($t, $5);
    if ($6) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($e);
    __label__ = 5;
    break;
   case 5:
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($1);
    var $9 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv($1);
    if ($9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer($this, $t) {
  __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer($this, $t);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map);
  return;
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($this, $k) {
  var $4 = HEAP32[HEAP32[$this >> 2] >> 2];
  var $5 = $k;
  var $6 = __Z20IsAboutToBeFinalizedP9JSContextPKv($4, $5);
  return $6 ^ 1;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  var $4 = HEAP32[$this >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($2, $4);
  HEAP8[$this + 12 | 0] = 1;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $_pre1 = HEAP32[$this + 4 >> 2];
    var $4 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $4;
    var $5 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $5;
    if (($5 | 0) == ($_pre1 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      var $4 = $5;
      __label__ = 2;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev($this) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 12 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this + 8 >> 2];
    __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($7);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi($this, -1);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv($e);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv($e);
    var $3 = $this + 20 | 0;
    var $5 = HEAP32[$3 >> 2] + 1 | 0;
    HEAP32[$3 >> 2] = $5;
    __label__ = 4;
    break;
   case 3:
    __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv($e);
    __label__ = 4;
    break;
   case 4:
    var $8 = $this + 12 | 0;
    var $10 = HEAP32[$8 >> 2] - 1 | 0;
    HEAP32[$8 >> 2] = $10;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 1;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var $1 = __stackBase__;
  HEAP32[$this >> 2] = 0;
  var $3 = $this + 8 | 0;
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev($1);
  __ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_($3, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_($this, $map) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = $map + 8 | 0;
  __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($1, $2);
  var $3 = $1;
  var $4 = $this;
  var $5$0 = HEAP32[$3 >> 2];
  var $5$1 = HEAP32[$3 + 4 >> 2];
  HEAP32[$4 >> 2] = $5$0;
  HEAP32[$4 + 4 >> 2] = $5$1;
  HEAP32[$this + 8 >> 2] = $2 | 0;
  HEAP8[$this + 12 | 0] = 0;
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv($agg_result, $this) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $1);
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv($agg_result, $this) {
  var $2 = HEAP32[$this + 24 >> 2];
  var $5 = $2 + HEAP32[$this + 8 >> 2] * 24 | 0;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($agg_result, $2, $5);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_($this, $c, $e) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    HEAP32[$1 >> 2] = $c;
    HEAP32[$this + 4 >> 2] = $e;
    var $4 = $c;
    __label__ = 2;
    break;
   case 2:
    var $4;
    if (($4 | 0) == ($e | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv($4);
    if ($7) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $4 + 24 | 0;
    HEAP32[$1 >> 2] = $9;
    var $4 = $9;
    __label__ = 2;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_($this, $k, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_($this, $k);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v);
    var $_0 = $3;
    __label__ = 5;
    break;
   case 3:
    var $5 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_($this, $k);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = HEAP32[$this >> 2];
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($8, $k, undef);
    var $9 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v);
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_($this, $v);
    if ($1) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = HEAP32[$this >> 2];
    __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($4, $v, undef);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_($this, $k) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[HEAP32[$this >> 2] + 4 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject8getClassEv($k);
    var $_0 = (HEAP8[$7 + 88 | 0] & 1) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_($this, $v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value10isMarkableEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[HEAP32[$this >> 2] >> 2];
    var $7 = __ZNK2JS5Value9toGCThingEv($v);
    var $8 = __Z20IsAboutToBeFinalizedP9JSContextPKv($6, $7);
    var $_0 = $8 ^ 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_($this, $v) {
  var $2 = HEAP32[$this >> 2];
  __ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc($2, $v, undef);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_($this, $ap) {
  var __stackBase__ = STACKTOP;
  var tempParam = $ap;
  $ap = STACKTOP;
  STACKTOP += 4;
  HEAP32[$ap >> 2] = HEAP32[tempParam >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_($this, $ap);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_($agg_result, $this, $l) {
  var $1 = $this | 0;
  __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $1, $l);
  return;
}

function __ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $1 = __stackBase__;
  var $2 = $this | 0;
  var $4 = HEAP32[$p >> 2];
  HEAP32[$1 >> 2] = $4;
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($2, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2JSL12BooleanValueEb4125($agg_result, $boo) {
  __ZN2JS5Value10setBooleanEb($agg_result, $boo);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE($this, $p) {
  var __stackBase__ = STACKTOP;
  var tempParam = $p;
  $p = STACKTOP;
  STACKTOP += 4;
  HEAP32[$p >> 2] = HEAP32[tempParam >> 2];
  var $2 = HEAP32[$p >> 2];
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE($this, $2);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv($this);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_($agg_result, $this, $l) {
  var $1 = __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_($l);
  var $2 = __ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj($this, $l, $1, 0);
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($agg_result, $2);
  return;
}

function __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE($this, $entry) {
  __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE($this, $entry);
  return;
}

function __ZNK8JSObject9isWrapperEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7isProxyEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject15getProxyHandlerEv($this);
    var $4 = __ZN2js14JSProxyHandler6familyEv($3);
    var $7 = ($4 | 0) == (__ZL14sWrapperFamily | 0);
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject25isCrossCompartmentWrapperEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject9isWrapperEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $9 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK8JSObject17getWrapperHandlerEv($this);
    var $4 = $3;
    var $5 = __ZNK9JSWrapper5flagsEv($4);
    var $9 = ($5 & 1 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject17getWrapperHandlerEv($this) {
  var $1 = __ZNK8JSObject15getProxyHandlerEv($this);
  return $1;
}

function __ZN8JSObject6unwrapEPj($this, $flagsp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags_0 = 0;
    var $wrapped_0 = $this;
    __label__ = 2;
    break;
   case 2:
    var $wrapped_0;
    var $flags_0;
    var $2 = __ZNK8JSObject9isWrapperEv($wrapped_0);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      var $flags_1 = $flags_0;
      var $wrapped_1 = $wrapped_0;
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = __ZNK8JSObject15getProxyHandlerEv($wrapped_0);
    var $5 = $4;
    var $6 = __ZNK9JSWrapper5flagsEv($5);
    var $7 = $6 | $flags_0;
    var $8 = __ZNK8JSObject15getProxyPrivateEv($wrapped_0);
    var $9 = __ZNK2JS5Value14toObjectOrNullEv($8);
    var $10 = __ZNK8JSObject8getClassEv($9);
    if ((HEAP32[$10 + 76 >> 2] | 0) == 0) {
      var $flags_0 = $7;
      var $wrapped_0 = $9;
      __label__ = 2;
      break;
    } else {
      var $flags_1 = $7;
      var $wrapped_1 = $9;
      __label__ = 4;
      break;
    }
   case 4:
    var $wrapped_1;
    var $flags_1;
    if (($flagsp | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$flagsp >> 2] = $flags_1;
    __label__ = 6;
    break;
   case 6:
    return $wrapped_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapperC2Ej($this, $flags) {
  var $1 = $this | 0;
  __ZN2js14JSProxyHandlerC2EPv($1, __ZL14sWrapperFamily);
  HEAP32[$this >> 2] = __ZTV9JSWrapper + 8 | 0;
  HEAP32[$this + 8 >> 2] = $flags;
  return;
}

function __ZN9JSWrapperD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    HEAP32[$desc >> 2] = 0;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = $set & 1;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, $6, $status);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = _JS_GetPropertyDescriptorById($cx, $13, $id, 1, $desc);
    var $15 = ($14 | 0) != 0;
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper) {
  var $1 = __ZNK8JSObject15getProxyPrivateEv($wrapper);
  var $2 = __ZNK2JS5Value14toObjectOrNullEv($1);
  return $2;
}

function __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    HEAP32[$desc >> 2] = 0;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = $set & 1;
    var $7 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, $6, $status);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = __ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor($cx, $13, $id, $desc);
    var $18 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$18]($this, $cx, $wrapper);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor($cx, $obj, $id, $desc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7isProxyEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($cx, $obj, $id, 0, $desc);
    var $_0 = $3;
    __label__ = 6;
    break;
   case 3:
    var $5 = _JS_GetPropertyDescriptorById($cx, $obj, $id, 1, $desc);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $desc | 0;
    if ((HEAP32[$8 >> 2] | 0) == ($obj | 0)) {
      var $_0 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$8 >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, 1, $status);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $12 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $13 = $desc + 16 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $1 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $17 = HEAP32[$desc + 8 >> 2];
    var $19 = HEAP32[$desc + 12 >> 2];
    var $21 = HEAP32[$desc + 4 >> 2];
    var $22 = _JS_DefinePropertyById($cx, $12, $id, $1, $17, $19, $21);
    var $23 = ($22 | 0) != 0;
    var $27 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$27]($this, $cx, $wrapper);
    var $_0 = $23;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 24, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $status = __stackBase__ + 8;
    HEAP8[$bp] = 1;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 1, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = _JS_DeletePropertyById2($cx, $11, $id, $v);
    if (($12 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL14ValueToBooleanPN2JS5ValueEPb($v, $bp);
    var $16 = 1;
    __label__ = 5;
    break;
   case 5:
    var $16;
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14ValueToBooleanPN2JS5ValueEPb($vp, $bp) {
  var $1 = __Z17js_ValueToBooleanRKN2JS5ValueE($vp);
  HEAP8[$bp] = ($1 | 0) != 0 & 1;
  return;
}

function __ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb($this, $cx, $wrapper, $id, $act, $bp) {
  HEAP8[$bp] = 1;
  return 1;
}

function __ZN9JSWrapper5leaveEP9JSContextP8JSObject($this, $cx, $wrapper) {
  return;
}

function __ZL4CondiPb($b, $bp) {
  HEAP8[$bp] = ($b | 0) != 0 & 1;
  return;
}

function __ZN2js10ForceFrameC2EP9JSContextP8JSObject($this, $cx, $target) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $target;
  HEAP32[$this + 8 >> 2] = 0;
  return;
}

function __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 0, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE($this, $cx, $wrapper, $vp) {
  __ZN2JS5Value12setUndefinedEv($vp);
  return 1;
}

function __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $status = __stackBase__ + 4;
    HEAP8[$bp] = 0;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = _JS_HasPropertyById($cx, $11, $id, $found);
    if (($12 | 0) == 0) {
      var $17 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = HEAP32[$found >> 2];
    __ZL4CondiPb($15, $bp);
    var $17 = 1;
    __label__ = 5;
    break;
   case 5:
    var $17;
    var $21 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$21]($this, $cx, $wrapper);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $desc = __stackBase__;
    var $status = __stackBase__ + 32;
    HEAP8[$bp] = 0;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, $id, 0, $status);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = _JS_GetPropertyDescriptorById($cx, $1, $id, 1, $desc);
    if (($12 | 0) == 0) {
      var $20 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = (HEAP32[$desc >> 2] | 0) == ($1 | 0) & 1;
    __ZL4CondiPb($18, $bp);
    var $20 = 1;
    __label__ = 5;
    break;
   case 5:
    var $20;
    var $24 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$24]($this, $cx, $wrapper);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = __ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE($11, $cx, $receiver, $id, $vp);
    var $13 = ($12 | 0) != 0;
    var $17 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$17]($this, $cx, $wrapper);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, $id, 1, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($11, $cx, $id, $vp, 0);
    var $13 = ($12 | 0) != 0;
    var $17 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$17]($this, $cx, $wrapper);
    var $_0 = $13;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = $props;
    var $15 = __ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE($12, $13, 8, $14);
    var $19 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$19]($this, $cx, $wrapper);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $12 = $cx;
    var $13 = $11;
    var $14 = __ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE($12, $13, $flags, $vp);
    var $18 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$18]($this, $cx, $wrapper);
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 2, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE(undef, $cx, $wrapper, $argc, $vp);
    var $15 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$15]($this, $cx, $wrapper);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($this, $cx, $wrapper, $argc, $argv, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    __ZN2JS5Value12setUndefinedEv($vp);
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 4;
    break;
   case 3:
    var $11 = __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_(undef, $cx, $wrapper, $argc, $argv, $vp);
    var $15 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$15]($this, $cx, $wrapper);
    var $_0 = $11;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $wrapper, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $b = __stackBase__;
    var $status = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    HEAP8[$bp] = 0;
    HEAP32[$b >> 2] = 0;
    var $5 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $6 = FUNCTION_TABLE[$5]($this, $cx, $wrapper, 2, 0, $status);
    if ($6) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = (HEAP8[$status] & 1) << 24 >> 24 != 0;
    __label__ = 6;
    break;
   case 3:
    var $12 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $13 = $vp | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $1 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = _JS_HasInstance($cx, $12, $1, $b);
    if (($16 | 0) == 0) {
      var $21 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[$b >> 2];
    __ZL4CondiPb($19, $bp);
    var $21 = 1;
    __label__ = 5;
    break;
   case 5:
    var $21;
    var $25 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$25]($this, $cx, $wrapper);
    var $_0 = $21;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper6typeOfEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2JSL11ObjectValueER8JSObject4137($1, $2);
  var $3 = __ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE($cx, $1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN2JSL11ObjectValueER8JSObject4137($agg_result, $obj) {
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $obj);
  return;
}

function __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$status] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str4127 | 0);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $13 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    var $14 = $cx;
    var $15 = $13;
    var $16 = __ZN2js18obj_toStringHelperEP9JSContextP8JSObject($14, $15);
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $wrapper, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $status = __stackBase__;
    var $v = __stackBase__ + 4;
    var $4 = HEAP32[HEAP32[$this >> 2] + 100 >> 2];
    var $5 = FUNCTION_TABLE[$4]($this, $cx, $wrapper, 2, 0, $status);
    if ($5) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$status] & 1) << 24 >> 24 == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN8JSObject10isCallableEv($wrapper);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = _JS_NewStringCopyZ($cx, STRING_TABLE.__str14128 | 0);
    var $_0 = $13;
    __label__ = 7;
    break;
   case 5:
    __ZN2JSL11ObjectValueER8JSObject4137($v, $wrapper);
    __Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj($cx, $v, 0);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 6:
    var $16 = __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj(undef, $cx, $wrapper, $indent);
    var $20 = HEAP32[HEAP32[$this >> 2] + 104 >> 2];
    FUNCTION_TABLE[$20]($this, $cx, $wrapper);
    var $_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $wrapper, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2JSL11ObjectValueER8JSObject4137($1, $2);
    var $3 = $1 | 0;
    var $4$0 = HEAP32[$3 >> 2];
    var $4$1 = HEAP32[$3 + 4 >> 2];
    var $5 = $vp | 0;
    HEAP32[$5 >> 2] = $4$0;
    HEAP32[$5 + 4 >> 2] = $4$1;
    if (($hint | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138($cx, $vp);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 3:
    var $10 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139($cx, $hint, $vp);
    var $_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 0, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139($cx, $preferredType, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, $preferredType, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSWrapper5traceEP8JSTracerP8JSObject($this, $trc, $wrapper) {
  var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
  return;
}

function __ZN9JSWrapper14wrapperHandlerEPK8JSObject($wrapper) {
  var $1 = __ZNK8JSObject15getProxyHandlerEv($wrapper);
  return $1;
}

function __ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_($cx, $obj, $proto, $parent, $handler) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZNK8JSObject5isXMLEv($obj);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _JS_ReportErrorNumber($cx, 2, 0, 263, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $5 = $handler | 0;
    __ZN2JSL11ObjectValueER8JSObject4137($1, $obj);
    var $6 = __ZN8JSObject10isCallableEv($obj);
    var $7 = $6 ? $obj : 0;
    var $8 = __ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_($cx, $5, $1, $proto, $parent, $7, 0);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _TransparentObjectWrapper($cx, $obj, $wrappedProto, $parent, $flags) {
  var $1 = __ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_($cx, $obj, $wrappedProto, $parent, __ZN25JSCrossCompartmentWrapper9singletonE | 0);
  return $1;
}

function __ZN2js10ForceFrameD2Ev($this) {
  var $2 = HEAP32[$this + 8 >> 2];
  __ZN9JSContext7delete_IN2js15DummyFrameGuardEEEvPT_(undef, $2);
  return;
}

function __ZN9JSContext7delete_IN2js15DummyFrameGuardEEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js15DummyFrameGuardD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js10ForceFrame5enterEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = __ZN9JSContext4new_IN2js15DummyFrameGuardEEEPT_v($2);
    HEAP32[$this + 8 >> 2] = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$1 >> 2];
    var $9 = HEAP32[$7 + 56 >> 2];
    var $12 = HEAP32[$this + 4 >> 2];
    var $13 = __ZNK8JSObject9getGlobalEv($12);
    var $15 = $7 + 60 | 0;
    var $16 = $7;
    var $17 = $9;
    var $18 = $13;
    var $19 = $3;
    var $20 = __ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE($15, $16, $17, $18, $19);
    var $_0 = $20;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_IN2js15DummyFrameGuardEEEPT_v($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN9JSContext7malloc_Ej($this, 28);
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    HEAP32[$1 >> 2] = 0;
    HEAP32[$1 + 4 >> 2] = 0;
    HEAP32[$1 + 8 >> 2] = 0;
    HEAP32[$1 + 12 >> 2] = 0;
    HEAP32[$1 + 16 >> 2] = 0;
    HEAP32[$1 + 20 >> 2] = 0;
    HEAP32[$1 + 24 >> 2] = 0;
    __ZN2js15DummyFrameGuardC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($this, $cx, $target) {
  HEAP32[$this >> 2] = $cx;
  var $4 = HEAP32[$cx + 56 >> 2];
  HEAP32[$this + 4 >> 2] = $4;
  HEAP32[$this + 8 >> 2] = $target;
  var $6 = $this + 12 | 0;
  var $7 = __ZNK8JSObject14getCompartmentEv($target);
  HEAP32[$6 >> 2] = $7;
  var $8 = $this + 16 | 0;
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev($8);
  HEAP8[$this + 48 | 0] = 0;
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev($this) {
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev($this);
  return;
}

function __ZN2js15AutoCompartmentD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 48 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js15AutoCompartment5leaveEv($this);
    __label__ = 3;
    break;
   case 3:
    var $7 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev($7);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js15AutoCompartment5leaveEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$this + 12 >> 2] | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv($7);
    var $9 = HEAP32[$this >> 2];
    __ZN9JSContext16resetCompartmentEv($9);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 48 | 0] = 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev($this) {
  __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev($this);
  return;
}

function __ZN2js15AutoCompartment5enterEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = $this + 12 | 0;
    if ((HEAP32[$this + 4 >> 2] | 0) == (HEAP32[$3 >> 2] | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $this | 0;
    var $10 = HEAP32[$this + 8 >> 2];
    var $11 = __ZNK8JSObject9getGlobalEv($10);
    var $12 = $this + 16 | 0;
    __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv($12);
    var $13 = HEAP32[$7 >> 2];
    var $14 = $13 + 60 | 0;
    var $15 = HEAP32[$3 >> 2];
    var $16 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($12);
    var $17 = $14;
    var $18 = $13;
    var $19 = $15;
    var $20 = $11;
    var $21 = $16;
    var $22 = __ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE($17, $18, $19, $20, $21);
    if ($22) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $24 = HEAP32[$7 >> 2];
    var $25 = __ZN9JSContext18isExceptionPendingEv($24);
    if ($25) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN9JSContext20wrapPendingExceptionEv($24);
    __label__ = 5;
    break;
   case 5:
    HEAP8[$this + 48 | 0] = 1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $2 = __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    HEAP32[$5 >> 2] = 0;
    HEAP32[$5 + 4 >> 2] = 0;
    HEAP32[$5 + 8 >> 2] = 0;
    HEAP32[$5 + 12 >> 2] = 0;
    HEAP32[$5 + 16 >> 2] = 0;
    HEAP32[$5 + 20 >> 2] = 0;
    HEAP32[$5 + 24 >> 2] = 0;
    __ZN2js15DummyFrameGuardC1Ev($2);
    __label__ = 3;
    break;
   case 3:
    HEAP8[$this + 28 | 0] = 1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this);
  return $1;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv($this) {
  var $1 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv($this);
  __ZN2js15DummyFrameGuardD1Ev($1);
  HEAP8[$this + 28 | 0] = 0;
  return;
}

function __ZN2js11ErrorCopierD2Ev($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $exc = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $this | 0;
    var $3 = HEAP32[$2 >> 2];
    var $5 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$3 + 12 >> 2];
    if ((HEAP32[$5 + 56 >> 2] | 0) == ($9 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 4 >> 2] | 0) == ($9 | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = __ZN9JSContext18isExceptionPendingEv($5);
    if ($16) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    __ZN9JSContext19getPendingExceptionEv($exc, $5);
    var $18 = __ZNK2JS5Value8isObjectEv($exc);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $20 = __ZNK2JS5Value8toObjectEv($exc);
    var $21 = $20;
    var $22 = __ZNK8JSObject7isErrorEv($21);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $24 = __ZNK8JSObject10getPrivateEv($20);
    if (($24 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN9JSContext21clearPendingExceptionEv($5);
    var $27 = HEAP32[$2 >> 2];
    __ZN2js15AutoCompartment5leaveEv($27);
    var $28 = __ZNK2JS5Value8toObjectEv($exc);
    var $31 = $5;
    var $32 = $28;
    var $33 = HEAP32[$this + 4 >> 2];
    var $34 = __Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_($31, $32, $33);
    if (($34 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $37 = $34;
    __ZN2JSL11ObjectValueER8JSObject4137($1, $37);
    __ZN9JSContext19setPendingExceptionEN2JS5ValueE($5, $1);
    __label__ = 9;
    break;
   case 9:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapperC2Ej($this, $flags) {
  var $1 = $this | 0;
  var $2 = $flags | 1;
  __ZN9JSWrapperC2Ej($1, $2);
  HEAP32[$this >> 2] = __ZTV25JSCrossCompartmentWrapper + 8 | 0;
  return;
}

function __ZN25JSCrossCompartmentWrapperD0Ev($this) {
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($9, $cx, $wrapper, $10, $set, $desc);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[$call + 4 >> 2];
    var $15 = $desc;
    var $16 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($14, $cx, $15);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $set, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor($9, $cx, $wrapper, $10, $set, $desc);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $14 = HEAP32[$call + 4 >> 2];
    var $15 = $desc;
    var $16 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($14, $cx, $15);
    var $_0 = $16;
    __label__ = 6;
    break;
   case 5:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($this, $cx, $wrapper, $id, $desc) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 104;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $desc2 = __stackBase__ + 4;
    var $call = __stackBase__ + 52;
    HEAP32[$1 >> 2] = $id;
    __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor($desc2, $cx, $desc);
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $call + 12 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $9 = HEAP32[$5 >> 2];
    var $10 = $desc2 + 16 | 0;
    var $phitmp = $10;
    var $11 = __ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor($9, $cx, $phitmp);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $17 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$1 >> 2];
    var $15 = __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor($13, $cx, $wrapper, $14, $10);
    var $17 = $15;
    __label__ = 5;
    break;
   case 5:
    var $17;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $17;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    __ZN2js28AutoPropertyDescriptorRooterD1Ev($desc2);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc);
  return;
}

function __ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($this) {
  return $this;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev($this) {
  HEAP8[$this + 28 | 0] = 0;
  return;
}

function __ZN17AutoCloseIterator5clearEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  return;
}

function __ZN17AutoCloseIteratorC2EP9JSContextP8JSObject($this, $cx, $obj) {
  HEAP32[$this >> 2] = $cx;
  HEAP32[$this + 4 >> 2] = $obj;
  return;
}

function _JS_XDRInitBase($xdr, $mode, $cx) {
  HEAP32[$xdr >> 2] = $mode;
  HEAP32[$xdr + 8 >> 2] = $cx;
  HEAP32[$xdr + 12 >> 2] = 0;
  HEAP32[$xdr + 20 >> 2] = 0;
  HEAP32[$xdr + 16 >> 2] = 0;
  HEAP32[$xdr + 24 >> 2] = 0;
  HEAP32[$xdr + 28 >> 2] = 0;
  HEAP32[$xdr + 32 >> 2] = 0;
  HEAP32[$xdr + 36 >> 2] = 0;
  return;
}

function _JS_XDRMemGetData($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP32[$xdr + 44 >> 2];
    HEAP32[$lp >> 2] = $7;
    var $_0 = HEAP32[$xdr + 40 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRMemSetData($xdr, $data, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$xdr + 48 >> 2] = $len;
    HEAP32[$xdr + 40 >> 2] = $data;
    HEAP32[$xdr + 44 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRMemDataLeft($xdr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$xdr + 48 >> 2] - HEAP32[$xdr + 44 >> 2] | 0;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRMemResetData($xdr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xdr + 4 >> 2] | 0) == (__ZL10xdrmem_ops | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$xdr + 44 >> 2] = 0;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb($this, $cx, $wrapper, $id, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $call = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 12 >> 2];
    var $7 = __ZN13JSCompartment6wrapIdEP9JSContextPi($6, $cx, $1);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $this | 0;
    var $10 = HEAP32[$1 >> 2];
    var $11 = __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb($9, $cx, $wrapper, $10, $bp);
    var $13 = $11;
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $13;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $call = __stackBase__ + 8;
    HEAP32[$1 >> 2] = $receiver;
    HEAP32[$2 >> 2] = $id;
    var $3 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $3);
    var $4 = __ZN2js15AutoCompartment5enterEv($call);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = $call + 12 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($7, $cx, $1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    var $11 = __ZN13JSCompartment6wrapIdEP9JSContextPi($10, $cx, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = $this | 0;
    var $14 = HEAP32[$1 >> 2];
    var $15 = HEAP32[$2 >> 2];
    var $16 = __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE($13, $cx, $wrapper, $14, $15, $vp);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $19 = HEAP32[$call + 4 >> 2];
    var $20 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($19, $cx, $vp);
    var $_0 = $20;
    __label__ = 8;
    break;
   case 6:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($this, $cx, $wrapper, $receiver, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 84;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $call = __stackBase__ + 32;
    HEAP32[$1 >> 2] = $receiver;
    HEAP32[$2 >> 2] = $id;
    __ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE($tvr, $cx, $vp);
    var $3 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $3);
    var $4 = __ZN2js15AutoCompartment5enterEv($call);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 2:
    var $6 = $call + 12 | 0;
    var $7 = HEAP32[$6 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($7, $cx, $1);
    if ($8) {
      __label__ = 3;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    var $11 = __ZN13JSCompartment6wrapIdEP9JSContextPi($10, $cx, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $13 = HEAP32[$6 >> 2];
    var $14 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $15 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($13, $cx, $14);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      var $21 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $this | 0;
    var $18 = HEAP32[$2 >> 2];
    var $19 = __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE($17, $cx, $wrapper, undef, $18, undef, $14);
    var $21 = $19;
    __label__ = 6;
    break;
   case 6:
    var $21;
    __ZN2js15AutoCompartment5leaveEv($call);
    var $_0 = $21;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($this, $cx, $wrapper, $props) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE($4, $cx, $wrapper, $props);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = HEAP32[$call + 4 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE($8, $cx, $props);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $flags, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE($4, $cx, $wrapper, $flags, $vp);
    __ZN2js15AutoCompartment5leaveEv($call);
    if ($5) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 3:
    var $7 = __ZL8CanReifyPN2JS5ValueE($vp);
    var $9 = HEAP32[$call + 4 >> 2];
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE($cx, $9, $vp);
    var $_0 = $11;
    __label__ = 6;
    break;
   case 5:
    var $13 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($9, $cx, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8CanReifyPN2JS5ValueE($vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($vp);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = __ZNK8JSObject8getClassEv($3);
    if (($4 | 0) == (__ZN2js13IteratorClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZNK8JSObject17getNativeIteratorEv($3);
    var $13 = (HEAP32[$7 + 28 >> 2] & 1 | 0) != 0;
    __label__ = 4;
    break;
   case 4:
    var $13;
    return $13;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE($cx, $origin, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 72;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $close = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $keys = __stackBase__ + 12;
    var $1 = __ZNK2JS5Value8toObjectEv($vp);
    var $2 = __ZNK8JSObject17getNativeIteratorEv($1);
    __ZN17AutoCloseIteratorC1EP9JSContextP8JSObject($close, $cx, $1);
    var $4 = HEAP32[$2 >> 2];
    HEAP32[$obj >> 2] = $4;
    var $5 = __ZN13JSCompartment4wrapEP9JSContextPP8JSObject($origin, $cx, $obj);
    if ($5) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    var $7 = __ZNK2js14NativeIterator7numKeysEv($2);
    var $8 = __ZNK2js14NativeIterator9isKeyIterEv($2);
    __ZN2js12AutoIdVectorC1EP9JSContext($keys, $cx);
    if (($7 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = $keys | 0;
    var $12 = __ZN2js16AutoVectorRooterIiE6resizeEj($11, $7);
    if ($12) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    var $13 = $2;
    var $i_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $i_0;
    if ($i_0 >>> 0 < $7 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $17 = __ZNK2js14NativeIterator5beginEv($13);
    var $19 = HEAP32[$17 + ($i_0 << 2) >> 2];
    var $20 = __ZN2js16AutoVectorRooterIiEixEj($11, $i_0);
    HEAP32[$20 >> 2] = $19;
    var $21 = __ZN2js16AutoVectorRooterIiEixEj($11, $i_0);
    var $22 = __ZN13JSCompartment6wrapIdEP9JSContextPi($origin, $cx, $21);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    __ZN17AutoCloseIterator5clearEv($close);
    var $25 = $cx;
    var $26 = $1;
    var $27 = __Z16js_CloseIteratorP9JSContextP8JSObject($25, $26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAP32[$2 + 28 >> 2];
    var $33 = HEAP32[$obj >> 2];
    var $34 = $keys;
    if ($8) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = __ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($25, $33, $32, $34, $vp);
    var $_0 = $36;
    __label__ = 12;
    break;
   case 11:
    var $38 = __ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE($25, $33, $32, $34, $vp);
    var $_0 = $38;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN2js12AutoIdVectorD1Ev($keys);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    __ZN17AutoCloseIteratorD1Ev($close);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE["X"] = 1;

function __ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($this, $cx, $wrapper, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __stackBase__ + 52;
    var $2 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $2);
    var $3 = __ZN2js15AutoCompartment5enterEv($call);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $6 = HEAP32[$call + 8 >> 2];
    __ZN2JSL11ObjectValueER8JSObject4137($1, $6);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = $call + 12 | 0;
    var $11 = HEAP32[$10 >> 2];
    var $12 = $vp + 8 | 0;
    var $13 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($11, $cx, $12);
    if ($13) {
      var $n_0 = 0;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $n_0;
    if ($n_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $16 = HEAP32[$10 >> 2];
    var $17 = $vp + ($n_0 + 2 << 3) | 0;
    var $18 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($16, $cx, $17);
    if ($18) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $22 = $this | 0;
    var $23 = __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE($22, $cx, $wrapper, $argc, $vp);
    if ($23) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $26 = HEAP32[$call + 4 >> 2];
    var $27 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($26, $cx, $vp);
    var $_0 = $27;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($this, $cx, $wrapper, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 2:
    var $3 = $call + 12 | 0;
    var $n_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $n_0;
    if ($n_0 >>> 0 < $argc >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    var $7 = HEAP32[$3 >> 2];
    var $8 = $argv + ($n_0 << 3) | 0;
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($7, $cx, $8);
    if ($9) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $n_0 = $n_0 + 1 | 0;
    __label__ = 3;
    break;
   case 6:
    var $13 = $this | 0;
    var $14 = __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_($13, $cx, $wrapper, $argc, $argv, $rval);
    if ($14) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $17 = HEAP32[$call + 4 >> 2];
    var $18 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($17, $cx, $rval);
    var $_0 = $18;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($this, $cx, $wrapper, $vp, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $v = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = $vp | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = $v | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    var $8 = HEAP32[$call + 12 >> 2];
    var $9 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($8, $cx, $v);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $this | 0;
    var $12 = __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb($11, $cx, $wrapper, $v, $bp);
    var $_0 = $12;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject($this, $cx, $wrapper) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $str = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject($4, $cx, $wrapper);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $9 = HEAP32[$call + 4 >> 2];
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($9, $cx, $str);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj($this, $cx, $wrapper, $indent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $str = __stackBase__ + 52;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = $this | 0;
    var $5 = __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj($4, $cx, $wrapper, $indent);
    HEAP32[$str >> 2] = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $9 = HEAP32[$call + 4 >> 2];
    var $10 = __ZN13JSCompartment4wrapEP9JSContextPP8JSString($9, $cx, $str);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = HEAP32[$str >> 2];
    __label__ = 5;
    break;
   case 5:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE($this, $cx, $wrapper, $hint, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $call = __stackBase__;
    var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
    __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject($call, $cx, $1);
    var $2 = __ZN2js15AutoCompartment5enterEv($call);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE(undef, $cx, $wrapper, $hint, $vp);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    __ZN2js15AutoCompartment5leaveEv($call);
    var $7 = HEAP32[$call + 4 >> 2];
    var $8 = __ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE($7, $cx, $vp);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js15AutoCompartmentD2Ev($call);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject($this, $trc, $wrapper) {
  var $1 = __ZN9JSWrapper13wrappedObjectEPK8JSObject($wrapper);
  __ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc($trc, $1, undef);
  return;
}

function __ZN2js15DummyFrameGuardD1Ev($this) {
  __ZN2js15DummyFrameGuardD2Ev($this);
  return;
}

function __ZN2js15DummyFrameGuardD2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardD2Ev($1);
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this) {
  var $1 = $this | 0;
  var $2 = __ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv($1);
  return $2;
}

function __ZN2js15DummyFrameGuardC1Ev($this) {
  __ZN2js15DummyFrameGuardC2Ev($this);
  return;
}

function __ZN2js15DummyFrameGuardC2Ev($this) {
  var $1 = $this | 0;
  __ZN2js10FrameGuardC2Ev($1);
  return;
}

function __ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP8[$this + 28 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv($this);
    __ZN2js15DummyFrameGuardD1Ev($6);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN17AutoCloseIteratorC1EP9JSContextP8JSObject($this, $cx, $obj) {
  __ZN17AutoCloseIteratorC2EP9JSContextP8JSObject($this, $cx, $obj);
  return;
}

function __ZNK2js14NativeIterator7numKeysEv($this) {
  var $1 = $this;
  var $2 = __ZNK2js14NativeIterator3endEv($1);
  var $3 = __ZNK2js14NativeIterator5beginEv($1);
  return $2 - $3 >> 2;
}

function __ZN17AutoCloseIteratorD1Ev($this) {
  __ZN17AutoCloseIteratorD2Ev($this);
  return;
}

function __ZN17AutoCloseIteratorD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$this >> 2];
    var $8 = $2;
    var $9 = __Z16js_CloseIteratorP9JSContextP8JSObject($7, $8);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor($this, $cx, $desc) {
  var $1 = $this | 0;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $cx, -13);
  var $3 = HEAP32[$desc >> 2];
  HEAP32[$this + 16 >> 2] = $3;
  var $6 = HEAP32[$desc + 4 >> 2];
  HEAP32[$this + 20 >> 2] = $6;
  var $9 = HEAP32[$desc + 8 >> 2];
  HEAP32[$this + 24 >> 2] = $9;
  var $12 = HEAP32[$desc + 12 >> 2];
  HEAP32[$this + 28 >> 2] = $12;
  var $14 = $desc + 16 | 0;
  var $15$0 = HEAP32[$14 >> 2];
  var $15$1 = HEAP32[$14 + 4 >> 2];
  var $16 = $this + 32 | 0;
  HEAP32[$16 >> 2] = $15$0;
  HEAP32[$16 + 4 >> 2] = $15$1;
  return;
}

function _JS_XDRNewMem($cx, $mode) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZN9JSContext7malloc_Ej($1, 52);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _JS_XDRInitBase($3, $mode, $cx);
    if (($mode | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $8 = __ZN9JSContext7malloc_Ej($1, 8192);
    HEAP32[$2 + 40 >> 2] = $8;
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv(undef, $2);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 5:
    HEAP32[$2 + 40 >> 2] = 0;
    __label__ = 6;
    break;
   case 6:
    HEAP32[$2 + 4 >> 2] = __ZL10xdrmem_ops;
    HEAP32[$2 + 44 >> 2] = 0;
    HEAP32[$2 + 48 >> 2] = 8192;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRDestroy($xdr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAP32[HEAP32[$xdr + 4 >> 2] + 28 >> 2];
    FUNCTION_TABLE[$4]($xdr);
    var $6 = HEAP32[$xdr + 12 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $6;
    __ZN9JSContext5free_EPv(undef, $9);
    var $11 = HEAP32[$xdr + 24 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    _JS_DHashTableDestroy($14);
    __label__ = 4;
    break;
   case 4:
    var $16 = $xdr;
    __ZN9JSContext5free_EPv(undef, $16);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRUint8($xdr, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $l = __stackBase__;
    HEAP32[$l >> 2] = HEAPU8[$b] & 255;
    var $3 = _JS_XDRUint32($xdr, $l);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP8[$b] = HEAP32[$l >> 2] & 255;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRUint32($xdr, $lp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $xl = __stackBase__;
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $ok_0 = 1;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = HEAP32[$lp >> 2];
    HEAP32[$xl >> 2] = $4;
    var $8 = HEAP32[HEAP32[$xdr + 4 >> 2] + 4 >> 2];
    var $9 = FUNCTION_TABLE[$8]($xdr, $xl);
    var $ok_0 = $9;
    __label__ = 4;
    break;
   case 3:
    var $14 = HEAP32[HEAP32[$xdr + 4 >> 2] >> 2];
    var $15 = FUNCTION_TABLE[$14]($xdr, $lp);
    var $ok_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $ok_0;
    STACKTOP = __stackBase__;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRUint16($xdr, $s) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $l = __stackBase__;
    HEAP32[$l >> 2] = HEAPU16[$s >> 1] & 65535;
    var $3 = _JS_XDRUint32($xdr, $l);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP16[$s >> 1] = HEAP32[$l >> 2] & 65535;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js14XDRScriptStateC2EP10JSXDRState($this, $x) {
  HEAP32[$this >> 2] = $x;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP8[$this + 8 | 0] = 0;
  HEAP32[$x + 36 >> 2] = $this;
  return;
}

function _JS_XDRBytes($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xdr | 0;
    var $4 = $xdr + 4 | 0;
    var $5 = HEAP32[$4 >> 2];
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = HEAP32[$5 + 12 >> 2];
    var $9 = FUNCTION_TABLE[$8]($xdr, $bytes, $len);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = HEAP32[$5 + 8 >> 2];
    var $14 = FUNCTION_TABLE[$13]($xdr, $bytes, $len);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[HEAP32[$4 >> 2] + 24 >> 2];
    var $20 = FUNCTION_TABLE[$19]($xdr);
    var $21 = $20 & 3;
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = 4 - $21 | 0;
    var $27 = HEAP32[$4 >> 2];
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $30 = HEAP32[$27 + 12 >> 2];
    var $31 = FUNCTION_TABLE[$30]($xdr, __ZZ11JS_XDRBytesE6padbuf | 0, $24);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $35 = HEAP32[$27 + 20 >> 2];
    var $36 = FUNCTION_TABLE[$35]($xdr, $24, 1);
    if (($36 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRCString($xdr, $sp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $len = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$sp >> 2];
    var $6 = _strlen($5);
    HEAP32[$len >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    var $8 = _JS_XDRUint32($xdr, $len);
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = HEAP32[$sp >> 2];
    __label__ = 6;
    break;
   case 5:
    var $15 = HEAP32[$len >> 2] + 1 | 0;
    var $16 = HEAP32[$xdr + 8 >> 2];
    var $17 = __ZN9JSContext7malloc_Ej($16, $15);
    HEAP32[$sp >> 2] = $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      var $20 = $17;
      __label__ = 6;
      break;
    }
   case 6:
    var $20;
    var $21 = HEAP32[$len >> 2];
    var $22 = _JS_XDRBytes($xdr, $20, $21);
    var $25 = (HEAP32[$1 >> 2] | 0) == 1;
    if (($22 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    if ($25) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $28 = HEAP32[$sp >> 2];
    __ZN9JSContext5free_EPv(undef, $28);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 9:
    if ($25) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 10:
    HEAP8[HEAP32[$sp >> 2] + HEAP32[$len >> 2] | 0] = 0;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRCStringOrNull($xdr, $sp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $null = __stackBase__;
    var $3 = (HEAP32[$sp >> 2] | 0) == 0 & 1;
    HEAP32[$null >> 2] = $3;
    var $4 = _JS_XDRUint32($xdr, $null);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$null >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$sp >> 2] = 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $11 = _JS_XDRCString($xdr, $sp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRString($xdr, $strp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nchars = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = HEAP32[$strp >> 2];
    var $6 = __ZNK8JSString6lengthEv($5);
    HEAP32[$nchars >> 2] = $6;
    __label__ = 3;
    break;
   case 3:
    var $8 = _JS_XDRUint32($xdr, $nchars);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = (HEAP32[$nchars >> 2] << 1) + 2 | 0;
    var $19 = HEAP32[$xdr + 8 >> 2];
    var $20 = __ZN9JSContext7malloc_Ej($19, $18);
    var $chars_0 = $20;
    __label__ = 7;
    break;
   case 6:
    var $23 = HEAP32[$strp >> 2];
    var $26 = HEAP32[$xdr + 8 >> 2];
    var $27 = __ZN8JSString8getCharsEP9JSContext($23, $26);
    var $chars_0 = $27;
    __label__ = 7;
    break;
   case 7:
    var $chars_0;
    if (($chars_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $31 = HEAP32[$nchars >> 2];
    var $32 = __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars_0, $31);
    if (($32 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 10:
    HEAP16[$chars_0 + (HEAP32[$nchars >> 2] << 1) >> 1] = 0;
    var $42 = HEAP32[$nchars >> 2];
    var $43 = HEAP32[$xdr + 8 >> 2];
    var $44 = _JS_NewUCString($43, $chars_0, $42);
    HEAP32[$strp >> 2] = $44;
    if (($44 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 11:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv(undef, $chars_0);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRString["X"] = 1;

function __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars, $nchars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nchars << 1;
    var $2 = $1 & 2;
    if (($2 | 0) == 0) {
      var $nbytes_0 = $1;
      var $padlen_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = 4 - $2 | 0;
    var $nbytes_0 = $5 + $1 | 0;
    var $padlen_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $padlen_0;
    var $nbytes_0;
    var $11 = HEAP32[HEAP32[$xdr + 4 >> 2] + 16 >> 2];
    var $12 = FUNCTION_TABLE[$11]($xdr, $nbytes_0);
    var $13 = $12;
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = HEAP32[$xdr >> 2];
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 11;
      break;
    }
   case 5:
    if (($nchars | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    if (($nchars | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $i_11 = 0;
      __label__ = 10;
      break;
    }
   case 7:
    var $i_03;
    var $21 = HEAP16[$chars + ($i_03 << 1) >> 1];
    HEAP16[$13 + ($i_03 << 1) >> 1] = $21;
    var $23 = $i_03 + 1 | 0;
    if (($23 | 0) == ($nchars | 0)) {
      __label__ = 8;
      break;
    } else {
      var $i_03 = $23;
      __label__ = 7;
      break;
    }
   case 8:
    if (($padlen_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = $12 + ($nbytes_0 - $padlen_0) | 0;
    _memset($27, 0, $padlen_0, 1);
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $i_11;
    var $29 = HEAP16[$13 + ($i_11 << 1) >> 1];
    HEAP16[$chars + ($i_11 << 1) >> 1] = $29;
    var $31 = $i_11 + 1 | 0;
    if (($31 | 0) == ($nchars | 0)) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      var $i_11 = $31;
      __label__ = 10;
      break;
    }
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRStringOrNull($xdr, $strp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $null = __stackBase__;
    var $3 = (HEAP32[$strp >> 2] | 0) == 0 & 1;
    HEAP32[$null >> 2] = $3;
    var $4 = _JS_XDRUint32($xdr, $null);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$null >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$strp >> 2] = 0;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 4:
    var $11 = _JS_XDRString($xdr, $strp);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRDouble($xdr, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    tempDoubleF64[0] = $7, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $8 = __ZL14XDRDoubleValueP10JSXDRStatePd($xdr, $d);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 6;
      break;
    }
   case 5:
    var $14 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $14, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14XDRDoubleValueP10JSXDRStatePd($xdr, $dp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $u = __stackBase__;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = (tempDoubleI32[0] = HEAP32[$dp >> 2], tempDoubleI32[1] = HEAP32[$dp + 4 >> 2], tempDoubleF64[0]);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = $u;
    tempDoubleF64[0] = $7, HEAP32[$8 >> 2] = tempDoubleI32[0], HEAP32[$8 + 4 >> 2] = tempDoubleI32[1];
    var $9 = $u | 0;
    var $10 = _JS_XDRUint32($xdr, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $u + 4 | 0;
    var $14 = _JS_XDRUint32($xdr, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = (tempDoubleI32[0] = HEAP32[$8 >> 2], tempDoubleI32[1] = HEAP32[$8 + 4 >> 2], tempDoubleF64[0]);
    tempDoubleF64[0] = $20, HEAP32[$dp >> 2] = tempDoubleI32[0], HEAP32[$dp + 4 >> 2] = tempDoubleI32[1];
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRValue($xdr, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $type = __stackBase__;
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $vp | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = __ZL9GetXDRTagN2JS5ValueE($6$0, $6$1);
    HEAP32[$type >> 2] = $7;
    __label__ = 3;
    break;
   case 3:
    var $9 = _JS_XDRUint32($xdr, $type);
    if (($9 | 0) == 0) {
      var $16 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAP32[$type >> 2];
    var $13 = __ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE($xdr, $12, $vp);
    var $16 = ($13 | 0) != 0;
    __label__ = 5;
    break;
   case 5:
    var $16;
    STACKTOP = __stackBase__;
    return $16 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9GetXDRTagN2JS5ValueE($_0_0_0_val$0, $_0_0_0_val$1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_NULL($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 5;
      __label__ = 7;
      break;
    }
   case 2:
    var $4 = _JSVAL_IS_VOID($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 6;
      __label__ = 7;
      break;
    }
   case 3:
    var $7 = _JSVAL_IS_OBJECT($_0_0_0_val$0, $_0_0_0_val$1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = _JSVAL_IS_INT($_0_0_0_val$0, $_0_0_0_val$1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 5:
    var $13 = _JSVAL_IS_DOUBLE4214($_0_0_0_val$0, $_0_0_0_val$1);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 2;
      __label__ = 7;
      break;
    }
   case 6:
    var $16 = _JSVAL_IS_STRING4215($_0_0_0_val$0, $_0_0_0_val$1);
    var $_ = ($16 | 0) == 0 ? 4 : 3;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE($xdr, $type, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 64;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $d = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $obj = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $b = __stackBase__ + 40;
    var $4 = __stackBase__ + 44;
    var $i = __stackBase__ + 52;
    var $5 = __stackBase__ + 56;
    if (($type | 0) == 5) {
      __label__ = 2;
      break;
    } else if (($type | 0) == 6) {
      __label__ = 3;
      break;
    } else if (($type | 0) == 3) {
      __label__ = 4;
      break;
    } else if (($type | 0) == 2) {
      __label__ = 9;
      break;
    } else if (($type | 0) == 0) {
      __label__ = 14;
      break;
    } else if (($type | 0) == 4) {
      __label__ = 19;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $7$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $7$1 = HEAP32[$st$1$1 >> 2];
    var $8 = $vp | 0;
    var $st$6$0 = $8 | 0;
    HEAP32[$st$6$0 >> 2] = $7$0;
    var $st$6$1 = $8 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $7$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 3:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $10$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $10$1 = HEAP32[$st$1$1 >> 2];
    var $11 = $vp | 0;
    var $st$6$0 = $11 | 0;
    HEAP32[$st$6$0 >> 2] = $10$0;
    var $st$6$1 = $11 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $10$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 4:
    var $13 = $xdr | 0;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $17 = $vp | 0;
    var $st$1$0 = $17 | 0;
    var $18$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $17 + 4 | 0;
    var $18$1 = HEAP32[$st$1$1 >> 2];
    var $19 = _JSVAL_TO_STRING4194($18$0, $18$1);
    HEAP32[$str >> 2] = $19;
    __label__ = 6;
    break;
   case 6:
    var $21 = _JS_XDRString($xdr, $str);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$13 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 8:
    var $27 = HEAP32[$str >> 2];
    _STRING_TO_JSVAL4195($1, $27);
    var $28 = $1 | 0;
    var $st$3$0 = $28 | 0;
    var $29$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $28 + 4 | 0;
    var $29$1 = HEAP32[$st$3$1 >> 2];
    var $30 = $vp | 0;
    var $st$8$0 = $30 | 0;
    HEAP32[$st$8$0 >> 2] = $29$0;
    var $st$8$1 = $30 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $29$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 9:
    var $32 = $xdr | 0;
    if ((HEAP32[$32 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $40 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = $vp | 0;
    var $st$1$0 = $36 | 0;
    var $37$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $36 + 4 | 0;
    var $37$1 = HEAP32[$st$1$1 >> 2];
    var $38 = _JSVAL_TO_DOUBLE4196($37$0, $37$1);
    var $40 = $38;
    __label__ = 11;
    break;
   case 11:
    var $40;
    tempDoubleF64[0] = $40, HEAP32[$d >> 2] = tempDoubleI32[0], HEAP32[$d + 4 >> 2] = tempDoubleI32[1];
    var $41 = _JS_XDRDouble($xdr, $d);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$32 >> 2] | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 13:
    var $47 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL4197($2, $47);
    var $48 = $2 | 0;
    var $st$3$0 = $48 | 0;
    var $49$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $48 + 4 | 0;
    var $49$1 = HEAP32[$st$3$1 >> 2];
    var $50 = $vp | 0;
    var $st$8$0 = $50 | 0;
    HEAP32[$st$8$0 >> 2] = $49$0;
    var $st$8$1 = $50 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $49$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 14:
    var $52 = $xdr | 0;
    if ((HEAP32[$52 >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $56 = $vp | 0;
    var $st$1$0 = $56 | 0;
    var $57$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $56 + 4 | 0;
    var $57$1 = HEAP32[$st$1$1 >> 2];
    var $58 = _JSVAL_TO_OBJECT4198($57$0, $57$1);
    HEAP32[$obj >> 2] = $58;
    __label__ = 16;
    break;
   case 16:
    var $60 = $xdr;
    var $61 = $obj;
    var $62 = __Z12js_XDRObjectP10JSXDRStatePP8JSObject($60, $61);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$52 >> 2] | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 18:
    var $68 = HEAP32[$obj >> 2];
    _OBJECT_TO_JSVAL4199($3, $68);
    var $69 = $3 | 0;
    var $st$3$0 = $69 | 0;
    var $70$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $69 + 4 | 0;
    var $70$1 = HEAP32[$st$3$1 >> 2];
    var $71 = $vp | 0;
    var $st$8$0 = $71 | 0;
    HEAP32[$st$8$0 >> 2] = $70$0;
    var $st$8$1 = $71 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $70$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 19:
    var $73 = $xdr | 0;
    if ((HEAP32[$73 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $77 = $vp | 0;
    var $st$1$0 = $77 | 0;
    var $78$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $77 + 4 | 0;
    var $78$1 = HEAP32[$st$1$1 >> 2];
    var $79 = _JSVAL_TO_BOOLEAN4200($78$0, $78$1);
    HEAP32[$b >> 2] = $79;
    __label__ = 21;
    break;
   case 21:
    var $81 = _JS_XDRUint32($xdr, $b);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    if ((HEAP32[$73 >> 2] | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 23:
    var $89 = (HEAP32[$b >> 2] | 0) != 0 & 1;
    _BOOLEAN_TO_JSVAL4201($4, $89);
    var $90 = $4 | 0;
    var $91$0 = HEAP32[$90 >> 2];
    var $91$1 = HEAP32[$90 + 4 >> 2];
    var $92 = $vp | 0;
    HEAP32[$92 >> 2] = $91$0;
    HEAP32[$92 + 4 >> 2] = $91$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 24:
    var $94 = $xdr | 0;
    if ((HEAP32[$94 >> 2] | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $98 = $vp | 0;
    var $st$1$0 = $98 | 0;
    var $99$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $98 + 4 | 0;
    var $99$1 = HEAP32[$st$1$1 >> 2];
    var $100 = _JSVAL_TO_INT4202($99$0, $99$1);
    HEAP32[$i >> 2] = $100;
    __label__ = 26;
    break;
   case 26:
    var $102 = _JS_XDRUint32($xdr, $i);
    if (($102 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ((HEAP32[$94 >> 2] | 0) == 1) {
      __label__ = 28;
      break;
    } else {
      var $_0 = 1;
      __label__ = 29;
      break;
    }
   case 28:
    var $108 = HEAP32[$i >> 2];
    _INT_TO_JSVAL4203($5, $108);
    var $109 = $5 | 0;
    var $st$3$0 = $109 | 0;
    var $110$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $109 + 4 | 0;
    var $110$1 = HEAP32[$st$3$1 >> 2];
    var $111 = $vp | 0;
    var $st$8$0 = $111 | 0;
    HEAP32[$st$8$0 >> 2] = $110$0;
    var $st$8$1 = $111 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $110$1;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE["X"] = 1;

function _js_XDRAtom($xdr, $atomp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 520;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $str = __stackBase__;
    var $nchars = __stackBase__ + 4;
    var $stackChars = __stackBase__ + 8;
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = HEAP32[$atomp >> 2] | 0;
    HEAP32[$str >> 2] = $6;
    var $7 = _JS_XDRString($xdr, $str);
    var $_0 = $7;
    __label__ = 14;
    break;
   case 3:
    var $9 = _JS_XDRUint32($xdr, $nchars);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAP32[$xdr + 8 >> 2];
    var $14 = HEAPU32[$nchars >> 2];
    if ($14 >>> 0 < 257) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $chars_0 = $stackChars | 0;
    var $25 = $14;
    __label__ = 8;
    break;
   case 6:
    var $19 = $14 << 1;
    var $20 = $13;
    var $21 = __ZN9JSContext7malloc_Ej($20, $19);
    if (($21 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $chars_0 = $21;
    var $25 = HEAP32[$nchars >> 2];
    __label__ = 8;
    break;
   case 8:
    var $25;
    var $chars_0;
    var $26 = __ZL8XDRCharsP10JSXDRStatePtj($xdr, $chars_0, $25);
    if (($26 | 0) == 0) {
      var $atom_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = HEAP32[$nchars >> 2];
    var $30 = $13;
    var $31 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($30, $chars_0, $29, 0);
    var $atom_0 = $31;
    __label__ = 10;
    break;
   case 10:
    var $atom_0;
    if (($chars_0 | 0) == ($stackChars | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN9JSContext5free_EPv(undef, $chars_0);
    __label__ = 12;
    break;
   case 12:
    if (($atom_0 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$atomp >> 2] = $atom_0;
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_XDRAtom["X"] = 1;

function __ZN2js14XDRScriptStateD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    var $3 = HEAP32[$1 >> 2] + 36 | 0;
    HEAP32[$3 >> 2] = 0;
    if ((HEAP32[HEAP32[$1 >> 2] >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $10 = HEAP32[$this + 4 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP8[$this + 8 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv(undef, $10);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JS_XDRScript($xdr, $scriptp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $script = __stackBase__;
    var $magic = __stackBase__ + 4;
    var $state = __stackBase__ + 8;
    var $1 = $xdr | 0;
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$script >> 2] = 0;
    HEAP32[$scriptp >> 2] = 0;
    var $8 = 0;
    __label__ = 4;
    break;
   case 3:
    var $6 = HEAP32[$scriptp >> 2];
    HEAP32[$script >> 2] = $6;
    HEAP32[$magic >> 2] = -559087605;
    var $8 = $6;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $9 = _JS_XDRUint32($xdr, $magic);
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$magic >> 2] | 0) == -559087605) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($17, 2, 0, 68, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_1 = 0;
    __label__ = 17;
    break;
   case 7:
    __ZN2js14XDRScriptStateC2EP10JSXDRState($state, $xdr);
    if ((HEAP32[$xdr + 36 >> 2] | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_pre_phi = $state + 4 | 0;
    __label__ = 11;
    break;
   case 10:
    var $27 = HEAP32[$8 + 52 >> 2];
    var $28 = $state + 4 | 0;
    HEAP32[$28 >> 2] = $27;
    var $_pre_phi = $28;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $30 = _JS_XDRCStringOrNull($xdr, $_pre_phi);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $33 = $xdr;
    var $34 = $script;
    var $35 = __Z12js_XDRScriptP10JSXDRStatePP8JSScript($33, $34);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$1 >> 2] | 0) == 1) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 1;
      __label__ = 16;
      break;
    }
   case 14:
    var $41 = $xdr + 8 | 0;
    var $43 = HEAP32[$script >> 2];
    var $44 = HEAP32[$41 >> 2];
    var $45 = $43;
    var $46 = __Z18js_NewScriptObjectP9JSContextP8JSScript($44, $45);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $50 = HEAP32[$41 >> 2];
    __Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction($50, $45, 0);
    var $54 = HEAP32[$41 >> 2];
    var $55 = $43;
    var $56 = HEAP32[$43 + 84 >> 2];
    __ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE($54, $55, $56, 1);
    HEAP32[$scriptp >> 2] = $43;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    __ZN2js14XDRScriptStateD2Ev($state);
    var $_1 = $_0;
    __label__ = 17;
    break;
   case 17:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRScript["X"] = 1;

function _JS_XDRRegisterClass($xdr, $clasp, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xdr + 16 | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $xdr + 20 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($2 | 0) == ($4 | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $_ = ($4 | 0) == 0 ? 8 : $4 << 1;
    var $11 = $xdr + 12 | 0;
    var $13 = HEAP32[$11 >> 2];
    var $14 = $_ << 2;
    var $15 = HEAP32[$xdr + 8 >> 2];
    var $16 = __ZN9JSContext8realloc_EPvj($15, $13, $14);
    var $17 = $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$11 >> 2] = $17;
    HEAP32[$3 >> 2] = $_;
    var $registry_0 = $17;
    __label__ = 5;
    break;
   case 4:
    var $registry_0 = HEAP32[$xdr + 12 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $registry_0;
    var $24 = $registry_0 + ($2 << 2) | 0;
    HEAP32[$24 >> 2] = $clasp;
    var $26 = HEAP32[$xdr + 24 >> 2];
    if (($26 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $clasp | 0;
    var $30 = HEAP32[$29 >> 2];
    var $31 = $26;
    var $32 = _JS_DHashTableOperate($31, $30, 1);
    if (($32 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $37 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportOutOfMemory($37);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 8:
    var $40 = $32 + 4 | 0;
    var $_c = HEAP32[$29 >> 2];
    HEAP32[$40 >> 2] = $_c;
    var $41 = $32 + 8 | 0;
    HEAP32[$41 >> 2] = $2;
    __label__ = 9;
    break;
   case 9:
    var $43 = $2 + 1 | 0;
    HEAP32[$idp >> 2] = $43;
    HEAP32[$1 >> 2] = $43;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRRegisterClass["X"] = 1;

function _JSVAL_TO_INT32_IMPL4206($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_BOOLEAN_IMPL4209($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_OBJECT_IMPL4211($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_TO_STRING_IMPL4213($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_STRING_IMPL4216($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _JSVAL_IS_DOUBLE_IMPL4217($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967169 & 1;
}

function _JSVAL_IS_INT32_IMPL4218($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function _JSVAL_IS_OBJECT_OR_NULL_IMPL4219($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 > 4294967173 & 1;
}

function _JSVAL_IS_UNDEFINED_IMPL4220($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function _JSVAL_IS_NULL_IMPL4221($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JS_XDRFindClassById($xdr, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $id - 1 | 0;
    if ($1 >>> 0 < HEAPU32[$xdr + 16 >> 2] >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[HEAP32[$xdr + 12 >> 2] + ($1 << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _INT32_TO_JSVAL_IMPL4205($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL4208($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function _OBJECT_TO_JSVAL_IMPL4210($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function _STRING_TO_JSVAL_IMPL4212($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZL8mem_tellP10JSXDRState($xdr) {
  return HEAP32[$xdr + 44 >> 2];
}

function _JS_XDRFindClassIdByName($xdr, $name) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$xdr + 16 >> 2];
    if ($2 >>> 0 > 9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $xdr + 12 | 0;
    var $i_1 = 0;
    __label__ = 10;
    break;
   case 3:
    var $6 = $xdr + 24 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $37 = $7;
      __label__ = 8;
      break;
    }
   case 4:
    var $11 = ($2 >>> 0) / .75;
    var $12 = $11 >= 0 ? Math.floor($11) : Math.ceil($11);
    var $17 = (($12 * 192 | 0) >>> 8 >>> 0 < $2 >>> 0 & 1) + $12 | 0;
    var $18 = _JS_NewDHashTable(__ZL8stub_ops, 0, 12, $17);
    var $19 = $18;
    HEAP32[$6 >> 2] = $19;
    if (($18 | 0) == 0 | ($2 | 0) == 0) {
      var $35 = $19;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $22 = $xdr + 12 | 0;
    var $i_01 = 0;
    var $23 = $19;
    __label__ = 6;
    break;
   case 6:
    var $23;
    var $i_01;
    var $27 = HEAP32[HEAP32[$22 >> 2] + ($i_01 << 2) >> 2] | 0;
    var $28 = HEAP32[$27 >> 2];
    var $30 = _JS_DHashTableOperate($23, $28, 1);
    var $32 = $30 + 4 | 0;
    var $_c = HEAP32[$27 >> 2];
    HEAP32[$32 >> 2] = $_c;
    var $33 = $30 + 8 | 0;
    HEAP32[$33 >> 2] = $i_01;
    var $34 = $i_01 + 1 | 0;
    var $_pr_pre = HEAPU32[$6 >> 2];
    if (($34 | 0) == ($2 | 0)) {
      var $35 = $_pr_pre;
      __label__ = 7;
      break;
    } else {
      var $i_01 = $34;
      var $23 = $_pr_pre;
      __label__ = 6;
      break;
    }
   case 7:
    var $35;
    if (($35 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $37 = $35;
      __label__ = 8;
      break;
    }
   case 8:
    var $37;
    var $39 = _JS_DHashTableOperate($37, $name, 0);
    if ((HEAP32[$39 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_0 = HEAP32[$39 + 8 >> 2] + 1 | 0;
    __label__ = 12;
    break;
   case 10:
    var $i_1;
    if ($i_1 >>> 0 < $2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[HEAP32[HEAP32[$4 >> 2] + ($i_1 << 2) >> 2] >> 2];
    var $55 = _strcmp($name, $54);
    var $57 = $i_1 + 1 | 0;
    if (($55 | 0) == 0) {
      var $_0 = $57;
      __label__ = 12;
      break;
    } else {
      var $i_1 = $57;
      __label__ = 10;
      break;
    }
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_JS_XDRFindClassIdByName["X"] = 1;

function _JSVAL_TO_STRING4194($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL4213($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _STRING_TO_JSVAL4195($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL4212($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_TO_DOUBLE4196($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function _DOUBLE_TO_JSVAL4197($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_OBJECT4198($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL4211($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _OBJECT_TO_JSVAL4199($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL4210($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_BOOLEAN4200($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_BOOLEAN_IMPL4209($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _BOOLEAN_TO_JSVAL4201($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL4208($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_TO_INT4202($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL4206($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _INT_TO_JSVAL4203($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL4205($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4204($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_NULL($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NULL_IMPL4221($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_VOID($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_UNDEFINED_IMPL4220($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_OBJECT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_OBJECT_OR_NULL_IMPL4219($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_INT($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_INT32_IMPL4218($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_DOUBLE4214($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_DOUBLE_IMPL4217($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_STRING4215($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4207($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL4216($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL9mem_get32P10JSXDRStatePj($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAPU32[$xdr + 44 >> 2];
    if ((HEAP32[$xdr >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    if (($6 + 4 | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($16, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $17;
    var $21 = $xdr + 44 | 0;
    var $22 = $21;
    var $25 = HEAP32[HEAP32[$xdr + 40 >> 2] + $17 >> 2];
    HEAP32[$lp >> 2] = $25;
    var $_c = HEAP32[$22 >> 2] + 4 | 0;
    HEAP32[$21 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9mem_set32P10JSXDRStatePj($xdr, $lp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = HEAPU32[$xdr + 44 >> 2];
    if (($11 + 4 | 0) >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $11 + 8195 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    HEAP32[$4 >> 2] = $16;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + 4 | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $40 = HEAP32[$lp >> 2];
    var $44 = $xdr + 44 | 0;
    var $45 = $44;
    var $48 = HEAP32[$xdr + 40 >> 2] + HEAP32[$45 >> 2] | 0;
    HEAP32[$48 >> 2] = $40;
    var $_c = HEAP32[$45 >> 2] + 4 | 0;
    HEAP32[$44 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9mem_set32P10JSXDRStatePj["X"] = 1;

function __ZL12mem_getbytesP10JSXDRStatePcj($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $6 = HEAPU32[$xdr + 44 >> 2];
    if ((HEAP32[$xdr >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 2:
    if (($6 + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $17 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $16 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($16, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $17;
    var $21 = $xdr + 44 | 0;
    var $22 = $21;
    var $23 = HEAP32[$xdr + 40 >> 2] + $17 | 0;
    _memcpy($bytes, $23, $len, 1);
    var $_c = HEAP32[$22 >> 2] + $len | 0;
    HEAP32[$21 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12mem_setbytesP10JSXDRStatePcj($xdr, $bytes, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$xdr + 44 >> 2] + $len | 0;
    if ($12 >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $12 + 8191 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    var $_c2 = $16;
    HEAP32[$4 >> 2] = $_c2;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $43 = $xdr + 44 | 0;
    var $44 = $43;
    var $46 = HEAP32[$xdr + 40 >> 2] + HEAP32[$44 >> 2] | 0;
    _memcpy($46, $bytes, $len, 1);
    var $_c = HEAP32[$44 >> 2] + $len | 0;
    HEAP32[$43 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12mem_setbytesP10JSXDRStatePcj["X"] = 1;

function __ZL7mem_rawP10JSXDRStatej($xdr, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xdr >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $4 = $xdr + 48 | 0;
    var $6 = HEAPU32[$4 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = HEAP32[$xdr + 44 >> 2] + $len | 0;
    if ($12 >>> 0 > $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = $12 + 8191 & -8192;
    var $19 = $xdr + 40 | 0;
    var $21 = HEAP32[$19 >> 2];
    var $22 = HEAP32[$xdr + 8 >> 2];
    var $23 = __ZN9JSContext8realloc_EPvj($22, $21, $16);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_c1 = $23;
    HEAP32[$19 >> 2] = $_c1;
    var $_c2 = $16;
    HEAP32[$4 >> 2] = $_c2;
    __label__ = 8;
    break;
   case 6:
    if ((HEAP32[$xdr + 44 >> 2] + $len | 0) >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $39 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($39, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $43 = $xdr + 44 | 0;
    var $45 = HEAP32[$43 >> 2];
    var $46 = HEAP32[$xdr + 40 >> 2] + $45 | 0;
    var $_c = $45 + $len | 0;
    HEAP32[$43 >> 2] = $_c;
    var $_0 = $46;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7mem_rawP10JSXDRStatej["X"] = 1;

function __ZL8mem_seekP10JSXDRStatei11JSXDRWhence($xdr, $offset, $whence) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    if (($whence | 0) == 1) {
      __label__ = 2;
      break;
    } else if (($whence | 0) == 0) {
      __label__ = 12;
      break;
    } else if (($whence | 0) == 2) {
      __label__ = 23;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 2:
    var $2 = $xdr + 44 | 0;
    var $3 = $2;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = $4 + $offset | 0;
    if (($5 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($10, 2, 0, 64, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 4:
    if (($offset | 0) > 0) {
      __label__ = 5;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 5:
    var $15 = HEAP32[$xdr >> 2];
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else if (($15 | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 6:
    var $17 = $xdr + 48 | 0;
    var $19 = HEAPU32[$17 >> 2];
    if (($19 | 0) != 0 & $5 >>> 0 > $19 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 7:
    var $24 = $5 + 8191 & -8192;
    var $27 = $xdr + 40 | 0;
    var $29 = HEAP32[$27 >> 2];
    var $30 = HEAP32[$xdr + 8 >> 2];
    var $31 = __ZN9JSContext8realloc_EPvj($30, $29, $24);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $_c5 = $31;
    HEAP32[$27 >> 2] = $_c5;
    HEAP32[$17 >> 2] = $24;
    var $45 = HEAP32[$3 >> 2];
    __label__ = 11;
    break;
   case 9:
    if ($5 >>> 0 > HEAPU32[$xdr + 48 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $45 = $4;
      __label__ = 11;
      break;
    }
   case 10:
    var $43 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($43, 2, 0, 63, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 11:
    var $45;
    HEAP32[$2 >> 2] = $45 + $offset | 0;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 12:
    if (($offset | 0) < 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $52 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($52, 2, 0, 64, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 14:
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 15:
    var $58 = $xdr + 44 | 0;
    if (HEAPU32[$58 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 16:
    var $63 = $xdr + 48 | 0;
    var $65 = HEAPU32[$63 >> 2];
    if (($65 | 0) != 0 & $65 >>> 0 < $offset >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $70 = $offset + 8191 & -8192;
    var $73 = $xdr + 40 | 0;
    var $75 = HEAP32[$73 >> 2];
    var $76 = HEAP32[$xdr + 8 >> 2];
    var $77 = __ZN9JSContext8realloc_EPvj($76, $75, $70);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_c2 = $77;
    HEAP32[$73 >> 2] = $_c2;
    HEAP32[$63 >> 2] = $70;
    __label__ = 19;
    break;
   case 19:
    HEAP32[$58 >> 2] = $offset;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 20:
    if (HEAPU32[$xdr + 48 >> 2] >>> 0 < $offset >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    var $90 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($90, 2, 0, 65, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 22:
    HEAP32[$xdr + 44 >> 2] = $offset;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 23:
    if (($offset | 0) > -1) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    if ((HEAP32[$xdr >> 2] | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $103 = HEAP32[$xdr + 48 >> 2] + $offset | 0;
    if (($103 | 0) < 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $108 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($108, 2, 0, 66, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 27:
    var $_c = $103;
    HEAP32[$xdr + 44 >> 2] = $_c;
    var $_0 = 1;
    __label__ = 29;
    break;
   case 28:
    var $112 = $numBuf | 0;
    var $113 = _JS_snprintf($112, 12, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $whence, tempInt));
    var $116 = HEAP32[$xdr + 8 >> 2];
    _JS_ReportErrorNumber($116, 2, 0, 67, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $112, tempInt));
    var $_0 = 0;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8mem_seekP10JSXDRStatei11JSXDRWhence["X"] = 1;

function __ZL12mem_finalizeP10JSXDRState($xdr) {
  var $3 = HEAP32[$xdr + 40 >> 2];
  __ZN9JSContext5free_EPv(undef, $3);
  return;
}

function __ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $v, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value14toObjectOrNullEv($v);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $13 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($1);
    if (($5 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $13 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZNK8JSObject10getNameURIEv($obj);
    var $9 = __ZNK8JSObject10getNameURIEv($2);
    var $10 = __ZN2js12EqualStringsEP14JSLinearStringS1_($8, $9);
    var $13 = $10 & 1;
    __label__ = 4;
    break;
   case 4:
    var $13;
    HEAP32[$bp >> 2] = $13;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18namespace_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject11isNamespaceEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js14NamespaceClassE);
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    __ZNK8JSObject13getNameURIValEv($1, $5);
    var $11 = $1 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $qn, $v, $bp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value14toObjectOrNullEv($v);
    var $2 = $1;
    if (($1 | 0) == 0) {
      var $10 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject8getClassEv($1);
    if (($5 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = __ZL14qname_identityP8JSObjectS0_($qn, $2);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    HEAP32[$bp >> 2] = $10;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_OBJECT4314($iden) {
  return ($iden & 7 | 0) == 4 & ($iden | 0) != 4 & 1;
}

function _JSID_TO_OBJECT4315($iden) {
  return $iden & -8;
}

function __ZNK8JSObject7isQNameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$this + 4 >> 2];
    if (($2 | 0) == (__ZN2js10QNameClassE | 0) | ($2 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $8 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = ($2 | 0) == (__ZN2js12AnyNameClassE | 0);
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16JSXMLArrayCursor10disconnectEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this + 8 | 0;
    var $6 = HEAP32[$5 >> 2];
    var $_pre1 = $this + 12 | 0;
    if (($6 | 0) == 0) {
      var $11 = $6;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$_pre1 >> 2];
    var $10 = $6 + 12 | 0;
    HEAP32[$10 >> 2] = $9;
    var $11 = HEAP32[$5 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $12 = HEAP32[$_pre1 >> 2];
    HEAP32[$12 >> 2] = $11;
    HEAP32[$1 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14qname_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject7isQNameEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js10QNameClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $10 = __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $4);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value9setStringEP8JSString($vp, $10);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_($cx, $nsval, $lnval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $1 = __ZNK2JS5Value8isObjectEv($nsval);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($nsval);
    var $4 = __ZNK8JSObject8getClassEv($3);
    if (($4 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = $argv | 0;
    __ZN2JS5Value7setNullEv($7);
    var $_pre_phi = $7;
    __label__ = 5;
    break;
   case 4:
    var $9 = $nsval | 0;
    var $10$0 = HEAP32[$9 >> 2];
    var $10$1 = HEAP32[$9 + 4 >> 2];
    var $11 = $argv | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $_pre_phi = $argv | 0;
    __label__ = 5;
    break;
   case 5:
    var $_pre_phi;
    var $13 = $lnval | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $argv + 8 | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = $cx;
    var $17 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($16, __ZN2js10QNameClassE, 0, 0, 2, $_pre_phi);
    var $18 = $17;
    STACKTOP = __stackBase__;
    return $18;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $2 = $0 | 0;
    var $3$0 = HEAP32[$2 >> 2];
    var $3$1 = HEAP32[$2 + 4 >> 2];
    var $4 = $v | 0;
    HEAP32[$4 >> 2] = $3$0;
    HEAP32[$4 + 4 >> 2] = $3$1;
    var $5 = _JSVAL_IS_PRIMITIVE4303($3$0, $3$1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = _JSVAL_TO_OBJECT4304($3$0, $3$1);
    var $9 = __ZNK8JSObject7isQNameEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = _JSVAL_TO_OBJECT4304($3$0, $3$1);
    var $12 = __ZNK8JSObject17getQNameLocalNameEv($11);
    var $name_1 = $12 | 0;
    __label__ = 8;
    break;
   case 4:
    var $15 = $cx;
    var $16 = _JS_SetErrorReporter($15, 0);
    var $17 = $cx;
    var $18 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($17, $v);
    if (($18 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $20 = _JS_SetErrorReporter($15, $16);
    __label__ = 7;
    break;
   case 6:
    var $22 = __ZN8JSString12ensureLinearEP9JSContext($18, $15);
    var $23 = _JS_SetErrorReporter($15, $16);
    if (($22 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $name_1 = $22;
      __label__ = 8;
      break;
    }
   case 7:
    _JS_ClearPendingException($15);
    var $_0 = 0;
    __label__ = 9;
    break;
   case 8:
    var $name_1;
    var $27 = __ZNK14JSLinearString5charsEv($name_1);
    var $29 = __ZNK8JSString6lengthEv($name_1 | 0);
    var $30 = __ZL9IsXMLNamePKtj($27, $29);
    var $_0 = $30;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_PRIMITIVE_IMPL4409($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_OBJECT_IMPL4449($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZNK8JSObject17getQNameLocalNameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 2);
    var $3 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($3) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($2);
    var $6 = __ZNK8JSString6asAtomEv($5);
    var $9 = $6;
    __label__ = 3;
    break;
   case 3:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9IsXMLNamePKtj($cp, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($n | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = HEAP16[$cp >> 1];
    var $4 = __ZN2js7unicode19IsXMLNamespaceStartEt($3);
    if ($4) {
      var $_01 = $cp;
      var $_02 = $n;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $_02;
    var $_01;
    var $5 = $_02 - 1 | 0;
    if (($5 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = $_01 + 2 | 0;
    var $9 = HEAP16[$8 >> 1];
    var $10 = __ZN2js7unicode18IsXMLNamespacePartEt($9);
    if ($10) {
      var $_01 = $8;
      var $_02 = $5;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN16JSXMLArrayCursor5traceEP8JSTracer($this, $trc) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($this | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = $this + 4 | 0;
    var $3 = $trc;
    var $cursor_01 = $this;
    __label__ = 3;
    break;
   case 3:
    var $cursor_01;
    var $6 = HEAP32[$cursor_01 + 16 >> 2];
    var $8 = HEAP32[$2 >> 2] + 1 | 0;
    HEAP32[$2 >> 2] = $8;
    __ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj($3, $6, undef, undef);
    var $10 = HEAP32[$cursor_01 + 8 >> 2];
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $cursor_01 = $10;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray11setCapacityEP9JSContextj($this, $cx, $newCapacity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($newCapacity | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $4;
    if (($cx | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN9JSContext5free_EPv(undef, $8);
    __label__ = 6;
    break;
   case 5:
    __ZN2js10Foreground5free_EPv($8);
    __label__ = 6;
    break;
   case 6:
    HEAP32[$3 >> 2] = 0;
    __label__ = 12;
    break;
   case 7:
    if ($newCapacity >>> 0 > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $15 = $this + 8 | 0;
    var $17 = HEAP32[$15 >> 2];
    var $18 = $newCapacity << 2;
    var $19 = __ZN2js11OffTheBooks8realloc_EPvj($17, $18);
    if (($19 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    if (($cx | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = $cx;
    _JS_ReportOutOfMemory($24);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 11:
    var $26 = $19;
    HEAP32[$15 >> 2] = $26;
    __label__ = 12;
    break;
   case 12:
    HEAP32[$this + 4 >> 2] = $newCapacity | -2147483648;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray4trimEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    if (($2 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$this >> 2];
    if ($6 >>> 0 < $2 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN10JSXMLArray11setCapacityEP9JSContextj($this, 0, $6);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10JSXMLArray6finishEP9JSContext($this, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$this + 8 >> 2];
    __ZN9JSContext5free_EPv(undef, $3);
    var $4 = $this + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $7 = $5;
      __label__ = 2;
      break;
    }
   case 2:
    var $7;
    __ZN16JSXMLArrayCursor10disconnectEv($7);
    var $8 = HEAP32[$4 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $7 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj, $funidp, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject7isQNameEv($obj);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj, $funidp, $cx);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($qn, $funidp, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getNameURIEv($qn);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[HEAP32[$cx + 52 >> 2] + 210428 >> 2] | 0;
    if (($1 | 0) == ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = __ZN2js12EqualStringsEP14JSLinearStringS1_($1, $8);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject17getQNameLocalNameEv($qn);
    var $14 = __ZL12ATOM_TO_JSIDP6JSAtom4336($13);
    HEAP32[$funidp >> 2] = $14;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE($cx, $obj, $hint, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anch = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2JS6AnchorIP8JSObjectEC1ES2_($anch, $obj);
    var $2 = $obj;
    var $3 = __ZNK8JSObject10getPrivateEv($2);
    var $4 = $3;
    var $5 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $4);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JSL11StringValueEP8JSString4311($1, $5);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $rval | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSObjectEC1ES2_($this, $t) {
  __ZN2JS6AnchorIP8JSObjectEC2ES2_($this, $t);
  return;
}

function __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $xml) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $3 = HEAP32[$xml + 16 >> 2];
    if (($3 | 0) == 2 || ($3 | 0) == 4) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$xml + 24 >> 2];
    __label__ = 12;
    break;
   case 3:
    var $9 = __ZL16HasSimpleContentP5JSXML($xml);
    if (($9 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = HEAP32[$xml >> 2];
    _OBJECT_TO_JSVAL4318($1, $13);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $14 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, 0);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 5:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $21 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $21);
    var $22 = $cx;
    var $str_0_ph = $20;
    __label__ = 6;
    break;
   case 6:
    var $str_0_ph;
    __label__ = 7;
    break;
   case 7:
    var $23 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($23 | 0) == 0) {
      var $str_1 = $str_0_ph;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = HEAP32[$23 + 16 >> 2];
    if (($28 | 0) == 5 || ($28 | 0) == 3) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $23;
    var $31 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $30);
    if (($31 | 0) == 0) {
      var $str_1 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($22, $str_0_ph, $31);
    if (($34 | 0) == 0) {
      var $str_1 = 0;
      __label__ = 11;
      break;
    } else {
      var $str_0_ph = $34;
      __label__ = 6;
      break;
    }
   case 11:
    var $str_1;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $str_1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_toString_helperP9JSContextP5JSXML["X"] = 1;

function __ZN2JSL11StringValueEP8JSString4311($agg_result, $str) {
  __ZN2JS5Value9setStringEP8JSString($agg_result, $str);
  return;
}

function __Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 4;
    HEAP32[$1 >> 2] = $id;
    var $2 = _JSID_IS_OBJECT4314($id);
    if (($2 | 0) == 0) {
      var $8 = $id;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSID_TO_OBJECT4315($id);
    var $6 = __Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($5, $1, $cx);
    var $8 = HEAP32[$1 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $8;
    var $9 = $cx;
    __ZN2js15AutoValueRooterC1EP9JSContext($tvr, $9);
    var $10 = __ZN2js15AutoValueRooter4addrEv($tvr);
    var $11 = __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $8, $10);
    var $12 = __ZNK2js15AutoValueRooter5valueEv($tvr);
    var $13 = $12 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __ZN2js15AutoValueRooterD1Ev($tvr);
    STACKTOP = __stackBase__;
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tvr = __stackBase__;
    var $1 = $tvr;
    var $2 = $cx;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($1, $2, 0);
    var $3 = $vp | 0;
    var $target_0 = $obj;
    __label__ = 2;
    break;
   case 2:
    var $target_0;
    var $5 = $target_0;
    var $6 = __Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($2, $5, $id, $vp);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $3 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = _JSVAL_IS_PRIMITIVE4303($9$0, $9$1);
    if (($10 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $st$0$0 = $3 | 0;
    var $13$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $3 + 4 | 0;
    var $13$1 = HEAP32[$st$0$1 >> 2];
    var $14 = _JSVAL_TO_OBJECT4304($13$0, $13$1);
    var $15 = $14;
    var $16 = __ZNK8JSObject10isFunctionEv($15);
    if ($16) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = __ZNK8JSObject8getProtoEv($5);
    var $19 = $18;
    if (($18 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __ZNK8JSObject8isNativeEv($18);
    if ($22) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZN2js16AutoObjectRooter9setObjectEP8JSObject($tvr, $19);
    var $target_0 = $19;
    __label__ = 2;
    break;
   case 8:
    var $25 = $obj;
    var $26 = __ZNK8JSObject10getPrivateEv($25);
    var $27 = $26;
    var $28 = __ZL16HasSimpleContentP5JSXML($27);
    if (($28 | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $tvr;
    var $32 = __ZN2js16AutoObjectRooter4addrEv($31);
    var $33 = $cx;
    var $34 = $32;
    var $35 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($33, 0, 9, $34, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = __ZNK2js16AutoObjectRooter6objectEv($31);
    var $39 = $38;
    var $40 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($39, $2, $id, $vp);
    var $_0 = $40;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($1);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $v1, $v2, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $d = __stackBase__;
    var $v = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $2 = __stackBase__ + 24;
    var $3 = __stackBase__ + 32;
    var $4 = __stackBase__ + 40;
    var $5 = __stackBase__ + 48;
    var $6 = __ZNK2JS5Value8isObjectEv($v1);
    if ($6) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = __ZNK2JS5Value8toObjectEv($v1);
    var $9 = __ZNK8JSObject5isXMLEv($8);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = $v2 | 0;
    var $st$1$0 = $11 | 0;
    var $12$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    var $13 = $v | 0;
    var $st$6$0 = $13 | 0;
    HEAP32[$st$6$0 >> 2] = $12$0;
    var $st$6$1 = $13 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $12$1;
    var $obj_0_in = $8;
    var $20$1 = $12$1;
    var $20$0 = $12$0;
    __label__ = 5;
    break;
   case 4:
    var $15 = $v1 | 0;
    var $st$1$0 = $15 | 0;
    var $16$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $15 + 4 | 0;
    var $16$1 = HEAP32[$st$1$1 >> 2];
    var $17 = $v | 0;
    var $st$6$0 = $17 | 0;
    HEAP32[$st$6$0 >> 2] = $16$0;
    var $st$6$1 = $17 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $16$1;
    var $18 = __ZNK2JS5Value8toObjectEv($v2);
    var $obj_0_in = $18;
    var $20$1 = $16$1;
    var $20$0 = $16$0;
    __label__ = 5;
    break;
   case 5:
    var $20$0;
    var $20$1;
    var $obj_0_in;
    var $obj_0 = $obj_0_in;
    var $21 = __ZNK8JSObject10getPrivateEv($obj_0_in);
    var $22 = $21;
    var $23 = _JSVAL_IS_PRIMITIVE4303($20$0, $20$1);
    if (($23 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 8;
      break;
    }
   case 6:
    var $26 = _JSVAL_TO_OBJECT4304($20$0, $20$1);
    var $27 = $26;
    var $28 = __ZNK8JSObject5isXMLEv($27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $30 = __ZNK8JSObject10getPrivateEv($27);
    var $vxml_0 = $30;
    __label__ = 8;
    break;
   case 8:
    var $vxml_0;
    var $35 = HEAP32[$21 + 16 >> 2];
    if (($35 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $38 = __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $22, $20$0, $20$1, $bp);
    var $ok_2 = $38;
    __label__ = 36;
    break;
   case 10:
    if (($vxml_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $43 = HEAP32[$vxml_0 + 16 >> 2];
    if (($43 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    _OBJECT_TO_JSVAL4318($1, $obj_0);
    var $_idx9 = $1 | 0;
    var $_idx9_val$0 = HEAP32[$_idx9 >> 2];
    var $_idx9_val$1 = HEAP32[$_idx9 + 4 >> 2];
    var $46 = __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $vxml_0, $_idx9_val$0, $_idx9_val$1, $bp);
    var $ok_2 = $46;
    __label__ = 36;
    break;
   case 13:
    if (($35 | 0) == 4 || ($35 | 0) == 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $49 = __ZL16HasSimpleContentP5JSXML($vxml_0);
    if (($49 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    if (($43 | 0) == 4 || ($43 | 0) == 2) {
      __label__ = 16;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 16:
    var $53 = __ZL16HasSimpleContentP5JSXML($22);
    if (($53 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    __ZN2JSL11ObjectValueER8JSObject4319($2, $obj_0);
    var $56 = $cx;
    var $57 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($56, $2);
    if (($57 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $60 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($56, $v);
    var $61 = ($60 | 0) != 0;
    var $62 = $61 & 1;
    if ($61) {
      __label__ = 19;
      break;
    } else {
      var $ok_2 = $62;
      __label__ = 36;
      break;
    }
   case 19:
    var $64 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($56, $57, $60, $bp);
    var $ok_2 = $64 & 1;
    __label__ = 36;
    break;
   case 20:
    var $67 = __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $22, $vxml_0, $bp);
    var $ok_2 = $67;
    __label__ = 36;
    break;
   case 21:
    var $69 = __ZL16HasSimpleContentP5JSXML($22);
    if (($69 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    __ZN2JSL11ObjectValueER8JSObject4319($3, $obj_0);
    var $72 = $cx;
    var $73 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($72, $3);
    if (($73 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $76 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($72, $v);
    var $77 = ($76 | 0) != 0;
    var $78 = $77 & 1;
    if ($77) {
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $78;
      __label__ = 36;
      break;
    }
   case 24:
    var $80 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($72, $73, $76, $bp);
    var $ok_2 = $80 & 1;
    __label__ = 36;
    break;
   case 25:
    var $83 = _JSVAL_IS_STRING4320($20$0, $20$1);
    if (($83 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $86 = _JSVAL_IS_NUMBER($20$0, $20$1);
    if (($86 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    __ZN2JSL11ObjectValueER8JSObject4319($4, $obj_0);
    var $89 = $cx;
    var $90 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($89, $4);
    if (($90 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $93 = _JSVAL_IS_STRING4320($20$0, $20$1);
    if (($93 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $96 = _JSVAL_TO_STRING4321($20$0, $20$1);
    var $97 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($89, $90, $96, $bp);
    var $ok_2 = $97 & 1;
    __label__ = 36;
    break;
   case 30:
    _STRING_TO_JSVAL4322($5, $90);
    var $100 = $cx;
    var $101 = _JS_ValueToNumber($100, $5, $d);
    if (($101 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 36;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $104 = _JSVAL_IS_INT4323($20$0, $20$1);
    if (($104 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    var $107 = _JSVAL_TO_INT4324($20$0, $20$1);
    var $112 = $107 | 0;
    __label__ = 34;
    break;
   case 33:
    var $110 = _JSVAL_TO_DOUBLE4325($20$0, $20$1);
    var $112 = $110;
    __label__ = 34;
    break;
   case 34:
    var $112;
    var $113 = (tempDoubleI32[0] = HEAP32[$d >> 2], tempDoubleI32[1] = HEAP32[$d + 4 >> 2], tempDoubleF64[0]);
    var $115 = $113 == $112 & 1;
    HEAP32[$bp >> 2] = $115;
    var $ok_2 = $101;
    __label__ = 36;
    break;
   case 35:
    HEAP32[$bp >> 2] = 0;
    var $ok_2 = 1;
    __label__ = 36;
    break;
   case 36:
    var $ok_2;
    STACKTOP = __stackBase__;
    return $ok_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi["X"] = 1;

function __ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi($cx, $xml, $_0_0_0_val$0, $_0_0_0_val$1, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $v | 0;
    HEAP32[$2 >> 2] = $_0_0_0_val$0;
    HEAP32[$2 + 4 >> 2] = $_0_0_0_val$1;
    var $3 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($3 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$bp >> 2] = 0;
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 3:
    var $10 = $xml + 24 | 0;
    if ((HEAP32[$10 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $16 = HEAP32[HEAP32[$xml + 32 >> 2] >> 2];
    if (($16 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $19 = $16;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $20);
    var $23 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $1, $v, $bp);
    var $_0 = $23;
    __label__ = 14;
    break;
   case 7:
    var $25 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($25 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$10 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    HEAP32[$bp >> 2] = 1;
    __label__ = 13;
    break;
   case 10:
    var $32 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $33 = $32;
    var $34 = __ZNK8JSObject5isXMLEv($33);
    if ($34) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    HEAP32[$bp >> 2] = 0;
    __label__ = 13;
    break;
   case 12:
    var $37 = __ZNK8JSObject10getPrivateEv($33);
    var $38 = $37;
    var $39 = __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $xml, $38, $bp);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $_0 = 1;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi["X"] = 1;

function _OBJECT_TO_JSVAL4318($agg_result, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($obj | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL_IMPL4443($1, $obj);
    var $_0 = $1 | 0;
    var $_0_val$0 = HEAP32[$_0 >> 2];
    var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
    __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
    __label__ = 4;
    break;
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $5$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $5$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $6 = $agg_result | 0;
    HEAP32[$6 >> 2] = $5$0;
    HEAP32[$6 + 4 >> 2] = $5$1;
    __label__ = 4;
    break;
   case 4:
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi($cx, $obj, $0, $bp) {
  return 1;
}

function __ZL16HasSimpleContentP5JSXML($xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = HEAPU32[$_01 + 16 >> 2];
    if (($3 | 0) == 0) {
      __label__ = 3;
      break;
    } else if (($3 | 0) == 5 || ($3 | 0) == 3) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $6 = HEAP32[$_01 + 24 >> 2];
    if (($6 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($6 | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 4:
    var $10 = HEAP32[HEAP32[$_01 + 32 >> 2] >> 2];
    var $11 = $10;
    if (($10 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_01 = $11;
      __label__ = 2;
      break;
    }
   case 5:
    if ($3 >>> 0 < 2) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $17 = 0;
    var $_pre_phi = $_01 + 24 | 0;
    __label__ = 8;
    break;
   case 7:
    var $14 = $_01 + 24 | 0;
    var $17 = HEAP32[$14 >> 2];
    var $_pre_phi = $14;
    __label__ = 8;
    break;
   case 8:
    var $_pre_phi;
    var $17;
    var $18 = $_01 + 32 | 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $17 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 10:
    if ($i_0 >>> 0 < HEAPU32[$_pre_phi >> 2] >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $27 = HEAP32[HEAP32[$18 >> 2] + ($i_0 << 2) >> 2];
    if (($27 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$27 + 16 >> 2] | 0) == 1) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11ObjectValueER8JSObject4319($agg_result, $obj) {
  var $1 = $obj;
  __ZN2JS5Value9setObjectER8JSObject($agg_result, $1);
  return;
}

function __ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi($cx, $xml, $vxml, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $vcursor = __stackBase__ + 20;
    var $1 = __stackBase__ + 40;
    var $2 = __stackBase__ + 48;
    var $_02_ph = $xml;
    var $_04_ph = $vxml;
    __label__ = 2;
    break;
   case 2:
    var $_04_ph;
    var $_02_ph;
    var $4 = HEAP32[$_04_ph + 16 >> 2];
    var $_02 = $_02_ph;
    __label__ = 3;
    break;
   case 3:
    var $_02;
    var $6 = $_02 + 16 | 0;
    var $7 = HEAP32[$6 >> 2];
    if (($7 | 0) == ($4 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_13 = $_02;
      __label__ = 7;
      break;
    }
   case 5:
    if ((HEAP32[$_02 + 24 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_13 = $_02;
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = HEAP32[HEAP32[$_02 + 32 >> 2] >> 2];
    var $19 = $18;
    if (($18 | 0) == 0) {
      var $_13 = 0;
      __label__ = 7;
      break;
    } else {
      var $_02 = $19;
      __label__ = 3;
      break;
    }
   case 7:
    var $_13;
    if (($4 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if ((HEAP32[$_04_ph + 24 >> 2] | 0) == 1) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $30 = HEAP32[HEAP32[$_04_ph + 32 >> 2] >> 2];
    var $31 = $30;
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_02_ph = $_13;
      var $_04_ph = $31;
      __label__ = 2;
      break;
    }
   case 10:
    HEAP32[$bp >> 2] = 0;
    var $_1 = 1;
    __label__ = 45;
    break;
   case 11:
    var $36 = HEAP32[$_02 + 12 >> 2];
    var $38 = HEAP32[$_04_ph + 12 >> 2];
    var $40 = ($38 | 0) == 0;
    if (($36 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ($40) {
      var $53 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $43 = __ZNK8JSObject17getQNameLocalNameEv($36);
    var $44 = $43 | 0;
    var $45 = __ZNK8JSObject17getQNameLocalNameEv($38);
    var $46 = $45 | 0;
    var $47 = __ZN2js12EqualStringsEP14JSLinearStringS1_($44, $46);
    if ($47) {
      __label__ = 14;
      break;
    } else {
      var $53 = 0;
      __label__ = 15;
      break;
    }
   case 14:
    var $49 = __ZNK8JSObject10getNameURIEv($36);
    var $50 = __ZNK8JSObject10getNameURIEv($38);
    var $51 = __ZN2js12EqualStringsEP14JSLinearStringS1_($49, $50);
    var $53 = $51;
    __label__ = 15;
    break;
   case 15:
    var $53;
    var $storemerge = $53 & 1;
    __label__ = 17;
    break;
   case 16:
    var $storemerge = $40 & 1;
    __label__ = 17;
    break;
   case 17:
    var $storemerge;
    HEAP32[$bp >> 2] = $storemerge;
    if (($storemerge | 0) == 0) {
      var $_1 = 1;
      __label__ = 45;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $62 = $_02 + 24 | 0;
    if (HEAPU32[$6 >> 2] >>> 0 > 1) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $65 = HEAP32[$62 >> 2];
    var $68 = HEAP32[$_04_ph + 24 >> 2];
    var $69 = $cx;
    var $70 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($69, $65, $68, $bp);
    if ($70) {
      __label__ = 42;
      break;
    } else {
      var $_1 = 0;
      __label__ = 45;
      break;
    }
   case 20:
    var $74 = $_04_ph + 24 | 0;
    if ((HEAP32[$62 >> 2] | 0) == (HEAP32[$74 >> 2] | 0)) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$bp >> 2] = 0;
    __label__ = 42;
    break;
   case 22:
    var $80 = $74 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $62 | 0);
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($vcursor, $80);
    __label__ = 23;
    break;
   case 23:
    var $83 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $84 = __ZN16JSXMLArrayCursor7getNextEv($vcursor);
    var $_not = ($83 | 0) == 0;
    var $85 = ($84 | 0) == 0;
    if ($85 | $_not) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    HEAP32[$bp >> 2] = $85 & $_not & 1;
    __label__ = 28;
    break;
   case 25:
    var $90 = $84;
    var $91 = $83;
    var $92 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $91);
    var $93 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $90);
    if (($92 | 0) == 0 | ($93 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $92);
    __ZN2JSL11ObjectValueER8JSObject4319($2, $93);
    var $97 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $1, $2, $bp);
    if (($97 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ((HEAP32[$bp >> 2] | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 28:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $102 = HEAP32[$bp >> 2];
    if (($102 | 0) == 0) {
      __label__ = 42;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ((HEAP32[$6 >> 2] | 0) == 1) {
      __label__ = 30;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 30:
    var $108 = $_02 + 56 | 0;
    var $109 = HEAPU32[$108 >> 2];
    var $110 = $_04_ph + 56 | 0;
    if (($109 | 0) == (HEAP32[$110 >> 2] | 0)) {
      var $114 = $102;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    HEAP32[$bp >> 2] = 0;
    var $114 = 0;
    __label__ = 32;
    break;
   case 32:
    var $114;
    var $115 = $_02 + 64 | 0;
    var $116 = $_04_ph + 64 | 0;
    var $117 = $cx;
    var $i_0 = 0;
    var $119 = $114;
    __label__ = 33;
    break;
   case 33:
    var $119;
    var $i_0;
    if (($119 | 0) != 0 & $i_0 >>> 0 < $109 >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 34:
    if ($i_0 >>> 0 < HEAPU32[$108 >> 2] >>> 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 35:
    var $128 = HEAPU32[HEAP32[$115 >> 2] + ($i_0 << 2) >> 2];
    if (($128 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $_idx_val = HEAP32[$110 >> 2];
    var $_idx1_val = HEAP32[$116 >> 2];
    var $131 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $128, 276);
    if (($131 | 0) == -1) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP32[$bp >> 2] = 0;
    __label__ = 42;
    break;
   case 38:
    if ($131 >>> 0 < HEAPU32[$110 >> 2] >>> 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 39:
    var $140 = HEAPU32[HEAP32[$116 >> 2] + ($131 << 2) >> 2];
    if (($140 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $145 = HEAP32[$128 + 24 >> 2];
    var $148 = HEAP32[$140 + 24 >> 2];
    var $149 = __ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi($117, $145, $148, $bp);
    if ($149) {
      __label__ = 41;
      break;
    } else {
      var $_1 = 0;
      __label__ = 45;
      break;
    }
   case 41:
    var $i_0 = $i_0 + 1 | 0;
    var $119 = HEAP32[$bp >> 2];
    __label__ = 33;
    break;
   case 42:
    var $_1 = 1;
    __label__ = 45;
    break;
   case 43:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 45;
    break;
   case 44:
    __ZN16JSXMLArrayCursorD1Ev($vcursor);
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 45;
    break;
   case 45:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi["X"] = 1;

function _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_STRING_IMPL4412($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_NUMBER($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NUMBER_IMPL4446($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_STRING_IMPL4397($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _STRING_TO_JSVAL4322($agg_result, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _STRING_TO_JSVAL_IMPL4413($1, $str);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_INT32_IMPL4445($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_TO_INT32_IMPL4444($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_TO_DOUBLE4325($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $tmp$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = (tempDoubleI32[0] = HEAP32[$_0 >> 2], tempDoubleI32[1] = $tmp$1, tempDoubleF64[0]);
  STACKTOP = __stackBase__;
  return $2;
}

function __Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE($cx, $obj, $robj, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($1 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    var $5 = __ZNK8JSObject10getPrivateEv($4);
    var $6 = $5;
    var $7 = $obj;
    var $8 = __ZNK8JSObject10getPrivateEv($7);
    var $9 = $8;
    var $10 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $6, $9);
    if (($10 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $robj;
    var $14 = __ZNK8JSObject10getPrivateEv($13);
    var $15 = $14;
    var $16 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $6, $15);
    if (($16 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2JS5Value9setObjectER8JSObject($vp, $4);
    var $ok_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $ok_0;
    return $ok_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, $xml_class) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $root = __stackBase__;
    var $1 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $xml_class);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML($root, $cx, $1);
    var $4 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $1);
    __ZN2js13AutoXMLRooterD1Ev($root);
    var $_0 = $4;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $list + 24 | 0;
    var $2 = $1 | 0;
    var $3 = $1 | 0;
    var $4 = HEAPU32[$3 >> 2];
    var $5 = $xml + 16 | 0;
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 2:
    var $9 = $xml + 24 | 0;
    var $_c2 = HEAP32[$xml + 40 >> 2];
    HEAP32[$list + 40 >> 2] = $_c2;
    var $_c3 = HEAP32[$xml + 44 >> 2];
    HEAP32[$list + 44 >> 2] = $_c3;
    if (HEAPU32[$5 >> 2] >>> 0 < 2) {
      __label__ = 3;
      break;
    } else {
      var $24 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $24 = HEAP32[$9 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $24;
    var $25 = $24 + $4 | 0;
    var $26 = __ZN10JSXMLArray11setCapacityEP9JSContextj($2, $cx, $25);
    if ($26) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 17;
      break;
    }
   case 5:
    if (($24 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $28 = $9 | 0;
    var $29 = $xml + 32 | 0;
    var $30 = $list + 32 | 0;
    var $j_04 = 0;
    __label__ = 7;
    break;
   case 7:
    var $j_04;
    if ($j_04 >>> 0 < HEAPU32[$28 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 8:
    var $36 = HEAPU32[HEAP32[$29 >> 2] + ($j_04 << 2) >> 2];
    if (($36 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $40 = $j_04 + $4 | 0;
    if (HEAPU32[$3 >> 2] >>> 0 > $40 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$3 >> 2] = $40 + 1 | 0;
    __label__ = 11;
    break;
   case 11:
    var $46 = HEAP32[$30 >> 2] + ($40 << 2) | 0;
    HEAP32[$46 >> 2] = $36;
    __label__ = 12;
    break;
   case 12:
    var $47 = $j_04 + 1 | 0;
    if (($47 | 0) == ($24 | 0)) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      var $j_04 = $47;
      __label__ = 7;
      break;
    }
   case 13:
    var $_c = HEAP32[$xml + 8 >> 2];
    HEAP32[$list + 40 >> 2] = $_c;
    if ((HEAP32[$5 >> 2] | 0) == 3) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$list + 44 >> 2] = 0;
    __label__ = 16;
    break;
   case 15:
    var $_c1 = HEAP32[$xml + 12 >> 2];
    HEAP32[$list + 44 >> 2] = $_c1;
    __label__ = 16;
    break;
   case 16:
    var $61 = $xml;
    var $62 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $2, $4, $61);
    var $_0 = ($62 | 0) != 0 & 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6AppendP9JSContextP5JSXMLS2_["X"] = 1;

function __ZL12xml_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    if ((HEAP32[$5 >> 2] | 0) == ($obj | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$5 >> 2] = 0;
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9xml_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $trc;
    _JS_CallTracer($5, $2, 3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $id, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = $obj;
    var $3 = __ZNK8JSObject10getPrivateEv($2);
    var $4 = $3;
    var $5 = __Z12js_IdIsIndexiPj($id, $i);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[$i >> 2];
    var $9 = __ZL18HasIndexedPropertyP5JSXMLj($4, $8);
    var $found_0 = $9;
    __label__ = 7;
    break;
   case 3:
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $11 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx_val$0, $_idx_val$1, $funid);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$funid >> 2];
    var $15 = _JSID_IS_VOID4359($14);
    if (($15 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = $obj;
    var $20 = $objp;
    var $21 = $propp;
    var $22 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($18, $19, $14, $20, $21);
    var $_0 = $22;
    __label__ = 11;
    break;
   case 6:
    var $24 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($4, $11);
    var $found_0 = $24;
    __label__ = 7;
    break;
   case 7:
    var $found_0;
    if (($found_0 | 0) == 0) {
      var $storemerge = 0;
      var $storemerge1 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $28 = $cx;
    var $29 = $obj;
    var $30 = __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($28, $29, $id, 278, 280, -1, 1, 0, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $storemerge = $30;
    var $storemerge1 = $obj;
    __label__ = 10;
    break;
   case 10:
    var $storemerge1;
    var $storemerge;
    HEAP32[$objp >> 2] = $storemerge1;
    HEAP32[$propp >> 2] = $storemerge;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty["X"] = 1;

function __ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty($cx, $obj, $index, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    var $3 = $2;
    var $4 = __ZL18HasIndexedPropertyP5JSXMLj($3, $index);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$objp >> 2] = 0;
    HEAP32[$propp >> 2] = 0;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 3:
    var $8 = $cx;
    var $9 = __ZN2js9IndexToIdEP9JSContextjPi($8, $index, $id);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $11 = HEAP32[$id >> 2];
    var $12 = $cx;
    var $13 = $obj;
    var $14 = __Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji($12, $13, $11, 278, 280, -1, 1, 0, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$objp >> 2] = $obj;
    var $17 = $14;
    HEAP32[$propp >> 2] = $17;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty($cx, $obj, $sid, $objp, $propp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($cx, $obj, $1, $objp, $propp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $id, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tmp = __stackBase__;
    var $1 = __ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442($v);
    if (($getter_coerce | 0) == 0 & ($1 ^ 1) & ($setter | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if (($attrs & 71 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $cx;
    var $9 = $obj;
    var $10 = $setter;
    var $11 = __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($8, $9, $id, $v, $getter_coerce, $10, $attrs);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 4:
    var $13 = $v | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $tmp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, 0, $tmp);
    var $_0 = $16;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $index, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $4, $v, $getter_coerce, $setter, $attrs);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej($cx, $obj, $sid, $v, $getter_coerce, $setter, $attrs) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej($cx, $obj, $1, $v, $getter_coerce, $setter, $attrs);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $id, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_DEFAULT_XML_NAMESPACE4441($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2JS5Value12setUndefinedEv($vp);
    var $_0 = 1;
    __label__ = 4;
    break;
   case 3:
    var $5 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE($cx, $obj, $receiver, $name, $vp) {
  var $1 = $name | 0;
  var $2 = __ZL12ATOM_TO_JSIDP6JSAtom4336($1);
  var $3 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $2, $vp);
  return $3;
}

function __ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE($cx, $obj, $receiver, $index, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $4, $vp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE($cx, $obj, $receiver, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE($cx, $obj, $receiver, $1, $vp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict);
  return $1;
}

function __ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $4, $vp, $strict);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $vp, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $vp, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_idx_val$0, $_idx_val$1, $found);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = (HEAP32[$found >> 2] | 0) != 0 & 1;
    HEAP32[$attrsp >> 2] = $7;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL17xml_getAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $id, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = __stackBase__ + 4;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $2 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_idx_val$0, $_idx_val$1, $found);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$found >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $cx;
    _JS_ReportErrorNumber($8, 2, 0, 189, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj($cx, $obj, $index, $attrsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $id = __stackBase__;
    var $1 = $cx;
    var $2 = __ZN2js9IndexToIdEP9JSContextjPi($1, $index, $id);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = HEAP32[$id >> 2];
    var $5 = __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $4, $attrsp);
    var $_0 = $5;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj($cx, $obj, $sid, $attrsp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL17xml_setAttributesP9JSContextP8JSObjectiPj($cx, $obj, $1, $attrsp);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL10xml_typeOfP9JSContextP8JSObject($cx, $obj) {
  return 7;
}

function __ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE($cx, $obj, $success, $props) {
  HEAP8[$success] = 0;
  return 1;
}

function __ZL9xml_clearP9JSContextP8JSObject($cx, $obj) {
  return;
}

function __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    __ZN2jsL9IdToJsvalEi4431($1, $id);
    var $_03 = $1 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $3 = $obj;
    var $4 = __ZNK8JSObject10getPrivateEv($3);
    var $5 = $4;
    var $6 = __Z12js_IdIsIndexiPj($id, $index);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$4 + 16 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2jsL9IdToValueEi4432($2, $id);
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $2);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $15 = HEAP32[$index >> 2];
    __ZL17DeleteListElementP9JSContextP5JSXMLj($5, $15);
    __label__ = 9;
    break;
   case 5:
    var $17 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = HEAP32[$funid >> 2];
    var $21 = _JSID_IS_VOID4359($20);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $24 = $cx;
    var $25 = $obj;
    var $26 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($24, $25, $20, $rval, 0);
    var $_0 = $26;
    __label__ = 12;
    break;
   case 8:
    var $28 = $17;
    var $29 = __ZNK8JSObject8getClassEv($28);
    var $31 = ($29 | 0) == (__ZN2js18AttributeNameClassE | 0) & 1;
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($5, $17, $31);
    __label__ = 9;
    break;
   case 9:
    var $33 = __ZNK8JSObject11nativeEmptyEv($3);
    if ($33) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $cx;
    var $36 = $obj;
    var $37 = __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($35, $36, $id, $rval, 0);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi["X"] = 1;

function __ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($cx, $obj, $index, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject10getPrivateEv($2);
    if ((HEAP32[$3 + 16 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $index >>> 0;
    __ZN2JSL11DoubleValueEd4439($1, $9);
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $1);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = $3;
    __ZL17DeleteListElementP9JSContextP5JSXMLj($11, $index);
    var $12 = __ZNK8JSObject11nativeEmptyEv($2);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $cx;
    var $15 = $obj;
    var $16 = __Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi($14, $15, $index, $rval, 0);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JS5Value10setBooleanEb($rval, 1);
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi($cx, $obj, $sid, $rval, $strict) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $1, $rval, $strict);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi($cx, $obj, $enum_op, $statep, $idp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (HEAPU32[$2 + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[$2 + 24 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $12;
    if (($enum_op | 0) == 0 || ($enum_op | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($enum_op | 0) == 2) {
      __label__ = 10;
      break;
    } else if (($enum_op | 0) == 3) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 20;
      break;
    }
   case 4:
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN2JS5Value8setInt32Ei($statep, 0);
    __label__ = 8;
    break;
   case 6:
    var $18 = $2 + 24 | 0;
    var $19 = __ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_($cx, $18);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = $19;
    __ZN2JS5Value10setPrivateEPv($statep, $22);
    __label__ = 8;
    break;
   case 8:
    if (($idp | 0) == 0) {
      var $_0 = 1;
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = _INT_TO_JSID4434($12);
    HEAP32[$idp >> 2] = $26;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 10:
    var $28 = __ZNK2JS5Value7isInt32Ei($statep, 0);
    if ($28) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    __ZN2JS5Value7setNullEv($statep);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 12:
    var $31 = __ZNK2JS5Value9toPrivateEv($statep);
    if (($31 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ((HEAP32[$31 >> 2] | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $39 = $31 + 4 | 0;
    var $40 = HEAPU32[$39 >> 2];
    if ($40 >>> 0 < $12 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $43 = _INT_TO_JSID4434($40);
    HEAP32[$idp >> 2] = $43;
    HEAP32[$39 >> 2] = $40 + 1 | 0;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 16:
    var $46 = __ZNK2JS5Value7isInt32Ei($statep, 0);
    if ($46) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $48 = __ZNK2JS5Value9toPrivateEv($statep);
    if (($48 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $51 = $48;
    __ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_($cx, $51);
    __label__ = 19;
    break;
   case 19:
    __ZN2JS5Value7setNullEv($statep);
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi["X"] = 1;

function __ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$3 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $35 = HEAP32[$obj >> 2];
    var $_pre_phi = $vp | 0;
    __label__ = 10;
    break;
   case 4:
    var $12 = HEAP32[$obj >> 2];
    if ((HEAP32[$3 >> 2] | 0) == ($12 | 0)) {
      var $17 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $3, $12);
    var $17 = $15;
    __label__ = 6;
    break;
   case 6:
    var $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $21 = ($argc | 0) == 0 ? -1 : 1;
    var $22 = $vp + 16 | 0;
    var $23 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $21, $22, $vp);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $26 = $vp | 0;
    var $st$1$0 = $26 | 0;
    var $27$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $26 + 4 | 0;
    var $27$1 = HEAP32[$st$1$1 >> 2];
    var $28 = _JSVAL_TO_OBJECT4304($27$0, $27$1);
    var $29 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $17, $28);
    if (($29 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $32$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $32$1 = HEAP32[$st$1$1 >> 2];
    var $33 = $1 | 0;
    HEAP32[$33 >> 2] = $32$0;
    HEAP32[$33 + 4 >> 2] = $32$1;
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($28, $1);
    var $35 = $12;
    var $_pre_phi = $26;
    __label__ = 10;
    break;
   case 10:
    var $_pre_phi;
    var $35;
    _OBJECT_TO_JSVAL4318($2, $35);
    var $36 = $2 | 0;
    var $37$0 = HEAP32[$36 >> 2];
    var $37$1 = HEAP32[$36 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $37$0;
    HEAP32[$_pre_phi + 4 >> 2] = $37$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15xml_appendChildP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $name = __stackBase__ + 12;
    var $1 = __stackBase__ + 16;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($7 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $7);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = __Z13js_GetAnyNameP9JSContextPi($cx, $name);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$name >> 2];
    var $16 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $7, $15, $v);
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $v | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = _JSVAL_TO_OBJECT4304($20$0, $20$1);
    var $22 = $21;
    var $23 = __ZNK8JSObject10getPrivateEv($22);
    var $26 = HEAP32[$23 + 24 >> 2];
    var $27 = $cx;
    var $28 = __ZN2js9IndexToIdEP9JSContextjPi($27, $26, $name);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if (($argc | 0) == 0) {
      var $34 = _JSVAL_VOID;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $vp + 16 | 0;
    __label__ = 9;
    break;
   case 9:
    var $34;
    var $35 = $34;
    var $st$2$0 = $35 | 0;
    var $36$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $37 = $vp | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $38$0 = HEAP32[$19 >> 2];
    var $38$1 = HEAP32[$19 + 4 >> 2];
    var $39 = _JSVAL_TO_OBJECT4304($38$0, $38$1);
    var $40 = HEAP32[$name >> 2];
    var $41 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $39, $40, 0, $vp);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL4318($1, $7);
    var $44 = $1 | 0;
    var $st$2$0 = $44 | 0;
    var $45$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $44 + 4 | 0;
    var $45$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$37 >> 2] = $45$0;
    HEAP32[$37 + 4 >> 2] = $45$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_appendChildP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13xml_attributeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($argc | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = $cx;
    __Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj($4, $vp, 0);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 3:
    var $6 = $vp + 16 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $7$0, $7$1);
    if (($8 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    _OBJECT_TO_JSVAL4318($1, $8);
    var $11 = $1 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    HEAP32[$6 >> 2] = $12$0;
    HEAP32[$6 + 4 >> 2] = $12$1;
    var $13 = $vp + 8 | 0;
    var $14 = $cx;
    var $15 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($14, $13);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = _OBJECT_TO_JSID4356($8);
    var $19 = $15;
    var $20 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $19, $18, $vp);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14xml_attributesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $6 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $6);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $7 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      var $_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $cx;
    var $11 = $7;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($tvr, $10, $11);
    var $12 = $vp + 8 | 0;
    var $13 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($10, $12);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = _OBJECT_TO_JSID4356($7);
    var $17 = $13;
    var $18 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $17, $16, $vp);
    var $_0 = $18;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    __ZN2js16AutoObjectRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 5;
    break;
   case 5:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9xml_childP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_1 = 0;
    __label__ = 20;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($3);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_04 = $16 | 0;
    var $tmp$0 = HEAPU32[$_04 >> 2];
    var $tmp$1 = HEAPU32[$_04 + 4 >> 2];
    if ((HEAP32[$10 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 6:
    var $22 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $10 + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $26);
    var $27 = $v | 0;
    __label__ = 8;
    break;
   case 8:
    var $28 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $_0 = 1;
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $29);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $32, $29, $tmp$0, $tmp$1, $v);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $st$0$0 = $27 | 0;
    var $38$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $27 + 4 | 0;
    var $38$1 = HEAP32[$st$0$1 >> 2];
    var $39 = _JSVAL_IS_VOID4396($38$0, $38$1);
    if (($39 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 12:
    var $st$0$0 = $27 | 0;
    var $42$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $27 + 4 | 0;
    var $42$1 = HEAP32[$st$0$1 >> 2];
    var $43 = _JSVAL_TO_OBJECT4304($42$0, $42$1);
    var $44 = $43;
    var $45 = __ZNK8JSObject10getPrivateEv($44);
    var $46 = $45;
    if (HEAPU32[$45 + 16 >> 2] >>> 0 < 2) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    if ((HEAP32[$45 + 24 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $22, $46);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 15:
    var $_0;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = $_0;
    __label__ = 20;
    break;
   case 16:
    var $61 = __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $4, $11, $tmp$0, $tmp$1, $vp);
    if (($61 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $64 = $vp | 0;
    var $65$0 = HEAP32[$64 >> 2];
    var $65$1 = HEAP32[$64 + 4 >> 2];
    var $66 = _JSVAL_IS_VOID4396($65$0, $65$1);
    if (($66 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $69 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    if (($69 | 0) == 0) {
      var $_1 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_1 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9xml_childP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL14xml_childIndexP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = __stackBase__ + 20;
    var $4 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAPU32[$4 + 8 >> 2];
    if (($8 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$4 + 16 >> 2] | 0) == 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $15 = (tempDoubleI32[0] = HEAP32[_js_NaN >> 2], tempDoubleI32[1] = HEAP32[_js_NaN + 4 >> 2], tempDoubleF64[0]);
    _DOUBLE_TO_JSVAL4435($1, $15);
    var $16 = $1 | 0;
    var $st$3$0 = $16 | 0;
    var $17$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $16 + 4 | 0;
    var $17$1 = HEAP32[$st$3$1 >> 2];
    var $18 = $vp | 0;
    var $st$8$0 = $18 | 0;
    HEAP32[$st$8$0 >> 2] = $17$0;
    var $st$8$1 = $18 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $17$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 5:
    var $23 = $8 + 24 | 0;
    if (HEAPU32[$8 + 16 >> 2] >>> 0 < 2) {
      __label__ = 6;
      break;
    } else {
      var $26 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $26 = HEAP32[$23 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $26;
    var $27 = $8 + 32 | 0;
    var $i_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ($i_0 >>> 0 < $26 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 9:
    if ($i_0 >>> 0 < HEAPU32[$23 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $39 = 0;
      __label__ = 11;
      break;
    }
   case 10:
    var $39 = HEAP32[HEAP32[$27 >> 2] + ($i_0 << 2) >> 2];
    __label__ = 11;
    break;
   case 11:
    var $39;
    if (($39 | 0) == ($4 | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 8;
    break;
   case 13:
    if (($i_0 | 0) > -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    _INT_TO_JSVAL4421($2, $i_0);
    var $46 = $2 | 0;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = $vp | 0;
    HEAP32[$48 >> 2] = $47$0;
    HEAP32[$48 + 4 >> 2] = $47$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 15:
    _DOUBLE_TO_JSVAL4435($3, $i_0 >>> 0);
    var $51 = $3 | 0;
    var $st$3$0 = $51 | 0;
    var $52$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $51 + 4 | 0;
    var $52$1 = HEAP32[$st$3$1 >> 2];
    var $53 = $vp | 0;
    var $st$8$0 = $53 | 0;
    HEAP32[$st$8$0 >> 2] = $52$0;
    var $st$8$1 = $53 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $52$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14xml_childIndexP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_childrenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    var $11 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $12 = __ZL12ATOM_TO_JSIDP6JSAtom4336($11);
    var $13 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $6, $12, $vp);
    var $_0 = $13;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_commentsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject5isXMLEv($3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $9 = __ZNK8JSObject10getPrivateEv($3);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_containsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 56;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $value = __stackBase__;
    var $eq = __stackBase__ + 8;
    var $cursor = __stackBase__ + 12;
    var $1 = __stackBase__ + 32;
    var $2 = __stackBase__ + 40;
    var $3 = __stackBase__ + 48;
    var $4 = $vp + 8 | 0;
    var $5 = $cx;
    var $6 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($5, $4);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = __ZNK8JSObject5isXMLEv($6);
    if ($10) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($5, $vp, __ZN2js8XMLClassE);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 4:
    var $13 = __ZNK8JSObject10getPrivateEv($6);
    if (($13 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      var $20 = _JSVAL_VOID;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $vp + 16 | 0;
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = $20;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = $value | 0;
    HEAP32[$23 >> 2] = $22$0;
    HEAP32[$23 + 4 >> 2] = $22$1;
    if ((HEAP32[$13 + 16 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    HEAP32[$eq >> 2] = 0;
    var $30 = $13 + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $30);
    __label__ = 9;
    break;
   case 9:
    var $32 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($32 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $35 = $32;
    var $36 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $35);
    if (($36 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $36);
    var $39 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $1, $value, $eq);
    if (($39 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if ((HEAP32[$eq >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    __label__ = 15;
    break;
   case 14:
    __ZN2JSL11ObjectValueER8JSObject4319($2, $7);
    var $46 = __Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi($cx, $2, $value, $eq);
    if (($46 | 0) == 0) {
      var $_1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = HEAP32[$eq >> 2];
    _BOOLEAN_TO_JSVAL4415($3, $49);
    var $50 = $3 | 0;
    var $51$0 = HEAP32[$50 >> 2];
    var $51$1 = HEAP32[$50 + 4 >> 2];
    var $52 = $vp | 0;
    HEAP32[$52 >> 2] = $51$0;
    HEAP32[$52 + 4 >> 2] = $51$1;
    var $_1 = 1;
    __label__ = 18;
    break;
   case 16:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 17:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12xml_containsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8xml_copyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($4);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $13, 0);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = HEAP32[$14 >> 2];
    _OBJECT_TO_JSVAL4318($1, $18);
    var $19 = $1 | 0;
    var $20$0 = HEAP32[$19 >> 2];
    var $20$1 = HEAP32[$19 + 4 >> 2];
    var $21 = $vp | 0;
    HEAP32[$21 >> 2] = $20$0;
    HEAP32[$21 + 4 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_descendantsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($5);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $21);
    var $_03_phi_trans_insert = $1 | 0;
    var $tmp$1 = HEAP32[$_03_phi_trans_insert + 4 >> 2];
    var $tmp$0 = HEAP32[$_03_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 7:
    var $23 = $vp + 16 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $1 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $tmp$1 = $24$1;
    var $tmp$0 = $24$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $27 = __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $12, $tmp$0, $tmp$1);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = HEAP32[$27 >> 2];
    _OBJECT_TO_JSVAL4318($2, $31);
    var $32 = $2 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_descendantsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_elementsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($4);
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $20);
    var $_03_phi_trans_insert = $1 | 0;
    var $tmp$1 = HEAP32[$_03_phi_trans_insert + 4 >> 2];
    var $tmp$0 = HEAP32[$_03_phi_trans_insert >> 2];
    __label__ = 8;
    break;
   case 7:
    var $22 = $vp + 16 | 0;
    var $23$0 = HEAP32[$22 >> 2];
    var $23$1 = HEAP32[$22 + 4 >> 2];
    var $24 = $1 | 0;
    HEAP32[$24 >> 2] = $23$0;
    HEAP32[$24 + 4 >> 2] = $23$1;
    var $tmp$1 = $23$1;
    var $tmp$0 = $23$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $26 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $29 = HEAP32[$funid >> 2];
    var $30 = _JSID_IS_VOID4359($29);
    if (($30 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $33 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $11, $vp);
    var $_0 = ($33 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 11:
    var $37 = __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $11, $26, $vp);
    var $_0 = $37;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12xml_elementsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $found = __stackBase__;
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($3);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 8;
    break;
   case 4:
    var $12 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_03 = $12 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $13 = __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $4, $tmp$0, $tmp$1, $found);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$found >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $19$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $19$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $20 = $vp | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 8;
    break;
   case 7:
    var $22 = $cx;
    var $23 = __Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE($22, 46, $argc, $vp);
    var $_0 = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject5isXMLEv($3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 4:
    var $9 = __ZNK8JSObject10getPrivateEv($3);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $xml_0_in = $9;
      __label__ = 5;
      break;
    }
   case 5:
    var $xml_0_in;
    var $13 = HEAP32[$xml_0_in + 16 >> 2];
    if (($13 | 0) == 2 || ($13 | 0) == 5 || ($13 | 0) == 3 || ($13 | 0) == 4) {
      __label__ = 7;
      break;
    } else if (($13 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_pre4_pre_phi = $xml_0_in + 24 | 0;
    __label__ = 13;
    break;
   case 7:
    var $$emscripten$temp$0 = _JSVAL_FALSE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $15$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $15$1 = HEAP32[$st$1$1 >> 2];
    var $16 = $vp | 0;
    var $st$6$0 = $16 | 0;
    HEAP32[$st$6$0 >> 2] = $15$0;
    var $st$6$1 = $16 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $15$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 8:
    var $19 = $xml_0_in + 24 | 0;
    var $20 = HEAP32[$19 >> 2];
    if (($20 | 0) == 0) {
      __label__ = 9;
      break;
    } else if (($20 | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $_pre4_pre_phi = $19;
      __label__ = 13;
      break;
    }
   case 9:
    var $$emscripten$temp$1 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $22$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $22$1 = HEAP32[$st$1$1 >> 2];
    var $23 = $vp | 0;
    var $st$6$0 = $23 | 0;
    HEAP32[$st$6$0 >> 2] = $22$0;
    var $st$6$1 = $23 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $22$1;
    var $_pre_phi = $23;
    var $_pre_phi5 = $19;
    __label__ = 14;
    break;
   case 10:
    var $28 = HEAP32[HEAP32[$xml_0_in + 32 >> 2] >> 2];
    if (($28 | 0) == 0) {
      var $_pre4_pre_phi = $19;
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = $28;
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $31);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $35 = $32;
    var $36 = __ZNK8JSObject10getPrivateEv($35);
    var $xml_0_in = $36;
    __label__ = 5;
    break;
   case 13:
    var $_pre4_pre_phi;
    var $_pre_phi = $vp | 0;
    var $_pre_phi5 = $_pre4_pre_phi;
    __label__ = 14;
    break;
   case 14:
    var $_pre_phi5;
    var $_pre_phi;
    var $$emscripten$temp$2 = _JSVAL_FALSE | 0;
    var $37$0 = HEAP32[$$emscripten$temp$2 >> 2];
    var $37$1 = HEAP32[$$emscripten$temp$2 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $37$0;
    HEAP32[$_pre_phi + 4 >> 2] = $37$1;
    var $38 = HEAPU32[$_pre_phi5 >> 2];
    var $40 = $xml_0_in + 32 | 0;
    var $i_0 = 0;
    __label__ = 15;
    break;
   case 15:
    var $i_0;
    if ($i_0 >>> 0 < $38 >>> 0) {
      __label__ = 16;
      break;
    } else {
      var $_0 = 1;
      __label__ = 20;
      break;
    }
   case 16:
    var $46 = HEAP32[HEAP32[$40 >> 2] + ($i_0 << 2) >> 2];
    if (($46 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$46 + 16 >> 2] | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $$emscripten$temp$3 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$3 | 0;
    var $54$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$3 + 4 | 0;
    var $54$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$_pre_phi >> 2] = $54$0;
    HEAP32[$_pre_phi + 4 >> 2] = $54$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 15;
    break;
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($4);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL16HasSimpleContentP5JSXML($13);
    _BOOLEAN_TO_JSVAL4415($1, $14);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $namespaces = __stackBase__ + 4;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($namespaces, $cx);
    var $4 = $namespaces + 12 | 0;
    var $5 = __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $1, $4);
    if (($5 | 0) == 0) {
      var $10 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $4, $vp);
    var $10 = $8;
    __label__ = 4;
    break;
   case 4:
    var $10;
    var $11 = $10 & 1;
    __ZN2js18AutoNamespaceArrayD1Ev($namespaces);
    var $_0 = $11;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$obj >> 2];
    _OBJECT_TO_JSVAL4318($1, $5);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    if (HEAPU32[$2 + 16 >> 2] >>> 0 > 1 | ($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_06 = $vp + 16 | 0;
    var $tmp$0 = HEAPU32[$_06 >> 2];
    var $tmp$1 = HEAPU32[$_06 + 4 >> 2];
    var $14 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $17 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 5:
    var $20 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $21 = $20;
    var $22 = __ZNK8JSObject5isXMLEv($21);
    if ($22) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 6:
    var $24 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $25 = $24;
    var $26 = __ZNK8JSObject10getPrivateEv($25);
    var $_idx3_val = HEAP32[$2 + 24 >> 2];
    var $_idx4_val = HEAP32[$2 + 32 >> 2];
    var $27 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx3_val, $_idx4_val, $26, 0);
    if (($27 | 0) == -1) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $27 + 1 | 0;
    __label__ = 8;
    break;
   case 8:
    var $i_0;
    if ((HEAP32[$2 >> 2] | 0) == ($5 | 0)) {
      var $38 = $2;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $5);
    var $38 = $36;
    __label__ = 10;
    break;
   case 10:
    var $38;
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $45 = _JSVAL_VOID;
      __label__ = 13;
      break;
    }
   case 12:
    var $45 = $vp + 24 | 0;
    __label__ = 13;
    break;
   case 13:
    var $45;
    var $46 = $45;
    var $47$0 = HEAP32[$46 >> 2];
    var $47$1 = HEAP32[$46 + 4 >> 2];
    var $48 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $38, $i_0, $47$0, $47$1);
    var $_0 = $48;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$obj >> 2];
    _OBJECT_TO_JSVAL4318($1, $5);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    if (HEAPU32[$2 + 16 >> 2] >>> 0 > 1 | ($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_06 = $vp + 16 | 0;
    var $tmp$0 = HEAPU32[$_06 >> 2];
    var $tmp$1 = HEAPU32[$_06 + 4 >> 2];
    var $14 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($14 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $i_0 = HEAP32[$2 + 24 >> 2];
    __label__ = 8;
    break;
   case 5:
    var $20 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 6:
    var $23 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $24 = $23;
    var $25 = __ZNK8JSObject5isXMLEv($24);
    if ($25) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 14;
      break;
    }
   case 7:
    var $27 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $28 = $27;
    var $29 = __ZNK8JSObject10getPrivateEv($28);
    var $_idx3_val = HEAP32[$2 + 24 >> 2];
    var $_idx4_val = HEAP32[$2 + 32 >> 2];
    var $30 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx3_val, $_idx4_val, $29, 0);
    if (($30 | 0) == -1) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      var $i_0 = $30;
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0;
    if ((HEAP32[$2 >> 2] | 0) == ($5 | 0)) {
      var $39 = $2;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $37 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $5);
    var $39 = $37;
    __label__ = 10;
    break;
   case 10:
    var $39;
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ($argc >>> 0 > 1) {
      __label__ = 12;
      break;
    } else {
      var $46 = _JSVAL_VOID;
      __label__ = 13;
      break;
    }
   case 12:
    var $46 = $vp + 24 | 0;
    __label__ = 13;
    break;
   case 13:
    var $46;
    var $47 = $46;
    var $48$0 = HEAP32[$47 >> 2];
    var $48$1 = HEAP32[$47 + 4 >> 2];
    var $49 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $39, $i_0, $48$0, $48$1);
    var $_0 = $49;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL10xml_lengthP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 10;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($5);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_ONE | 0;
    var $19$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $19$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $20 = $vp | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 7:
    var $24 = HEAPU32[$11 + 24 >> 2];
    if (($24 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    _INT_TO_JSVAL4421($1, $24);
    var $27 = $1 | 0;
    var $28$0 = HEAP32[$27 >> 2];
    var $28$1 = HEAP32[$27 + 4 >> 2];
    var $29 = $vp | 0;
    HEAP32[$29 >> 2] = $28$0;
    HEAP32[$29 + 4 >> 2] = $28$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 9:
    var $31 = $24 >>> 0;
    _DOUBLE_TO_JSVAL4435($2, $31);
    var $32 = $2 | 0;
    var $33$0 = HEAP32[$32 >> 2];
    var $33$1 = HEAP32[$32 + 4 >> 2];
    var $34 = $vp | 0;
    HEAP32[$34 >> 2] = $33$0;
    HEAP32[$34 + 4 >> 2] = $33$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10xml_lengthP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL13xml_localNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 12 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZNK8JSObject20getQNameLocalNameValEv($1, $6);
    var $_phi_trans_insert = $1 | 0;
    var $13$1 = HEAP32[$_phi_trans_insert + 4 >> 2];
    var $13$0 = HEAP32[$_phi_trans_insert >> 2];
    __label__ = 5;
    break;
   case 4:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $10$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $10$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $13$1 = $10$1;
    var $13$0 = $10$0;
    __label__ = 5;
    break;
   case 5:
    var $13$0;
    var $13$1;
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8xml_nameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAP32[$2 + 12 >> 2];
    _OBJECT_TO_JSVAL4318($1, $6);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13xml_namespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 48;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $inScopeNSes = __stackBase__ + 12;
    var $2 = __stackBase__ + 40;
    var $3 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if ((HEAP32[$3 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      var $prefix_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    var $14 = $vp | 0;
    var $st$6$0 = $14 | 0;
    HEAP32[$st$6$0 >> 2] = $13$0;
    var $st$6$1 = $14 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $13$1;
    var $_1 = 1;
    __label__ = 21;
    break;
   case 5:
    var $15 = $vp + 16 | 0;
    var $16 = $cx;
    var $17 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($16, $15);
    if (($17 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $cx;
    var $21 = __ZN8JSString12ensureLinearEP9JSContext($17, $20);
    if (($21 | 0) == 0) {
      var $_1 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = $21 | 0;
    _STRING_TO_JSVAL4322($1, $24);
    var $25 = $1 | 0;
    var $st$3$0 = $25 | 0;
    var $26$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $25 + 4 | 0;
    var $26$1 = HEAP32[$st$3$1 >> 2];
    var $27 = $15 | 0;
    HEAP32[$27 >> 2] = $26$0;
    HEAP32[$27 + 4 >> 2] = $26$1;
    var $prefix_0 = $21;
    __label__ = 8;
    break;
   case 8:
    var $prefix_0;
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($inScopeNSes, $cx);
    var $29 = $inScopeNSes + 12 | 0;
    var $30 = __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $3, $29);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if (($prefix_0 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $36 = HEAP32[$3 + 12 >> 2];
    var $37 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $36, $29);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $ns_22 = $37;
      __label__ = 18;
      break;
    }
   case 11:
    var $41 = HEAPU32[$29 >> 2];
    var $43 = HEAP32[$inScopeNSes + 20 >> 2];
    var $i_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_0;
    if ($i_0 >>> 0 < $41 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 13:
    var $48 = HEAP32[$43 + ($i_0 << 2) >> 2];
    var $49 = $48;
    if (($48 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = __ZNK8JSObject13getNamePrefixEv($49);
    if (($52 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZN2js12EqualStringsEP14JSLinearStringS1_($52, $prefix_0);
    if ($55) {
      var $ns_22 = $49;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 12;
    break;
   case 17:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $57$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $57$1 = HEAP32[$st$1$1 >> 2];
    var $58 = $2 | 0;
    var $st$6$0 = $58 | 0;
    HEAP32[$st$6$0 >> 2] = $57$0;
    var $st$6$1 = $58 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $57$1;
    var $60$1 = $57$1;
    var $60$0 = $57$0;
    __label__ = 19;
    break;
   case 18:
    var $ns_22;
    _OBJECT_TO_JSVAL4318($2, $ns_22);
    var $_phi_trans_insert = $2 | 0;
    var $st$3$0 = $_phi_trans_insert | 0;
    var $st$3$1 = $_phi_trans_insert + 4 | 0;
    var $60$1 = HEAP32[$st$3$1 >> 2];
    var $60$0 = HEAP32[$st$3$0 >> 2];
    __label__ = 19;
    break;
   case 19:
    var $60$0;
    var $60$1;
    var $61 = $vp | 0;
    var $st$3$0 = $61 | 0;
    HEAP32[$st$3$0 >> 2] = $60$0;
    var $st$3$1 = $61 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $60$1;
    var $_0 = 1;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    __ZN2js18AutoNamespaceArrayD1Ev($inScopeNSes);
    var $_1 = $_0;
    __label__ = 21;
    break;
   case 21:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13xml_namespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 60;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $ancestors = __stackBase__ + 4;
    var $declared = __stackBase__ + 32;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (HEAPU32[$1 + 16 >> 2] >>> 0 > 1) {
      var $_1 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($ancestors, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($declared, $cx);
    var $8 = $ancestors + 12 | 0;
    var $9 = $8 | 0;
    var $_idx3 = $ancestors + 20 | 0;
    var $yml_0 = $1;
    __label__ = 4;
    break;
   case 4:
    var $yml_0;
    var $11 = HEAP32[$yml_0 + 8 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11 + 40 | 0;
    var $15 = HEAPU32[$14 >> 2];
    var $16 = $11 + 48 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $15 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $yml_0 = $11;
      __label__ = 4;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $25 = HEAPU32[HEAP32[$16 >> 2] + ($i_0 << 2) >> 2];
    if (($25 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $_idx2_val = HEAP32[$9 >> 2];
    var $_idx3_val = HEAP32[$_idx3 >> 2];
    var $28 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx2_val, $_idx3_val, $25, 282);
    if (($28 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $31 = HEAP32[$9 >> 2];
    var $32 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $8, $31, $25);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $36 = $1 + 40 | 0;
    var $37 = HEAPU32[$36 >> 2];
    var $38 = $1 + 48 | 0;
    var $39 = $declared + 12 | 0;
    var $40 = $39 | 0;
    var $_idx = $ancestors + 12 | 0;
    var $i1_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $i1_0;
    if ($i1_0 >>> 0 < $37 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 14:
    if ($i1_0 >>> 0 < HEAPU32[$36 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $49 = HEAPU32[HEAP32[$38 >> 2] + ($i1_0 << 2) >> 2];
    if (($49 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $52 = $49;
    var $53 = __ZL10IsDeclaredPK8JSObject($52);
    if (($53 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $_idx_val = HEAP32[$_idx >> 2];
    var $_idx1_val = HEAP32[$_idx3 >> 2];
    var $56 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $49, 282);
    if (($56 | 0) == -1) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $59 = HEAP32[$40 >> 2];
    var $60 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $39, $59, $49);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i1_0 = $i1_0 + 1 | 0;
    __label__ = 13;
    break;
   case 20:
    var $64 = __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $39, $vp);
    var $_0 = $64 & 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js18AutoNamespaceArrayD1Ev($declared);
    __ZN2js18AutoNamespaceArrayD1Ev($ancestors);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12xml_nodeKindP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = HEAP32[_js_xml_class_str + (HEAP32[$2 + 16 >> 2] << 2) >> 2];
    var $9 = $cx;
    var $10 = _JS_InternString($9, $8);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($1, $10);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13xml_normalizeP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($4);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($4);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11;
    _OBJECT_TO_JSVAL4318($1, $5);
    var $15 = $1 | 0;
    var $16$0 = HEAP32[$15 >> 2];
    var $16$1 = HEAP32[$15 + 4 >> 2];
    var $17 = $vp | 0;
    HEAP32[$17 >> 2] = $16$0;
    HEAP32[$17 + 4 >> 2] = $16$1;
    var $18 = __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $5, $14);
    var $_0 = $18;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10xml_parentP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 17;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($4);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $15 = HEAP32[$10 + 8 >> 2];
    if ((HEAP32[$10 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $parent_0 = $15;
      __label__ = 13;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = $vp | 0;
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $21$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $21$1;
    var $25 = HEAPU32[$10 + 24 >> 2];
    if (($25 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $30 = HEAPU32[$10 + 32 >> 2];
    var $31 = HEAP32[$30 >> 2];
    if (($31 | 0) == 0) {
      var $_0 = 1;
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $36 = HEAP32[$31 + 8 >> 2];
    var $i_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $25 >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $parent_0 = $36;
      __label__ = 13;
      break;
    }
   case 10:
    var $41 = HEAPU32[$30 + ($i_0 << 2) >> 2];
    if (($41 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$41 + 8 >> 2] | 0) == ($36 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 1;
      __label__ = 17;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 13:
    var $parent_0;
    if (($parent_0 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $$emscripten$temp$1 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $51$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $51$1 = HEAP32[$st$1$1 >> 2];
    var $52 = $vp | 0;
    var $st$6$0 = $52 | 0;
    HEAP32[$st$6$0 >> 2] = $51$0;
    var $st$6$1 = $52 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $51$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 15:
    var $54 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $parent_0);
    if (($54 | 0) == 0) {
      var $_0 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    _OBJECT_TO_JSVAL4318($1, $54);
    var $57 = $1 | 0;
    var $58$0 = HEAP32[$57 >> 2];
    var $58$1 = HEAP32[$57 + 4 >> 2];
    var $59 = $vp | 0;
    HEAP32[$59 >> 2] = $58$0;
    HEAP32[$59 + 4 >> 2] = $58$1;
    var $_0 = 1;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL10xml_parentP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __stackBase__ + 12;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($5);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($argc | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $21 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $21);
    var $_03_phi_trans_insert = $1 | 0;
    var $st$7$0 = $_03_phi_trans_insert | 0;
    var $st$7$1 = $_03_phi_trans_insert + 4 | 0;
    var $tmp$1 = HEAP32[$st$7$1 >> 2];
    var $tmp$0 = HEAP32[$st$7$0 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $23 = $vp + 16 | 0;
    var $24$0 = HEAP32[$23 >> 2];
    var $24$1 = HEAP32[$23 + 4 >> 2];
    var $25 = $1 | 0;
    HEAP32[$25 >> 2] = $24$0;
    HEAP32[$25 + 4 >> 2] = $24$1;
    var $tmp$1 = $24$1;
    var $tmp$0 = $24$0;
    __label__ = 8;
    break;
   case 8:
    var $tmp$0;
    var $tmp$1;
    var $27 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $tmp$0, $tmp$1, $funid);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($2, $27);
    var $30 = $2 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    var $32 = $vp + 16 | 0;
    var $st$7$0 = $32 | 0;
    HEAP32[$st$7$0 >> 2] = $31$0;
    var $st$7$1 = $32 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $31$1;
    var $33 = HEAP32[$funid >> 2];
    var $34 = _JSID_IS_VOID4359($33);
    if (($34 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $37 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = ($37 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 11:
    var $41 = __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $12, $27, $vp);
    var $_0 = $41;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL16xml_prependChildP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($7 | 0)) {
      var $12 = $2;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $7);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      var $12 = $10;
      __label__ = 4;
      break;
    }
   case 4:
    var $12;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    if (($argc | 0) == 0) {
      var $20 = _JSVAL_VOID;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $vp + 16 | 0;
    __label__ = 6;
    break;
   case 6:
    var $20;
    var $21 = $20;
    var $22$0 = HEAP32[$21 >> 2];
    var $22$1 = HEAP32[$21 + 4 >> 2];
    var $23 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $12, 0, $22$0, $22$1);
    var $_0 = $23;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $index = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($5);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($4, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 11;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($5);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $$emscripten$temp$0 = _JSVAL_FALSE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    if (($argc | 0) == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = $vp + 16 | 0;
    var $st$1$0 = $18 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $20 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $19$0, $19$1, $index, $isIndex);
    if ($20) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 7:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      var $_0 = 1;
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = HEAPU32[$index >> 2];
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $36 = $30 >>> 0 < HEAPU32[$11 + 24 >> 2] >>> 0 & 1;
    _BOOLEAN_TO_JSVAL4415($1, $36);
    var $37 = $1 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    HEAP32[$15 >> 2] = $38$0;
    HEAP32[$15 + 4 >> 2] = $38$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 10:
    var $41 = ($30 | 0) == 0 & 1;
    _BOOLEAN_TO_JSVAL4415($2, $41);
    var $42 = $2 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    HEAP32[$15 >> 2] = $43$0;
    HEAP32[$15 + 4 >> 2] = $43$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$2 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $29 = HEAP32[$obj >> 2];
    var $_pre_phi = $vp | 0;
    __label__ = 9;
    break;
   case 4:
    var $11 = HEAP32[$obj >> 2];
    if ((HEAP32[$2 >> 2] | 0) == ($11 | 0)) {
      var $16 = $2;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $2, $11);
    var $16 = $14;
    __label__ = 6;
    break;
   case 6:
    var $16;
    if (($16 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $20 = ($argc | 0) == 0 ? -1 : 1;
    var $21 = $vp + 16 | 0;
    var $22 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $20, $21, $vp);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $25 = $vp | 0;
    var $26$0 = HEAP32[$25 >> 2];
    var $26$1 = HEAP32[$25 + 4 >> 2];
    var $27 = _JSVAL_TO_OBJECT4304($26$0, $26$1);
    __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $16, $27);
    var $29 = $11;
    var $_pre_phi = $25;
    __label__ = 9;
    break;
   case 9:
    var $_pre_phi;
    var $29;
    _OBJECT_TO_JSVAL4318($1, $29);
    var $30 = $1 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $31$0;
    HEAP32[$_pre_phi + 4 >> 2] = $31$1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11xml_replaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $obj = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $haveIndex = __stackBase__ + 32;
    var $4 = __stackBase__ + 36;
    var $5 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$5 + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $93 = HEAP32[$obj >> 2];
    __label__ = 31;
    break;
   case 4:
    if ($argc >>> 0 < 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $18);
    var $value_0_0_0_in = $1 | 0;
    __label__ = 12;
    break;
   case 6:
    var $20 = $vp + 24 | 0;
    var $_011 = $20 | 0;
    var $tmp12$0 = HEAPU32[$_011 >> 2];
    var $tmp12$1 = HEAPU32[$_011 + 4 >> 2];
    var $21 = _JSVAL_IS_PRIMITIVE4303($tmp12$0, $tmp12$1);
    if (($21 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $24 = _JSVAL_TO_OBJECT4304($tmp12$0, $tmp12$1);
    var $25 = $24;
    var $26 = __ZNK8JSObject5isXMLEv($25);
    if ($26) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $28 = _JSVAL_TO_OBJECT4304($tmp12$0, $tmp12$1);
    var $29 = $28;
    var $30 = __ZNK8JSObject10getPrivateEv($29);
    if (($30 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_019 = $2 | 0;
    var $st$1$0 = $_019 | 0;
    HEAP32[$st$1$0 >> 2] = $tmp12$0;
    var $st$1$1 = $_019 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $tmp12$1;
    var $32 = $cx;
    var $33 = _JS_ConvertValue($32, $2, 3, $20);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $value_0_0_0_in = $_011;
      __label__ = 12;
      break;
    }
   case 10:
    var $36 = $30;
    var $37 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $36, 0);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = HEAP32[$37 >> 2];
    _OBJECT_TO_JSVAL4318($3, $41);
    var $42 = $3 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $st$8$0 = $_011 | 0;
    HEAP32[$st$8$0 >> 2] = $43$0;
    var $st$8$1 = $_011 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $43$1;
    var $value_0_0_0_in = $_011;
    __label__ = 12;
    break;
   case 12:
    var $value_0_0_0_in;
    var $st$1$0 = $value_0_0_0_in | 0;
    var $value_0_0_0$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $value_0_0_0_in + 4 | 0;
    var $value_0_0_0$1 = HEAP32[$st$1$1 >> 2];
    var $46 = HEAPU32[$obj >> 2];
    if ((HEAP32[$5 >> 2] | 0) == ($46 | 0)) {
      var $51 = $5;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $5, $46);
    var $51 = $49;
    __label__ = 14;
    break;
   case 14:
    var $51;
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $54 = ($argc | 0) == 0;
    if ($54) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    HEAP8[$haveIndex] = 0;
    __label__ = 20;
    break;
   case 17:
    var $56 = $vp + 16 | 0;
    var $st$1$0 = $56 | 0;
    var $57$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $56 + 4 | 0;
    var $57$1 = HEAP32[$st$1$1 >> 2];
    var $58 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $57$0, $57$1, $index, $haveIndex);
    if ($58) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 0;
      __label__ = 32;
      break;
    }
   case 18:
    if ((HEAP8[$haveIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $90 = HEAP32[$index >> 2];
    __label__ = 30;
    break;
   case 20:
    var $61 = $54 ? -1 : 1;
    var $62 = $vp + 16 | 0;
    var $63 = __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, 0, $61, $62, $vp);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $66 = $vp | 0;
    var $st$1$0 = $66 | 0;
    var $67$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $66 + 4 | 0;
    var $67$1 = HEAP32[$st$1$1 >> 2];
    var $68 = _JSVAL_TO_OBJECT4304($67$0, $67$1);
    var $69 = $51 + 24 | 0;
    var $70 = HEAP32[$69 >> 2];
    HEAP32[$index >> 2] = -1;
    if (($70 | 0) == 0) {
      var $93 = $46;
      __label__ = 31;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $72 = $51 + 32 | 0;
    var $i_028 = $70;
    var $_pr6 = -1;
    var $74 = $70;
    __label__ = 23;
    break;
   case 23:
    var $74;
    var $_pr6;
    var $i_028;
    var $75 = $i_028 - 1 | 0;
    if ($75 >>> 0 < $74 >>> 0) {
      __label__ = 24;
      break;
    } else {
      var $_pr = $_pr6;
      __label__ = 27;
      break;
    }
   case 24:
    var $80 = HEAP32[HEAP32[$72 >> 2] + ($75 << 2) >> 2];
    if (($80 | 0) == 0) {
      var $_pr = $_pr6;
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $83 = $80;
    var $84 = __ZL13MatchElemNameP8JSObjectP5JSXML($68, $83);
    if (($84 | 0) == 0) {
      var $_pr = $_pr6;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($51, $75);
    HEAP32[$index >> 2] = $75;
    var $_pr = $75;
    __label__ = 27;
    break;
   case 27:
    var $_pr;
    if (($75 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $i_028 = $75;
    var $_pr6 = $_pr;
    var $74 = HEAP32[$69 >> 2];
    __label__ = 23;
    break;
   case 29:
    if (($_pr | 0) == -1) {
      var $93 = $46;
      __label__ = 31;
      break;
    } else {
      var $90 = $_pr;
      __label__ = 30;
      break;
    }
   case 30:
    var $90;
    var $91 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $51, $90, $value_0_0_0$0, $value_0_0_0$1);
    if (($91 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $93 = $46;
      __label__ = 31;
      break;
    }
   case 31:
    var $93;
    _OBJECT_TO_JSVAL4318($4, $93);
    var $94 = $4 | 0;
    var $95$0 = HEAP32[$94 >> 2];
    var $95$1 = HEAP32[$94 + 4 >> 2];
    var $96 = $vp | 0;
    var $st$8$0 = $96 | 0;
    HEAP32[$st$8$0 >> 2] = $95$0;
    var $st$8$1 = $96 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $95$1;
    var $_0 = 1;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11xml_replaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL15xml_setChildrenP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $2 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($argc | 0) == 0) {
      var $9 = _JSVAL_VOID;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $vp + 16 | 0;
    __label__ = 4;
    break;
   case 4:
    var $9;
    var $10 = $9;
    var $st$2$0 = $10 | 0;
    var $11$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $10 + 4 | 0;
    var $11$1 = HEAP32[$st$2$1 >> 2];
    var $12 = $vp | 0;
    HEAP32[$12 >> 2] = $11$0;
    HEAP32[$12 + 4 >> 2] = $11$1;
    var $13 = HEAP32[$obj >> 2];
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $19 = __ZL12ATOM_TO_JSIDP6JSAtom4336($18);
    var $20 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $13, $19, 0, $vp);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    _OBJECT_TO_JSVAL4318($1, $13);
    var $23 = $1 | 0;
    var $st$2$0 = $23 | 0;
    var $24$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $23 + 4 | 0;
    var $24$1 = HEAP32[$st$2$1 >> 2];
    HEAP32[$12 >> 2] = $24$0;
    HEAP32[$12 + 4 >> 2] = $24$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $obj = __stackBase__;
    var $namestr = __stackBase__ + 4;
    var $name = __stackBase__ + 8;
    var $1 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$1 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $9$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $9$1 = HEAP32[$st$1$1 >> 2];
    var $10 = $vp | 0;
    var $st$6$0 = $10 | 0;
    HEAP32[$st$6$0 >> 2] = $9$0;
    var $st$6$1 = $10 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 4:
    if (($argc | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $18 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    HEAP32[$namestr >> 2] = $18;
    __label__ = 10;
    break;
   case 6:
    var $20 = $vp + 16 | 0;
    var $st$1$0 = $20 | 0;
    var $21$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $20 + 4 | 0;
    var $21$1 = HEAP32[$st$1$1 >> 2];
    var $22 = $name | 0;
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $21$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $21$1;
    var $23 = _JSVAL_IS_PRIMITIVE4303($21$0, $21$1);
    if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $26 = _JSVAL_TO_OBJECT4304($21$0, $21$1);
    var $27 = __ZNK8JSObject7isQNameEv($26);
    if ($27) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $29 = _JSVAL_TO_OBJECT4304($21$0, $21$1);
    var $30 = __ZNK8JSObject17getQNameLocalNameEv($29);
    HEAP32[$namestr >> 2] = $30;
    __label__ = 10;
    break;
   case 9:
    var $32 = $cx;
    var $33 = $namestr;
    var $34 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($32, $name, $33);
    if ($34) {
      __label__ = 10;
      break;
    } else {
      var $_0 = 0;
      __label__ = 16;
      break;
    }
   case 10:
    var $38 = HEAP32[$obj >> 2];
    if ((HEAP32[$1 >> 2] | 0) == ($38 | 0)) {
      var $43 = $1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $41 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $1, $38);
    var $43 = $41;
    __label__ = 12;
    break;
   case 12:
    var $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = HEAP32[$namestr >> 2];
    if (($46 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $50 = HEAP32[$43 + 12 >> 2];
    __ZN8JSObject17setQNameLocalNameEP6JSAtom($50, $46);
    __label__ = 15;
    break;
   case 15:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $52$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $52$1 = HEAP32[$st$1$1 >> 2];
    var $53 = $vp | 0;
    var $st$6$0 = $53 | 0;
    HEAP32[$st$6$0 >> 2] = $52$0;
    var $st$6$1 = $53 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $52$1;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL11xml_setNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $name = __stackBase__;
    var $obj = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $3 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + 16 | 0;
    if ((HEAP32[$6 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 31;
      break;
    }
   case 3:
    if (($argc | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $17);
    var $18 = $1 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $name | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    __label__ = 9;
    break;
   case 5:
    var $22 = $vp + 16 | 0;
    var $st$1$0 = $22 | 0;
    var $23$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $22 + 4 | 0;
    var $23$1 = HEAP32[$st$1$1 >> 2];
    var $24 = $name | 0;
    var $st$6$0 = $24 | 0;
    HEAP32[$st$6$0 >> 2] = $23$0;
    var $st$6$1 = $24 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $23$1;
    var $25 = _JSVAL_IS_PRIMITIVE4303($23$0, $23$1);
    if (($25 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $st$0$0 = $24 | 0;
    var $28$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $24 + 4 | 0;
    var $28$1 = HEAP32[$st$0$1 >> 2];
    var $29 = _JSVAL_TO_OBJECT4304($28$0, $28$1);
    var $30 = $29;
    var $31 = __ZNK8JSObject8getClassEv($30);
    if (($31 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $st$0$0 = $24 | 0;
    var $34$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $24 + 4 | 0;
    var $34$1 = HEAP32[$st$0$1 >> 2];
    var $35 = _JSVAL_TO_OBJECT4304($34$0, $34$1);
    var $36 = __ZNK8JSObject10getNameURIEv($35);
    if (($36 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZNK8JSObject20getQNameLocalNameValEv($2, $35);
    var $39 = $2 | 0;
    var $40$0 = HEAP32[$39 >> 2];
    var $40$1 = HEAP32[$39 + 4 >> 2];
    var $st$6$0 = $22 | 0;
    HEAP32[$st$6$0 >> 2] = $40$0;
    var $st$6$1 = $22 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $40$1;
    HEAP32[$24 >> 2] = $40$0;
    HEAP32[$24 + 4 >> 2] = $40$1;
    __label__ = 9;
    break;
   case 9:
    var $42 = $cx;
    var $43 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($42, __ZN2js10QNameClassE, 0, 0, 1, $name);
    var $44 = $43;
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$6 >> 2] | 0) == 3) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $54 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject10setNameURIEP14JSLinearString($44, $54);
    __label__ = 12;
    break;
   case 12:
    var $58 = HEAP32[$obj >> 2];
    if ((HEAP32[$3 >> 2] | 0) == ($58 | 0)) {
      var $63 = $3;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $61 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $3, $58);
    var $63 = $61;
    __label__ = 14;
    break;
   case 14:
    var $63;
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$63 + 12 >> 2] = $44;
    if ((HEAP32[$63 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $63;
      __label__ = 18;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $72 = HEAP32[$63 + 8 >> 2];
    if (($72 | 0) == 0) {
      var $_0 = 1;
      __label__ = 31;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    if ((HEAP32[$72 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $72;
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 31;
      break;
    }
   case 18:
    var $nsowner_0;
    var $79 = __ZNK8JSObject13getNamePrefixEv($44);
    if (($79 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $82 = $nsowner_0 + 40 | 0;
    var $83 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $44, $82);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $86 = $83;
    var $_idx3_val = HEAP32[$82 >> 2];
    var $_idx4_val = HEAP32[$nsowner_0 + 48 >> 2];
    var $87 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx3_val, $_idx4_val, $86, 0);
    if (($87 | 0) == -1) {
      var $ns_0 = $83;
      __label__ = 29;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $90$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $90$1 = HEAP32[$st$1$1 >> 2];
    var $91 = $vp | 0;
    var $st$6$0 = $91 | 0;
    HEAP32[$st$6$0 >> 2] = $90$0;
    var $st$6$1 = $91 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $90$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 22:
    var $94 = HEAPU32[$nsowner_0 + 40 >> 2];
    var $95 = $nsowner_0 + 48 | 0;
    var $i_0 = 0;
    __label__ = 23;
    break;
   case 23:
    var $i_0;
    if ($i_0 >>> 0 < $94 >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 24:
    var $101 = HEAP32[HEAP32[$95 >> 2] + ($i_0 << 2) >> 2];
    var $102 = $101;
    if (($101 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $105 = __ZNK8JSObject10getNameURIEv($102);
    var $106 = __ZNK8JSObject10getNameURIEv($44);
    var $107 = __ZN2js12EqualStringsEP14JSLinearStringS1_($105, $106);
    if ($107) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $109 = __ZNK8JSObject13getNamePrefixEv($102);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($44, $109);
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $110$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $110$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    var $111 = $vp | 0;
    HEAP32[$111 >> 2] = $110$0;
    HEAP32[$111 + 4 >> 2] = $110$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 27:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 23;
    break;
   case 28:
    var $114 = __ZNK8JSObject10getNameURIEv($44);
    var $115 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, 0, $114, 1);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      var $ns_0 = $115;
      __label__ = 29;
      break;
    }
   case 29:
    var $ns_0;
    var $118 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $nsowner_0, $ns_0);
    if (($118 | 0) == 0) {
      var $_0 = 0;
      __label__ = 31;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    var $$emscripten$temp$2 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $121$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $121$1 = HEAP32[$st$1$1 >> 2];
    var $122 = $vp | 0;
    var $st$6$0 = $122 | 0;
    HEAP32[$st$6$0 >> 2] = $121$0;
    var $st$6$1 = $122 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $121$1;
    var $_0 = 1;
    __label__ = 31;
    break;
   case 31:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11xml_setNameP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZN10JSXMLArray4initEv($this) {
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP32[$this + 12 >> 2] = 0;
  return;
}

function __ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 52;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $qnargv = __stackBase__;
    var $obj = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __stackBase__ + 44;
    var $5 = __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $obj);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$5 + 16 >> 2] - 1 | 0) >>> 0 < 3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 3:
    var $15 = HEAPU32[$obj >> 2];
    if ((HEAP32[$5 >> 2] | 0) == ($15 | 0)) {
      var $20 = $5;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $18 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $5, $15);
    var $20 = $18;
    __label__ = 5;
    break;
   case 5:
    var $20;
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = ($argc | 0) != 0 & 1;
    var $24 = $vp + 16 | 0;
    var $25 = $cx;
    var $26 = $15;
    var $27 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($25, __ZN2js14NamespaceClassE, 0, $26, $23, $24);
    var $28 = $27;
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _OBJECT_TO_JSVAL4318($1, $28);
    var $31 = $1 | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    var $33 = $vp | 0;
    HEAP32[$33 >> 2] = $32$0;
    HEAP32[$33 + 4 >> 2] = $32$1;
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $34$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $34$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $35 = $2 | 0;
    HEAP32[$35 >> 2] = $34$0;
    HEAP32[$35 + 4 >> 2] = $34$1;
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($28, $2);
    var $36 = $qnargv | 0;
    _OBJECT_TO_JSVAL4318($3, $28);
    var $37 = $3 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $qnargv | 0;
    HEAP32[$39 >> 2] = $38$0;
    HEAP32[$39 + 4 >> 2] = $38$1;
    var $40 = $20 + 12 | 0;
    var $41 = HEAP32[$40 >> 2];
    _OBJECT_TO_JSVAL4318($4, $41);
    var $42 = $4 | 0;
    var $43$0 = HEAP32[$42 >> 2];
    var $43$1 = HEAP32[$42 + 4 >> 2];
    var $44 = $qnargv + 8 | 0;
    HEAP32[$44 >> 2] = $43$0;
    HEAP32[$44 + 4 >> 2] = $43$1;
    var $45 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($25, __ZN2js10QNameClassE, 0, 0, 2, $36);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$40 >> 2] = $45;
    if ((HEAP32[$20 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $20;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $54 = HEAP32[$20 + 8 >> 2];
    if (($54 | 0) == 0) {
      var $_0 = 1;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$54 + 16 >> 2] | 0) == 1) {
      var $nsowner_0 = $54;
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 13;
      break;
    }
   case 11:
    var $nsowner_0;
    var $61 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $nsowner_0, $28);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $64$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $64$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    HEAP32[$33 >> 2] = $64$0;
    HEAP32[$33 + 4 >> 2] = $64$1;
    var $_0 = 1;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL8xml_textP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject5isXMLEv($3);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($2, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 6;
    break;
   case 4:
    var $9 = __ZNK8JSObject10getPrivateEv($3);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $12, $vp);
    var $_0 = $13;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_toSourceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    _OBJECT_TO_JSVAL4318($1, $8);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, -2147483648);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($2, $9);
    var $12 = $2 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_toStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZNK8JSObject5isXMLEv($4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 7;
    break;
   case 4:
    var $10 = __ZNK8JSObject10getPrivateEv($4);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = $10;
    var $14 = __ZL19xml_toString_helperP9JSContextP5JSXML($cx, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    _STRING_TO_JSVAL4322($1, $14);
    var $17 = $1 | 0;
    var $18$0 = HEAP32[$17 >> 2];
    var $18$1 = HEAP32[$17 + 4 >> 2];
    var $19 = $vp | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    var $_0 = 1;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $vp + 8 | 0;
    var $4 = $cx;
    var $5 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($4, $3);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $5;
    _OBJECT_TO_JSVAL4318($1, $8);
    var $_idx = $1 | 0;
    var $_idx_val$0 = HEAP32[$_idx >> 2];
    var $_idx_val$1 = HEAP32[$_idx + 4 >> 2];
    var $9 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_idx_val$0, $_idx_val$1, 0);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _STRING_TO_JSVAL4322($2, $9);
    var $12 = $2 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11xml_valueOfP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $vp | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12xml_settingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = _JS_NewObject($2, 0, 0, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $4);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = $vp + 8 | 0;
    var $11 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $10);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    var $15 = __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $14, $4);
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_setSettingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = $cx;
    var $3 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($2, $1);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_06 = $9 | 0;
    var $tmp$0 = HEAP32[$_06 >> 2];
    var $tmp$1 = HEAP32[$_06 + 4 >> 2];
    var $10 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $13 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $4);
    var $ok_0 = $16;
    __label__ = 8;
    break;
   case 5:
    var $18 = _JSVAL_IS_PRIMITIVE4303($tmp$0, $tmp$1);
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $21$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $21$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $22 = $vp | 0;
    HEAP32[$22 >> 2] = $21$0;
    HEAP32[$22 + 4 >> 2] = $21$1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $24 = _JSVAL_TO_OBJECT4304($tmp$0, $tmp$1);
    var $25 = __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $24, $4);
    var $ok_0 = $25;
    __label__ = 8;
    break;
   case 8:
    var $ok_0;
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $27$0 = HEAP32[$$emscripten$temp$1 >> 2];
    var $27$1 = HEAP32[$$emscripten$temp$1 + 4 >> 2];
    var $28 = $vp | 0;
    HEAP32[$28 >> 2] = $27$0;
    HEAP32[$28 + 4 >> 2] = $27$1;
    var $_0 = $ok_0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_setSettingsP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $cx;
    var $3 = _JS_NewObject($2, 0, 0, 0);
    var $4 = $3;
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $4);
    var $7 = $1 | 0;
    var $8$0 = HEAP32[$7 >> 2];
    var $8$1 = HEAP32[$7 + 4 >> 2];
    var $9 = $vp | 0;
    HEAP32[$9 >> 2] = $8$0;
    HEAP32[$9 + 4 >> 2] = $8$1;
    var $10 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $4);
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $xml_class) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z11js_NewGCXMLP9JSContext($1);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$2 >> 2] = 0;
    HEAP32[$2 + 4 >> 2] = 0;
    HEAP32[$2 + 8 >> 2] = 0;
    HEAP32[$2 + 12 >> 2] = 0;
    HEAP32[$2 + 16 >> 2] = $xml_class;
    HEAP32[$2 + 20 >> 2] = 0;
    if (($xml_class | 0) > 1) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_c = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    HEAP32[$2 + 24 >> 2] = $_c;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 4:
    var $21 = $2 + 24 | 0;
    __ZN10JSXMLArray4initEv($21);
    if (($xml_class | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$2 + 40 >> 2] = 0;
    HEAP32[$2 + 44 >> 2] = 0;
    var $_0 = $3;
    __label__ = 7;
    break;
   case 6:
    var $28 = $2 + 40 | 0;
    __ZN10JSXMLArray4initEv($28);
    var $30 = $2 + 56 | 0;
    __ZN10JSXMLArray4initEv($30);
    var $_0 = $3;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_TraceXML($trc, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml >> 2];
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $trc;
    var $6 = $2;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($5, $6, undef);
    __label__ = 3;
    break;
   case 3:
    var $9 = HEAP32[$xml + 12 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $trc;
    var $13 = $9;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($12, $13, undef);
    __label__ = 5;
    break;
   case 5:
    var $16 = HEAP32[$xml + 8 >> 2];
    if (($16 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $19 = $16;
    var $20 = $trc;
    _JS_CallTracer($20, $19, 3);
    __label__ = 7;
    break;
   case 7:
    var $22 = $xml + 16 | 0;
    if (HEAPU32[$22 >> 2] >>> 0 > 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $28 = HEAPU32[$xml + 24 >> 2];
    if (($28 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = $trc;
    __ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc($31, $28, undef);
    __label__ = 16;
    break;
   case 10:
    var $35 = HEAP32[$xml + 32 >> 2];
    var $37 = HEAP32[$xml + 24 >> 2];
    __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $35, $37);
    var $39 = HEAP32[$xml + 36 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $39);
    if ((HEAP32[$22 >> 2] | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $45 = HEAP32[$xml + 40 >> 2];
    if (($45 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $45;
    var $49 = $trc;
    _JS_CallTracer($49, $48, 3);
    __label__ = 13;
    break;
   case 13:
    var $53 = HEAP32[$xml + 44 >> 2];
    if (($53 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $56 = $trc;
    var $57 = $53;
    __ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc($56, $57, undef);
    __label__ = 16;
    break;
   case 15:
    var $60 = HEAP32[$xml + 40 >> 2];
    var $63 = $trc;
    var $64 = HEAP32[$xml + 48 >> 2];
    __ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc($63, $60, $64, undef);
    var $66 = HEAP32[$xml + 52 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $66);
    var $69 = HEAP32[$xml + 64 >> 2];
    var $71 = HEAP32[$xml + 56 >> 2];
    __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $69, $71);
    var $73 = HEAP32[$xml + 68 >> 2];
    __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $73);
    __label__ = 16;
    break;
   case 16:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_js_TraceXML["X"] = 1;

function __ZL16xml_trace_vectorP8JSTracerPP5JSXMLj($trc, $vec, $len) {
  var $1 = $trc;
  var $2 = $vec;
  __ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc($1, $len, $2, undef);
  return;
}

function __ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor($trc, $cursor) {
  __ZN16JSXMLArrayCursor5traceEP8JSTracer($cursor, $trc);
  return;
}

function __ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML($this, $cx, $xml) {
  __ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML($this, $cx, $xml);
  return;
}

function __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml | 0;
    var $2 = HEAP32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = __ZL12NewXMLObjectP9JSContextP5JSXML($cx, $xml);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$1 >> 2] = $5;
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoXMLRooterD1Ev($this) {
  __ZN2js13AutoXMLRooterD2Ev($this);
  return;
}

function __ZL12NewXMLObjectP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $2 = $1 | 0;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427($cx, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $xml;
    var $7 = $3;
    __ZN8JSObject10setPrivateEPv($7, $6);
    var $_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_InitNamespaceClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js14NamespaceClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx + 52 | 0;
    var $12 = HEAP32[HEAP32[$8 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject13setNamePrefixEP14JSLinearString($5, $12);
    __ZN8JSObject10setNameURIEP14JSLinearString($5, $12);
    __ZN8JSObject19syncSpecialEqualityEv($4);
    var $16 = HEAP32[HEAP32[$8 >> 2] + 210068 >> 2];
    var $17 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $3, 284, __ZN2js14NamespaceClassE, $16, 2);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = $17 | 0;
    var $21 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($3, $20, $4);
    if ($21) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $23 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, __ZL15namespace_props, __ZL17namespace_methods);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 6;
      break;
    }
   case 5:
    var $25 = $cx;
    var $26 = $2;
    var $27 = $17;
    var $28 = $4;
    var $29 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($25, $26, 12, $27, $28);
    var $_ = $29 ? $5 : 0;
    var $_0 = $_;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject13setNamePrefixEP14JSLinearString($this, $prefix) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($prefix | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $prefix | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 0, $1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN8JSObject10setNameURIEP14JSLinearString($this, $uri) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($uri | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $uri | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 1, $1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9NamespaceP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $thisobj = __stackBase__;
  HEAP32[$thisobj >> 2] = 0;
  __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $thisobj);
  var $1 = HEAP32[$thisobj >> 2];
  var $2 = $vp + 16 | 0;
  var $3 = __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $1, $argc, $2, $vp);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z17js_InitQNameClassP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZN8JSObject8asGlobalEv($1);
    var $3 = $cx;
    var $4 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($2, $3, __ZN2js10QNameClassE);
    var $5 = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = $cx + 52 | 0;
    var $11 = HEAP32[HEAP32[$8 >> 2] + 144136 >> 2];
    var $12 = $11 | 0;
    var $13 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $5, $12, $12, $11);
    if ($13) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 3:
    __ZN8JSObject19syncSpecialEqualityEv($4);
    var $18 = HEAP32[HEAP32[$8 >> 2] + 210072 >> 2];
    var $19 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($2, $3, 286, __ZN2js10QNameClassE, $18, 2);
    if (($19 | 0) == 0) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = $19 | 0;
    var $23 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($3, $22, $4);
    if ($23) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $25 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($3, $4, 0, __ZL13qname_methods);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $27 = $cx;
    var $28 = $2;
    var $29 = $19;
    var $30 = $4;
    var $31 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($27, $28, 13, $29, $30);
    var $_ = $31 ? $5 : 0;
    var $_0 = $_;
    __label__ = 7;
    break;
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $obj, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = $obj;
    var $3 = _JS_DefineProperties($1, $2, __ZL11qname_props);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($uri | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN8JSObject10setNameURIEP14JSLinearString($obj, $uri);
    __label__ = 4;
    break;
   case 4:
    if (($prefix | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($obj, $prefix);
    __label__ = 6;
    break;
   case 6:
    if (($localName | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject17setQNameLocalNameEP6JSAtom($obj, $localName);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5QNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $thisobj = __stackBase__;
  HEAP32[$thisobj >> 2] = 0;
  __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $thisobj);
  var $1 = HEAP32[$thisobj >> 2];
  var $2 = $vp + 16 | 0;
  var $3 = __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $1, $argc, $2, $vp);
  STACKTOP = __stackBase__;
  return $3;
}

function __Z15js_InitXMLClassP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZN8JSObject8asGlobalEv($2);
    var $4 = $cx;
    var $5 = __ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE($3, $4, __ZN2js8XMLClassE);
    var $6 = $5;
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $12 = $9;
    var $13 = $5;
    __ZN8JSObject10setPrivateEPv($13, $12);
    HEAP32[$9 >> 2] = $6;
    var $15 = $cx;
    var $16 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($15);
    if ($16) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = HEAP32[_sE4XObjectsCreated >> 2] - 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $19;
    __label__ = 5;
    break;
   case 5:
    var $21 = $cx + 52 | 0;
    var $25 = HEAP32[HEAP32[$21 >> 2] + 210064 >> 2];
    var $26 = __ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj($3, $4, 288, __ZN2js8XMLClassE, $25, 1);
    if (($26 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = $26;
    var $30 = $26 | 0;
    var $31 = __ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_($4, $30, $5);
    if ($31) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $33 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $5, 0, __ZL11xml_methods);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 8:
    var $35 = __ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec($4, $30, __ZL16xml_static_props, __ZL18xml_static_methods);
    if ($35) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $37 = __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $29);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = $3;
    var $41 = _JS_DefineFunction($15, $40, STRING_TABLE._js_XMLList_str | 0, 290, 1, 512);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $47 = HEAP32[HEAP32[$21 >> 2] + 210200 >> 2] | 0;
    var $48 = __ZL12ATOM_TO_JSIDP6JSAtom4336($47);
    __ZN2JSL11ObjectValueER8JSObject4319($1, $6);
    var $49 = $41 | 0;
    var $50 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($49, $15, $48, $1, 10, 12, 6);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $53 = $3;
    var $54 = $26;
    var $55 = __ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_($15, $53, 11, $54, $13);
    if ($55) {
      __label__ = 13;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 13:
    var $57 = $obj;
    var $58 = _JS_DefineFunction($15, $57, STRING_TABLE._js_isXMLName_str | 0, 292, 1, 0);
    var $_ = ($58 | 0) == 0 ? 0 : $6;
    var $_0 = $_;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15js_InitXMLClassP9JSContextP8JSObject["X"] = 1;

function __ZL3XMLP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $4 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_08 = $4 | 0;
    var $tmp$0 = HEAP32[$_08 >> 2];
    var $tmp$1 = HEAP32[$_08 + 4 >> 2];
    var $5 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($5 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $8 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($8 | 0) == 0) {
      var $v_0_0_0$1 = $tmp$1;
      var $v_0_0_0$0 = $tmp$0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $15 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $15);
    var $_013 = $1 | 0;
    var $v_0_0_0$1 = HEAP32[$_013 + 4 >> 2];
    var $v_0_0_0$0 = HEAP32[$_013 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $17 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $v_0_0_0$0, $v_0_0_0$1);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = $17;
    var $21 = __ZNK8JSObject10getPrivateEv($20);
    var $22 = $21;
    var $23 = __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp);
    if ($23) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $25 = _JSVAL_IS_PRIMITIVE4303($v_0_0_0$0, $v_0_0_0$1);
    if (($25 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = _JSVAL_TO_OBJECT4304($v_0_0_0$0, $v_0_0_0$1);
    var $29 = $28;
    var $30 = __ZNK8JSObject8getClassEv($29);
    if (($30 | 0) == (__ZN2js8XMLClassE | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ((HEAP32[$30 + 4 >> 2] & 128 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $38 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $22, 0);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $43 = HEAP32[$38 >> 2];
    __ZN2JS5Value9setObjectER8JSObject($vp, $43);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 11:
    __ZN2JS5Value9setObjectER8JSObject($vp, $20);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL3XMLP9JSContextjPN2JS5ValueE["X"] = 1;

function _OBJECT_TO_JSID4356($obj) {
  return $obj | 4;
}

function __ZL21SetDefaultXMLSettingsP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = $1 | 0;
    var $3 = $v | 0;
    var $4 = $cx;
    var $5 = $obj;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $7 = __ZL16xml_static_props + ($i_0 << 4) | 0;
    var $8 = HEAP32[$7 >> 2];
    if (($8 | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($8 | 0) == (STRING_TABLE.__ZL19js_prettyIndent_str | 0);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $13$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $13$1 = HEAP32[$st$1$1 >> 2];
    HEAP32[$2 >> 2] = $13$0;
    HEAP32[$2 + 4 >> 2] = $13$1;
    var $17$1 = $13$1;
    var $17$0 = $13$0;
    var $16 = $8;
    __label__ = 6;
    break;
   case 5:
    _INT_TO_JSVAL4421($1, 2);
    var $st$1$0 = $2 | 0;
    var $st$1$1 = $2 + 4 | 0;
    var $17$1 = HEAP32[$st$1$1 >> 2];
    var $17$0 = HEAP32[$st$1$0 >> 2];
    var $16 = HEAP32[$7 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $16;
    var $17$0;
    var $17$1;
    HEAP32[$3 >> 2] = $17$0;
    HEAP32[$3 + 4 >> 2] = $17$1;
    var $18 = _JS_SetProperty($4, $5, $16, $v);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL7XMLListP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $6 = ($argc | 0) == 0 ? _JSVAL_VOID : $vp + 16 | 0;
    var $_08 = $6 | 0;
    var $st$7$0 = $_08 | 0;
    var $tmp$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_08 + 4 | 0;
    var $tmp$1 = HEAP32[$st$7$1 >> 2];
    var $7 = _JSVAL_IS_NULL4395($tmp$0, $tmp$1);
    if (($7 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $10 = _JSVAL_IS_VOID4396($tmp$0, $tmp$1);
    if (($10 | 0) == 0) {
      var $v_0_0_0$1 = $tmp$1;
      var $v_0_0_0$0 = $tmp$0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $17 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $17);
    var $_013 = $1 | 0;
    var $st$7$0 = $_013 | 0;
    var $st$7$1 = $_013 + 4 | 0;
    var $v_0_0_0$1 = HEAP32[$st$7$1 >> 2];
    var $v_0_0_0$0 = HEAP32[$st$7$0 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $v_0_0_0$0;
    var $v_0_0_0$1;
    var $19 = __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $21 = _JSVAL_IS_PRIMITIVE4303($v_0_0_0$0, $v_0_0_0$1);
    if (($21 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $24 = _JSVAL_TO_OBJECT4304($v_0_0_0$0, $v_0_0_0$1);
    var $25 = $24;
    var $26 = __ZNK8JSObject5isXMLEv($25);
    if ($26) {
      __label__ = 7;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 7:
    var $28 = __ZNK8JSObject10getPrivateEv($25);
    var $29 = $28;
    if ((HEAP32[$28 + 16 >> 2] | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $35 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($2, $35);
    var $38 = $2 | 0;
    var $st$2$0 = $38 | 0;
    var $39$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$2$1 >> 2];
    var $40 = $vp | 0;
    var $st$7$0 = $40 | 0;
    HEAP32[$st$7$0 >> 2] = $39$0;
    var $st$7$1 = $40 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $39$1;
    var $41 = $35;
    var $42 = __ZNK8JSObject10getPrivateEv($41);
    var $43 = $42;
    var $44 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $43, $29);
    var $_0 = ($44 | 0) != 0 & 1;
    __label__ = 12;
    break;
   case 10:
    var $46 = __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $v_0_0_0$0, $v_0_0_0$1);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _OBJECT_TO_JSVAL4318($3, $46);
    var $49 = $3 | 0;
    var $st$2$0 = $49 | 0;
    var $50$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $49 + 4 | 0;
    var $50$1 = HEAP32[$st$2$1 >> 2];
    var $51 = $vp | 0;
    var $st$7$0 = $51 | 0;
    HEAP32[$st$7$0 >> 2] = $50$0;
    var $st$7$1 = $51 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $50$1;
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7XMLListP9JSContextjPN2JS5ValueE["X"] = 1;

function __ZL12ATOM_TO_JSIDP6JSAtom4336($atom) {
  var $1 = $atom;
  var $2 = __ZL14JSID_FROM_BITSj4418($1);
  return $2;
}

function __ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE($cx, $argc, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    if (($argc | 0) == 0) {
      var $7 = _JSVAL_VOID;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $vp + 16 | 0;
    __label__ = 3;
    break;
   case 3:
    var $7;
    var $8 = $7;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $2 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $2);
    _BOOLEAN_TO_JSVAL4415($1, $11);
    var $12 = $1 | 0;
    var $13$0 = HEAP32[$12 >> 2];
    var $13$1 = HEAP32[$12 + 4 >> 2];
    var $14 = $vp | 0;
    HEAP32[$14 >> 2] = $13$0;
    HEAP32[$14 + 4 >> 2] = $13$1;
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z17js_InitXMLClassesP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __Z21js_InitNamespaceClassP9JSContextP8JSObject($cx, $obj);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z17js_InitQNameClassP9JSContextP8JSObject($cx, $obj);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = __Z15js_InitXMLClassP9JSContextP8JSObject($cx, $obj);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE($this, $cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN8JSObject10getSlotRefEj($1, 114);
    var $3 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = HEAP32[$cx + 52 >> 2];
    var $9 = HEAP32[$6 + 209992 >> 2] | 0;
    var $12 = HEAP32[$6 + 210428 >> 2] | 0;
    var $13 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $9, $12, 0);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $16 = $13;
    __ZN8JSObject9clearTypeEv($16);
    __ZN2JS5Value9setObjectER8JSObject($2, $16);
    __label__ = 4;
    break;
   case 4:
    var $18 = $2 | 0;
    var $19$0 = HEAP32[$18 >> 2];
    var $19$1 = HEAP32[$18 + 4 >> 2];
    var $20 = $vp | 0;
    HEAP32[$20 >> 2] = $19$0;
    HEAP32[$20 + 4 >> 2] = $19$1;
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $prefix, $uri, $declared) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js14NamespaceClassE);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $2;
    var $7 = _JS_DefineProperties($5, $6, __ZL15namespace_props);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($prefix | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($2, $prefix);
    __label__ = 5;
    break;
   case 5:
    if (($uri | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    __ZN8JSObject10setNameURIEP14JSLinearString($2, $uri);
    __label__ = 7;
    break;
   case 7:
    if (($declared | 0) == 0) {
      var $_0 = $2;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_TRUE | 0;
    var $18$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $18$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $19 = $1 | 0;
    HEAP32[$19 >> 2] = $18$0;
    HEAP32[$19 + 4 >> 2] = $18$1;
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($2, $1);
    var $_0 = $2;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 12;
    var $3 = $cx;
    var $4 = __ZN2js13GetScopeChainEP9JSContext($3);
    var $5 = $v | 0;
    var $tmp_0_in = $4;
    var $obj_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $obj_0;
    var $tmp_0_in;
    var $tmp_0 = $tmp_0_in;
    if (($tmp_0_in | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZNK8JSObject8getClassEv($tmp_0_in);
    if (($9 | 0) == (__ZN2js10BlockClassE | 0) | ($9 | 0) == (__ZN2js9WithClassE | 0)) {
      var $obj_1 = $obj_0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZN2js9SpecialId19defaultXMLNamespaceEv($1);
    var $13 = __ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE($tmp_0, $cx, $1, $v);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $st$0$0 = $5 | 0;
    var $16$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $16$1 = HEAP32[$st$0$1 >> 2];
    var $17 = _JSVAL_IS_PRIMITIVE4303($16$0, $16$1);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $obj_1 = $tmp_0;
      __label__ = 7;
      break;
    }
   case 6:
    var $st$0$0 = $5 | 0;
    var $20$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $20$1 = HEAP32[$st$0$1 >> 2];
    var $21 = $vp | 0;
    var $st$5$0 = $21 | 0;
    HEAP32[$st$5$0 >> 2] = $20$0;
    var $st$5$1 = $21 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $20$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 7:
    var $obj_1;
    var $23 = __ZNK8JSObject9getParentEv($tmp_0_in);
    var $tmp_0_in = $23;
    var $obj_0 = $obj_1;
    __label__ = 2;
    break;
   case 8:
    var $25 = $cx;
    var $27 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($25, __ZN2js14NamespaceClassE, 0, $obj_0, 0, 0);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $27;
    _OBJECT_TO_JSVAL4318($2, $30);
    var $31 = $2 | 0;
    var $32$0 = HEAP32[$31 >> 2];
    var $32$1 = HEAP32[$31 + 4 >> 2];
    HEAP32[$5 >> 2] = $32$0;
    HEAP32[$5 + 4 >> 2] = $32$1;
    var $34 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($obj_0, $3, 6, $v, 10, 12, 4);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $st$0$0 = $5 | 0;
    var $37$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $5 + 4 | 0;
    var $37$1 = HEAP32[$st$0$1 >> 2];
    var $38 = $vp | 0;
    var $st$5$0 = $38 | 0;
    HEAP32[$st$5$0 >> 2] = $37$0;
    var $st$5$1 = $38 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $37$1;
    var $_0 = 1;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE["X"] = 1;

function __ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE($this, $cx, $sid, $vp) {
  var __stackBase__ = STACKTOP;
  var tempParam = $sid;
  $sid = STACKTOP;
  STACKTOP += 4;
  HEAP32[$sid >> 2] = HEAP32[tempParam >> 2];
  var $sid_idx_val = HEAP32[$sid >> 2];
  var $1 = __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_idx_val);
  var $2 = $this;
  var $3 = $cx;
  var $4 = __ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE($2, $3, $1, $vp);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZN2js9SpecialId19defaultXMLNamespaceEv($agg_result) {
  __ZN2js9SpecialIdC1Ej($agg_result, 6);
  return;
}

function __Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE($cx, $v) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $1 = __stackBase__ + 16;
    var $2 = $argv | 0;
    var $7 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN2JS5Value9setStringEP8JSString($2, $7);
    var $8 = $v | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $argv + 8 | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = $cx;
    var $12 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($11, __ZN2js14NamespaceClassE, 0, 0, 2, $2);
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $15 = $12;
    var $16 = $cx;
    var $17 = __ZNK9JSContext2fpEv($16);
    var $18 = __ZN2js10StackFrame6varObjEv($17);
    __ZN2JSL11ObjectValueER8JSObject4319($1, $15);
    var $19 = __ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej($18, $16, 6, $1, 10, 12, 4);
    var $_0 = ($19 | 0) != 0 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_ToAttributeNameP9JSContextPN2JS5ValueE($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp | 0;
    var $2$0 = HEAP32[$1 >> 2];
    var $2$1 = HEAP32[$1 + 4 >> 2];
    var $3 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $2$0, $2$1);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3;
    __ZN2JS5Value9setObjectER8JSObject($vp, $6);
    var $_0 = 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $name = __stackBase__ + 8;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = $name;
    var $7 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($5, $v, $6);
    if ($7) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $uri_0 = $13;
    var $prefix_0 = $13;
    __label__ = 14;
    break;
   case 4:
    var $15 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($15 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $18 = $cx;
    var $19 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($18, 0, 178, 0, $v, 0, 0, 0);
    var $_0 = 0;
    __label__ = 15;
    break;
   case 6:
    var $21 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $22 = $21;
    var $23 = __ZNK8JSObject8getClassEv($22);
    if (($23 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $_0 = $21;
      __label__ = 15;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($23 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $28 = __ZNK8JSObject10getNameURIEv($21);
    var $29 = __ZNK8JSObject13getNamePrefixEv($21);
    var $30 = __ZNK8JSObject17getQNameLocalNameEv($21);
    HEAP32[$name >> 2] = $30;
    var $uri_0 = $28;
    var $prefix_0 = $29;
    __label__ = 14;
    break;
   case 9:
    if (($23 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $35 = HEAP32[$cx + 52 >> 2];
    var $38 = HEAP32[$35 + 210412 >> 2] | 0;
    HEAP32[$name >> 2] = $38;
    var $44 = $35;
    __label__ = 13;
    break;
   case 11:
    var $40 = $cx;
    var $41 = $name;
    var $42 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($40, $v, $41);
    if ($42) {
      __label__ = 12;
      break;
    } else {
      var $_0 = 0;
      __label__ = 15;
      break;
    }
   case 12:
    var $44 = HEAP32[$cx + 52 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $44;
    var $47 = HEAP32[$44 + 144136 >> 2] | 0;
    var $uri_0 = $47;
    var $prefix_0 = $47;
    __label__ = 14;
    break;
   case 14:
    var $prefix_0;
    var $uri_0;
    var $49 = HEAP32[$name >> 2];
    var $50 = __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri_0, $prefix_0, $49);
    var $_0 = $50;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15ToAttributeNameP9JSContextN2JS5ValueE["X"] = 1;

function __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $str, $quote) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $str, $quote);
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $str, $quote) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($quote | 0) != 0;
    var $7 = $sb;
    if ($6) {
      __label__ = 3;
      break;
    } else {
      var $_pre_phi = $7;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = __ZN2js12StringBuffer6appendEt($7, 34);
    if ($9) {
      var $_pre_phi = $7;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 4:
    var $_pre_phi;
    var $10 = $3 + ($1 << 1) | 0;
    var $11 = $sb;
    var $cp_0 = $3;
    __label__ = 5;
    break;
   case 5:
    var $cp_0;
    if (($cp_0 | 0) == ($10 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = HEAPU16[$cp_0 >> 1];
    var $16 = $15 & 65535;
    if (($16 | 0) == 34) {
      __label__ = 7;
      break;
    } else if (($16 | 0) == 60) {
      __label__ = 8;
      break;
    } else if (($16 | 0) == 38) {
      __label__ = 9;
      break;
    } else if (($16 | 0) == 10) {
      __label__ = 10;
      break;
    } else if (($16 | 0) == 13) {
      __label__ = 11;
      break;
    } else if (($16 | 0) == 9) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 7:
    var $18 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE._js_quot_entity_str);
    if ($18) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 8:
    var $20 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($11, STRING_TABLE._js_lt_entity_str);
    if ($20) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 9:
    var $22 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE._js_amp_entity_str);
    if ($22) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 10:
    var $24 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str504296);
    if ($24) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $26 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str514297);
    if ($26) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 12:
    var $28 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($11, STRING_TABLE.__str524298);
    if ($28) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 13:
    var $30 = __ZN2js12StringBuffer6appendEt($_pre_phi, $15);
    if ($30) {
      __label__ = 14;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 14:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 5;
    break;
   case 15:
    if ($6) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $35 = __ZN2js12StringBuffer6appendEt($_pre_phi, 34);
    if ($35) {
      __label__ = 17;
      break;
    } else {
      var $_0 = 0;
      __label__ = 18;
      break;
    }
   case 17:
    var $37 = $sb;
    var $38 = __ZN2js12StringBuffer12finishStringEv($37);
    var $_0 = $38 | 0;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_AddAttributePartP9JSContextiP8JSStringS2_($cx, $isName, $str, $str2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSString6lengthEv($str2);
    var $7 = __ZN8JSString8getCharsEP9JSContext($str2, $2);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($isName | 0) != 0;
    var $_pn_v = $10 ? 1 : 3;
    var $11 = $1 + $_pn_v + $6 | 0;
    var $13 = ($11 << 1) + 2 | 0;
    var $14 = __ZN9JSContext7malloc_Ej($2, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $14;
    var $18 = $3;
    var $19 = $1 << 1;
    _memcpy($14, $18, $19, 1);
    var $20 = $17 + ($1 << 1) | 0;
    var $_sum = $1 + 1 | 0;
    var $21 = $17 + ($_sum << 1) | 0;
    if ($10) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP16[$20 >> 1] = 32;
    var $23 = $21;
    var $24 = $7;
    var $25 = $6 << 1;
    _memcpy($23, $24, $25, 1);
    var $_sum4_pn = $6 + $_sum | 0;
    __label__ = 7;
    break;
   case 6:
    HEAP16[$20 >> 1] = 61;
    var $_sum1 = $1 + 2 | 0;
    var $27 = $17 + ($_sum1 << 1) | 0;
    HEAP16[$21 >> 1] = 34;
    var $28 = $27;
    var $29 = $7;
    var $30 = $6 << 1;
    _memcpy($28, $29, $30, 1);
    var $_sum2 = $6 + $_sum1 | 0;
    var $_sum3 = $_sum2 + 1 | 0;
    HEAP16[$17 + ($_sum2 << 1) >> 1] = 34;
    var $_sum4_pn = $_sum3;
    __label__ = 7;
    break;
   case 7:
    var $_sum4_pn;
    HEAP16[$17 + ($_sum4_pn << 1) >> 1] = 0;
    var $33 = $17 + ($_sum4_pn - $11 << 1) | 0;
    var $34 = $cx;
    var $35 = __Z12js_NewStringP9JSContextPtj($34, $33, $11);
    var $_0 = $35 | 0;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z19js_AddAttributePartP9JSContextiP8JSStringS2_["X"] = 1;

function __Z21js_EscapeElementValueP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str, 0);
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $3;
}

function __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str, $toSourceFlag) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($1 << 1) | 0;
    var $7 = $sb;
    var $8 = $sb;
    var $9 = ($toSourceFlag | 0) == 0;
    var $cp_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $cp_0;
    if (($cp_0 | 0) == ($6 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = HEAPU16[$cp_0 >> 1];
    var $14 = $13 & 65535;
    if (($14 | 0) == 60) {
      __label__ = 5;
      break;
    } else if (($14 | 0) == 62) {
      __label__ = 6;
      break;
    } else if (($14 | 0) == 38) {
      __label__ = 7;
      break;
    } else if (($14 | 0) == 123) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 5:
    var $16 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE._js_lt_entity_str);
    if ($16) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 6:
    var $18 = __ZN2js12StringBuffer6appendILj5EEEbRAT__Kc($8, STRING_TABLE._js_gt_entity_str);
    if ($18) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 7:
    var $20 = __ZN2js12StringBuffer6appendILj6EEEbRAT__Kc($8, STRING_TABLE._js_amp_entity_str);
    if ($20) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 8:
    if ($9) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__ZL23js_leftcurly_entity_str);
    if ($23) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 10:
    var $25 = __ZN2js12StringBuffer6appendEt($7, $13);
    if ($25) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 13;
      break;
    }
   case 11:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 3;
    break;
   case 12:
    var $29 = $sb;
    var $30 = __ZN2js12StringBuffer12finishStringEv($29);
    var $_0 = $30 | 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE($cx, $v) {
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $2$0, $2$1, 0);
  return $3;
}

function __ZL11ToXMLStringP9JSContextN2JS5ValueEj($cx, $_0_0_0_val$0, $_0_0_0_val$1, $toSourceFlag) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 172;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $sb = __stackBase__ + 8;
    var $sb1 = __stackBase__ + 88;
    var $anch = __stackBase__ + 168;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $st$0$0 = $1 | 0;
    var $5$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $5$1 = HEAP32[$st$0$1 >> 2];
    var $6 = _JSVAL_IS_VOID4396($5$0, $5$1);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $st$0$0 = $1 | 0;
    var $9$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $9$1 = HEAP32[$st$0$1 >> 2];
    var $10 = _JSVAL_IS_NULL4395($9$0, $9$1);
    var $_ = ($10 | 0) != 0 ? STRING_TABLE._js_null_str : STRING_TABLE._js_undefined_str;
    var $12 = $_ | 0;
    var $13 = $cx;
    _JS_ReportErrorNumber($13, 2, 0, 180, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $12, tempInt));
    var $_0 = 0;
    __label__ = 14;
    break;
   case 4:
    var $st$0$0 = $1 | 0;
    var $15$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $15$1 = HEAP32[$st$0$1 >> 2];
    var $16 = _JSVAL_IS_BOOLEAN4407($15$0, $15$1);
    if (($16 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $st$0$0 = $1 | 0;
    var $19$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $19$1 = HEAP32[$st$0$1 >> 2];
    var $20 = _JSVAL_IS_NUMBER($19$0, $19$1);
    if (($20 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = $cx;
    var $24 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($23, $v);
    var $_0 = $24;
    __label__ = 14;
    break;
   case 7:
    var $st$0$0 = $1 | 0;
    var $26$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $26$1 = HEAP32[$st$0$1 >> 2];
    var $27 = _JSVAL_IS_STRING4320($26$0, $26$1);
    if (($27 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $30 = $sb;
    var $31 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($30, $31);
    var $32$0 = HEAP32[$1 >> 2];
    var $32$1 = HEAP32[$1 + 4 >> 2];
    var $33 = _JSVAL_TO_STRING4321($32$0, $32$1);
    var $34 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $33, $toSourceFlag);
    var $35 = $34 | 0;
    __ZN2js12StringBufferD1Ev($30);
    var $_0 = $35;
    __label__ = 14;
    break;
   case 9:
    var $st$0$0 = $1 | 0;
    var $37$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $1 + 4 | 0;
    var $37$1 = HEAP32[$st$0$1 >> 2];
    var $38 = _JSVAL_TO_OBJECT4304($37$0, $37$1);
    var $39 = $38;
    var $40 = __ZNK8JSObject5isXMLEv($39);
    if ($40) {
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $42 = __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408($cx, $v);
    if ($42) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $44 = $cx;
    var $45 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($44, $v);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $48 = $sb1;
    var $49 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($48, $49);
    var $50 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb1, $45, $toSourceFlag);
    var $51 = $50 | 0;
    __ZN2js12StringBufferD1Ev($48);
    var $_0 = $51;
    __label__ = 14;
    break;
   case 13:
    __ZN2JS6AnchorIP8JSObjectEC1ES2_($anch, $38);
    var $53 = __ZNK8JSObject10getPrivateEv($39);
    var $54 = $53;
    var $55 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $54, 0, $toSourceFlag);
    var $_0 = $55;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11ToXMLStringP9JSContextN2JS5ValueEj["X"] = 1;

function __Z13js_GetAnyNameP9JSContextPi($cx, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext5hasfpEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($1);
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $6 = $5;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $13 = $7;
    __label__ = 4;
    break;
   case 3:
    var $13 = HEAP32[$cx + 132 >> 2];
    __label__ = 4;
    break;
   case 4:
    var $13;
    __ZNK8JSObject15getReservedSlotEj($v, $13, 35);
    var $15 = __ZNK2JS5Value11isUndefinedEv($v);
    if ($15) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $17 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, __ZN2js12AnyNameClassE, $13);
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = HEAP32[$cx + 52 >> 2];
    var $24 = HEAP32[$21 + 144136 >> 2] | 0;
    var $27 = HEAP32[$21 + 210412 >> 2] | 0;
    var $28 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $17, $24, $24, $27);
    if ($28) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $30 = $17;
    __ZN2JS5Value9setObjectER8JSObject($v, $30);
    var $31 = $cx;
    var $33 = __Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE($31, $13, 35, $v);
    if ($33) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $35 = __ZNK2JS5Value8toObjectEv($v);
    var $36 = $35;
    var $37 = _OBJECT_TO_JSID4356($36);
    HEAP32[$idp >> 2] = $37;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, $clasp, $parent) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4379($4);
  var $6 = __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380($cx, $clasp, $parent, $5);
  return $6;
}

function _JSID_IS_VOID4359($iden) {
  return ($iden | 0) == 2 & 1;
}

function __ZN16JSXMLArrayCursor7getNextEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $this + 4 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if ($6 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    HEAP32[$5 >> 2] = $6 + 1 | 0;
    var $15 = HEAP32[HEAP32[$2 + 8 >> 2] + ($6 << 2) >> 2];
    HEAP32[$this + 16 >> 2] = $15;
    var $_0 = $15;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi($cx, $nameval, $objp, $idp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $funid = __stackBase__ + 8;
    var $pobj = __stackBase__ + 12;
    var $found = __stackBase__ + 16;
    var $prop = __stackBase__ + 20;
    var $1 = __stackBase__ + 24;
    var $printable = __stackBase__ + 32;
    var $2 = __stackBase__ + 36;
    var $3 = __ZNK2JS5Value8toObjectEv($nameval);
    var $4 = $3;
    var $5 = __ZNK8JSObject8getClassEv($3);
    if (($5 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      var $nameobj_0 = $4;
      __label__ = 3;
      break;
    }
   case 2:
    var $12 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $12);
    var $13 = $1 | 0;
    var $14$0 = HEAP32[$13 >> 2];
    var $14$1 = HEAP32[$13 + 4 >> 2];
    var $15 = $v | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $16 = $cx;
    var $17 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($16, __ZN2js10QNameClassE, 0, 0, 1, $v);
    var $18 = $17;
    if (($17 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      var $nameobj_0 = $18;
      __label__ = 3;
      break;
    }
   case 3:
    var $nameobj_0;
    var $21 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($nameobj_0, $funid, $cx);
    if ($21) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$funid >> 2] = 2;
    __label__ = 5;
    break;
   case 5:
    var $25 = $cx + 60 | 0;
    var $26 = __ZNK2js12ContextStack25currentScriptedScopeChainEv($25);
    var $28 = $cx;
    var $29 = $prop;
    var $obj_0 = $26;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    var $target_0 = $obj_0;
    __label__ = 7;
    break;
   case 7:
    var $target_0;
    var $32 = $target_0;
    var $33 = __ZNK8JSObject8getClassEv($32);
    if (($33 | 0) == (__ZN2js9WithClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    var $36 = __ZNK8JSObject8getProtoEv($32);
    if (($36 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $target_0 = $36;
    __label__ = 7;
    break;
   case 10:
    var $40 = __ZNK8JSObject5isXMLEv($32);
    var $41 = HEAP32[$funid >> 2];
    var $42 = _JSID_IS_VOID4359($41);
    var $43 = ($42 | 0) != 0;
    if ($40) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    if ($43) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $46 = __ZNK8JSObject10getPrivateEv($32);
    var $47 = $46;
    var $48 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($47, $nameobj_0);
    HEAP32[$found >> 2] = $48;
    var $53 = $48;
    __label__ = 15;
    break;
   case 13:
    var $50 = __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $target_0, $41, $found);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $53 = HEAP32[$found >> 2];
    __label__ = 15;
    break;
   case 15:
    var $53;
    if (($53 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $56 = _OBJECT_TO_JSID4356($nameobj_0);
    HEAP32[$idp >> 2] = $56;
    HEAP32[$objp >> 2] = $target_0;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 17:
    if ($43) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $59 = __ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty($32, $28, $41, $pobj, $29);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ((HEAP32[$prop >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$idp >> 2] = $41;
    HEAP32[$objp >> 2] = $target_0;
    var $_0 = 1;
    __label__ = 26;
    break;
   case 21:
    var $67 = __ZNK8JSObject9getParentEv($obj_0);
    var $68 = $67;
    if (($67 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $obj_0 = $68;
      __label__ = 6;
      break;
    }
   case 22:
    __ZN16JSAutoByteStringC1Ev($printable);
    var $71 = __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $nameobj_0);
    if (($71 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    __ZN2JSL11StringValueEP8JSString4311($2, $71);
    var $74 = $cx;
    var $75 = $printable;
    var $76 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($74, $2, $75, 0);
    if (($76 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $79 = __ZNK16JSAutoByteString3ptrEv($printable);
    var $80 = _JS_ReportErrorFlagsAndNumber($28, 0, 2, 0, 197, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $79, tempInt));
    __label__ = 25;
    break;
   case 25:
    __ZN16JSAutoByteStringD1Ev($printable);
    var $_0 = 0;
    __label__ = 26;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi["X"] = 1;

function __ZL16HasNamedPropertyP5JSXMLP8JSObject($xml, $nameqn) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $4);
    __label__ = 3;
    break;
   case 3:
    var $6 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($6 | 0) == 0) {
      var $found_1 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = $6;
    var $10 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($9, $nameqn);
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $found_1 = $10;
      __label__ = 5;
      break;
    }
   case 5:
    var $found_1;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $found_1;
    __label__ = 12;
    break;
   case 6:
    var $14 = $nameqn;
    var $15 = __ZNK8JSObject8getClassEv($14);
    var $16 = ($15 | 0) == (__ZN2js18AttributeNameClassE | 0);
    var $array_0 = $16 ? $xml + 56 | 0 : $xml + 24 | 0;
    var $matcher_0 = $16 ? 294 : 296;
    var $19 = $array_0 | 0;
    var $20 = HEAPU32[$19 >> 2];
    var $21 = $array_0 + 8 | 0;
    var $i_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0;
    if ($i_0 >>> 0 < $20 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 8:
    if ($i_0 >>> 0 < HEAPU32[$19 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $30 = HEAP32[HEAP32[$21 >> 2] + ($i_0 << 2) >> 2];
    if (($30 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $33 = $30;
    var $34 = FUNCTION_TABLE[$matcher_0]($nameqn, $33);
    if (($34 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $obj, $funid, $found) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pobj = __stackBase__;
    var $prop = __stackBase__ + 4;
    var $tvr = __stackBase__ + 8;
    var $1 = $cx;
    var $2 = $obj;
    var $3 = $prop;
    var $4 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($1, $2, $funid, $pobj, $3);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$prop >> 2];
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $29 = $7;
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = $obj;
    var $11 = __ZNK8JSObject10getPrivateEv($10);
    var $12 = $11;
    var $13 = __ZL16HasSimpleContentP5JSXML($12);
    if (($13 | 0) == 0) {
      var $29 = $7;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $tvr;
    var $17 = $cx;
    __ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject($16, $17, 0);
    var $18 = $tvr;
    var $19 = __ZN2js16AutoObjectRooter4addrEv($18);
    var $20 = $19;
    var $21 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($1, 0, 9, $20, 0);
    if (($21 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $24 = __ZNK2js16AutoObjectRooter6objectEv($18);
    var $25 = $24;
    var $26 = __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty($1, $25, $funid, $pobj, $3);
    var $27 = ($26 | 0) == 0;
    __ZN2js16AutoObjectRooterD1Ev($16);
    if ($27) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $29 = HEAP32[$prop >> 2];
    __label__ = 7;
    break;
   case 7:
    var $29;
    HEAP32[$found >> 2] = ($29 | 0) != 0 & 1;
    var $_1 = 1;
    __label__ = 9;
    break;
   case 8:
    __ZN2js16AutoObjectRooterD1Ev($16);
    var $_1 = 0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20ConvertQNameToStringP9JSContextP8JSObject($cx, $obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $anchor = __stackBase__;
    var $1 = __ZNK8JSObject10getNameURIEv($obj);
    var $2 = $1 | 0;
    if (($1 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $str_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 210416 >> 2] | 0;
    __label__ = 6;
    break;
   case 3:
    var $11 = __ZNK8JSString5emptyEv($2);
    var $13 = HEAP32[$cx + 52 >> 2];
    if ($11) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $str_0 = HEAP32[$13 + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 5:
    var $21 = HEAP32[$13 + 210400 >> 2] | 0;
    var $22 = $cx;
    var $23 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($22, $2, $21);
    if (($23 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      var $str_0 = $23;
      __label__ = 6;
      break;
    }
   case 6:
    var $str_0;
    var $26 = __ZNK8JSObject17getQNameLocalNameEv($obj);
    var $27 = $26 | 0;
    var $28 = $cx;
    var $29 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($28, $str_0, $27);
    if (($29 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $32 = $obj;
    var $33 = __ZNK8JSObject8getClassEv($32);
    if (($33 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_1 = $29;
      __label__ = 13;
      break;
    }
   case 8:
    __ZN2JS6AnchorIP8JSStringEC1ES2_($anchor, $29);
    var $36 = __ZNK8JSString6lengthEv($29);
    var $37 = $36 << 1;
    var $38 = $37 + 4 | 0;
    var $39 = __ZN9JSContext7malloc_Ej($28, $38);
    var $40 = $39;
    if (($39 | 0) == 0) {
      var $_1 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP16[$40 >> 1] = 64;
    var $43 = __ZN8JSString8getCharsEP9JSContext($29, $28);
    if (($43 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    __ZN9JSContext5free_EPv(undef, $39);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 11:
    var $47 = $39 + 2 | 0;
    var $48 = $43;
    _memcpy($47, $48, $37, 1);
    var $49 = $36 + 1 | 0;
    HEAP16[$40 + ($49 << 1) >> 1] = 0;
    var $51 = $cx;
    var $52 = __Z12js_NewStringP9JSContextPtj($51, $40, $49);
    var $53 = $52 | 0;
    if (($52 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      var $_1 = $53;
      __label__ = 13;
      break;
    }
   case 12:
    __ZN9JSContext5free_EPv(undef, $39);
    var $_1 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20ConvertQNameToStringP9JSContextP8JSObject["X"] = 1;

function __Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_($cx, $obj, $0, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = __stackBase__;
    var $_03 = $0 | 0;
    var $tmp$0 = HEAP32[$_03 >> 2];
    var $tmp$1 = HEAP32[$_03 + 4 >> 2];
    var $3 = __ZL10GetPrivateP9JSContextP8JSObjectPKc($cx, $obj);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $3, $tmp$0, $tmp$1);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$6 >> 2];
    _OBJECT_TO_JSVAL4318($2, $10);
    var $11 = $2 | 0;
    var $12$0 = HEAP32[$11 >> 2];
    var $12$1 = HEAP32[$11 + 4 >> 2];
    var $13 = $vp | 0;
    HEAP32[$13 >> 2] = $12$0;
    HEAP32[$13 + 4 >> 2] = $12$1;
    var $_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10GetPrivateP9JSContextP8JSObjectPKc($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject5isXMLEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZNK8JSObject8getClassEv($1);
    var $6 = HEAP32[$4 >> 2];
    var $7 = $cx;
    _JS_ReportErrorNumber($7, 2, 0, 188, (tempInt = STACKTOP, STACKTOP += 12, HEAP32[tempInt >> 2] = STRING_TABLE._js_XML_str | 0, HEAP32[tempInt + 4 >> 2] = STRING_TABLE.__str444290 | 0, HEAP32[tempInt + 8 >> 2] = $6, tempInt));
    var $_0 = 0;
    __label__ = 4;
    break;
   case 3:
    var $9 = __ZNK8JSObject10getPrivateEv($1);
    var $_0 = $9;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE($cx, $xml, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $funid = __stackBase__;
    var $1 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funid);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4;
    var $8 = __ZNK8JSObject10getPrivateEv($7);
    var $9 = $8;
    var $10 = HEAP32[$funid >> 2];
    var $11 = _JSID_IS_VOID4359($10);
    if (($11 | 0) == 0) {
      var $_0 = $9;
      __label__ = 15;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $15 = $8 + 12 | 0;
    HEAP32[$15 >> 2] = $1;
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 5:
    var $20 = $xml + 24 | 0;
    var $21 = HEAPU32[$20 >> 2];
    var $22 = $xml + 32 | 0;
    var $ok_0 = 1;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $ok_0;
    if ($i_0 >>> 0 < $21 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 13;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    }
   case 8:
    var $31 = HEAPU32[HEAP32[$22 >> 2] + ($i_0 << 2) >> 2];
    var $32 = $31;
    if (($31 | 0) == 0) {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$31 + 16 >> 2] | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $ok_1 = $ok_0;
      __label__ = 11;
      break;
    }
   case 10:
    var $40 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $32, $1, $9);
    if (($40 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      var $ok_1 = $40;
      __label__ = 11;
      break;
    }
   case 11:
    var $ok_1;
    var $ok_0 = $ok_1;
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $44 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $1, $9);
    var $ok_2 = $44;
    __label__ = 13;
    break;
   case 13:
    var $ok_2;
    if (($ok_2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    HEAP32[$15 >> 2] = 0;
    var $_0 = $9;
    __label__ = 15;
    break;
   case 15:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE["X"] = 1;

function __Z24js_DeleteXMLListElementsP9JSContextP8JSObject($cx, $listobj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $listobj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    var $3 = $2;
    var $6 = HEAP32[$2 + 24 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_01 = $6;
      __label__ = 2;
      break;
    }
   case 2:
    var $n_01;
    __ZL17DeleteListElementP9JSContextP5JSXMLj($3, 0);
    var $8 = $n_01 - 1 | 0;
    if (($8 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17DeleteListElementP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml + 24 | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 2:
    var $9 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($9 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = HEAPU32[$9 + 8 >> 2];
    if (($14 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$9 + 16 >> 2] | 0) == 2) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $24 = HEAP32[$9 + 12 >> 2];
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($14, $24, 1);
    __label__ = 7;
    break;
   case 6:
    var $_idx_val = HEAP32[$14 + 24 >> 2];
    var $_idx1_val = HEAP32[$14 + 32 >> 2];
    var $26 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $9, 0);
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($14, $26);
    __label__ = 7;
    break;
   case 7:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($1, $index, 1);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18xmlfilter_finalizeP9JSContextP8JSObject($cx, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN9JSContext7delete_I11JSXMLFilterEEvPT_($cx, $5);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xmlfilter_traceP8JSTracerP8JSObject($trc, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    if (($2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = HEAP32[$2 >> 2];
    var $8 = $trc;
    _JS_CallTracer($8, $7, 3);
    var $11 = HEAP32[$2 + 4 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $14 = $11;
    _JS_CallTracer($8, $14, 3);
    __label__ = 4;
    break;
   case 4:
    var $18 = HEAP32[$2 + 8 >> 2];
    if (($18 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $18;
    _JS_CallTracer($8, $21, 3);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z20js_StepXMLListFilterP9JSContexti($cx, $initialized) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = __stackBase__ + 16;
    var $4 = __stackBase__ + 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext4regsEv($5);
    var $8 = HEAP32[$6 >> 2];
    var $10 = $8 - 16 | 0;
    var $11 = $10 | 0;
    var $st$11$0 = $11 | 0;
    var $12$0 = HEAP32[$st$11$0 >> 2];
    var $st$11$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$11$1 >> 2];
    if (($initialized | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 2:
    var $14 = _JSVAL_IS_PRIMITIVE4303($12$0, $12$1);
    if (($14 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $st$0$0 = $11 | 0;
    var $17$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $11 + 4 | 0;
    var $17$1 = HEAP32[$st$0$1 >> 2];
    var $18 = _JSVAL_TO_OBJECT4304($17$0, $17$1);
    var $19 = $18;
    var $20 = __ZNK8JSObject5isXMLEv($19);
    if ($20) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $22 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($5, 0, 217, -2, $10, 0, 0, 0);
    var $_0 = 0;
    __label__ = 18;
    break;
   case 5:
    var $st$0$0 = $11 | 0;
    var $24$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $11 + 4 | 0;
    var $24$1 = HEAP32[$st$0$1 >> 2];
    var $25 = _JSVAL_TO_OBJECT4304($24$0, $24$1);
    var $26 = $25;
    var $27 = __ZNK8JSObject10getPrivateEv($26);
    var $28 = $27;
    if ((HEAP32[$27 + 16 >> 2] | 0) == 0) {
      var $list_0 = $28;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $34 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _OBJECT_TO_JSVAL4318($1, $34);
    var $37 = $1 | 0;
    var $38$0 = HEAP32[$37 >> 2];
    var $38$1 = HEAP32[$37 + 4 >> 2];
    var $39 = $8 - 8 | 0;
    var $st$7$0 = $39 | 0;
    HEAP32[$st$7$0 >> 2] = $38$0;
    var $st$7$1 = $39 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $38$1;
    var $40 = $34;
    var $41 = __ZNK8JSObject10getPrivateEv($40);
    var $42 = $41;
    var $43 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $42, $28);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $list_0 = $42;
      __label__ = 8;
      break;
    }
   case 8:
    var $list_0;
    var $46 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $47 = $46 | 0;
    var $48 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, _js_XMLFilterClass, $47);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $52 = __ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_($cx, $list_0, $list_0 + 24 | 0);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $55 = $52;
    var $56 = $48;
    __ZN8JSObject10setPrivateEPv($56, $55);
    _OBJECT_TO_JSVAL4318($2, $48);
    var $57 = $2 | 0;
    var $58$0 = HEAP32[$57 >> 2];
    var $58$1 = HEAP32[$57 + 4 >> 2];
    var $st$9$0 = $11 | 0;
    HEAP32[$st$9$0 >> 2] = $58$0;
    var $st$9$1 = $11 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $58$1;
    var $59 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($59 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $62 = $59;
    var $63 = __ZNK8JSObject10getPrivateEv($62);
    HEAP32[$52 + 4 >> 2] = $63;
    var $filter_0 = $52;
    __label__ = 14;
    break;
   case 12:
    var $67 = _JSVAL_TO_OBJECT4304($12$0, $12$1);
    var $68 = $67;
    var $69 = __ZNK8JSObject10getPrivateEv($68);
    var $70 = $69;
    var $71 = $8 - 8 | 0;
    var $72 = __Z17js_ValueToBooleanRKN2JS5ValueE($71);
    if (($72 | 0) == 0) {
      var $filter_0 = $70;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $77 = HEAP32[$69 + 4 >> 2];
    var $80 = HEAP32[$69 + 8 >> 2];
    var $81 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $77, $80);
    if (($81 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $filter_0 = $70;
      __label__ = 14;
      break;
    }
   case 14:
    var $filter_0;
    var $84 = $filter_0 + 12 | 0;
    var $85 = __ZN16JSXMLArrayCursor7getNextEv($84);
    var $86 = $85;
    HEAP32[$filter_0 + 8 >> 2] = $86;
    if (($85 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZN16JSXMLArrayCursor10disconnectEv($84);
    var $93 = HEAP32[HEAP32[$filter_0 + 4 >> 2] >> 2];
    _OBJECT_TO_JSVAL4318($3, $93);
    var $94 = $3 | 0;
    var $st$7$0 = $94 | 0;
    var $95$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $94 + 4 | 0;
    var $95$1 = HEAP32[$st$7$1 >> 2];
    var $st$11$0 = $11 | 0;
    HEAP32[$st$11$0 >> 2] = $95$0;
    var $st$11$1 = $11 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $95$1;
    var $kidobj_0 = 0;
    __label__ = 17;
    break;
   case 16:
    var $97 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $86);
    if (($97 | 0) == 0) {
      var $_0 = 0;
      __label__ = 18;
      break;
    } else {
      var $kidobj_0 = $97;
      __label__ = 17;
      break;
    }
   case 17:
    var $kidobj_0;
    _OBJECT_TO_JSVAL4318($4, $kidobj_0);
    var $100 = $4 | 0;
    var $101$0 = HEAP32[$100 >> 2];
    var $101$1 = HEAP32[$100 + 4 >> 2];
    var $102 = $8 - 8 | 0;
    var $st$8$0 = $102 | 0;
    HEAP32[$st$8$0 >> 2] = $101$0;
    var $st$8$1 = $102 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $101$1;
    var $_0 = 1;
    __label__ = 18;
    break;
   case 18:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z20js_StepXMLListFilterP9JSContexti["X"] = 1;

function __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $scope = __stackBase__;
    var $1 = $cx;
    var $2 = __ZNK9JSContext5hasfpEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK9JSContext2fpEv($1);
    var $5 = __ZNK2js10StackFrame10scopeChainEv($4);
    var $6 = $5;
    var $7 = __ZNK8JSObject9getGlobalEv($6);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 3:
    var $11 = HEAP32[$cx + 132 >> 2];
    HEAP32[$scope >> 2] = $11;
    var $12 = $cx;
    var $13 = $scope;
    var $14 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($12, $13);
    if ($14) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = HEAP32[$scope >> 2];
    var $18 = __ZN8JSObject8asGlobalEv($17);
    var $_0 = $18;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_($this, $p1, $p2) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 32);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray($5, $p1, $p2);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $2$0, $2$1);
  return $3;
}

function __ZN16JSXMLArrayCursorC2EP10JSXMLArray($this, $array) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    HEAP32[$this >> 2] = $array;
    HEAP32[$this + 4 >> 2] = 0;
    var $3 = $this + 8 | 0;
    var $4 = $array + 12 | 0;
    var $5 = HEAP32[$4 >> 2];
    HEAP32[$3 >> 2] = $5;
    HEAP32[$this + 12 >> 2] = $4;
    HEAP32[$this + 16 >> 2] = 0;
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $5 + 12 | 0;
    HEAP32[$10 >> 2] = $3;
    __label__ = 3;
    break;
   case 3:
    HEAP32[$4 >> 2] = $this;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS6AnchorIP8JSObjectEC2ES2_($this, $t) {
  HEAP32[$this >> 2] = $t;
  return;
}

function __ZN2js2gcL15GetGCObjectKindEjb4379($numSlots) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($numSlots >>> 0 > 16) {
      var $_0 = 10;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_0 = HEAP32[__ZN2js2gc16slotsToThingKindE + ($numSlots << 2) >> 2];
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSString5emptyEv($this) {
  return HEAPU32[$this >> 2] >>> 0 < 16;
}

function __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 3:
    var $8 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($8 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 4:
    var $11 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $12 = $11;
    var $13 = __ZNK8JSObject5isXMLEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    var $15 = __ZNK8JSObject10getPrivateEv($12);
    if ((HEAP32[$15 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $11;
      __label__ = 21;
      break;
    }
   case 6:
    if ((HEAP32[$15 + 24 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 7:
    var $29 = HEAP32[HEAP32[$15 + 32 >> 2] >> 2];
    if (($29 | 0) == 0) {
      var $_0 = $11;
      __label__ = 21;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = $29;
    var $33 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $32);
    var $_0 = $33;
    __label__ = 21;
    break;
   case 9:
    var $35 = __ZNK8JSObject8getClassEv($12);
    if (($35 | 0) != (__ZN2js11StringClassE | 0) & ($35 | 0) != (__ZN2js11NumberClassE | 0) & ($35 | 0) != (__ZN2js12BooleanClassE | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = $cx;
    var $41 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($40, $v);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $44 = __ZNK8JSString5emptyEv($41);
    if ($44) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $46 = __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $41);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if (HEAPU32[$46 + 16 >> 2] >>> 0 < 2) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $54 = HEAP32[$46 + 24 >> 2];
    if (($54 | 0) == 0) {
      __label__ = 15;
      break;
    } else if (($54 | 0) == 1) {
      __label__ = 16;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 15:
    var $55 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 4);
    if (($55 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $obj_0 = $55;
      __label__ = 19;
      break;
    }
   case 16:
    var $58 = __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $46, 0);
    if (($58 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $61 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $58);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      var $obj_0 = $61;
      __label__ = 19;
      break;
    }
   case 18:
    var $64 = $cx;
    _JS_ReportErrorNumber($64, 2, 0, 133, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 21;
    break;
   case 19:
    var $obj_0;
    var $_0 = $obj_0;
    __label__ = 21;
    break;
   case 20:
    var $67 = $cx;
    var $68 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($67, 0, 180, 0, $v, 0, 0, 0);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5ToXMLP9JSContextN2JS5ValueE["X"] = 1;

function __Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE($cx, $v) {
  var $1 = $v | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $2$0, $2$1);
  return $3;
}

function __ZL9ToXMLListP9JSContextN2JS5ValueE($cx, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 3:
    var $8 = _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1);
    if (($8 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 4:
    var $11 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $12 = $11;
    var $13 = __ZNK8JSObject5isXMLEv($12);
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $15 = __ZNK8JSObject10getPrivateEv($12);
    var $16 = $15;
    if ((HEAP32[$15 + 16 >> 2] | 0) == 0) {
      var $_0 = $11;
      __label__ = 21;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $22 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $25 = $22;
    var $26 = __ZNK8JSObject10getPrivateEv($25);
    var $27 = $26;
    var $28 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $27, $16);
    var $_ = ($28 | 0) == 0 ? 0 : $22;
    var $_0 = $_;
    __label__ = 21;
    break;
   case 8:
    var $31 = __ZNK8JSObject8getClassEv($12);
    if (($31 | 0) != (__ZN2js11StringClassE | 0) & ($31 | 0) != (__ZN2js11NumberClassE | 0) & ($31 | 0) != (__ZN2js12BooleanClassE | 0)) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $36 = $cx;
    var $37 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($36, $v);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $40 = __ZNK8JSString5emptyEv($37);
    if ($40) {
      var $length_0 = 0;
      var $xml_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $42 = __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $37);
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (HEAPU32[$42 + 16 >> 2] >>> 0 < 2) {
      __label__ = 13;
      break;
    } else {
      var $length_0 = 0;
      var $xml_0 = $42;
      __label__ = 14;
      break;
    }
   case 13:
    var $length_0 = HEAP32[$42 + 24 >> 2];
    var $xml_0 = $42;
    __label__ = 14;
    break;
   case 14:
    var $xml_0;
    var $length_0;
    var $52 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = $52;
    var $56 = __ZNK8JSObject10getPrivateEv($55);
    var $57 = $56;
    var $i_0 = 0;
    __label__ = 16;
    break;
   case 16:
    var $i_0;
    if ($i_0 >>> 0 < $length_0 >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $_0 = $52;
      __label__ = 21;
      break;
    }
   case 17:
    var $61 = __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $xml_0, $i_0);
    if (($61 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $64 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $57, $61);
    if (($64 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 16;
    break;
   case 20:
    var $69 = $cx;
    var $70 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($69, 0, 181, 0, $v, 0, 0, 0);
    var $_0 = 0;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ToXMLListP9JSContextN2JS5ValueE["X"] = 1;

function __Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_($cx, $xml_class, $name, $value) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flags = __stackBase__;
    var $1 = __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flags);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($xml_class | 0) == 5) {
      __label__ = 3;
      break;
    } else if (($xml_class | 0) == 3) {
      __label__ = 4;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    if ((HEAP32[$flags >> 2] & 1 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    if ((HEAP32[$flags >> 2] & 2 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $13 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 4);
    var $_0 = $13;
    __label__ = 12;
    break;
   case 6:
    var $15 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, $xml_class);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = $15;
    var $19 = __ZNK8JSObject10getPrivateEv($18);
    if (($name | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $22 = $cx;
    var $23 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($22, $name, 0);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $26 = $23;
    var $31 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $32 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $31, 0, $26);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$19 + 12 >> 2] = $32;
    __label__ = 11;
    break;
   case 11:
    HEAP32[$19 + 24 >> 2] = $value;
    var $_0 = $15;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flagsp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $flag = __stackBase__;
    var $1 = $flag | 0;
    var $2 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_ignoreComments_str | 0, $1);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $flag + 4 | 0;
    var $6 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str | 0, $5);
    if (($6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $flag + 8 | 0;
    var $10 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL23js_ignoreWhitespace_str | 0, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = $flag + 12 | 0;
    var $14 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_prettyPrinting_str | 0, $13);
    if (($14 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    HEAP32[$flagsp >> 2] = 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      var $21 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    HEAP32[$flagsp >> 2] = 1;
    var $21 = 1;
    __label__ = 7;
    break;
   case 7:
    var $21;
    if ((HEAP32[$5 >> 2] | 0) == 0) {
      var $27 = $21;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   case 9:
    var $25 = $21 | 2;
    HEAP32[$flagsp >> 2] = $25;
    var $27 = $25;
    __label__ = 10;
    break;
   case 10:
    var $27;
    if ((HEAP32[$9 >> 2] | 0) == 0) {
      var $33 = $27;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $31 = $27 | 4;
    HEAP32[$flagsp >> 2] = $31;
    var $33 = $31;
    __label__ = 12;
    break;
   case 12:
    var $33;
    if ((HEAP32[$13 >> 2] | 0) == 0) {
      var $_0 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    HEAP32[$flagsp >> 2] = $33 | 8;
    var $_0 = 1;
    __label__ = 8;
    break;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js10QNameClassE);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $1, $uri, $prefix, $localName);
    var $_ = $4 ? $1 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z21js_MakeXMLCDATAStringP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, 0, __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr | 0, 9, __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr | 0, 3);
  return $1;
}

function __Z23js_MakeXMLCommentStringP9JSContextP8JSString($cx, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $str) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, 0, __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr | 0, 4, __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr | 0, 3);
  return $1;
}

function __Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_($cx, $name, $str) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var $sb = __stackBase__;
  var $1 = $sb;
  var $2 = $cx;
  __ZN2js12StringBufferC1EP9JSContext($1, $2);
  var $3 = __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $name, $str);
  var $4 = $3 | 0;
  __ZN2js12StringBufferD1Ev($1);
  STACKTOP = __stackBase__;
  return $4;
}

function __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $name, $value) {
  var $1 = __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $name, $value, __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr | 0, 2, __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr | 0, 2);
  return $1;
}

function __ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray($this, $list, $array) {
  __ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray($this, $list, $array);
  return;
}

function __ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray($this, $list, $array) {
  HEAP32[$this >> 2] = $list;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  var $4 = $this + 12 | 0;
  __ZN16JSXMLArrayCursorC1EP10JSXMLArray($4, $array);
  return;
}

function __ZN16JSXMLArrayCursorC1EP10JSXMLArray($this, $array) {
  __ZN16JSXMLArrayCursorC2EP10JSXMLArray($this, $array);
  return;
}

function __ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380($cx, $clasp, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($1, $kind);
    var $3 = $2;
    if (($2 | 0) == 0) {
      var $obj_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $7 = $clasp;
    var $8 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($2, undef, $7, __ZN2js5types15emptyTypeObjectE, $8, 0, $6);
    var $9 = __ZNK2js5Class8isNativeEv($7);
    if ($9) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    var $11 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $3, $clasp, __ZN2js5types15emptyTypeObjectE, $kind);
    if ($11) {
      var $obj_0 = $3;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $obj_0 = 0;
    __label__ = 6;
    break;
   case 5:
    __ZN8JSObject21setSharedNonNativeMapEv($2);
    var $obj_0 = $3;
    __label__ = 6;
    break;
   case 6:
    var $obj_0;
    return $obj_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $obj, $clasp, $type, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
    var $5 = $obj;
    var $6 = __ZNK8JSObject8numSlotsEv($5);
    if ($4 >>> 0 > $6 >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = $obj;
    var $10 = $cx;
    var $11 = __ZN8JSObject10allocSlotsEP9JSContextj($9, $10, $4);
    if ($11) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 8;
      break;
    }
   case 3:
    var $13 = $type;
    var $14 = $clasp;
    var $15 = __ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE($13, $14);
    var $16 = $cx;
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $18 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($13, $16, $14, $kind);
    var $empty_0_in = $18;
    __label__ = 6;
    break;
   case 5:
    var $20 = __ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE($16, $14);
    var $empty_0_in = $20;
    __label__ = 6;
    break;
   case 6:
    var $empty_0_in;
    if (($empty_0_in | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    __ZN8JSObject6setMapEPN2js5ShapeE($5, $empty_0_in | 0);
    var $_0 = 1;
    __label__ = 8;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j($sb, $str, $str2, $prefix, $prefixlength, $suffix, $suffixlength) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $sb;
    var $2 = __ZN2js12StringBuffer6appendEPKtj($1, $prefix, $prefixlength);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    var $4 = __ZN2js12StringBuffer6appendEP8JSString($1, $str);
    if ($4) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 3:
    if (($str2 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = __ZNK8JSString5emptyEv($str2);
    if ($8) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = __ZN2js12StringBuffer6appendEt($1, 32);
    if ($10) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 6:
    var $12 = __ZN2js12StringBuffer6appendEP8JSString($1, $str2);
    if ($12) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $14 = __ZN2js12StringBuffer6appendEPKtj($1, $suffix, $suffixlength);
    if ($14) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $16 = $sb;
    var $17 = __ZN2js12StringBuffer12finishStringEv($16);
    var $_0 = $17 | 0;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, $clasp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $cx;
    var $2 = __ZNK9JSContext28runningWithTrustedPrincipalsEv($1);
    if ($2) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[_sE4XObjectsCreated >> 2] + 1 | 0;
    HEAP32[_sE4XObjectsCreated >> 2] = $5;
    __label__ = 3;
    break;
   case 3:
    var $7 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392($cx, $clasp);
    if (($7 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7;
    __ZN8JSObject19syncSpecialEqualityEv($10);
    __label__ = 5;
    break;
   case 5:
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392($cx, $clasp) {
  var $4 = HEAPU32[$clasp + 4 >> 2] >>> 8 & 255;
  var $5 = __ZN2js2gcL15GetGCObjectKindEjb4379($4);
  var $6 = __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393($cx, $clasp, $5);
  return $6;
}

function __ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393($cx, $clasp, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $global = __stackBase__;
    var $1 = __stackBase__ + 4;
    var $proto = __stackBase__ + 12;
    var $4 = HEAPU32[$clasp + 4 >> 2] >>> 24;
    var $5 = $cx;
    var $6 = __ZNK9JSContext5hasfpEv($5);
    if ($6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = HEAP32[$cx + 132 >> 2];
    HEAP32[$global >> 2] = $9;
    var $10 = $cx;
    var $11 = $global;
    var $12 = __Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject($10, $11);
    if ($12) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 3:
    var $20 = HEAP32[$global >> 2];
    __label__ = 5;
    break;
   case 4:
    var $14 = __ZNK9JSContext2fpEv($5);
    var $15 = __ZNK2js10StackFrame10scopeChainEv($14);
    var $16 = $15;
    var $17 = __ZNK8JSObject9getGlobalEv($16);
    var $18 = $17;
    HEAP32[$global >> 2] = $18;
    var $20 = $18;
    __label__ = 5;
    break;
   case 5:
    var $20;
    var $21 = $4 + 37 | 0;
    __ZNK8JSObject15getReservedSlotEj($1, $20, $21);
    var $23 = __ZNK2JS5Value8isObjectEv($1);
    if ($23) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $25 = __ZNK2JS5Value8toObjectEv($1);
    var $26 = $25;
    HEAP32[$proto >> 2] = $26;
    var $34 = $26;
    __label__ = 9;
    break;
   case 7:
    var $28 = $cx;
    var $30 = $proto;
    var $31 = $clasp;
    var $32 = __ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE($28, $20, $4, $30, $31);
    if ($32) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $34 = HEAP32[$proto >> 2];
    __label__ = 9;
    break;
   case 9:
    var $34;
    var $35 = __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394($cx, $clasp, $34, $20, $kind);
    var $_0 = $35;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394($cx, $clasp, $proto, $parent, $kind) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $proto;
    var $2 = $cx;
    var $3 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($1, $2, 0, 0);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($2, $kind);
    var $7 = $6;
    if (($6 | 0) == 0) {
      var $_0 = $7;
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = ($clasp | 0) == (__ZN2js10ArrayClassE | 0);
    var $11 = $clasp;
    var $12 = $parent;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($6, undef, $11, $3, $12, 0, $10);
    var $13 = __ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE($3, $2, $11, $kind);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $13 | 0;
    __ZN8JSObject6setMapEPN2js5ShapeE($6, $16);
    var $_0 = $7;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, $name, $bp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, $name, $v);
    if (($2 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = _JS_ValueToBoolean(undef, $1, $bp);
    var $10 = 1;
    __label__ = 3;
    break;
   case 3:
    var $10;
    STACKTOP = __stackBase__;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, $name, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = __Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE($1, 0, 11, $v, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $st$1$0 = $5 | 0;
    var $6$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $5 + 4 | 0;
    var $6$1 = HEAP32[$st$1$1 >> 2];
    var $7 = _JSVAL_IS_PRIMITIVE4303($6$0, $6$1);
    if (($7 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = _JSVAL_TO_OBJECT4304($6$0, $6$1);
    var $11 = $10;
    var $12 = __ZNK8JSObject10isFunctionEv($11);
    if ($12) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $14$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $14$1 = HEAP32[$st$1$1 >> 2];
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    var $_0 = 1;
    __label__ = 6;
    break;
   case 5:
    var $17 = _JSVAL_TO_OBJECT4304($6$0, $6$1);
    var $18 = $cx;
    var $19 = $17;
    var $20 = _JS_GetProperty($18, $19, $name, $vp);
    var $_0 = $20;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_IS_NULL4395($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_NULL_IMPL4400($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function _JSVAL_IS_VOID4396($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_UNDEFINED_IMPL4398($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL14ParseXMLSourceP9JSContextP8JSString($cx, $src) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1076;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nsval = __stackBase__;
    var $dstlen = __stackBase__ + 8;
    var $i = __stackBase__ + 12;
    var $parser = __stackBase__ + 52;
    var $flags = __stackBase__ + 1044;
    var $namespaces = __stackBase__ + 1048;
    var $1 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($1 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $nsval | 0;
    var $5$0 = HEAP32[$4 >> 2];
    var $5$1 = HEAP32[$4 + 4 >> 2];
    var $6 = _JSVAL_TO_OBJECT4304($5$0, $5$1);
    var $7 = __ZNK8JSObject10getNameURIEv($6);
    var $8 = $7 | 0;
    var $9 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $8, 0);
    var $10 = $9 | 0;
    if (($9 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = $9 | 0;
    var $14 = __ZNK8JSString6lengthEv($13);
    var $15 = __ZNK8JSString6lengthEv($src);
    var $17 = $15 + ($14 + 17) | 0;
    var $18 = $17 + 9 | 0;
    var $20 = ($17 << 1) + 20 | 0;
    var $21 = $cx;
    var $22 = __ZN9JSContext7malloc_Ej($21, $20);
    var $23 = $22;
    if (($22 | 0) == 0) {
      var $_1 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$dstlen >> 2] = $18;
    var $26 = $cx;
    var $27 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($26, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6prefix | 0, 15, $23, $dstlen);
    var $28 = HEAP32[$dstlen >> 2];
    var $30 = $23 + ($28 << 1) | 0;
    var $31 = __ZNK14JSLinearString5charsEv($10);
    var $32 = $31;
    var $33 = $14 << 1;
    _memcpy($30, $32, $33, 1);
    var $34 = $28 + $14 | 0;
    var $35 = $17 + 10 | 0;
    var $36 = $35 - $34 | 0;
    HEAP32[$dstlen >> 2] = $36;
    var $37 = $23 + ($34 << 1) | 0;
    var $38 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($26, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6middle | 0, 2, $37, $dstlen);
    var $40 = HEAP32[$dstlen >> 2] + $34 | 0;
    var $41 = __ZN8JSString8getCharsEP9JSContext($src, $21);
    if (($41 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZN9JSContext5free_EPv(undef, $22);
    var $_1 = 0;
    __label__ = 19;
    break;
   case 6:
    var $46 = $23 + ($40 << 1) | 0;
    var $47 = $41;
    var $48 = $15 << 1;
    _memcpy($46, $47, $48, 1);
    var $49 = $40 + $15 | 0;
    var $50 = $35 - $49 | 0;
    HEAP32[$dstlen >> 2] = $50;
    var $51 = $23 + ($49 << 1) | 0;
    var $52 = __ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj($26, STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6suffix | 0, 9, $51, $dstlen);
    HEAP16[$23 + (HEAP32[$dstlen >> 2] + $49 << 1) >> 1] = 0;
    __ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE($i, $21, 0);
    var $56 = __ZNK2js13FrameRegsIter4doneEv($i);
    if ($56) {
      var $lineno_2 = 1;
      var $filename_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $58 = __ZNK2js13FrameRegsIter2pcEv($i);
    if ((HEAP8[$58] + 78 & 255 & 255) < 2) {
      __label__ = 8;
      break;
    } else {
      var $lineno_2 = 1;
      var $filename_0 = 0;
      __label__ = 10;
      break;
    }
   case 8:
    var $62 = __ZNK2js13FrameRegsIter2fpEv($i);
    var $63 = __ZNK2js10StackFrame6scriptEv($62);
    var $65 = HEAP32[$63 + 52 >> 2];
    var $66 = $cx;
    var $67 = $62;
    var $68 = __Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh($66, $67, $58);
    var $69 = $41 + ($15 << 1) | 0;
    if (($15 | 0) > 0) {
      var $srcp_05 = $41;
      var $lineno_06 = $68;
      __label__ = 9;
      break;
    } else {
      var $lineno_2 = $68;
      var $filename_0 = $65;
      __label__ = 10;
      break;
    }
   case 9:
    var $lineno_06;
    var $srcp_05;
    var $_lineno_0 = ((HEAP16[$srcp_05 >> 1] << 16 >> 16 == 10) << 31 >> 31) + $lineno_06 | 0;
    var $74 = $srcp_05 + 2 | 0;
    if ($74 >>> 0 < $69 >>> 0) {
      var $srcp_05 = $74;
      var $lineno_06 = $_lineno_0;
      __label__ = 9;
      break;
    } else {
      var $lineno_2 = $_lineno_0;
      var $filename_0 = $65;
      __label__ = 10;
      break;
    }
   case 10:
    var $filename_0;
    var $lineno_2;
    var $76 = $parser;
    __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb($76, $21, 0, 0, 1);
    var $77 = __ZNK9JSContext11findVersionEv($21);
    var $78 = __ZN2js6Parser4initEPKtjPKcj9JSVersion($76, $23, $18, $filename_0, $lineno_2, $77);
    if ($78) {
      __label__ = 11;
      break;
    } else {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    }
   case 11:
    var $80 = __ZN2js13GetScopeChainEP9JSContext($21);
    if (($80 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $83 = __ZN2js6Parser12parseXMLTextEP8JSObjectb($76, $80, 0);
    if (($83 | 0) == 0) {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $86 = __ZL18GetXMLSettingFlagsP9JSContextPj($cx, $flags);
    if (($86 | 0) == 0) {
      var $xml_2_ph = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($namespaces, $cx);
    var $89 = $namespaces + 12 | 0;
    var $90 = __ZN10JSXMLArray11setCapacityEP9JSContextj($89, $cx, 1);
    if ($90) {
      __label__ = 15;
      break;
    } else {
      var $xml_0 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $92 = HEAP32[$flags >> 2];
    var $93 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $83, $89, $92);
    var $xml_0 = $93;
    __label__ = 16;
    break;
   case 16:
    var $xml_0;
    __ZN2js18AutoNamespaceArrayD1Ev($namespaces);
    var $xml_2_ph = $xml_0;
    __label__ = 18;
    break;
   case 17:
    __ZN9JSContext5free_EPv(undef, $22);
    __ZN2js6ParserD2Ev($76);
    var $_1 = 0;
    __label__ = 19;
    break;
   case 18:
    var $xml_2_ph;
    __ZN2js6ParserD2Ev($76);
    __ZN9JSContext5free_EPv(undef, $22);
    var $_1 = $xml_2_ph;
    __label__ = 19;
    break;
   case 19:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14ParseXMLSourceP9JSContextP8JSString["X"] = 1;

function __ZL14OrphanXMLChildP9JSContextP5JSXMLj($cx, $xml, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if ((HEAP32[$xml + 40 >> 2] | 0) == 0) {
      var $11 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $11 = HEAP32[HEAP32[$xml + 48 >> 2] >> 2];
    __label__ = 3;
    break;
   case 3:
    var $11;
    if (HEAPU32[$xml + 24 >> 2] >>> 0 > $i >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    var $19 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($i << 2) >> 2];
    var $20 = $19;
    if (($11 | 0) == 0 | ($19 | 0) == 0) {
      var $_0 = $20;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$19 + 16 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 6:
    var $29 = $19 + 40 | 0;
    var $30 = $29;
    var $32 = HEAP32[$29 >> 2];
    var $34 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $30, $32, $11);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $37$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $37$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $38 = $1 | 0;
    HEAP32[$38 >> 2] = $37$0;
    HEAP32[$38 + 4 >> 2] = $37$1;
    __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($11, $1);
    __label__ = 8;
    break;
   case 8:
    var $41 = $19 + 8 | 0;
    HEAP32[$41 >> 2] = 0;
    var $_0 = $20;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14OrphanXMLChildP9JSContextP5JSXMLj["X"] = 1;

function __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $array, $index, $elt) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $array + 4 | 0;
    if ((HEAP32[$5 >> 2] & 2147483647) >>> 0 > $index >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($index >>> 0 > 255) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $capacity_0 = $index + 32 & -32;
    __label__ = 8;
    break;
   case 5:
    if (($index + 1 | 0) >>> 0 < 2) {
      var $21 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $18 = _llvm_ctlz_i32($index);
    var $21 = 32 - $18 | 0;
    __label__ = 7;
    break;
   case 7:
    var $21;
    var $capacity_0 = 1 << $21;
    __label__ = 8;
    break;
   case 8:
    var $capacity_0;
    if ($capacity_0 >>> 0 > 1073741823) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $_pre_phi = $cx;
    __label__ = 11;
    break;
   case 10:
    var $26 = $array + 8 | 0;
    var $28 = HEAP32[$26 >> 2];
    var $30 = $cx;
    var $31 = __ZN9JSContext8realloc_EPvj($30, $28, $capacity_0 << 2);
    if (($31 | 0) == 0) {
      var $_pre_phi = $30;
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $_pre_phi;
    _JS_ReportOutOfMemory($_pre_phi);
    var $_0 = 0;
    __label__ = 16;
    break;
   case 12:
    var $35 = $31;
    HEAP32[$5 >> 2] = $capacity_0;
    HEAP32[$26 >> 2] = $35;
    var $36 = HEAPU32[$1 >> 2];
    if ($36 >>> 0 < $index >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $scevgep = $31 + ($36 << 2) | 0;
    var $40 = $index - $36 << 2;
    _memset($scevgep, 0, $40, 4);
    __label__ = 14;
    break;
   case 14:
    HEAP32[$1 >> 2] = $index + 1 | 0;
    __label__ = 15;
    break;
   case 15:
    var $44 = HEAP32[$array + 8 >> 2] + ($index << 2) | 0;
    HEAP32[$44 >> 2] = $elt;
    var $_0 = 1;
    __label__ = 16;
    break;
   case 16:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv["X"] = 1;

function __ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE($this, $0) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var tempParam = $0;
  $0 = STACKTOP;
  STACKTOP += 8;
  HEAP32[$0 >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$0 + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var $decl = __stackBase__;
  var $2 = $0 | 0;
  var $3$0 = HEAP32[$2 >> 2];
  var $3$1 = HEAP32[$2 + 4 >> 2];
  var $4 = $decl | 0;
  HEAP32[$4 >> 2] = $3$0;
  HEAP32[$4 + 4 >> 2] = $3$1;
  var $5 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($5, 2, $decl);
  STACKTOP = __stackBase__;
  return;
}

function __ZNK8JSObject10getNameURIEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 1);
    var $3 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($3) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($2);
    var $6 = __ZN8JSString8asLinearEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoNamespaceArrayC1EP9JSContext($this, $cx) {
  __ZN2js18AutoNamespaceArrayC2EP9JSContext($this, $cx);
  return;
}

function __ZL12IS_XML_CHARSPKt($chars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP16[$chars >> 1];
    if ($1 << 16 >> 16 == 120 || $1 << 16 >> 16 == 88) {
      __label__ = 2;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = HEAP16[$chars + 2 >> 1];
    if ($4 << 16 >> 16 == 109 || $4 << 16 >> 16 == 77) {
      __label__ = 3;
      break;
    } else {
      var $12 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = HEAP16[$chars + 4 >> 1];
    if ($7 << 16 >> 16 == 108) {
      var $12 = 1;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = $7 << 16 >> 16 == 76;
    __label__ = 5;
    break;
   case 5:
    var $12;
    return $12;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16HAS_NS_AFTER_XMLPKt($chars) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP16[$chars + 6 >> 1];
    if ($2 << 16 >> 16 == 110 || $2 << 16 >> 16 == 78) {
      __label__ = 2;
      break;
    } else {
      var $10 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $5 = HEAP16[$chars + 8 >> 1];
    if ($5 << 16 >> 16 == 115) {
      var $10 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $5 << 16 >> 16 == 83;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $pn, $inScopeNSes, $flags) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__ + 4;
    var $bytes = __stackBase__ + 12;
    var $v3 = __stackBase__ + 16;
    var $bytes4 = __stackBase__ + 24;
    var $v6 = __stackBase__ + 28;
    var $bytes7 = __stackBase__ + 36;
    var $2 = HEAPU32[$parser + 12 >> 2];
    if (__stackBase__ >>> 0 < HEAPU32[$2 + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = $parser + 40 | 0;
    var $10 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $9, $pn, 0, 26, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 103;
    break;
   case 3:
    var $12 = __ZNK11JSParseNode7getKindEv($pn);
    if (($12 | 0) == 75) {
      __label__ = 4;
      break;
    } else if (($12 | 0) == 76) {
      __label__ = 23;
      break;
    } else if (($12 | 0) == 59 || ($12 | 0) == 61) {
      __label__ = 37;
      break;
    } else if (($12 | 0) == 65 || ($12 | 0) == 66 || ($12 | 0) == 68 || ($12 | 0) == 67 || ($12 | 0) == 69) {
      __label__ = 84;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 4:
    var $15 = HEAP32[$inScopeNSes >> 2];
    var $17 = HEAPU32[$pn + 32 >> 2];
    var $18 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $17, $inScopeNSes, $flags);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $21 = $pn + 40 | 0;
    var $23 = HEAP32[$21 >> 2] - 2 | 0;
    var $24 = $18 + 24 | 0;
    var $25 = __ZN10JSXMLArray11setCapacityEP9JSContextj($24, $2, $23);
    if ($25) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 6:
    var $27 = ($flags & 4 | 0) != 0;
    var $28 = $24 | 0;
    var $29 = $18 + 32 | 0;
    var $pn2_0_ph = $17;
    var $n_0_ph = $23;
    var $i_0_ph = 0;
    __label__ = 7;
    break;
   case 7:
    var $i_0_ph;
    var $n_0_ph;
    var $pn2_0_ph;
    var $pn2_0 = $pn2_0_ph;
    var $n_0 = $n_0_ph;
    __label__ = 8;
    break;
   case 8:
    var $n_0;
    var $pn2_0;
    var $32 = HEAPU32[$pn2_0 + 24 >> 2];
    if (($32 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$32 + 24 >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $or_cond = $27 & $n_0 >>> 0 > 1;
    if ($or_cond) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    var $41 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($32, 65);
    if ($41) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $pn2_0 = $32;
    var $n_0 = $n_0 - 1 | 0;
    __label__ = 8;
    break;
   case 13:
    var $43 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $32, $inScopeNSes, $flags);
    var $magicptr = $43;
    if (($magicptr | 0) == 1) {
      __label__ = 12;
      break;
    } else if (($magicptr | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $_pre8 = $i_0_ph + 1 | 0;
    if (HEAPU32[$28 >> 2] >>> 0 > $i_0_ph >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$28 >> 2] = $_pre8;
    __label__ = 16;
    break;
   case 16:
    var $50 = HEAP32[$29 >> 2] + ($i_0_ph << 2) | 0;
    HEAP32[$50 >> 2] = $43;
    HEAP32[$43 + 8 >> 2] = $18;
    if ($or_cond) {
      __label__ = 17;
      break;
    } else {
      var $pn2_0_ph = $32;
      var $n_0_ph = $n_0;
      var $i_0_ph = $_pre8;
      __label__ = 7;
      break;
    }
   case 17:
    if ((HEAP32[$43 + 16 >> 2] | 0) == 4) {
      __label__ = 18;
      break;
    } else {
      var $pn2_0_ph = $32;
      var $n_0_ph = $n_0;
      var $i_0_ph = $_pre8;
      __label__ = 7;
      break;
    }
   case 18:
    var $57 = $43 + 24 | 0;
    var $59 = HEAP32[$57 >> 2];
    var $60 = __ZL18ChompXMLWhitespaceP9JSContextP8JSString($2, $59);
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $_c4 = $60;
    HEAP32[$57 >> 2] = $_c4;
    var $pn2_0_ph = $32;
    var $n_0_ph = $n_0;
    var $i_0_ph = $_pre8;
    __label__ = 7;
    break;
   case 20:
    if ($n_0 >>> 0 < (HEAP32[$21 >> 2] - 2 | 0) >>> 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 21:
    __ZN10JSXMLArray4trimEv($24);
    __label__ = 22;
    break;
   case 22:
    __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($2, $inScopeNSes, $15);
    var $_0 = $18;
    __label__ = 103;
    break;
   case 23:
    var $71 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 0);
    if (($71 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $74 = $pn + 40 | 0;
    var $75 = HEAP32[$74 >> 2];
    var $76 = $71 + 24 | 0;
    var $77 = __ZN10JSXMLArray11setCapacityEP9JSContextj($76, $2, $75);
    if ($77) {
      __label__ = 25;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 25:
    var $80 = $76 | 0;
    var $81 = $71 + 32 | 0;
    var $pn2_1_in = $pn + 32 | 0;
    var $n_1 = $75;
    var $i_1 = 0;
    __label__ = 26;
    break;
   case 26:
    var $i_1;
    var $n_1;
    var $pn2_1_in;
    var $pn2_1 = HEAPU32[$pn2_1_in >> 2];
    if (($pn2_1 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $85 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn2_1, 65);
    if ($85) {
      __label__ = 28;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 28:
    var $n_2 = $n_1 - 1 | 0;
    var $i_2 = $i_1;
    __label__ = 34;
    break;
   case 29:
    var $89 = __ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj($parser, $pn2_1, $inScopeNSes, $flags);
    var $magicptr6 = $89;
    if (($magicptr6 | 0) == 1) {
      __label__ = 30;
      break;
    } else if (($magicptr6 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $n_2 = $n_1 - 1 | 0;
    var $i_2 = $i_1;
    __label__ = 34;
    break;
   case 31:
    var $_pre9 = $i_1 + 1 | 0;
    if (HEAPU32[$80 >> 2] >>> 0 > $i_1 >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    HEAP32[$80 >> 2] = $_pre9;
    __label__ = 33;
    break;
   case 33:
    var $98 = HEAP32[$81 >> 2] + ($i_1 << 2) | 0;
    HEAP32[$98 >> 2] = $89;
    var $n_2 = $n_1;
    var $i_2 = $_pre9;
    __label__ = 34;
    break;
   case 34:
    var $i_2;
    var $n_2;
    var $pn2_1_in = $pn2_1 + 24 | 0;
    var $n_1 = $n_2;
    var $i_1 = $i_2;
    __label__ = 26;
    break;
   case 35:
    if ($n_1 >>> 0 < HEAPU32[$74 >> 2] >>> 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $71;
      __label__ = 103;
      break;
    }
   case 36:
    __ZN10JSXMLArray4trimEv($76);
    var $_0 = $71;
    __label__ = 103;
    break;
   case 37:
    var $106 = $inScopeNSes | 0;
    var $107 = HEAP32[$106 >> 2];
    var $108 = $pn + 32 | 0;
    var $109 = HEAPU32[$108 >> 2];
    var $110 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($109, 5);
    if ($110) {
      __label__ = 102;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $112 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 1);
    if (($112 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $118 = $109 + 24 | 0;
    var $119 = HEAPU32[$118 >> 2];
    var $120 = $2 + 52 | 0;
    var $121 = $112 + 40 | 0;
    var $122 = $121 | 0;
    var $123 = $2;
    var $inScopeNSes_idx1 = $inScopeNSes + 8 | 0;
    var $pnp_0_ph = $118;
    var $n_3_ph = HEAP32[$pn + 40 >> 2] - 1 | 0;
    var $124 = $119;
    __label__ = 40;
    break;
   case 40:
    var $124;
    var $n_3_ph;
    var $pnp_0_ph;
    var $pnp_0 = $pnp_0_ph;
    var $126 = $124;
    __label__ = 41;
    break;
   case 41:
    var $126;
    var $pnp_0;
    if (($126 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $129 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($126, 63);
    if ($129) {
      __label__ = 43;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 43:
    var $131 = __ZNK11JSParseNode7isArityE16JSParseNodeArity($126, 0);
    if ($131) {
      __label__ = 44;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 44:
    var $133 = $126 + 32 | 0;
    var $pn3_0 = $119;
    __label__ = 45;
    break;
   case 45:
    var $pn3_0;
    if (($pn3_0 | 0) == ($126 | 0)) {
      __label__ = 51;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    var $140 = HEAP32[$133 >> 2];
    if ((HEAP32[$pn3_0 + 32 >> 2] | 0) == ($140 | 0)) {
      __label__ = 47;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 47:
    var $143 = $140 | 0;
    __ZN2JSL11StringValueEP8JSString4311($v, $143);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $144 = $bytes;
    var $145 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($123, $v, $144, 0);
    if (($145 | 0) == 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 48:
    var $148 = $parser + 40 | 0;
    var $149 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $150 = $148;
    var $151 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $150, $126, 0, 198, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $149, tempInt));
    __label__ = 49;
    break;
   case 49:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 103;
    break;
   case 50:
    var $pn3_0 = HEAP32[HEAP32[$pn3_0 + 24 >> 2] + 24 >> 2];
    __label__ = 45;
    break;
   case 51:
    var $159 = HEAP32[$133 >> 2];
    var $161 = HEAPU32[$126 + 24 >> 2];
    var $162 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($161, 64);
    if ($162) {
      __label__ = 52;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 52:
    var $164 = $159 | 0;
    var $165 = __ZNK14JSLinearString5charsEv($164);
    var $166 = $159 | 0;
    var $167 = __ZNK8JSString6lengthEv($166);
    if ($167 >>> 0 > 4) {
      __label__ = 53;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 53:
    var $170 = __ZL12IS_XML_CHARSPKt($165);
    if ($170) {
      __label__ = 54;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 54:
    var $172 = __ZL16HAS_NS_AFTER_XMLPKt($165);
    if ($172) {
      __label__ = 55;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 55:
    if (($167 | 0) == 5) {
      __label__ = 57;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 56:
    if (HEAP16[$165 + 10 >> 1] << 16 >> 16 == 58) {
      __label__ = 58;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 57:
    var $prefix_0 = HEAP32[HEAP32[$120 >> 2] + 144136 >> 2] | 0;
    var $_pn = HEAP32[$161 + 32 >> 2];
    __label__ = 59;
    break;
   case 58:
    var $190 = HEAP32[$161 + 32 >> 2];
    var $191 = $165 + 12 | 0;
    var $192 = $167 - 6 | 0;
    var $193 = __Z17js_NewStringCopyNP9JSContextPKtj($123, $191, $192);
    var $194 = $193 | 0;
    if (($193 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      var $prefix_0 = $194;
      var $_pn = $190;
      __label__ = 59;
      break;
    }
   case 59:
    var $_pn;
    var $prefix_0;
    var $198 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($2, $prefix_0, $_pn | 0, 1);
    if (($198 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    var $201 = $198;
    var $inScopeNSes_idx_val = HEAP32[$106 >> 2];
    var $inScopeNSes_idx1_val = HEAP32[$inScopeNSes_idx1 >> 2];
    var $202 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($inScopeNSes_idx_val, $inScopeNSes_idx1_val, $201, 298);
    if (($202 | 0) == -1) {
      __label__ = 61;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 61:
    var $205 = HEAP32[$106 >> 2];
    var $206 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($2, $inScopeNSes, $205, $201);
    if (($206 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $209 = HEAP32[$122 >> 2];
    var $210 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($2, $121, $209, $201);
    if (($210 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $215 = HEAPU32[$161 + 24 >> 2];
    HEAP32[$pnp_0 >> 2] = $215;
    var $pnp_0_ph = $pnp_0;
    var $n_3_ph = $n_3_ph - 2 | 0;
    var $124 = $215;
    __label__ = 40;
    break;
   case 64:
    var $217 = $161 + 24 | 0;
    var $pnp_0 = $217;
    var $126 = HEAP32[$217 >> 2];
    __label__ = 41;
    break;
   case 65:
    __ZN10JSXMLArray4trimEv($121);
    var $219 = HEAPU32[$108 >> 2];
    var $220 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $219, $inScopeNSes, 0);
    if (($220 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    HEAP32[$112 + 12 >> 2] = $220;
    var $225 = $112 + 56 | 0;
    var $226 = __ZN10JSXMLArray11setCapacityEP9JSContextj($225, $2, $n_3_ph >>> 1);
    if ($226) {
      __label__ = 67;
      break;
    } else {
      var $_0 = 0;
      __label__ = 103;
      break;
    }
   case 67:
    var $227 = $112 + 64 | 0;
    var $228 = $225 | 0;
    var $pn2_2 = $219;
    var $i_3 = 0;
    __label__ = 68;
    break;
   case 68:
    var $i_3;
    var $pn2_2;
    var $231 = HEAPU32[$pn2_2 + 24 >> 2];
    if (($231 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $234 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $231, $inScopeNSes, 1);
    if (($234 | 0) == 0) {
      __label__ = 70;
      break;
    } else {
      var $j_0 = 0;
      __label__ = 71;
      break;
    }
   case 70:
    HEAP32[$228 >> 2] = $i_3;
    var $_0 = 0;
    __label__ = 103;
    break;
   case 71:
    var $j_0;
    if ($j_0 >>> 0 < $i_3 >>> 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 72:
    var $244 = HEAP32[HEAP32[HEAP32[$227 >> 2] + ($j_0 << 2) >> 2] + 12 >> 2];
    var $245 = __ZNK8JSObject10getNameURIEv($244);
    var $246 = __ZNK8JSObject10getNameURIEv($234);
    var $247 = __ZN2js12EqualStringsEP14JSLinearStringS1_($245, $246);
    if ($247) {
      __label__ = 73;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 73:
    var $249 = __ZNK8JSObject17getQNameLocalNameEv($244);
    var $250 = $249 | 0;
    var $251 = __ZNK8JSObject17getQNameLocalNameEv($234);
    var $252 = $251 | 0;
    var $253 = __ZN2js12EqualStringsEP14JSLinearStringS1_($250, $252);
    if ($253) {
      __label__ = 74;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 74:
    var $258 = HEAP32[$231 + 32 >> 2] | 0;
    __ZN2JSL11StringValueEP8JSString4311($v3, $258);
    __ZN16JSAutoByteStringC1Ev($bytes4);
    var $259 = $bytes4;
    var $260 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($123, $v3, $259, 0);
    if (($260 | 0) == 0) {
      __label__ = 76;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $263 = $parser + 40 | 0;
    var $264 = __ZNK16JSAutoByteString3ptrEv($bytes4);
    var $265 = $263;
    var $266 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $265, $231, 0, 198, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $264, tempInt));
    __label__ = 76;
    break;
   case 76:
    __ZN16JSAutoByteStringD1Ev($bytes4);
    var $_0 = 0;
    __label__ = 103;
    break;
   case 77:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 71;
    break;
   case 78:
    var $272 = HEAPU32[$231 + 24 >> 2];
    var $273 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, 2);
    if (($273 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $_pre11 = $i_3 + 1 | 0;
    if (HEAPU32[$228 >> 2] >>> 0 > $i_3 >>> 0) {
      __label__ = 81;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    HEAP32[$228 >> 2] = $_pre11;
    __label__ = 81;
    break;
   case 81:
    var $281 = HEAP32[$227 >> 2] + ($i_3 << 2) | 0;
    HEAP32[$281 >> 2] = $273;
    HEAP32[$273 + 8 >> 2] = $112;
    HEAP32[$273 + 12 >> 2] = $234;
    var $_c3 = HEAP32[$272 + 32 >> 2];
    HEAP32[$273 + 24 >> 2] = $_c3;
    var $pn2_2 = $272;
    var $i_3 = $_pre11;
    __label__ = 68;
    break;
   case 82:
    var $289 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 61);
    if ($289) {
      __label__ = 83;
      break;
    } else {
      var $_0 = $112;
      __label__ = 103;
      break;
    }
   case 83:
    __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($2, $inScopeNSes, $107);
    var $_0 = $112;
    __label__ = 103;
    break;
   case 84:
    var $294 = HEAP32[$pn + 32 >> 2];
    var $295 = $294 | 0;
    var $296 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 67);
    if ($296) {
      __label__ = 85;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 85:
    if (($flags & 1 | 0) == 0) {
      var $xml_class_0 = 5;
      var $qn_0 = 0;
      var $str_0 = $295;
      __label__ = 98;
      break;
    } else {
      var $_0 = 1;
      __label__ = 103;
      break;
    }
   case 86:
    var $301 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 69);
    if ($301) {
      __label__ = 87;
      break;
    } else {
      var $xml_class_0 = 4;
      var $qn_0 = 0;
      var $str_0 = $295;
      __label__ = 98;
      break;
    }
   case 87:
    var $303 = $294 | 0;
    var $304 = __ZNK8JSString6lengthEv($303);
    if (($304 | 0) == 3) {
      __label__ = 88;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 88:
    var $307 = __ZNK14JSLinearString5charsEv($295);
    var $308 = __ZL12IS_XML_CHARSPKt($307);
    if ($308) {
      __label__ = 89;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 89:
    __ZN2JSL11StringValueEP8JSString4311($v6, $303);
    __ZN16JSAutoByteStringC1Ev($bytes7);
    var $310 = $2;
    var $311 = $bytes7;
    var $312 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($310, $v6, $311, 0);
    if (($312 | 0) == 0) {
      __label__ = 91;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $315 = $parser + 40 | 0;
    var $316 = __ZNK16JSAutoByteString3ptrEv($bytes7);
    var $317 = $315;
    var $318 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $317, $pn, 0, 132, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $316, tempInt));
    __label__ = 91;
    break;
   case 91:
    __ZN16JSAutoByteStringD1Ev($bytes7);
    var $_0 = 0;
    __label__ = 103;
    break;
   case 92:
    if (($flags & 2 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      var $_0 = 1;
      __label__ = 103;
      break;
    }
   case 93:
    var $324 = __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $pn, $inScopeNSes, 0);
    if (($324 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    var $328 = HEAP32[$pn + 36 >> 2];
    if (($328 | 0) == 0) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    var $338 = $328;
    __label__ = 97;
    break;
   case 96:
    var $338 = HEAP32[HEAP32[$2 + 52 >> 2] + 144136 >> 2];
    __label__ = 97;
    break;
   case 97:
    var $338;
    var $xml_class_0 = 3;
    var $qn_0 = $324;
    var $str_0 = $338 | 0;
    __label__ = 98;
    break;
   case 98:
    var $str_0;
    var $qn_0;
    var $xml_class_0;
    var $341 = __Z9js_NewXMLP9JSContext10JSXMLClass($2, $xml_class_0);
    if (($341 | 0) == 0) {
      var $_0 = 0;
      __label__ = 103;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    HEAP32[$341 + 12 >> 2] = $qn_0;
    var $345 = __ZNK11JSParseNode6isKindEN2js9TokenKindE($pn, 65);
    if ($345) {
      __label__ = 100;
      break;
    } else {
      __label__ = 101;
      break;
    }
   case 100:
    var $347 = $341 + 20 | 0;
    var $349 = HEAP32[$347 >> 2] | 1;
    HEAP32[$347 >> 2] = $349;
    __label__ = 101;
    break;
   case 101:
    HEAP32[$341 + 24 >> 2] = $str_0;
    var $_0 = $341;
    __label__ = 103;
    break;
   case 102:
    var $353 = $parser + 40 | 0;
    var $354 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $353, $pn, 0, 170, (tempInt = STACKTOP, STACKTOP += 1, STACKTOP = STACKTOP + 3 >> 2 << 2, HEAP32[tempInt >> 2] = 0, tempInt));
    var $_0 = 0;
    __label__ = 103;
    break;
   case 103:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj["X"] = 1;

function __ZN2js18AutoNamespaceArrayD1Ev($this) {
  __ZN2js18AutoNamespaceArrayD2Ev($this);
  return;
}

function __ZN2js18AutoNamespaceArrayD2Ev($this) {
  var $1 = $this + 12 | 0;
  var $3 = HEAP32[$this + 8 >> 2];
  __ZN10JSXMLArray6finishEP9JSContext($1, $3);
  var $4 = $this;
  __ZN2js12AutoGCRooterD2Ev($4);
  return;
}

function __ZL18ChompXMLWhitespaceP9JSContextP8JSString($cx, $str) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSString6lengthEv($str);
    var $2 = $cx;
    var $3 = __ZN8JSString8getCharsEP9JSContext($str, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $3 + ($1 << 1) | 0;
    var $cp_0 = $3;
    __label__ = 3;
    break;
   case 3:
    var $cp_0;
    if ($cp_0 >>> 0 < $6 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $end_0 = $6;
      __label__ = 6;
      break;
    }
   case 4:
    var $10 = HEAP16[$cp_0 >> 1];
    var $11 = __ZN2js7unicode10IsXMLSpaceEt($10);
    if ($11) {
      __label__ = 5;
      break;
    } else {
      var $end_0 = $6;
      __label__ = 6;
      break;
    }
   case 5:
    var $cp_0 = $cp_0 + 2 | 0;
    __label__ = 3;
    break;
   case 6:
    var $end_0;
    if ($end_0 >>> 0 > $cp_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $16 = $end_0 - 2 | 0;
    var $17 = HEAP16[$16 >> 1];
    var $18 = __ZN2js7unicode10IsXMLSpaceEt($17);
    if ($18) {
      var $end_0 = $16;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $21 = $cp_0;
    var $23 = $end_0 - $21 >> 1;
    if (($23 | 0) == ($1 | 0)) {
      var $_0 = $str;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $28 = $21 - $3 >> 1;
    var $29 = $cx;
    var $30 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($29, $str, $28, $23);
    var $_0 = $30 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj($cx, $array, $length) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    if (HEAPU32[$1 >> 2] >>> 0 > $length >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $6 = $array + 8 | 0;
    var $7 = HEAPU32[$6 >> 2];
    if (($length | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 3:
    if (($7 | 0) == 0) {
      var $vector_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $7;
    __ZN9JSContext5free_EPv(undef, $11);
    var $vector_0 = 0;
    __label__ = 7;
    break;
   case 5:
    var $13 = $7;
    var $14 = $length << 2;
    var $15 = $cx;
    var $16 = __ZN9JSContext8realloc_EPvj($15, $13, $14);
    if (($16 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $vector_0 = $16;
    __label__ = 7;
    break;
   case 7:
    var $vector_0;
    if (HEAPU32[$1 >> 2] >>> 0 > $length >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$1 >> 2] = $length;
    __label__ = 9;
    break;
   case 9:
    HEAP32[$array + 4 >> 2] = $length;
    HEAP32[$6 >> 2] = $vector_0;
    __label__ = 10;
    break;
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($array_0_0_val, $array_0_2_val, $elt, $identity) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($identity | 0) == 0) {
      var $i_1 = 0;
      __label__ = 5;
      break;
    } else {
      var $i_0 = 0;
      __label__ = 2;
      break;
    }
   case 2:
    var $i_0;
    if ($i_0 >>> 0 < $array_0_0_val >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = -1;
      __label__ = 8;
      break;
    }
   case 3:
    var $5 = HEAP32[$array_0_2_val + ($i_0 << 2) >> 2];
    var $6 = FUNCTION_TABLE[$identity]($5, $elt);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $i_0;
      __label__ = 8;
      break;
    }
   case 4:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    var $i_1;
    if ($i_1 >>> 0 < $array_0_0_val >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = -1;
      __label__ = 8;
      break;
    }
   case 6:
    if ((HEAP32[$array_0_2_val + ($i_1 << 2) >> 2] | 0) == ($elt | 0)) {
      var $_0 = $i_1;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 5;
    break;
   case 8:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL18namespace_identityPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($1);
    var $4 = __ZNK8JSObject13getNamePrefixEv($2);
    var $_not = ($3 | 0) == 0;
    var $5 = ($4 | 0) == 0;
    if ($_not | $5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3, $4);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 3:
    if ($_not & $5) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $10 = __ZNK8JSObject10getNameURIEv($1);
    var $11 = __ZNK8JSObject10getNameURIEv($2);
    var $12 = __ZN2js12EqualStringsEP14JSLinearStringS1_($10, $11);
    var $_0 = $12 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSVAL_TO_STRING_IMPL4397($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _JSVAL_IS_UNDEFINED_IMPL4398($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -126) & 1;
}

function _JSVAL_IS_NULL_IMPL4400($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -122) & 1;
}

function _JSID_IS_INT4401($iden) {
  return $iden & 1;
}

function _JSID_TO_INT4402($iden) {
  return $iden >> 1;
}

function _JSID_IS_STRING4403($iden) {
  return ($iden & 7 | 0) == 0 & 1;
}

function _JSID_TO_STRING4405($iden) {
  return $iden;
}

function _JS_ASSERT_STRING_IS_FLAT($str) {
  return $str;
}

function __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($agg_result, $_0_0_0_val$0, $_0_0_0_val$1) {
  var $agg_result_0 = $agg_result | 0;
  HEAP32[$agg_result_0 >> 2] = $_0_0_0_val$0;
  HEAP32[$agg_result_0 + 4 >> 2] = $_0_0_0_val$1;
  return;
}

function __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($array, $index, $compress) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    var $2 = HEAPU32[$1 >> 2];
    if ($2 >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 2:
    var $6 = HEAP32[$array + 8 >> 2];
    if (($compress | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $index + 1 | 0;
    if ($8 >>> 0 < $2 >>> 0) {
      var $_011 = $index;
      var $10 = $8;
      __label__ = 4;
      break;
    } else {
      var $_lcssa = $8;
      __label__ = 5;
      break;
    }
   case 4:
    var $10;
    var $_011;
    var $12 = HEAP32[$6 + ($10 << 2) >> 2];
    var $13 = $6 + ($_011 << 2) | 0;
    HEAP32[$13 >> 2] = $12;
    var $14 = $10 + 1 | 0;
    if (($14 | 0) == ($2 | 0)) {
      var $_lcssa = $2;
      __label__ = 5;
      break;
    } else {
      var $_011 = $10;
      var $10 = $14;
      __label__ = 4;
      break;
    }
   case 5:
    var $_lcssa;
    HEAP32[$1 >> 2] = $2 - 1 | 0;
    var $16 = $array + 4 | 0;
    var $18 = HEAP32[$16 >> 2] & 2147483647;
    HEAP32[$16 >> 2] = $18;
    var $_1 = $_lcssa;
    __label__ = 7;
    break;
   case 6:
    var $20 = $6 + ($index << 2) | 0;
    HEAP32[$20 >> 2] = 0;
    var $_1 = $index;
    __label__ = 7;
    break;
   case 7:
    var $_1;
    var $cursor_02 = HEAP32[$array + 12 >> 2];
    if (($cursor_02 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $cursor_03 = $cursor_02;
      __label__ = 8;
      break;
    }
   case 8:
    var $cursor_03;
    var $24 = $cursor_03 + 4 | 0;
    var $25 = HEAPU32[$24 >> 2];
    if ($25 >>> 0 > $_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    HEAP32[$24 >> 2] = $25 - 1 | 0;
    __label__ = 10;
    break;
   case 10:
    var $cursor_0 = HEAPU32[$cursor_03 + 8 >> 2];
    if (($cursor_0 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      var $cursor_03 = $cursor_0;
      __label__ = 8;
      break;
    }
   case 11:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js16AutoObjectRooter9setObjectEP8JSObject($this, $obj) {
  HEAP32[$this + 12 >> 2] = $obj;
  return;
}

function __ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi($parser, $pn, $inScopeNSes, $isAttributeName) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $bytes = __stackBase__ + 8;
    var $1 = $parser + 12 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $5 = HEAPU32[$pn + 32 >> 2];
    var $6 = $5 | 0;
    var $7 = __ZNK14JSLinearString5charsEv($6);
    var $8 = $5 | 0;
    var $9 = __ZNK8JSString6lengthEv($8);
    var $13 = HEAPU32[HEAP32[$2 + 52 >> 2] + 144136 >> 2];
    var $14 = $13 | 0;
    var $15 = $7 + ($9 << 1) | 0;
    var $16 = __Z15js_strchr_limitPKttS0_($7, 58, $15);
    if (($16 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $22 = $16 - $7 >> 1;
    var $23 = $2;
    var $24 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($23, $8, 0, $22);
    if (($24 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($22 >>> 0 > 2) {
      __label__ = 4;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 4:
    var $29 = __ZL12IS_XML_CHARSPKt($7);
    if ($29) {
      __label__ = 5;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 5:
    if (($22 | 0) == 3) {
      __label__ = 6;
      break;
    } else if (($22 | 0) == 5) {
      __label__ = 7;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 6:
    var $32 = $2;
    var $33 = _JS_InternString($32, STRING_TABLE.__ZL17xml_namespace_str | 0);
    var $34 = _JS_ASSERT_STRING_IS_FLAT($33);
    var $35 = $34 | 0;
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $uri_0 = $35;
      __label__ = 16;
      break;
    }
   case 7:
    var $38 = __ZL16HAS_NS_AFTER_XMLPKt($7);
    if ($38) {
      __label__ = 8;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 8:
    var $40 = $2;
    var $41 = _JS_InternString($40, STRING_TABLE.__ZL19xmlns_namespace_str | 0);
    var $42 = _JS_ASSERT_STRING_IS_FLAT($41);
    var $43 = $42 | 0;
    if (($42 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      var $uri_0 = $43;
      __label__ = 16;
      break;
    }
   case 9:
    var $47 = HEAPU32[$inScopeNSes >> 2];
    var $48 = $inScopeNSes + 8 | 0;
    var $n_0 = $47;
    __label__ = 10;
    break;
   case 10:
    var $n_0;
    if (($n_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $51 = $n_0 - 1 | 0;
    if ($51 >>> 0 < $47 >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $59 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    var $59 = HEAP32[HEAP32[$48 >> 2] + ($51 << 2) >> 2];
    __label__ = 13;
    break;
   case 13:
    var $59;
    var $60 = __ZNK8JSObject13getNamePrefixEv($59);
    if (($60 | 0) == 0) {
      var $n_0 = $51;
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $63 = __ZN2js12EqualStringsEP14JSLinearStringS1_($60, $24);
    if ($63) {
      __label__ = 15;
      break;
    } else {
      var $n_0 = $51;
      __label__ = 10;
      break;
    }
   case 15:
    var $65 = __ZNK8JSObject10getNameURIEv($59);
    var $uri_0 = $65;
    __label__ = 16;
    break;
   case 16:
    var $uri_0;
    if (($uri_0 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 17:
    var $68 = $24 | 0;
    __ZN2JSL11StringValueEP8JSString4311($v, $68);
    __ZN16JSAutoByteStringC1Ev($bytes);
    var $70 = HEAP32[$1 >> 2];
    var $71 = $bytes;
    var $72 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($70, $v, $71, 0);
    if (($72 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $75 = $parser + 40 | 0;
    var $76 = __ZNK16JSAutoByteString3ptrEv($bytes);
    var $77 = $75;
    var $78 = __ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz(undef, $77, $pn, 0, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $76, tempInt));
    __label__ = 19;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 32;
    break;
   case 20:
    var $82 = $16 + 2 | 0;
    var $83 = $9 - 1 - $22 | 0;
    var $84 = HEAP32[$1 >> 2];
    var $85 = __Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE($84, $82, $83, 0);
    if (($85 | 0) == 0) {
      var $_0 = 0;
      __label__ = 32;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $localName_0 = $85;
    var $prefix_1 = $24;
    var $uri_3 = $uri_0;
    var $118 = HEAP32[$1 >> 2];
    __label__ = 31;
    break;
   case 22:
    if (($isAttributeName | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $localName_0 = $5;
      var $prefix_1 = $14;
      var $uri_3 = $14;
      var $118 = $2;
      __label__ = 31;
      break;
    }
   case 23:
    var $92 = HEAPU32[$inScopeNSes >> 2];
    var $93 = $inScopeNSes + 8 | 0;
    var $n_1 = $92;
    __label__ = 24;
    break;
   case 24:
    var $n_1;
    if (($n_1 | 0) == 0) {
      var $uri_1 = $14;
      __label__ = 30;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $97 = $n_1 - 1 | 0;
    if ($97 >>> 0 < $92 >>> 0) {
      __label__ = 26;
      break;
    } else {
      var $105 = 0;
      __label__ = 27;
      break;
    }
   case 26:
    var $105 = HEAP32[HEAP32[$93 >> 2] + ($97 << 2) >> 2];
    __label__ = 27;
    break;
   case 27:
    var $105;
    var $106 = __ZNK8JSObject13getNamePrefixEv($105);
    if (($106 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $109 = $106 | 0;
    var $110 = __ZNK8JSString5emptyEv($109);
    if ($110) {
      __label__ = 29;
      break;
    } else {
      var $n_1 = $97;
      __label__ = 24;
      break;
    }
   case 29:
    var $112 = __ZNK8JSObject10getNameURIEv($105);
    var $uri_1 = $112;
    __label__ = 30;
    break;
   case 30:
    var $uri_1;
    var $114 = __ZNK8JSString5emptyEv($uri_1 | 0);
    var $115 = $114 ? $13 : 0;
    var $localName_0 = $5;
    var $prefix_1 = $115 | 0;
    var $uri_3 = $uri_1;
    var $118 = $2;
    __label__ = 31;
    break;
   case 31:
    var $118;
    var $uri_3;
    var $prefix_1;
    var $localName_0;
    var $119 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($118, $uri_3, $prefix_1, $localName_0);
    var $_0 = $119;
    __label__ = 32;
    break;
   case 32:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi["X"] = 1;

function __ZNK8JSObject13getNamePrefixEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZNK8JSObject7getSlotEj($1, 0);
    var $3 = __ZNK2JS5Value11isUndefinedEv($2);
    if ($3) {
      var $8 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = __ZNK2JS5Value8toStringEv($2);
    var $6 = __ZN8JSString8asLinearEv($5);
    var $8 = $6;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js18AutoNamespaceArrayC2EP9JSContext($this, $cx) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $2, -8);
  var $3 = $this + 12 | 0;
  __ZN10JSXMLArray4initEv($3);
  return;
}

function __ZN9JSContext7delete_I11JSXMLFilterEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN11JSXMLFilterD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11JSXMLFilterD1Ev($this) {
  __ZN11JSXMLFilterD2Ev($this);
  return;
}

function __ZN11JSXMLFilterD2Ev($this) {
  var $1 = $this + 12 | 0;
  __ZN16JSXMLArrayCursorD1Ev($1);
  return;
}

function __ZN16JSXMLArrayCursorD1Ev($this) {
  __ZN16JSXMLArrayCursorD2Ev($this);
  return;
}

function __ZN16JSXMLArrayCursorD2Ev($this) {
  __ZN16JSXMLArrayCursor10disconnectEv($this);
  return;
}

function __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($xml, $nameqn, $attributes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 2:
    var $3 = $xml + 24 | 0;
    var $4 = HEAP32[$3 >> 2];
    if (($4 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $xml + 32 | 0;
    var $index_06 = 0;
    var $7 = $4;
    __label__ = 4;
    break;
   case 4:
    var $7;
    var $index_06;
    var $10 = HEAP32[HEAP32[$6 >> 2] + ($index_06 << 2) >> 2];
    var $11 = $10;
    if (($10 | 0) == 0) {
      var $20 = $7;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$10 + 16 >> 2] | 0) == 1) {
      __label__ = 6;
      break;
    } else {
      var $20 = $7;
      __label__ = 7;
      break;
    }
   case 6:
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($11, $nameqn, $attributes);
    var $20 = HEAP32[$3 >> 2];
    __label__ = 7;
    break;
   case 7:
    var $20;
    var $21 = $index_06 + 1 | 0;
    if ($21 >>> 0 < $20 >>> 0) {
      var $index_06 = $21;
      var $7 = $20;
      __label__ = 4;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 8:
    var $24 = ($attributes | 0) == 0;
    var $array_0 = $24 ? $xml + 24 | 0 : $xml + 56 | 0;
    var $matcher_0 = $24 ? 296 : 294;
    var $27 = $array_0 | 0;
    if ((HEAP32[$27 >> 2] | 0) == 0) {
      var $deleteCount_0_lcssa = 0;
      var $_lcssa1 = 0;
      __label__ = 18;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $array_0 + 8 | 0;
    var $index_12 = 0;
    var $deleteCount_03 = 0;
    __label__ = 10;
    break;
   case 10:
    var $deleteCount_03;
    var $index_12;
    var $33 = HEAP32[HEAP32[$30 >> 2] + ($index_12 << 2) >> 2];
    if (($33 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $33;
    var $37 = FUNCTION_TABLE[$matcher_0]($nameqn, $36);
    if (($37 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = $33 + 8 | 0;
    HEAP32[$41 >> 2] = 0;
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($array_0, $index_12, 0);
    var $deleteCount_1 = $deleteCount_03 + 1 | 0;
    __label__ = 17;
    break;
   case 13:
    if (($deleteCount_03 | 0) == 0) {
      var $deleteCount_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $47 = $index_12 - $deleteCount_03 | 0;
    if (HEAPU32[$27 >> 2] >>> 0 > $47 >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP32[$27 >> 2] = $47 + 1 | 0;
    __label__ = 16;
    break;
   case 16:
    var $51 = HEAP32[$30 >> 2];
    var $53 = HEAP32[$51 + ($index_12 << 2) >> 2];
    var $54 = $51 + ($47 << 2) | 0;
    HEAP32[$54 >> 2] = $53;
    var $deleteCount_1 = $deleteCount_03;
    __label__ = 17;
    break;
   case 17:
    var $deleteCount_1;
    var $55 = $index_12 + 1 | 0;
    var $56 = HEAPU32[$27 >> 2];
    if ($55 >>> 0 < $56 >>> 0) {
      var $index_12 = $55;
      var $deleteCount_03 = $deleteCount_1;
      __label__ = 10;
      break;
    } else {
      var $deleteCount_0_lcssa = $deleteCount_1;
      var $_lcssa1 = $56;
      __label__ = 18;
      break;
    }
   case 18:
    var $_lcssa1;
    var $deleteCount_0_lcssa;
    HEAP32[$27 >> 2] = $_lcssa1 - $deleteCount_0_lcssa | 0;
    __label__ = 19;
    break;
   case 19:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti["X"] = 1;

function __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    var $5 = $xml + 24 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    var $13 = HEAP32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $17 = $13 + 8 | 0;
    HEAP32[$17 >> 2] = 0;
    __label__ = 5;
    break;
   case 5:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($5, $index, 1);
    __label__ = 6;
    break;
   case 6:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MatchAttrNameP8JSObjectP5JSXML($nameqn, $attr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$attr + 12 >> 2];
    var $3 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $4 = $3 | 0;
    var $5 = $3 | 0;
    var $6 = __ZNK8JSString6lengthEv($5);
    if (($6 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = __ZNK14JSLinearString5charsEv($4);
    if (HEAP16[$9 >> 1] << 16 >> 16 == 42) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __ZNK8JSObject17getQNameLocalNameEv($2);
    var $14 = $13 | 0;
    var $15 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $4);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      var $23 = 0;
      __label__ = 6;
      break;
    }
   case 4:
    var $17 = __ZNK8JSObject10getNameURIEv($nameqn);
    if (($17 | 0) == 0) {
      var $23 = 1;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $20 = __ZNK8JSObject10getNameURIEv($2);
    var $21 = __ZN2js12EqualStringsEP14JSLinearStringS1_($20, $17);
    var $23 = $21;
    __label__ = 6;
    break;
   case 6:
    var $23;
    return $23 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $elem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $2 = $1 | 0;
    var $3 = $1 | 0;
    var $4 = __ZNK8JSString6lengthEv($3);
    if (($4 | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = __ZNK14JSLinearString5charsEv($2);
    if (HEAP16[$7 >> 1] << 16 >> 16 == 42) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$elem + 16 >> 2] | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $33 = 0;
      __label__ = 8;
      break;
    }
   case 4:
    var $16 = HEAP32[$elem + 12 >> 2];
    var $17 = __ZNK8JSObject17getQNameLocalNameEv($16);
    var $18 = $17 | 0;
    var $19 = __ZN2js12EqualStringsEP14JSLinearStringS1_($18, $2);
    if ($19) {
      __label__ = 5;
      break;
    } else {
      var $33 = 0;
      __label__ = 8;
      break;
    }
   case 5:
    var $21 = __ZNK8JSObject10getNameURIEv($nameqn);
    if (($21 | 0) == 0) {
      var $33 = 1;
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$elem + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $33 = 0;
      __label__ = 8;
      break;
    }
   case 7:
    var $29 = HEAP32[$elem + 12 >> 2];
    var $30 = __ZNK8JSObject10getNameURIEv($29);
    var $31 = __ZN2js12EqualStringsEP14JSLinearStringS1_($30, $21);
    var $33 = $31;
    __label__ = 8;
    break;
   case 8:
    var $33;
    return $33 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funidp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $index = __stackBase__ + 8;
    var $1 = __stackBase__ + 12;
    var $2 = __stackBase__ + 20;
    var $bytes = __stackBase__ + 28;
    var $3 = __stackBase__ + 32;
    var $4 = $v | 0;
    var $st$7$0 = $4 | 0;
    HEAP32[$st$7$0 >> 2] = $_0_0_0_val$0;
    var $st$7$1 = $4 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $_0_0_0_val$1;
    var $5 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    var $7$0 = HEAP32[$4 >> 2];
    var $7$1 = HEAP32[$4 + 4 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = _JSVAL_TO_STRING4321($7$0, $7$1);
    var $name_0 = $9;
    __label__ = 9;
    break;
   case 3:
    var $11 = _JSVAL_IS_PRIMITIVE4303($7$0, $7$1);
    if (($11 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $v);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 5:
    var $15$0 = HEAP32[$4 >> 2];
    var $15$1 = HEAP32[$4 + 4 >> 2];
    var $16 = _JSVAL_TO_OBJECT4304($15$0, $15$1);
    var $17 = $16;
    var $18 = __ZNK8JSObject8getClassEv($17);
    if (($18 | 0) == (__ZN2js18AttributeNameClassE | 0) | ($18 | 0) == (__ZN2js10QNameClassE | 0)) {
      var $obj_0 = $16;
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($18 | 0) == (__ZN2js12AnyNameClassE | 0)) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $name_1 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    __label__ = 14;
    break;
   case 8:
    var $30 = $cx;
    var $31 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($30, $v);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $name_0 = $31;
      __label__ = 9;
      break;
    }
   case 9:
    var $name_0;
    var $34 = $cx;
    var $35 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($34, $name_0, 0);
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $38 = $35;
    var $39 = __ZL12ATOM_TO_JSIDP6JSAtom4336($38);
    var $40 = __Z12js_IdIsIndexiPj($39, $index);
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 11:
    var $43 = $35 | 0;
    var $44 = __ZNK14JSLinearString5charsEv($43);
    if (HEAP16[$44 >> 1] << 16 >> 16 == 64) {
      __label__ = 12;
      break;
    } else {
      var $name_1 = $name_0;
      __label__ = 14;
      break;
    }
   case 12:
    var $48 = __ZNK8JSString6lengthEv($name_0);
    var $49 = $48 - 1 | 0;
    var $50 = $cx;
    var $51 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($50, $name_0, 1, $49);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $54 = $51 | 0;
    HEAP32[$funidp >> 2] = 2;
    _STRING_TO_JSVAL4322($1, $54);
    var $_idx4 = $1 | 0;
    var $_idx4_val$0 = HEAP32[$_idx4 >> 2];
    var $_idx4_val$1 = HEAP32[$_idx4 + 4 >> 2];
    var $55 = __ZL15ToAttributeNameP9JSContextN2JS5ValueE($cx, $_idx4_val$0, $_idx4_val$1);
    var $_0 = $55;
    __label__ = 20;
    break;
   case 14:
    var $name_1;
    _STRING_TO_JSVAL4322($2, $name_1);
    var $57 = $2 | 0;
    var $58$0 = HEAP32[$57 >> 2];
    var $58$1 = HEAP32[$57 + 4 >> 2];
    var $st$7$0 = $4 | 0;
    HEAP32[$st$7$0 >> 2] = $58$0;
    var $st$7$1 = $4 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $58$1;
    var $59 = $cx;
    var $60 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($59, __ZN2js10QNameClassE, 0, 0, 1, $v);
    var $61 = $60;
    if (($60 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      var $obj_0 = $61;
      __label__ = 15;
      break;
    }
   case 15:
    var $obj_0;
    var $64 = __ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext($obj_0, $funidp, $cx);
    if ($64) {
      var $_0 = $obj_0;
      __label__ = 20;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$funidp >> 2] = 2;
    var $_0 = $obj_0;
    __label__ = 20;
    break;
   case 17:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2JSL11StringValueEP8JSString4311($3, $name_0);
    var $67 = $cx;
    var $68 = $bytes;
    var $69 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($67, $3, $68, 0);
    if (($69 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $72 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($34, 2, 0, 179, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $72, tempInt));
    __label__ = 19;
    break;
   case 19:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 20;
    break;
   case 20:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ToXMLNameP9JSContextN2JS5ValueEPi["X"] = 1;

function __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $nameqn, $list) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 25;
    break;
   case 3:
    var $8 = $xml + 16 | 0;
    var $9 = HEAPU32[$8 >> 2];
    if (($9 | 0) == 1) {
      __label__ = 4;
      break;
    } else {
      var $37 = $9;
      __label__ = 13;
      break;
    }
   case 4:
    var $12 = $nameqn;
    var $13 = __ZNK8JSObject8getClassEv($12);
    if (($13 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 5:
    var $16 = $xml + 56 | 0;
    var $17 = HEAPU32[$16 >> 2];
    var $18 = $xml + 64 | 0;
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    if ($i_0 >>> 0 < $17 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$16 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $27 = HEAP32[HEAP32[$18 >> 2] + ($i_0 << 2) >> 2];
    var $28 = $27;
    if (($27 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $31 = __ZL13MatchAttrNameP8JSObjectP5JSXML($nameqn, $28);
    if (($31 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $28);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 6;
    break;
   case 12:
    var $37 = HEAP32[$8 >> 2];
    __label__ = 13;
    break;
   case 13:
    var $37;
    if ($37 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $42 = 0;
    var $_pre_phi = $xml + 24 | 0;
    __label__ = 16;
    break;
   case 15:
    var $39 = $xml + 24 | 0;
    var $42 = HEAP32[$39 >> 2];
    var $_pre_phi = $39;
    __label__ = 16;
    break;
   case 16:
    var $_pre_phi;
    var $42;
    var $43 = $xml + 32 | 0;
    var $44 = $nameqn;
    var $i_1 = 0;
    __label__ = 17;
    break;
   case 17:
    var $i_1;
    if ($i_1 >>> 0 < $42 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = 1;
      __label__ = 25;
      break;
    }
   case 18:
    if ($i_1 >>> 0 < HEAPU32[$_pre_phi >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 19:
    var $53 = HEAP32[HEAP32[$43 >> 2] + ($i_1 << 2) >> 2];
    var $54 = $53;
    if (($53 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $57 = __ZNK8JSObject8getClassEv($44);
    if (($57 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $60 = __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $54);
    if (($60 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $63 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $54);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $66 = __ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_($cx, $54, $nameqn, $list);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 17;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_["X"] = 1;

function __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $idval) {
  var $1 = $cx;
  var $2 = __Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_($1, 0, 179, 0, $idval, 0, 0, 0);
  return;
}

function __ZN2JSL14UndefinedValueEv4406($agg_result) {
  __ZN2JS5Value12setUndefinedEv($agg_result);
  return;
}

function _JSVAL_IS_BOOLEAN4407($_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZL13JSVAL_TO_IMPLN2JS5ValueE4399($1, $_0_0_0_val$0, $_0_0_0_val$1);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  var $2 = _JSVAL_IS_BOOLEAN_IMPL4410($_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return $2;
}

function __ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408($cx, $vp) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value11isPrimitiveEv($vp);
    if ($1) {
      var $_0 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($vp);
    var $4 = $3;
    var $5 = $cx;
    var $6 = __ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE($4, $5, 3, $vp);
    var $_0 = $6;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2js18AutoNamespaceArray6lengthEv($this) {
  return HEAP32[$this + 12 >> 2];
}

function __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $xml, $ancestorNSes, $indentLevel) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 272;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $pretty = __stackBase__;
    var $sb = __stackBase__ + 4;
    var $i = __stackBase__ + 84;
    var $empty = __stackBase__ + 88;
    var $decls = __stackBase__ + 116;
    var $ancdecls = __stackBase__ + 144;
    var $cursor = __stackBase__ + 172;
    var $cursor1 = __stackBase__ + 192;
    var $cursor3 = __stackBase__ + 212;
    var $cursor5 = __stackBase__ + 232;
    var $cursor8 = __stackBase__ + 252;
    var $1 = $sb;
    var $2 = $cx;
    __ZN2js12StringBufferC1EP9JSContext($1, $2);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($empty, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($decls, $cx);
    __ZN2js18AutoNamespaceArrayC1EP9JSContext($ancdecls, $cx);
    var $3 = __ZL20GetBooleanXMLSettingP9JSContextPKcPi($cx, STRING_TABLE.__ZL21js_prettyPrinting_str | 0, $pretty);
    if (($3 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = (HEAP32[$pretty >> 2] | 0) == 0;
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = $indentLevel & 2147483647;
    var $10 = $sb;
    var $11 = __ZN2js12StringBuffer7appendNEtj($10, 32, $9);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 4:
    var $14 = HEAP32[$xml + 16 >> 2];
    if (($14 | 0) == 4) {
      __label__ = 5;
      break;
    } else if (($14 | 0) == 2) {
      __label__ = 8;
      break;
    } else if (($14 | 0) == 5) {
      __label__ = 9;
      break;
    } else if (($14 | 0) == 3) {
      __label__ = 10;
      break;
    } else if (($14 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 5:
    var $18 = HEAP32[$xml + 24 >> 2];
    if ($7) {
      var $str_0 = $18;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = __ZL18ChompXMLWhitespaceP9JSContextP8JSString($cx, $18);
    if (($20 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $str_0 = $20;
      __label__ = 7;
      break;
    }
   case 7:
    var $str_0;
    var $23 = $indentLevel & -2147483648;
    var $24 = __ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj($cx, $sb, $str_0, $23);
    var $_1 = $24 | 0;
    __label__ = 115;
    break;
   case 8:
    var $29 = HEAP32[$xml + 24 >> 2];
    var $indentLevel_lobit = $indentLevel >>> 31;
    var $30 = __ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi($cx, $sb, $29, $indentLevel_lobit);
    var $_1 = $30 | 0;
    __label__ = 115;
    break;
   case 9:
    var $35 = HEAP32[$xml + 24 >> 2];
    var $36 = __ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString($sb, $35);
    var $_1 = $36 | 0;
    __label__ = 115;
    break;
   case 10:
    var $40 = HEAP32[$xml + 12 >> 2];
    var $41 = __ZNK8JSObject17getQNameLocalNameEv($40);
    var $42 = $41 | 0;
    var $45 = HEAP32[$xml + 24 >> 2];
    var $46 = __ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_($sb, $42, $45);
    var $_1 = $46 | 0;
    __label__ = 115;
    break;
   case 11:
    var $49 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $49);
    var $storemerge = 0;
    __label__ = 12;
    break;
   case 12:
    var $storemerge;
    var $51 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $52 = $51;
    if (($51 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($7 | ($storemerge | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($57) {
      __label__ = 15;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 15:
    var $59 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $52, $ancestorNSes, $indentLevel);
    if (($59 | 0) == 0) {
      __label__ = 113;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $62 = __ZN2js12StringBuffer6appendEP8JSString($1, $59);
    if ($62) {
      __label__ = 17;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 17:
    var $storemerge = $storemerge + 1 | 0;
    __label__ = 12;
    break;
   case 18:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $66 = __ZNK2js12StringBuffer5emptyEv($1);
    if ($66) {
      __label__ = 19;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 19:
    var $_1 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 115;
    break;
   case 20:
    var $74 = $sb;
    var $75 = __ZN2js12StringBuffer12finishStringEv($74);
    var $_1 = $75 | 0;
    __label__ = 115;
    break;
   case 21:
    var $_03 = ($ancestorNSes | 0) == 0 ? $empty + 12 | 0 : $ancestorNSes;
    var $80 = $xml + 40 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor1, $80);
    var $81 = $decls + 12 | 0;
    var $82 = $81 | 0;
    var $_03_idx = $_03 | 0;
    var $_03_idx2 = $_03 + 8 | 0;
    __label__ = 22;
    break;
   case 22:
    var $83 = __ZN16JSXMLArrayCursor7getNextEv($cursor1);
    var $84 = $83;
    if (($83 | 0) == 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $87 = __ZL10IsDeclaredPK8JSObject($84);
    if (($87 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $_03_idx_val = HEAP32[$_03_idx >> 2];
    var $_03_idx2_val = HEAP32[$_03_idx2 >> 2];
    var $90 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_03_idx_val, $_03_idx2_val, $83, 298);
    if (($90 | 0) == -1) {
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 25:
    var $93 = __ZNK8JSObject13getNamePrefixEv($84);
    var $94 = __ZNK8JSObject10getNameURIEv($84);
    var $95 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $93, $94, 1);
    if (($95 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $98 = HEAP32[$82 >> 2];
    var $99 = $95;
    var $100 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $98, $99);
    if (($100 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 27:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 28:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $103 = $ancdecls + 12 | 0;
    var $104 = HEAP32[$_03_idx >> 2];
    var $105 = __ZNK2js18AutoNamespaceArray6lengthEv($decls);
    var $106 = $105 + $104 | 0;
    var $107 = __ZN10JSXMLArray11setCapacityEP9JSContextj($103, $cx, $106);
    if ($107) {
      __label__ = 29;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 29:
    HEAP32[$i >> 2] = 0;
    var $109 = HEAPU32[$_03_idx >> 2];
    var $110 = $103 | 0;
    var $112 = 0;
    __label__ = 30;
    break;
   case 30:
    var $112;
    if ($112 >>> 0 < $109 >>> 0) {
      __label__ = 31;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 31:
    if ($112 >>> 0 < HEAPU32[$_03_idx >> 2] >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    var $120 = HEAPU32[HEAP32[$_03_idx2 >> 2] + ($112 << 2) >> 2];
    if (($120 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $123 = HEAP32[$110 >> 2];
    var $124 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $123, $120);
    if (($124 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $126 = $112 + 1 | 0;
    HEAP32[$i >> 2] = $126;
    var $112 = $126;
    __label__ = 30;
    break;
   case 35:
    HEAP32[$i >> 2] = 0;
    var $128 = __ZNK2js18AutoNamespaceArray6lengthEv($decls);
    var $129 = $decls + 12 | 0;
    var $130 = $decls + 20 | 0;
    var $132 = 0;
    __label__ = 36;
    break;
   case 36:
    var $132;
    if ($132 >>> 0 < $128 >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 37:
    if ($132 >>> 0 < HEAPU32[$129 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 38:
    var $140 = HEAPU32[HEAP32[$130 >> 2] + ($132 << 2) >> 2];
    if (($140 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $143 = HEAP32[$110 >> 2];
    var $144 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $143, $140);
    if (($144 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $146 = $132 + 1 | 0;
    HEAP32[$i >> 2] = $146;
    var $132 = $146;
    __label__ = 36;
    break;
   case 41:
    var $148 = $xml + 12 | 0;
    var $149 = HEAP32[$148 >> 2];
    var $150 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $149, $103);
    if (($150 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $153 = __ZNK8JSObject13getNamePrefixEv($150);
    if (($153 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      var $ns_0 = $150;
      var $prefix_1 = $153;
      __label__ = 52;
      break;
    }
   case 43:
    var $156 = __ZNK8JSObject10getNameURIEv($150);
    var $157 = HEAP32[$148 >> 2];
    var $158 = __ZNK8JSObject13getNamePrefixEv($157);
    if (($158 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 44:
    var $prefix_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 46;
    break;
   case 45:
    var $167 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $156, $103);
    if (($167 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $prefix_0 = $167;
      __label__ = 46;
      break;
    }
   case 46:
    var $prefix_0;
    var $170 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $prefix_0, $156, 1);
    if (($170 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    var $174 = __ZNK8JSString5emptyEv($prefix_0 | 0);
    var $175 = $170;
    if ($174) {
      __label__ = 48;
      break;
    } else {
      var $_pre_phi = $175;
      __label__ = 50;
      break;
    }
   case 48:
    var $_idx_val = HEAP32[$82 >> 2];
    var $_idx1_val = HEAP32[$130 >> 2];
    var $177 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $175, 282);
    HEAP32[$i >> 2] = $177;
    if (($177 | 0) == -1) {
      var $_pre_phi = $175;
      __label__ = 50;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($81, $177, 1);
    var $_pre_phi = $175;
    __label__ = 50;
    break;
   case 50:
    var $_pre_phi;
    var $180 = HEAP32[$110 >> 2];
    var $181 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $180, $_pre_phi);
    if (($181 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 51:
    var $184 = HEAP32[$82 >> 2];
    var $185 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $184, $_pre_phi);
    if (($185 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      var $ns_0 = $170;
      var $prefix_1 = $prefix_0;
      __label__ = 52;
      break;
    }
   case 52:
    var $prefix_1;
    var $ns_0;
    var $188 = __ZN2js12StringBuffer6appendEt($1, 60);
    if ($188) {
      __label__ = 53;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 53:
    var $190 = $prefix_1 | 0;
    var $191 = __ZNK8JSString5emptyEv($190);
    if ($191) {
      __label__ = 56;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $193 = __ZN2js12StringBuffer6appendEP8JSString($1, $190);
    if ($193) {
      __label__ = 55;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 55:
    var $195 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($195) {
      __label__ = 56;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 56:
    var $197 = HEAP32[$148 >> 2];
    var $198 = __ZNK8JSObject17getQNameLocalNameEv($197);
    var $199 = $sb;
    var $200 = $198;
    var $201 = __ZN2js12StringBuffer6appendEP6JSAtom($199, $200);
    if ($201) {
      __label__ = 57;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 57:
    var $203 = $xml + 56 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor3, $203);
    __label__ = 58;
    break;
   case 58:
    var $205 = __ZN16JSXMLArrayCursor7getNextEv($cursor3);
    if (($205 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $208 = __ZN2js12StringBuffer6appendEt($1, 32);
    if ($208) {
      __label__ = 60;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 60:
    var $211 = $205 + 12 | 0;
    var $212 = HEAP32[$211 >> 2];
    var $213 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $212, $103);
    if (($213 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $216 = __ZNK8JSObject13getNamePrefixEv($213);
    if (($216 | 0) == 0) {
      __label__ = 62;
      break;
    } else {
      var $prefix_2 = $216;
      __label__ = 66;
      break;
    }
   case 62:
    var $219 = __ZNK8JSObject10getNameURIEv($213);
    var $220 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $219, $103);
    if (($220 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $223 = __ZNK8JSObject10getNameURIEv($213);
    var $224 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $220, $223, 1);
    if (($224 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $227 = HEAP32[$110 >> 2];
    var $228 = $224;
    var $229 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $103, $227, $228);
    if (($229 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $232 = HEAP32[$82 >> 2];
    var $233 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $81, $232, $228);
    if (($233 | 0) == 0) {
      __label__ = 71;
      break;
    } else {
      var $prefix_2 = $220;
      __label__ = 66;
      break;
    }
   case 66:
    var $prefix_2;
    var $236 = $prefix_2 | 0;
    var $237 = __ZNK8JSString5emptyEv($236);
    if ($237) {
      __label__ = 69;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $239 = __ZN2js12StringBuffer6appendEP8JSString($1, $236);
    if ($239) {
      __label__ = 68;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 68:
    var $241 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($241) {
      __label__ = 69;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 69:
    var $243 = HEAP32[$211 >> 2];
    var $244 = __ZNK8JSObject17getQNameLocalNameEv($243);
    var $245 = $244;
    var $246 = __ZN2js12StringBuffer6appendEP6JSAtom($199, $245);
    if ($246) {
      __label__ = 70;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 70:
    var $250 = HEAP32[$205 + 24 >> 2];
    var $251 = __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $250);
    if ($251) {
      __label__ = 58;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    __ZN16JSXMLArrayCursorD1Ev($cursor3);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 72:
    __ZN16JSXMLArrayCursorD1Ev($cursor3);
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor5, $81);
    __label__ = 73;
    break;
   case 73:
    var $254 = __ZN16JSXMLArrayCursor7getNextEv($cursor5);
    var $255 = $254;
    if (($254 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 74:
    var $258 = __ZN2js12StringBuffer6appendILj7EEEbRAT__Kc($sb, STRING_TABLE.__str464292);
    if ($258) {
      __label__ = 75;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 75:
    var $260 = __ZNK8JSObject13getNamePrefixEv($255);
    if (($260 | 0) == 0) {
      __label__ = 76;
      break;
    } else {
      var $prefix_3 = $260;
      __label__ = 78;
      break;
    }
   case 76:
    var $263 = __ZNK8JSObject10getNameURIEv($255);
    var $264 = __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $263, $103);
    if (($264 | 0) == 0) {
      __label__ = 82;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($255, $264);
    var $prefix_3 = $264;
    __label__ = 78;
    break;
   case 78:
    var $prefix_3;
    var $268 = $prefix_3 | 0;
    var $269 = __ZNK8JSString5emptyEv($268);
    if ($269) {
      __label__ = 81;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $271 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($271) {
      __label__ = 80;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 80:
    var $273 = __ZN2js12StringBuffer6appendEP8JSString($1, $268);
    if ($273) {
      __label__ = 81;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 81:
    var $275 = __ZNK8JSObject10getNameURIEv($255);
    var $276 = $275 | 0;
    var $277 = __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $276);
    if ($277) {
      __label__ = 73;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    __ZN16JSXMLArrayCursorD1Ev($cursor5);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 83:
    __ZN16JSXMLArrayCursorD1Ev($cursor5);
    var $279 = $xml + 24 | 0;
    var $280 = $279 | 0;
    var $281 = HEAPU32[$280 >> 2];
    if (($281 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    var $284 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($1, STRING_TABLE._js_ptagc_str);
    if ($284) {
      __label__ = 111;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 85:
    var $286 = __ZN2js12StringBuffer6appendEt($1, 62);
    if ($286) {
      __label__ = 86;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 86:
    if ($281 >>> 0 > 1) {
      var $302 = 0;
      __label__ = 90;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    if ((HEAP32[$280 >> 2] | 0) == 0) {
      var $_not22 = 1;
      __label__ = 93;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    var $295 = HEAP32[HEAP32[$xml + 32 >> 2] >> 2];
    if (($295 | 0) == 0) {
      var $_not22 = 1;
      __label__ = 93;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    var $302 = (HEAP32[$295 + 16 >> 2] | 0) == 4;
    __label__ = 90;
    break;
   case 90:
    var $302;
    if ($7 | $302) {
      var $_not22 = $302;
      __label__ = 93;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    var $304 = __ZL19GetUint32XMLSettingP9JSContextPKcPj($cx, $i);
    if (($304 | 0) == 0) {
      var $_1 = 0;
      __label__ = 115;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $nextIndentLevel_0 = HEAP32[$i >> 2] + $indentLevel | 0;
    var $_not21 = $302;
    __label__ = 94;
    break;
   case 93:
    var $_not22;
    var $nextIndentLevel_0 = $indentLevel & -2147483648;
    var $_not21 = $_not22;
    __label__ = 94;
    break;
   case 94:
    var $_not21;
    var $nextIndentLevel_0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor8, $279);
    var $brmerge7 = $7 | $_not21;
    __label__ = 95;
    break;
   case 95:
    var $312 = __ZN16JSXMLArrayCursor7getNextEv($cursor8);
    var $313 = $312;
    if (($312 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    if ($brmerge7) {
      __label__ = 98;
      break;
    } else {
      __label__ = 97;
      break;
    }
   case 97:
    var $317 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($317) {
      __label__ = 98;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 98:
    var $319 = __ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj($cx, $313, $103, $nextIndentLevel_0);
    if (($319 | 0) == 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    var $322 = __ZN2js12StringBuffer6appendEP8JSString($1, $319);
    if ($322) {
      __label__ = 95;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    __ZN16JSXMLArrayCursorD1Ev($cursor8);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 101:
    __ZN16JSXMLArrayCursorD1Ev($cursor8);
    if ($brmerge7) {
      __label__ = 104;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    var $325 = __ZN2js12StringBuffer6appendEt($1, 10);
    if ($325) {
      __label__ = 103;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 103:
    var $327 = $indentLevel & 2147483647;
    var $328 = $sb;
    var $329 = __ZN2js12StringBuffer7appendNEtj($328, 32, $327);
    if ($329) {
      __label__ = 104;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 104:
    var $331 = __ZN2js12StringBuffer6appendILj3EEEbRAT__Kc($1, STRING_TABLE._js_etago_str);
    if ($331) {
      __label__ = 105;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 105:
    var $333 = __ZNK8JSObject13getNamePrefixEv($ns_0);
    if (($333 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 106:
    var $336 = $333 | 0;
    var $337 = __ZNK8JSString5emptyEv($336);
    if ($337) {
      __label__ = 109;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    var $339 = __ZN2js12StringBuffer6appendEP8JSString($1, $336);
    if ($339) {
      __label__ = 108;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 108:
    var $341 = __ZN2js12StringBuffer6appendEt($1, 58);
    if ($341) {
      __label__ = 109;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 109:
    var $343 = HEAP32[$148 >> 2];
    var $344 = __ZNK8JSObject17getQNameLocalNameEv($343);
    var $345 = $344;
    var $346 = __ZN2js12StringBuffer6appendEP6JSAtom($199, $345);
    if ($346) {
      __label__ = 110;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 110:
    var $348 = __ZN2js12StringBuffer6appendEt($1, 62);
    if ($348) {
      __label__ = 111;
      break;
    } else {
      var $_1 = 0;
      __label__ = 115;
      break;
    }
   case 111:
    var $350 = __ZN2js12StringBuffer12finishStringEv($199);
    var $_1 = $350 | 0;
    __label__ = 115;
    break;
   case 112:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 113:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 114:
    HEAP32[$i >> 2] = $storemerge;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = 0;
    __label__ = 115;
    break;
   case 115:
    var $_1;
    __ZN2js18AutoNamespaceArrayD1Ev($ancdecls);
    __ZN2js18AutoNamespaceArrayD1Ev($decls);
    __ZN2js18AutoNamespaceArrayD1Ev($empty);
    __ZN2js12StringBufferD1Ev($1);
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj["X"] = 1;

function __ZL10IsDeclaredPK8JSObject($obj) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $v = __stackBase__;
  __ZNK8JSObject20getNamespaceDeclaredEv($v, $obj);
  var $1 = __ZNK2JS5ValueeqERKS0_($v, _JSVAL_TRUE);
  var $2 = $1 & 1;
  STACKTOP = __stackBase__;
  return $2;
}

function __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $qn, $inScopeNSes) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $argv = __stackBase__;
    var $bytes = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    var $4 = __ZNK8JSObject10getNameURIEv($qn);
    var $5 = __ZNK8JSObject13getNamePrefixEv($qn);
    if (($4 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZN16JSAutoByteStringC1Ev($bytes);
    if (($5 | 0) == 0) {
      var $15 = STRING_TABLE._js_undefined_str | 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = $5 | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $10);
    var $11 = $cx;
    var $12 = $bytes;
    var $13 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($11, $1, $12, 0);
    if (($13 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $15 = $13;
      __label__ = 4;
      break;
    }
   case 4:
    var $15;
    var $16 = $cx;
    _JS_ReportErrorNumber($16, 2, 0, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $15, tempInt));
    __label__ = 5;
    break;
   case 5:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 22;
    break;
   case 6:
    if (($inScopeNSes | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $20 = $argv | 0;
    if (($5 | 0) == 0) {
      var $54 = $20;
      __label__ = 19;
      break;
    } else {
      var $51 = $20;
      __label__ = 18;
      break;
    }
   case 8:
    var $23 = HEAPU32[$inScopeNSes >> 2];
    var $24 = $inScopeNSes + 8 | 0;
    var $25 = ($5 | 0) == 0;
    var $i_0 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_0;
    if ($i_0 >>> 0 < $23 >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 10:
    var $31 = HEAP32[HEAP32[$24 >> 2] + ($i_0 << 2) >> 2];
    var $32 = $31;
    if (($31 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $35 = __ZNK8JSObject10getNameURIEv($32);
    var $36 = __ZN2js12EqualStringsEP14JSLinearStringS1_($35, $4);
    if ($36) {
      __label__ = 12;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 12:
    var $38 = __ZNK8JSObject13getNamePrefixEv($32);
    if (($38 | 0) == ($5 | 0)) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $41 = ($38 | 0) != 0;
    if ($25 | $41 ^ 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $43 = __ZN2js12EqualStringsEP14JSLinearStringS1_($38, $5);
    if ($43) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $45 = $41 ? $38 : $5;
    var $46 = $45 | 0;
    var $47 = __ZNK8JSString5emptyEv($46);
    if ($47) {
      var $_0 = $32;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 9;
    break;
   case 17:
    var $49 = $argv | 0;
    if ($25) {
      var $54 = $49;
      __label__ = 19;
      break;
    } else {
      var $51 = $49;
      __label__ = 18;
      break;
    }
   case 18:
    var $51;
    var $52 = $5 | 0;
    _STRING_TO_JSVAL4322($2, $52);
    var $_phi_trans_insert = $2 | 0;
    var $st$4$0 = $_phi_trans_insert | 0;
    var $st$4$1 = $_phi_trans_insert + 4 | 0;
    var $59$1 = HEAP32[$st$4$1 >> 2];
    var $59$0 = HEAP32[$st$4$0 >> 2];
    var $58 = $51;
    __label__ = 20;
    break;
   case 19:
    var $54;
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $55$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $55$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $56 = $2 | 0;
    HEAP32[$56 >> 2] = $55$0;
    HEAP32[$56 + 4 >> 2] = $55$1;
    var $59$1 = $55$1;
    var $59$0 = $55$0;
    var $58 = $54;
    __label__ = 20;
    break;
   case 20:
    var $58;
    var $59$0;
    var $59$1;
    var $60 = $argv | 0;
    var $st$4$0 = $60 | 0;
    HEAP32[$st$4$0 >> 2] = $59$0;
    var $st$4$1 = $60 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $59$1;
    var $61 = $4 | 0;
    _STRING_TO_JSVAL4322($3, $61);
    var $62 = $3 | 0;
    var $63$0 = HEAP32[$62 >> 2];
    var $63$1 = HEAP32[$62 + 4 >> 2];
    var $64 = $argv + 8 | 0;
    HEAP32[$64 >> 2] = $63$0;
    HEAP32[$64 + 4 >> 2] = $63$1;
    var $65 = $cx;
    var $66 = __Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE($65, __ZN2js14NamespaceClassE, 0, 0, 2, $58);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = $66;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray["X"] = 1;

function __ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414($sid_0_0_val) {
  return $sid_0_0_val;
}

function __ZL14JSID_FROM_BITSj4418($bits) {
  return $bits;
}

function _JSVAL_IS_PRIMITIVE_IMPL4409($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967175 & 1;
}

function _JSVAL_IS_BOOLEAN_IMPL4410($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -125) & 1;
}

function _JSVAL_IS_STRING_IMPL4412($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -123) & 1;
}

function _MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _STRING_TO_JSVAL_IMPL4413($agg_result, $str) {
  HEAP32[$agg_result + 4 >> 2] = -123;
  HEAP32[$agg_result >> 2] = $str;
  return;
}

function __ZN2js9SpecialIdC2Ej($this, $bits) {
  HEAP32[$this >> 2] = $bits;
  return;
}

function __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $l_0$0, $l_0$1) {
  var $1 = $agg_result | 0;
  HEAP32[$1 >> 2] = $l_0$0;
  HEAP32[$1 + 4 >> 2] = $l_0$1;
  return;
}

function _BOOLEAN_TO_JSVAL_IMPL4417($agg_result, $b) {
  HEAP32[$agg_result + 4 >> 2] = -125;
  HEAP32[$agg_result >> 2] = $b;
  return;
}

function _INT32_TO_JSVAL_IMPL4422($agg_result, $i) {
  HEAP32[$agg_result + 4 >> 2] = -127;
  HEAP32[$agg_result >> 2] = $i;
  return;
}

function __ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray($cx, $uri, $decls) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $decls | 0;
    var $2 = HEAPU32[$1 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $5 = $cx;
    var $6 = __Z17js_NewStringCopyZP9JSContextPKc($5, STRING_TABLE.__str494295 | 0);
    var $_0 = $6 | 0;
    __label__ = 37;
    break;
   case 3:
    var $9 = __ZNK14JSLinearString5charsEv($uri);
    var $10 = $uri | 0;
    var $11 = __ZNK8JSString6lengthEv($10);
    var $end_0_ph = $9 + ($11 << 1) | 0;
    __label__ = 4;
    break;
   case 4:
    var $end_0_ph;
    var $cp_0 = $end_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $cp_0;
    var $14 = $cp_0 - 2 | 0;
    if ($14 >>> 0 > $9 >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $17 = HEAP16[$14 >> 1];
    if ($17 << 16 >> 16 == 46 || $17 << 16 >> 16 == 47 || $17 << 16 >> 16 == 58) {
      __label__ = 7;
      break;
    } else {
      var $cp_0 = $14;
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $end_0_ph;
    var $22 = $19 - $cp_0 >> 1;
    var $23 = __ZL9IsXMLNamePKtj($cp_0, $22);
    if (($23 | 0) == 0) {
      var $end_0_ph = $14;
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    if ($22 >>> 0 > 2) {
      __label__ = 9;
      break;
    } else {
      var $cp_1 = $cp_0;
      var $_pre_phi = $19;
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZL12IS_XML_CHARSPKt($cp_0);
    if ($28) {
      var $end_0_ph = $14;
      __label__ = 4;
      break;
    } else {
      var $cp_1 = $cp_0;
      var $_pre_phi = $19;
      __label__ = 11;
      break;
    }
   case 10:
    var $cp_1 = $14;
    var $_pre_phi = $end_0_ph;
    __label__ = 11;
    break;
   case 11:
    var $_pre_phi;
    var $cp_1;
    var $29 = $cp_1;
    var $30 = $_pre_phi - $29 | 0;
    var $31 = $30 >> 1;
    if ($31 >>> 0 > 2) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $34 = __ZL12IS_XML_CHARSPKt($cp_1);
    if ($34) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $36 = __ZL9IsXMLNamePKtj($cp_1, $31);
    if (($36 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $bp_1_ph = $cp_1;
    var $newlength_1_ph = $31;
    var $_pre_phi3 = $31 + 2 | 0;
    var $_pre_phi5 = $cx;
    __label__ = 18;
    break;
   case 15:
    var $39 = $2 >>> 0;
    var $40 = _log10($39);
    var $41 = $40 >= 0 ? Math.floor($40) : Math.ceil($40);
    var $42 = $31 + 2 | 0;
    var $43 = $42 + $41 | 0;
    var $45 = ($43 << 1) + 2 | 0;
    var $46 = $cx;
    var $47 = __ZN9JSContext7malloc_Ej($46, $45);
    var $48 = $47;
    if (($47 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP16[$48 + ($43 << 1) >> 1] = 0;
    if (($43 | 0) == 0) {
      var $bp_1_ph = $48;
      var $newlength_1_ph = 0;
      var $_pre_phi3 = $42;
      var $_pre_phi5 = $46;
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $54 = $31 + ($41 + 2) | 0;
    var $i_07 = 0;
    __label__ = 19;
    break;
   case 18:
    var $_pre_phi5;
    var $_pre_phi3;
    var $newlength_1_ph;
    var $bp_1_ph;
    var $55 = $decls + 8 | 0;
    var $56 = $cp_1;
    var $bp_1 = $bp_1_ph;
    var $newlength_1 = $newlength_1_ph;
    var $serial_0 = 1;
    __label__ = 20;
    break;
   case 19:
    var $i_07;
    HEAP16[$48 + ($i_07 << 1) >> 1] = 97;
    var $59 = $i_07 + 1 | 0;
    if (($59 | 0) == ($54 | 0)) {
      var $bp_1_ph = $48;
      var $newlength_1_ph = $43;
      var $_pre_phi3 = $42;
      var $_pre_phi5 = $46;
      __label__ = 18;
      break;
    } else {
      var $i_07 = $59;
      __label__ = 19;
      break;
    }
   case 20:
    var $serial_0;
    var $newlength_1;
    var $bp_1;
    var $61 = HEAPU32[$1 >> 2];
    var $62 = $bp_1;
    var $63 = $newlength_1 << 1;
    var $i_1 = 0;
    __label__ = 21;
    break;
   case 21:
    var $i_1;
    if ($i_1 >>> 0 < $61 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 22:
    var $69 = HEAP32[HEAP32[$55 >> 2] + ($i_1 << 2) >> 2];
    if (($69 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $72 = $69;
    var $73 = __ZNK8JSObject13getNamePrefixEv($72);
    if (($73 | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $76 = $73 | 0;
    var $77 = __ZNK8JSString6lengthEv($76);
    if (($77 | 0) == ($newlength_1 | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 25:
    var $80 = __ZNK14JSLinearString5charsEv($73);
    var $81 = $80;
    var $82 = _memcmp($81, $62, $63);
    if (($82 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 26:
    if (($bp_1 | 0) == ($cp_1 | 0)) {
      __label__ = 27;
      break;
    } else {
      var $bp_2 = $bp_1;
      var $newlength_2 = $newlength_1;
      __label__ = 29;
      break;
    }
   case 27:
    var $87 = $61 >>> 0;
    var $88 = _log10($87);
    var $89 = $88 >= 0 ? Math.floor($88) : Math.ceil($88);
    var $90 = $_pre_phi3 + $89 | 0;
    var $92 = ($90 << 1) + 2 | 0;
    var $93 = __ZN9JSContext7malloc_Ej($_pre_phi5, $92);
    if (($93 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $96 = $93;
    _memcpy($93, $56, $30, 1);
    var $bp_2 = $96;
    var $newlength_2 = $90;
    __label__ = 29;
    break;
   case 29:
    var $newlength_2;
    var $bp_2;
    var $99 = _log10($serial_0 >>> 0);
    var $100 = $99 >= 0 ? Math.floor($99) : Math.ceil($99);
    var $101 = $bp_2 + ($_pre_phi3 + $100 << 1) | 0;
    HEAP16[$101 >> 1] = 0;
    if (($serial_0 | 0) == 0) {
      var $dp_0_lcssa = $101;
      __label__ = 31;
      break;
    } else {
      var $m_03 = $serial_0;
      var $dp_04 = $101;
      __label__ = 30;
      break;
    }
   case 30:
    var $dp_04;
    var $m_03;
    var $106 = $dp_04 - 2 | 0;
    HEAP16[$106 >> 1] = (($m_03 >>> 0) % 10 | 48) & 65535;
    var $107 = Math.floor(($m_03 >>> 0) / 10);
    if ($m_03 >>> 0 < 10) {
      var $dp_0_lcssa = $106;
      __label__ = 31;
      break;
    } else {
      var $m_03 = $107;
      var $dp_04 = $106;
      __label__ = 30;
      break;
    }
   case 31:
    var $dp_0_lcssa;
    HEAP16[$dp_0_lcssa - 2 >> 1] = 45;
    var $bp_1 = $bp_2;
    var $newlength_1 = $newlength_2;
    var $serial_0 = $serial_0 + 1 | 0;
    __label__ = 20;
    break;
   case 32:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 21;
    break;
   case 33:
    if (($bp_1 | 0) == ($cp_1 | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    var $116 = $29 - $9 >> 1;
    var $117 = $cx;
    var $118 = __Z21js_NewDependentStringP9JSContextP8JSStringjj($117, $10, $116, $31);
    var $_0 = $118;
    __label__ = 37;
    break;
   case 35:
    var $120 = $cx;
    var $121 = __Z12js_NewStringP9JSContextPtj($120, $bp_1, $newlength_1);
    var $122 = $121 | 0;
    if (($121 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      var $_0 = $122;
      __label__ = 37;
      break;
    }
   case 36:
    __ZN9JSContext5free_EPv(undef, $62);
    var $_0 = $122;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray["X"] = 1;

function __ZL15namespace_matchPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($2);
    if (($3 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13getNamePrefixEv($1);
    if (($6 | 0) == 0) {
      var $11 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js12EqualStringsEP14JSLinearStringS1_($6, $3);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    var $_0 = $11 & 1;
    __label__ = 6;
    break;
   case 5:
    var $14 = __ZNK8JSObject10getNameURIEv($1);
    var $15 = __ZNK8JSObject10getNameURIEv($2);
    var $16 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $15);
    var $_0 = $16 & 1;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString($cx, $sb, $valstr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $sb;
    var $2 = __ZN2js12StringBuffer6appendEt($1, 61);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $4 = __Z23js_EscapeAttributeValueP9JSContextP8JSStringi($cx, $valstr, 1);
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 | 0;
    var $8 = __ZN2js12StringBuffer6appendEP8JSString($1, $7);
    var $_0 = $8;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19GetUint32XMLSettingP9JSContextPKcPj($cx, $uip) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __stackBase__ + 8;
    var $2 = __ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE($cx, STRING_TABLE.__ZL19js_prettyIndent_str | 0, $v);
    if (($2 | 0) == 0) {
      var $12 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $v | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $1 | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $cx;
    var $9 = _JS_ValueToECMAUint32($8, $1, $uip);
    var $12 = ($9 | 0) != 0;
    __label__ = 3;
    break;
   case 3:
    var $12;
    STACKTOP = __stackBase__;
    return $12 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject20getNamespaceDeclaredEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $uri, $prefix, $localName) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL22GetGlobalForScopeChainEP9JSContext4366($cx);
    var $2 = $1 | 0;
    var $3 = __ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355($cx, __ZN2js18AttributeNameClassE, $2);
    if (($3 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $3, $uri, $prefix, $localName);
    var $_ = $6 ? $3 : 0;
    var $_0 = $_;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js9SpecialIdC1Ej($this, $bits) {
  __ZN2js9SpecialIdC2Ej($this, $bits);
  return;
}

function _BOOLEAN_TO_JSVAL4415($agg_result, $b) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _BOOLEAN_TO_JSVAL_IMPL4417($1, $b);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL14IsConstructingEPKN2JS5ValueE4419($vp) {
  var $1 = $vp + 8 | 0;
  var $2 = __ZNK2JS5Value7isMagicEv($1);
  return $2;
}

function _INT_TO_JSVAL4421($agg_result, $i) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  _INT32_TO_JSVAL_IMPL4422($1, $i);
  var $_0 = $1 | 0;
  var $_0_val$0 = HEAP32[$_0 >> 2];
  var $_0_val$1 = HEAP32[$_0 + 4 >> 2];
  __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $_0_val$0, $_0_val$1);
  STACKTOP = __stackBase__;
  return;
}

function __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $xml, $obj) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $xml);
    if (($1 | 0) == 0) {
      var $copy_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if (($obj | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $1;
    var $7 = $obj;
    __ZN8JSObject10setPrivateEPv($7, $6);
    HEAP32[$1 >> 2] = $obj;
    var $copy_0 = $1;
    __label__ = 6;
    break;
   case 4:
    var $10 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $1);
    if (($10 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $copy_0 = $1;
      __label__ = 6;
      break;
    }
   case 5:
    var $copy_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $copy_0;
    return $copy_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $xml) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (__stackBase__ >>> 0 < HEAPU32[$cx + 48 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = $cx;
    __Z21js_ReportOverRecursedP9JSContext($6);
    var $_0 = 0;
    __label__ = 24;
    break;
   case 3:
    var $8 = $xml + 16 | 0;
    var $9 = HEAP32[$8 >> 2];
    var $10 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, $9);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = HEAP32[$xml + 12 >> 2];
    if (($14 | 0) == 0) {
      var $qn_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = __ZNK8JSObject10getNameURIEv($14);
    var $18 = __ZNK8JSObject13getNamePrefixEv($14);
    var $19 = __ZNK8JSObject17getQNameLocalNameEv($14);
    var $20 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $17, $18, $19);
    if (($20 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 23;
      break;
    } else {
      var $qn_0 = $20;
      __label__ = 6;
      break;
    }
   case 6:
    var $qn_0;
    var $23 = $10 + 12 | 0;
    HEAP32[$23 >> 2] = $qn_0;
    var $25 = HEAP32[$xml + 20 >> 2];
    var $26 = $10 + 20 | 0;
    HEAP32[$26 >> 2] = $25;
    if (HEAPU32[$8 >> 2] >>> 0 > 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $33 = $10 + 24 | 0;
    var $_c2 = HEAP32[$xml + 24 >> 2];
    HEAP32[$33 >> 2] = $_c2;
    var $ok_0 = 1;
    __label__ = 23;
    break;
   case 8:
    var $35 = $xml + 24 | 0;
    var $36 = $10 + 24 | 0;
    var $37 = __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $35, $36, $10);
    if (($37 | 0) == 0) {
      var $ok_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ((HEAP32[$8 >> 2] | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $46 = $10 + 40 | 0;
    var $_c = HEAP32[$xml + 40 >> 2];
    HEAP32[$46 >> 2] = $_c;
    var $50 = $10 + 44 | 0;
    var $_c1 = HEAP32[$xml + 44 >> 2];
    HEAP32[$50 >> 2] = $_c1;
    var $ok_0 = $37;
    __label__ = 23;
    break;
   case 11:
    var $52 = $xml + 40 | 0;
    var $53 = HEAPU32[$52 >> 2];
    var $54 = $10 + 40 | 0;
    var $55 = __ZN10JSXMLArray11setCapacityEP9JSContextj($54, $cx, $53);
    var $56 = $55 & 1;
    if ($55) {
      __label__ = 12;
      break;
    } else {
      var $ok_0 = $56;
      __label__ = 23;
      break;
    }
   case 12:
    var $57 = $xml + 48 | 0;
    var $58 = $54 | 0;
    var $59 = $10 + 48 | 0;
    var $i_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $i_0;
    if ($i_0 >>> 0 < $53 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 14:
    if ($i_0 >>> 0 < HEAPU32[$52 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $68 = HEAP32[HEAP32[$57 >> 2] + ($i_0 << 2) >> 2];
    var $69 = $68;
    if (($68 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $72 = __ZNK8JSObject13getNamePrefixEv($69);
    var $73 = __ZNK8JSObject10getNameURIEv($69);
    var $74 = __ZL10IsDeclaredPK8JSObject($69);
    var $75 = __ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i($cx, $72, $73, $74);
    if (($75 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$58 >> 2] = $i_0;
    var $ok_0 = 0;
    __label__ = 23;
    break;
   case 18:
    if (HEAPU32[$58 >> 2] >>> 0 > $i_0 >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP32[$58 >> 2] = $i_0 + 1 | 0;
    __label__ = 20;
    break;
   case 20:
    var $84 = $75;
    var $86 = HEAP32[$59 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$86 >> 2] = $84;
    __label__ = 21;
    break;
   case 21:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 13;
    break;
   case 22:
    var $89 = $xml + 56 | 0;
    var $90 = $10 + 56 | 0;
    var $91 = __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $89, $90, $10);
    var $ok_0 = $91;
    __label__ = 23;
    break;
   case 23:
    var $ok_0;
    var $_ = ($ok_0 | 0) == 0 ? 0 : $10;
    var $_0 = $_;
    __label__ = 24;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13DeepCopyInLRSP9JSContextP5JSXMLj["X"] = 1;

function __ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj($cx, $from, $to, $parent) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $2 = HEAPU32[$from >> 2];
    var $3 = __ZN10JSXMLArray11setCapacityEP9JSContextj($to, $cx, $2);
    if ($3) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 13;
      break;
    }
   case 2:
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $from);
    var $5 = $to | 0;
    var $6 = $to + 8 | 0;
    var $7 = $parent + 16 | 0;
    var $j_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $j_0;
    var $8 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($8 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $11 = $8;
    var $12 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $11);
    if (($12 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    HEAP32[$5 >> 2] = $j_0;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 6:
    var $_pre = $j_0 + 1 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 > $j_0 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    HEAP32[$5 >> 2] = $_pre;
    __label__ = 8;
    break;
   case 8:
    var $21 = HEAP32[$6 >> 2] + ($j_0 << 2) | 0;
    HEAP32[$21 >> 2] = $12;
    if ((HEAP32[$7 >> 2] | 0) == 0) {
      var $j_0 = $_pre;
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$12 + 8 >> 2] = $parent;
    var $j_0 = $_pre;
    __label__ = 3;
    break;
   case 10:
    if ($j_0 >>> 0 < $2 >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    __ZN10JSXMLArray4trimEv($to);
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_1 = $_0;
    __label__ = 13;
    break;
   case 13:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject($vp, $ctorThis) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $vp + 8 | 0;
    var $2 = __ZNK2JS5Value7isMagicEv($1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = __ZNK2JS5Value27getMagicObjectOrNullPayloadEv($1);
    HEAP32[$ctorThis >> 2] = $4;
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 36;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $nameval = __stackBase__;
    var $nsval = __stackBase__ + 8;
    var $name = __stackBase__ + 16;
    var $1 = __stackBase__ + 20;
    var $2 = __stackBase__ + 28;
    if (($argc | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $5$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $5$1 = HEAPU32[$st$1$1 >> 2];
    var $6 = $nameval | 0;
    var $st$6$0 = $6 | 0;
    HEAP32[$st$6$0 >> 2] = $5$0;
    var $st$6$1 = $6 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $5$1;
    var $isQName_0 = 0;
    var $24$1 = $5$1;
    var $24$0 = $5$0;
    __label__ = 6;
    break;
   case 3:
    var $10 = $argv + ((($argc | 0) > 1 & 1) << 3) | 0;
    var $st$3$0 = $10 | 0;
    var $11$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $10 + 4 | 0;
    var $11$1 = HEAPU32[$st$3$1 >> 2];
    var $12 = $nameval | 0;
    var $st$8$0 = $12 | 0;
    HEAP32[$st$8$0 >> 2] = $11$0;
    var $st$8$1 = $12 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $11$1;
    var $13 = _JSVAL_IS_PRIMITIVE4303($11$0, $11$1);
    if (($13 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $21 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = _JSVAL_TO_OBJECT4304($11$0, $11$1);
    var $17 = $16;
    var $18 = __ZNK8JSObject8getClassEv($17);
    var $21 = ($18 | 0) == (__ZN2js10QNameClassE | 0);
    __label__ = 5;
    break;
   case 5:
    var $21;
    var $isQName_0 = $21 & 1;
    var $24$1 = $11$1;
    var $24$0 = $11$0;
    __label__ = 6;
    break;
   case 6:
    var $24$0;
    var $24$1;
    var $isQName_0;
    if (($obj | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_01 = $obj;
    var $_pre_phi = ($isQName_0 | 0) == 0;
    __label__ = 11;
    break;
   case 8:
    var $28 = ($isQName_0 | 0) == 0;
    if (($argc | 0) != 1 | $28) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $30 = $rval | 0;
    var $st$1$0 = $30 | 0;
    HEAP32[$st$1$0 >> 2] = $24$0;
    var $st$1$1 = $30 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $24$1;
    var $_0 = 1;
    __label__ = 41;
    break;
   case 10:
    var $32 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js10QNameClassE);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      var $_01 = $32;
      var $_pre_phi = $28;
      __label__ = 11;
      break;
    }
   case 11:
    var $_pre_phi;
    var $_01;
    _OBJECT_TO_JSVAL4318($1, $_01);
    var $35 = $1 | 0;
    var $36$0 = HEAP32[$35 >> 2];
    var $36$1 = HEAP32[$35 + 4 >> 2];
    var $37 = $rval | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    if ($_pre_phi) {
      __label__ = 15;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $39 = _JSVAL_TO_OBJECT4304($24$0, $24$1);
    if (($argc | 0) == 1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $42 = __ZNK8JSObject10getNameURIEv($39);
    var $43 = __ZNK8JSObject13getNamePrefixEv($39);
    var $44 = __ZNK8JSObject17getQNameLocalNameEv($39);
    HEAP32[$name >> 2] = $44;
    var $prefix_0 = $43;
    var $uri_0 = $42;
    __label__ = 40;
    break;
   case 14:
    __ZNK8JSObject20getQNameLocalNameValEv($nameval, $39);
    __label__ = 15;
    break;
   case 15:
    if (($argc | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $51 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    HEAP32[$name >> 2] = $51;
    __label__ = 23;
    break;
   case 17:
    if (($argc | 0) < 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 18:
    var $58 = HEAP32[HEAP32[$cx + 52 >> 2] + 209984 >> 2] | 0;
    HEAP32[$name >> 2] = $58;
    __label__ = 23;
    break;
   case 19:
    var $60 = $cx;
    var $61 = $name;
    var $62 = __Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom($60, $nameval, $61);
    if ($62) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 41;
      break;
    }
   case 20:
    if (($argc | 0) > 1) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    var $66 = $argv | 0;
    var $st$1$0 = $66 | 0;
    var $67$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $66 + 4 | 0;
    var $67$1 = HEAP32[$st$1$1 >> 2];
    var $68 = _JSVAL_IS_VOID4396($67$0, $67$1);
    if (($68 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $71$0 = HEAP32[$66 >> 2];
    var $71$1 = HEAP32[$66 + 4 >> 2];
    var $72 = $nsval | 0;
    HEAP32[$72 >> 2] = $71$0;
    HEAP32[$72 + 4 >> 2] = $71$1;
    var $89$1 = $71$1;
    var $89$0 = $71$0;
    __label__ = 28;
    break;
   case 23:
    var $73 = HEAP32[$name >> 2];
    var $74 = $73 | 0;
    var $75 = __ZNK8JSString6lengthEv($74);
    if (($75 | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 24:
    var $78 = $73 | 0;
    var $79 = __ZNK14JSLinearString5charsEv($78);
    if (HEAP16[$79 >> 1] << 16 >> 16 == 42) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    var $$emscripten$temp$1 = _JSVAL_NULL | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $83$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $83$1 = HEAP32[$st$1$1 >> 2];
    var $84 = $nsval | 0;
    var $st$6$0 = $84 | 0;
    HEAP32[$st$6$0 >> 2] = $83$0;
    var $st$6$1 = $84 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $83$1;
    var $89$1 = $83$1;
    var $89$0 = $83$0;
    __label__ = 28;
    break;
   case 26:
    var $86 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($86 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $_phi_trans_insert = $nsval | 0;
    var $st$1$0 = $_phi_trans_insert | 0;
    var $st$1$1 = $_phi_trans_insert + 4 | 0;
    var $89$1 = HEAP32[$st$1$1 >> 2];
    var $89$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 28;
    break;
   case 28:
    var $89$0;
    var $89$1;
    var $90 = _JSVAL_IS_NULL4395($89$0, $89$1);
    if (($90 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $prefix_0 = 0;
      var $uri_0 = 0;
      __label__ = 40;
      break;
    }
   case 29:
    var $93 = _JSVAL_IS_PRIMITIVE4303($89$0, $89$1);
    if (($93 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 30:
    var $96 = _JSVAL_TO_OBJECT4304($89$0, $89$1);
    var $97 = $96;
    var $98 = __ZNK8JSObject8getClassEv($97);
    if (($98 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    var $101 = __ZNK8JSObject10getNameURIEv($96);
    var $102 = __ZNK8JSObject13getNamePrefixEv($96);
    var $prefix_0 = $102;
    var $uri_0 = $101;
    __label__ = 40;
    break;
   case 32:
    if (($98 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 33;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 33:
    var $106 = __ZNK8JSObject10getNameURIEv($96);
    if (($106 | 0) == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $109 = __ZNK8JSObject13getNamePrefixEv($96);
    var $prefix_0 = $109;
    var $uri_0 = $106;
    __label__ = 40;
    break;
   case 35:
    var $110 = $cx;
    var $111 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($110, $nsval);
    if (($111 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $114 = $cx;
    var $115 = __ZN8JSString12ensureLinearEP9JSContext($111, $114);
    if (($115 | 0) == 0) {
      var $_0 = 0;
      __label__ = 41;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $118 = $115 | 0;
    _STRING_TO_JSVAL4322($2, $118);
    var $119 = $2 | 0;
    var $st$3$0 = $119 | 0;
    var $120$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $119 + 4 | 0;
    var $120$1 = HEAP32[$st$3$1 >> 2];
    var $121 = $argv | 0;
    var $st$8$0 = $121 | 0;
    HEAP32[$st$8$0 >> 2] = $120$0;
    var $st$8$1 = $121 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $120$1;
    var $122 = __ZNK8JSString5emptyEv($118);
    if ($122) {
      __label__ = 38;
      break;
    } else {
      var $129 = 0;
      __label__ = 39;
      break;
    }
   case 38:
    var $129 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2];
    __label__ = 39;
    break;
   case 39:
    var $129;
    var $prefix_0 = $129 | 0;
    var $uri_0 = $115;
    __label__ = 40;
    break;
   case 40:
    var $uri_0;
    var $prefix_0;
    var $131 = HEAP32[$name >> 2];
    var $132 = __ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom($cx, $_01, $uri_0, $prefix_0, $131);
    var $_0 = $132 & 1;
    __label__ = 41;
    break;
   case 41:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_["X"] = 1;

function __ZNK8JSObject20getQNameLocalNameValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 2);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZNK2JS5Value27getMagicObjectOrNullPayloadEv($this) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL($2$0, $2$1);
  return $3;
}

function __ZN8JSObject17setQNameLocalNameEP6JSAtom($this, $name) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (($name | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $name | 0;
    __ZN2JSL11StringValueEP8JSString4311($1, $4);
    __label__ = 4;
    break;
   case 3:
    __ZN2JSL14UndefinedValueEv4406($1);
    __label__ = 4;
    break;
   case 4:
    var $7 = $this;
    __ZN8JSObject7setSlotEjRKN2JS5ValueE($7, 2, $1);
    STACKTOP = __stackBase__;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__ZN2js8XMLClassE + 4 >> 2];
    var $2 = $1 >>> 24;
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = $2;
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = $1 >>> 17 & 1;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    var $3 = $obj;
    var $4 = __ZNK8JSObject8getClassEv($3);
    if (($4 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    __ZNK8JSObject13getNameURIValEv($2, $obj);
    var $_idx = $2 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $7 = _JSVAL_IS_VOID4396($_idx_val$0, $_idx_val$1);
    if (($7 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $10$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $10$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    var $11 = $1 | 0;
    HEAP32[$11 >> 2] = $10$0;
    HEAP32[$11 + 4 >> 2] = $10$1;
    var $14$1 = $10$1;
    var $14$0 = $10$0;
    __label__ = 5;
    break;
   case 4:
    __ZNK8JSObject13getNameURIValEv($1, $obj);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $14$1 = HEAP32[$st$2$1 >> 2];
    var $14$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $14$0;
    var $14$1;
    var $15 = $vp | 0;
    HEAP32[$15 >> 2] = $14$0;
    HEAP32[$15 + 4 >> 2] = $14$1;
    __label__ = 6;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8getClassEv($2);
    if (($3 | 0) == (__ZN2js10QNameClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject20getQNameLocalNameValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject13getNameURIValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 1);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8getClassEv($2);
    if (($3 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject16getNamePrefixValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = $obj;
    var $3 = __ZNK8JSObject8getClassEv($2);
    if (($3 | 0) == (__ZN2js14NamespaceClassE | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZNK8JSObject13getNameURIValEv($1, $obj);
    var $6 = $1 | 0;
    var $7$0 = HEAP32[$6 >> 2];
    var $7$1 = HEAP32[$6 + 4 >> 2];
    var $8 = $vp | 0;
    HEAP32[$8 >> 2] = $7$0;
    HEAP32[$8 + 4 >> 2] = $7$1;
    __label__ = 3;
    break;
   case 3:
    STACKTOP = __stackBase__;
    return 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK8JSObject16getNamePrefixValEv($agg_result, $this) {
  var $1 = $this;
  var $2 = __ZNK8JSObject7getSlotEj($1, 0);
  var $3 = $2 | 0;
  var $4$0 = HEAP32[$3 >> 2];
  var $4$1 = HEAP32[$3 + 4 >> 2];
  var $5 = $agg_result | 0;
  HEAP32[$5 >> 2] = $4$0;
  HEAP32[$5 + 4 >> 2] = $4$1;
  return;
}

function __ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_($cx, $obj, $argc, $argv, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $urival = __stackBase__;
    var $prefixval = __stackBase__ + 8;
    var $1 = __stackBase__ + 16;
    var $bytes = __stackBase__ + 24;
    var $2 = __stackBase__ + 28;
    var $3 = __stackBase__ + 36;
    if (($argc | 0) < 1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $6$0 = HEAPU32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $6$1 = HEAPU32[$st$1$1 >> 2];
    var $7 = $urival | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $isQName_0 = 0;
    var $isNamespace_0 = 0;
    var $uriobj_0 = 0;
    var $25$1 = $6$1;
    var $25$0 = $6$0;
    __label__ = 5;
    break;
   case 3:
    var $11 = $argv + ((($argc | 0) > 1 & 1) << 3) | 0;
    var $st$3$0 = $11 | 0;
    var $12$0 = HEAPU32[$st$3$0 >> 2];
    var $st$3$1 = $11 + 4 | 0;
    var $12$1 = HEAPU32[$st$3$1 >> 2];
    var $13 = $urival | 0;
    var $st$8$0 = $13 | 0;
    HEAP32[$st$8$0 >> 2] = $12$0;
    var $st$8$1 = $13 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $12$1;
    var $14 = _JSVAL_IS_PRIMITIVE4303($12$0, $12$1);
    if (($14 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $isQName_0 = 0;
      var $isNamespace_0 = 0;
      var $uriobj_0 = 0;
      var $25$1 = $12$1;
      var $25$0 = $12$0;
      __label__ = 5;
      break;
    }
   case 4:
    var $17 = _JSVAL_TO_OBJECT4304($12$0, $12$1);
    var $18 = $17;
    var $19 = __ZNK8JSObject8getClassEv($18);
    var $isQName_0 = ($19 | 0) == (__ZN2js10QNameClassE | 0) & 1;
    var $isNamespace_0 = ($19 | 0) == (__ZN2js14NamespaceClassE | 0) & 1;
    var $uriobj_0 = $17;
    var $25$1 = $12$1;
    var $25$0 = $12$0;
    __label__ = 5;
    break;
   case 5:
    var $25$0;
    var $25$1;
    var $uriobj_0;
    var $isNamespace_0;
    var $isQName_0;
    if (($obj | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_02 = $obj;
      __label__ = 9;
      break;
    }
   case 6:
    if (($argc | 0) != 1 | ($isNamespace_0 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $rval | 0;
    var $st$1$0 = $31 | 0;
    HEAP32[$st$1$0 >> 2] = $25$0;
    var $st$1$1 = $31 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $25$1;
    var $_0 = 1;
    __label__ = 37;
    break;
   case 8:
    var $33 = __ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE($cx, __ZN2js14NamespaceClassE);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      var $_02 = $33;
      __label__ = 9;
      break;
    }
   case 9:
    var $_02;
    var $36 = $cx;
    var $38 = _JS_DefineProperties($36, $_02, __ZL15namespace_props);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    _OBJECT_TO_JSVAL4318($1, $_02);
    var $41 = $1 | 0;
    var $42$0 = HEAP32[$41 >> 2];
    var $42$1 = HEAP32[$41 + 4 >> 2];
    var $43 = $rval | 0;
    HEAP32[$43 >> 2] = $42$0;
    HEAP32[$43 + 4 >> 2] = $42$1;
    var $48 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $48);
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $48);
    if (($argc | 0) == -1 || ($argc | 0) == 1) {
      __label__ = 11;
      break;
    } else if (($argc | 0) == 2) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 11:
    if (($isNamespace_0 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $52 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $52);
    var $53 = __ZNK8JSObject13getNamePrefixEv($uriobj_0);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $53);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 13:
    if (($isQName_0 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $57 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    if (($57 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $57);
    var $60 = __ZNK8JSObject13getNamePrefixEv($uriobj_0);
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $60);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 16:
    var $62 = $cx;
    var $63 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($62, $urival);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $66 = __ZN8JSString12ensureLinearEP9JSContext($63, $36);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $66);
    var $69 = $66 | 0;
    var $70 = __ZNK8JSString5emptyEv($69);
    if ($70) {
      var $_0 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN8JSObject15clearNamePrefixEv($_02);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 20:
    if (($isQName_0 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $75 = __ZNK8JSObject10getNameURIEv($uriobj_0);
    if (($75 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $uri_0 = $75;
      __label__ = 24;
      break;
    }
   case 22:
    var $78 = $cx;
    var $79 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($78, $urival);
    if (($79 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $82 = __ZN8JSString12ensureLinearEP9JSContext($79, $36);
    if (($82 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      var $uri_0 = $82;
      __label__ = 24;
      break;
    }
   case 24:
    var $uri_0;
    __ZN8JSObject10setNameURIEP14JSLinearString($_02, $uri_0);
    var $85 = $argv | 0;
    var $st$3$0 = $85 | 0;
    var $86$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $85 + 4 | 0;
    var $86$1 = HEAP32[$st$3$1 >> 2];
    var $87 = $prefixval | 0;
    var $st$8$0 = $87 | 0;
    HEAP32[$st$8$0 >> 2] = $86$0;
    var $st$8$1 = $87 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $86$1;
    var $89 = __ZNK8JSString5emptyEv($uri_0 | 0);
    var $90 = _JSVAL_IS_VOID4396($86$0, $86$1);
    var $91 = ($90 | 0) == 0;
    if ($89) {
      __label__ = 25;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 25:
    if ($91) {
      __label__ = 26;
      break;
    } else {
      var $_0 = 1;
      __label__ = 37;
      break;
    }
   case 26:
    var $94 = $cx;
    var $95 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($94, $prefixval);
    if (($95 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $98 = __ZNK8JSString5emptyEv($95);
    if ($98) {
      var $_0 = 1;
      __label__ = 37;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2JSL11StringValueEP8JSString4311($2, $95);
    var $100 = $bytes;
    var $101 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($94, $2, $100, 0);
    if (($101 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $104 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($36, 2, 0, 177, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $104, tempInt));
    __label__ = 30;
    break;
   case 30:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $_0 = 0;
    __label__ = 37;
    break;
   case 31:
    if ($91) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $108 = $3 | 0;
    var $st$1$0 = $108 | 0;
    HEAP32[$st$1$0 >> 2] = $86$0;
    var $st$1$1 = $108 + 4 | 0;
    HEAP32[$st$1$1 >> 2] = $86$1;
    var $109 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $3);
    if (($109 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 33:
    __ZN8JSObject15clearNamePrefixEv($_02);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 34:
    var $113 = $cx;
    var $114 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($113, $prefixval);
    if (($114 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $117 = __ZN8JSString12ensureLinearEP9JSContext($114, $36);
    if (($117 | 0) == 0) {
      var $_0 = 0;
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    __ZN8JSObject13setNamePrefixEP14JSLinearString($_02, $117);
    var $_0 = 1;
    __label__ = 37;
    break;
   case 37:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_["X"] = 1;

function __ZN8JSObject15clearNamePrefixEv($this) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $1 = __stackBase__;
  __ZN2JSL14UndefinedValueEv4406($1);
  var $2 = $this;
  __ZN8JSObject7setSlotEjRKN2JS5ValueE($2, 0, $1);
  STACKTOP = __stackBase__;
  return;
}

function __ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427($cx, $parent) {
  var $3 = HEAPU32[__ZN2js8XMLClassE + 4 >> 2] >>> 8 & 255;
  var $4 = __ZN2js2gcL15GetGCObjectKindEjb4379($3);
  var $5 = __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428($cx, $parent, $4);
  return $5;
}

function __ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428($cx, $parent, $kind) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = 0;
    var $2 = __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429($cx, $parent, $1);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    var $4 = HEAP32[$1 >> 2];
    var $5 = ($4 | 0) == 0;
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $12 = __ZN2js5types15emptyTypeObjectE;
    var $_pre_phi = $cx;
    __label__ = 5;
    break;
   case 4:
    var $7 = $4;
    var $8 = $cx;
    var $9 = __ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb($7, $8, 0, 0);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      var $12 = $10;
      var $_pre_phi = $8;
      __label__ = 5;
      break;
    }
   case 5:
    var $_pre_phi;
    var $12;
    var $13 = __Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE($_pre_phi, $kind);
    var $14 = $13;
    if (($13 | 0) == 0) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_not = ($parent | 0) == 0 ^ 1;
    var $parent_mux = $_not ? $parent : 0;
    if ($_not | $5) {
      var $23 = $parent_mux;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $19 = $4;
    var $20 = __ZNK8JSObject9getParentEv($19);
    var $23 = $20;
    __label__ = 8;
    break;
   case 8:
    var $23;
    __ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb($13, undef, __ZN2js8XMLClassE, $12, $23, 0, (__ZN2js8XMLClassE | 0) == (__ZN2js10ArrayClassE | 0));
    var $26 = __ZNK2js5Class8isNativeEv(__ZN2js8XMLClassE);
    if ($26) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $28 = __ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383($cx, $14, __ZN2js8XMLClassE, $12, $kind);
    if ($28) {
      var $_0 = $14;
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    __ZN8JSObject21setSharedNonNativeMapEv($13);
    var $_0 = $14;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429($cx, $parent, $proto) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430();
    var $2 = $cx;
    var $3 = $parent;
    var $4 = $proto;
    var $5 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, $1, $4, __ZN2js8XMLClassE);
    if (($5 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP32[$proto >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE($2, $3, 1, $4, 0);
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $_0 = 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js13AutoXMLRooterD2Ev($this) {
  var $1 = $this;
  __ZN2js12AutoGCRooterD2Ev($1);
  return;
}

function __ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML($this, $cx, $xml) {
  var $1 = $this;
  var $2 = $cx;
  __ZN2js12AutoGCRooterC2EP9JSContexti($1, $2, -9);
  HEAP32[$this + 12 >> 2] = $xml;
  return;
}

function __ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_($cx, $from, $to) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $cx;
    var $2 = $from;
    var $3 = $v | 0;
    var $4 = $to;
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    var $7 = HEAP32[__ZL16xml_static_props + ($i_0 << 4) >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = _JS_GetProperty($1, $2, $7, $v);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $13 = ($7 | 0) == (STRING_TABLE.__ZL19js_prettyIndent_str | 0);
    var $14$0 = HEAP32[$3 >> 2];
    var $14$1 = HEAP32[$3 + 4 >> 2];
    if ($13) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $16 = _JSVAL_IS_NUMBER($14$0, $14$1);
    if (($16 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $19 = _JSVAL_IS_BOOLEAN4407($14$0, $14$1);
    if (($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $22 = _JS_SetProperty($1, $4, $7, $v);
    if (($22 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $xml, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$xml + 16 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    var $8 = $xml + 24 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $xml + 32 | 0;
    var $11 = $v | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$8 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$10 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$20 + 16 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $21);
    if (($29 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = __ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $21, $v);
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $33$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $33$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$11 >> 2] = $33$0;
    HEAP32[$11 + 4 >> 2] = $33$1;
    var $_0 = 0;
    __label__ = 24;
    break;
   case 11:
    var $35$0 = HEAP32[$11 >> 2];
    var $35$1 = HEAP32[$11 + 4 >> 2];
    var $36 = _JSVAL_TO_OBJECT4304($35$0, $35$1);
    var $37 = $36;
    var $38 = __ZNK8JSObject10getPrivateEv($37);
    var $39 = $38;
    if (HEAPU32[$38 + 16 >> 2] >>> 0 < 2) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$38 + 24 >> 2] | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $49 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $39);
    if (($49 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 15:
    var $54 = $xml + 24 | 0;
    if ($5 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $57 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $57 = HEAP32[$54 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $57;
    var $58 = $xml + 32 | 0;
    var $i_1 = 0;
    __label__ = 18;
    break;
   case 18:
    var $i_1;
    if ($i_1 >>> 0 < $57 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $_0 = 1;
      __label__ = 24;
      break;
    }
   case 19:
    if ($i_1 >>> 0 < HEAPU32[$54 >> 2] >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 20:
    var $67 = HEAPU32[HEAP32[$58 >> 2] + ($i_1 << 2) >> 2];
    var $68 = $67;
    if (($67 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP32[$67 + 16 >> 2] | 0) == 4) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $76 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $68);
    if (($76 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 18;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE["X"] = 1;

function __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _OBJECT_TO_JSVAL4318($1, $2);
    var $5 = $1 | 0;
    var $6$0 = HEAP32[$5 >> 2];
    var $6$1 = HEAP32[$5 + 4 >> 2];
    var $7 = $rval | 0;
    HEAP32[$7 >> 2] = $6$0;
    HEAP32[$7 + 4 >> 2] = $6$1;
    var $8 = $2;
    var $9 = __ZNK8JSObject10getPrivateEv($8);
    var $10 = $9;
    HEAP32[$9 + 40 >> 2] = $xml;
    var $_0 = $10;
    __label__ = 3;
    break;
   case 3:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject($cx, $vp, $objp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 24;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $numBuf = __stackBase__;
    var $1 = __stackBase__ + 12;
    var $funNameBytes = __stackBase__ + 20;
    var $2 = $vp + 8 | 0;
    var $3 = $cx;
    var $4 = __ZN2js8ToObjectEP9JSContextPN2JS5ValueE($3, $2);
    HEAP32[$objp >> 2] = $4;
    if (($4 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $8 = __ZNK8JSObject5isXMLEv($4);
    if ($8) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE($3, $vp, __ZN2js8XMLClassE);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 4:
    var $11 = __ZNK8JSObject10getPrivateEv($4);
    var $12 = $11;
    if (($11 | 0) == 0) {
      var $_0 = $12;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = $12;
      __label__ = 13;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 24 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $xml_0 = $12;
      __label__ = 10;
      break;
    }
   case 7:
    var $28 = HEAP32[HEAP32[$11 + 32 >> 2] >> 2];
    var $29 = $28;
    if (($28 | 0) == 0) {
      var $xml_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $29);
    HEAP32[$objp >> 2] = $32;
    if (($32 | 0) == 0) {
      var $_0 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    _OBJECT_TO_JSVAL4318($1, $32);
    var $35 = $1 | 0;
    var $st$2$0 = $35 | 0;
    var $36$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $35 + 4 | 0;
    var $36$1 = HEAP32[$st$2$1 >> 2];
    var $37 = $2 | 0;
    HEAP32[$37 >> 2] = $36$0;
    HEAP32[$37 + 4 >> 2] = $36$1;
    var $_0 = $29;
    __label__ = 13;
    break;
   case 10:
    var $xml_0;
    var $39 = $vp | 0;
    var $st$2$0 = $39 | 0;
    var $40$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $39 + 4 | 0;
    var $40$1 = HEAP32[$st$2$1 >> 2];
    var $41 = _JSVAL_TO_OBJECT4304($40$0, $40$1);
    var $42 = $41;
    var $43 = __ZNK8JSObject18getFunctionPrivateEv($42);
    var $44 = $numBuf | 0;
    var $46 = HEAP32[$xml_0 + 24 >> 2];
    var $47 = _JS_snprintf($44, 12, STRING_TABLE.__str544300 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $46, tempInt));
    __ZN16JSAutoByteStringC1Ev($funNameBytes);
    var $48 = __ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString($3, $43, $funNameBytes);
    if (($48 | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _JS_ReportErrorNumber($3, 2, 0, 219, (tempInt = STACKTOP, STACKTOP += 8, HEAP32[tempInt >> 2] = $48, HEAP32[tempInt + 4 >> 2] = $44, tempInt));
    __label__ = 12;
    break;
   case 12:
    __ZN16JSAutoByteStringD1Ev($funNameBytes);
    var $_0 = 0;
    __label__ = 13;
    break;
   case 13:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject["X"] = 1;

function __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $xml, $obj) {
  var $1 = __ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj($cx, $xml, $obj);
  return $1;
}

function __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml, $ns) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xml + 16 >> 2] | 0) == 1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    var $5 = __ZNK8JSObject13getNamePrefixEv($ns);
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 3:
    var $8 = $xml + 40 | 0;
    var $10 = HEAPU32[$8 >> 2];
    var $11 = $xml + 48 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 5:
    var $17 = HEAP32[HEAP32[$11 >> 2] + ($i_0 << 2) >> 2];
    if (($17 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $20 = $17;
    var $21 = __ZNK8JSObject10getNameURIEv($20);
    var $22 = __ZNK8JSObject10getNameURIEv($ns);
    var $23 = __ZN2js12EqualStringsEP14JSLinearStringS1_($21, $22);
    if ($23) {
      __label__ = 21;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 8:
    var $26 = $ns;
    var $27 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $8, $10, $26);
    if (($27 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 9:
    var $30 = $5 | 0;
    var $31 = __ZNK8JSString5emptyEv($30);
    if ($31) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $34 = HEAP32[$xml + 12 >> 2];
    var $35 = __ZNK8JSObject10getNameURIEv($34);
    var $36 = $35 | 0;
    var $37 = __ZNK8JSString5emptyEv($36);
    if ($37) {
      var $_0 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $39 = $xml + 40 | 0;
    var $40 = $39 | 0;
    var $41 = HEAPU32[$40 >> 2];
    var $42 = $xml + 48 | 0;
    var $i_1 = 0;
    __label__ = 12;
    break;
   case 12:
    var $i_1;
    if ($i_1 >>> 0 < $41 >>> 0) {
      __label__ = 13;
      break;
    } else {
      var $64 = $41;
      __label__ = 20;
      break;
    }
   case 13:
    var $48 = HEAP32[HEAP32[$42 >> 2] + ($i_1 << 2) >> 2];
    var $49 = $48;
    if (($48 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $52 = __ZNK8JSObject13getNamePrefixEv($49);
    if (($52 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $55 = __ZN2js12EqualStringsEP14JSLinearStringS1_($52, $5);
    if ($55) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 12;
    break;
   case 17:
    var $58 = __ZNK8JSObject10getNameURIEv($49);
    var $59 = __ZNK8JSObject10getNameURIEv($ns);
    var $60 = __ZN2js12EqualStringsEP14JSLinearStringS1_($58, $59);
    if ($60) {
      var $64 = $41;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($39, $i_1, 1);
    __ZN8JSObject15clearNamePrefixEv($49);
    var $62 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml, $49);
    if (($62 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $64 = HEAP32[$40 >> 2];
    __label__ = 20;
    break;
   case 20:
    var $64;
    var $65 = $ns;
    var $66 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $39, $64, $65);
    if (($66 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $_0 = 1;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject["X"] = 1;

function __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 260;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $rxml = __stackBase__;
    var $index = __stackBase__ + 4;
    var $attrval = __stackBase__ + 8;
    var $nsval = __stackBase__ + 16;
    var $funid = __stackBase__ + 24;
    var $roots = __stackBase__ + 28;
    var $1 = __stackBase__ + 52;
    var $2 = __stackBase__ + 60;
    var $tvr = __stackBase__ + 68;
    var $3 = __stackBase__ + 84;
    var $4 = __stackBase__ + 92;
    var $5 = __stackBase__ + 100;
    var $6 = __stackBase__ + 108;
    var $7 = __stackBase__ + 116;
    var $8 = __stackBase__ + 124;
    var $9 = __stackBase__ + 132;
    var $10 = __stackBase__ + 140;
    var $11 = __stackBase__ + 148;
    var $12 = __stackBase__ + 156;
    var $13 = __stackBase__ + 164;
    var $14 = __stackBase__ + 172;
    var $15 = __stackBase__ + 180;
    var $16 = __stackBase__ + 188;
    var $17 = __stackBase__ + 196;
    var $18 = __stackBase__ + 204;
    var $19 = __stackBase__ + 212;
    var $cursor = __stackBase__ + 220;
    var $20 = __stackBase__ + 240;
    var $bytes = __stackBase__ + 248;
    var $21 = __stackBase__ + 252;
    var $22 = $obj;
    var $23 = __ZNK8JSObject5isXMLEv($22);
    if ($23) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 192;
      break;
    }
   case 2:
    var $25 = __ZNK8JSObject10getPrivateEv($22);
    var $26 = $25;
    if (($25 | 0) == 0) {
      var $_0 = 1;
      __label__ = 192;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ((HEAP32[$25 >> 2] | 0) == ($obj | 0)) {
      var $35 = $26;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $33 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $26, $obj);
    var $35 = $33;
    __label__ = 5;
    break;
   case 5:
    var $35;
    if (($35 | 0) == 0) {
      var $_0 = 0;
      __label__ = 192;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $38 = $vp | 0;
    var $st$1$0 = $38 | 0;
    var $39$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $38 + 4 | 0;
    var $39$1 = HEAP32[$st$1$1 >> 2];
    var $40 = _JSVAL_IS_PRIMITIVE4303($39$0, $39$1);
    if (($40 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    var $st$0$0 = $38 | 0;
    var $43$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $43$1 = HEAP32[$st$0$1 >> 2];
    var $44 = _JSVAL_TO_OBJECT4304($43$0, $43$1);
    var $45 = $44;
    var $46 = __ZNK8JSObject5isXMLEv($45);
    if ($46) {
      __label__ = 8;
      break;
    } else {
      var $vxml_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $48 = __ZNK8JSObject10getPrivateEv($45);
    var $vxml_0 = $48;
    __label__ = 9;
    break;
   case 9:
    var $vxml_0;
    var $51 = $roots | 0;
    _OBJECT_TO_JSVAL4318($1, $obj);
    var $52 = $1 | 0;
    var $st$4$0 = $52 | 0;
    var $53$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $52 + 4 | 0;
    var $53$1 = HEAP32[$st$4$1 >> 2];
    var $54 = $roots | 0;
    var $st$9$0 = $54 | 0;
    HEAP32[$st$9$0 >> 2] = $53$0;
    var $st$9$1 = $54 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $53$1;
    __ZN2jsL9IdToJsvalEi4431($2, $id);
    var $55 = $2 | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = $roots + 8 | 0;
    HEAP32[$57 >> 2] = $56$0;
    HEAP32[$57 + 4 >> 2] = $56$1;
    var $58$0 = HEAP32[$38 >> 2];
    var $58$1 = HEAP32[$38 + 4 >> 2];
    var $59 = $roots + 16 | 0;
    HEAP32[$59 >> 2] = $58$0;
    HEAP32[$59 + 4 >> 2] = $58$1;
    var $60 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $60, 3, $51);
    var $61 = __Z12js_IdIsIndexiPj($id, $index);
    if (($61 | 0) == 0) {
      __label__ = 91;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ((HEAP32[$35 + 16 >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    __ZN2jsL9IdToValueEi4432($3, $id);
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $3);
    var $ok_13 = 0;
    __label__ = 188;
    break;
   case 12:
    var $69 = HEAPU32[$index >> 2];
    var $70 = $35 + 24 | 0;
    var $73 = HEAP32[$35 + 40 >> 2];
    if (($73 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $76 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $73, $rxml);
    var $78 = HEAP32[$rxml >> 2];
    if (($76 | 0) == 0 | ($78 | 0) == 0) {
      var $ok_13 = $76;
      __label__ = 188;
      break;
    } else {
      var $ok_0 = $76;
      var $82 = $78;
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[$rxml >> 2] = 0;
    var $ok_0 = 1;
    var $82 = 0;
    __label__ = 15;
    break;
   case 15:
    var $82;
    var $ok_0;
    var $83 = $70 | 0;
    var $84 = $70 | 0;
    if ($69 >>> 0 < HEAPU32[$84 >> 2] >>> 0) {
      var $ok_2 = $ok_0;
      var $i_0 = $69;
      __label__ = 51;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if (($82 | 0) == 0) {
      var $113 = $82;
      __label__ = 23;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $91 = HEAPU32[$82 + 16 >> 2];
    if (($91 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $ok_1 = $ok_0;
      var $110 = $82;
      var $109 = $91;
      __label__ = 22;
      break;
    }
   case 18:
    if ((HEAP32[$82 + 24 >> 2] | 0) == 1) {
      __label__ = 19;
      break;
    } else {
      var $ok_13 = $ok_0;
      __label__ = 188;
      break;
    }
   case 19:
    var $100 = HEAPU32[HEAP32[$82 + 32 >> 2] >> 2];
    var $101 = $100;
    HEAP32[$rxml >> 2] = $101;
    if (($100 | 0) == 0) {
      var $ok_13 = $ok_0;
      __label__ = 188;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $104 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $101);
    var $105 = ($104 | 0) != 0;
    var $106 = $105 & 1;
    if ($105) {
      __label__ = 21;
      break;
    } else {
      var $ok_13 = $106;
      __label__ = 188;
      break;
    }
   case 21:
    var $ok_1 = $106;
    var $110 = $101;
    var $109 = HEAP32[$100 + 16 >> 2];
    __label__ = 22;
    break;
   case 22:
    var $109;
    var $110;
    var $ok_1;
    if ($109 >>> 0 < 2) {
      var $113 = $110;
      __label__ = 23;
      break;
    } else {
      var $ok_13 = $ok_1;
      __label__ = 188;
      break;
    }
   case 23:
    var $113;
    var $116 = HEAPU32[$35 + 44 >> 2];
    if (($116 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $119 = __ZNK8JSObject17getQNameLocalNameEv($116);
    var $120 = $119 | 0;
    var $121 = __ZNK8JSString6lengthEv($120);
    if (($121 | 0) == 1) {
      __label__ = 25;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 25:
    var $124 = $119 | 0;
    var $125 = __ZNK14JSLinearString5charsEv($124);
    if (HEAP16[$125 >> 1] << 16 >> 16 == 42) {
      __label__ = 26;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 26:
    var $129 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($129 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $kid_1 = $129;
      __label__ = 36;
      break;
    }
   case 27:
    var $132 = $116;
    var $133 = __ZNK8JSObject8getClassEv($132);
    if (($133 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 28:
    var $137 = HEAP32[$113 >> 2];
    var $138 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $137, $id, $attrval);
    if (($138 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $141 = $attrval | 0;
    var $st$1$0 = $141 | 0;
    var $142$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $141 + 4 | 0;
    var $142$1 = HEAP32[$st$1$1 >> 2];
    var $143 = _JSVAL_IS_PRIMITIVE4303($142$0, $142$1);
    if (($143 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $ok_13 = $138;
      __label__ = 188;
      break;
    }
   case 30:
    var $st$0$0 = $141 | 0;
    var $146$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $141 + 4 | 0;
    var $146$1 = HEAP32[$st$0$1 >> 2];
    var $147 = _JSVAL_TO_OBJECT4304($146$0, $146$1);
    var $148 = $147;
    var $149 = __ZNK8JSObject10getPrivateEv($148);
    if (HEAPU32[$149 + 16 >> 2] >>> 0 < 2) {
      __label__ = 31;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 31:
    if ((HEAP32[$149 + 24 >> 2] | 0) == 0) {
      __label__ = 32;
      break;
    } else {
      var $ok_13 = $138;
      __label__ = 188;
      break;
    }
   case 32:
    var $158 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 2);
    var $kid_0 = $158;
    __label__ = 34;
    break;
   case 33:
    var $160 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 1);
    var $kid_0 = $160;
    __label__ = 34;
    break;
   case 34:
    var $kid_0;
    if (($kid_0 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    HEAP32[$kid_0 + 12 >> 2] = $116;
    var $kid_1 = $kid_0;
    __label__ = 36;
    break;
   case 36:
    var $kid_1;
    HEAP32[$kid_1 + 8 >> 2] = $113;
    var $167 = HEAPU32[$84 >> 2];
    if ((HEAP32[$kid_1 + 16 >> 2] | 0) == 2) {
      __label__ = 50;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    var $172 = HEAPU32[$rxml >> 2];
    if (($172 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $176 = HEAP32[$172 + 24 >> 2];
    var $177 = $176 - 1 | 0;
    if (($176 | 0) == 0 | ($167 | 0) == 0) {
      var $j_1 = $177;
      __label__ = 43;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $180 = $172 + 32 | 0;
    var $181 = $167 - 1 | 0;
    var $182 = $35 + 32 | 0;
    var $j_0 = 0;
    __label__ = 40;
    break;
   case 40:
    var $j_0;
    if ($j_0 >>> 0 < $177 >>> 0) {
      __label__ = 41;
      break;
    } else {
      var $j_1 = $j_0;
      __label__ = 43;
      break;
    }
   case 41:
    if ((HEAP32[HEAP32[$180 >> 2] + ($j_0 << 2) >> 2] | 0) == (HEAP32[HEAP32[$182 >> 2] + ($181 << 2) >> 2] | 0)) {
      var $j_1 = $j_0;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 40;
    break;
   case 43:
    var $j_1;
    var $195 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $kid_1);
    if (($195 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    var $198 = $j_1 + 1 | 0;
    _OBJECT_TO_JSVAL4318($4, $195);
    var $_idx14 = $4 | 0;
    var $st$3$0 = $_idx14 | 0;
    var $_idx14_val$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $_idx14 + 4 | 0;
    var $_idx14_val$1 = HEAP32[$st$3$1 >> 2];
    var $199 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $172, $198, $_idx14_val$0, $_idx14_val$1);
    if (($199 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if (($vxml_0 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if ((HEAP32[$vxml_0 + 16 >> 2] | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 48;
      break;
    }
   case 47:
    var $_in = $vxml_0 + 44 | 0;
    __label__ = 49;
    break;
   case 48:
    var $_in = $vxml_0 + 12 | 0;
    __label__ = 49;
    break;
   case 49:
    var $_in;
    var $213 = HEAP32[$_in >> 2];
    HEAP32[$kid_1 + 12 >> 2] = $213;
    __label__ = 50;
    break;
   case 50:
    var $216 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $35, $kid_1);
    if (($216 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_2 = $216;
      var $i_0 = $167;
      __label__ = 51;
      break;
    }
   case 51:
    var $i_0;
    var $ok_2;
    var $219 = ($vxml_0 | 0) != 0;
    if ($219) {
      __label__ = 52;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 52:
    var $222 = HEAP32[$vxml_0 + 16 >> 2];
    if (($222 | 0) == 4 || ($222 | 0) == 2) {
      __label__ = 53;
      break;
    } else {
      var $ok_3 = $ok_2;
      __label__ = 55;
      break;
    }
   case 53:
    var $st$0$0 = $38 | 0;
    var $224$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $224$1 = HEAP32[$st$0$1 >> 2];
    var $225 = $5 | 0;
    var $st$5$0 = $225 | 0;
    HEAP32[$st$5$0 >> 2] = $224$0;
    var $st$5$1 = $225 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $224$1;
    var $226 = _JS_ConvertValue($60, $5, 3, $vp);
    if (($226 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 54:
    var $st$0$0 = $38 | 0;
    var $229$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $229$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $59 | 0;
    HEAP32[$st$4$0 >> 2] = $229$0;
    var $st$4$1 = $59 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $229$1;
    var $ok_3 = $226;
    __label__ = 55;
    break;
   case 55:
    var $ok_3;
    if ($i_0 >>> 0 < HEAPU32[$84 >> 2] >>> 0) {
      __label__ = 56;
      break;
    } else {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    }
   case 56:
    var $233 = $35 + 32 | 0;
    var $236 = HEAPU32[HEAP32[$233 >> 2] + ($i_0 << 2) >> 2];
    var $237 = $236;
    if (($236 | 0) == 0) {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 57:
    var $242 = HEAPU32[$236 + 8 >> 2];
    var $245 = HEAPU32[$236 + 16 >> 2];
    if (($245 | 0) == 2) {
      __label__ = 58;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 58:
    var $250 = HEAP32[$236 + 12 >> 2];
    var $251 = $250;
    var $252 = __ZNK8JSObject8getClassEv($251);
    if (($252 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      var $nameobj_0 = $250;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $255 = __ZNK8JSObject10getNameURIEv($250);
    var $256 = __ZNK8JSObject13getNamePrefixEv($250);
    var $257 = __ZNK8JSObject17getQNameLocalNameEv($250);
    var $258 = __ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $255, $256, $257);
    if (($258 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $nameobj_0 = $258;
      __label__ = 60;
      break;
    }
   case 60:
    var $nameobj_0;
    var $261 = _OBJECT_TO_JSID4356($nameobj_0);
    if (($242 | 0) == 0) {
      var $ok_13 = $ok_3;
      __label__ = 188;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 61:
    var $264 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $242);
    if (($264 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    var $267 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $264, $261, $strict, $vp);
    if (($267 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $270 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $264, $261, $vp);
    if (($270 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    var $st$0$0 = $38 | 0;
    var $273$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $273$1 = HEAP32[$st$0$1 >> 2];
    var $274 = _JSVAL_TO_OBJECT4304($273$0, $273$1);
    var $275 = $274;
    var $276 = __ZNK8JSObject10getPrivateEv($275);
    if ((HEAP32[$276 + 24 >> 2] | 0) == 0) {
      var $ok_13 = $270;
      __label__ = 188;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    var $285 = HEAP32[HEAP32[$276 + 32 >> 2] >> 2];
    var $287 = HEAP32[$233 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$287 >> 2] = $285;
    var $ok_13 = $270;
    __label__ = 188;
    break;
   case 66:
    if ($219) {
      __label__ = 67;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 67:
    if ((HEAP32[$vxml_0 + 16 >> 2] | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 68:
    var $294 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $vxml_0);
    if (($294 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    var $297 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $294);
    if (($297 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    if (($242 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $_idx8_val = HEAP32[$242 + 24 >> 2];
    var $_idx9_val = HEAP32[$242 + 32 >> 2];
    var $302 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx8_val, $_idx9_val, $236, 0);
    _OBJECT_TO_JSVAL4318($6, $297);
    var $_idx19 = $6 | 0;
    var $st$7$0 = $_idx19 | 0;
    var $_idx19_val$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $_idx19 + 4 | 0;
    var $_idx19_val$1 = HEAP32[$st$7$1 >> 2];
    var $303 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $242, $302, $_idx19_val$0, $_idx19_val$1);
    if (($303 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_4 = $303;
      __label__ = 72;
      break;
    }
   case 72:
    var $ok_4;
    var $307 = HEAP32[$294 + 24 >> 2];
    if (($307 | 0) == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 74;
      break;
    }
   case 73:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($83, $i_0, 1);
    var $ok_13 = $ok_4;
    __label__ = 188;
    break;
   case 74:
    var $312 = $307 - 1 | 0;
    var $313 = __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $83, $i_0 + 1 | 0, $312);
    if (($313 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 75;
      break;
    }
   case 75:
    var $315 = $294 + 32 | 0;
    var $j_215 = 0;
    __label__ = 76;
    break;
   case 76:
    var $j_215;
    var $319 = HEAP32[HEAP32[$315 >> 2] + ($j_215 << 2) >> 2];
    var $322 = HEAP32[$233 >> 2] + ($j_215 + $i_0 << 2) | 0;
    HEAP32[$322 >> 2] = $319;
    var $323 = $j_215 + 1 | 0;
    if (($323 | 0) == ($307 | 0)) {
      var $ok_13 = $313;
      __label__ = 188;
      break;
    } else {
      var $j_215 = $323;
      __label__ = 76;
      break;
    }
   case 77:
    if ($245 >>> 0 > 1) {
      __label__ = 78;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 78:
    if (($242 | 0) == 0) {
      __label__ = 83;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $_idx6 = $242 + 24 | 0;
    var $_idx6_val = HEAP32[$_idx6 >> 2];
    var $_idx7 = $242 + 32 | 0;
    var $_idx7_val = HEAP32[$_idx7 >> 2];
    var $328 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx6_val, $_idx7_val, $236, 0);
    var $st$5$0 = $38 | 0;
    var $329$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $38 + 4 | 0;
    var $329$1 = HEAP32[$st$5$1 >> 2];
    var $330 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $242, $328, $329$0, $329$1);
    if (($330 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 80:
    if ($328 >>> 0 < HEAPU32[$_idx6 >> 2] >>> 0) {
      __label__ = 81;
      break;
    } else {
      var $ok_13 = $330;
      __label__ = 188;
      break;
    }
   case 81:
    var $338 = HEAPU32[HEAP32[$_idx7 >> 2] + ($328 << 2) >> 2];
    if (($338 | 0) == 0) {
      var $ok_13 = $330;
      __label__ = 188;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 82:
    var $340 = $338;
    var $342 = HEAP32[$338 >> 2];
    _OBJECT_TO_JSVAL4318($7, $342);
    var $343 = $7 | 0;
    var $st$5$0 = $343 | 0;
    var $344$0 = HEAP32[$st$5$0 >> 2];
    var $st$5$1 = $343 + 4 | 0;
    var $344$1 = HEAP32[$st$5$1 >> 2];
    var $st$9$0 = $38 | 0;
    HEAP32[$st$9$0 >> 2] = $344$0;
    var $st$9$1 = $38 + 4 | 0;
    HEAP32[$st$9$1 >> 2] = $344$1;
    HEAP32[$59 >> 2] = $344$0;
    HEAP32[$59 + 4 >> 2] = $344$1;
    var $vxml_2 = $340;
    var $ok_510 = $330;
    __label__ = 86;
    break;
   case 83:
    if (($vxml_0 | 0) == 0) {
      __label__ = 84;
      break;
    } else {
      var $vxml_2 = $vxml_0;
      var $ok_510 = $ok_3;
      __label__ = 86;
      break;
    }
   case 84:
    var $st$0$0 = $38 | 0;
    var $348$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $348$1 = HEAP32[$st$0$1 >> 2];
    var $349 = __ZL5ToXMLP9JSContextN2JS5ValueE($cx, $348$0, $348$1);
    if (($349 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 85:
    _OBJECT_TO_JSVAL4318($8, $349);
    var $352 = $8 | 0;
    var $st$2$0 = $352 | 0;
    var $353$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $352 + 4 | 0;
    var $353$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $38 | 0;
    HEAP32[$st$6$0 >> 2] = $353$0;
    var $st$6$1 = $38 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $353$1;
    var $st$10$0 = $59 | 0;
    HEAP32[$st$10$0 >> 2] = $353$0;
    var $st$10$1 = $59 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $353$1;
    var $354 = $349;
    var $355 = __ZNK8JSObject10getPrivateEv($354);
    var $vxml_2 = $355;
    var $ok_510 = $ok_3;
    __label__ = 86;
    break;
   case 86:
    var $ok_510;
    var $vxml_2;
    if (HEAPU32[$84 >> 2] >>> 0 > $i_0 >>> 0) {
      __label__ = 88;
      break;
    } else {
      __label__ = 87;
      break;
    }
   case 87:
    HEAP32[$84 >> 2] = $i_0 + 1 | 0;
    __label__ = 88;
    break;
   case 88:
    var $364 = HEAP32[$233 >> 2] + ($i_0 << 2) | 0;
    HEAP32[$364 >> 2] = $vxml_2;
    var $ok_13 = $ok_510;
    __label__ = 188;
    break;
   case 89:
    var $366 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $237);
    if (($366 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    var $373 = HEAP32[HEAP32[$cx + 52 >> 2] + 210412 >> 2] | 0;
    var $374 = __ZL12ATOM_TO_JSIDP6JSAtom4336($373);
    var $375 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $366, $374, $strict, $vp);
    var $ok_13 = $375;
    __label__ = 188;
    break;
   case 91:
    __ZN2jsL9IdToJsvalEi4431($9, $id);
    var $_idx13 = $9 | 0;
    var $st$2$0 = $_idx13 | 0;
    var $_idx13_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx13 + 4 | 0;
    var $_idx13_val$1 = HEAP32[$st$2$1 >> 2];
    var $377 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx13_val$0, $_idx13_val$1, $funid);
    if (($377 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 92;
      break;
    }
   case 92:
    var $380 = HEAP32[$funid >> 2];
    var $381 = _JSID_IS_VOID4359($380);
    if (($381 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 93:
    var $384 = $cx;
    var $385 = $obj;
    var $386 = __Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi($384, $385, $380, 0, $vp, 0);
    var $ok_13 = $386;
    __label__ = 188;
    break;
   case 94:
    _OBJECT_TO_JSVAL4318($10, $377);
    var $388 = $10 | 0;
    var $st$2$0 = $388 | 0;
    var $389$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $388 + 4 | 0;
    var $389$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $57 | 0;
    HEAP32[$st$6$0 >> 2] = $389$0;
    var $st$6$1 = $57 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $389$1;
    var $391 = HEAPU32[$35 + 16 >> 2];
    if (($391 | 0) == 0) {
      __label__ = 95;
      break;
    } else {
      var $ok_7 = 1;
      var $xml_0 = $35;
      var $430 = $391;
      __label__ = 106;
      break;
    }
   case 95:
    var $394 = $35 + 24 | 0;
    var $395 = HEAPU32[$394 >> 2];
    if ($395 >>> 0 > 1) {
      __label__ = 189;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 96:
    if (($395 | 0) == 0) {
      __label__ = 97;
      break;
    } else {
      var $ok_633 = 1;
      __label__ = 103;
      break;
    }
   case 97:
    var $400 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $35, $rxml);
    if (($400 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    var $403 = HEAPU32[$rxml >> 2];
    if (($403 | 0) == 0) {
      __label__ = 189;
      break;
    } else {
      __label__ = 99;
      break;
    }
   case 99:
    if (HEAPU32[$403 + 16 >> 2] >>> 0 < 2) {
      __label__ = 100;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 100:
    if ((HEAP32[$403 + 24 >> 2] | 0) == 1) {
      __label__ = 101;
      break;
    } else {
      __label__ = 189;
      break;
    }
   case 101:
    var $413 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $35, $403);
    if (($413 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 102:
    if ((HEAP32[$394 >> 2] | 0) == 0) {
      var $ok_13 = $413;
      __label__ = 188;
      break;
    } else {
      var $ok_633 = $413;
      __label__ = 103;
      break;
    }
   case 103:
    var $ok_633;
    var $419 = HEAPU32[HEAP32[$35 + 32 >> 2] >> 2];
    var $420 = $419;
    if (($419 | 0) == 0) {
      var $ok_13 = $ok_633;
      __label__ = 188;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    var $423 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $420);
    if (($423 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 105;
      break;
    }
   case 105:
    _OBJECT_TO_JSVAL4318($11, $423);
    var $426 = $11 | 0;
    var $st$2$0 = $426 | 0;
    var $427$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $426 + 4 | 0;
    var $427$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $54 | 0;
    HEAP32[$st$6$0 >> 2] = $427$0;
    var $st$6$1 = $54 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $427$1;
    var $ok_7 = $ok_633;
    var $xml_0 = $420;
    var $430 = HEAP32[$419 + 16 >> 2];
    __label__ = 106;
    break;
   case 106:
    var $430;
    var $xml_0;
    var $ok_7;
    if ($430 >>> 0 > 1) {
      var $ok_13 = $ok_7;
      __label__ = 188;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 107:
    if (($vxml_0 | 0) == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    var $436 = HEAP32[$vxml_0 + 16 >> 2];
    if (($436 | 0) == 4 || ($436 | 0) == 2) {
      __label__ = 109;
      break;
    } else {
      __label__ = 111;
      break;
    }
   case 109:
    var $st$0$0 = $38 | 0;
    var $438$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $438$1 = HEAP32[$st$0$1 >> 2];
    var $439 = $12 | 0;
    var $st$5$0 = $439 | 0;
    HEAP32[$st$5$0 >> 2] = $438$0;
    var $st$5$1 = $439 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $438$1;
    var $440 = _JS_ConvertValue($60, $12, 3, $vp);
    if (($440 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 110;
      break;
    }
   case 110:
    var $st$0$0 = $38 | 0;
    var $st$0$1 = $38 + 4 | 0;
    var $vxml_3 = $vxml_0;
    var $454$1 = HEAP32[$st$0$1 >> 2];
    var $454$0 = HEAP32[$st$0$0 >> 2];
    __label__ = 114;
    break;
   case 111:
    var $443 = __ZL13DeepCopyInLRSP9JSContextP5JSXMLj($cx, $vxml_0);
    HEAP32[$rxml >> 2] = $443;
    if (($443 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 112:
    var $446 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $443);
    if (($446 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $450 = HEAP32[$443 >> 2];
    _OBJECT_TO_JSVAL4318($13, $450);
    var $451 = $13 | 0;
    var $st$4$0 = $451 | 0;
    var $452$0 = HEAP32[$st$4$0 >> 2];
    var $st$4$1 = $451 + 4 | 0;
    var $452$1 = HEAP32[$st$4$1 >> 2];
    HEAP32[$38 >> 2] = $452$0;
    HEAP32[$38 + 4 >> 2] = $452$1;
    var $vxml_3 = $443;
    var $454$1 = $452$1;
    var $454$0 = $452$0;
    __label__ = 114;
    break;
   case 114:
    var $454$0;
    var $454$1;
    var $vxml_3;
    var $st$3$0 = $59 | 0;
    HEAP32[$st$3$0 >> 2] = $454$0;
    var $st$3$1 = $59 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $454$1;
    var $455 = __Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE($cx, $nsval);
    if (($455 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 115;
      break;
    }
   case 115:
    var $458 = $377;
    var $459 = __ZNK8JSObject8getClassEv($458);
    if (($459 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 116;
      break;
    } else {
      __label__ = 152;
      break;
    }
   case 116:
    _OBJECT_TO_JSVAL4318($14, $377);
    var $462 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $14);
    if (($462 | 0) == 0) {
      var $ok_13 = $455;
      __label__ = 188;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    if (($vxml_3 | 0) == 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 118:
    if ((HEAP32[$vxml_3 + 16 >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      __label__ = 129;
      break;
    }
   case 119:
    var $472 = HEAPU32[$vxml_3 + 24 >> 2];
    if (($472 | 0) == 0) {
      __label__ = 120;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 120:
    var $479 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($15, $479);
    var $480 = $15 | 0;
    var $st$7$0 = $480 | 0;
    var $481$0 = HEAP32[$st$7$0 >> 2];
    var $st$7$1 = $480 + 4 | 0;
    var $481$1 = HEAP32[$st$7$1 >> 2];
    HEAP32[$38 >> 2] = $481$0;
    HEAP32[$38 + 4 >> 2] = $481$1;
    var $ok_8 = $455;
    __label__ = 131;
    break;
   case 121:
    var $483 = __ZL11KidToStringP9JSContextP5JSXMLj($cx, $vxml_3, 0);
    if (($483 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    var $490 = HEAP32[HEAP32[$cx + 52 >> 2] + 210404 >> 2] | 0;
    var $left_0 = $483;
    var $i_1 = 1;
    __label__ = 123;
    break;
   case 123:
    var $i_1;
    var $left_0;
    if ($i_1 >>> 0 < $472 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 124:
    var $494 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($60, $left_0, $490);
    if (($494 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 125;
      break;
    }
   case 125:
    var $497 = __ZL11KidToStringP9JSContextP5JSXMLj($cx, $vxml_3, $i_1);
    if (($497 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 126:
    var $500 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($60, $494, $497);
    if (($500 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 127:
    var $left_0 = $500;
    var $i_1 = $i_1 + 1 | 0;
    __label__ = 123;
    break;
   case 128:
    _STRING_TO_JSVAL4322($16, $left_0);
    var $505 = $16 | 0;
    var $st$2$0 = $505 | 0;
    var $506$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $505 + 4 | 0;
    var $506$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $38 | 0;
    HEAP32[$st$6$0 >> 2] = $506$0;
    var $st$6$1 = $38 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $506$1;
    var $st$10$0 = $59 | 0;
    HEAP32[$st$10$0 >> 2] = $506$0;
    var $st$10$1 = $59 + 4 | 0;
    HEAP32[$st$10$1 >> 2] = $506$1;
    var $ok_8 = $455;
    __label__ = 131;
    break;
   case 129:
    var $st$0$0 = $38 | 0;
    var $508$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $508$1 = HEAP32[$st$0$1 >> 2];
    var $509 = $17 | 0;
    var $st$5$0 = $509 | 0;
    HEAP32[$st$5$0 >> 2] = $508$0;
    var $st$5$1 = $509 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $508$1;
    var $510 = _JS_ConvertValue($60, $17, 3, $vp);
    if (($510 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    var $st$0$0 = $38 | 0;
    var $513$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $513$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $59 | 0;
    HEAP32[$st$4$0 >> 2] = $513$0;
    var $st$4$1 = $59 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $513$1;
    var $ok_8 = $510;
    __label__ = 131;
    break;
   case 131:
    var $ok_8;
    var $515 = $xml_0 + 56 | 0;
    var $516 = $515 | 0;
    var $517 = HEAPU32[$516 >> 2];
    if (($517 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      __label__ = 132;
      break;
    }
   case 132:
    var $519 = $xml_0 + 64 | 0;
    var $i_219 = 0;
    var $match_020 = 0;
    var $521 = $517;
    __label__ = 133;
    break;
   case 133:
    var $521;
    var $match_020;
    var $i_219;
    if ($i_219 >>> 0 < $521 >>> 0) {
      __label__ = 134;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 134:
    var $526 = HEAPU32[HEAP32[$519 >> 2] + ($i_219 << 2) >> 2];
    var $527 = $526;
    if (($526 | 0) == 0) {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    } else {
      __label__ = 135;
      break;
    }
   case 135:
    var $532 = HEAPU32[$526 + 12 >> 2];
    var $533 = __ZNK8JSObject17getQNameLocalNameEv($532);
    var $534 = $533 | 0;
    var $535 = __ZNK8JSObject17getQNameLocalNameEv($377);
    var $536 = $535 | 0;
    var $537 = __ZN2js12EqualStringsEP14JSLinearStringS1_($534, $536);
    if ($537) {
      __label__ = 136;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 136:
    var $539 = __ZNK8JSObject10getNameURIEv($377);
    if (($539 | 0) == 0) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $542 = __ZNK8JSObject10getNameURIEv($532);
    var $543 = __ZN2js12EqualStringsEP14JSLinearStringS1_($542, $539);
    if ($543) {
      __label__ = 138;
      break;
    } else {
      var $match_1 = $match_020;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    }
   case 138:
    if (($match_020 | 0) == 0) {
      var $match_1 = $527;
      var $i_3 = $i_219;
      __label__ = 140;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 139:
    __ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti($xml_0, $532, 1);
    var $match_1 = $match_020;
    var $i_3 = $i_219 - 1 | 0;
    __label__ = 140;
    break;
   case 140:
    var $i_3;
    var $match_1;
    var $548 = $i_3 + 1 | 0;
    if ($548 >>> 0 < $517 >>> 0) {
      __label__ = 141;
      break;
    } else {
      __label__ = 142;
      break;
    }
   case 141:
    var $i_219 = $548;
    var $match_020 = $match_1;
    var $521 = HEAP32[$516 >> 2];
    __label__ = 133;
    break;
   case 142:
    if (($match_1 | 0) == 0) {
      __label__ = 143;
      break;
    } else {
      var $ok_9 = $ok_8;
      var $attr_0 = $match_1;
      __label__ = 151;
      break;
    }
   case 143:
    var $551 = __ZNK8JSObject10getNameURIEv($377);
    if (($551 | 0) == 0) {
      __label__ = 144;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    var $558 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    var $right3_0 = $558;
    var $left2_0 = $558;
    __label__ = 146;
    break;
   case 145:
    var $560 = __ZNK8JSObject13getNamePrefixEv($377);
    var $right3_0 = $560;
    var $left2_0 = $551;
    __label__ = 146;
    break;
   case 146:
    var $left2_0;
    var $right3_0;
    var $562 = __ZNK8JSObject17getQNameLocalNameEv($377);
    var $563 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $left2_0, $right3_0, $562);
    if (($563 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 147;
      break;
    }
   case 147:
    var $566 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 2);
    if (($566 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 148;
      break;
    }
   case 148:
    HEAP32[$566 + 8 >> 2] = $xml_0;
    HEAP32[$566 + 12 >> 2] = $563;
    var $571 = $566;
    var $572 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $515, $517, $571);
    if (($572 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 149:
    var $575 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $563, 0);
    if (($575 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 150;
      break;
    }
   case 150:
    var $578 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $xml_0, $575);
    if (($578 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_9 = $578;
      var $attr_0 = $566;
      __label__ = 151;
      break;
    }
   case 151:
    var $attr_0;
    var $ok_9;
    var $st$2$0 = $38 | 0;
    var $580$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $38 + 4 | 0;
    var $580$1 = HEAP32[$st$2$1 >> 2];
    var $581 = _JSVAL_TO_STRING4321($580$0, $580$1);
    var $_c = $581;
    HEAP32[$attr_0 + 24 >> 2] = $_c;
    var $ok_13 = $ok_9;
    __label__ = 188;
    break;
   case 152:
    _OBJECT_TO_JSVAL4318($18, $377);
    var $584 = __Z12js_IsXMLNameP9JSContextN2JS5ValueE($cx, $18);
    if (($584 | 0) == 0) {
      __label__ = 153;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 153:
    var $587 = __ZNK8JSObject17getQNameLocalNameEv($377);
    var $588 = $587 | 0;
    var $589 = __ZNK8JSString6lengthEv($588);
    if (($589 | 0) == 1) {
      __label__ = 154;
      break;
    } else {
      var $ok_13 = $455;
      __label__ = 188;
      break;
    }
   case 154:
    var $592 = $587 | 0;
    var $593 = __ZNK14JSLinearString5charsEv($592);
    if (HEAP16[$593 >> 1] << 16 >> 16 == 42) {
      __label__ = 155;
      break;
    } else {
      var $ok_13 = $455;
      __label__ = 188;
      break;
    }
   case 155:
    if (($vxml_3 | 0) == 0) {
      __label__ = 156;
      break;
    } else {
      var $608 = 0;
      __label__ = 158;
      break;
    }
   case 156:
    var $599 = __ZNK8JSObject17getQNameLocalNameEv($377);
    var $600 = $599 | 0;
    var $601 = __ZNK8JSString6lengthEv($600);
    if (($601 | 0) == 1) {
      __label__ = 157;
      break;
    } else {
      var $608 = 1;
      __label__ = 158;
      break;
    }
   case 157:
    var $604 = $599 | 0;
    var $605 = __ZNK14JSLinearString5charsEv($604);
    var $608 = HEAP16[$605 >> 1] << 16 >> 16 != 42;
    __label__ = 158;
    break;
   case 158:
    var $608;
    var $609 = $xml_0 + 24 | 0;
    var $610 = $609 | 0;
    var $611 = HEAPU32[$610 >> 2];
    var $612 = $xml_0 + 32 | 0;
    var $kid2_0_ph = 0;
    var $matchIndex_0_ph = -1;
    var $k_0_ph = $611;
    __label__ = 159;
    break;
   case 159:
    var $k_0_ph;
    var $matchIndex_0_ph;
    var $kid2_0_ph;
    var $k_0 = $k_0_ph;
    __label__ = 160;
    break;
   case 160:
    var $k_0;
    if (($k_0 | 0) == 0) {
      __label__ = 166;
      break;
    } else {
      __label__ = 161;
      break;
    }
   case 161:
    var $615 = $k_0 - 1 | 0;
    if ($615 >>> 0 < HEAPU32[$610 >> 2] >>> 0) {
      __label__ = 162;
      break;
    } else {
      var $k_0 = $615;
      __label__ = 160;
      break;
    }
   case 162:
    var $621 = HEAP32[HEAP32[$612 >> 2] + ($615 << 2) >> 2];
    var $622 = $621;
    if (($621 | 0) == 0) {
      var $k_0 = $615;
      __label__ = 160;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $625 = __ZL13MatchElemNameP8JSObjectP5JSXML($377, $622);
    if (($625 | 0) == 0) {
      var $k_0 = $615;
      __label__ = 160;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    if (($matchIndex_0_ph | 0) == -1) {
      var $kid2_0_ph = $622;
      var $matchIndex_0_ph = $615;
      var $k_0_ph = $615;
      __label__ = 159;
      break;
    } else {
      __label__ = 165;
      break;
    }
   case 165:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml_0, $matchIndex_0_ph);
    var $kid2_0_ph = $622;
    var $matchIndex_0_ph = $615;
    var $k_0_ph = $615;
    __label__ = 159;
    break;
   case 166:
    if (($kid2_0_ph | 0) == 0) {
      __label__ = 169;
      break;
    } else {
      __label__ = 167;
      break;
    }
   case 167:
    var $633 = $kid2_0_ph + 8 | 0;
    if ((HEAP32[$633 >> 2] | 0) == 0) {
      __label__ = 168;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 168:
    HEAP32[$633 >> 2] = $xml_0;
    __label__ = 169;
    break;
   case 169:
    var $_not = ($matchIndex_0_ph | 0) != -1;
    var $matchIndex_0_mux = $_not ? $matchIndex_0_ph : $611;
    if ($_not | $608 ^ 1) {
      var $ok_10 = $455;
      var $matchIndex_1 = $matchIndex_0_mux;
      __label__ = 178;
      break;
    } else {
      __label__ = 170;
      break;
    }
   case 170:
    var $639 = __ZNK8JSObject10getNameURIEv($377);
    if (($639 | 0) == 0) {
      __label__ = 171;
      break;
    } else {
      __label__ = 172;
      break;
    }
   case 171:
    var $642 = $nsval | 0;
    var $st$1$0 = $642 | 0;
    var $643$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $642 + 4 | 0;
    var $643$1 = HEAP32[$st$1$1 >> 2];
    var $644 = _JSVAL_TO_OBJECT4304($643$0, $643$1);
    var $645 = __ZNK8JSObject10getNameURIEv($644);
    var $646 = __ZNK8JSObject13getNamePrefixEv($644);
    var $right6_0 = $646;
    var $left5_0 = $645;
    __label__ = 173;
    break;
   case 172:
    var $648 = __ZNK8JSObject13getNamePrefixEv($377);
    var $right6_0 = $648;
    var $left5_0 = $639;
    __label__ = 173;
    break;
   case 173:
    var $left5_0;
    var $right6_0;
    var $650 = __ZNK8JSObject17getQNameLocalNameEv($377);
    var $651 = __ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom($cx, $left5_0, $right6_0, $650);
    if (($651 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 174;
      break;
    }
   case 174:
    var $654 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 1);
    if (($654 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 175:
    var $657 = $654;
    var $658 = __ZNK8JSObject10getPrivateEv($657);
    var $659 = $658;
    HEAP32[$658 + 8 >> 2] = $xml_0;
    HEAP32[$658 + 12 >> 2] = $651;
    var $664 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $651, 0);
    if (($664 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 176;
      break;
    }
   case 176:
    _OBJECT_TO_JSVAL4318($19, $654);
    var $_idx17 = $19 | 0;
    var $st$2$0 = $_idx17 | 0;
    var $_idx17_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx17 + 4 | 0;
    var $_idx17_val$1 = HEAP32[$st$2$1 >> 2];
    var $667 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml_0, $611, $_idx17_val$0, $_idx17_val$1);
    if (($667 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $670 = __ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject($cx, $659, $664);
    if (($670 | 0) == 0) {
      var $ok_13 = 0;
      __label__ = 188;
      break;
    } else {
      var $ok_10 = $670;
      var $matchIndex_1 = $611;
      __label__ = 178;
      break;
    }
   case 178:
    var $matchIndex_1;
    var $ok_10;
    if ($608) {
      __label__ = 179;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 179:
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $609);
    HEAP32[$cursor + 4 >> 2] = $matchIndex_1;
    var $675 = __ZN16JSXMLArrayCursor10getCurrentEv($cursor);
    var $676 = $675;
    if (HEAPU32[$675 + 16 >> 2] >>> 0 < 2) {
      __label__ = 180;
      break;
    } else {
      var $ok_11 = $ok_10;
      __label__ = 181;
      break;
    }
   case 180:
    var $683 = $675 + 24 | 0;
    __ZN10JSXMLArray6finishEP9JSContext($683, $cx);
    __ZN10JSXMLArray4initEv($683);
    var $684 = __ZN10JSXMLArray11setCapacityEP9JSContextj($683, $cx, 1);
    var $ok_11 = $684 & 1;
    __label__ = 181;
    break;
   case 181:
    var $ok_11;
    if (($ok_11 | 0) == 0) {
      var $ok_12 = 0;
      __label__ = 186;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 182:
    var $st$0$0 = $38 | 0;
    var $689$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $689$1 = HEAP32[$st$0$1 >> 2];
    var $690 = $20 | 0;
    var $st$5$0 = $690 | 0;
    HEAP32[$st$5$0 >> 2] = $689$0;
    var $st$5$1 = $690 + 4 | 0;
    HEAP32[$st$5$1 >> 2] = $689$1;
    var $691 = _JS_ConvertValue($60, $20, 3, $vp);
    if (($691 | 0) == 0) {
      var $ok_12 = 0;
      __label__ = 186;
      break;
    } else {
      __label__ = 183;
      break;
    }
   case 183:
    var $st$0$0 = $38 | 0;
    var $694$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $694$1 = HEAP32[$st$0$1 >> 2];
    var $695 = _JSVAL_TO_STRING4321($694$0, $694$1);
    var $696 = __ZNK8JSString5emptyEv($695);
    if ($696) {
      var $ok_12 = $691;
      __label__ = 186;
      break;
    } else {
      __label__ = 184;
      break;
    }
   case 184:
    var $st$0$0 = $38 | 0;
    var $698$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $698$1 = HEAP32[$st$0$1 >> 2];
    var $st$4$0 = $59 | 0;
    HEAP32[$st$4$0 >> 2] = $698$0;
    var $st$4$1 = $59 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $698$1;
    var $699 = __ZN16JSXMLArrayCursor10getCurrentEv($cursor);
    if (($699 | 0) == ($675 | 0)) {
      __label__ = 185;
      break;
    } else {
      var $ok_12 = $691;
      __label__ = 186;
      break;
    }
   case 185:
    var $st$0$0 = $38 | 0;
    var $702$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $702$1 = HEAP32[$st$0$1 >> 2];
    var $703 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $676, 0, $702$0, $702$1);
    var $ok_12 = $703;
    __label__ = 186;
    break;
   case 186:
    var $ok_12;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $ok_13 = $ok_12;
    __label__ = 188;
    break;
   case 187:
    var $st$0$0 = $38 | 0;
    var $706$0 = HEAP32[$st$0$0 >> 2];
    var $st$0$1 = $38 + 4 | 0;
    var $706$1 = HEAP32[$st$0$1 >> 2];
    var $707 = __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml_0, $matchIndex_1, $706$0, $706$1);
    var $ok_13 = $707;
    __label__ = 188;
    break;
   case 188:
    var $ok_13;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_0 = $ok_13;
    __label__ = 192;
    break;
   case 189:
    __ZN16JSAutoByteStringC1Ev($bytes);
    __ZN2jsL9IdToValueEi4432($21, $id);
    var $708 = $cx;
    var $709 = $bytes;
    var $710 = __Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb($708, $21, $709, 0);
    if (($710 | 0) == 0) {
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $713 = __ZNK16JSAutoByteString3ptrEv($bytes);
    _JS_ReportErrorNumber($60, 2, 0, 194, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $713, tempInt));
    __label__ = 191;
    break;
   case 191:
    __ZN16JSAutoByteStringD1Ev($bytes);
    var $ok_13 = 0;
    __label__ = 188;
    break;
   case 192:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE["X"] = 1;

function __ZN16JSXMLArrayCursor10getCurrentEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this >> 2];
    if (($2 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = HEAPU32[$this + 4 >> 2];
    if ($6 >>> 0 < HEAPU32[$2 >> 2] >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $14 = HEAP32[HEAP32[$2 + 8 >> 2] + ($6 << 2) >> 2];
    HEAP32[$this + 16 >> 2] = $14;
    var $_0 = $14;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2jsL9IdToJsvalEi4431($agg_result, $id) {
  __ZN2jsL9IdToValueEi4432($agg_result, $id);
  return;
}

function __ZN2jsL9IdToValueEi4432($agg_result, $id) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSID_IS_STRING4403($id);
    if (($1 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSID_TO_STRING4405($id);
    __ZN2JSL11StringValueEP8JSString4311($agg_result, $4);
    __label__ = 8;
    break;
   case 3:
    var $6 = _JSID_IS_INT4401($id);
    if (($6 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $9 = _JSID_TO_INT4402($id);
    __ZN2JSL10Int32ValueEi4433($agg_result, $9);
    __label__ = 8;
    break;
   case 5:
    var $11 = _JSID_IS_OBJECT4314($id);
    if (($11 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $14 = _JSID_TO_OBJECT4315($id);
    __ZN2JSL11ObjectValueER8JSObject4319($agg_result, $14);
    __label__ = 8;
    break;
   case 7:
    __ZN2JSL14UndefinedValueEv4406($agg_result);
    __label__ = 8;
    break;
   case 8:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $list, $result) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 20;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $base = __stackBase__;
    var $tv = __stackBase__ + 4;
    var $1 = __stackBase__ + 12;
    if ((HEAP32[$list + 16 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    if ((HEAP32[$list + 24 >> 2] | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $list);
    if (($10 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    HEAP32[$result >> 2] = $list;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 5:
    var $16 = HEAP32[$list + 40 >> 2];
    var $19 = HEAP32[$list + 44 >> 2];
    if (($16 | 0) == 0 | ($19 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = __ZNK8JSObject17getQNameLocalNameEv($19);
    var $24 = $23 | 0;
    var $25 = __ZNK8JSString6lengthEv($24);
    if (($25 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 7:
    var $28 = $23 | 0;
    var $29 = __ZNK14JSLinearString5charsEv($28);
    if (HEAP16[$29 >> 1] << 16 >> 16 == 42) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 9:
    var $34 = $19;
    var $35 = __ZNK8JSObject8getClassEv($34);
    if (($35 | 0) == (__ZN2js18AttributeNameClassE | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 11:
    var $39 = __ZL12ResolveValueP9JSContextP5JSXMLPS2_($cx, $16, $base);
    if (($39 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $42 = HEAPU32[$base >> 2];
    if (($42 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 14:
    var $46 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $42);
    if (($46 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $49 = _OBJECT_TO_JSID4356($19);
    var $50 = $42 | 0;
    var $51 = HEAP32[$50 >> 2];
    var $52 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $51, $49, $tv);
    if (($52 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = $tv | 0;
    var $56$0 = HEAP32[$55 >> 2];
    var $56$1 = HEAP32[$55 + 4 >> 2];
    var $57 = _JSVAL_TO_OBJECT4304($56$0, $56$1);
    var $58 = $57;
    var $59 = __ZNK8JSObject10getPrivateEv($58);
    if (HEAPU32[$59 + 16 >> 2] >>> 0 < 2) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    if ((HEAP32[$59 + 24 >> 2] | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      var $target_0_in = $59;
      __label__ = 24;
      break;
    }
   case 18:
    if ((HEAP32[$42 + 16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 19:
    if (HEAPU32[$42 + 24 >> 2] >>> 0 > 1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[$result >> 2] = 0;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 21:
    var $79 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    _STRING_TO_JSVAL4322($1, $79);
    var $80 = $1 | 0;
    var $81$0 = HEAP32[$80 >> 2];
    var $81$1 = HEAP32[$80 + 4 >> 2];
    HEAP32[$55 >> 2] = $81$0;
    HEAP32[$55 + 4 >> 2] = $81$1;
    var $82 = HEAP32[$50 >> 2];
    var $83 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $82, $49, 0, $tv);
    if (($83 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $86 = HEAP32[$50 >> 2];
    var $87 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $86, $49, $tv);
    if (($87 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $90$0 = HEAP32[$55 >> 2];
    var $90$1 = HEAP32[$55 + 4 >> 2];
    var $91 = _JSVAL_TO_OBJECT4304($90$0, $90$1);
    var $92 = $91;
    var $93 = __ZNK8JSObject10getPrivateEv($92);
    var $target_0_in = $93;
    __label__ = 24;
    break;
   case 24:
    var $target_0_in;
    HEAP32[$result >> 2] = $target_0_in;
    var $_0 = 1;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL12ResolveValueP9JSContextP5JSXMLPS2_["X"] = 1;

function __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $id, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 80;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $index = __stackBase__;
    var $funid = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $2 = __stackBase__ + 16;
    var $3 = __stackBase__ + 24;
    var $roots = __stackBase__ + 32;
    var $tvr = __stackBase__ + 48;
    var $4 = __stackBase__ + 64;
    var $5 = __stackBase__ + 72;
    var $6 = $obj;
    var $7 = __ZNK8JSObject5isXMLEv($6);
    if ($7) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    var $9 = __ZNK8JSObject10getPrivateEv($6);
    var $10 = $9;
    if (($9 | 0) == 0) {
      var $_1 = 1;
      __label__ = 22;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $13 = __Z12js_IdIsIndexiPj($id, $index);
    if (($13 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $20 = HEAPU32[$index >> 2];
    if (HEAPU32[$9 + 16 >> 2] >>> 0 < 2) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($20 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    _OBJECT_TO_JSVAL4318($1, $obj);
    var $_phi_trans_insert = $1 | 0;
    var $st$2$0 = $_phi_trans_insert | 0;
    var $st$2$1 = $_phi_trans_insert + 4 | 0;
    var $28$1 = HEAP32[$st$2$1 >> 2];
    var $28$0 = HEAP32[$st$2$0 >> 2];
    __label__ = 8;
    break;
   case 7:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $25$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $25$1 = HEAP32[$st$1$1 >> 2];
    var $26 = $1 | 0;
    var $st$6$0 = $26 | 0;
    HEAP32[$st$6$0 >> 2] = $25$0;
    var $st$6$1 = $26 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $25$1;
    var $28$1 = $25$1;
    var $28$0 = $25$0;
    __label__ = 8;
    break;
   case 8:
    var $28$0;
    var $28$1;
    var $29 = $vp | 0;
    var $st$3$0 = $29 | 0;
    HEAP32[$st$3$0 >> 2] = $28$0;
    var $st$3$1 = $29 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $28$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 9:
    if ($20 >>> 0 < HEAPU32[$9 + 24 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $40 = HEAPU32[HEAP32[$9 + 32 >> 2] + ($20 << 2) >> 2];
    if (($40 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 11:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $43$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $43$1 = HEAP32[$st$1$1 >> 2];
    var $44 = $vp | 0;
    var $st$6$0 = $44 | 0;
    HEAP32[$st$6$0 >> 2] = $43$0;
    var $st$6$1 = $44 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $43$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 12:
    var $46 = $40;
    var $47 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $46);
    if (($47 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    _OBJECT_TO_JSVAL4318($2, $47);
    var $50 = $2 | 0;
    var $st$2$0 = $50 | 0;
    var $51$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $50 + 4 | 0;
    var $51$1 = HEAP32[$st$2$1 >> 2];
    var $52 = $vp | 0;
    HEAP32[$52 >> 2] = $51$0;
    HEAP32[$52 + 4 >> 2] = $51$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 14:
    var $$emscripten$temp$2 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$2 | 0;
    var $54$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$2 + 4 | 0;
    var $54$1 = HEAP32[$st$1$1 >> 2];
    var $55 = $vp | 0;
    var $st$6$0 = $55 | 0;
    HEAP32[$st$6$0 >> 2] = $54$0;
    var $st$6$1 = $55 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $54$1;
    var $_1 = 1;
    __label__ = 22;
    break;
   case 15:
    __ZN2jsL9IdToJsvalEi4431($3, $id);
    var $_idx = $3 | 0;
    var $st$2$0 = $_idx | 0;
    var $_idx_val$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $_idx + 4 | 0;
    var $_idx_val$1 = HEAP32[$st$2$1 >> 2];
    var $57 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_idx_val$0, $_idx_val$1, $funid);
    if (($57 | 0) == 0) {
      var $_1 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $60 = HEAP32[$funid >> 2];
    var $61 = _JSID_IS_VOID4359($60);
    if (($61 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    var $64 = __ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $60, $vp);
    var $_1 = $64;
    __label__ = 22;
    break;
   case 18:
    var $66 = $roots | 0;
    _OBJECT_TO_JSVAL4318($66, $57);
    var $$emscripten$temp$3 = _JSVAL_NULL | 0;
    var $st$3$0 = $$emscripten$temp$3 | 0;
    var $67$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $$emscripten$temp$3 + 4 | 0;
    var $67$1 = HEAP32[$st$3$1 >> 2];
    var $68 = $roots + 8 | 0;
    var $st$8$0 = $68 | 0;
    HEAP32[$st$8$0 >> 2] = $67$0;
    var $st$8$1 = $68 + 4 | 0;
    HEAP32[$st$8$1 >> 2] = $67$1;
    var $69 = $cx;
    __ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE($tvr, $69, 2, $66);
    var $70 = __Z15js_NewXMLObjectP9JSContext10JSXMLClass($cx, 0);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    _OBJECT_TO_JSVAL4318($4, $70);
    var $73 = $4 | 0;
    var $st$2$0 = $73 | 0;
    var $74$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $73 + 4 | 0;
    var $74$1 = HEAP32[$st$2$1 >> 2];
    var $st$6$0 = $68 | 0;
    HEAP32[$st$6$0 >> 2] = $74$0;
    var $st$6$1 = $68 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $74$1;
    var $75 = $70;
    var $76 = __ZNK8JSObject10getPrivateEv($75);
    var $77 = $76;
    var $78 = __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $10, $57, $77);
    if (($78 | 0) == 0) {
      var $_0 = 0;
      __label__ = 21;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    HEAP32[$76 + 40 >> 2] = $10;
    HEAP32[$76 + 44 >> 2] = $57;
    _OBJECT_TO_JSVAL4318($5, $70);
    var $85 = $5 | 0;
    var $st$8$0 = $85 | 0;
    var $86$0 = HEAP32[$st$8$0 >> 2];
    var $st$8$1 = $85 + 4 | 0;
    var $86$1 = HEAP32[$st$8$1 >> 2];
    var $87 = $vp | 0;
    HEAP32[$87 >> 2] = $86$0;
    HEAP32[$87 + 4 >> 2] = $86$1;
    var $_0 = 1;
    __label__ = 21;
    break;
   case 21:
    var $_0;
    __ZN2js15AutoArrayRooterD1Ev($tvr);
    var $_1 = $_0;
    __label__ = 22;
    break;
   case 22:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE["X"] = 1;

function __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $i, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 30;
      break;
    }
   case 2:
    var $6 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $n_04 = 1;
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $10 = $9;
    var $11 = __ZNK8JSObject5isXMLEv($10);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $n_04 = 1;
      __label__ = 14;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject10getPrivateEv($10);
    var $14 = $13;
    var $17 = HEAP32[$13 + 16 >> 2];
    if (($17 | 0) == 0) {
      __label__ = 5;
      break;
    } else if (($17 | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      var $n_0 = 1;
      __label__ = 13;
      break;
    }
   case 5:
    var $20 = $13 + 24 | 0;
    var $21 = HEAPU32[$20 >> 2];
    if (($21 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $24 = $13 + 32 | 0;
    var $j_0 = 0;
    __label__ = 7;
    break;
   case 7:
    var $j_0;
    if ($j_0 >>> 0 < $21 >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $n_0 = $21;
      __label__ = 13;
      break;
    }
   case 8:
    if ($j_0 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $33 = HEAP32[HEAP32[$24 >> 2] + ($j_0 << 2) >> 2];
    if (($33 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = $33;
    var $37 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $36);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 7;
    break;
   case 12:
    var $41 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $14);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      var $n_0 = 1;
      __label__ = 13;
      break;
    }
   case 13:
    var $n_0;
    if (($13 | 0) == 0) {
      var $n_04 = $n_0;
      __label__ = 14;
      break;
    } else {
      var $vxml_1 = $14;
      var $n_03 = $n_0;
      __label__ = 17;
      break;
    }
   case 14:
    var $n_04;
    var $44 = $cx;
    var $45 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($44, $v);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $48 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($48 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$48 + 24 >> 2] = $45;
    var $vxml_1 = $48;
    var $n_03 = $n_04;
    __label__ = 17;
    break;
   case 17:
    var $n_03;
    var $vxml_1;
    var $53 = $xml + 24 | 0;
    var $54 = $53 | 0;
    var $55 = HEAPU32[$54 >> 2];
    var $_01 = $55 >>> 0 < $i >>> 0 ? $55 : $i;
    var $57 = __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $53, $_01, $n_03);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 30;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if ((HEAP32[$vxml_1 + 16 >> 2] | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 19:
    if (($n_03 | 0) == 0) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $64 = $vxml_1 + 24 | 0;
    var $65 = $vxml_1 + 32 | 0;
    var $66 = $xml + 32 | 0;
    var $j_19 = 0;
    __label__ = 21;
    break;
   case 21:
    var $j_19;
    if ($j_19 >>> 0 < HEAPU32[$64 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 22:
    var $72 = HEAPU32[HEAP32[$65 >> 2] + ($j_19 << 2) >> 2];
    if (($72 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $76 = $72 + 8 | 0;
    HEAP32[$76 >> 2] = $xml;
    var $78 = $j_19 + $_01 | 0;
    if (HEAPU32[$54 >> 2] >>> 0 > $78 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$54 >> 2] = $78 + 1 | 0;
    __label__ = 25;
    break;
   case 25:
    var $84 = HEAP32[$66 >> 2] + ($78 << 2) | 0;
    HEAP32[$84 >> 2] = $72;
    __label__ = 26;
    break;
   case 26:
    var $85 = $j_19 + 1 | 0;
    if (($85 | 0) == ($n_03 | 0)) {
      var $_0 = 1;
      __label__ = 30;
      break;
    } else {
      var $j_19 = $85;
      __label__ = 21;
      break;
    }
   case 27:
    HEAP32[$vxml_1 + 8 >> 2] = $xml;
    if (HEAPU32[$54 >> 2] >>> 0 > $_01 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$54 >> 2] = $_01 + 1 | 0;
    __label__ = 29;
    break;
   case 29:
    var $96 = HEAP32[$xml + 32 >> 2] + ($_01 << 2) | 0;
    HEAP32[$96 >> 2] = $vxml_1;
    var $_0 = 1;
    __label__ = 30;
    break;
   case 30:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE["X"] = 1;

function __ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $i, $_0_0_0_val$0, $_0_0_0_val$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 19;
      break;
    }
   case 2:
    var $6 = $xml + 24 | 0;
    var $7 = $6 | 0;
    var $8 = HEAPU32[$7 >> 2];
    var $_01 = $8 >>> 0 < $i >>> 0 ? $8 : $i;
    var $10 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($10 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $13 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $14 = $13;
    var $15 = __ZNK8JSObject5isXMLEv($14);
    if ($15) {
      __label__ = 4;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 4:
    var $17 = __ZNK8JSObject10getPrivateEv($14);
    var $18 = $17;
    if (($17 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $23 = HEAP32[$17 + 16 >> 2];
    if (($23 | 0) == 1) {
      __label__ = 6;
      break;
    } else if (($23 | 0) == 0) {
      __label__ = 7;
      break;
    } else if (($23 | 0) == 5 || ($23 | 0) == 3 || ($23 | 0) == 4) {
      var $vxml_1 = $18;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 6:
    var $25 = __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $18);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      var $vxml_1 = $18;
      __label__ = 13;
      break;
    }
   case 7:
    if ($_01 >>> 0 < $8 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $_01);
    __label__ = 9;
    break;
   case 9:
    var $31 = __ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE($cx, $xml, $_01, $_0_0_0_val$0, $_0_0_0_val$1);
    if (($31 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 10:
    var $33 = $cx;
    var $34 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($33, $v);
    if (($34 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = __Z9js_NewXMLP9JSContext10JSXMLClass($cx, 4);
    if (($37 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    HEAP32[$37 + 24 >> 2] = $34;
    var $vxml_1 = $37;
    __label__ = 13;
    break;
   case 13:
    var $vxml_1;
    HEAP32[$vxml_1 + 8 >> 2] = $xml;
    if ($_01 >>> 0 < $8 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 14:
    if ($_01 >>> 0 < HEAPU32[$7 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 15:
    var $51 = HEAP32[HEAP32[$xml + 32 >> 2] + ($_01 << 2) >> 2];
    if (($51 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $55 = $51 + 8 | 0;
    HEAP32[$55 >> 2] = 0;
    __label__ = 17;
    break;
   case 17:
    var $57 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $6, $_01, $vxml_1);
    if (($57 | 0) == 0) {
      var $_0 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $_0 = 1;
    __label__ = 19;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE["X"] = 1;

function __ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj($cx, $array, $i, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $array | 0;
    var $2 = HEAP32[$1 >> 2];
    var $3 = $2 + $n | 0;
    var $4 = __ZN10JSXMLArray11setCapacityEP9JSContextj($array, $cx, $3);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    HEAP32[$1 >> 2] = $3;
    if (($2 | 0) == ($i | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $array + 8 | 0;
    var $j_03 = $2;
    __label__ = 4;
    break;
   case 4:
    var $j_03;
    var $9 = $j_03 - 1 | 0;
    var $10 = HEAP32[$7 >> 2];
    var $12 = HEAP32[$10 + ($9 << 2) >> 2];
    var $14 = $10 + ($9 + $n << 2) | 0;
    HEAP32[$14 >> 2] = $12;
    if (($9 | 0) == ($i | 0)) {
      __label__ = 5;
      break;
    } else {
      var $j_03 = $9;
      __label__ = 4;
      break;
    }
   case 5:
    var $cursor_01 = HEAP32[$array + 12 >> 2];
    if (($cursor_01 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $cursor_02 = $cursor_01;
      __label__ = 6;
      break;
    }
   case 6:
    var $cursor_02;
    var $18 = $cursor_02 + 4 | 0;
    var $19 = HEAPU32[$18 >> 2];
    if ($19 >>> 0 > $i >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    HEAP32[$18 >> 2] = $19 + $n | 0;
    __label__ = 8;
    break;
   case 8:
    var $cursor_0 = HEAPU32[$cursor_02 + 8 >> 2];
    if (($cursor_0 | 0) == 0) {
      var $_0 = 1;
      __label__ = 9;
      break;
    } else {
      var $cursor_02 = $cursor_0;
      __label__ = 6;
      break;
    }
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11KidToStringP9JSContextP5JSXMLj($cx, $xml, $index) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    if (HEAPU32[$xml + 24 >> 2] >>> 0 > $index >>> 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $9 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($index << 2) >> 2];
    if (($9 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $_0 = HEAP32[HEAP32[$cx + 52 >> 2] + 144136 >> 2] | 0;
    __label__ = 6;
    break;
   case 4:
    var $17 = $9;
    var $18 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $17);
    if (($18 | 0) == 0) {
      var $_0 = 0;
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    __ZN2JSL11ObjectValueER8JSObject4319($1, $18);
    var $21 = $cx;
    var $22 = __Z16js_ValueToStringP9JSContextRKN2JS5ValueE($21, $1);
    var $_0 = $22;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL10CheckCycleP9JSContextP5JSXMLS2_($cx, $xml, $kid) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    if (($_01 | 0) == ($kid | 0)) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $4 = $cx;
    _JS_ReportErrorNumber($4, 2, 0, 36, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = STRING_TABLE._js_XML_str | 0, tempInt));
    var $_0 = 0;
    __label__ = 5;
    break;
   case 4:
    var $7 = HEAP32[$_01 + 8 >> 2];
    if (($7 | 0) == 0) {
      var $_0 = 1;
      __label__ = 5;
      break;
    } else {
      var $_01 = $7;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $xml, $nameqn, $list) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cursor = __stackBase__;
    var $cursor1 = __stackBase__ + 20;
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      var $_2 = 1;
      __label__ = 18;
      break;
    }
   case 2:
    var $4 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $4);
    __label__ = 3;
    break;
   case 3:
    var $5 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    var $6 = $5;
    if (($5 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ((HEAP32[$5 + 16 >> 2] | 0) == 1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 5:
    var $14 = __ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_($cx, $6, $nameqn, $list);
    if (($14 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 6:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_2 = 1;
    __label__ = 18;
    break;
   case 7:
    var $18 = $nameqn;
    var $19 = __ZNK8JSObject8getClassEv($18);
    var $20 = ($19 | 0) == (__ZN2js18AttributeNameClassE | 0);
    var $array_0 = $20 ? $xml + 56 | 0 : $xml + 24 | 0;
    var $matcher_0 = $20 ? 294 : 296;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor1, $array_0);
    __label__ = 8;
    break;
   case 8:
    var $23 = __ZN16JSXMLArrayCursor7getNextEv($cursor1);
    var $24 = $23;
    if (($23 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $27 = FUNCTION_TABLE[$matcher_0]($nameqn, $24);
    if (($27 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    if ($20) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    if ((HEAP32[$23 + 16 >> 2] | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $36 = __ZL21SyncInScopeNamespacesP9JSContextP5JSXML($cx, $24);
    if (($36 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $39 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $list, $24);
    if (($39 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 14:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 1;
    __label__ = 18;
    break;
   case 15:
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 16:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 17:
    __ZN16JSXMLArrayCursorD1Ev($cursor1);
    var $_2 = 0;
    __label__ = 18;
    break;
   case 18:
    var $_2;
    STACKTOP = __stackBase__;
    return $_2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_["X"] = 1;

function __ZL21SyncInScopeNamespacesP9JSContextP5JSXML($cx, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $xml + 40 | 0;
    var $2 = $1 | 0;
    var $_idx1 = $xml + 48 | 0;
    var $_01 = $xml;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $4 = HEAP32[$_01 + 8 >> 2];
    if (($4 | 0) == 0) {
      var $_0 = 1;
      __label__ = 10;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $7 = $4 + 40 | 0;
    var $8 = HEAPU32[$7 >> 2];
    var $9 = $4 + 48 | 0;
    var $i_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $i_0;
    if ($i_0 >>> 0 < $8 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_01 = $4;
      __label__ = 2;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$7 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 6:
    var $18 = HEAPU32[HEAP32[$9 >> 2] + ($i_0 << 2) >> 2];
    if (($18 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $_idx_val = HEAP32[$2 >> 2];
    var $_idx1_val = HEAP32[$_idx1 >> 2];
    var $21 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $18, 298);
    if (($21 | 0) == -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $24 = HEAP32[$2 >> 2];
    var $25 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $1, $24, $18);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 4;
    break;
   case 10:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL10Int32ValueEi4433($agg_result, $i32) {
  __ZN2JS5Value8setInt32Ei($agg_result, $i32);
  return;
}

function _INT_TO_JSID4434($i) {
  return $i << 1 | 1;
}

function __ZL18HasIndexedPropertyP5JSXMLj($xml, $i) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 16 >> 2];
    if (($2 | 0) == 0) {
      __label__ = 2;
      break;
    } else if (($2 | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $_0 = HEAPU32[$xml + 24 >> 2] >>> 0 > $i >>> 0 & 1;
    __label__ = 4;
    break;
   case 3:
    var $_0 = ($i | 0) == 0 & 1;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $indexp, $isIndex) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1);
    if (($1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1);
    if (($4 | 0) < 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    HEAP8[$isIndex] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 4:
    HEAP32[$indexp >> 2] = $4;
    HEAP8[$isIndex] = 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    var $9 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP8[$isIndex] = 0;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 7:
    var $13 = _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1);
    var $14 = $cx;
    var $15 = __ZN8JSString12ensureLinearEP9JSContext($13, $14);
    if (($15 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $18 = __ZN2js18StringIsArrayIndexEP14JSLinearStringPj($15, $indexp);
    HEAP8[$isIndex] = $18 & 1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $xml, $ns) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$xml + 12 >> 2];
    var $3 = $xml + 40 | 0;
    var $4 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $2, $3);
    if (($4 | 0) == ($ns | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $xml + 56 | 0;
    var $8 = HEAPU32[$7 >> 2];
    var $9 = $xml + 64 | 0;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $8 >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 4:
    if ($i_0 >>> 0 < HEAPU32[$7 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $18 = HEAP32[HEAP32[$9 >> 2] + ($i_0 << 2) >> 2];
    if (($18 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = HEAP32[$18 + 12 >> 2];
    var $24 = __ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray($cx, $23, $3);
    if (($24 | 0) == ($ns | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $28 = $ns;
    var $_idx_val = HEAP32[$3 >> 2];
    var $_idx1_val = HEAP32[$xml + 48 >> 2];
    var $29 = __ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E($_idx_val, $_idx1_val, $28, 300);
    if (($29 | 0) == -1) {
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    __ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji($3, $29, 1);
    __label__ = 10;
    break;
   case 10:
    var $33 = $xml + 24 | 0;
    var $34 = HEAPU32[$33 >> 2];
    if (($34 | 0) == 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36 = $xml + 32 | 0;
    var $i_12 = 0;
    var $38 = $34;
    __label__ = 12;
    break;
   case 12:
    var $38;
    var $i_12;
    if ($i_12 >>> 0 < $38 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 13:
    var $43 = HEAPU32[HEAP32[$36 >> 2] + ($i_12 << 2) >> 2];
    var $44 = $43;
    if (($43 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ((HEAP32[$43 + 16 >> 2] | 0) == 1) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    __ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject($cx, $44, $ns);
    __label__ = 16;
    break;
   case 16:
    var $52 = $i_12 + 1 | 0;
    if (($52 | 0) == ($34 | 0)) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $i_12 = $52;
    var $38 = HEAP32[$33 >> 2];
    __label__ = 12;
    break;
   case 18:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject["X"] = 1;

function __ZL20namespace_full_matchPKvS0_($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $a;
    var $2 = $b;
    var $3 = __ZNK8JSObject13getNamePrefixEv($1);
    if (($3 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $6 = __ZNK8JSObject13getNamePrefixEv($2);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZN2js12EqualStringsEP14JSLinearStringS1_($3, $6);
    if ($9) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $11 = __ZNK8JSObject10getNameURIEv($1);
    var $12 = __ZNK8JSObject10getNameURIEv($2);
    var $13 = __ZN2js12EqualStringsEP14JSLinearStringS1_($11, $12);
    var $_0 = $13 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $xml, $nameqn, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 44 >> 2] = $nameqn;
    var $6 = HEAPU32[$xml + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $9);
    var $10 = $v | 0;
    var $ok_0_ph = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($11 | 0) == 0) {
      var $ok_2 = $ok_0_ph;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $11;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $22$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $22$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$10 >> 2] = $22$0;
    HEAP32[$10 + 4 >> 2] = $22$1;
    var $ok_2 = 0;
    __label__ = 13;
    break;
   case 9:
    var $24 = __ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $19, $nameqn, $v);
    if (($24 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = HEAP32[$10 >> 2];
    var $27$1 = HEAP32[$10 + 4 >> 2];
    var $28 = _JSVAL_TO_OBJECT4304($27$0, $27$1);
    var $29 = $28;
    var $30 = __ZNK8JSObject10getPrivateEv($29);
    var $31 = $30;
    if (HEAPU32[$30 + 16 >> 2] >>> 0 < 2) {
      __label__ = 11;
      break;
    } else {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    }
   case 11:
    if ((HEAP32[$30 + 24 >> 2] | 0) == 0) {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $31);
    if (($41 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      var $ok_0_ph = $41;
      __label__ = 4;
      break;
    }
   case 13:
    var $ok_2;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $ok_2;
    __label__ = 26;
    break;
   case 14:
    var $45 = $xml + 24 | 0;
    if ($6 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      var $48 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$45 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $48;
    var $49 = $xml + 32 | 0;
    var $i_0 = 0;
    var $ok_3 = 1;
    __label__ = 17;
    break;
   case 17:
    var $ok_3;
    var $i_0;
    if ($i_0 >>> 0 < $48 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 26;
      break;
    }
   case 18:
    if ($i_0 >>> 0 < HEAPU32[$45 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 19:
    var $58 = HEAPU32[HEAP32[$49 >> 2] + ($i_0 << 2) >> 2];
    var $59 = $58;
    if (($58 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[$58 + 16 >> 2] | 0) == 3) {
      __label__ = 21;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 21:
    var $67 = __ZNK8JSObject17getQNameLocalNameEv($nameqn);
    var $68 = $67 | 0;
    var $69 = $67 | 0;
    var $70 = __ZNK8JSString6lengthEv($69);
    if (($70 | 0) == 1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $73 = __ZNK14JSLinearString5charsEv($68);
    if (HEAP16[$73 >> 1] << 16 >> 16 == 42) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $79 = HEAP32[$58 + 12 >> 2];
    var $80 = __ZNK8JSObject17getQNameLocalNameEv($79);
    var $81 = $80 | 0;
    var $82 = __ZN2js12EqualStringsEP14JSLinearStringS1_($68, $81);
    if ($82) {
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 25;
      break;
    }
   case 24:
    var $84 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $59);
    if (($84 | 0) == 0) {
      var $_0 = 0;
      __label__ = 26;
      break;
    } else {
      var $ok_4 = $84;
      __label__ = 25;
      break;
    }
   case 25:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 17;
    break;
   case 26:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE["X"] = 1;

function __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $obj, $xml) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 2:
    if ((HEAP32[$xml >> 2] | 0) == ($obj | 0)) {
      var $11 = $xml;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = __ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject($cx, $xml, $obj);
    var $11 = $9;
    __label__ = 4;
    break;
   case 4:
    var $11;
    if (($11 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $14 = $11 + 24 | 0;
    var $16 = $11 + 32 | 0;
    var $17 = $cx;
    var $n_0 = HEAP32[$14 >> 2];
    var $i_0 = 0;
    __label__ = 6;
    break;
   case 6:
    var $i_0;
    var $n_0;
    if ($i_0 >>> 0 < $n_0 >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 1;
      __label__ = 22;
      break;
    }
   case 7:
    if ($i_0 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 8:
    var $26 = HEAPU32[HEAP32[$16 >> 2] + ($i_0 << 2) >> 2];
    var $27 = $26;
    if (($26 | 0) == 0) {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $32 = HEAP32[$26 + 16 >> 2];
    if (($32 | 0) == 4) {
      __label__ = 10;
      break;
    } else if (($32 | 0) == 1) {
      __label__ = 11;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 10:
    var $33 = $i_0 + 1 | 0;
    var $34 = $26 + 24 | 0;
    var $35 = $34;
    var $36 = $34;
    var $n_1 = $n_0;
    __label__ = 13;
    break;
   case 11:
    var $38 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $27);
    if (($38 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML($cx, $38, $27);
    if (($41 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      var $n_2 = $n_0;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 13:
    var $n_1;
    if ($33 >>> 0 < $n_1 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 14:
    if ($33 >>> 0 < HEAPU32[$14 >> 2] >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 15:
    var $51 = HEAPU32[HEAP32[$16 >> 2] + ($33 << 2) >> 2];
    if (($51 | 0) == 0) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ((HEAP32[$51 + 16 >> 2] | 0) == 4) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $59 = HEAP32[$35 >> 2];
    var $62 = HEAP32[$51 + 24 >> 2];
    var $63 = __Z16js_ConcatStringsP9JSContextP8JSStringS2_($17, $59, $62);
    if (($63 | 0) == 0) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    __ZL17NormalizingDeleteP9JSContextP5JSXMLj($11, $33);
    var $66 = HEAP32[$14 >> 2];
    var $_c = $63;
    HEAP32[$36 >> 2] = $_c;
    var $n_1 = $66;
    __label__ = 13;
    break;
   case 19:
    var $67 = HEAP32[$35 >> 2];
    var $68 = __ZNK8JSString5emptyEv($67);
    if ($68) {
      __label__ = 20;
      break;
    } else {
      var $n_2 = $n_1;
      var $i_1 = $i_0;
      __label__ = 21;
      break;
    }
   case 20:
    __ZL17NormalizingDeleteP9JSContextP5JSXMLj($11, $i_0);
    var $n_2 = HEAP32[$14 >> 2];
    var $i_1 = $i_0 - 1 | 0;
    __label__ = 21;
    break;
   case 21:
    var $i_1;
    var $n_2;
    var $n_0 = $n_2;
    var $i_0 = $i_1 + 1 | 0;
    __label__ = 6;
    break;
   case 22:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML["X"] = 1;

function __ZL17NormalizingDeleteP9JSContextP5JSXMLj($xml, $index) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[$xml + 16 >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    __ZL17DeleteListElementP9JSContextP5JSXMLj($xml, $index);
    __label__ = 4;
    break;
   case 3:
    __ZL13DeleteByIndexP9JSContextP5JSXMLj($xml, $index);
    __label__ = 4;
    break;
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE($cx, $array, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 40;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $tvr = __stackBase__ + 8;
    var $2 = __stackBase__ + 32;
    var $3 = $cx;
    var $4 = __ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject($3, 0);
    if (($4 | 0) == 0) {
      var $_1 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $7 = $4;
    _OBJECT_TO_JSVAL4318($1, $7);
    var $8 = $1 | 0;
    var $9$0 = HEAP32[$8 >> 2];
    var $9$1 = HEAP32[$8 + 4 >> 2];
    var $10 = $rval | 0;
    HEAP32[$10 >> 2] = $9$0;
    HEAP32[$10 + 4 >> 2] = $9$1;
    var $11 = $tvr;
    __ZN2js15AutoValueRooterC1EP9JSContext($11, $3);
    var $12 = $array | 0;
    var $13 = HEAPU32[$12 >> 2];
    var $14 = $array + 8 | 0;
    var $15 = $tvr;
    var $i_0 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_0;
    if ($i_0 >>> 0 < $13 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 8;
      break;
    }
   case 4:
    if ($i_0 >>> 0 < HEAPU32[$12 >> 2] >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 5:
    var $24 = HEAP32[HEAP32[$14 >> 2] + ($i_0 << 2) >> 2];
    if (($24 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $27 = $24;
    __ZN2JSL11ObjectValueER8JSObject4319($2, $27);
    __ZN2js15AutoValueRooter3setEN2JS5ValueE($15, $2);
    var $28 = _INT_TO_JSID4434($i_0);
    var $29 = __ZN2js15AutoValueRooter4addrEv($11);
    var $30 = __ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi($4, $3, $28, $29, 0);
    if (($30 | 0) == 0) {
      var $_0 = 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 3;
    break;
   case 8:
    var $_0;
    __ZN2js15AutoValueRooterD1Ev($11);
    var $_1 = $_0;
    __label__ = 9;
    break;
   case 9:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE["X"] = 1;

function __ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray($cx, $xml, $nsarray) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $nsarray | 0;
    var $3 = $nsarray + 8 | 0;
    var $_01 = $xml;
    var $length_0 = HEAP32[$1 >> 2];
    __label__ = 2;
    break;
   case 2:
    var $length_0;
    var $_01;
    if ((HEAP32[$_01 + 16 >> 2] | 0) == 1) {
      __label__ = 3;
      break;
    } else {
      var $length_3 = $length_0;
      __label__ = 19;
      break;
    }
   case 3:
    var $9 = $_01 + 40 | 0;
    var $10 = HEAPU32[$9 >> 2];
    var $11 = $_01 + 48 | 0;
    var $i_0 = 0;
    var $length_1 = $length_0;
    __label__ = 4;
    break;
   case 4:
    var $length_1;
    var $i_0;
    if ($i_0 >>> 0 < $10 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $length_3 = $length_1;
      __label__ = 19;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$9 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$11 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $24 = __ZNK8JSObject13getNamePrefixEv($21);
    var $25 = ($24 | 0) == 0;
    var $j_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $j_0;
    if ($j_0 >>> 0 < $length_1 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    if ($j_0 >>> 0 < HEAPU32[$1 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $34 = HEAP32[HEAP32[$3 >> 2] + ($j_0 << 2) >> 2];
    var $35 = $34;
    if (($34 | 0) == 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = __ZNK8JSObject13getNamePrefixEv($35);
    if (($38 | 0) == 0 | $25) {
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZN2js12EqualStringsEP14JSLinearStringS1_($38, $24);
    if ($41) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $43 = __ZNK8JSObject10getNameURIEv($35);
    var $44 = __ZNK8JSObject10getNameURIEv($21);
    var $45 = __ZN2js12EqualStringsEP14JSLinearStringS1_($43, $44);
    if ($45) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $j_0 = $j_0 + 1 | 0;
    __label__ = 8;
    break;
   case 15:
    if (($j_0 | 0) == ($length_1 | 0)) {
      __label__ = 16;
      break;
    } else {
      var $length_2 = $length_1;
      __label__ = 18;
      break;
    }
   case 16:
    var $50 = HEAP32[$1 >> 2];
    var $51 = __ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv($cx, $nsarray, $50, $20);
    if (($51 | 0) == 0) {
      var $_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $length_2 = $length_1 + 1 | 0;
    __label__ = 18;
    break;
   case 18:
    var $length_2;
    var $i_0 = $i_0 + 1 | 0;
    var $length_1 = $length_2;
    __label__ = 4;
    break;
   case 19:
    var $length_3;
    var $57 = HEAPU32[$_01 + 8 >> 2];
    if (($57 | 0) == 0) {
      var $_0 = 1;
      __label__ = 20;
      break;
    } else {
      var $_01 = $57;
      var $length_0 = $length_3;
      __label__ = 2;
      break;
    }
   case 20:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray["X"] = 1;

function _DOUBLE_TO_JSVAL4435($agg_result, $d) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = isNaN($d) || isNaN(0);
    if ($1) {
      var $l_0_0$1 = 2146959360;
      var $l_0_0$0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    tempDoubleF64[0] = $d;
    var $l_0_0$1 = tempDoubleI32[1];
    var $l_0_0$0 = tempDoubleI32[0];
    __label__ = 3;
    break;
   case 3:
    var $l_0_0$0;
    var $l_0_0$1;
    __ZL13IMPL_TO_JSVAL12jsval_layout4416($agg_result, $l_0_0$0, $l_0_0$1);
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi($cx, $obj, $_0_0_0_val$0, $_0_0_0_val$1, $found) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 12;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $i = __stackBase__ + 4;
    var $funid = __stackBase__ + 8;
    var $1 = $obj;
    var $2 = __ZNK8JSObject10getPrivateEv($1);
    var $3 = $2;
    var $4 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $i, $isIndex);
    if ($4) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 2:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAP32[$i >> 2];
    var $11 = __ZL18HasIndexedPropertyP5JSXMLj($3, $10);
    HEAP32[$found >> 2] = $11;
    __label__ = 8;
    break;
   case 4:
    var $13 = __ZL9ToXMLNameP9JSContextN2JS5ValueEPi($cx, $_0_0_0_val$0, $_0_0_0_val$1, $funid);
    if (($13 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $16 = HEAP32[$funid >> 2];
    var $17 = _JSID_IS_VOID4359($16);
    if (($17 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $20 = __ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi($cx, $obj, $16, $found);
    if (($20 | 0) == 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $23 = __ZL16HasNamedPropertyP5JSXMLP8JSObject($3, $13);
    HEAP32[$found >> 2] = $23;
    __label__ = 8;
    break;
   case 8:
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $xml, $nameqn, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 28;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $cursor = __stackBase__ + 8;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$1 + 44 >> 2] = $nameqn;
    var $6 = HEAPU32[$xml + 16 >> 2];
    if (($6 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 3:
    var $9 = $xml + 24 | 0;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($cursor, $9);
    var $10 = $v | 0;
    var $ok_0_ph = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0_ph;
    __label__ = 5;
    break;
   case 5:
    var $11 = __ZN16JSXMLArrayCursor7getNextEv($cursor);
    if (($11 | 0) == 0) {
      var $ok_2 = $ok_0_ph;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$11 + 16 >> 2] | 0) == 1) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 7:
    var $19 = $11;
    var $20 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $19);
    if (($20 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $22$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $22$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$10 >> 2] = $22$0;
    HEAP32[$10 + 4 >> 2] = $22$1;
    var $ok_2 = 0;
    __label__ = 13;
    break;
   case 9:
    var $24 = __ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE($cx, $19, $nameqn, $v);
    if (($24 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $27$0 = HEAP32[$10 >> 2];
    var $27$1 = HEAP32[$10 + 4 >> 2];
    var $28 = _JSVAL_TO_OBJECT4304($27$0, $27$1);
    var $29 = $28;
    var $30 = __ZNK8JSObject10getPrivateEv($29);
    var $31 = $30;
    if (HEAPU32[$30 + 16 >> 2] >>> 0 < 2) {
      __label__ = 11;
      break;
    } else {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    }
   case 11:
    if ((HEAP32[$30 + 24 >> 2] | 0) == 0) {
      var $ok_0_ph = $24;
      __label__ = 4;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $41 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $31);
    if (($41 | 0) == 0) {
      var $ok_2 = 0;
      __label__ = 13;
      break;
    } else {
      var $ok_0_ph = $41;
      __label__ = 4;
      break;
    }
   case 13:
    var $ok_2;
    __ZN16JSXMLArrayCursorD1Ev($cursor);
    var $_0 = $ok_2;
    __label__ = 24;
    break;
   case 14:
    var $45 = $xml + 24 | 0;
    if ($6 >>> 0 < 2) {
      __label__ = 15;
      break;
    } else {
      var $48 = 0;
      __label__ = 16;
      break;
    }
   case 15:
    var $48 = HEAP32[$45 >> 2];
    __label__ = 16;
    break;
   case 16:
    var $48;
    var $49 = $xml + 32 | 0;
    var $i_0 = 0;
    var $ok_3 = 1;
    __label__ = 17;
    break;
   case 17:
    var $ok_3;
    var $i_0;
    if ($i_0 >>> 0 < $48 >>> 0) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 24;
      break;
    }
   case 18:
    if ($i_0 >>> 0 < HEAPU32[$45 >> 2] >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 19:
    var $58 = HEAPU32[HEAP32[$49 >> 2] + ($i_0 << 2) >> 2];
    var $59 = $58;
    if (($58 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    if ((HEAP32[$58 + 16 >> 2] | 0) == 1) {
      __label__ = 21;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 21:
    var $67 = __ZL13MatchElemNameP8JSObjectP5JSXML($nameqn, $59);
    if (($67 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $70 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $59);
    if (($70 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $70;
      __label__ = 23;
      break;
    }
   case 23:
    var $ok_4;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 17;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE["X"] = 1;

function _JSVAL_TO_INT32_IMPL4444($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _INT_FITS_IN_JSID4436($i) {
  return ($i + 1073741824 | 0) >>> 31 ^ 1;
}

function _JSVAL_IS_SPECIFIC_INT32_IMPL($l_0$0, $l_0$1, $i32) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = ($l_0$0 | 0) == ($i32 | 0);
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _JSID_IS_DEFAULT_XML_NAMESPACE4441($iden) {
  return ($iden | 0) == 6 & 1;
}

function _JSVAL_IS_INT32_IMPL4445($l_0$0, $l_0$1) {
  return (($l_0$0 & 0) == 0 && ($l_0$1 & -1) == -127) & 1;
}

function _JSVAL_IS_NUMBER_IMPL4446($l_0$0, $l_0$1) {
  return $l_0$1 >>> 0 < 4294967170 & 1;
}

function _JSVAL_TO_OBJECT_IMPL4449($l_0$0, $l_0$1) {
  return $l_0$0;
}

function _OBJECT_TO_JSVAL_IMPL4443($agg_result, $obj) {
  HEAP32[$agg_result + 4 >> 2] = -121;
  HEAP32[$agg_result >> 2] = $obj;
  return;
}

function __ZNK8JSObject11isNamespaceEv($this) {
  return (HEAP32[$this + 4 >> 2] | 0) == (__ZN2js14NamespaceClassE | 0);
}

function __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $xml, $vp) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = __ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE($cx, $xml, $vp);
    if (($1 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAPU32[$xml + 16 >> 2];
    if (($5 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 3:
    var $8 = $xml + 24 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $xml + 32 | 0;
    var $11 = $v | 0;
    var $i_0 = 0;
    var $ok_0 = 1;
    __label__ = 4;
    break;
   case 4:
    var $ok_0;
    var $i_0;
    if ($i_0 >>> 0 < $9 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $_0 = $ok_0;
      __label__ = 24;
      break;
    }
   case 5:
    if ($i_0 >>> 0 < HEAPU32[$8 >> 2] >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    }
   case 6:
    var $20 = HEAPU32[HEAP32[$10 >> 2] + ($i_0 << 2) >> 2];
    var $21 = $20;
    if (($20 | 0) == 0) {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if ((HEAP32[$20 + 16 >> 2] | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $ok_2 = $ok_0;
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $21);
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $$emscripten$temp$0 = _JSVAL_NULL | 0;
    var $31$0 = HEAP32[$$emscripten$temp$0 >> 2];
    var $31$1 = HEAP32[$$emscripten$temp$0 + 4 >> 2];
    HEAP32[$11 >> 2] = $31$0;
    HEAP32[$11 + 4 >> 2] = $31$1;
    var $_0 = 0;
    __label__ = 24;
    break;
   case 10:
    var $33 = __ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE($cx, $21, $v);
    if (($33 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $36$0 = HEAP32[$11 >> 2];
    var $36$1 = HEAP32[$11 + 4 >> 2];
    var $37 = _JSVAL_TO_OBJECT4304($36$0, $36$1);
    var $38 = $37;
    var $39 = __ZNK8JSObject10getPrivateEv($38);
    var $40 = $39;
    if (HEAPU32[$39 + 16 >> 2] >>> 0 < 2) {
      __label__ = 12;
      break;
    } else {
      var $ok_2 = $33;
      __label__ = 14;
      break;
    }
   case 12:
    if ((HEAP32[$39 + 24 >> 2] | 0) == 0) {
      var $ok_2 = $33;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $50 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $40);
    if (($50 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_2 = $50;
      __label__ = 14;
      break;
    }
   case 14:
    var $ok_2;
    var $i_0 = $i_0 + 1 | 0;
    var $ok_0 = $ok_2;
    __label__ = 4;
    break;
   case 15:
    var $55 = $xml + 24 | 0;
    if ($5 >>> 0 < 2) {
      __label__ = 16;
      break;
    } else {
      var $58 = 0;
      __label__ = 17;
      break;
    }
   case 16:
    var $58 = HEAP32[$55 >> 2];
    __label__ = 17;
    break;
   case 17:
    var $58;
    var $59 = $xml + 32 | 0;
    var $i_1 = 0;
    var $ok_3 = 1;
    __label__ = 18;
    break;
   case 18:
    var $ok_3;
    var $i_1;
    if ($i_1 >>> 0 < $58 >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $_0 = $ok_3;
      __label__ = 24;
      break;
    }
   case 19:
    if ($i_1 >>> 0 < HEAPU32[$55 >> 2] >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 20:
    var $68 = HEAPU32[HEAP32[$59 >> 2] + ($i_1 << 2) >> 2];
    var $69 = $68;
    if (($68 | 0) == 0) {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    if ((HEAP32[$68 + 16 >> 2] | 0) == 5) {
      __label__ = 22;
      break;
    } else {
      var $ok_4 = $ok_3;
      __label__ = 23;
      break;
    }
   case 22:
    var $77 = __ZL6AppendP9JSContextP5JSXMLS2_($cx, $1, $69);
    if (($77 | 0) == 0) {
      var $_0 = 0;
      __label__ = 24;
      break;
    } else {
      var $ok_4 = $77;
      __label__ = 23;
      break;
    }
   case 23:
    var $ok_4;
    var $i_1 = $i_1 + 1 | 0;
    var $ok_3 = $ok_4;
    __label__ = 18;
    break;
   case 24:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE["X"] = 1;

function __ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_($cx, $obj, $xml, $_0_0_0_val$0, $_0_0_0_val$1, $rval) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 32;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $isIndex = __stackBase__;
    var $index = __stackBase__ + 4;
    var $1 = __stackBase__ + 8;
    var $idr = __stackBase__ + 16;
    var $2 = __ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb($cx, $_0_0_0_val$0, $_0_0_0_val$1, $index, $isIndex);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_1 = 0;
      __label__ = 15;
      break;
    }
   case 2:
    if ((HEAP8[$isIndex] & 1) << 24 >> 24 == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = HEAPU32[$index >> 2];
    if (HEAPU32[$xml + 16 >> 2] >>> 0 < 2) {
      __label__ = 4;
      break;
    } else {
      var $16 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $16 = HEAP32[$xml + 24 >> 2];
    __label__ = 5;
    break;
   case 5:
    var $16;
    if ($8 >>> 0 < $16 >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $$emscripten$temp$0 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$0 | 0;
    var $19$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$0 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $20 = $rval | 0;
    var $st$6$0 = $20 | 0;
    HEAP32[$st$6$0 >> 2] = $19$0;
    var $st$6$1 = $20 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $19$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 7:
    if ($8 >>> 0 < HEAPU32[$xml + 24 >> 2] >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $29 = HEAPU32[HEAP32[$xml + 32 >> 2] + ($8 << 2) >> 2];
    if (($29 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $$emscripten$temp$1 = _JSVAL_VOID | 0;
    var $st$1$0 = $$emscripten$temp$1 | 0;
    var $31$0 = HEAP32[$st$1$0 >> 2];
    var $st$1$1 = $$emscripten$temp$1 + 4 | 0;
    var $31$1 = HEAP32[$st$1$1 >> 2];
    var $32 = $rval | 0;
    var $st$6$0 = $32 | 0;
    HEAP32[$st$6$0 >> 2] = $31$0;
    var $st$6$1 = $32 + 4 | 0;
    HEAP32[$st$6$1 >> 2] = $31$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 10:
    var $34 = $29;
    var $35 = __Z15js_GetXMLObjectP9JSContextP5JSXML($cx, $34);
    if (($35 | 0) == 0) {
      var $_1 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    _OBJECT_TO_JSVAL4318($1, $35);
    var $38 = $1 | 0;
    var $39$0 = HEAP32[$38 >> 2];
    var $39$1 = HEAP32[$38 + 4 >> 2];
    var $40 = $rval | 0;
    HEAP32[$40 >> 2] = $39$0;
    HEAP32[$40 + 4 >> 2] = $39$1;
    var $_1 = 1;
    __label__ = 15;
    break;
   case 12:
    var $42 = _INT_TO_JSID4434(0);
    var $43 = $idr;
    var $44 = $cx;
    __ZN2js12AutoIdRooterC1EP9JSContexti($43, $44, $42);
    var $45 = __ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE($cx, $_0_0_0_val$0, $_0_0_0_val$1, $idr);
    if (($45 | 0) == 0) {
      var $_0 = 0;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $48 = __ZN2js12AutoIdRooter2idEv($43);
    var $49 = __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE($cx, $obj, $48, $rval);
    var $_0 = $49;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    __ZN2js12AutoIdRooterD1Ev($43);
    var $_1 = $_0;
    __label__ = 15;
    break;
   case 15:
    var $_1;
    STACKTOP = __stackBase__;
    return $_1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_["X"] = 1;

function __ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE($cx, $_0_0_0_val$0, $_0_0_0_val$1, $idr) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $v = __stackBase__;
    var $1 = $v | 0;
    HEAP32[$1 >> 2] = $_0_0_0_val$0;
    HEAP32[$1 + 4 >> 2] = $_0_0_0_val$1;
    var $2 = _JSVAL_IS_INT4323($_0_0_0_val$0, $_0_0_0_val$1);
    if (($2 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = _JSVAL_TO_INT4324($_0_0_0_val$0, $_0_0_0_val$1);
    var $6 = _INT_FITS_IN_JSID4436($5);
    if (($6 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = _INT_TO_JSID4434($5);
    var $10 = $idr;
    var $11 = __ZN2js12AutoIdRooter4addrEv($10);
    HEAP32[$11 >> 2] = $9;
    __label__ = 11;
    break;
   case 4:
    var $13 = $idr;
    var $14 = __ZN2js12AutoIdRooter4addrEv($13);
    var $15 = $cx;
    var $16 = __Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi($15, $v, $14);
    if ($16) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 5:
    var $18 = _JSVAL_IS_STRING4320($_0_0_0_val$0, $_0_0_0_val$1);
    if (($18 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = _JSVAL_TO_STRING4321($_0_0_0_val$0, $_0_0_0_val$1);
    var $22 = $cx;
    var $23 = __Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE($22, $21, 0);
    if (($23 | 0) == 0) {
      var $_0 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $26 = $23;
    var $27 = __ZL12ATOM_TO_JSIDP6JSAtom4336($26);
    var $28 = $idr;
    var $29 = __ZN2js12AutoIdRooter4addrEv($28);
    HEAP32[$29 >> 2] = $27;
    __label__ = 11;
    break;
   case 8:
    var $31 = _JSVAL_IS_PRIMITIVE4303($_0_0_0_val$0, $_0_0_0_val$1);
    if (($31 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = _JSVAL_TO_OBJECT4304($_0_0_0_val$0, $_0_0_0_val$1);
    var $35 = _OBJECT_TO_JSID4356($34);
    var $36 = $idr;
    var $37 = __ZN2js12AutoIdRooter4addrEv($36);
    HEAP32[$37 >> 2] = $35;
    __label__ = 11;
    break;
   case 10:
    __ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE($cx, $v);
    var $_0 = 0;
    __label__ = 12;
    break;
   case 11:
    var $_0 = 1;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE["X"] = 1;

function __ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_($this, $p1) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this;
    var $2 = __ZN9JSContext7malloc_Ej($1, 20);
    if (($2 | 0) == 0) {
      var $7 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = $2;
    __ZN16JSXMLArrayCursorC1EP10JSXMLArray($5, $p1);
    var $7 = $5;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2JS5Value7isInt32Ei($this, $i32) {
  var $1 = $this | 0;
  var $2$0 = HEAP32[$1 >> 2];
  var $2$1 = HEAP32[$1 + 4 >> 2];
  var $3 = _JSVAL_IS_SPECIFIC_INT32_IMPL($2$0, $2$1, $i32);
  return ($3 | 0) != 0;
}

function __ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_($this, $p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN16JSXMLArrayCursorD1Ev($p);
    var $3 = $p;
    __ZN9JSContext5free_EPv(undef, $3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JSL11DoubleValueEd4439($agg_result, $dbl) {
  __ZN2JS5Value9setDoubleEd($agg_result, $dbl);
  return;
}

function __ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi($cx, $obj, $id, $vp, $strict) {
  var $1 = __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE($cx, $obj, $id, $strict, $vp);
  return $1;
}

function __ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442($v) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK2JS5Value8isObjectEv($v);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $6 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = __ZNK2JS5Value8toObjectEv($v);
    var $4 = __ZNK8JSObject10isFunctionEv($3);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13attr_identityPKvS0_($a, $b) {
  var $3 = HEAP32[$a + 12 >> 2];
  var $6 = HEAP32[$b + 12 >> 2];
  var $7 = __ZL14qname_identityP8JSObjectS0_($3, $6);
  return $7;
}

function __ZL14qname_identityP8JSObjectS0_($qna, $qnb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZNK8JSObject10getNameURIEv($qna);
    var $2 = __ZNK8JSObject10getNameURIEv($qnb);
    var $3 = ($1 | 0) != 0;
    if (($3 & 1 ^ 1 | 0) == (($2 | 0) == 0 & 1 | 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ($3) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $11 = __ZN2js12EqualStringsEP14JSLinearStringS1_($1, $2);
    if ($11) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $13 = __ZNK8JSObject17getQNameLocalNameEv($qna);
    var $14 = $13 | 0;
    var $15 = __ZNK8JSObject17getQNameLocalNameEv($qnb);
    var $16 = $15 | 0;
    var $17 = __ZN2js12EqualStringsEP14JSLinearStringS1_($14, $16);
    var $_0 = $17 & 1;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi($pattern, $patternLength, $ignoreCase, $multiline, $numSubpatterns, $error) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $cd = __stackBase__;
    var $errorcode = __stackBase__ + 20;
    var $ptr = __stackBase__ + 24;
    var $code = __stackBase__ + 28;
    var $firstByte = __stackBase__ + 32;
    var $reqByte = __stackBase__ + 36;
    var $bracketCount = __stackBase__ + 40;
    if (($error | 0) == 0) {
      var $_0 = 0;
      __label__ = 46;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    HEAP32[$error >> 2] = 0;
    __ZN11CompileDataC1Ev($cd);
    HEAP32[$errorcode >> 2] = 0;
    var $3 = __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode);
    var $4 = __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode);
    var $5 = HEAP32[$errorcode >> 2];
    if (($5 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    __ZL11returnError9ErrorCodePi($5, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 4:
    if (($4 | 0) > 4194304) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    __ZL11returnError9ErrorCodePi(16, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 6:
    var $12 = $4 + 12 | 0;
    var $13 = __ZN2js11OffTheBooks9array_newIcEEPT_j($12);
    var $14 = $13;
    if (($13 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    __ZL11returnError9ErrorCodePi(13, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 8:
    var $21 = ($multiline | 0) != 0 ? 2 : 0;
    var $23 = $13;
    HEAP32[$23 >> 2] = $21 | ($ignoreCase | 0) != 0 & 1;
    var $24 = $13 + 12 | 0;
    HEAP32[$ptr >> 2] = $pattern;
    var $25 = $pattern + ($patternLength << 1) | 0;
    HEAP32[$code >> 2] = $24;
    HEAP32[$bracketCount >> 2] = 0;
    var $26 = $cd + 12 | 0;
    if ((HEAP8[$26] & 1) << 24 >> 24 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $31 = HEAP32[$23 >> 2];
    var $32 = __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($31, $bracketCount, $code, $ptr, $25, $errorcode, $firstByte, $reqByte, $cd);
    __label__ = 11;
    break;
   case 10:
    HEAP8[$24] = 67;
    var $34 = HEAP32[$23 >> 2];
    var $35 = __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($34, $bracketCount, $code, $ptr, $25, $errorcode, 2, $firstByte, $reqByte, $cd);
    var $36 = $13 + 16 | 0;
    var $38 = HEAP32[$bracketCount >> 2] & 255;
    __ZL13put2ByteValuePhi($36, $38);
    __label__ = 11;
    break;
   case 11:
    var $43 = $13 + 4 | 0;
    HEAP16[$43 >> 1] = HEAP32[$bracketCount >> 2] & 65535;
    var $48 = $13 + 6 | 0;
    HEAP16[$48 >> 1] = HEAP32[$cd >> 2] & 65535;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    if (HEAPU32[$ptr >> 2] >>> 0 < $25 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$errorcode >> 2] = 10;
    __label__ = 14;
    break;
   case 14:
    var $56 = HEAP32[$code >> 2];
    var $57 = $56 + 1 | 0;
    HEAP32[$code >> 2] = $57;
    HEAP8[$56] = 0;
    if (($57 - $24 | 0) > ($4 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    HEAP32[$errorcode >> 2] = 7;
    __label__ = 16;
    break;
   case 16:
    if ((HEAPU16[$48 >> 1] & 65535) > (HEAPU16[$43 >> 1] & 65535)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$errorcode >> 2] = 15;
    __label__ = 19;
    break;
   case 18:
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    __ZN2js10Foreground12array_deleteIcEEvPT_($13);
    var $70 = HEAP32[$errorcode >> 2];
    __ZL11returnError9ErrorCodePi($70, $error);
    var $_0 = 0;
    __label__ = 46;
    break;
   case 20:
    var $74 = (HEAP8[$26] & 1) << 24 >> 24 == 0;
    if ($74) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $76 = __ZL17bracketIsAnchoredPKh($24);
    if ($76) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 22:
    var $78 = __ZL16branchIsAnchoredPKh($24);
    if ($78) {
      __label__ = 23;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 23:
    var $81 = HEAP32[$23 >> 2] | 33554432;
    HEAP32[$23 >> 2] = $81;
    __label__ = 37;
    break;
   case 24:
    var $83 = HEAP32[$firstByte >> 2];
    if (($83 | 0) < 0) {
      __label__ = 25;
      break;
    } else {
      var $97 = $83;
      __label__ = 29;
      break;
    }
   case 25:
    if ($74) {
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $87 = __ZL33bracketFindFirstAssertedCharacterPKhb($24, 0);
    var $91 = $87;
    __label__ = 28;
    break;
   case 27:
    var $89 = __ZL32branchFindFirstAssertedCharacterPKhb($24, 0);
    var $91 = $89;
    __label__ = 28;
    break;
   case 28:
    var $91;
    var $92 = HEAPU32[$23 >> 2];
    var $95 = $92 << 8 & 256 | $91;
    HEAP32[$firstByte >> 2] = $95;
    if (($95 | 0) > -1) {
      var $97 = $95;
      __label__ = 29;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 29:
    var $97;
    var $98 = $97 & 255;
    if ($98 >>> 0 < 127) {
      __label__ = 30;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 30:
    if (($97 & 256 | 0) == 0) {
      var $108 = $97;
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $105 = __ZL8flipCaseh($97 & 255);
    var $phitmp = ($105 & 255 | 0) == ($98 | 0) ? $98 : $97;
    var $108 = $phitmp;
    __label__ = 32;
    break;
   case 32:
    var $108;
    HEAP16[$13 + 8 >> 1] = $108 & 65535;
    var $113 = HEAP32[$23 >> 2] | 1073741824;
    HEAP32[$23 >> 2] = $113;
    __label__ = 37;
    break;
   case 33:
    var $119 = HEAP32[$cd + 4 >> 2];
    if ((HEAP8[$26] & 1) << 24 >> 24 == 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $121 = __ZL21bracketNeedsLineStartPKhjj($24, 0, $119);
    if ($121) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    var $123 = __ZL20branchNeedsLineStartPKhjj($24, 0, $119);
    if ($123) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    HEAP32[$23 >> 2] = $92 | 268435456;
    __label__ = 37;
    break;
   case 37:
    var $127 = HEAPU32[$reqByte >> 2];
    if (($127 | 0) > -1) {
      __label__ = 38;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 38:
    var $130 = HEAPU32[$23 >> 2];
    if (($130 & 33554432 | 0) == 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    if (($127 & 512 | 0) == 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    var $137 = $127 & 255;
    if ($137 >>> 0 < 127) {
      __label__ = 41;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 41:
    if (($127 & 256 | 0) == 0) {
      var $149 = $127;
      __label__ = 43;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $143 = $127 & 255;
    var $144 = __ZL8flipCaseh($143);
    var $_ = ($144 & 255 | 0) == ($137 | 0) ? $127 & -257 : $127;
    var $149 = $_;
    __label__ = 43;
    break;
   case 43:
    var $149;
    HEAP16[$13 + 10 >> 1] = $149 & 65535;
    HEAP32[$23 >> 2] = $130 | 536870912;
    __label__ = 44;
    break;
   case 44:
    if (($numSubpatterns | 0) == 0) {
      var $_0 = $14;
      __label__ = 46;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    HEAP32[$numSubpatterns >> 2] = HEAPU16[$43 >> 1] & 65535;
    var $_0 = $14;
    __label__ = 46;
    break;
   case 46:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi["X"] = 1;

function __ZN11CompileDataC1Ev($this) {
  __ZN11CompileDataC2Ev($this);
  return;
}

function __ZL11returnError9ErrorCodePi($errorcode, $error) {
  HEAP32[$error >> 2] = $errorcode;
  return;
}

function __ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode($pattern, $patternLength, $ignoreCase, $cd, $errorcode) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1040;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $brastack = __stackBase__;
    var $bralenstack = __stackBase__ + 800;
    var $ptr = __stackBase__ + 1e3;
    var $minRepeats = __stackBase__ + 1004;
    var $maxRepeats = __stackBase__ + 1008;
    var $buffer = __stackBase__ + 1012;
    var $occ = __stackBase__ + 1020;
    var $ocd = __stackBase__ + 1024;
    var $cc = __stackBase__ + 1028;
    var $buffer1 = __stackBase__ + 1032;
    if (($patternLength | 0) > 4194304) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 3:
    var $4 = $pattern - 2 | 0;
    HEAP32[$ptr >> 2] = $4;
    var $5 = $pattern + ($patternLength << 1) | 0;
    var $6 = $cd + 16 | 0;
    var $7 = $cd + 4 | 0;
    var $8 = $cd | 0;
    var $9 = $cd + 12 | 0;
    var $10 = ($ignoreCase | 0) == 0;
    var $11 = $buffer | 0;
    var $12 = ($ignoreCase | 0) != 0;
    var $13 = $12 ? 2 : 1;
    var $14 = $buffer1 | 0;
    var $length_0 = 6;
    var $branch_extra_0 = 0;
    var $lastitemlength_0 = 0;
    var $brastackptr_0 = 0;
    var $bracount_0 = 0;
    var $15 = $4;
    __label__ = 4;
    break;
   case 4:
    var $15;
    var $bracount_0;
    var $brastackptr_0;
    var $lastitemlength_0;
    var $branch_extra_0;
    var $length_0;
    var $16 = $15 + 2 | 0;
    HEAP32[$ptr >> 2] = $16;
    if ($16 >>> 0 < $5 >>> 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 5:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = 0;
    var $20 = HEAPU16[$16 >> 1] & 65535;
    if (($20 | 0) == 92) {
      __label__ = 6;
      break;
    } else if (($20 | 0) == 94 || ($20 | 0) == 46 || ($20 | 0) == 36) {
      __label__ = 28;
      break;
    } else if (($20 | 0) == 42 || ($20 | 0) == 43 || ($20 | 0) == 63) {
      __label__ = 29;
      break;
    } else if (($20 | 0) == 123) {
      __label__ = 30;
      break;
    } else if (($20 | 0) == 124) {
      __label__ = 44;
      break;
    } else if (($20 | 0) == 91) {
      __label__ = 47;
      break;
    } else if (($20 | 0) == 40) {
      __label__ = 98;
      break;
    } else if (($20 | 0) == 41) {
      __label__ = 108;
      break;
    } else {
      var $length_14 = $length_0;
      var $c_6 = $20;
      __label__ = 135;
      break;
    }
   case 6:
    var $22 = HEAP32[$6 >> 2];
    var $23 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $22, 0);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 7:
    if (($23 | 0) > -1) {
      __label__ = 8;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 8:
    var $29 = $length_0 + 2 | 0;
    if (($23 | 0) > 127) {
      var $i_0 = 0;
      __label__ = 10;
      break;
    } else {
      var $length_0_be = $29;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 9:
    var $bracount_0_be;
    var $brastackptr_0_be;
    var $lastitemlength_0_be;
    var $branch_extra_0_be;
    var $length_0_be;
    var $length_0 = $length_0_be;
    var $branch_extra_0 = $branch_extra_0_be;
    var $lastitemlength_0 = $lastitemlength_0_be;
    var $brastackptr_0 = $brastackptr_0_be;
    var $bracount_0 = $bracount_0_be;
    var $15 = HEAP32[$ptr >> 2];
    __label__ = 4;
    break;
   case 10:
    var $i_0;
    if (($i_0 | 0) < 6) {
      __label__ = 11;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 11:
    if (($23 | 0) > (HEAP32[_jsc_pcre_utf8_table1 + ($i_0 << 2) >> 2] | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 10;
    break;
   case 13:
    var $length_0_be = $i_0 + $29 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $i_0 + 1 | 0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 14:
    if (($23 | 0) < -8) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0_be = $length_0 + 1 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 16:
    var $45 = -9 - $23 | 0;
    var $_ = ($45 | 0) < 32 ? 1 << $45 : 1;
    var $49 = HEAP32[$7 >> 2] | $_;
    HEAP32[$7 >> 2] = $49;
    if (($45 | 0) > (HEAP32[$8 >> 2] | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 17:
    HEAP32[$8 >> 2] = $45;
    __label__ = 18;
    break;
   case 18:
    var $54 = $length_0 + 3 | 0;
    var $55 = HEAP32[$ptr >> 2];
    var $56 = __ZL19safelyCheckNextCharPKtS0_t($55, $5, 123);
    if ($56) {
      __label__ = 19;
      break;
    } else {
      var $length_0_be = $54;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 19:
    var $58 = $55 + 4 | 0;
    var $59 = __ZL15isCountedRepeatPKtS0_($58, $5);
    if ($59) {
      __label__ = 20;
      break;
    } else {
      var $length_0_be = $54;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 20:
    var $61 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($58, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $61;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 21:
    var $65 = HEAP32[$minRepeats >> 2];
    if (($65 | 0) == 0) {
      __label__ = 22;
      break;
    } else if (($65 | 0) == 1) {
      __label__ = 23;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 22:
    var $67 = HEAP32[$maxRepeats >> 2];
    if (($67 | 0) == -1 || ($67 | 0) == 1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 23:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 24;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 24:
    var $length_1 = $length_0 + 4 | 0;
    __label__ = 26;
    break;
   case 25:
    var $length_1 = $length_0 + 8 | 0;
    __label__ = 26;
    break;
   case 26:
    var $length_1;
    var $75 = __ZL19safelyCheckNextCharPKtS0_t($61, $5, 63);
    if ($75) {
      __label__ = 27;
      break;
    } else {
      var $length_0_be = $length_1;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 27:
    var $77 = $61 + 2 | 0;
    HEAP32[$ptr >> 2] = $77;
    var $length_0_be = $length_1;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 28:
    var $length_0_be = $length_0 + 1 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 29:
    var $length_4 = $length_0 + 1 | 0;
    var $113 = $16;
    __label__ = 42;
    break;
   case 30:
    var $83 = $15 + 4 | 0;
    var $84 = __ZL15isCountedRepeatPKtS0_($83, $5);
    if ($84) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $length_0_be = $length_0 + 2 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = 1;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 32:
    var $87 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($83, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $87;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 33:
    var $91 = HEAP32[$minRepeats >> 2];
    if (($91 | 0) == 0) {
      __label__ = 34;
      break;
    } else if (($91 | 0) == 1) {
      __label__ = 35;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 34:
    var $93 = HEAP32[$maxRepeats >> 2];
    if (($93 | 0) == -1 || ($93 | 0) == 1) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 36;
      break;
    } else {
      var $length_2 = $length_0;
      __label__ = 39;
      break;
    }
   case 36:
    var $length_3 = $length_0 + 1 | 0;
    __label__ = 40;
    break;
   case 37:
    __label__ = 38;
    break;
   case 38:
    var $_6_p = ($91 | 0) > 0 ? 5 : -$lastitemlength_0 | 0;
    var $length_2 = $_6_p + $length_0 | 0;
    __label__ = 39;
    break;
   case 39:
    var $length_2;
    var $105 = (HEAP32[$maxRepeats >> 2] | 0) > 0 ? 5 : 1;
    var $length_3 = $length_2 + $lastitemlength_0 + $105 | 0;
    __label__ = 40;
    break;
   case 40:
    var $length_3;
    var $109 = __ZL19safelyCheckNextCharPKtS0_t($87, $5, 63);
    if ($109) {
      __label__ = 41;
      break;
    } else {
      var $length_4 = $length_3;
      var $113 = $87;
      __label__ = 42;
      break;
    }
   case 41:
    var $111 = $87 + 2 | 0;
    HEAP32[$ptr >> 2] = $111;
    var $length_4 = $length_3;
    var $113 = $111;
    __label__ = 42;
    break;
   case 42:
    var $113;
    var $length_4;
    var $114 = __ZL19safelyCheckNextCharPKtS0_t($113, $5, 43);
    if ($114) {
      __label__ = 43;
      break;
    } else {
      var $length_0_be = $length_4;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 43:
    HEAP32[$ptr >> 2] = $113 + 2 | 0;
    var $length_0_be = $length_4 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 44:
    if (($brastackptr_0 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    HEAP8[$9] = 1;
    __label__ = 46;
    break;
   case 46:
    var $length_0_be = $length_0 + ($branch_extra_0 + 4) | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 47:
    var $125 = $15 + 4 | 0;
    HEAP32[$ptr >> 2] = $125;
    if (HEAP16[$125 >> 1] << 16 >> 16 == 94) {
      __label__ = 48;
      break;
    } else {
      var $length_5 = $length_0;
      var $c_0 = 91;
      var $class_utf8_0 = 0;
      var $class_optcount_1 = 0;
      var $130 = $125;
      __label__ = 49;
      break;
    }
   case 48:
    var $129 = $15 + 6 | 0;
    HEAP32[$ptr >> 2] = $129;
    var $length_5 = $length_0;
    var $c_0 = 91;
    var $class_utf8_0 = 0;
    var $class_optcount_1 = 10;
    var $130 = $129;
    __label__ = 49;
    break;
   case 49:
    var $130;
    var $class_optcount_1;
    var $class_utf8_0;
    var $c_0;
    var $length_5;
    if ($130 >>> 0 < $5 >>> 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 84;
      break;
    }
   case 50:
    var $133 = HEAPU16[$130 >> 1];
    if ($133 << 16 >> 16 == 92) {
      __label__ = 51;
      break;
    } else if ($133 << 16 >> 16 == 93) {
      __label__ = 85;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 51:
    var $135 = HEAP32[$6 >> 2];
    var $136 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $135, 1);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 52;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 52:
    if (($136 | 0) > -1) {
      __label__ = 53;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $136;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = 10;
      __label__ = 83;
      break;
    }
   case 53:
    var $c_1 = $136;
    var $144 = HEAP32[$ptr >> 2];
    __label__ = 55;
    break;
   case 54:
    var $c_1 = $133 & 65535;
    var $144 = $130;
    __label__ = 55;
    break;
   case 55:
    var $144;
    var $c_1;
    var $145 = $class_optcount_1 + 1 | 0;
    var $146 = __ZL19safelyCheckNextCharPKtS0_t($144, $5, 45);
    if ($146) {
      __label__ = 56;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 56:
    var $148 = $144 + 2 | 0;
    HEAP32[$ptr >> 2] = $148;
    var $149 = __ZL19safelyCheckNextCharPKtS0_t($148, $5, 92);
    var $150 = $144 + 4 | 0;
    if ($149) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP32[$ptr >> 2] = $150;
    var $152 = HEAP32[$6 >> 2];
    var $153 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $5, $errorcode, $152, 1);
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 58:
    if ($150 >>> 0 < $5 >>> 0) {
      __label__ = 59;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 59:
    if (HEAP16[$150 >> 1] << 16 >> 16 == 93) {
      __label__ = 62;
      break;
    } else {
      __label__ = 60;
      break;
    }
   case 60:
    HEAP32[$ptr >> 2] = $150;
    var $d_1_ph = HEAPU16[$150 >> 1] & 65535;
    __label__ = 63;
    break;
   case 61:
    if (($153 | 0) < 0) {
      __label__ = 62;
      break;
    } else {
      var $d_1_ph = $153;
      __label__ = 63;
      break;
    }
   case 62:
    HEAP32[$ptr >> 2] = $144;
    __label__ = 81;
    break;
   case 63:
    var $d_1_ph;
    if (($d_1_ph | 0) < ($c_1 | 0)) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    HEAP32[$errorcode >> 2] = 8;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 65:
    if (($d_1_ph | 0) > 255 | $12 & ($d_1_ph | 0) > 127) {
      __label__ = 66;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $c_1;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = 10;
      __label__ = 83;
      break;
    }
   case 66:
    var $174 = ($class_utf8_0 & 1) << 24 >> 24 == 0;
    var $_length_5 = $174 ? $length_5 + 5 | 0 : $length_5;
    var $class_utf8_1 = $174 ? 1 : $class_utf8_0;
    if ($10) {
      var $length_8 = $_length_5;
      var $d_3 = $d_1_ph;
      var $c_3 = $c_1;
      __label__ = 80;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    HEAP32[$cc >> 2] = $c_1;
    var $length_7_ph = $_length_5;
    var $d_2_ph = $d_1_ph;
    var $c_2_ph = $c_1;
    __label__ = 68;
    break;
   case 68:
    var $c_2_ph;
    var $d_2_ph;
    var $length_7_ph;
    var $176 = $c_2_ph - 1 | 0;
    var $length_7_ph34 = $length_7_ph;
    var $d_2_ph33 = $d_2_ph;
    __label__ = 69;
    break;
   case 69:
    var $d_2_ph33;
    var $length_7_ph34;
    var $177 = $d_2_ph33 + 1 | 0;
    var $length_7_ph36 = $length_7_ph34;
    __label__ = 70;
    break;
   case 70:
    var $length_7_ph36;
    __label__ = 71;
    break;
   case 71:
    var $179 = __ZL17getOthercaseRangePiiS_S_($cc, $d_1_ph, $occ, $ocd);
    if ($179) {
      __label__ = 72;
      break;
    } else {
      var $length_8 = $length_7_ph36;
      var $d_3 = $d_2_ph33;
      var $c_3 = $c_2_ph;
      __label__ = 80;
      break;
    }
   case 72:
    var $181 = HEAP32[$occ >> 2];
    var $183 = HEAP32[$ocd >> 2];
    if (($181 | 0) < ($c_2_ph | 0)) {
      __label__ = 75;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    if (($183 | 0) > ($d_2_ph33 | 0)) {
      __label__ = 74;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 74:
    var $189 = HEAP32[$ocd >> 2];
    __label__ = 76;
    break;
   case 75:
    if (($183 | 0) < ($176 | 0)) {
      var $189 = $183;
      __label__ = 76;
      break;
    } else {
      var $length_7_ph = $length_7_ph36;
      var $d_2_ph = $d_2_ph33;
      var $c_2_ph = $181;
      __label__ = 68;
      break;
    }
   case 76:
    var $189;
    if (($189 | 0) <= ($d_2_ph33 | 0) | ($181 | 0) > ($177 | 0)) {
      __label__ = 77;
      break;
    } else {
      var $length_7_ph34 = $length_7_ph36;
      var $d_2_ph33 = $189;
      __label__ = 69;
      break;
    }
   case 77:
    var $193 = __ZL10encodeUTF8iPh($181, $11);
    if (($181 | 0) == ($189 | 0)) {
      var $198 = 0;
      __label__ = 79;
      break;
    } else {
      __label__ = 78;
      break;
    }
   case 78:
    var $196 = __ZL10encodeUTF8iPh($189, $11);
    var $198 = $196;
    __label__ = 79;
    break;
   case 79:
    var $198;
    var $length_7_ph36 = $198 + ($193 + ($length_7_ph36 + 1)) | 0;
    __label__ = 70;
    break;
   case 80:
    var $c_3;
    var $d_3;
    var $length_8;
    var $202 = __ZL10encodeUTF8iPh($c_3, $11);
    var $203 = __ZL10encodeUTF8iPh($d_3, $11);
    var $length_10 = $203 + ($202 + ($length_8 + 1)) | 0;
    var $c_4 = $c_3;
    var $class_utf8_3 = $class_utf8_1;
    var $class_optcount_2 = 10;
    __label__ = 83;
    break;
   case 81:
    if (($c_1 | 0) > 255 | $12 & ($c_1 | 0) > 127) {
      __label__ = 82;
      break;
    } else {
      var $length_10 = $length_5;
      var $c_4 = $c_1;
      var $class_utf8_3 = $class_utf8_0;
      var $class_optcount_2 = $145;
      __label__ = 83;
      break;
    }
   case 82:
    var $212 = ($class_utf8_0 & 1) << 24 >> 24 == 0;
    var $_length_58 = $212 ? $length_5 + 5 | 0 : $length_5;
    var $class_utf8_2 = $212 ? 1 : $class_utf8_0;
    var $213 = __ZL10encodeUTF8iPh($c_1, $14);
    var $length_10 = ($213 + 1) * $13 + $_length_58 | 0;
    var $c_4 = $c_1;
    var $class_utf8_3 = $class_utf8_2;
    var $class_optcount_2 = 10;
    __label__ = 83;
    break;
   case 83:
    var $class_optcount_2;
    var $class_utf8_3;
    var $c_4;
    var $length_10;
    var $218 = HEAP32[$ptr >> 2] + 2 | 0;
    HEAP32[$ptr >> 2] = $218;
    var $length_5 = $length_10;
    var $c_0 = $c_4;
    var $class_utf8_0 = $class_utf8_3;
    var $class_optcount_1 = $class_optcount_2;
    var $130 = $218;
    __label__ = 49;
    break;
   case 84:
    HEAP32[$errorcode >> 2] = 6;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 85:
    if (($class_optcount_1 | 0) == 1) {
      var $length_14 = $length_5;
      var $c_6 = $c_0;
      __label__ = 135;
      break;
    } else {
      __label__ = 86;
      break;
    }
   case 86:
    var $223 = $length_5 + 33 | 0;
    var $224 = __ZL19safelyCheckNextCharPKtS0_t($130, $5, 123);
    if ($224) {
      __label__ = 87;
      break;
    } else {
      var $length_0_be = $223;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 87:
    var $226 = $130 + 4 | 0;
    var $227 = __ZL15isCountedRepeatPKtS0_($226, $5);
    if ($227) {
      __label__ = 88;
      break;
    } else {
      var $length_0_be = $223;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 88:
    var $229 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($226, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $229;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 89;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 89:
    var $233 = HEAP32[$minRepeats >> 2];
    if (($233 | 0) == 0) {
      __label__ = 90;
      break;
    } else if (($233 | 0) == 1) {
      __label__ = 91;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 90:
    var $235 = HEAP32[$maxRepeats >> 2];
    if (($235 | 0) == -1 || ($235 | 0) == 1) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 91:
    if ((HEAP32[$maxRepeats >> 2] | 0) == -1) {
      __label__ = 92;
      break;
    } else {
      __label__ = 93;
      break;
    }
   case 92:
    var $length_11 = $length_5 + 34 | 0;
    __label__ = 94;
    break;
   case 93:
    var $length_11 = $length_5 + 38 | 0;
    __label__ = 94;
    break;
   case 94:
    var $length_11;
    var $243 = __ZL19safelyCheckNextCharPKtS0_t($229, $5, 43);
    if ($243) {
      __label__ = 95;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 95:
    HEAP32[$ptr >> 2] = $229 + 2 | 0;
    var $length_0_be = $length_11 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 96:
    var $248 = __ZL19safelyCheckNextCharPKtS0_t($229, $5, 63);
    if ($248) {
      __label__ = 97;
      break;
    } else {
      var $length_0_be = $length_11;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 97:
    HEAP32[$ptr >> 2] = $229 + 2 | 0;
    var $length_0_be = $length_11;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 98:
    var $252 = __ZL19safelyCheckNextCharPKtS0_t($16, $5, 63);
    if ($252) {
      __label__ = 99;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 99:
    var $254 = $15 + 6 | 0;
    if ($254 >>> 0 < $5 >>> 0) {
      __label__ = 100;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 100:
    var $258 = HEAPU16[$254 >> 1] & 65535;
    if (($258 | 0) == 58 || ($258 | 0) == 61 || ($258 | 0) == 33) {
      __label__ = 101;
      break;
    } else {
      __label__ = 102;
      break;
    }
   case 101:
    HEAP32[$ptr >> 2] = $254;
    var $bracket_length_0 = 6;
    var $bracount_1 = $bracount_0;
    __label__ = 105;
    break;
   case 102:
    HEAP32[$errorcode >> 2] = 12;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 103:
    var $260 = $bracount_0 + 1 | 0;
    if (($260 | 0) > 100) {
      __label__ = 104;
      break;
    } else {
      var $bracket_length_0 = 6;
      var $bracount_1 = $260;
      __label__ = 105;
      break;
    }
   case 104:
    var $bracket_length_0 = 9;
    var $bracount_1 = $260;
    __label__ = 105;
    break;
   case 105:
    var $bracount_1;
    var $bracket_length_0;
    if ($brastackptr_0 >>> 0 > 199) {
      __label__ = 106;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 106:
    HEAP32[$errorcode >> 2] = 17;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 107:
    HEAP8[$bralenstack + $brastackptr_0 | 0] = $branch_extra_0 & 255;
    HEAP32[$brastack + ($brastackptr_0 << 2) >> 2] = $length_0;
    var $length_0_be = $bracket_length_0 + $length_0 | 0;
    var $branch_extra_0_be = 0;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_0 + 1 | 0;
    var $bracount_0_be = $bracount_1;
    __label__ = 9;
    break;
   case 108:
    var $273 = $length_0 + 4 | 0;
    if (($brastackptr_0 | 0) == 0) {
      var $duplength_0 = 0;
      var $branch_extra_1 = $branch_extra_0;
      var $brastackptr_1 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $276 = $brastackptr_0 - 1 | 0;
    var $duplength_0 = $273 - HEAP32[$brastack + ($276 << 2) >> 2] | 0;
    var $branch_extra_1 = HEAPU8[$bralenstack + $276 | 0] & 255;
    var $brastackptr_1 = $276;
    __label__ = 110;
    break;
   case 110:
    var $brastackptr_1;
    var $branch_extra_1;
    var $duplength_0;
    var $284 = $15 + 4 | 0;
    if ($284 >>> 0 < $5 >>> 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 111:
    var $287 = HEAPU16[$284 >> 1];
    var $288 = $287 & 65535;
    if ($287 << 16 >> 16 == 123) {
      __label__ = 112;
      break;
    } else {
      var $c_5 = $288;
      __label__ = 114;
      break;
    }
   case 112:
    var $291 = $15 + 6 | 0;
    var $292 = __ZL15isCountedRepeatPKtS0_($291, $5);
    if ($292) {
      __label__ = 113;
      break;
    } else {
      var $c_5 = $288;
      __label__ = 114;
      break;
    }
   case 113:
    var $294 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($291, $minRepeats, $maxRepeats, $errorcode);
    HEAP32[$ptr >> 2] = $294;
    if ((HEAP32[$errorcode >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      var $_0 = -1;
      __label__ = 141;
      break;
    }
   case 114:
    var $c_5;
    if (($c_5 | 0) == 42) {
      __label__ = 115;
      break;
    } else if (($c_5 | 0) == 43) {
      __label__ = 116;
      break;
    } else if (($c_5 | 0) == 63) {
      __label__ = 117;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 115:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = -1;
    HEAP32[$ptr >> 2] = $284;
    var $length_13 = $length_0 + 5 | 0;
    var $341 = $284;
    __label__ = 133;
    break;
   case 116:
    HEAP32[$minRepeats >> 2] = 1;
    HEAP32[$maxRepeats >> 2] = -1;
    HEAP32[$ptr >> 2] = $284;
    var $319 = 1;
    var $318 = $284;
    __label__ = 125;
    break;
   case 117:
    HEAP32[$minRepeats >> 2] = 0;
    HEAP32[$maxRepeats >> 2] = 1;
    HEAP32[$ptr >> 2] = $284;
    var $308 = 1;
    var $307 = $length_0 + 5 | 0;
    var $306 = $284;
    __label__ = 121;
    break;
   case 118:
    HEAP32[$minRepeats >> 2] = 1;
    HEAP32[$maxRepeats >> 2] = 1;
    var $319 = 1;
    var $318 = $16;
    __label__ = 125;
    break;
   case 119:
    var $_pr24 = HEAP32[$minRepeats >> 2];
    if (($_pr24 | 0) == 0) {
      __label__ = 120;
      break;
    } else {
      var $319 = $_pr24;
      var $318 = $294;
      __label__ = 125;
      break;
    }
   case 120:
    var $_pr30 = HEAP32[$maxRepeats >> 2];
    var $303 = $length_0 + 5 | 0;
    if (($_pr30 | 0) > 0) {
      var $308 = $_pr30;
      var $307 = $303;
      var $306 = $294;
      __label__ = 121;
      break;
    } else {
      var $length_13 = $303;
      var $341 = $294;
      __label__ = 133;
      break;
    }
   case 121:
    var $306;
    var $307;
    var $308;
    var $311 = __ZL25multiplyWithOverflowCheckii($308 - 1 | 0, $duplength_0 + 11 | 0);
    if (($311 | 0) < 0) {
      __label__ = 122;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 122:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 123:
    var $315 = $311 + $307 | 0;
    if (($315 | 0) > 4194304) {
      __label__ = 124;
      break;
    } else {
      var $length_13 = $315;
      var $341 = $306;
      __label__ = 133;
      break;
    }
   case 124:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 125:
    var $318;
    var $319;
    var $321 = __ZL25multiplyWithOverflowCheckii($319 - 1 | 0, $duplength_0);
    if (($321 | 0) < 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 127:
    var $325 = $321 + $273 | 0;
    var $326 = HEAP32[$maxRepeats >> 2];
    if (($326 | 0) > ($319 | 0)) {
      __label__ = 128;
      break;
    } else {
      var $length_12 = $325;
      __label__ = 131;
      break;
    }
   case 128:
    var $329 = $326 - $319 | 0;
    var $331 = __ZL25multiplyWithOverflowCheckii($329, $duplength_0 + 11 | 0);
    if (($331 | 0) < 0) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 130:
    var $length_12 = $325 - 8 + $331 | 0;
    __label__ = 131;
    break;
   case 131:
    var $length_12;
    if (($length_12 | 0) > 4194304) {
      __label__ = 132;
      break;
    } else {
      var $length_13 = $length_12;
      var $341 = $318;
      __label__ = 133;
      break;
    }
   case 132:
    HEAP32[$errorcode >> 2] = 16;
    var $_0 = -1;
    __label__ = 141;
    break;
   case 133:
    var $341;
    var $length_13;
    var $342 = __ZL19safelyCheckNextCharPKtS0_t($341, $5, 43);
    if ($342) {
      __label__ = 134;
      break;
    } else {
      var $length_0_be = $length_13;
      var $branch_extra_0_be = $branch_extra_1;
      var $lastitemlength_0_be = $lastitemlength_0;
      var $brastackptr_0_be = $brastackptr_1;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 134:
    HEAP32[$ptr >> 2] = $341 + 2 | 0;
    var $length_0_be = $length_13 + 8 | 0;
    var $branch_extra_0_be = $branch_extra_1;
    var $lastitemlength_0_be = $lastitemlength_0;
    var $brastackptr_0_be = $brastackptr_1;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 135:
    var $c_6;
    var $length_14;
    var $347 = $length_14 + 2 | 0;
    if (($c_6 | 0) > 127) {
      var $i2_0 = 0;
      __label__ = 136;
      break;
    } else {
      var $length_0_be = $347;
      var $branch_extra_0_be = $branch_extra_0;
      var $lastitemlength_0_be = 1;
      var $brastackptr_0_be = $brastackptr_0;
      var $bracount_0_be = $bracount_0;
      __label__ = 9;
      break;
    }
   case 136:
    var $i2_0;
    if (($i2_0 | 0) < 6) {
      __label__ = 137;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 137:
    if (($c_6 | 0) > (HEAP32[_jsc_pcre_utf8_table1 + ($i2_0 << 2) >> 2] | 0)) {
      __label__ = 138;
      break;
    } else {
      __label__ = 139;
      break;
    }
   case 138:
    var $i2_0 = $i2_0 + 1 | 0;
    __label__ = 136;
    break;
   case 139:
    var $length_0_be = $i2_0 + $347 | 0;
    var $branch_extra_0_be = $branch_extra_0;
    var $lastitemlength_0_be = $i2_0 + 1 | 0;
    var $brastackptr_0_be = $brastackptr_0;
    var $bracount_0_be = $bracount_0;
    __label__ = 9;
    break;
   case 140:
    HEAP32[$6 >> 2] = $bracount_0;
    var $_0 = $length_0 + 5 | 0;
    __label__ = 141;
    break;
   case 141:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode["X"] = 1;

function __ZN2js11OffTheBooks9array_newIcEEPT_j($n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1$0 = $n;
    var $2$0 = (i64Math.add($1$0, 0, 8, 0), i64Math.result[0]);
    var $2$1 = i64Math.result[1];
    if ($2$0 == ($2$0 & -1) && $2$1 == ($2$1 & 0)) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 2:
    var $6 = $2$0;
    var $7 = _js_malloc4456($6);
    if (($7 | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    HEAP32[$7 >> 2] = $n;
    var $_0 = $7 + 8 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($options, $brackets, $codePtr, $ptrPtr, $patternEnd, $errorCodePtr, $firstbyteptr, $reqbyteptr, $cd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 96;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $repeatMin = __stackBase__;
    var $repeat_max = __stackBase__ + 4;
    var $code = __stackBase__ + 8;
    var $tempcode = __stackBase__ + 12;
    var $ptr = __stackBase__ + 16;
    var $previous = __stackBase__ + 20;
    var $classbits = __stackBase__ + 24;
    var $utf8_char = __stackBase__ + 56;
    var $subReqByte = __stackBase__ + 64;
    var $subFirstByte = __stackBase__ + 68;
    var $mcbuffer = __stackBase__ + 72;
    var $occ = __stackBase__ + 80;
    var $ocd = __stackBase__ + 84;
    var $cc = __stackBase__ + 88;
    var $ket = __stackBase__ + 92;
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = 0;
    var $1 = HEAP32[$codePtr >> 2];
    HEAP32[$code >> 2] = $1;
    var $2 = HEAP32[$ptrPtr >> 2];
    HEAP32[$ptr >> 2] = $2;
    HEAP32[$previous >> 2] = 0;
    var $3 = $options & 1;
    var $4 = ($3 | 0) != 0;
    var $5 = $3 << 8;
    var $6 = $mcbuffer | 0;
    var $8 = ($3 | 14) & 255;
    var $10 = ($options & 2 | 0) == 0;
    var $11 = $classbits | 0;
    var $12 = $cd + 16 | 0;
    var $13 = $cd + 8 | 0;
    var $14 = ($3 | 0) == 0;
    var $15 = $utf8_char | 0;
    var $didGroupSetFirstByte_0 = 0;
    var $firstByte_0 = -2;
    var $reqByte_0 = -2;
    var $zeroReqByte_0 = -2;
    var $zeroFirstByte_0 = -2;
    var $17 = $2;
    __label__ = 2;
    break;
   case 2:
    var $17;
    var $zeroFirstByte_0;
    var $zeroReqByte_0;
    var $reqByte_0;
    var $firstByte_0;
    var $didGroupSetFirstByte_0;
    var $18 = $17 >>> 0 < $patternEnd >>> 0;
    if ($18) {
      __label__ = 3;
      break;
    } else {
      var $23 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $23 = HEAPU16[$17 >> 1] & 65535;
    __label__ = 4;
    break;
   case 4:
    var $23;
    if (($23 - 42 | 0) >>> 0 < 2 | ($23 | 0) == 63) {
      var $31 = 1;
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($23 | 0) == 123) {
      __label__ = 6;
      break;
    } else {
      var $31 = 0;
      __label__ = 7;
      break;
    }
   case 6:
    var $28 = $17 + 2 | 0;
    var $29 = __ZL15isCountedRepeatPKtS0_($28, $patternEnd);
    if ($29) {
      var $_pre_phi = $28;
      __label__ = 88;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 7:
    var $31;
    if (($23 | 0) == 0) {
      __label__ = 8;
      break;
    } else if (($23 | 0) == 124 || ($23 | 0) == 41) {
      __label__ = 9;
      break;
    } else if (($23 | 0) == 94) {
      __label__ = 10;
      break;
    } else if (($23 | 0) == 36) {
      __label__ = 14;
      break;
    } else if (($23 | 0) == 46) {
      __label__ = 17;
      break;
    } else if (($23 | 0) == 91) {
      __label__ = 18;
      break;
    } else if (($23 | 0) == 123) {
      __label__ = 86;
      break;
    } else if (($23 | 0) == 42) {
      __label__ = 89;
      break;
    } else if (($23 | 0) == 43) {
      __label__ = 90;
      break;
    } else if (($23 | 0) == 63) {
      __label__ = 91;
      break;
    } else if (($23 | 0) == 40) {
      __label__ = 177;
      break;
    } else if (($23 | 0) == 92) {
      __label__ = 206;
      break;
    } else {
      var $c_13 = $23;
      __label__ = 214;
      break;
    }
   case 8:
    if ($18) {
      __label__ = 213;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    HEAP32[$firstbyteptr >> 2] = $firstByte_0;
    HEAP32[$reqbyteptr >> 2] = $reqByte_0;
    var $33 = HEAP32[$code >> 2];
    HEAP32[$codePtr >> 2] = $33;
    HEAP32[$ptrPtr >> 2] = $17;
    var $_0 = 1;
    __label__ = 230;
    break;
   case 10:
    if ($10) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $firstByte_1 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $37 = HEAP32[$code >> 2];
    var $38 = $37 + 1 | 0;
    HEAP32[$code >> 2] = $38;
    HEAP8[$37] = 12;
    var $firstByte_2 = $firstByte_1;
    __label__ = 13;
    break;
   case 12:
    var $40 = HEAP32[$code >> 2];
    var $41 = $40 + 1 | 0;
    HEAP32[$code >> 2] = $41;
    HEAP8[$40] = 10;
    var $firstByte_2 = $firstByte_0;
    __label__ = 13;
    break;
   case 13:
    var $firstByte_2;
    HEAP32[$previous >> 2] = 0;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_2;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 14:
    HEAP32[$previous >> 2] = 0;
    var $44 = HEAP32[$code >> 2];
    var $45 = $44 + 1 | 0;
    HEAP32[$code >> 2] = $45;
    if ($10) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    HEAP8[$44] = 13;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 16:
    HEAP8[$44] = 11;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 17:
    var $firstByte_3 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $50 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $50;
    var $51 = $50 + 1 | 0;
    HEAP32[$code >> 2] = $51;
    HEAP8[$50] = 9;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_3;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_3;
    __label__ = 228;
    break;
   case 18:
    var $53 = HEAPU32[$code >> 2];
    HEAP32[$previous >> 2] = $53;
    var $54 = $17 + 2 | 0;
    if ($54 >>> 0 < $patternEnd >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    HEAP32[$errorCodePtr >> 2] = 6;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 20:
    if (HEAP16[$54 >> 1] << 16 >> 16 == 94) {
      __label__ = 21;
      break;
    } else {
      var $negateClass_0 = 0;
      var $62 = $17;
      __label__ = 22;
      break;
    }
   case 21:
    HEAP32[$ptr >> 2] = $54;
    var $negateClass_0 = 1;
    var $62 = $54;
    __label__ = 22;
    break;
   case 22:
    var $62;
    var $negateClass_0;
    var $63 = $53 + 37 | 0;
    _memset($11, 0, 32, 1);
    var $classLastChar_0 = -1;
    var $classCharCount_0 = 0;
    var $shouldFlipNegation_0 = 0;
    var $class_utf8_0 = 0;
    var $class_utf8data_0 = $63;
    var $64 = $62;
    __label__ = 23;
    break;
   case 23:
    var $64;
    var $class_utf8data_0;
    var $class_utf8_0;
    var $shouldFlipNegation_0;
    var $classCharCount_0;
    var $classLastChar_0;
    var $65 = $64 + 2 | 0;
    HEAP32[$ptr >> 2] = $65;
    if ($65 >>> 0 < $patternEnd >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 24:
    var $68 = HEAPU16[$65 >> 1];
    if ($68 << 16 >> 16 == 93) {
      __label__ = 72;
      break;
    } else {
      __label__ = 25;
      break;
    }
   case 25:
    var $71 = $68 & 65535;
    if ($68 << 16 >> 16 == 92) {
      __label__ = 26;
      break;
    } else {
      var $c_6 = $71;
      var $128 = $65;
      __label__ = 36;
      break;
    }
   case 26:
    var $74 = HEAP32[$12 >> 2];
    var $75 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $74, 1);
    if (($75 | 0) < 0) {
      __label__ = 28;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $c_6 = $75;
    var $128 = HEAP32[$ptr >> 2];
    __label__ = 36;
    break;
   case 28:
    var $78 = $classCharCount_0 + 2 | 0;
    var $79 = -$75 | 0;
    if (($79 | 0) == 4) {
      var $c_081 = 0;
      __label__ = 29;
      break;
    } else if (($79 | 0) == 3) {
      var $c_178 = 0;
      __label__ = 30;
      break;
    } else if (($79 | 0) == 8) {
      var $c_275 = 0;
      __label__ = 31;
      break;
    } else if (($79 | 0) == 7) {
      var $c_372 = 0;
      __label__ = 32;
      break;
    } else if (($79 | 0) == 6) {
      var $c_469 = 0;
      __label__ = 33;
      break;
    } else if (($79 | 0) == 5) {
      var $c_566 = 0;
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 29:
    var $c_081;
    var $82 = __ZL18classBitmapForCharh($c_081 + 32 & 255);
    var $83 = $classbits + $c_081 | 0;
    var $85 = HEAP8[$83] | $82;
    HEAP8[$83] = $85;
    var $86 = $c_081 + 1 | 0;
    if (($86 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_081 = $86;
      __label__ = 29;
      break;
    }
   case 30:
    var $c_178;
    var $89 = __ZL18classBitmapForCharh($c_178 + 32 & 255);
    var $91 = $classbits + $c_178 | 0;
    var $93 = HEAP8[$91] | $89 ^ -1;
    HEAP8[$91] = $93;
    var $94 = $c_178 + 1 | 0;
    if (($94 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_178 = $94;
      __label__ = 30;
      break;
    }
   case 31:
    var $c_275;
    var $97 = __ZL18classBitmapForCharh($c_275 + 64 & 255);
    var $98 = $classbits + $c_275 | 0;
    var $100 = HEAP8[$98] | $97;
    HEAP8[$98] = $100;
    var $101 = $c_275 + 1 | 0;
    if (($101 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_275 = $101;
      __label__ = 31;
      break;
    }
   case 32:
    var $c_372;
    var $104 = __ZL18classBitmapForCharh($c_372 + 64 & 255);
    var $106 = $classbits + $c_372 | 0;
    var $108 = HEAP8[$106] | $104 ^ -1;
    HEAP8[$106] = $108;
    var $109 = $c_372 + 1 | 0;
    if (($109 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_372 = $109;
      __label__ = 32;
      break;
    }
   case 33:
    var $c_469;
    var $111 = __ZL18classBitmapForCharh($c_469 & 255);
    var $112 = $classbits + $c_469 | 0;
    var $114 = HEAP8[$112] | $111;
    HEAP8[$112] = $114;
    var $115 = $c_469 + 1 | 0;
    if (($115 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_469 = $115;
      __label__ = 33;
      break;
    }
   case 34:
    var $c_566;
    var $117 = __ZL18classBitmapForCharh($c_566 & 255);
    var $119 = $classbits + $c_566 | 0;
    var $121 = HEAP8[$119] | $117 ^ -1;
    HEAP8[$119] = $121;
    var $122 = $c_566 + 1 | 0;
    if (($122 | 0) == 32) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $78;
      var $shouldFlipNegation_0_be = 1;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_566 = $122;
      __label__ = 34;
      break;
    }
   case 35:
    var $124 = HEAPU32[$ptr >> 2];
    var $c_6 = HEAPU16[$124 >> 1] & 65535;
    var $128 = $124;
    __label__ = 36;
    break;
   case 36:
    var $128;
    var $c_6;
    var $129 = $128 + 4 | 0;
    if ($129 >>> 0 < $patternEnd >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 37:
    if (HEAP16[$128 + 2 >> 1] << 16 >> 16 == 45) {
      __label__ = 38;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 38:
    if (HEAP16[$129 >> 1] << 16 >> 16 == 93) {
      __label__ = 65;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    HEAP32[$ptr >> 2] = $129;
    var $139 = HEAPU16[$129 >> 1];
    var $140 = $139 & 65535;
    if ($139 << 16 >> 16 == 92) {
      __label__ = 40;
      break;
    } else {
      var $d_0 = $140;
      __label__ = 42;
      break;
    }
   case 40:
    var $143 = HEAP32[$12 >> 2];
    var $144 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $143, 1);
    if (($144 | 0) < 0) {
      __label__ = 41;
      break;
    } else {
      var $d_0 = $144;
      __label__ = 42;
      break;
    }
   case 41:
    HEAP32[$ptr >> 2] = $128;
    __label__ = 65;
    break;
   case 42:
    var $d_0;
    if (($d_0 | 0) == ($c_6 | 0)) {
      __label__ = 65;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if (($d_0 | 0) > 255 | $4 & ($d_0 | 0) > 127) {
      __label__ = 46;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    if (($c_6 | 0) > ($d_0 | 0)) {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_959 = $c_6;
      var $classCharCount_260 = $classCharCount_0;
      __label__ = 62;
      break;
    }
   case 45:
    var $class_utf8data_0_be;
    var $class_utf8_0_be;
    var $shouldFlipNegation_0_be;
    var $classCharCount_0_be;
    var $classLastChar_0_be;
    var $classLastChar_0 = $classLastChar_0_be;
    var $classCharCount_0 = $classCharCount_0_be;
    var $shouldFlipNegation_0 = $shouldFlipNegation_0_be;
    var $class_utf8_0 = $class_utf8_0_be;
    var $class_utf8data_0 = $class_utf8data_0_be;
    var $64 = HEAP32[$ptr >> 2];
    __label__ = 23;
    break;
   case 46:
    if ($4) {
      __label__ = 47;
      break;
    } else {
      var $d_2 = $d_0;
      var $c_8 = $c_6;
      var $class_utf8data_3 = $class_utf8data_0;
      __label__ = 61;
      break;
    }
   case 47:
    HEAP32[$cc >> 2] = $c_6;
    var $d_1_ph = $d_0;
    var $c_7_ph = $c_6;
    var $class_utf8data_1_ph = $class_utf8data_0;
    __label__ = 48;
    break;
   case 48:
    var $class_utf8data_1_ph;
    var $c_7_ph;
    var $d_1_ph;
    var $d_1_ph85 = $d_1_ph;
    var $c_7_ph84 = $c_7_ph;
    __label__ = 49;
    break;
   case 49:
    var $c_7_ph84;
    var $d_1_ph85;
    var $155 = $c_7_ph84 - 1 | 0;
    var $d_1_ph87 = $d_1_ph85;
    __label__ = 50;
    break;
   case 50:
    var $d_1_ph87;
    __label__ = 51;
    break;
   case 51:
    var $157 = __ZL17getOthercaseRangePiiS_S_($cc, $d_0, $occ, $ocd);
    if ($157) {
      __label__ = 52;
      break;
    } else {
      var $d_2 = $d_1_ph87;
      var $c_8 = $c_7_ph84;
      var $class_utf8data_3 = $class_utf8data_1_ph;
      __label__ = 61;
      break;
    }
   case 52:
    var $159 = HEAP32[$occ >> 2];
    var $161 = HEAP32[$ocd >> 2];
    if (($159 | 0) < ($c_7_ph84 | 0)) {
      __label__ = 55;
      break;
    } else {
      __label__ = 53;
      break;
    }
   case 53:
    if (($161 | 0) > ($d_1_ph87 | 0)) {
      __label__ = 54;
      break;
    } else {
      __label__ = 51;
      break;
    }
   case 54:
    var $167 = HEAP32[$ocd >> 2];
    __label__ = 56;
    break;
   case 55:
    if (($161 | 0) < ($155 | 0)) {
      var $167 = $161;
      __label__ = 56;
      break;
    } else {
      var $d_1_ph85 = $d_1_ph87;
      var $c_7_ph84 = $159;
      __label__ = 49;
      break;
    }
   case 56:
    var $167;
    if (($167 | 0) <= ($d_1_ph87 | 0) | ($159 | 0) > ($d_1_ph87 + 1 | 0)) {
      __label__ = 57;
      break;
    } else {
      var $d_1_ph87 = $167;
      __label__ = 50;
      break;
    }
   case 57:
    var $173 = $class_utf8data_1_ph + 1 | 0;
    if (($159 | 0) == ($167 | 0)) {
      __label__ = 58;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 58:
    HEAP8[$class_utf8data_1_ph] = 1;
    var $class_utf8data_2 = $173;
    __label__ = 60;
    break;
   case 59:
    HEAP8[$class_utf8data_1_ph] = 2;
    var $176 = HEAP32[$occ >> 2];
    var $177 = __ZL10encodeUTF8iPh($176, $173);
    var $class_utf8data_2 = $177 + ($class_utf8data_1_ph + 1) | 0;
    __label__ = 60;
    break;
   case 60:
    var $class_utf8data_2;
    var $180 = HEAP32[$ocd >> 2];
    var $181 = __ZL10encodeUTF8iPh($180, $class_utf8data_2);
    var $d_1_ph = $d_1_ph87;
    var $c_7_ph = $c_7_ph84;
    var $class_utf8data_1_ph = $class_utf8data_2 + $181 | 0;
    __label__ = 48;
    break;
   case 61:
    var $class_utf8data_3;
    var $c_8;
    var $d_2;
    HEAP8[$class_utf8data_3] = 2;
    var $184 = __ZL10encodeUTF8iPh($c_8, $class_utf8data_3 + 1 | 0);
    var $_sum7 = $184 + 1 | 0;
    var $185 = $class_utf8data_3 + $_sum7 | 0;
    var $186 = __ZL10encodeUTF8iPh($d_2, $185);
    var $classLastChar_0_be = $classLastChar_0;
    var $classCharCount_0_be = $classCharCount_0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = 1;
    var $class_utf8data_0_be = $class_utf8data_3 + ($_sum7 + $186) | 0;
    __label__ = 45;
    break;
   case 62:
    var $classCharCount_260;
    var $c_959;
    var $191 = $classbits + (($c_959 | 0) / 8 & -1) | 0;
    HEAP8[$191] = (HEAPU8[$191] & 255 | 1 << ($c_959 & 7)) & 255;
    if ($4) {
      __label__ = 63;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 63:
    var $198 = __ZL8flipCaseh($c_959 & 255);
    var $199 = $198 & 255;
    var $203 = $classbits + ($199 >>> 3) | 0;
    HEAP8[$203] = (1 << ($199 & 7) | HEAPU8[$203] & 255) & 255;
    __label__ = 64;
    break;
   case 64:
    var $209 = $classCharCount_260 + 1 | 0;
    var $210 = $c_959 + 1 | 0;
    if (($210 | 0) > ($d_0 | 0)) {
      var $classLastChar_0_be = $c_959;
      var $classCharCount_0_be = $209;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = $class_utf8_0;
      var $class_utf8data_0_be = $class_utf8data_0;
      __label__ = 45;
      break;
    } else {
      var $c_959 = $210;
      var $classCharCount_260 = $209;
      __label__ = 62;
      break;
    }
   case 65:
    if (($c_6 | 0) > 255 | $4 & ($c_6 | 0) > 127) {
      __label__ = 66;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 66:
    HEAP8[$class_utf8data_0] = 1;
    var $217 = __ZL10encodeUTF8iPh($c_6, $class_utf8data_0 + 1 | 0);
    var $218 = $217 + ($class_utf8data_0 + 1) | 0;
    if ($4) {
      __label__ = 67;
      break;
    } else {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = 1;
      var $class_utf8data_0_be = $218;
      __label__ = 45;
      break;
    }
   case 67:
    var $220 = __Z22jsc_pcre_ucp_othercasej($c_6);
    if (($220 | 0) > -1) {
      __label__ = 68;
      break;
    } else {
      var $classLastChar_0_be = $classLastChar_0;
      var $classCharCount_0_be = $classCharCount_0;
      var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
      var $class_utf8_0_be = 1;
      var $class_utf8data_0_be = $218;
      __label__ = 45;
      break;
    }
   case 68:
    var $_sum5 = $217 + 2 | 0;
    var $223 = $class_utf8data_0 + $_sum5 | 0;
    HEAP8[$218] = 1;
    var $224 = __ZL10encodeUTF8iPh($220, $223);
    var $classLastChar_0_be = $classLastChar_0;
    var $classCharCount_0_be = $classCharCount_0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = 1;
    var $class_utf8data_0_be = $class_utf8data_0 + ($224 + $_sum5) | 0;
    __label__ = 45;
    break;
   case 69:
    var $230 = $classbits + (($c_6 | 0) / 8 & -1) | 0;
    HEAP8[$230] = (HEAPU8[$230] & 255 | 1 << ($c_6 & 7)) & 255;
    if ($4) {
      __label__ = 70;
      break;
    } else {
      var $c_10 = $c_6;
      __label__ = 71;
      break;
    }
   case 70:
    var $237 = __ZL8flipCaseh($c_6 & 255);
    var $238 = $237 & 255;
    var $242 = $classbits + ($238 >>> 3) | 0;
    HEAP8[$242] = (1 << ($238 & 7) | HEAPU8[$242] & 255) & 255;
    var $c_10 = $238;
    __label__ = 71;
    break;
   case 71:
    var $c_10;
    var $classLastChar_0_be = $c_10;
    var $classCharCount_0_be = $classCharCount_0 + 1 | 0;
    var $shouldFlipNegation_0_be = $shouldFlipNegation_0;
    var $class_utf8_0_be = $class_utf8_0;
    var $class_utf8data_0_be = $class_utf8data_0;
    __label__ = 45;
    break;
   case 72:
    if (($classCharCount_0 | 0) == 1 & $class_utf8_0 << 24 >> 24 == 0) {
      __label__ = 73;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 73:
    if (($classLastChar_0 | 0) < 128 | $negateClass_0 ^ 1) {
      __label__ = 74;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 74:
    if ($negateClass_0) {
      __label__ = 75;
      break;
    } else {
      var $c_13 = $classLastChar_0;
      __label__ = 214;
      break;
    }
   case 75:
    var $firstByte_4 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    var $256 = HEAP32[$code >> 2];
    var $257 = $256 + 1 | 0;
    HEAP32[$code >> 2] = $257;
    HEAP8[$256] = 18;
    var $259 = HEAP32[$code >> 2];
    var $260 = $259 + 1 | 0;
    HEAP32[$code >> 2] = $260;
    HEAP8[$259] = $classLastChar_0 & 255;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_4;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_4;
    __label__ = 228;
    break;
   case 76:
    var $firstByte_5 = ($firstByte_0 | 0) == -2 ? -1 : $firstByte_0;
    if ($class_utf8_0 << 24 >> 24 != 0 & $shouldFlipNegation_0 << 24 >> 24 == 0) {
      __label__ = 77;
      break;
    } else {
      __label__ = 81;
      break;
    }
   case 77:
    var $266 = $class_utf8data_0 + 1 | 0;
    HEAP8[$class_utf8data_0] = 0;
    var $267 = HEAP32[$code >> 2];
    var $268 = $267 + 1 | 0;
    HEAP32[$code >> 2] = $268;
    HEAP8[$267] = 56;
    var $270 = HEAP32[$code >> 2] + 3 | 0;
    HEAP32[$code >> 2] = $270;
    HEAP8[$270] = $negateClass_0 & 1;
    var $273 = HEAPU32[$code >> 2];
    if (($classCharCount_0 | 0) > 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 78:
    HEAP32[$code >> 2] = $273 + 1 | 0;
    var $277 = HEAP8[$273] | 2;
    HEAP8[$273] = $277;
    var $278 = HEAP32[$code >> 2];
    _memcpy($278, $11, 32, 1);
    var $storemerge = $266;
    __label__ = 80;
    break;
   case 79:
    var $280 = $273 + 33 | 0;
    var $283 = $266 - $280 | 0;
    var $284 = $273 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($284, $280, $283, 1, 0);
    var $storemerge = HEAP32[$code >> 2] + ($283 + 1) | 0;
    __label__ = 80;
    break;
   case 80:
    var $storemerge;
    HEAP32[$code >> 2] = $storemerge;
    var $289 = HEAP32[$previous >> 2];
    var $290 = $289 + 1 | 0;
    var $293 = $storemerge - $289 | 0;
    __ZL12putLinkValuePhi($290, $293);
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_5;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_5;
    __label__ = 228;
    break;
   case 81:
    var $298 = ($negateClass_0 & 1 | 0) == ($shouldFlipNegation_0 & 255 | 0) ? 54 : 55;
    var $299 = HEAPU32[$code >> 2];
    HEAP32[$code >> 2] = $299 + 1 | 0;
    HEAP8[$299] = $298;
    if ($negateClass_0) {
      var $c_1137 = 0;
      __label__ = 82;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 82:
    var $c_1137;
    var $303 = HEAP8[$classbits + $c_1137 | 0] ^ -1;
    HEAP8[HEAP32[$code >> 2] + $c_1137 | 0] = $303;
    var $306 = $c_1137 + 1 | 0;
    if (($306 | 0) == 32) {
      __label__ = 84;
      break;
    } else {
      var $c_1137 = $306;
      __label__ = 82;
      break;
    }
   case 83:
    var $308 = HEAP32[$code >> 2];
    _memcpy($308, $11, 32, 1);
    var $309 = $308;
    __label__ = 85;
    break;
   case 84:
    var $309 = HEAP32[$code >> 2];
    __label__ = 85;
    break;
   case 85:
    var $309;
    HEAP32[$code >> 2] = $309 + 32 | 0;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_5;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_5;
    __label__ = 228;
    break;
   case 86:
    if ($31) {
      __label__ = 87;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 87:
    var $_pre_phi = $17 + 2 | 0;
    __label__ = 88;
    break;
   case 88:
    var $_pre_phi;
    var $313 = __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($_pre_phi, $repeatMin, $repeat_max, $errorCodePtr);
    HEAP32[$ptr >> 2] = $313;
    if ((HEAP32[$errorCodePtr >> 2] | 0) == 0) {
      var $319 = $313;
      __label__ = 92;
      break;
    } else {
      var $762 = $313;
      __label__ = 229;
      break;
    }
   case 89:
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = -1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 90:
    HEAP32[$repeatMin >> 2] = 1;
    HEAP32[$repeat_max >> 2] = -1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 91:
    HEAP32[$repeatMin >> 2] = 0;
    HEAP32[$repeat_max >> 2] = 1;
    var $319 = $17;
    __label__ = 92;
    break;
   case 92:
    var $319;
    var $320 = HEAPU32[$previous >> 2];
    if (($320 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 93:
    HEAP32[$errorCodePtr >> 2] = 9;
    var $762 = $319;
    __label__ = 229;
    break;
   case 94:
    var $324 = HEAPU32[$repeatMin >> 2];
    var $325 = ($324 | 0) == 0;
    var $reqByte_1 = $325 ? $zeroReqByte_0 : $reqByte_0;
    var $firstByte_6 = $325 ? $zeroFirstByte_0 : $firstByte_0;
    var $326 = HEAPU32[$repeat_max >> 2];
    var $328 = ($324 | 0) == ($326 | 0) ? 0 : 512;
    HEAP32[$tempcode >> 2] = $320;
    var $329 = __ZL19safelyCheckNextCharPKtS0_t($319, $patternEnd, 63);
    if ($329) {
      __label__ = 95;
      break;
    } else {
      var $repeatType_0 = 0;
      var $333 = $319;
      __label__ = 96;
      break;
    }
   case 95:
    var $331 = $319 + 2 | 0;
    HEAP32[$ptr >> 2] = $331;
    var $repeatType_0 = 1;
    var $333 = $331;
    __label__ = 96;
    break;
   case 96:
    var $333;
    var $repeatType_0;
    var $334 = HEAPU8[$320];
    if ($334 << 24 >> 24 == 14 || $334 << 24 >> 24 == 15) {
      __label__ = 97;
      break;
    } else if ($334 << 24 >> 24 == 16 || $334 << 24 >> 24 == 17) {
      __label__ = 103;
      break;
    } else if ($334 << 24 >> 24 == 18) {
      __label__ = 105;
      break;
    } else {
      __label__ = 106;
      break;
    }
   case 97:
    var $335 = HEAPU32[$code >> 2];
    var $336 = $335 - 1 | 0;
    var $337 = HEAPU8[$336];
    var $338 = $337 & 255;
    if (($338 & 128 | 0) == 0) {
      __label__ = 101;
      break;
    } else {
      __label__ = 98;
      break;
    }
   case 98:
    if (($337 & -64) << 24 >> 24 == -128) {
      var $lastchar_050 = $336;
      __label__ = 99;
      break;
    } else {
      var $lastchar_0_lcssa = $336;
      __label__ = 100;
      break;
    }
   case 99:
    var $lastchar_050;
    var $343 = $lastchar_050 - 1 | 0;
    if ((HEAP8[$343] & -64) << 24 >> 24 == -128) {
      var $lastchar_050 = $343;
      __label__ = 99;
      break;
    } else {
      var $lastchar_0_lcssa = $343;
      __label__ = 100;
      break;
    }
   case 100:
    var $lastchar_0_lcssa;
    var $349 = $335 - $lastchar_0_lcssa | 0;
    _memcpy($15, $lastchar_0_lcssa, $349, 1);
    var $opType_0 = 0;
    var $c_12 = $349 | 128;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 101:
    if (($324 | 0) > 1) {
      __label__ = 102;
      break;
    } else {
      var $opType_0 = 0;
      var $c_12 = $338;
      var $reqByte_2 = $reqByte_1;
      __label__ = 108;
      break;
    }
   case 102:
    var $opType_0 = 0;
    var $c_12 = $338;
    var $reqByte_2 = $338 | $5 | HEAP32[$13 >> 2];
    __label__ = 108;
    break;
   case 103:
    var $360 = HEAPU8[$320 + 1 | 0] & 255;
    if (($324 | 0) > 1) {
      __label__ = 104;
      break;
    } else {
      var $opType_0 = 0;
      var $c_12 = $360;
      var $reqByte_2 = $reqByte_1;
      __label__ = 108;
      break;
    }
   case 104:
    var $opType_0 = 0;
    var $c_12 = $360;
    var $reqByte_2 = $360 | $5 | HEAP32[$13 >> 2];
    __label__ = 108;
    break;
   case 105:
    var $opType_0 = 9;
    var $c_12 = HEAPU8[$320 + 1 | 0] & 255;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 106:
    if (($334 & 255) < 10) {
      __label__ = 107;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 107:
    var $opType_0 = 18;
    var $c_12 = $334 & 255;
    var $reqByte_2 = $reqByte_1;
    __label__ = 108;
    break;
   case 108:
    var $reqByte_2;
    var $c_12;
    var $opType_0;
    var $373 = HEAP32[$code >> 2];
    HEAP32[$code >> 2] = $320;
    if (($326 | 0) == 0) {
      var $reqByte_6 = $reqByte_2;
      __label__ = 176;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $376 = $opType_0 + $repeatType_0 | 0;
    if (($324 | 0) == 0) {
      __label__ = 110;
      break;
    } else if (($324 | 0) == 1) {
      __label__ = 114;
      break;
    } else {
      __label__ = 118;
      break;
    }
   case 110:
    if (($326 | 0) == -1) {
      __label__ = 111;
      break;
    } else if (($326 | 0) == 1) {
      __label__ = 112;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 111:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 19 & 255;
    __label__ = 128;
    break;
   case 112:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 23 & 255;
    __label__ = 128;
    break;
   case 113:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 25 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $326);
    __label__ = 128;
    break;
   case 114:
    if (($326 | 0) == -1) {
      __label__ = 115;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 115:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $376 + 21 & 255;
    __label__ = 128;
    break;
   case 116:
    HEAP32[$code >> 2] = $373;
    if (($326 | 0) == 1) {
      var $reqByte_6 = $reqByte_2;
      __label__ = 176;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $401 = $373 + 1 | 0;
    HEAP32[$code >> 2] = $401;
    HEAP8[$373] = $376 + 25 & 255;
    var $402 = $326 - 1 | 0;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $402);
    __label__ = 128;
    break;
   case 118:
    HEAP32[$code >> 2] = $320 + 1 | 0;
    HEAP8[$320] = $opType_0 + 27 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $324);
    if (($326 | 0) < 0) {
      __label__ = 119;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 119:
    if (($c_12 | 0) > 127) {
      __label__ = 120;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 120:
    var $411 = HEAP32[$code >> 2];
    var $412 = $c_12 & 7;
    _memcpy($411, $15, $412, 1);
    var $414 = HEAP32[$code >> 2] + $412 | 0;
    HEAP32[$code >> 2] = $414;
    var $420 = $414;
    __label__ = 122;
    break;
   case 121:
    var $417 = HEAP32[$code >> 2];
    var $418 = $417 + 1 | 0;
    HEAP32[$code >> 2] = $418;
    HEAP8[$417] = $c_12 & 255;
    var $420 = HEAP32[$code >> 2];
    __label__ = 122;
    break;
   case 122:
    var $420;
    HEAP32[$code >> 2] = $420 + 1 | 0;
    HEAP8[$420] = $376 + 19 & 255;
    __label__ = 128;
    break;
   case 123:
    if (($326 | 0) == ($324 | 0)) {
      __label__ = 128;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    if (($c_12 | 0) > 127) {
      __label__ = 125;
      break;
    } else {
      __label__ = 126;
      break;
    }
   case 125:
    var $429 = HEAP32[$code >> 2];
    var $430 = $c_12 & 7;
    _memcpy($429, $15, $430, 1);
    var $432 = HEAP32[$code >> 2] + $430 | 0;
    HEAP32[$code >> 2] = $432;
    var $438 = $432;
    __label__ = 127;
    break;
   case 126:
    var $435 = HEAP32[$code >> 2];
    var $436 = $435 + 1 | 0;
    HEAP32[$code >> 2] = $436;
    HEAP8[$435] = $c_12 & 255;
    var $438 = HEAP32[$code >> 2];
    __label__ = 127;
    break;
   case 127:
    var $438;
    var $439 = $326 - $324 | 0;
    HEAP32[$repeat_max >> 2] = $439;
    HEAP32[$code >> 2] = $438 + 1 | 0;
    HEAP8[$438] = $376 + 25 & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $439);
    __label__ = 128;
    break;
   case 128:
    if (($c_12 | 0) > 127) {
      __label__ = 129;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 129:
    var $446 = HEAP32[$code >> 2];
    var $447 = $c_12 & 7;
    _memcpy($446, $15, $447, 1);
    var $449 = HEAP32[$code >> 2] + $447 | 0;
    HEAP32[$code >> 2] = $449;
    var $reqByte_6 = $reqByte_2;
    __label__ = 176;
    break;
   case 130:
    var $452 = HEAP32[$code >> 2];
    var $453 = $452 + 1 | 0;
    HEAP32[$code >> 2] = $453;
    HEAP8[$452] = $c_12 & 255;
    var $reqByte_6 = $reqByte_2;
    __label__ = 176;
    break;
   case 131:
    if (($334 - 54 & 255 & 255) < 4) {
      __label__ = 132;
      break;
    } else {
      __label__ = 143;
      break;
    }
   case 132:
    if (($326 | 0) == 0) {
      __label__ = 133;
      break;
    } else {
      __label__ = 134;
      break;
    }
   case 133:
    HEAP32[$code >> 2] = $320;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 134:
    var $459 = ($326 | 0) == -1;
    if ($325 & $459) {
      __label__ = 135;
      break;
    } else {
      __label__ = 136;
      break;
    }
   case 135:
    var $463 = HEAP32[$code >> 2];
    var $464 = $463 + 1 | 0;
    HEAP32[$code >> 2] = $464;
    HEAP8[$463] = ($repeatType_0 | 46) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 136:
    if (($324 | 0) != 1 | $459 ^ 1) {
      __label__ = 138;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 137:
    var $469 = HEAP32[$code >> 2];
    var $470 = $469 + 1 | 0;
    HEAP32[$code >> 2] = $470;
    HEAP8[$469] = ($repeatType_0 | 48) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 138:
    if ($325 & ($326 | 0) == 1) {
      __label__ = 139;
      break;
    } else {
      __label__ = 140;
      break;
    }
   case 139:
    var $476 = HEAP32[$code >> 2];
    var $477 = $476 + 1 | 0;
    HEAP32[$code >> 2] = $477;
    HEAP8[$476] = ($repeatType_0 | 50) & 255;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 140:
    var $480 = HEAP32[$code >> 2];
    var $481 = $480 + 1 | 0;
    HEAP32[$code >> 2] = $481;
    HEAP8[$480] = ($repeatType_0 | 52) & 255;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $324);
    var $482 = HEAP32[$repeat_max >> 2];
    if (($482 | 0) == -1) {
      __label__ = 141;
      break;
    } else {
      var $486 = $482;
      __label__ = 142;
      break;
    }
   case 141:
    HEAP32[$repeat_max >> 2] = 0;
    var $486 = 0;
    __label__ = 142;
    break;
   case 142:
    var $486;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $486);
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 143:
    if (($334 & 255) > 66) {
      __label__ = 144;
      break;
    } else {
      __label__ = 172;
      break;
    }
   case 144:
    var $490 = HEAPU32[$code >> 2];
    var $493 = $490 - $320 | 0;
    var $_val = HEAP8[$320 + 4 | 0];
    var $_idx_val = HEAP8[$320 + 5 | 0];
    var $495 = __ZL13get2ByteValuePKh($_val, $_idx_val);
    if (($326 | 0) == -1) {
      __label__ = 145;
      break;
    } else {
      var $ketoffset_0 = 0;
      var $504 = $490;
      __label__ = 146;
      break;
    }
   case 145:
    HEAP32[$ket >> 2] = $320;
    __ZL21advanceToEndOfBracketRPKh($ket);
    var $498 = HEAP32[$code >> 2];
    var $ketoffset_0 = $498 - HEAP32[$ket >> 2] | 0;
    var $504 = $498;
    __label__ = 146;
    break;
   case 146:
    var $504;
    var $ketoffset_0;
    if ($325) {
      __label__ = 147;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 147:
    var $506 = HEAP32[$repeat_max >> 2];
    if (($506 | 0) == 0) {
      __label__ = 148;
      break;
    } else {
      __label__ = 149;
      break;
    }
   case 148:
    var $509 = HEAP32[$previous >> 2];
    HEAP32[$code >> 2] = $509;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 149:
    var $511 = ($506 | 0) < 2;
    HEAP8[$504] = 0;
    var $512 = HEAP32[$previous >> 2];
    if ($511) {
      __label__ = 150;
      break;
    } else {
      __label__ = 151;
      break;
    }
   case 150:
    var $514 = $512 + 1 | 0;
    _llvm_memmove_p0i8_p0i8_i32($514, $512, $493, 1, 0);
    var $516 = HEAP32[$code >> 2] + 1 | 0;
    HEAP32[$code >> 2] = $516;
    var $519 = HEAP32[$previous >> 2];
    var $520 = $519 + 1 | 0;
    HEAP32[$previous >> 2] = $520;
    HEAP8[$519] = ($repeatType_0 | 64) & 255;
    var $bralink_0 = 0;
    __label__ = 152;
    break;
   case 151:
    var $522 = $512 + 7 | 0;
    _llvm_memmove_p0i8_p0i8_i32($522, $512, $493, 1, 0);
    var $524 = HEAP32[$code >> 2] + 7 | 0;
    HEAP32[$code >> 2] = $524;
    var $527 = HEAP32[$previous >> 2];
    var $528 = $527 + 1 | 0;
    HEAP32[$previous >> 2] = $528;
    HEAP8[$527] = ($repeatType_0 | 64) & 255;
    var $529 = HEAP32[$previous >> 2];
    var $530 = $529 + 1 | 0;
    HEAP32[$previous >> 2] = $530;
    HEAP8[$529] = 67;
    var $531 = HEAP32[$previous >> 2];
    __ZL31putLinkValueAllowZeroAndAdvanceRPhi($previous, 0);
    __ZL23put2ByteValueAndAdvanceRPhi($previous, $495);
    var $bralink_0 = $531;
    __label__ = 152;
    break;
   case 152:
    var $bralink_0;
    var $534 = HEAP32[$repeat_max >> 2] - 1 | 0;
    HEAP32[$repeat_max >> 2] = $534;
    var $bralink_1 = $bralink_0;
    var $reqByte_5 = $reqByte_1;
    var $552 = $534;
    __label__ = 159;
    break;
   case 153:
    if (($324 | 0) > 1) {
      __label__ = 154;
      break;
    } else {
      var $reqByte_4 = $reqByte_1;
      __label__ = 157;
      break;
    }
   case 154:
    var $reqByte_3 = ($didGroupSetFirstByte_0 & 1) << 24 >> 24 != 0 & ($reqByte_1 | 0) < 0 ? $firstByte_6 : $reqByte_1;
    var $i_047 = 2;
    var $541 = $504;
    __label__ = 155;
    break;
   case 155:
    var $541;
    var $i_047;
    var $542 = HEAP32[$previous >> 2];
    _memcpy($541, $542, $493, 1);
    var $544 = HEAP32[$code >> 2] + $493 | 0;
    HEAP32[$code >> 2] = $544;
    if (($i_047 | 0) < ($324 | 0)) {
      __label__ = 156;
      break;
    } else {
      var $reqByte_4 = $reqByte_3;
      __label__ = 157;
      break;
    }
   case 156:
    var $i_047 = $i_047 + 1 | 0;
    var $541 = $544;
    __label__ = 155;
    break;
   case 157:
    var $reqByte_4;
    var $546 = HEAP32[$repeat_max >> 2];
    if (($546 | 0) > 0) {
      __label__ = 158;
      break;
    } else {
      var $bralink_1 = 0;
      var $reqByte_5 = $reqByte_4;
      var $552 = $546;
      __label__ = 159;
      break;
    }
   case 158:
    var $550 = $546 - HEAP32[$repeatMin >> 2] | 0;
    HEAP32[$repeat_max >> 2] = $550;
    var $bralink_1 = 0;
    var $reqByte_5 = $reqByte_4;
    var $552 = $550;
    __label__ = 159;
    break;
   case 159:
    var $552;
    var $reqByte_5;
    var $bralink_1;
    if (($552 | 0) > -1) {
      __label__ = 160;
      break;
    } else {
      __label__ = 171;
      break;
    }
   case 160:
    if (($552 | 0) > 0) {
      __label__ = 161;
      break;
    } else {
      var $bralink_2_lcssa = $bralink_1;
      __label__ = 167;
      break;
    }
   case 161:
    var $556 = ($repeatType_0 | 64) & 255;
    var $bralink_241 = $bralink_1;
    var $i2_042_in = $552;
    var $558 = HEAP32[$code >> 2];
    __label__ = 162;
    break;
   case 162:
    var $558;
    var $i2_042_in;
    var $bralink_241;
    var $i2_042 = $i2_042_in - 1 | 0;
    HEAP32[$code >> 2] = $558 + 1 | 0;
    HEAP8[$558] = $556;
    if (($i2_042 | 0) == 0) {
      var $bralink_3 = $bralink_241;
      __label__ = 166;
      break;
    } else {
      __label__ = 163;
      break;
    }
   case 163:
    var $562 = HEAP32[$code >> 2];
    var $563 = $562 + 1 | 0;
    HEAP32[$code >> 2] = $563;
    HEAP8[$562] = 67;
    var $_pre48 = HEAP32[$code >> 2];
    if (($bralink_241 | 0) == 0) {
      var $569 = 0;
      __label__ = 165;
      break;
    } else {
      __label__ = 164;
      break;
    }
   case 164:
    var $569 = $_pre48 - $bralink_241 | 0;
    __label__ = 165;
    break;
   case 165:
    var $569;
    __ZL31putLinkValueAllowZeroAndAdvanceRPhi($code, $569);
    __ZL23put2ByteValueAndAdvanceRPhi($code, $495);
    var $bralink_3 = $_pre48;
    __label__ = 166;
    break;
   case 166:
    var $bralink_3;
    var $571 = HEAP32[$code >> 2];
    var $572 = HEAP32[$previous >> 2];
    _memcpy($571, $572, $493, 1);
    var $574 = HEAP32[$code >> 2] + $493 | 0;
    HEAP32[$code >> 2] = $574;
    if (($i2_042 | 0) > 0) {
      var $bralink_241 = $bralink_3;
      var $i2_042_in = $i2_042;
      var $558 = $574;
      __label__ = 162;
      break;
    } else {
      var $bralink_2_lcssa = $bralink_3;
      __label__ = 167;
      break;
    }
   case 167:
    var $bralink_2_lcssa;
    if (($bralink_2_lcssa | 0) == 0) {
      var $reqByte_6 = $reqByte_5;
      __label__ = 176;
      break;
    } else {
      var $bralink_444 = $bralink_2_lcssa;
      __label__ = 168;
      break;
    }
   case 168:
    var $bralink_444;
    var $577 = HEAP32[$code >> 2];
    var $580 = $577 - $bralink_444 | 0;
    var $581 = $580 + 1 | 0;
    var $582 = $577 + -$580 | 0;
    var $_val1 = HEAP8[$582];
    var $_idx2_val = HEAP8[$577 + (1 - $580) | 0];
    var $_idx3_val = HEAP8[$577 + (2 - $580) | 0];
    var $583 = __ZL21getLinkValueAllowZeroPKh($_val1, $_idx2_val, $_idx3_val);
    if (($583 | 0) == 0) {
      var $589 = 0;
      __label__ = 170;
      break;
    } else {
      __label__ = 169;
      break;
    }
   case 169:
    var $589 = $bralink_444 + -$583 | 0;
    __label__ = 170;
    break;
   case 170:
    var $589;
    var $590 = $577 + 1 | 0;
    HEAP32[$code >> 2] = $590;
    HEAP8[$577] = 59;
    __ZL22putLinkValueAndAdvanceRPhi($code, $581);
    __ZL12putLinkValuePhi($582, $581);
    if (($589 | 0) == 0) {
      var $reqByte_6 = $reqByte_5;
      __label__ = 176;
      break;
    } else {
      var $bralink_444 = $589;
      __label__ = 168;
      break;
    }
   case 171:
    HEAP8[HEAP32[$code >> 2] + -$ketoffset_0 | 0] = ($repeatType_0 | 60) & 255;
    var $reqByte_6 = $reqByte_5;
    __label__ = 176;
    break;
   case 172:
    if (($334 - 62 & 255 & 255) < 2) {
      __label__ = 173;
      break;
    } else {
      __label__ = 175;
      break;
    }
   case 173:
    if ($325) {
      __label__ = 174;
      break;
    } else {
      var $reqByte_6 = $reqByte_1;
      __label__ = 176;
      break;
    }
   case 174:
    HEAP32[$code >> 2] = $320;
    var $reqByte_6 = $reqByte_1;
    __label__ = 176;
    break;
   case 175:
    HEAP32[$errorCodePtr >> 2] = 11;
    var $762 = $333;
    __label__ = 229;
    break;
   case 176:
    var $reqByte_6;
    HEAP32[$previous >> 2] = 0;
    var $603 = HEAP32[$13 >> 2] | $328;
    HEAP32[$13 >> 2] = $603;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_6;
    var $reqByte_8 = $reqByte_6;
    var $zeroReqByte_1 = $zeroReqByte_0;
    var $zeroFirstByte_3 = $zeroFirstByte_0;
    __label__ = 228;
    break;
   case 177:
    var $605 = HEAPU32[$brackets >> 2];
    var $606 = $605 + 1 | 0;
    var $607 = $17 + 2 | 0;
    HEAP32[$ptr >> 2] = $607;
    if (HEAP16[$607 >> 1] << 16 >> 16 == 63) {
      __label__ = 178;
      break;
    } else {
      __label__ = 183;
      break;
    }
   case 178:
    var $611 = $17 + 4 | 0;
    HEAP32[$ptr >> 2] = $611;
    var $613 = HEAPU16[$611 >> 1] & 65535;
    if (($613 | 0) == 58) {
      __label__ = 179;
      break;
    } else if (($613 | 0) == 61) {
      __label__ = 180;
      break;
    } else if (($613 | 0) == 33) {
      __label__ = 181;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 179:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 67;
    __label__ = 186;
    break;
   case 180:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 62;
    __label__ = 186;
    break;
   case 181:
    HEAP32[$ptr >> 2] = $17 + 6 | 0;
    var $skipBytes_0 = 2;
    var $bravalue_0 = 63;
    __label__ = 186;
    break;
   case 182:
    HEAP32[$errorCodePtr >> 2] = 12;
    var $762 = $611;
    __label__ = 229;
    break;
   case 183:
    HEAP32[$brackets >> 2] = $606;
    if (($606 | 0) > 100) {
      __label__ = 184;
      break;
    } else {
      __label__ = 185;
      break;
    }
   case 184:
    HEAP8[HEAP32[$code >> 2] + 6 | 0] = 66;
    var $627 = HEAP32[$code >> 2] + 7 | 0;
    var $628 = HEAP32[$brackets >> 2];
    __ZL13put2ByteValuePhi($627, $628);
    var $skipBytes_0 = 5;
    var $bravalue_0 = 168;
    __label__ = 186;
    break;
   case 185:
    var $skipBytes_0 = 2;
    var $bravalue_0 = $605 + 68 | 0;
    __label__ = 186;
    break;
   case 186:
    var $bravalue_0;
    var $skipBytes_0;
    var $632 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $632;
    HEAP8[$632] = $bravalue_0 & 255;
    var $634 = HEAP32[$code >> 2];
    HEAP32[$tempcode >> 2] = $634;
    var $635 = HEAP32[$13 >> 2];
    var $636 = HEAP32[$brackets >> 2];
    var $637 = __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($options, $brackets, $tempcode, $ptr, $patternEnd, $errorCodePtr, $skipBytes_0, $subFirstByte, $subReqByte, $cd);
    if ($637) {
      __label__ = 188;
      break;
    } else {
      __label__ = 187;
      break;
    }
   case 187:
    var $762 = HEAP32[$ptr >> 2];
    __label__ = 229;
    break;
   case 188:
    var $644 = (($bravalue_0 | 0) > 67 & 1) + $606 - $636 + HEAP32[$brackets >> 2] | 0;
    if (($606 & 511 | 0) == ($606 | 0)) {
      __label__ = 189;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 189:
    if (($644 & 511 | 0) == ($644 | 0)) {
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    HEAP32[$errorCodePtr >> 2] = 17;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 191:
    var $653 = HEAP32[$code >> 2] + 4 | 0;
    var $655 = $644 | $606 << 8;
    __ZL13put2ByteValuePhi($653, $655);
    if (($bravalue_0 | 0) > 66) {
      __label__ = 192;
      break;
    } else {
      __label__ = 200;
      break;
    }
   case 192:
    var $659 = HEAPU32[$subFirstByte >> 2];
    var $660 = ($659 | 0) > -1;
    if (($firstByte_0 | 0) == -2) {
      __label__ = 193;
      break;
    } else {
      __label__ = 194;
      break;
    }
   case 193:
    var $_ = $660 ? $659 : -1;
    var $didGroupSetFirstByte_2_ph = $659 >>> 31 & 255 ^ 1;
    var $firstByte_8_ph = $_;
    var $zeroFirstByte_1_ph = -1;
    __label__ = 197;
    break;
   case 194:
    if ($660) {
      __label__ = 195;
      break;
    } else {
      var $didGroupSetFirstByte_2_ph = 0;
      var $firstByte_8_ph = $firstByte_0;
      var $zeroFirstByte_1_ph = $firstByte_0;
      __label__ = 197;
      break;
    }
   case 195:
    var $665 = HEAPU32[$subReqByte >> 2];
    if (($665 | 0) < 0) {
      __label__ = 196;
      break;
    } else {
      var $672 = $665;
      var $zeroFirstByte_128 = $firstByte_0;
      var $firstByte_829 = $firstByte_0;
      var $didGroupSetFirstByte_230 = 0;
      __label__ = 199;
      break;
    }
   case 196:
    var $668 = $659 | $635;
    HEAP32[$subReqByte >> 2] = $668;
    var $didGroupSetFirstByte_2 = 0;
    var $firstByte_8 = $firstByte_0;
    var $zeroFirstByte_1 = $firstByte_0;
    var $670 = $668;
    __label__ = 198;
    break;
   case 197:
    var $zeroFirstByte_1_ph;
    var $firstByte_8_ph;
    var $didGroupSetFirstByte_2_ph;
    var $didGroupSetFirstByte_2 = $didGroupSetFirstByte_2_ph;
    var $firstByte_8 = $firstByte_8_ph;
    var $zeroFirstByte_1 = $zeroFirstByte_1_ph;
    var $670 = HEAP32[$subReqByte >> 2];
    __label__ = 198;
    break;
   case 198:
    var $670;
    var $zeroFirstByte_1;
    var $firstByte_8;
    var $didGroupSetFirstByte_2;
    if (($670 | 0) > -1) {
      var $672 = $670;
      var $zeroFirstByte_128 = $zeroFirstByte_1;
      var $firstByte_829 = $firstByte_8;
      var $didGroupSetFirstByte_230 = $didGroupSetFirstByte_2;
      __label__ = 199;
      break;
    } else {
      var $didGroupSetFirstByte_3 = $didGroupSetFirstByte_2;
      var $firstByte_9 = $firstByte_8;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $zeroFirstByte_1;
      __label__ = 203;
      break;
    }
   case 199:
    var $didGroupSetFirstByte_230;
    var $firstByte_829;
    var $zeroFirstByte_128;
    var $672;
    var $didGroupSetFirstByte_3 = $didGroupSetFirstByte_230;
    var $firstByte_9 = $firstByte_829;
    var $reqByte_7 = $672;
    var $zeroFirstByte_2 = $zeroFirstByte_128;
    __label__ = 203;
    break;
   case 200:
    if (($bravalue_0 | 0) == 62) {
      __label__ = 201;
      break;
    } else {
      var $didGroupSetFirstByte_3 = 0;
      var $firstByte_9 = $firstByte_0;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $firstByte_0;
      __label__ = 203;
      break;
    }
   case 201:
    var $676 = HEAP32[$subReqByte >> 2];
    if (($676 | 0) > -1) {
      __label__ = 202;
      break;
    } else {
      var $didGroupSetFirstByte_3 = 0;
      var $firstByte_9 = $firstByte_0;
      var $reqByte_7 = $reqByte_0;
      var $zeroFirstByte_2 = $firstByte_0;
      __label__ = 203;
      break;
    }
   case 202:
    var $didGroupSetFirstByte_3 = 0;
    var $firstByte_9 = $firstByte_0;
    var $reqByte_7 = $676;
    var $zeroFirstByte_2 = $firstByte_0;
    __label__ = 203;
    break;
   case 203:
    var $zeroFirstByte_2;
    var $reqByte_7;
    var $firstByte_9;
    var $didGroupSetFirstByte_3;
    var $680 = HEAP32[$tempcode >> 2];
    HEAP32[$code >> 2] = $680;
    var $681 = HEAPU32[$ptr >> 2];
    if ($681 >>> 0 < $patternEnd >>> 0) {
      __label__ = 204;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 204:
    if (HEAP16[$681 >> 1] << 16 >> 16 == 41) {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_3;
      var $firstByte_11 = $firstByte_9;
      var $reqByte_8 = $reqByte_7;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = $zeroFirstByte_2;
      __label__ = 228;
      break;
    } else {
      __label__ = 205;
      break;
    }
   case 205:
    HEAP32[$errorCodePtr >> 2] = 14;
    var $762 = $681;
    __label__ = 229;
    break;
   case 206:
    var $688 = HEAP32[$12 >> 2];
    var $689 = __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptr, $patternEnd, $errorCodePtr, $688, 0);
    if (($689 | 0) < 0) {
      __label__ = 207;
      break;
    } else {
      var $c_13 = $689;
      __label__ = 214;
      break;
    }
   case 207:
    if (($firstByte_0 | 0) == -2) {
      __label__ = 208;
      break;
    } else {
      var $firstByte_10 = $firstByte_0;
      __label__ = 210;
      break;
    }
   case 208:
    if ((-3 - $689 | 0) >>> 0 < 6) {
      __label__ = 209;
      break;
    } else {
      var $firstByte_10 = -2;
      __label__ = 210;
      break;
    }
   case 209:
    var $firstByte_10 = -1;
    __label__ = 210;
    break;
   case 210:
    var $firstByte_10;
    var $697 = -$689 | 0;
    if (($697 | 0) > 8) {
      __label__ = 211;
      break;
    } else {
      __label__ = 212;
      break;
    }
   case 211:
    var $700 = -9 - $689 | 0;
    var $701 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $701;
    var $702 = $701 + 1 | 0;
    HEAP32[$code >> 2] = $702;
    HEAP8[$701] = 57;
    __ZL23put2ByteValueAndAdvanceRPhi($code, $700);
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_10;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_10;
    __label__ = 228;
    break;
   case 212:
    var $705 = HEAP32[$code >> 2];
    var $706 = ($697 | 0) > 2 ? $705 : 0;
    HEAP32[$previous >> 2] = $706;
    var $707 = $697 & 255;
    var $708 = $705 + 1 | 0;
    HEAP32[$code >> 2] = $708;
    HEAP8[$705] = $707;
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_10;
    var $reqByte_8 = $reqByte_0;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_10;
    __label__ = 228;
    break;
   case 213:
    var $709 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $709;
    var $c_1332 = $23;
    var $713 = $709;
    __label__ = 215;
    break;
   case 214:
    var $c_13;
    var $710 = HEAP32[$code >> 2];
    HEAP32[$previous >> 2] = $710;
    if (($c_13 | 0) < 128) {
      var $c_1332 = $c_13;
      var $713 = $710;
      __label__ = 215;
      break;
    } else {
      __label__ = 219;
      break;
    }
   case 215:
    var $713;
    var $c_1332;
    var $714 = $c_1332 & 255;
    HEAP8[$6] = $714;
    if ($4) {
      __label__ = 216;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 216:
    var $716 = $c_1332 | 32;
    if (($716 - 97 | 0) >>> 0 < 26) {
      __label__ = 217;
      break;
    } else {
      __label__ = 218;
      break;
    }
   case 217:
    HEAP32[$code >> 2] = $713 + 1 | 0;
    HEAP8[$713] = 17;
    var $721 = HEAP32[$code >> 2];
    var $722 = $721 + 1 | 0;
    HEAP32[$code >> 2] = $722;
    HEAP8[$721] = $716 & 255;
    var $mcLength_0 = 1;
    __label__ = 222;
    break;
   case 218:
    HEAP32[$code >> 2] = $713 + 1 | 0;
    HEAP8[$713] = 16;
    var $725 = HEAP32[$code >> 2];
    var $726 = $725 + 1 | 0;
    HEAP32[$code >> 2] = $726;
    HEAP8[$725] = $714;
    var $mcLength_0 = 1;
    __label__ = 222;
    break;
   case 219:
    var $728 = __ZL10encodeUTF8iPh($c_13, $6);
    var $729 = HEAP32[$code >> 2];
    var $730 = $729 + 1 | 0;
    HEAP32[$code >> 2] = $730;
    HEAP8[$729] = $8;
    if (($728 | 0) > 0) {
      var $c_1454 = 0;
      __label__ = 220;
      break;
    } else {
      __label__ = 221;
      break;
    }
   case 220:
    var $c_1454;
    var $733 = HEAP8[$mcbuffer + $c_1454 | 0];
    var $734 = HEAP32[$code >> 2];
    var $735 = $734 + 1 | 0;
    HEAP32[$code >> 2] = $735;
    HEAP8[$734] = $733;
    var $736 = $c_1454 + 1 | 0;
    if (($736 | 0) == ($728 | 0)) {
      __label__ = 221;
      break;
    } else {
      var $c_1454 = $736;
      __label__ = 220;
      break;
    }
   case 221:
    var $mcLength_0 = ($728 | 0) == 1;
    __label__ = 222;
    break;
   case 222:
    var $mcLength_0;
    var $or_cond20 = $mcLength_0 | $14;
    if (($firstByte_0 | 0) == -2) {
      __label__ = 223;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 223:
    if ($or_cond20) {
      __label__ = 224;
      break;
    } else {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = -1;
      var $reqByte_8 = -1;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = -1;
      __label__ = 228;
      break;
    }
   case 224:
    var $743 = HEAPU8[$6] & 255 | $5;
    if ($mcLength_0) {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = $743;
      var $reqByte_8 = $reqByte_0;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = -1;
      __label__ = 228;
      break;
    } else {
      __label__ = 225;
      break;
    }
   case 225:
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $743;
    var $reqByte_8 = HEAPU8[HEAP32[$code >> 2] - 1 | 0] & 255 | HEAP32[$13 >> 2];
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = -1;
    __label__ = 228;
    break;
   case 226:
    if ($or_cond20) {
      __label__ = 227;
      break;
    } else {
      var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
      var $firstByte_11 = $firstByte_0;
      var $reqByte_8 = $reqByte_0;
      var $zeroReqByte_1 = $reqByte_0;
      var $zeroFirstByte_3 = $firstByte_0;
      __label__ = 228;
      break;
    }
   case 227:
    var $didGroupSetFirstByte_4 = $didGroupSetFirstByte_0;
    var $firstByte_11 = $firstByte_0;
    var $reqByte_8 = HEAP32[$13 >> 2] | $5 | HEAPU8[HEAP32[$code >> 2] - 1 | 0] & 255;
    var $zeroReqByte_1 = $reqByte_0;
    var $zeroFirstByte_3 = $firstByte_0;
    __label__ = 228;
    break;
   case 228:
    var $zeroFirstByte_3;
    var $zeroReqByte_1;
    var $reqByte_8;
    var $firstByte_11;
    var $didGroupSetFirstByte_4;
    var $761 = HEAP32[$ptr >> 2] + 2 | 0;
    HEAP32[$ptr >> 2] = $761;
    var $didGroupSetFirstByte_0 = $didGroupSetFirstByte_4;
    var $firstByte_0 = $firstByte_11;
    var $reqByte_0 = $reqByte_8;
    var $zeroReqByte_0 = $zeroReqByte_1;
    var $zeroFirstByte_0 = $zeroFirstByte_3;
    var $17 = $761;
    __label__ = 2;
    break;
   case 229:
    var $762;
    HEAP32[$ptrPtr >> 2] = $762;
    var $_0 = 0;
    __label__ = 230;
    break;
   case 230:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData["X"] = 1;

function __ZL13get2ByteValuePKh($opcodePtr_val, $opcodePtr_1_val) {
  return ($opcodePtr_val & 255) << 8 | $opcodePtr_1_val & 255;
}

function __ZL13get3ByteValuePKh($opcodePtr_val, $opcodePtr_1_val, $opcodePtr_2_val) {
  return $opcodePtr_2_val & 255 | ($opcodePtr_val & 255) << 16 | ($opcodePtr_1_val & 255) << 8;
}

function __ZL13put2ByteValuePhi($opcodePtr, $value) {
  HEAP8[$opcodePtr] = $value >>> 8 & 255;
  HEAP8[$opcodePtr + 1 | 0] = $value & 255;
  return;
}

function __ZL8flipCaseh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 128) | 0;
  return HEAP8[$2];
}

function __ZL22firstSignificantOpcodePKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (HEAP8[$code] << 24 >> 24 == 66) {
      var $_01 = $code;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $code;
      __label__ = 3;
      break;
    }
   case 2:
    var $_01;
    var $3 = $_01 + 3 | 0;
    if (HEAP8[$3] << 24 >> 24 == 66) {
      var $_01 = $3;
      __label__ = 2;
      break;
    } else {
      var $_0_lcssa = $3;
      __label__ = 3;
      break;
    }
   case 3:
    var $_0_lcssa;
    return $_0_lcssa;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL13put3ByteValuePhi($opcodePtr, $value) {
  HEAP8[$opcodePtr] = $value >>> 16 & 255;
  HEAP8[$opcodePtr + 1 | 0] = $value >>> 8 & 255;
  HEAP8[$opcodePtr + 2 | 0] = $value & 255;
  return;
}

function __ZL18classBitmapForCharh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + ($c & 255 | 256) | 0;
  return HEAP8[$2];
}

function __ZL10encodeUTF8iPh($cvalue, $buffer) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_0 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_0;
    if (($i_0 | 0) < 6) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $j_02 = $i_0;
    var $_013 = $buffer + $i_0 | 0;
    var $_04 = $cvalue;
    __label__ = 7;
    break;
   case 4:
    if ((HEAP32[_jsc_pcre_utf8_table1 + ($i_0 << 2) >> 2] | 0) < ($cvalue | 0)) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $i_0 = $i_0 + 1 | 0;
    __label__ = 2;
    break;
   case 6:
    var $11 = $buffer + $i_0 | 0;
    if (($i_0 | 0) > 0) {
      var $j_02 = $i_0;
      var $_013 = $11;
      var $_04 = $cvalue;
      __label__ = 7;
      break;
    } else {
      var $_01_lcssa = $11;
      var $_0_lcssa = $cvalue;
      __label__ = 8;
      break;
    }
   case 7:
    var $_04;
    var $_013;
    var $j_02;
    HEAP8[$_013] = ($_04 & 63 | 128) & 255;
    var $17 = $_04 >> 6;
    var $18 = $j_02 - 1 | 0;
    if (($18 | 0) > 0) {
      var $j_02 = $18;
      var $_013 = $_013 - 1 | 0;
      var $_04 = $17;
      __label__ = 7;
      break;
    } else {
      var $_01_lcssa = $buffer;
      var $_0_lcssa = $17;
      __label__ = 8;
      break;
    }
   case 8:
    var $_0_lcssa;
    var $_01_lcssa;
    HEAP8[$_01_lcssa] = (HEAP32[_jsc_pcre_utf8_table2 + ($i_0 << 2) >> 2] | $_0_lcssa) & 255;
    return $i_0 + 1 | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData($options, $brackets, $codePtr, $ptrPtr, $patternEnd, $errorCodePtr, $skipBytes, $firstbyteptr, $reqbyteptr, $cd) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ptr = __stackBase__;
    var $code = __stackBase__ + 4;
    var $branchFirstByte = __stackBase__ + 8;
    var $branchReqByte = __stackBase__ + 12;
    var $1 = HEAP32[$ptrPtr >> 2];
    HEAP32[$ptr >> 2] = $1;
    var $2 = HEAPU32[$codePtr >> 2];
    var $3 = $2 + 1 | 0;
    __ZL21putLinkValueAllowZeroPhi($3, 0);
    HEAP32[$code >> 2] = $skipBytes + ($2 + 4) | 0;
    var $reqByte_0 = -2;
    var $firstByte_0 = -2;
    var $lastBranch_0 = $2;
    __label__ = 2;
    break;
   case 2:
    var $lastBranch_0;
    var $firstByte_0;
    var $reqByte_0;
    var $7 = __ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData($options, $brackets, $code, $ptr, $patternEnd, $errorCodePtr, $branchFirstByte, $branchReqByte, $cd);
    if ($7) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = HEAP32[$ptr >> 2];
    HEAP32[$ptrPtr >> 2] = $9;
    var $_0 = 0;
    __label__ = 19;
    break;
   case 4:
    if (HEAP8[$lastBranch_0] << 24 >> 24 == 58) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $reqByte_3 = HEAP32[$branchReqByte >> 2];
    var $firstByte_2 = HEAP32[$branchFirstByte >> 2];
    __label__ = 13;
    break;
   case 6:
    var $18 = HEAP32[$branchFirstByte >> 2];
    if (($firstByte_0 | 0) > -1) {
      __label__ = 7;
      break;
    } else {
      var $reqByte_2_ph = $reqByte_0;
      var $firstByte_1_ph = $firstByte_0;
      var $23 = $18;
      __label__ = 9;
      break;
    }
   case 7:
    if (($firstByte_0 | 0) == ($18 | 0)) {
      var $firstByte_11 = $firstByte_0;
      var $reqByte_23 = $reqByte_0;
      __label__ = 12;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $reqByte_1 = ($reqByte_0 | 0) < 0 ? $firstByte_0 : $reqByte_0;
    var $reqByte_2_ph = $reqByte_1;
    var $firstByte_1_ph = -1;
    var $23 = $18;
    __label__ = 9;
    break;
   case 9:
    var $23;
    var $firstByte_1_ph;
    var $reqByte_2_ph;
    if (($23 | 0) > -1) {
      __label__ = 10;
      break;
    } else {
      var $firstByte_11 = $firstByte_1_ph;
      var $reqByte_23 = $reqByte_2_ph;
      __label__ = 12;
      break;
    }
   case 10:
    if ((HEAP32[$branchReqByte >> 2] | 0) < 0) {
      __label__ = 11;
      break;
    } else {
      var $firstByte_11 = $firstByte_1_ph;
      var $reqByte_23 = $reqByte_2_ph;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$branchReqByte >> 2] = $23;
    var $firstByte_11 = $firstByte_1_ph;
    var $reqByte_23 = $reqByte_2_ph;
    __label__ = 12;
    break;
   case 12:
    var $reqByte_23;
    var $firstByte_11;
    var $29 = HEAP32[$branchReqByte >> 2];
    var $_ = (($29 ^ $reqByte_23) & -513 | 0) == 0 ? $29 | $reqByte_23 : -1;
    var $reqByte_3 = $_;
    var $firstByte_2 = $firstByte_11;
    __label__ = 13;
    break;
   case 13:
    var $firstByte_2;
    var $reqByte_3;
    var $35 = HEAPU32[$ptr >> 2];
    if ($35 >>> 0 < $patternEnd >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    if (HEAP16[$35 >> 1] << 16 >> 16 == 124) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $length_0 = HEAP32[$code >> 2] - $lastBranch_0 | 0;
    var $lastBranch_1 = $lastBranch_0;
    __label__ = 16;
    break;
   case 16:
    var $lastBranch_1;
    var $length_0;
    var $46 = $lastBranch_1 + 1 | 0;
    var $_val = HEAP8[$46];
    var $_idx_val = HEAP8[$lastBranch_1 + 2 | 0];
    var $_idx1_val = HEAP8[$lastBranch_1 + 3 | 0];
    var $47 = __ZL21getLinkValueAllowZeroPKh($_val, $_idx_val, $_idx1_val);
    __ZL12putLinkValuePhi($46, $length_0);
    if (($47 | 0) > 0) {
      var $length_0 = $47;
      var $lastBranch_1 = $lastBranch_1 + -$47 | 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    var $52 = HEAP32[$code >> 2];
    HEAP8[$52] = 59;
    var $53 = $52 + 1 | 0;
    var $56 = $52 - $2 | 0;
    __ZL12putLinkValuePhi($53, $56);
    var $57 = $52 + 4 | 0;
    HEAP32[$code >> 2] = $57;
    HEAP32[$codePtr >> 2] = $57;
    var $58 = HEAP32[$ptr >> 2];
    HEAP32[$ptrPtr >> 2] = $58;
    HEAP32[$firstbyteptr >> 2] = $firstByte_2;
    HEAP32[$reqbyteptr >> 2] = $reqByte_3;
    var $_0 = 1;
    __label__ = 19;
    break;
   case 18:
    var $60 = HEAPU32[$code >> 2];
    HEAP8[$60] = 58;
    var $61 = $60 + 1 | 0;
    var $64 = $60 - $lastBranch_0 | 0;
    __ZL12putLinkValuePhi($61, $64);
    HEAP32[$code >> 2] = $60 + 4 | 0;
    HEAP32[$ptr >> 2] = $35 + 2 | 0;
    var $reqByte_0 = $reqByte_3;
    var $firstByte_0 = $firstByte_2;
    var $lastBranch_0 = $60;
    __label__ = 2;
    break;
   case 19:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData["X"] = 1;

function __ZN2js10Foreground12array_deleteIcEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $p - 8 | 0;
    _js_free4455($4);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL17bracketIsAnchoredPKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZL16branchIsAnchoredPKh($_01 + 4 | 0);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$_01 + 1 | 0];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $6 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $7 = $_01 + $6 | 0;
    if (HEAP8[$7] << 24 >> 24 == 58) {
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16branchIsAnchoredPKh($code) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL22firstSignificantOpcodePKh($code);
    var $2 = HEAPU8[$1];
    if (($2 & 255) > 66 | $2 << 24 >> 24 == 62) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $6 = __ZL17bracketIsAnchoredPKh($1);
    var $_0 = $6;
    __label__ = 4;
    break;
   case 3:
    var $_0 = $2 << 24 >> 24 == 10;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL33bracketFindFirstAssertedCharacterPKhb($code, $inassert) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    var $c_0 = -1;
    __label__ = 2;
    break;
   case 2:
    var $c_0;
    var $_01;
    var $2 = $_01 + 1 | 0;
    var $4 = __ZL32branchFindFirstAssertedCharacterPKhb($_01 + 4 | 0, $inassert);
    if (($4 | 0) < 0) {
      var $_0 = -1;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($c_0 | 0) < 0) {
      var $c_1 = $4;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if (($c_0 | 0) == ($4 | 0)) {
      var $c_1 = $c_0;
      __label__ = 5;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 5:
    var $c_1;
    var $_val = HEAP8[$2];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $11 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $12 = $_01 + $11 | 0;
    if (HEAP8[$12] << 24 >> 24 == 58) {
      var $_01 = $12;
      var $c_0 = $c_1;
      __label__ = 2;
      break;
    } else {
      var $_0 = $c_1;
      __label__ = 6;
      break;
    }
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL32branchFindFirstAssertedCharacterPKhb($code, $inassert) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL40firstSignificantOpcodeSkippingAssertionsPKh($code);
    var $3 = HEAPU8[$1] & 255;
    var $op_0 = $3 >>> 0 < 67 ? $3 : 67;
    if (($op_0 | 0) == 67 || ($op_0 | 0) == 62) {
      __label__ = 2;
      break;
    } else if (($op_0 | 0) == 27) {
      __label__ = 3;
      break;
    } else if (($op_0 | 0) == 14 || ($op_0 | 0) == 15 || ($op_0 | 0) == 16 || ($op_0 | 0) == 17 || ($op_0 | 0) == 21 || ($op_0 | 0) == 22) {
      var $scode_0 = $1;
      __label__ = 4;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 2:
    var $6 = ($op_0 | 0) == 62;
    var $7 = __ZL33bracketFindFirstAssertedCharacterPKhb($1, $6);
    var $_0 = $7;
    __label__ = 6;
    break;
   case 3:
    var $scode_0 = $1 + 2 | 0;
    __label__ = 4;
    break;
   case 4:
    var $scode_0;
    if ($inassert) {
      __label__ = 5;
      break;
    } else {
      var $_0 = -1;
      __label__ = 6;
      break;
    }
   case 5:
    var $_0 = HEAPU8[$scode_0 + 1 | 0] & 255;
    __label__ = 6;
    break;
   case 6:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21bracketNeedsLineStartPKhjj($code, $captureMap, $backrefMap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_01 = $code;
    __label__ = 2;
    break;
   case 2:
    var $_01;
    var $3 = __ZL20branchNeedsLineStartPKhjj($_01 + 4 | 0, $captureMap, $backrefMap);
    if ($3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$_01 + 1 | 0];
    var $_idx_val = HEAP8[$_01 + 2 | 0];
    var $_idx1_val = HEAP8[$_01 + 3 | 0];
    var $6 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $7 = $_01 + $6 | 0;
    if (HEAP8[$7] << 24 >> 24 == 58) {
      var $_01 = $7;
      __label__ = 2;
      break;
    } else {
      var $_0 = 1;
      __label__ = 4;
      break;
    }
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL20branchNeedsLineStartPKhjj($code, $captureMap, $backrefMap) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZL22firstSignificantOpcodePKh($code);
    var $2 = HEAPU8[$1];
    if (($2 & 255) > 67) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = ($2 & 255) - 67 | 0;
    if (($6 | 0) > 100) {
      __label__ = 3;
      break;
    } else {
      var $captureNum_0 = $6;
      __label__ = 4;
      break;
    }
   case 3:
    var $_val = HEAP8[$1 + 5 | 0];
    var $_idx_val = HEAP8[$1 + 6 | 0];
    var $10 = __ZL13get2ByteValuePKh($_val, $_idx_val);
    var $captureNum_0 = $10;
    __label__ = 4;
    break;
   case 4:
    var $captureNum_0;
    var $_ = ($captureNum_0 | 0) < 32 ? 1 << $captureNum_0 : 1;
    var $14 = $_ | $captureMap;
    var $15 = __ZL21bracketNeedsLineStartPKhjj($1, $14, $backrefMap);
    var $_0 = $15;
    __label__ = 11;
    break;
   case 5:
    if ($2 << 24 >> 24 == 67 || $2 << 24 >> 24 == 62) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $18 = __ZL21bracketNeedsLineStartPKhjj($1, $captureMap, $backrefMap);
    var $_0 = $18;
    __label__ = 11;
    break;
   case 7:
    if (($2 - 37 & 255 & 255) < 2) {
      __label__ = 8;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 8:
    if (HEAP8[$1 + 1 | 0] << 24 >> 24 == 9) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 11;
      break;
    }
   case 9:
    var $_0 = ($backrefMap & $captureMap | 0) == 0;
    __label__ = 11;
    break;
   case 10:
    var $_0 = $2 << 24 >> 24 == 10 | $2 << 24 >> 24 == 12;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Z12jsRegExpFreeP8JSRegExp($re) {
  var $1 = $re;
  __ZN2js10Foreground12array_deleteIcEEvPT_($1);
  return;
}

function _js_free4455($p) {
  _free($p);
  return;
}

function _js_malloc4456($bytes) {
  var $1 = _malloc($bytes);
  return $1;
}

function __ZL12getLinkValuePKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL21getLinkValueAllowZeroPKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL21getLinkValueAllowZeroPKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL13get3ByteValuePKh($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL40firstSignificantOpcodeSkippingAssertionsPKh($code) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    HEAP32[$1 >> 2] = $code;
    var $2 = $code;
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $4 = HEAPU8[$2] & 255;
    if (($4 | 0) == 63) {
      __label__ = 3;
      break;
    } else if (($4 | 0) == 2 || ($4 | 0) == 1) {
      __label__ = 4;
      break;
    } else if (($4 | 0) == 66) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 3:
    __ZL21advanceToEndOfBracketRPKh($1);
    var $7 = HEAP32[$1 >> 2] + 4 | 0;
    HEAP32[$1 >> 2] = $7;
    var $2 = $7;
    __label__ = 2;
    break;
   case 4:
    var $9 = $2 + 1 | 0;
    HEAP32[$1 >> 2] = $9;
    var $2 = $9;
    __label__ = 2;
    break;
   case 5:
    var $11 = $2 + 3 | 0;
    HEAP32[$1 >> 2] = $11;
    var $2 = $11;
    __label__ = 2;
    break;
   case 6:
    STACKTOP = __stackBase__;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21advanceToEndOfBracketRPKh($opcodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$opcodePtr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $_val = HEAP8[$2 + 1 | 0];
    var $_idx_val = HEAP8[$2 + 2 | 0];
    var $_idx1_val = HEAP8[$2 + 3 | 0];
    var $4 = __ZL12getLinkValuePKh($_val, $_idx_val, $_idx1_val);
    var $5 = $2 + $4 | 0;
    HEAP32[$opcodePtr >> 2] = $5;
    if (HEAP8[$5] << 24 >> 24 == 58) {
      var $2 = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21putLinkValueAllowZeroPhi($opcodePtr, $value) {
  __ZL13put3ByteValuePhi($opcodePtr, $value);
  return;
}

function __ZL12putLinkValuePhi($opcodePtr, $value) {
  __ZL21putLinkValueAllowZeroPhi($opcodePtr, $value);
  return;
}

function __ZL15isCountedRepeatPKtS0_($p, $patternEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($p >>> 0 < $patternEnd >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 2:
    var $3 = HEAP16[$p >> 1];
    var $4 = __ZN3WTF12isASCIIDigitEt($3);
    if ($4) {
      var $p_pn = $p;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 3:
    var $p_pn;
    var $_01 = $p_pn + 2 | 0;
    if ($_01 >>> 0 < $patternEnd >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 4:
    var $7 = HEAPU16[$_01 >> 1];
    var $8 = __ZN3WTF12isASCIIDigitEt($7);
    if ($8) {
      var $p_pn = $_01;
      __label__ = 3;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($7 << 16 >> 16 == 125) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $12 = $p_pn + 4 | 0;
    if ($7 << 16 >> 16 == 44 & $12 >>> 0 < $patternEnd >>> 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 7:
    var $16 = HEAPU16[$12 >> 1];
    if ($16 << 16 >> 16 == 125) {
      var $_0 = 1;
      __label__ = 14;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $19 = __ZN3WTF12isASCIIDigitEt($16);
    if ($19) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 9:
    var $_1 = $p_pn + 6 | 0;
    __label__ = 10;
    break;
   case 10:
    var $_1;
    if ($_1 >>> 0 < $patternEnd >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $25 = HEAPU16[$_1 >> 1];
    var $26 = __ZN3WTF12isASCIIDigitEt($25);
    if ($26) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $_1 = $_1 + 2 | 0;
    __label__ = 10;
    break;
   case 13:
    var $_0 = $25 << 16 >> 16 == 125;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11checkEscapePPKtS0_P9ErrorCodeib($ptrPtr, $patternEnd, $errorCodePtr, $bracount, $isClass) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[$ptrPtr >> 2];
    var $2 = $1 + 2 | 0;
    if (($2 | 0) == ($patternEnd | 0)) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$errorCodePtr >> 2] = 1;
    HEAP32[$ptrPtr >> 2] = $2;
    var $_0 = 0;
    __label__ = 40;
    break;
   case 3:
    var $6 = HEAPU16[$2 >> 1];
    var $7 = $6 & 65535;
    if (($6 - 48 & 65535 & 65535) > 74) {
      var $ptr_3 = $2;
      var $c_7 = $7;
      __label__ = 39;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $10 = $7 - 48 | 0;
    var $12 = HEAP16[__ZL7escapes + ($10 << 1) >> 1];
    var $13 = $12 << 16 >> 16;
    if ($12 << 16 >> 16 == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($isClass) {
      __label__ = 6;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $13;
      __label__ = 39;
      break;
    }
   case 6:
    var $17 = -$13 | 0;
    if (($17 | 0) == 2) {
      var $ptr_3 = $2;
      var $c_7 = 8;
      __label__ = 39;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($17 | 0) == 1) {
      __label__ = 8;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $13;
      __label__ = 39;
      break;
    }
   case 8:
    var $ptr_3 = $2;
    var $c_7 = 66;
    __label__ = 39;
    break;
   case 9:
    if (($7 | 0) == 49 || ($7 | 0) == 50 || ($7 | 0) == 51 || ($7 | 0) == 52 || ($7 | 0) == 53 || ($7 | 0) == 54 || ($7 | 0) == 55 || ($7 | 0) == 56 || ($7 | 0) == 57) {
      __label__ = 10;
      break;
    } else if (($7 | 0) == 48) {
      var $c_1 = 48;
      __label__ = 17;
      break;
    } else if (($7 | 0) == 120) {
      var $i1_0 = 1;
      var $c_3 = 0;
      __label__ = 23;
      break;
    } else if (($7 | 0) == 117) {
      var $i3_0 = 1;
      var $c_5 = 0;
      __label__ = 28;
      break;
    } else if (($7 | 0) == 99) {
      __label__ = 33;
      break;
    } else {
      var $ptr_3 = $2;
      var $c_7 = $7;
      __label__ = 39;
      break;
    }
   case 10:
    if ($isClass) {
      __label__ = 16;
      break;
    } else {
      var $ptr_0 = $2;
      var $c_0 = $10;
      __label__ = 11;
      break;
    }
   case 11:
    var $c_0;
    var $ptr_0;
    var $24 = $ptr_0 + 2 | 0;
    if ($24 >>> 0 < $patternEnd >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $27 = HEAPU16[$24 >> 1];
    var $28 = __ZN3WTF12isASCIIDigitEt($27);
    if ($28 & ($c_0 | 0) <= ($bracount | 0)) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $34 = $c_0 * 10 - 48 + ($27 & 65535) | 0;
    var $ptr_0 = $24;
    var $c_0 = $34;
    __label__ = 11;
    break;
   case 14:
    if (($c_0 | 0) > ($bracount | 0)) {
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $ptr_3 = $ptr_0;
    var $c_7 = -9 - $c_0 | 0;
    __label__ = 39;
    break;
   case 16:
    if (($6 & 65535) > 55) {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    } else {
      var $c_1 = $7;
      __label__ = 17;
      break;
    }
   case 17:
    var $c_1;
    var $i_0 = 1;
    var $c_2 = $c_1 - 48 | 0;
    __label__ = 18;
    break;
   case 18:
    var $c_2;
    var $i_0;
    if (($i_0 | 0) < 3) {
      __label__ = 19;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 19:
    var $_sum7 = $i_0 + 1 | 0;
    var $45 = $1 + ($_sum7 << 1) | 0;
    if ($45 >>> 0 < $patternEnd >>> 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 20:
    var $48 = HEAPU16[$45 >> 1];
    if (($48 - 48 & 65535 & 65535) > 7) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $54 = ($c_2 << 3) - 48 + ($48 & 65535) | 0;
    if (($54 | 0) > 255) {
      __label__ = 22;
      break;
    } else {
      var $i_0 = $_sum7;
      var $c_2 = $54;
      __label__ = 18;
      break;
    }
   case 22:
    var $ptr_3 = $1 + ($i_0 << 1) | 0;
    var $c_7 = $c_2;
    __label__ = 39;
    break;
   case 23:
    var $c_3;
    var $i1_0;
    if (($i1_0 | 0) < 3) {
      __label__ = 24;
      break;
    } else {
      var $i1_1 = $i1_0;
      var $c_4 = $c_3;
      __label__ = 27;
      break;
    }
   case 24:
    var $_sum5 = $i1_0 + 1 | 0;
    var $60 = $1 + ($_sum5 << 1) | 0;
    if ($60 >>> 0 < $patternEnd >>> 0) {
      __label__ = 25;
      break;
    } else {
      var $i1_1 = 1;
      var $c_4 = 120;
      __label__ = 27;
      break;
    }
   case 25:
    var $63 = HEAPU16[$60 >> 1];
    var $64 = __ZN3WTF15isASCIIHexDigitEt($63);
    if ($64) {
      __label__ = 26;
      break;
    } else {
      var $i1_1 = 1;
      var $c_4 = 120;
      __label__ = 27;
      break;
    }
   case 26:
    var $66 = $63 & 65535;
    var $cc2_0 = ($63 & 65535) > 96 ? $66 - 32 | 0 : $66;
    var $_neg = ($cc2_0 | 0) < 65 ? -48 : -55;
    var $72 = $cc2_0 + ($c_3 << 4) + $_neg | 0;
    var $i1_0 = $_sum5;
    var $c_3 = $72;
    __label__ = 23;
    break;
   case 27:
    var $c_4;
    var $i1_1;
    var $ptr_3 = $1 + ($i1_1 << 1) | 0;
    var $c_7 = $c_4;
    __label__ = 39;
    break;
   case 28:
    var $c_5;
    var $i3_0;
    if (($i3_0 | 0) < 5) {
      __label__ = 29;
      break;
    } else {
      var $i3_1 = $i3_0;
      var $c_6 = $c_5;
      __label__ = 32;
      break;
    }
   case 29:
    var $_sum = $i3_0 + 1 | 0;
    var $77 = $1 + ($_sum << 1) | 0;
    if ($77 >>> 0 < $patternEnd >>> 0) {
      __label__ = 30;
      break;
    } else {
      var $i3_1 = 1;
      var $c_6 = 117;
      __label__ = 32;
      break;
    }
   case 30:
    var $80 = HEAPU16[$77 >> 1];
    var $81 = __ZN3WTF15isASCIIHexDigitEt($80);
    if ($81) {
      __label__ = 31;
      break;
    } else {
      var $i3_1 = 1;
      var $c_6 = 117;
      __label__ = 32;
      break;
    }
   case 31:
    var $83 = $80 & 65535;
    var $cc4_0 = ($80 & 65535) > 96 ? $83 - 32 | 0 : $83;
    var $_neg11 = ($cc4_0 | 0) < 65 ? -48 : -55;
    var $89 = $cc4_0 + ($c_5 << 4) + $_neg11 | 0;
    var $i3_0 = $_sum;
    var $c_5 = $89;
    __label__ = 28;
    break;
   case 32:
    var $c_6;
    var $i3_1;
    var $ptr_3 = $1 + ($i3_1 << 1) | 0;
    var $c_7 = $c_6;
    __label__ = 39;
    break;
   case 33:
    var $93 = $1 + 4 | 0;
    if (($93 | 0) == ($patternEnd | 0)) {
      __label__ = 34;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 34:
    HEAP32[$errorCodePtr >> 2] = 2;
    var $_0 = 0;
    __label__ = 40;
    break;
   case 35:
    var $97 = HEAPU16[$93 >> 1];
    var $98 = $97 & 65535;
    if ($isClass) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    var $100 = __ZN3WTF12isASCIIAlphaEi($98);
    if ($100) {
      __label__ = 37;
      break;
    } else {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    }
   case 37:
    var $102 = __ZN3WTF19isASCIIAlphanumericEi($98);
    if ($97 << 16 >> 16 != 95 & ($102 ^ 1)) {
      var $ptr_3 = $1;
      var $c_7 = 92;
      __label__ = 39;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $105 = __ZN3WTF12toASCIIUpperEi($98);
    var $ptr_3 = $93;
    var $c_7 = $105 ^ 64;
    __label__ = 39;
    break;
   case 39:
    var $c_7;
    var $ptr_3;
    HEAP32[$ptrPtr >> 2] = $ptr_3;
    var $_0 = $c_7;
    __label__ = 40;
    break;
   case 40:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL11checkEscapePPKtS0_P9ErrorCodeib["X"] = 1;

function __ZL17getOthercaseRangePiiS_S_($cptr, $d, $ocptr, $odptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $c_0 = HEAP32[$cptr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $c_0;
    if (($c_0 | 0) > ($d | 0)) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $5 = __Z22jsc_pcre_ucp_othercasej($c_0);
    if (($5 | 0) > -1) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $c_0 = $c_0 + 1 | 0;
    __label__ = 2;
    break;
   case 5:
    HEAP32[$ocptr >> 2] = $5;
    var $next_0_in = $5;
    var $c_1_in = $c_0;
    __label__ = 6;
    break;
   case 6:
    var $c_1_in;
    var $next_0_in;
    var $next_0 = $next_0_in + 1 | 0;
    var $c_1 = $c_1_in + 1 | 0;
    if (($c_1 | 0) > ($d | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $13 = __Z22jsc_pcre_ucp_othercasej($c_1);
    if (($13 | 0) == ($next_0 | 0)) {
      var $next_0_in = $next_0;
      var $c_1_in = $c_1;
      __label__ = 6;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$odptr >> 2] = $next_0_in;
    HEAP32[$cptr >> 2] = $c_1;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12isASCIIDigitEt($c) {
  return ($c - 48 & 65535 & 65535) < 10;
}

function __ZN3WTF15isASCIIHexDigitEt($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c - 48 & 65535 & 65535) < 10) {
      var $9 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $c & 65535 | 32;
    if ($4 >>> 0 > 96) {
      __label__ = 3;
      break;
    } else {
      var $9 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $9 = $4 >>> 0 < 103;
    __label__ = 4;
    break;
   case 4:
    var $9;
    return $9;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12isASCIIAlphaEi($c) {
  return (($c | 32) - 97 | 0) >>> 0 < 26;
}

function __ZN3WTF19isASCIIAlphanumericEi($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c - 48 | 0) >>> 0 < 10) {
      var $8 = 1;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $c | 32;
    if (($3 | 0) > 96) {
      __label__ = 3;
      break;
    } else {
      var $8 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $8 = ($3 | 0) < 123;
    __label__ = 4;
    break;
   case 4:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN3WTF12toASCIIUpperEi($c) {
  return ((($c - 97 | 0) >>> 0 < 26 & 1) << 5 ^ -1) & $c;
}

function __ZL25multiplyWithOverflowCheckii($a, $b) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($a | 0) == 0 | ($b | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((4194304 / ($b | 0) & -1 | 0) < ($a | 0)) {
      var $_0 = -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $_0 = $b * $a | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL19safelyCheckNextCharPKtS0_t($ptr, $patternEnd, $expected) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $ptr + 2 | 0;
    if ($1 >>> 0 < $patternEnd >>> 0) {
      __label__ = 2;
      break;
    } else {
      var $7 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $7 = HEAP16[$1 >> 1] << 16 >> 16 == $expected << 16 >> 16;
    __label__ = 3;
    break;
   case 3:
    var $7;
    return $7;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN11CompileDataC2Ev($this) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  HEAP32[$this + 8 >> 2] = 0;
  HEAP8[$this + 12 | 0] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZL11toLowerCaseh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + ($c & 255) | 0;
  return HEAP8[$2];
}

function __ZL8flipCaseh4460($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 128) | 0;
  return HEAP8[$2];
}

function __ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_($subjectPtr_val, $endSubject, $reqByte, $reqByte2, $reqByteIsCaseless, $hasFirstByte, $reqBytePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($reqByte | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 2:
    if (($endSubject - $subjectPtr_val | 0) < 2e3) {
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 3:
    var $9 = $subjectPtr_val + (($hasFirstByte & 1) << 1) | 0;
    if ($9 >>> 0 > HEAPU32[$reqBytePtr >> 2] >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 12;
      break;
    }
   case 4:
    if ($reqByteIsCaseless) {
      var $p_0 = $9;
      __label__ = 5;
      break;
    } else {
      var $p_1 = $9;
      __label__ = 8;
      break;
    }
   case 5:
    var $p_0;
    if ($p_0 >>> 0 < $endSubject >>> 0) {
      __label__ = 6;
      break;
    } else {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    }
   case 6:
    var $16 = HEAPU16[$p_0 >> 1] & 65535;
    if (($16 | 0) == ($reqByte | 0)) {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($16 | 0) == ($reqByte2 | 0)) {
      var $p_2 = $p_0;
      __label__ = 10;
      break;
    } else {
      var $p_0 = $p_0 + 2 | 0;
      __label__ = 5;
      break;
    }
   case 8:
    var $p_1;
    if ($p_1 >>> 0 < $endSubject >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $p_2 = $p_1;
      __label__ = 10;
      break;
    }
   case 9:
    if ((HEAPU16[$p_1 >> 1] & 65535 | 0) == ($reqByte | 0)) {
      var $p_2 = $p_1;
      __label__ = 10;
      break;
    } else {
      var $p_1 = $p_1 + 2 | 0;
      __label__ = 8;
      break;
    }
   case 10:
    var $p_2;
    if ($p_2 >>> 0 < $endSubject >>> 0) {
      __label__ = 11;
      break;
    } else {
      var $_0 = 1;
      __label__ = 12;
      break;
    }
   case 11:
    HEAP32[$reqBytePtr >> 2] = $p_2;
    var $_0 = 0;
    __label__ = 12;
    break;
   case 12:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16readRepeatCountsPKtPiS1_P9ErrorCode($p, $minp, $maxp, $errorCodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU16[$p >> 1];
    var $2 = __ZN3WTF12isASCIIDigitEt($1);
    if ($2) {
      var $min_09 = 0;
      var $_0410 = $p;
      var $3 = $1;
      __label__ = 2;
      break;
    } else {
      var $_lcssa22 = $1;
      var $_04_lcssa23 = $p;
      var $min_0_lcssa24 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    var $3;
    var $_0410;
    var $min_09;
    var $5 = $_0410 + 2 | 0;
    var $8 = $min_09 * 10 - 48 + ($3 & 65535) | 0;
    var $9 = HEAPU16[$5 >> 1];
    var $10 = __ZN3WTF12isASCIIDigitEt($9);
    if ($10) {
      var $min_09 = $8;
      var $_0410 = $5;
      var $3 = $9;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if ($8 >>> 0 > 65535) {
      __label__ = 4;
      break;
    } else {
      var $_lcssa22 = $9;
      var $_04_lcssa23 = $5;
      var $min_0_lcssa24 = $8;
      __label__ = 5;
      break;
    }
   case 4:
    HEAP32[$errorCodePtr >> 2] = 5;
    var $_0 = $5;
    __label__ = 14;
    break;
   case 5:
    var $min_0_lcssa24;
    var $_04_lcssa23;
    var $_lcssa22;
    if ($_lcssa22 << 16 >> 16 == 125) {
      var $_2 = $_04_lcssa23;
      var $max_1 = $min_0_lcssa24;
      __label__ = 13;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $_04_lcssa23 + 2 | 0;
    var $16 = HEAP16[$15 >> 1];
    if ($16 << 16 >> 16 == 125) {
      var $_2 = $15;
      var $max_1 = -1;
      __label__ = 13;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = __ZN3WTF12isASCIIDigitEt($16);
    if ($18) {
      var $max_05 = 0;
      var $_16 = $15;
      var $19 = $16;
      __label__ = 8;
      break;
    } else {
      var $_1_lcssa26 = $15;
      var $max_0_lcssa27 = 0;
      __label__ = 11;
      break;
    }
   case 8:
    var $19;
    var $_16;
    var $max_05;
    var $21 = $_16 + 2 | 0;
    var $24 = $max_05 * 10 - 48 + ($19 & 65535) | 0;
    var $25 = HEAPU16[$21 >> 1];
    var $26 = __ZN3WTF12isASCIIDigitEt($25);
    if ($26) {
      var $max_05 = $24;
      var $_16 = $21;
      var $19 = $25;
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($24 >>> 0 > 65535) {
      __label__ = 10;
      break;
    } else {
      var $_1_lcssa26 = $21;
      var $max_0_lcssa27 = $24;
      __label__ = 11;
      break;
    }
   case 10:
    HEAP32[$errorCodePtr >> 2] = 5;
    var $_0 = $21;
    __label__ = 14;
    break;
   case 11:
    var $max_0_lcssa27;
    var $_1_lcssa26;
    if (($max_0_lcssa27 | 0) < ($min_0_lcssa24 | 0)) {
      __label__ = 12;
      break;
    } else {
      var $_2 = $_1_lcssa26;
      var $max_1 = $max_0_lcssa27;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[$errorCodePtr >> 2] = 4;
    var $_0 = $_1_lcssa26;
    __label__ = 14;
    break;
   case 13:
    var $max_1;
    var $_2;
    HEAP32[$minp >> 2] = $min_0_lcssa24;
    HEAP32[$maxp >> 2] = $max_1;
    var $_0 = $_2;
    __label__ = 14;
    break;
   case 14:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL16readRepeatCountsPKtPiS1_P9ErrorCode["X"] = 1;

function __ZL23put2ByteValueAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL13put2ByteValuePhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 2 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __ZL31putLinkValueAllowZeroAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL21putLinkValueAllowZeroPhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 3 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __ZL22putLinkValueAndAdvanceRPhi($opcodePtr, $value) {
  var $1 = HEAP32[$opcodePtr >> 2];
  __ZL12putLinkValuePhi($1, $value);
  var $3 = HEAP32[$opcodePtr >> 2] + 3 | 0;
  HEAP32[$opcodePtr >> 2] = $3;
  return;
}

function __Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii($cx, $re, $subject, $length, $start_offset, $offsets, $offsetCount) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $matchBlock = __stackBase__;
    var $startMatch = __stackBase__ + 36;
    var $reqBytePtr = __stackBase__ + 40;
    var $1 = $matchBlock + 16 | 0;
    HEAP32[$1 >> 2] = $subject;
    var $2 = $subject + ($length << 1) | 0;
    HEAP32[$matchBlock + 20 >> 2] = $2;
    var $4 = $re | 0;
    var $5 = HEAPU32[$4 >> 2];
    HEAP8[$matchBlock + 32 | 0] = $5 >>> 1 & 255 & 1;
    HEAP8[$matchBlock + 33 | 0] = $5 & 255 & 1;
    var $12 = $offsetCount - $offsetCount % 3 | 0;
    var $13 = $matchBlock | 0;
    HEAP32[$13 >> 2] = $offsets;
    HEAP32[$matchBlock + 4 >> 2] = $12;
    HEAP32[$matchBlock + 8 >> 2] = ($12 << 1 | 0) / 3 & -1;
    var $18 = $matchBlock + 12 | 0;
    HEAP8[$18] = 0;
    var $23 = ((HEAPU16[$re + 4 >> 1] & 65535) << 1) + 2 | 0;
    var $resetCount_0 = ($23 | 0) > ($offsetCount | 0) ? $12 : $23;
    if (($offsets | 0) == 0) {
      var $35 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $_sum3 = $12 + 1 + (($resetCount_0 | 0) / -2 & -1) | 0;
    var $28 = $offsets + ($_sum3 << 2) | 0;
    var $_sum7 = $12 - 1 | 0;
    if (($_sum7 | 0) < ($_sum3 | 0)) {
      var $35 = $5;
      __label__ = 6;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $32 = $offsets + ($_sum7 << 2) | 0;
    __label__ = 4;
    break;
   case 4:
    var $32;
    HEAP32[$32 >> 2] = -1;
    var $33 = $32 - 4 | 0;
    if ($33 >>> 0 < $28 >>> 0) {
      __label__ = 5;
      break;
    } else {
      var $32 = $33;
      __label__ = 4;
      break;
    }
   case 5:
    var $35 = HEAP32[$4 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $35;
    if (($35 & 1073741824 | 0) == 0) {
      var $firstByte_0 = -1;
      var $firstByteIsCaseless_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $40 = HEAPU16[$re + 8 >> 1];
    var $41 = $40 & 65535;
    var $43 = $41 & 256;
    var $45 = $43 >>> 8 & 255;
    if (($43 | 0) == 0) {
      var $firstByte_0 = $41 & 255;
      var $firstByteIsCaseless_0 = $45;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $47 = $40 & 255;
    var $48 = __ZL11toLowerCaseh($47);
    var $firstByte_0 = $48 & 255;
    var $firstByteIsCaseless_0 = $45;
    __label__ = 9;
    break;
   case 9:
    var $firstByteIsCaseless_0;
    var $firstByte_0;
    if (($35 & 536870912 | 0) == 0) {
      var $reqByte2_0 = -1;
      var $reqByte_0 = -1;
      var $reqByteIsCaseless_0 = 0;
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $55 = HEAPU16[$re + 10 >> 1];
    var $56 = $55 & 65535;
    var $57 = $56 & 255;
    var $59 = ($56 & 256 | 0) != 0;
    var $60 = $55 & 255;
    var $61 = __ZL8flipCaseh4460($60);
    var $reqByte2_0 = $61 & 255;
    var $reqByte_0 = $57;
    var $reqByteIsCaseless_0 = $59;
    __label__ = 11;
    break;
   case 11:
    var $reqByteIsCaseless_0;
    var $reqByte_0;
    var $reqByte2_0;
    HEAP32[$startMatch >> 2] = $subject + ($start_offset << 1) | 0;
    HEAP32[$reqBytePtr >> 2] = $subject + ($start_offset - 1 << 1) | 0;
    var $67 = ($35 & 268435456 | 0) != 0;
    var $68 = $firstByteIsCaseless_0 << 24 >> 24 != 0;
    var $69 = ($firstByte_0 | 0) > -1;
    var $71 = $re + 12 | 0;
    var $72 = $cx + 104 | 0;
    var $73 = ($resetCount_0 | 0) > 0;
    __label__ = 12;
    break;
   case 12:
    var $74 = HEAP32[$13 >> 2];
    if (($74 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $77 = $74 + ($resetCount_0 << 2) | 0;
    if ($73) {
      var $iptr1_05 = $74;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    var $iptr1_05;
    var $78 = $iptr1_05 + 4 | 0;
    HEAP32[$iptr1_05 >> 2] = -1;
    if ($78 >>> 0 < $77 >>> 0) {
      var $iptr1_05 = $78;
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $81 = HEAP32[$1 >> 2] + ($start_offset << 1) | 0;
    __ZL24tryFirstByteOptimizationRPKtS0_ibbS0_($startMatch, $2, $firstByte_0, $68, $67, $81);
    var $startMatch_val = HEAPU32[$startMatch >> 2];
    var $82 = __ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_($startMatch_val, $2, $reqByte_0, $reqByte2_0, $reqByteIsCaseless_0, $69, $reqBytePtr);
    if ($82) {
      var $_0 = -1;
      __label__ = 22;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $84 = __ZL5matchP11JSArenaPoolPKtPKhiR9MatchData($72, $startMatch_val, $71, $matchBlock);
    if (($84 | 0) == 0) {
      __label__ = 17;
      break;
    } else if (($84 | 0) == 1) {
      __label__ = 18;
      break;
    } else {
      var $_0 = $84;
      __label__ = 22;
      break;
    }
   case 17:
    var $86 = $startMatch_val + 2 | 0;
    HEAP32[$startMatch >> 2] = $86;
    if ((HEAP32[$4 >> 2] & 33554432 | 0) != 0 | $86 >>> 0 > $2 >>> 0) {
      var $_0 = -1;
      __label__ = 22;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 18:
    if ((HEAP8[$18] & 1) << 24 >> 24 == 0) {
      __label__ = 19;
      break;
    } else {
      var $100 = 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $100 = (HEAP32[$matchBlock + 28 >> 2] | 0) / 2 & -1;
    __label__ = 20;
    break;
   case 20:
    var $100;
    if (($offsetCount | 0) < 2) {
      var $_0 = 0;
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $105 = HEAP32[$1 >> 2];
    var $107 = $startMatch_val - $105 >> 1;
    HEAP32[$offsets >> 2] = $107;
    var $112 = HEAP32[$matchBlock + 24 >> 2] - $105 >> 1;
    HEAP32[$offsets + 4 >> 2] = $112;
    var $_0 = $100;
    __label__ = 22;
    break;
   case 22:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii["X"] = 1;

function __ZL24tryFirstByteOptimizationRPKtS0_ibbS0_($subjectPtr, $endSubject, $firstByte, $firstByteIsCaseless, $useMultiLineFirstCharOptimization, $originalSubjectStart) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($firstByte | 0) > -1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 2:
    var $3 = $firstByte & 65535;
    var $_pre3 = HEAPU32[$subjectPtr >> 2];
    if ($firstByteIsCaseless) {
      var $4 = $_pre3;
      __label__ = 3;
      break;
    } else {
      var $16 = $_pre3;
      __label__ = 7;
      break;
    }
   case 3:
    var $4;
    if ($4 >>> 0 < $endSubject >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 4:
    var $7 = HEAPU16[$4 >> 1];
    if (($7 & 65535) > 127) {
      __label__ = 15;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $10 = $7 & 255;
    var $11 = __ZL11toLowerCaseh($10);
    if (($11 & 255 | 0) == ($3 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $4 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $15;
    var $4 = $15;
    __label__ = 3;
    break;
   case 7:
    var $16;
    if ($16 >>> 0 < $endSubject >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 8:
    if ((HEAPU16[$16 >> 1] & 65535 | 0) == ($3 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $23 = $16 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $23;
    var $16 = $23;
    __label__ = 7;
    break;
   case 10:
    if ($useMultiLineFirstCharOptimization) {
      __label__ = 11;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 11:
    var $26 = HEAPU32[$subjectPtr >> 2];
    if ($26 >>> 0 > $originalSubjectStart >>> 0) {
      var $28 = $26;
      __label__ = 12;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 12:
    var $28;
    if ($28 >>> 0 < $endSubject >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 13:
    var $32 = HEAP16[$28 - 2 >> 1];
    var $33 = __ZL9isNewlinet($32);
    if ($33) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $35 = $28 + 2 | 0;
    HEAP32[$subjectPtr >> 2] = $35;
    var $28 = $35;
    __label__ = 12;
    break;
   case 15:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL5matchP11JSArenaPoolPKtPKhiR9MatchData($regExpPool, $subjectPtr, $instructionPtr, $md) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 1952;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $min = __stackBase__;
    var $minimize = __stackBase__ + 4;
    var $stack = __stackBase__ + 8;
    var $minSatNextBracket = __stackBase__ + 1948;
    HEAP8[$minimize] = 0;
    __ZN10MatchStackC1EP11JSArenaPool($stack, $regExpPool);
    __ZN10LinearFlagC1Ev($minSatNextBracket);
    var $1 = $stack + 1932 | 0;
    var $3 = HEAP32[$1 >> 2] | 0;
    HEAP32[$3 >> 2] = 0;
    var $5 = HEAP32[$1 >> 2] + 20 | 0;
    HEAP32[$5 >> 2] = $subjectPtr;
    var $7 = HEAP32[$1 >> 2] + 24 | 0;
    HEAP32[$7 >> 2] = $instructionPtr;
    var $9 = HEAP32[$1 >> 2] + 28 | 0;
    HEAP32[$9 >> 2] = 2;
    var $11 = HEAP32[$1 >> 2] + 32 | 0;
    HEAP32[$11 >> 2] = 0;
    var $12 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($12, 0);
    var $13 = $md + 24 | 0;
    var $14 = $md + 28 | 0;
    var $15 = $md + 8 | 0;
    var $16 = $md + 4 | 0;
    var $17 = $md | 0;
    var $18 = $md + 16 | 0;
    var $19 = $md + 12 | 0;
    var $20 = $md + 20 | 0;
    var $21 = $md + 33 | 0;
    var $remainingMatchCount_0 = 999999;
    __label__ = 2;
    break;
   case 2:
    var $remainingMatchCount_0;
    if (($remainingMatchCount_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $25 = __ZL10matchErroriR10MatchStack(-2, $stack);
    var $_0 = $25;
    __label__ = 410;
    break;
   case 4:
    var $26 = HEAPU32[$1 >> 2];
    var $27 = $26 + 20 | 0;
    var $28 = $26 + 24 | 0;
    var $29 = HEAPU32[$28 >> 2];
    var $31 = HEAPU8[$29] & 255;
    if (($31 | 0) == 67) {
      var $33 = $26;
      var $32 = $29;
      __label__ = 5;
      break;
    } else if (($31 | 0) == 66) {
      __label__ = 11;
      break;
    } else if (($31 | 0) == 0) {
      __label__ = 12;
      break;
    } else if (($31 | 0) == 62) {
      __label__ = 13;
      break;
    } else if (($31 | 0) == 63) {
      __label__ = 20;
      break;
    } else if (($31 | 0) == 58) {
      __label__ = 24;
      break;
    } else if (($31 | 0) == 64) {
      __label__ = 25;
      break;
    } else if (($31 | 0) == 65) {
      __label__ = 27;
      break;
    } else if (($31 | 0) == 59 || ($31 | 0) == 61 || ($31 | 0) == 60) {
      __label__ = 29;
      break;
    } else if (($31 | 0) == 10) {
      __label__ = 49;
      break;
    } else if (($31 | 0) == 12) {
      __label__ = 51;
      break;
    } else if (($31 | 0) == 11) {
      __label__ = 54;
      break;
    } else if (($31 | 0) == 13) {
      __label__ = 56;
      break;
    } else if (($31 | 0) == 1 || ($31 | 0) == 2) {
      __label__ = 59;
      break;
    } else if (($31 | 0) == 9) {
      __label__ = 66;
      break;
    } else if (($31 | 0) == 3) {
      __label__ = 69;
      break;
    } else if (($31 | 0) == 4) {
      __label__ = 72;
      break;
    } else if (($31 | 0) == 5) {
      __label__ = 75;
      break;
    } else if (($31 | 0) == 6) {
      __label__ = 78;
      break;
    } else if (($31 | 0) == 7) {
      __label__ = 81;
      break;
    } else if (($31 | 0) == 8) {
      __label__ = 84;
      break;
    } else if (($31 | 0) == 57) {
      __label__ = 87;
      break;
    } else if (($31 | 0) == 55 || ($31 | 0) == 54) {
      __label__ = 116;
      break;
    } else if (($31 | 0) == 56) {
      __label__ = 148;
      break;
    } else if (($31 | 0) == 14) {
      __label__ = 173;
      break;
    } else if (($31 | 0) == 15) {
      __label__ = 175;
      break;
    } else if (($31 | 0) == 16) {
      __label__ = 178;
      break;
    } else if (($31 | 0) == 17) {
      __label__ = 181;
      break;
    } else if (($31 | 0) == 27) {
      __label__ = 184;
      break;
    } else if (($31 | 0) == 25 || ($31 | 0) == 26) {
      __label__ = 185;
      break;
    } else if (($31 | 0) == 19 || ($31 | 0) == 20 || ($31 | 0) == 21 || ($31 | 0) == 22 || ($31 | 0) == 23 || ($31 | 0) == 24) {
      __label__ = 186;
      break;
    } else if (($31 | 0) == 18) {
      __label__ = 231;
      break;
    } else if (($31 | 0) == 36) {
      __label__ = 237;
      break;
    } else if (($31 | 0) == 34 || ($31 | 0) == 35) {
      __label__ = 238;
      break;
    } else if (($31 | 0) == 28 || ($31 | 0) == 29 || ($31 | 0) == 30 || ($31 | 0) == 31 || ($31 | 0) == 32 || ($31 | 0) == 33) {
      __label__ = 239;
      break;
    } else if (($31 | 0) == 45) {
      __label__ = 286;
      break;
    } else if (($31 | 0) == 43 || ($31 | 0) == 44) {
      __label__ = 287;
      break;
    } else if (($31 | 0) == 37 || ($31 | 0) == 38 || ($31 | 0) == 39 || ($31 | 0) == 40 || ($31 | 0) == 41 || ($31 | 0) == 42) {
      __label__ = 288;
      break;
    } else if (($31 | 0) == 49 || ($31 | 0) == 51 || ($31 | 0) == 53 || ($31 | 0) == 47 || ($31 | 0) == 48 || ($31 | 0) == 50 || ($31 | 0) == 52 || ($31 | 0) == 46) {
      __label__ = 369;
      break;
    } else {
      __label__ = 370;
      break;
    }
   case 5:
    var $32;
    var $33;
    __ZN10MatchFrame15extractBracketsEPKh($33, $32);
    var $35 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$35 >> 2] = 3;
    var $36 = __ZN10LinearFlag12readAndClearEv($minSatNextBracket);
    HEAP8[HEAP32[$1 >> 2] + 104 | 0] = $36 & 1;
    var $_pre87 = HEAPU32[$1 >> 2];
    var $41 = $_pre87;
    var $40 = HEAP32[$_pre87 + 24 >> 2];
    __label__ = 6;
    break;
   case 6:
    var $40;
    var $41;
    var $45 = (HEAP8[$41 + 104 | 0] & 1) << 24 >> 24 != 0;
    var $48 = $40 + (HEAP32[$41 + 88 >> 2] + 3) | 0;
    var $50 = HEAP32[$41 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $48, $50, 2);
    var $51 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($51, $45);
    __label__ = 7;
    break;
   case 7:
    var $remainingMatchCount_0 = $remainingMatchCount_0 - 1 | 0;
    __label__ = 2;
    break;
   case 8:
    var $54 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$54 >> 2] = 1;
    var $56 = HEAP32[$1 >> 2] + 24 | 0;
    var $57 = HEAP32[$56 >> 2];
    var $_val48 = HEAP8[$57 + 1 | 0];
    var $_idx49_val = HEAP8[$57 + 2 | 0];
    var $_idx50_val = HEAP8[$57 + 3 | 0];
    var $59 = __ZL12getLinkValuePKh4461($_val48, $_idx49_val, $_idx50_val);
    var $60 = $57 + $59 | 0;
    HEAP32[$56 >> 2] = $60;
    var $61 = HEAPU32[$1 >> 2];
    var $63 = HEAPU32[$61 + 24 >> 2];
    if (HEAP8[$63] << 24 >> 24 == 58) {
      var $41 = $61;
      var $40 = $63;
      __label__ = 6;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $68 = HEAPU32[$61 + 92 >> 2];
    if ($68 >>> 0 < HEAPU32[$61 + 96 >> 2] >>> 0) {
      var $i_081 = $68;
      __label__ = 10;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 10:
    var $i_081;
    __ZN9MatchData13setOffsetPairEjii($md, $i_081, -1, -1);
    var $72 = $i_081 + 1 | 0;
    if ($72 >>> 0 < HEAPU32[HEAP32[$1 >> 2] + 96 >> 2] >>> 0) {
      var $i_081 = $72;
      __label__ = 10;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 11:
    HEAP32[$28 >> 2] = $29 + 3 | 0;
    __label__ = 4;
    break;
   case 12:
    var $81 = HEAP32[$27 >> 2];
    HEAP32[$13 >> 2] = $81;
    var $83 = HEAP32[$26 + 28 >> 2];
    HEAP32[$14 >> 2] = $83;
    var $isMatch_0 = 1;
    __label__ = 380;
    break;
   case 13:
    var $_val31 = HEAP8[$29 + 4 | 0];
    var $_idx32_val = HEAP8[$29 + 5 | 0];
    var $86 = __ZL13get2ByteValuePKh4462($_val31, $_idx32_val);
    HEAP32[$26 + 92 >> 2] = $86 >>> 8 & 255;
    var $92 = HEAP32[$1 >> 2] + 96 | 0;
    HEAP32[$92 >> 2] = $86 & 255;
    var $94 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$94 >> 2] = 3;
    var $_pre90 = HEAP32[$1 >> 2];
    var $96 = $_pre90;
    var $95 = HEAP32[$_pre90 + 24 >> 2];
    __label__ = 14;
    break;
   case 14:
    var $95;
    var $96;
    var $99 = $95 + (HEAP32[$96 + 88 >> 2] + 3) | 0;
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $99, 0, 6);
    var $100 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($100, 0);
    __label__ = 7;
    break;
   case 15:
    HEAP32[$2144 + 88 >> 2] = 1;
    var $104 = HEAP32[$1 >> 2] + 24 | 0;
    var $105 = HEAP32[$104 >> 2];
    var $_val45 = HEAP8[$105 + 1 | 0];
    var $_idx46_val = HEAP8[$105 + 2 | 0];
    var $_idx47_val = HEAP8[$105 + 3 | 0];
    var $107 = __ZL12getLinkValuePKh4461($_val45, $_idx46_val, $_idx47_val);
    var $108 = $105 + $107 | 0;
    HEAP32[$104 >> 2] = $108;
    var $109 = HEAPU32[$1 >> 2];
    var $111 = HEAPU32[$109 + 24 >> 2];
    var $112 = HEAP8[$111];
    if ($112 << 24 >> 24 == 58) {
      var $96 = $109;
      var $95 = $111;
      __label__ = 14;
      break;
    } else {
      var $116 = $109;
      var $115 = $112;
      __label__ = 16;
      break;
    }
   case 16:
    var $115;
    var $116;
    if ($115 << 24 >> 24 == 59) {
      __label__ = 17;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 17:
    var $120 = HEAPU32[$116 + 92 >> 2];
    if ($120 >>> 0 < HEAPU32[$116 + 96 >> 2] >>> 0) {
      var $i1_079 = $120;
      __label__ = 18;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 18:
    var $i1_079;
    __ZN9MatchData13setOffsetPairEjii($md, $i1_079, -1, -1);
    var $124 = $i1_079 + 1 | 0;
    if ($124 >>> 0 < HEAPU32[HEAP32[$1 >> 2] + 96 >> 2] >>> 0) {
      var $i1_079 = $124;
      __label__ = 18;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 19:
    __ZL21advanceToEndOfBracketRPKh4463($116 + 24 | 0);
    var $132 = HEAP32[$1 >> 2] + 24 | 0;
    var $134 = HEAP32[$132 >> 2] + 4 | 0;
    HEAP32[$132 >> 2] = $134;
    var $135 = HEAP32[$14 >> 2];
    var $137 = HEAP32[$1 >> 2] + 28 | 0;
    HEAP32[$137 >> 2] = $135;
    __label__ = 4;
    break;
   case 20:
    HEAP32[$26 + 88 >> 2] = 3;
    var $140 = HEAPU32[$1 >> 2];
    var $142 = HEAP32[$140 + 24 >> 2];
    var $_val29 = HEAP8[$142 + 4 | 0];
    var $_idx30_val = HEAP8[$142 + 5 | 0];
    var $144 = __ZL13get2ByteValuePKh4462($_val29, $_idx30_val);
    var $146 = $144 >>> 8 & 255;
    HEAP32[$140 + 92 >> 2] = $146;
    var $148 = $144 & 255;
    var $150 = HEAP32[$1 >> 2] + 96 | 0;
    HEAP32[$150 >> 2] = $148;
    var $_pre93 = HEAP32[$1 >> 2];
    var $152 = $_pre93;
    var $151 = HEAP32[$_pre93 + 24 >> 2];
    __label__ = 21;
    break;
   case 21:
    var $151;
    var $152;
    var $155 = $151 + (HEAP32[$152 + 88 >> 2] + 3) | 0;
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $155, 0, 7);
    var $156 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($156, 0);
    __label__ = 7;
    break;
   case 22:
    var $159 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$159 >> 2] = 1;
    var $161 = HEAP32[$1 >> 2] + 24 | 0;
    var $162 = HEAP32[$161 >> 2];
    var $_val42 = HEAP8[$162 + 1 | 0];
    var $_idx43_val = HEAP8[$162 + 2 | 0];
    var $_idx44_val = HEAP8[$162 + 3 | 0];
    var $164 = __ZL12getLinkValuePKh4461($_val42, $_idx43_val, $_idx44_val);
    var $165 = $162 + $164 | 0;
    HEAP32[$161 >> 2] = $165;
    var $166 = HEAP32[$1 >> 2];
    var $167 = $166 + 24 | 0;
    var $168 = HEAP32[$167 >> 2];
    if (HEAP8[$168] << 24 >> 24 == 58) {
      var $152 = $166;
      var $151 = $168;
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $175 = $168 + (HEAP32[$166 + 88 >> 2] + 3) | 0;
    HEAP32[$167 >> 2] = $175;
    __label__ = 4;
    break;
   case 24:
    __ZL21advanceToEndOfBracketRPKh4463($28);
    __label__ = 4;
    break;
   case 25:
    HEAP32[$26 + 40 >> 2] = $29 + 1 | 0;
    var $180 = HEAP32[$1 >> 2];
    var $183 = HEAP32[$180 + 24 >> 2] + 1 | 0;
    __ZN10MatchFrame15extractBracketsEPKh($180, $183);
    var $184 = HEAP32[$1 >> 2];
    var $186 = HEAP32[$184 + 92 >> 2];
    var $188 = HEAP32[$184 + 96 >> 2];
    var $189 = HEAP32[$17 >> 2];
    var $190 = HEAP32[$16 >> 2];
    __ZN10MatchFrame11saveOffsetsEiiPii($184, $186, $188, $189, $190);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $191 = HEAP32[$1 >> 2];
    var $193 = HEAP32[$191 + 40 >> 2];
    var $195 = HEAP32[$191 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $193, $195, 14);
    var $196 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($196, 1);
    __label__ = 7;
    break;
   case 26:
    var $198 = HEAP32[$1 >> 2];
    var $200 = HEAP32[$198 + 92 >> 2];
    var $202 = HEAP32[$198 + 96 >> 2];
    var $203 = HEAP32[$17 >> 2];
    var $204 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($198, $200, $202, $203, $204);
    var $206 = HEAP32[$1 >> 2] + 40 | 0;
    __ZL21advanceToEndOfBracketRPKh4463($206);
    var $207 = HEAP32[$1 >> 2];
    var $210 = HEAP32[$207 + 40 >> 2] + 4 | 0;
    var $211 = $207 + 24 | 0;
    HEAP32[$211 >> 2] = $210;
    __label__ = 4;
    break;
   case 27:
    HEAP32[$26 + 40 >> 2] = $29 + 1 | 0;
    var $216 = HEAP32[$1 >> 2] + 40 | 0;
    __ZL21advanceToEndOfBracketRPKh4463($216);
    var $217 = HEAP32[$1 >> 2];
    var $220 = HEAP32[$217 + 40 >> 2] + 4 | 0;
    var $222 = HEAP32[$217 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $220, $222, 15);
    var $223 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($223, 0);
    __label__ = 7;
    break;
   case 28:
    var $226 = HEAP32[$1 >> 2] + 24 | 0;
    var $228 = HEAP32[$226 >> 2] + 1 | 0;
    HEAP32[$226 >> 2] = $228;
    __label__ = 4;
    break;
   case 29:
    var $_val39 = HEAP8[$29 + 1 | 0];
    var $_idx40_val = HEAP8[$29 + 2 | 0];
    var $_idx41_val = HEAP8[$29 + 3 | 0];
    var $231 = __ZL12getLinkValuePKh4461($_val39, $_idx40_val, $_idx41_val);
    HEAP32[$26 + 48 >> 2] = $29 + -$231 | 0;
    var $235 = HEAP32[$1 >> 2];
    var $239 = HEAP32[HEAP32[$235 + 32 >> 2] + 4 >> 2];
    var $240 = $235 + 44 | 0;
    HEAP32[$240 >> 2] = $239;
    var $241 = HEAP32[$1 >> 2];
    var $246 = HEAP8[HEAP32[$241 + 32 >> 2] + 8 | 0] & 1;
    HEAP8[$241 + 104 | 0] = $246;
    var $249 = HEAP32[$1 >> 2] + 32 | 0;
    var $252 = HEAP32[HEAP32[$249 >> 2] >> 2];
    HEAP32[$249 >> 2] = $252;
    var $253 = HEAPU32[$1 >> 2];
    var $256 = HEAPU8[HEAP32[$253 + 48 >> 2]];
    if (($256 - 62 & 255 & 255) < 2) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    var $259 = HEAP32[$253 + 28 >> 2];
    HEAP32[$14 >> 2] = $259;
    var $isMatch_0 = 1;
    __label__ = 380;
    break;
   case 31:
    var $262 = ($256 & 255) - 67 | 0;
    HEAP32[$253 + 80 >> 2] = $262;
    var $264 = HEAPU32[$1 >> 2];
    var $265 = $264 + 80 | 0;
    var $266 = HEAPU32[$265 >> 2];
    if (($266 | 0) > 100) {
      __label__ = 32;
      break;
    } else {
      var $275 = $264;
      var $274 = $266;
      __label__ = 33;
      break;
    }
   case 32:
    var $270 = HEAP32[$264 + 48 >> 2];
    var $_val27 = HEAP8[$270 + 7 | 0];
    var $_idx28_val = HEAP8[$270 + 8 | 0];
    var $272 = __ZL13get2ByteValuePKh4462($_val27, $_idx28_val);
    HEAP32[$265 >> 2] = $272;
    var $_pre100 = HEAP32[$1 >> 2];
    var $275 = $_pre100;
    var $274 = HEAP32[$_pre100 + 80 >> 2];
    __label__ = 33;
    break;
   case 33:
    var $274;
    var $275;
    HEAP32[$275 + 84 >> 2] = $274 << 1;
    var $278 = HEAPU32[$1 >> 2];
    var $280 = HEAPU32[$278 + 80 >> 2];
    if (($280 | 0) > 0) {
      __label__ = 34;
      break;
    } else {
      var $317 = $278;
      __label__ = 40;
      break;
    }
   case 34:
    if ((HEAP32[$278 + 84 >> 2] | 0) < (HEAP32[$15 >> 2] | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    HEAP8[$19] = 1;
    var $317 = $278;
    __label__ = 40;
    break;
   case 36:
    var $293 = HEAP32[HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - $280 << 2) >> 2];
    var $300 = HEAP32[$278 + 20 >> 2] - HEAP32[$18 >> 2] >> 1;
    if (($293 | 0) == ($300 | 0)) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    if ((HEAP8[$278 + 104 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 38;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 38:
    __ZN9MatchData13setOffsetPairEjii($md, $280, $293, $300);
    var $308 = HEAP32[$1 >> 2];
    var $309 = $308 + 28 | 0;
    var $312 = HEAP32[$308 + 84 >> 2];
    if ((HEAP32[$309 >> 2] | 0) > ($312 | 0)) {
      var $317 = $308;
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    var $315 = $312 + 2 | 0;
    HEAP32[$309 >> 2] = $315;
    var $317 = HEAP32[$1 >> 2];
    __label__ = 40;
    break;
   case 40:
    var $317;
    var $318 = $317 + 24 | 0;
    var $319 = HEAP32[$318 >> 2];
    var $_pre133 = HEAP32[$317 + 20 >> 2];
    var $_pre135 = HEAP32[$317 + 44 >> 2];
    if (HEAP8[$319] << 24 >> 24 == 59 | ($_pre133 | 0) == ($_pre135 | 0)) {
      __label__ = 41;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 41:
    if (($_pre133 | 0) == ($_pre135 | 0)) {
      __label__ = 42;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 42:
    if ((HEAP8[$317 + 104 | 0] & 1) << 24 >> 24 == 0) {
      __label__ = 43;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 43:
    var $330 = $319 + 4 | 0;
    HEAP32[$318 >> 2] = $330;
    __label__ = 4;
    break;
   case 44:
    var $333 = HEAP32[$317 + 48 >> 2];
    __ZN10MatchFrame15extractBracketsEPKh($317, $333);
    var $334 = HEAP32[$1 >> 2];
    var $338 = HEAP8[HEAP32[$334 + 24 >> 2]] << 24 >> 24 == 61;
    var $340 = HEAP32[$334 + 92 >> 2];
    var $342 = HEAP32[$334 + 96 >> 2];
    var $343 = HEAP32[$17 >> 2];
    var $344 = HEAP32[$16 >> 2];
    __ZN10MatchFrame11saveOffsetsEiiPii($334, $340, $342, $343, $344);
    var $345 = HEAP32[$1 >> 2];
    if ($338) {
      __label__ = 45;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 45:
    var $349 = HEAP32[$345 + 24 >> 2] + 4 | 0;
    var $351 = HEAP32[$345 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $349, $351, 16);
    __label__ = 7;
    break;
   case 46:
    var $353 = HEAP32[$1 >> 2];
    var $355 = HEAP32[$353 + 92 >> 2];
    var $357 = HEAP32[$353 + 96 >> 2];
    var $358 = HEAP32[$17 >> 2];
    var $359 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($353, $355, $357, $358, $359);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $360 = HEAP32[$1 >> 2];
    var $362 = HEAP32[$360 + 48 >> 2];
    var $364 = HEAP32[$360 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $362, $364, 17);
    var $365 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($365, 1);
    __label__ = 7;
    break;
   case 47:
    var $368 = HEAP32[$345 + 92 >> 2];
    var $370 = HEAP32[$345 + 96 >> 2];
    var $371 = HEAP32[$17 >> 2];
    __ZN10MatchFrame14clobberOffsetsEiiPii(undef, $368, $370, $371, undef);
    __ZN10LinearFlag3setEv($minSatNextBracket);
    var $372 = HEAP32[$1 >> 2];
    var $374 = HEAP32[$372 + 48 >> 2];
    var $376 = HEAP32[$372 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $374, $376, 18);
    var $377 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($377, 1);
    __label__ = 7;
    break;
   case 48:
    var $379 = HEAP32[$1 >> 2];
    var $381 = HEAP32[$379 + 92 >> 2];
    var $383 = HEAP32[$379 + 96 >> 2];
    var $384 = HEAP32[$17 >> 2];
    var $385 = HEAP32[$16 >> 2];
    __ZN10MatchFrame14restoreOffsetsEiiPii($379, $381, $383, $384, $385);
    var $386 = HEAP32[$1 >> 2];
    var $389 = HEAP32[$386 + 24 >> 2] + 4 | 0;
    var $391 = HEAP32[$386 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $389, $391, 19);
    __label__ = 7;
    break;
   case 49:
    if ((HEAP32[$27 >> 2] | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 50;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 50:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 51:
    var $401 = HEAP32[$27 >> 2];
    if (($401 | 0) == (HEAP32[$18 >> 2] | 0)) {
      __label__ = 53;
      break;
    } else {
      __label__ = 52;
      break;
    }
   case 52:
    var $406 = HEAP16[$401 - 2 >> 1];
    var $407 = __ZL9isNewlinet($406);
    if ($407) {
      __label__ = 53;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 53:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 54:
    if (HEAPU32[$27 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 55:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 56:
    var $419 = HEAPU32[$27 >> 2];
    if ($419 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $423 = HEAP16[$419 >> 1];
    var $424 = __ZL9isNewlinet($423);
    if ($424) {
      __label__ = 58;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 58:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    __label__ = 4;
    break;
   case 59:
    var $429 = HEAPU32[$26 + 20 >> 2];
    if ($429 >>> 0 > HEAPU32[$18 >> 2] >>> 0) {
      __label__ = 60;
      break;
    } else {
      var $previousCharIsWordChar_0 = 0;
      __label__ = 61;
      break;
    }
   case 60:
    var $434 = HEAP16[$429 - 2 >> 1];
    var $435 = __ZL10isWordChart($434);
    var $previousCharIsWordChar_0 = $435;
    __label__ = 61;
    break;
   case 61:
    var $previousCharIsWordChar_0;
    if ($429 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 62;
      break;
    } else {
      var $currentCharIsWordChar_0 = 0;
      __label__ = 63;
      break;
    }
   case 62:
    var $439 = HEAP16[$429 >> 1];
    var $440 = __ZL10isWordChart($439);
    var $currentCharIsWordChar_0 = $440;
    __label__ = 63;
    break;
   case 63:
    var $currentCharIsWordChar_0;
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $tmp = $currentCharIsWordChar_0 ^ $previousCharIsWordChar_0;
    if (HEAP8[$29] << 24 >> 24 == 2) {
      __label__ = 64;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 64:
    if ($tmp) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 65:
    if ($tmp) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 66:
    var $448 = $27 | 0;
    var $449 = HEAPU32[$448 >> 2];
    if ($449 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 67;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 67:
    HEAP32[$448 >> 2] = $449 + 2 | 0;
    var $454 = HEAP16[$449 >> 1];
    var $455 = __ZL9isNewlinet($454);
    if ($455) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $458 = HEAP32[$1 >> 2] + 24 | 0;
    var $460 = HEAP32[$458 >> 2] + 1 | 0;
    HEAP32[$458 >> 2] = $460;
    __label__ = 4;
    break;
   case 69:
    var $462 = $27 | 0;
    var $463 = HEAPU32[$462 >> 2];
    if ($463 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 70:
    HEAP32[$462 >> 2] = $463 + 2 | 0;
    var $468 = HEAP16[$463 >> 1];
    var $469 = __ZN3WTF12isASCIIDigitEt($468);
    if ($469) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $472 = HEAP32[$1 >> 2] + 24 | 0;
    var $474 = HEAP32[$472 >> 2] + 1 | 0;
    HEAP32[$472 >> 2] = $474;
    __label__ = 4;
    break;
   case 72:
    var $476 = $27 | 0;
    var $477 = HEAPU32[$476 >> 2];
    if ($477 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 73;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 73:
    HEAP32[$476 >> 2] = $477 + 2 | 0;
    var $482 = HEAP16[$477 >> 1];
    var $483 = __ZN3WTF12isASCIIDigitEt($482);
    if ($483) {
      __label__ = 74;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 74:
    var $486 = HEAP32[$1 >> 2] + 24 | 0;
    var $488 = HEAP32[$486 >> 2] + 1 | 0;
    HEAP32[$486 >> 2] = $488;
    __label__ = 4;
    break;
   case 75:
    var $490 = $27 | 0;
    var $491 = HEAPU32[$490 >> 2];
    if ($491 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 76;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 76:
    HEAP32[$490 >> 2] = $491 + 2 | 0;
    var $496 = HEAP16[$491 >> 1];
    var $497 = __ZL11isSpaceChart($496);
    if ($497) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    var $500 = HEAP32[$1 >> 2] + 24 | 0;
    var $502 = HEAP32[$500 >> 2] + 1 | 0;
    HEAP32[$500 >> 2] = $502;
    __label__ = 4;
    break;
   case 78:
    var $504 = $27 | 0;
    var $505 = HEAPU32[$504 >> 2];
    if ($505 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 79;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 79:
    HEAP32[$504 >> 2] = $505 + 2 | 0;
    var $510 = HEAP16[$505 >> 1];
    var $511 = __ZL11isSpaceChart($510);
    if ($511) {
      __label__ = 80;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 80:
    var $514 = HEAP32[$1 >> 2] + 24 | 0;
    var $516 = HEAP32[$514 >> 2] + 1 | 0;
    HEAP32[$514 >> 2] = $516;
    __label__ = 4;
    break;
   case 81:
    var $518 = $27 | 0;
    var $519 = HEAPU32[$518 >> 2];
    if ($519 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 82;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 82:
    HEAP32[$518 >> 2] = $519 + 2 | 0;
    var $524 = HEAP16[$519 >> 1];
    var $525 = __ZL10isWordChart($524);
    if ($525) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $528 = HEAP32[$1 >> 2] + 24 | 0;
    var $530 = HEAP32[$528 >> 2] + 1 | 0;
    HEAP32[$528 >> 2] = $530;
    __label__ = 4;
    break;
   case 84:
    var $532 = $27 | 0;
    var $533 = HEAPU32[$532 >> 2];
    if ($533 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 85;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 85:
    HEAP32[$532 >> 2] = $533 + 2 | 0;
    var $538 = HEAP16[$533 >> 1];
    var $539 = __ZL10isWordChart($538);
    if ($539) {
      __label__ = 86;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 86:
    var $542 = HEAP32[$1 >> 2] + 24 | 0;
    var $544 = HEAP32[$542 >> 2] + 1 | 0;
    HEAP32[$542 >> 2] = $544;
    __label__ = 4;
    break;
   case 87:
    var $_val25 = HEAP8[$29 + 1 | 0];
    var $_idx26_val = HEAP8[$29 + 2 | 0];
    var $547 = __ZL13get2ByteValuePKh4462($_val25, $_idx26_val);
    HEAP32[$26 + 84 >> 2] = $547 << 1;
    var $551 = HEAP32[$1 >> 2] + 24 | 0;
    var $553 = HEAP32[$551 >> 2] + 3 | 0;
    HEAP32[$551 >> 2] = $553;
    var $554 = HEAP32[$1 >> 2];
    var $556 = HEAP32[$554 + 84 >> 2];
    if (($556 | 0) < (HEAP32[$554 + 28 >> 2] | 0)) {
      __label__ = 88;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 88:
    var $561 = HEAP32[$17 >> 2];
    var $563 = HEAP32[$561 + ($556 << 2) >> 2];
    if (($563 | 0) < 0) {
      __label__ = 89;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 89:
    var $566 = $554 + 72 | 0;
    HEAP32[$566 >> 2] = 0;
    __label__ = 91;
    break;
   case 90:
    var $571 = HEAP32[$561 + ($556 + 1 << 2) >> 2] - $563 | 0;
    var $572 = $554 + 72 | 0;
    HEAP32[$572 >> 2] = $571;
    __label__ = 91;
    break;
   case 91:
    var $574 = HEAPU32[$1 >> 2];
    var $575 = $574 + 24 | 0;
    var $576 = HEAPU32[$575 >> 2];
    var $577 = HEAPU8[$576];
    var $578 = $577 & 255;
    if (($578 | 0) == 46 || ($578 | 0) == 47 || ($578 | 0) == 48 || ($578 | 0) == 49 || ($578 | 0) == 50 || ($578 | 0) == 51) {
      __label__ = 92;
      break;
    } else if (($578 | 0) == 52 || ($578 | 0) == 53) {
      __label__ = 93;
      break;
    } else {
      __label__ = 96;
      break;
    }
   case 92:
    HEAP32[$575 >> 2] = $576 + 1 | 0;
    var $583 = (HEAPU8[$576] & 255) - 46 & 65535;
    var $585 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($583, $minimize, $min, $585);
    __label__ = 98;
    break;
   case 93:
    HEAP8[$minimize] = $577 << 24 >> 24 == 53 & 1;
    var $_val23 = HEAP8[$576 + 1 | 0];
    var $_idx24_val = HEAP8[$576 + 2 | 0];
    var $590 = __ZL13get2ByteValuePKh4462($_val23, $_idx24_val);
    HEAP32[$min >> 2] = $590;
    var $591 = HEAP32[$575 >> 2];
    var $_val21 = HEAP8[$591 + 3 | 0];
    var $_idx22_val = HEAP8[$591 + 4 | 0];
    var $593 = __ZL13get2ByteValuePKh4462($_val21, $_idx22_val);
    HEAP32[$574 + 76 >> 2] = $593;
    var $595 = HEAP32[$1 >> 2];
    var $596 = $595 + 76 | 0;
    if ((HEAP32[$596 >> 2] | 0) == 0) {
      __label__ = 94;
      break;
    } else {
      var $601 = $595;
      __label__ = 95;
      break;
    }
   case 94:
    HEAP32[$596 >> 2] = 2147483647;
    var $601 = HEAP32[$1 >> 2];
    __label__ = 95;
    break;
   case 95:
    var $601;
    var $602 = $601 + 24 | 0;
    var $604 = HEAP32[$602 >> 2] + 5 | 0;
    HEAP32[$602 >> 2] = $604;
    __label__ = 98;
    break;
   case 96:
    var $607 = HEAP32[$574 + 84 >> 2];
    var $608 = $574 + 20 | 0;
    var $609 = HEAP32[$608 >> 2];
    var $611 = HEAP32[$574 + 72 >> 2];
    var $612 = __ZL8matchRefiPKtiRK9MatchData($607, $609, $611, $md);
    if ($612) {
      __label__ = 97;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 97:
    var $614 = $609 + ($611 << 1) | 0;
    HEAP32[$608 >> 2] = $614;
    __label__ = 4;
    break;
   case 98:
    var $616 = HEAP32[$1 >> 2];
    if ((HEAP32[$616 + 72 >> 2] | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $i3_0 = 1;
      var $620 = $616;
      __label__ = 99;
      break;
    }
   case 99:
    var $620;
    var $i3_0;
    var $621 = HEAP32[$min >> 2];
    if (($i3_0 | 0) > ($621 | 0)) {
      __label__ = 102;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 100:
    var $625 = HEAP32[$620 + 84 >> 2];
    var $626 = $620 + 20 | 0;
    var $627 = HEAP32[$626 >> 2];
    var $629 = HEAP32[$620 + 72 >> 2];
    var $630 = __ZL8matchRefiPKtiRK9MatchData($625, $627, $629, $md);
    if ($630) {
      __label__ = 101;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 101:
    var $632 = $627 + ($629 << 1) | 0;
    HEAP32[$626 >> 2] = $632;
    var $i3_0 = $i3_0 + 1 | 0;
    var $620 = HEAP32[$1 >> 2];
    __label__ = 99;
    break;
   case 102:
    if (($621 | 0) == (HEAP32[$620 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 103;
      break;
    }
   case 103:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 109;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 104:
    HEAP32[$620 + 68 >> 2] = $621;
    __label__ = 105;
    break;
   case 105:
    var $645 = HEAP32[$1 >> 2];
    var $647 = HEAP32[$645 + 24 >> 2];
    var $649 = HEAP32[$645 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $647, $649, 20);
    __label__ = 7;
    break;
   case 106:
    var $651 = HEAP32[$1 >> 2];
    if ((HEAP32[$651 + 68 >> 2] | 0) < (HEAP32[$651 + 76 >> 2] | 0)) {
      __label__ = 107;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 107:
    var $659 = HEAP32[$651 + 84 >> 2];
    var $660 = $651 + 20 | 0;
    var $661 = HEAP32[$660 >> 2];
    var $663 = HEAP32[$651 + 72 >> 2];
    var $664 = __ZL8matchRefiPKtiRK9MatchData($659, $661, $663, $md);
    if ($664) {
      __label__ = 108;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 108:
    var $666 = $661 + ($663 << 1) | 0;
    HEAP32[$660 >> 2] = $666;
    var $668 = HEAP32[$1 >> 2] + 68 | 0;
    var $670 = HEAP32[$668 >> 2] + 1 | 0;
    HEAP32[$668 >> 2] = $670;
    __label__ = 105;
    break;
   case 109:
    var $673 = HEAP32[$620 + 20 >> 2];
    HEAP32[$620 + 44 >> 2] = $673;
    var $i4_0 = HEAP32[$min >> 2];
    __label__ = 110;
    break;
   case 110:
    var $i4_0;
    var $677 = HEAP32[$1 >> 2];
    if (($i4_0 | 0) < (HEAP32[$677 + 76 >> 2] | 0)) {
      __label__ = 111;
      break;
    } else {
      var $692 = $677;
      __label__ = 113;
      break;
    }
   case 111:
    var $683 = HEAP32[$677 + 84 >> 2];
    var $684 = $677 + 20 | 0;
    var $685 = HEAP32[$684 >> 2];
    var $687 = HEAP32[$677 + 72 >> 2];
    var $688 = __ZL8matchRefiPKtiRK9MatchData($683, $685, $687, $md);
    if ($688) {
      __label__ = 112;
      break;
    } else {
      var $692 = $677;
      __label__ = 113;
      break;
    }
   case 112:
    var $690 = $685 + ($687 << 1) | 0;
    HEAP32[$684 >> 2] = $690;
    var $i4_0 = $i4_0 + 1 | 0;
    __label__ = 110;
    break;
   case 113:
    var $692;
    if (HEAPU32[$692 + 20 >> 2] >>> 0 < HEAPU32[$692 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 114;
      break;
    }
   case 114:
    var $700 = HEAP32[$692 + 24 >> 2];
    var $702 = HEAP32[$692 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $700, $702, 21);
    __label__ = 7;
    break;
   case 115:
    var $704 = HEAP32[$1 >> 2];
    var $707 = $704 + 20 | 0;
    var $710 = HEAP32[$707 >> 2] + (-HEAP32[$704 + 72 >> 2] << 1) | 0;
    HEAP32[$707 >> 2] = $710;
    var $692 = HEAP32[$1 >> 2];
    __label__ = 113;
    break;
   case 116:
    HEAP32[$26 + 36 >> 2] = $29 + 1 | 0;
    var $715 = HEAP32[$1 >> 2] + 24 | 0;
    var $717 = HEAP32[$715 >> 2] + 33 | 0;
    HEAP32[$715 >> 2] = $717;
    var $718 = HEAPU32[$1 >> 2];
    var $719 = $718 + 24 | 0;
    var $720 = HEAPU32[$719 >> 2];
    var $721 = HEAPU8[$720];
    var $722 = $721 & 255;
    if (($722 | 0) == 46 || ($722 | 0) == 47 || ($722 | 0) == 48 || ($722 | 0) == 49 || ($722 | 0) == 50 || ($722 | 0) == 51) {
      __label__ = 117;
      break;
    } else if (($722 | 0) == 52 || ($722 | 0) == 53) {
      __label__ = 118;
      break;
    } else {
      __label__ = 121;
      break;
    }
   case 117:
    HEAP32[$719 >> 2] = $720 + 1 | 0;
    var $727 = (HEAPU8[$720] & 255) - 46 & 65535;
    var $729 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($727, $minimize, $min, $729);
    __label__ = 122;
    break;
   case 118:
    HEAP8[$minimize] = $721 << 24 >> 24 == 53 & 1;
    var $_val19 = HEAP8[$720 + 1 | 0];
    var $_idx20_val = HEAP8[$720 + 2 | 0];
    var $734 = __ZL13get2ByteValuePKh4462($_val19, $_idx20_val);
    HEAP32[$min >> 2] = $734;
    var $735 = HEAP32[$719 >> 2];
    var $_val17 = HEAP8[$735 + 3 | 0];
    var $_idx18_val = HEAP8[$735 + 4 | 0];
    var $737 = __ZL13get2ByteValuePKh4462($_val17, $_idx18_val);
    HEAP32[$718 + 76 >> 2] = $737;
    var $739 = HEAP32[$1 >> 2];
    var $740 = $739 + 76 | 0;
    if ((HEAP32[$740 >> 2] | 0) == 0) {
      __label__ = 119;
      break;
    } else {
      var $745 = $739;
      __label__ = 120;
      break;
    }
   case 119:
    HEAP32[$740 >> 2] = 2147483647;
    var $745 = HEAP32[$1 >> 2];
    __label__ = 120;
    break;
   case 120:
    var $745;
    var $746 = $745 + 24 | 0;
    var $748 = HEAP32[$746 >> 2] + 5 | 0;
    HEAP32[$746 >> 2] = $748;
    __label__ = 122;
    break;
   case 121:
    HEAP32[$718 + 76 >> 2] = 1;
    HEAP32[$min >> 2] = 1;
    __label__ = 122;
    break;
   case 122:
    var $i5_0 = 1;
    var $751 = HEAP32[$1 >> 2];
    __label__ = 123;
    break;
   case 123:
    var $751;
    var $i5_0;
    var $752 = HEAPU32[$min >> 2];
    if (($i5_0 | 0) > ($752 | 0)) {
      __label__ = 129;
      break;
    } else {
      __label__ = 124;
      break;
    }
   case 124:
    var $755 = $751 + 20 | 0;
    var $756 = HEAPU32[$755 >> 2];
    if ($756 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 125;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 125:
    HEAP32[$755 >> 2] = $756 + 2 | 0;
    var $761 = HEAPU16[$756 >> 1];
    var $762 = $761 & 65535;
    if (($761 & 65535) > 255) {
      __label__ = 126;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 126:
    var $765 = HEAPU32[$1 >> 2];
    if (HEAP8[HEAP32[$765 + 36 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $784 = $765;
      __label__ = 128;
      break;
    }
   case 127:
    var $773 = HEAPU32[$1 >> 2];
    if ((HEAPU8[HEAP32[$773 + 36 >> 2] + ($762 >>> 3) | 0] & 255 & 1 << ($762 & 7) | 0) == 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $784 = $773;
      __label__ = 128;
      break;
    }
   case 128:
    var $784;
    var $i5_0 = $i5_0 + 1 | 0;
    var $751 = $784;
    __label__ = 123;
    break;
   case 129:
    if (($752 | 0) == (HEAP32[$751 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 130;
      break;
    }
   case 130:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 139;
      break;
    } else {
      __label__ = 131;
      break;
    }
   case 131:
    HEAP32[$751 + 68 >> 2] = $752;
    __label__ = 132;
    break;
   case 132:
    var $797 = HEAP32[$1 >> 2];
    var $799 = HEAP32[$797 + 24 >> 2];
    var $801 = HEAP32[$797 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $799, $801, 22);
    __label__ = 7;
    break;
   case 133:
    var $803 = HEAP32[$1 >> 2];
    if ((HEAP32[$803 + 68 >> 2] | 0) < (HEAP32[$803 + 76 >> 2] | 0)) {
      __label__ = 134;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 134:
    var $810 = $803 + 20 | 0;
    var $811 = HEAPU32[$810 >> 2];
    if ($811 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 135;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 135:
    var $815 = $811 + 2 | 0;
    HEAP32[$810 >> 2] = $815;
    var $816 = HEAPU16[$811 >> 1];
    var $817 = $816 & 65535;
    if (($816 & 65535) > 255) {
      __label__ = 136;
      break;
    } else {
      __label__ = 137;
      break;
    }
   case 136:
    var $820 = HEAPU32[$1 >> 2];
    if (HEAP8[HEAP32[$820 + 36 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      var $839 = $820;
      __label__ = 138;
      break;
    }
   case 137:
    var $828 = HEAPU32[$1 >> 2];
    if ((HEAPU8[HEAP32[$828 + 36 >> 2] + ($817 >>> 3) | 0] & 255 & 1 << ($817 & 7) | 0) == 0) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      var $839 = $828;
      __label__ = 138;
      break;
    }
   case 138:
    var $839;
    var $840 = $839 + 68 | 0;
    var $842 = HEAP32[$840 >> 2] + 1 | 0;
    HEAP32[$840 >> 2] = $842;
    __label__ = 132;
    break;
   case 139:
    var $845 = HEAP32[$751 + 20 >> 2];
    HEAP32[$751 + 44 >> 2] = $845;
    var $i7_0 = HEAP32[$min >> 2];
    __label__ = 140;
    break;
   case 140:
    var $i7_0;
    var $849 = HEAPU32[$1 >> 2];
    var $850 = $849 + 36 | 0;
    if (($i7_0 | 0) < (HEAP32[$849 + 76 >> 2] | 0)) {
      __label__ = 141;
      break;
    } else {
      var $883 = $849;
      __label__ = 146;
      break;
    }
   case 141:
    var $855 = $849 + 20 | 0;
    var $856 = HEAPU32[$855 >> 2];
    if ($856 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 142;
      break;
    } else {
      var $883 = $849;
      __label__ = 146;
      break;
    }
   case 142:
    var $860 = HEAPU16[$856 >> 1];
    var $861 = $860 & 65535;
    if (($860 & 65535) > 255) {
      __label__ = 143;
      break;
    } else {
      __label__ = 144;
      break;
    }
   case 143:
    if (HEAP8[HEAP32[$850 >> 2] - 1 | 0] << 24 >> 24 == 54) {
      var $883 = $849;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 144:
    if ((HEAPU8[HEAP32[$850 >> 2] + ($861 >>> 3) | 0] & 255 & 1 << ($861 & 7) | 0) == 0) {
      var $883 = $849;
      __label__ = 146;
      break;
    } else {
      __label__ = 145;
      break;
    }
   case 145:
    HEAP32[$855 >> 2] = $856 + 2 | 0;
    var $i7_0 = $i7_0 + 1 | 0;
    __label__ = 140;
    break;
   case 146:
    var $883;
    var $885 = HEAP32[$883 + 24 >> 2];
    var $887 = HEAP32[$883 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $885, $887, 24);
    __label__ = 7;
    break;
   case 147:
    var $890 = HEAP32[$1 >> 2] + 20 | 0;
    var $891 = HEAP32[$890 >> 2];
    var $892 = $891 - 2 | 0;
    HEAP32[$890 >> 2] = $892;
    var $893 = HEAP32[$1 >> 2];
    if (($891 | 0) == (HEAP32[$893 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $883 = $893;
      __label__ = 146;
      break;
    }
   case 148:
    HEAP32[$26 + 36 >> 2] = $29 + 4 | 0;
    var $901 = HEAP32[$1 >> 2] + 24 | 0;
    var $902 = HEAP32[$901 >> 2];
    var $_val36 = HEAP8[$902 + 1 | 0];
    var $_idx37_val = HEAP8[$902 + 2 | 0];
    var $_idx38_val = HEAP8[$902 + 3 | 0];
    var $904 = __ZL12getLinkValuePKh4461($_val36, $_idx37_val, $_idx38_val);
    var $905 = $902 + $904 | 0;
    HEAP32[$901 >> 2] = $905;
    var $906 = HEAPU32[$1 >> 2];
    var $907 = $906 + 24 | 0;
    var $908 = HEAPU32[$907 >> 2];
    var $909 = HEAPU8[$908];
    var $910 = $909 & 255;
    if (($910 | 0) == 46 || ($910 | 0) == 47 || ($910 | 0) == 48 || ($910 | 0) == 49 || ($910 | 0) == 50 || ($910 | 0) == 51) {
      __label__ = 149;
      break;
    } else if (($910 | 0) == 52 || ($910 | 0) == 53) {
      __label__ = 150;
      break;
    } else {
      __label__ = 153;
      break;
    }
   case 149:
    HEAP32[$907 >> 2] = $908 + 1 | 0;
    var $915 = (HEAPU8[$908] & 255) - 46 & 65535;
    var $917 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($915, $minimize, $min, $917);
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 150:
    HEAP8[$minimize] = $909 << 24 >> 24 == 53 & 1;
    var $_val15 = HEAP8[$908 + 1 | 0];
    var $_idx16_val = HEAP8[$908 + 2 | 0];
    var $922 = __ZL13get2ByteValuePKh4462($_val15, $_idx16_val);
    HEAP32[$min >> 2] = $922;
    var $923 = HEAP32[$907 >> 2];
    var $_val13 = HEAP8[$923 + 3 | 0];
    var $_idx14_val = HEAP8[$923 + 4 | 0];
    var $925 = __ZL13get2ByteValuePKh4462($_val13, $_idx14_val);
    HEAP32[$906 + 76 >> 2] = $925;
    var $927 = HEAP32[$1 >> 2];
    var $928 = $927 + 76 | 0;
    if ((HEAP32[$928 >> 2] | 0) == 0) {
      __label__ = 151;
      break;
    } else {
      var $933 = $927;
      __label__ = 152;
      break;
    }
   case 151:
    HEAP32[$928 >> 2] = 2147483647;
    var $933 = HEAP32[$1 >> 2];
    __label__ = 152;
    break;
   case 152:
    var $933;
    var $934 = $933 + 24 | 0;
    var $936 = HEAP32[$934 >> 2] + 5 | 0;
    HEAP32[$934 >> 2] = $936;
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 153:
    HEAP32[$906 + 76 >> 2] = 1;
    HEAP32[$min >> 2] = 1;
    var $i9_0 = 1;
    __label__ = 154;
    break;
   case 154:
    var $i9_0;
    var $939 = HEAPU32[$min >> 2];
    var $941 = HEAPU32[$1 >> 2];
    if (($i9_0 | 0) > ($939 | 0)) {
      __label__ = 158;
      break;
    } else {
      __label__ = 155;
      break;
    }
   case 155:
    var $943 = $941 + 20 | 0;
    var $944 = HEAPU32[$943 >> 2];
    if ($944 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 156;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 156:
    HEAP32[$943 >> 2] = $944 + 2 | 0;
    var $950 = HEAPU16[$944 >> 1] & 65535;
    var $953 = HEAP32[HEAP32[$1 >> 2] + 36 >> 2];
    var $954 = __Z15jsc_pcre_xclassiPKh($950, $953);
    if ($954) {
      __label__ = 157;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 157:
    var $i9_0 = $i9_0 + 1 | 0;
    __label__ = 154;
    break;
   case 158:
    if (($939 | 0) == (HEAP32[$941 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 159;
      break;
    }
   case 159:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 166;
      break;
    } else {
      __label__ = 160;
      break;
    }
   case 160:
    HEAP32[$941 + 68 >> 2] = $939;
    __label__ = 161;
    break;
   case 161:
    var $968 = HEAP32[$1 >> 2];
    var $970 = HEAP32[$968 + 24 >> 2];
    var $972 = HEAP32[$968 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $970, $972, 26);
    __label__ = 7;
    break;
   case 162:
    var $974 = HEAP32[$1 >> 2];
    if ((HEAP32[$974 + 68 >> 2] | 0) < (HEAP32[$974 + 76 >> 2] | 0)) {
      __label__ = 163;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 163:
    var $981 = $974 + 20 | 0;
    var $982 = HEAPU32[$981 >> 2];
    if ($982 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 164;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 164:
    var $986 = $982 + 2 | 0;
    HEAP32[$981 >> 2] = $986;
    var $988 = HEAPU16[$982 >> 1] & 65535;
    var $991 = HEAP32[HEAP32[$1 >> 2] + 36 >> 2];
    var $992 = __Z15jsc_pcre_xclassiPKh($988, $991);
    if ($992) {
      __label__ = 165;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 165:
    var $995 = HEAP32[$1 >> 2] + 68 | 0;
    var $997 = HEAP32[$995 >> 2] + 1 | 0;
    HEAP32[$995 >> 2] = $997;
    __label__ = 161;
    break;
   case 166:
    var $1000 = HEAP32[$941 + 20 >> 2];
    HEAP32[$941 + 44 >> 2] = $1000;
    var $i12_0 = HEAP32[$min >> 2];
    __label__ = 167;
    break;
   case 167:
    var $i12_0;
    var $1004 = HEAPU32[$1 >> 2];
    if (($i12_0 | 0) < (HEAP32[$1004 + 76 >> 2] | 0)) {
      __label__ = 168;
      break;
    } else {
      var $1025 = $1004;
      __label__ = 171;
      break;
    }
   case 168:
    var $1010 = HEAPU32[$1004 + 20 >> 2];
    if ($1010 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 169;
      break;
    } else {
      var $1025 = $1004;
      __label__ = 171;
      break;
    }
   case 169:
    var $1015 = HEAPU16[$1010 >> 1] & 65535;
    var $1017 = HEAP32[$1004 + 36 >> 2];
    var $1018 = __Z15jsc_pcre_xclassiPKh($1015, $1017);
    var $1019 = HEAPU32[$1 >> 2];
    if ($1018) {
      __label__ = 170;
      break;
    } else {
      var $1025 = $1019;
      __label__ = 171;
      break;
    }
   case 170:
    var $1021 = $1019 + 20 | 0;
    var $1023 = HEAP32[$1021 >> 2] + 2 | 0;
    HEAP32[$1021 >> 2] = $1023;
    var $i12_0 = $i12_0 + 1 | 0;
    __label__ = 167;
    break;
   case 171:
    var $1025;
    var $1027 = HEAP32[$1025 + 24 >> 2];
    var $1029 = HEAP32[$1025 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1027, $1029, 27);
    __label__ = 7;
    break;
   case 172:
    var $1032 = HEAP32[$1 >> 2] + 20 | 0;
    var $1033 = HEAP32[$1032 >> 2];
    var $1034 = $1033 - 2 | 0;
    HEAP32[$1032 >> 2] = $1034;
    var $1035 = HEAP32[$1 >> 2];
    if (($1033 | 0) == (HEAP32[$1035 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1025 = $1035;
      __label__ = 171;
      break;
    }
   case 173:
    HEAP32[$26 + 72 >> 2] = 1;
    var $1042 = HEAP32[$1 >> 2] + 24 | 0;
    var $1044 = HEAP32[$1042 >> 2] + 1 | 0;
    HEAP32[$1042 >> 2] = $1044;
    var $1045 = HEAP32[$1 >> 2];
    var $1046 = $1045 + 64 | 0;
    var $1048 = HEAP32[$1045 + 24 >> 2];
    var $1049 = $1045 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1046, $1048, $1049);
    var $1050 = HEAP32[$1 >> 2];
    var $1053 = $1050 + 24 | 0;
    var $1055 = HEAP32[$1053 >> 2] + HEAP32[$1050 + 72 >> 2] | 0;
    HEAP32[$1053 >> 2] = $1055;
    var $1056 = HEAPU32[$1 >> 2];
    var $1057 = $1056 + 20 | 0;
    var $1058 = HEAPU32[$1057 >> 2];
    if ($1058 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 174;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 174:
    var $1063 = HEAP32[$1056 + 64 >> 2];
    HEAP32[$1057 >> 2] = $1058 + 2 | 0;
    if (($1063 | 0) == (HEAPU16[$1058 >> 1] & 65535 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 175:
    HEAP32[$26 + 72 >> 2] = 1;
    var $1071 = HEAP32[$1 >> 2] + 24 | 0;
    var $1073 = HEAP32[$1071 >> 2] + 1 | 0;
    HEAP32[$1071 >> 2] = $1073;
    var $1074 = HEAP32[$1 >> 2];
    var $1075 = $1074 + 64 | 0;
    var $1077 = HEAP32[$1074 + 24 >> 2];
    var $1078 = $1074 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1075, $1077, $1078);
    var $1079 = HEAP32[$1 >> 2];
    var $1082 = $1079 + 24 | 0;
    var $1084 = HEAP32[$1082 >> 2] + HEAP32[$1079 + 72 >> 2] | 0;
    HEAP32[$1082 >> 2] = $1084;
    var $1086 = HEAP32[$1 >> 2] + 20 | 0;
    var $1087 = HEAPU32[$1086 >> 2];
    if ($1087 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 176;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 176:
    var $1091 = $1087 + 2 | 0;
    HEAP32[$1086 >> 2] = $1091;
    var $1093 = HEAPU16[$1087 >> 1] & 65535;
    var $1096 = HEAPU32[HEAP32[$1 >> 2] + 64 >> 2];
    if (($1096 | 0) == ($1093 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 177;
      break;
    }
   case 177:
    var $1099 = __Z22jsc_pcre_ucp_othercasej($1096);
    if (($1099 | 0) == ($1093 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 178:
    var $1103 = $27 | 0;
    var $1104 = HEAPU32[$1103 >> 2];
    if ((HEAP32[$20 >> 2] | 0) == ($1104 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 179;
      break;
    }
   case 179:
    if ((HEAPU16[$1104 >> 1] & 65535 | 0) == (HEAPU8[$29 + 1 | 0] & 255 | 0)) {
      __label__ = 180;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 180:
    HEAP32[$1103 >> 2] = $1104 + 2 | 0;
    var $1116 = HEAP32[$1 >> 2] + 24 | 0;
    var $1118 = HEAP32[$1116 >> 2] + 2 | 0;
    HEAP32[$1116 >> 2] = $1118;
    __label__ = 4;
    break;
   case 181:
    var $1121 = $27 | 0;
    var $1122 = HEAPU32[$1121 >> 2];
    if ((HEAP32[$20 >> 2] | 0) == ($1122 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 182;
      break;
    }
   case 182:
    if ((HEAPU16[$1122 >> 1] & 65535 | 32 | 0) == (HEAPU8[$29 + 1 | 0] & 255 | 0)) {
      __label__ = 183;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 183:
    HEAP32[$1121 >> 2] = $1122 + 2 | 0;
    var $1135 = HEAP32[$1 >> 2] + 24 | 0;
    var $1137 = HEAP32[$1135 >> 2] + 2 | 0;
    HEAP32[$1135 >> 2] = $1137;
    __label__ = 4;
    break;
   case 184:
    var $_val11 = HEAP8[$29 + 1 | 0];
    var $_idx12_val = HEAP8[$29 + 2 | 0];
    var $1140 = __ZL13get2ByteValuePKh4462($_val11, $_idx12_val);
    HEAP32[$26 + 76 >> 2] = $1140;
    HEAP32[$min >> 2] = $1140;
    HEAP8[$minimize] = 0;
    var $1143 = HEAP32[$1 >> 2] + 24 | 0;
    var $1145 = HEAP32[$1143 >> 2] + 3 | 0;
    HEAP32[$1143 >> 2] = $1145;
    __label__ = 187;
    break;
   case 185:
    HEAP32[$min >> 2] = 0;
    var $1147 = HEAP32[$28 >> 2];
    var $_val9 = HEAP8[$1147 + 1 | 0];
    var $_idx10_val = HEAP8[$1147 + 2 | 0];
    var $1149 = __ZL13get2ByteValuePKh4462($_val9, $_idx10_val);
    HEAP32[$26 + 76 >> 2] = $1149;
    var $1152 = HEAP32[$1 >> 2] + 24 | 0;
    var $1153 = HEAPU32[$1152 >> 2];
    var $1156 = HEAP8[$1153] << 24 >> 24 == 26 & 1;
    HEAP8[$minimize] = $1156;
    var $1157 = $1153 + 3 | 0;
    HEAP32[$1152 >> 2] = $1157;
    __label__ = 187;
    break;
   case 186:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1162 = (HEAPU8[$29] & 255) - 19 & 65535;
    var $1164 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1162, $minimize, $min, $1164);
    __label__ = 187;
    break;
   case 187:
    var $1167 = HEAP32[$1 >> 2] + 72 | 0;
    HEAP32[$1167 >> 2] = 1;
    var $1168 = HEAP32[$1 >> 2];
    var $1169 = $1168 + 64 | 0;
    var $1171 = HEAP32[$1168 + 24 >> 2];
    var $1172 = $1168 + 72 | 0;
    __ZL29getUTF8CharAndIncrementLengthRiPKhS_($1169, $1171, $1172);
    var $1174 = HEAPU32[$1 >> 2];
    var $1178 = (HEAP32[$1174 + 64 >> 2] | 0) > 65535 ? 2 : 1;
    if (($1178 * HEAP32[$min >> 2] | 0) > (HEAP32[$20 >> 2] - HEAP32[$1174 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 188;
      break;
    }
   case 188:
    var $1191 = $1174 + 24 | 0;
    var $1193 = HEAP32[$1191 >> 2] + HEAP32[$1174 + 72 >> 2] | 0;
    HEAP32[$1191 >> 2] = $1193;
    var $1194 = HEAPU32[$1 >> 2];
    var $1196 = HEAP32[$1194 + 64 >> 2];
    if (($1196 | 0) < 65536) {
      __label__ = 189;
      break;
    } else {
      var $i16_0 = 1;
      var $1310 = $1194;
      __label__ = 212;
      break;
    }
   case 189:
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      var $1205 = -1;
      __label__ = 191;
      break;
    } else {
      __label__ = 190;
      break;
    }
   case 190:
    var $1203 = __Z22jsc_pcre_ucp_othercasej($1196);
    var $1205 = $1203;
    __label__ = 191;
    break;
   case 191:
    var $1205;
    var $i14_0 = 1;
    var $1207 = $1194;
    __label__ = 192;
    break;
   case 192:
    var $1207;
    var $i14_0;
    var $1208 = HEAPU32[$min >> 2];
    if (($i14_0 | 0) > ($1208 | 0)) {
      __label__ = 195;
      break;
    } else {
      __label__ = 193;
      break;
    }
   case 193:
    var $1211 = $1207 + 20 | 0;
    var $1212 = HEAPU32[$1211 >> 2];
    var $1214 = HEAPU16[$1212 >> 1] & 65535;
    if (($1214 | 0) == (HEAP32[$1207 + 64 >> 2] | 0) | ($1214 | 0) == ($1205 | 0)) {
      __label__ = 194;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 194:
    HEAP32[$1211 >> 2] = $1212 + 2 | 0;
    var $i14_0 = $i14_0 + 1 | 0;
    var $1207 = HEAP32[$1 >> 2];
    __label__ = 192;
    break;
   case 195:
    if (($1208 | 0) == (HEAP32[$1207 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 196;
      break;
    }
   case 196:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 204;
      break;
    } else {
      __label__ = 197;
      break;
    }
   case 197:
    HEAP32[$1207 + 52 >> 2] = $1205;
    var $1232 = HEAP32[$min >> 2];
    var $1234 = HEAP32[$1 >> 2] + 68 | 0;
    HEAP32[$1234 >> 2] = $1232;
    __label__ = 198;
    break;
   case 198:
    var $1236 = HEAP32[$1 >> 2];
    var $1238 = HEAP32[$1236 + 24 >> 2];
    var $1240 = HEAP32[$1236 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1238, $1240, 28);
    __label__ = 7;
    break;
   case 199:
    var $1242 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1242 + 68 >> 2] | 0) < (HEAP32[$1242 + 76 >> 2] | 0)) {
      __label__ = 200;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 200:
    var $1249 = $1242 + 20 | 0;
    var $1250 = HEAPU32[$1249 >> 2];
    if ($1250 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 201;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 201:
    var $1255 = HEAPU16[$1250 >> 1] & 65535;
    if (($1255 | 0) == (HEAP32[$1242 + 64 >> 2] | 0)) {
      __label__ = 203;
      break;
    } else {
      __label__ = 202;
      break;
    }
   case 202:
    if (($1255 | 0) == (HEAP32[$1242 + 52 >> 2] | 0)) {
      __label__ = 203;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 203:
    HEAP32[$1249 >> 2] = $1250 + 2 | 0;
    var $1266 = HEAP32[$1 >> 2] + 68 | 0;
    var $1268 = HEAP32[$1266 >> 2] + 1 | 0;
    HEAP32[$1266 >> 2] = $1268;
    __label__ = 198;
    break;
   case 204:
    var $1271 = HEAP32[$1207 + 20 >> 2];
    HEAP32[$1207 + 44 >> 2] = $1271;
    var $i15_0 = HEAP32[$min >> 2];
    __label__ = 205;
    break;
   case 205:
    var $i15_0;
    var $1275 = HEAPU32[$1 >> 2];
    if (($i15_0 | 0) < (HEAP32[$1275 + 76 >> 2] | 0)) {
      __label__ = 206;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 206:
    var $1280 = $1275 + 20 | 0;
    var $1281 = HEAPU32[$1280 >> 2];
    if ($1281 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 207;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 207:
    var $1286 = HEAPU16[$1281 >> 1] & 65535;
    if (($1286 | 0) == (HEAP32[$1275 + 64 >> 2] | 0) | ($1286 | 0) == ($1205 | 0)) {
      __label__ = 208;
      break;
    } else {
      var $1294 = $1275;
      __label__ = 209;
      break;
    }
   case 208:
    HEAP32[$1280 >> 2] = $1281 + 2 | 0;
    var $i15_0 = $i15_0 + 1 | 0;
    __label__ = 205;
    break;
   case 209:
    var $1294;
    if (HEAPU32[$1294 + 20 >> 2] >>> 0 < HEAPU32[$1294 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 210;
      break;
    }
   case 210:
    var $1302 = HEAP32[$1294 + 24 >> 2];
    var $1304 = HEAP32[$1294 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1302, $1304, 29);
    __label__ = 7;
    break;
   case 211:
    var $1307 = HEAP32[$1 >> 2] + 20 | 0;
    var $1309 = HEAP32[$1307 >> 2] - 2 | 0;
    HEAP32[$1307 >> 2] = $1309;
    var $1294 = HEAP32[$1 >> 2];
    __label__ = 209;
    break;
   case 212:
    var $1310;
    var $i16_0;
    var $1311 = HEAPU32[$min >> 2];
    if (($i16_0 | 0) > ($1311 | 0)) {
      __label__ = 215;
      break;
    } else {
      __label__ = 213;
      break;
    }
   case 213:
    var $1314 = $1310 + 20 | 0;
    var $1315 = HEAPU32[$1314 >> 2];
    if ((HEAPU16[$1315 >> 1] & 65535 | 0) == (HEAP32[$1310 + 64 >> 2] | 0)) {
      __label__ = 214;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 214:
    HEAP32[$1314 >> 2] = $1315 + 4 | 0;
    var $i16_0 = $i16_0 + 1 | 0;
    var $1310 = HEAP32[$1 >> 2];
    __label__ = 212;
    break;
   case 215:
    if (($1311 | 0) == (HEAP32[$1310 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 216;
      break;
    }
   case 216:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 223;
      break;
    } else {
      __label__ = 217;
      break;
    }
   case 217:
    HEAP32[$1310 + 68 >> 2] = $1311;
    __label__ = 218;
    break;
   case 218:
    var $1335 = HEAP32[$1 >> 2];
    var $1337 = HEAP32[$1335 + 24 >> 2];
    var $1339 = HEAP32[$1335 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1337, $1339, 30);
    __label__ = 7;
    break;
   case 219:
    var $1341 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1341 + 68 >> 2] | 0) < (HEAP32[$1341 + 76 >> 2] | 0)) {
      __label__ = 220;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 220:
    var $1348 = $1341 + 20 | 0;
    var $1349 = HEAPU32[$1348 >> 2];
    if ($1349 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 221;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 221:
    if ((HEAPU16[$1349 >> 1] & 65535 | 0) == (HEAP32[$1341 + 64 >> 2] | 0)) {
      __label__ = 222;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 222:
    HEAP32[$1348 >> 2] = $1349 + 4 | 0;
    var $1361 = HEAP32[$1 >> 2] + 68 | 0;
    var $1363 = HEAP32[$1361 >> 2] + 1 | 0;
    HEAP32[$1361 >> 2] = $1363;
    __label__ = 218;
    break;
   case 223:
    var $1366 = HEAP32[$1310 + 20 >> 2];
    HEAP32[$1310 + 44 >> 2] = $1366;
    var $i17_0 = HEAP32[$min >> 2];
    __label__ = 224;
    break;
   case 224:
    var $i17_0;
    var $1370 = HEAPU32[$1 >> 2];
    if (($i17_0 | 0) < (HEAP32[$1370 + 76 >> 2] | 0)) {
      __label__ = 225;
      break;
    } else {
      var $1389 = $1370;
      __label__ = 228;
      break;
    }
   case 225:
    var $1375 = $1370 + 20 | 0;
    var $1376 = HEAPU32[$1375 >> 2];
    if ($1376 >>> 0 > (HEAP32[$20 >> 2] - 4 | 0) >>> 0) {
      var $1389 = $1370;
      __label__ = 228;
      break;
    } else {
      __label__ = 226;
      break;
    }
   case 226:
    if ((HEAPU16[$1376 >> 1] & 65535 | 0) == (HEAP32[$1370 + 64 >> 2] | 0)) {
      __label__ = 227;
      break;
    } else {
      var $1389 = $1370;
      __label__ = 228;
      break;
    }
   case 227:
    HEAP32[$1375 >> 2] = $1376 + 4 | 0;
    var $i17_0 = $i17_0 + 1 | 0;
    __label__ = 224;
    break;
   case 228:
    var $1389;
    if (HEAPU32[$1389 + 20 >> 2] >>> 0 < HEAPU32[$1389 + 44 >> 2] >>> 0) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 229;
      break;
    }
   case 229:
    var $1397 = HEAP32[$1389 + 24 >> 2];
    var $1399 = HEAP32[$1389 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1397, $1399, 31);
    __label__ = 7;
    break;
   case 230:
    var $1402 = HEAP32[$1 >> 2] + 20 | 0;
    var $1404 = HEAP32[$1402 >> 2] - 4 | 0;
    HEAP32[$1402 >> 2] = $1404;
    var $1389 = HEAP32[$1 >> 2];
    __label__ = 228;
    break;
   case 231:
    var $1406 = $27 | 0;
    var $1407 = HEAPU32[$1406 >> 2];
    if ($1407 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 232;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 232:
    var $1412 = HEAPU8[$29 + 1 | 0];
    HEAP32[$1406 >> 2] = $1407 + 2 | 0;
    var $1414 = HEAPU16[$1407 >> 1];
    var $1415 = $1414 & 65535;
    var $1417 = HEAP32[$1 >> 2] + 24 | 0;
    var $1419 = HEAP32[$1417 >> 2] + 2 | 0;
    HEAP32[$1417 >> 2] = $1419;
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      __label__ = 236;
      break;
    } else {
      __label__ = 233;
      break;
    }
   case 233:
    if (($1414 & 65535) < 128) {
      __label__ = 234;
      break;
    } else {
      var $c18_0 = $1415;
      __label__ = 235;
      break;
    }
   case 234:
    var $1426 = $1414 & 255;
    var $1427 = __ZL11toLowerCaseh($1426);
    var $c18_0 = $1427 & 255;
    __label__ = 235;
    break;
   case 235:
    var $c18_0;
    var $1430 = __ZL11toLowerCaseh($1412);
    if (($1430 & 255 | 0) == ($c18_0 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 236:
    if (($1412 & 255 | 0) == ($1415 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 237:
    var $_val7 = HEAP8[$29 + 1 | 0];
    var $_idx8_val = HEAP8[$29 + 2 | 0];
    var $1438 = __ZL13get2ByteValuePKh4462($_val7, $_idx8_val);
    HEAP32[$26 + 76 >> 2] = $1438;
    HEAP32[$min >> 2] = $1438;
    HEAP8[$minimize] = 0;
    var $1441 = HEAP32[$1 >> 2] + 24 | 0;
    var $1443 = HEAP32[$1441 >> 2] + 3 | 0;
    HEAP32[$1441 >> 2] = $1443;
    __label__ = 240;
    break;
   case 238:
    HEAP32[$min >> 2] = 0;
    var $1445 = HEAP32[$28 >> 2];
    var $_val5 = HEAP8[$1445 + 1 | 0];
    var $_idx6_val = HEAP8[$1445 + 2 | 0];
    var $1447 = __ZL13get2ByteValuePKh4462($_val5, $_idx6_val);
    HEAP32[$26 + 76 >> 2] = $1447;
    var $1450 = HEAP32[$1 >> 2] + 24 | 0;
    var $1451 = HEAPU32[$1450 >> 2];
    var $1454 = HEAP8[$1451] << 24 >> 24 == 35 & 1;
    HEAP8[$minimize] = $1454;
    var $1455 = $1451 + 3 | 0;
    HEAP32[$1450 >> 2] = $1455;
    __label__ = 240;
    break;
   case 239:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1460 = (HEAPU8[$29] & 255) - 28 & 65535;
    var $1462 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1460, $minimize, $min, $1462);
    __label__ = 240;
    break;
   case 240:
    var $1466 = HEAPU32[$1 >> 2];
    if ((HEAP32[$min >> 2] | 0) > (HEAP32[$20 >> 2] - HEAP32[$1466 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 241;
      break;
    }
   case 241:
    var $1475 = $1466 + 24 | 0;
    var $1476 = HEAP32[$1475 >> 2];
    var $1477 = $1476 + 1 | 0;
    HEAP32[$1475 >> 2] = $1477;
    var $1479 = HEAPU8[$1476] & 255;
    var $1481 = HEAP32[$1 >> 2] + 64 | 0;
    HEAP32[$1481 >> 2] = $1479;
    var $_pre112 = HEAPU32[$1 >> 2];
    if ((HEAP8[$21] & 1) << 24 >> 24 == 0) {
      var $i23_0 = 1;
      var $1604 = $_pre112;
      __label__ = 268;
      break;
    } else {
      __label__ = 242;
      break;
    }
   case 242:
    var $1486 = $_pre112 + 64 | 0;
    var $1487 = HEAP32[$1486 >> 2];
    if (($1487 | 0) < 128) {
      __label__ = 243;
      break;
    } else {
      var $i19_0 = 1;
      var $1493 = $_pre112;
      __label__ = 244;
      break;
    }
   case 243:
    var $1490 = $1487 & 255;
    var $1491 = __ZL11toLowerCaseh($1490);
    var $1492 = $1491 & 255;
    HEAP32[$1486 >> 2] = $1492;
    var $i19_0 = 1;
    var $1493 = HEAP32[$1 >> 2];
    __label__ = 244;
    break;
   case 244:
    var $1493;
    var $i19_0;
    var $1494 = HEAPU32[$min >> 2];
    if (($i19_0 | 0) > ($1494 | 0)) {
      __label__ = 249;
      break;
    } else {
      __label__ = 245;
      break;
    }
   case 245:
    var $1497 = $1493 + 20 | 0;
    var $1498 = HEAP32[$1497 >> 2];
    var $1499 = $1498 + 2 | 0;
    HEAP32[$1497 >> 2] = $1499;
    var $1500 = HEAPU16[$1498 >> 1];
    var $1501 = $1500 & 65535;
    if (($1500 & 65535) < 128) {
      __label__ = 246;
      break;
    } else {
      var $d_0 = $1501;
      __label__ = 247;
      break;
    }
   case 246:
    var $1504 = $1500 & 255;
    var $1505 = __ZL11toLowerCaseh($1504);
    var $d_0 = $1505 & 255;
    __label__ = 247;
    break;
   case 247:
    var $d_0;
    var $1508 = HEAPU32[$1 >> 2];
    if ((HEAP32[$1508 + 64 >> 2] | 0) == ($d_0 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 248;
      break;
    }
   case 248:
    var $i19_0 = $i19_0 + 1 | 0;
    var $1493 = $1508;
    __label__ = 244;
    break;
   case 249:
    if (($1494 | 0) == (HEAP32[$1493 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 250;
      break;
    }
   case 250:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 259;
      break;
    } else {
      __label__ = 251;
      break;
    }
   case 251:
    HEAP32[$1493 + 68 >> 2] = $1494;
    __label__ = 252;
    break;
   case 252:
    var $1525 = HEAP32[$1 >> 2];
    var $1527 = HEAP32[$1525 + 24 >> 2];
    var $1529 = HEAP32[$1525 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1527, $1529, 38);
    __label__ = 7;
    break;
   case 253:
    var $1532 = HEAP32[$1 >> 2] + 20 | 0;
    var $1533 = HEAP32[$1532 >> 2];
    var $1534 = $1533 + 2 | 0;
    HEAP32[$1532 >> 2] = $1534;
    var $1535 = HEAPU16[$1533 >> 1];
    var $1536 = $1535 & 65535;
    if (($1535 & 65535) < 128) {
      __label__ = 254;
      break;
    } else {
      var $d20_0 = $1536;
      __label__ = 255;
      break;
    }
   case 254:
    var $1539 = $1535 & 255;
    var $1540 = __ZL11toLowerCaseh($1539);
    var $d20_0 = $1540 & 255;
    __label__ = 255;
    break;
   case 255:
    var $d20_0;
    var $1543 = HEAPU32[$1 >> 2];
    var $1544 = $1543 + 68 | 0;
    var $1545 = HEAPU32[$1544 >> 2];
    if (($1545 | 0) < (HEAP32[$1543 + 76 >> 2] | 0)) {
      __label__ = 256;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 256:
    if (HEAPU32[$1543 + 20 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 257;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 257:
    if ((HEAP32[$1543 + 64 >> 2] | 0) == ($d20_0 | 0)) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 258;
      break;
    }
   case 258:
    HEAP32[$1544 >> 2] = $1545 + 1 | 0;
    __label__ = 252;
    break;
   case 259:
    var $1562 = HEAP32[$1493 + 20 >> 2];
    HEAP32[$1493 + 44 >> 2] = $1562;
    var $i21_0 = HEAP32[$min >> 2];
    __label__ = 260;
    break;
   case 260:
    var $i21_0;
    var $1566 = HEAPU32[$1 >> 2];
    if (($i21_0 | 0) < (HEAP32[$1566 + 76 >> 2] | 0)) {
      __label__ = 261;
      break;
    } else {
      var $1590 = $1566;
      __label__ = 266;
      break;
    }
   case 261:
    var $1571 = $1566 + 20 | 0;
    var $1572 = HEAPU32[$1571 >> 2];
    if ($1572 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 262;
      break;
    } else {
      var $1590 = $1566;
      __label__ = 266;
      break;
    }
   case 262:
    var $1576 = HEAPU16[$1572 >> 1];
    var $1577 = $1576 & 65535;
    if (($1576 & 65535) < 128) {
      __label__ = 263;
      break;
    } else {
      var $d22_0 = $1577;
      __label__ = 264;
      break;
    }
   case 263:
    var $1580 = $1576 & 255;
    var $1581 = __ZL11toLowerCaseh($1580);
    var $d22_0 = $1581 & 255;
    __label__ = 264;
    break;
   case 264:
    var $d22_0;
    if ((HEAP32[$1566 + 64 >> 2] | 0) == ($d22_0 | 0)) {
      var $1590 = $1566;
      __label__ = 266;
      break;
    } else {
      __label__ = 265;
      break;
    }
   case 265:
    HEAP32[$1571 >> 2] = $1572 + 2 | 0;
    var $i21_0 = $i21_0 + 1 | 0;
    __label__ = 260;
    break;
   case 266:
    var $1590;
    var $1592 = HEAP32[$1590 + 24 >> 2];
    var $1594 = HEAP32[$1590 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1592, $1594, 40);
    __label__ = 7;
    break;
   case 267:
    var $1597 = HEAP32[$1 >> 2] + 20 | 0;
    var $1598 = HEAP32[$1597 >> 2];
    var $1599 = $1598 - 2 | 0;
    HEAP32[$1597 >> 2] = $1599;
    var $1600 = HEAP32[$1 >> 2];
    if (($1598 | 0) == (HEAP32[$1600 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1590 = $1600;
      __label__ = 266;
      break;
    }
   case 268:
    var $1604;
    var $i23_0;
    var $1605 = HEAPU32[$min >> 2];
    if (($i23_0 | 0) > ($1605 | 0)) {
      __label__ = 271;
      break;
    } else {
      __label__ = 269;
      break;
    }
   case 269:
    var $1608 = $1604 + 20 | 0;
    var $1609 = HEAP32[$1608 >> 2];
    var $1610 = $1609 + 2 | 0;
    HEAP32[$1608 >> 2] = $1610;
    var $1613 = HEAP32[$1 >> 2];
    if ((HEAP32[$1613 + 64 >> 2] | 0) == (HEAPU16[$1609 >> 1] & 65535 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 270;
      break;
    }
   case 270:
    var $i23_0 = $i23_0 + 1 | 0;
    var $1604 = $1613;
    __label__ = 268;
    break;
   case 271:
    if (($1605 | 0) == (HEAP32[$1604 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 272;
      break;
    }
   case 272:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 279;
      break;
    } else {
      __label__ = 273;
      break;
    }
   case 273:
    HEAP32[$1604 + 68 >> 2] = $1605;
    __label__ = 274;
    break;
   case 274:
    var $1630 = HEAP32[$1 >> 2];
    var $1632 = HEAP32[$1630 + 24 >> 2];
    var $1634 = HEAP32[$1630 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1632, $1634, 42);
    __label__ = 7;
    break;
   case 275:
    var $1637 = HEAP32[$1 >> 2] + 20 | 0;
    var $1638 = HEAP32[$1637 >> 2];
    var $1639 = $1638 + 2 | 0;
    HEAP32[$1637 >> 2] = $1639;
    var $1641 = HEAPU16[$1638 >> 1] & 65535;
    var $1642 = HEAPU32[$1 >> 2];
    var $1643 = $1642 + 68 | 0;
    var $1644 = HEAPU32[$1643 >> 2];
    if (($1644 | 0) < (HEAP32[$1642 + 76 >> 2] | 0)) {
      __label__ = 276;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 276:
    if (HEAPU32[$1642 + 20 >> 2] >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 277;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 277:
    if ((HEAP32[$1642 + 64 >> 2] | 0) == ($1641 | 0)) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 278;
      break;
    }
   case 278:
    HEAP32[$1643 >> 2] = $1644 + 1 | 0;
    __label__ = 274;
    break;
   case 279:
    var $1661 = HEAP32[$1604 + 20 >> 2];
    HEAP32[$1604 + 44 >> 2] = $1661;
    var $i26_0 = HEAP32[$min >> 2];
    __label__ = 280;
    break;
   case 280:
    var $i26_0;
    var $1665 = HEAPU32[$1 >> 2];
    if (($i26_0 | 0) < (HEAP32[$1665 + 76 >> 2] | 0)) {
      __label__ = 281;
      break;
    } else {
      var $1683 = $1665;
      __label__ = 284;
      break;
    }
   case 281:
    var $1670 = $1665 + 20 | 0;
    var $1671 = HEAPU32[$1670 >> 2];
    if ($1671 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 282;
      break;
    } else {
      var $1683 = $1665;
      __label__ = 284;
      break;
    }
   case 282:
    if ((HEAP32[$1665 + 64 >> 2] | 0) == (HEAPU16[$1671 >> 1] & 65535 | 0)) {
      var $1683 = $1665;
      __label__ = 284;
      break;
    } else {
      __label__ = 283;
      break;
    }
   case 283:
    HEAP32[$1670 >> 2] = $1671 + 2 | 0;
    var $i26_0 = $i26_0 + 1 | 0;
    __label__ = 280;
    break;
   case 284:
    var $1683;
    var $1685 = HEAP32[$1683 + 24 >> 2];
    var $1687 = HEAP32[$1683 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1685, $1687, 44);
    __label__ = 7;
    break;
   case 285:
    var $1690 = HEAP32[$1 >> 2] + 20 | 0;
    var $1691 = HEAP32[$1690 >> 2];
    var $1692 = $1691 - 2 | 0;
    HEAP32[$1690 >> 2] = $1692;
    var $1693 = HEAP32[$1 >> 2];
    if (($1691 | 0) == (HEAP32[$1693 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $1683 = $1693;
      __label__ = 284;
      break;
    }
   case 286:
    var $_val3 = HEAP8[$29 + 1 | 0];
    var $_idx4_val = HEAP8[$29 + 2 | 0];
    var $1699 = __ZL13get2ByteValuePKh4462($_val3, $_idx4_val);
    HEAP32[$26 + 76 >> 2] = $1699;
    HEAP32[$min >> 2] = $1699;
    HEAP8[$minimize] = 1;
    var $1702 = HEAP32[$1 >> 2] + 24 | 0;
    var $1704 = HEAP32[$1702 >> 2] + 3 | 0;
    HEAP32[$1702 >> 2] = $1704;
    __label__ = 289;
    break;
   case 287:
    HEAP32[$min >> 2] = 0;
    var $1706 = HEAP32[$28 >> 2];
    var $_val1 = HEAP8[$1706 + 1 | 0];
    var $_idx2_val = HEAP8[$1706 + 2 | 0];
    var $1708 = __ZL13get2ByteValuePKh4462($_val1, $_idx2_val);
    HEAP32[$26 + 76 >> 2] = $1708;
    var $1711 = HEAP32[$1 >> 2] + 24 | 0;
    var $1712 = HEAPU32[$1711 >> 2];
    var $1715 = HEAP8[$1712] << 24 >> 24 == 44 & 1;
    HEAP8[$minimize] = $1715;
    var $1716 = $1712 + 3 | 0;
    HEAP32[$1711 >> 2] = $1716;
    __label__ = 289;
    break;
   case 288:
    HEAP32[$28 >> 2] = $29 + 1 | 0;
    var $1721 = (HEAPU8[$29] & 255) - 37 & 65535;
    var $1723 = HEAP32[$1 >> 2] + 76 | 0;
    __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($1721, $minimize, $min, $1723);
    __label__ = 289;
    break;
   case 289:
    var $1726 = HEAP32[$1 >> 2] + 24 | 0;
    var $1727 = HEAP32[$1726 >> 2];
    var $1728 = $1727 + 1 | 0;
    HEAP32[$1726 >> 2] = $1728;
    var $1730 = HEAPU8[$1727] & 255;
    var $1732 = HEAP32[$1 >> 2] + 60 | 0;
    HEAP32[$1732 >> 2] = $1730;
    var $1733 = HEAPU32[$min >> 2];
    var $1735 = HEAPU32[$1 >> 2];
    if (($1733 | 0) > (HEAP32[$20 >> 2] - HEAP32[$1735 + 20 >> 2] >> 1 | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 290;
      break;
    }
   case 290:
    if (($1733 | 0) > 0) {
      __label__ = 291;
      break;
    } else {
      var $1827 = $1733;
      __label__ = 314;
      break;
    }
   case 291:
    var $1747 = HEAP32[$1735 + 60 >> 2];
    if (($1747 | 0) == 9) {
      var $i28_0 = 1;
      var $1748 = $1733;
      __label__ = 292;
      break;
    } else if (($1747 | 0) == 3) {
      var $i29_0 = 1;
      var $1759 = $1733;
      __label__ = 295;
      break;
    } else if (($1747 | 0) == 4) {
      var $i30_0 = 1;
      var $1770 = $1733;
      __label__ = 298;
      break;
    } else if (($1747 | 0) == 5) {
      var $i31_0 = 1;
      var $1781 = $1733;
      __label__ = 301;
      break;
    } else if (($1747 | 0) == 6) {
      var $i32_0 = 1;
      var $1792 = $1733;
      __label__ = 304;
      break;
    } else if (($1747 | 0) == 7) {
      var $i33_0 = 1;
      var $1803 = $1733;
      __label__ = 307;
      break;
    } else if (($1747 | 0) == 8) {
      var $i34_0 = 1;
      var $1814 = $1733;
      __label__ = 310;
      break;
    } else {
      __label__ = 313;
      break;
    }
   case 292:
    var $1748;
    var $i28_0;
    if (($i28_0 | 0) > ($1748 | 0)) {
      var $1827 = $1748;
      __label__ = 314;
      break;
    } else {
      __label__ = 293;
      break;
    }
   case 293:
    var $1752 = HEAP32[$1 >> 2] + 20 | 0;
    var $1753 = HEAP32[$1752 >> 2];
    var $1754 = HEAP16[$1753 >> 1];
    var $1755 = __ZL9isNewlinet($1754);
    if ($1755) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 294;
      break;
    }
   case 294:
    var $1757 = $1753 + 2 | 0;
    HEAP32[$1752 >> 2] = $1757;
    var $i28_0 = $i28_0 + 1 | 0;
    var $1748 = HEAP32[$min >> 2];
    __label__ = 292;
    break;
   case 295:
    var $1759;
    var $i29_0;
    if (($i29_0 | 0) > ($1759 | 0)) {
      var $1827 = $1759;
      __label__ = 314;
      break;
    } else {
      __label__ = 296;
      break;
    }
   case 296:
    var $1763 = HEAP32[$1 >> 2] + 20 | 0;
    var $1764 = HEAP32[$1763 >> 2];
    var $1765 = HEAP16[$1764 >> 1];
    var $1766 = __ZN3WTF12isASCIIDigitEt($1765);
    if ($1766) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 297;
      break;
    }
   case 297:
    var $1768 = $1764 + 2 | 0;
    HEAP32[$1763 >> 2] = $1768;
    var $i29_0 = $i29_0 + 1 | 0;
    var $1759 = HEAP32[$min >> 2];
    __label__ = 295;
    break;
   case 298:
    var $1770;
    var $i30_0;
    if (($i30_0 | 0) > ($1770 | 0)) {
      var $1827 = $1770;
      __label__ = 314;
      break;
    } else {
      __label__ = 299;
      break;
    }
   case 299:
    var $1774 = HEAP32[$1 >> 2] + 20 | 0;
    var $1775 = HEAP32[$1774 >> 2];
    var $1776 = HEAP16[$1775 >> 1];
    var $1777 = __ZN3WTF12isASCIIDigitEt($1776);
    if ($1777) {
      __label__ = 300;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 300:
    var $1779 = $1775 + 2 | 0;
    HEAP32[$1774 >> 2] = $1779;
    var $i30_0 = $i30_0 + 1 | 0;
    var $1770 = HEAP32[$min >> 2];
    __label__ = 298;
    break;
   case 301:
    var $1781;
    var $i31_0;
    if (($i31_0 | 0) > ($1781 | 0)) {
      var $1827 = $1781;
      __label__ = 314;
      break;
    } else {
      __label__ = 302;
      break;
    }
   case 302:
    var $1785 = HEAP32[$1 >> 2] + 20 | 0;
    var $1786 = HEAP32[$1785 >> 2];
    var $1787 = HEAP16[$1786 >> 1];
    var $1788 = __ZL11isSpaceChart($1787);
    if ($1788) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 303;
      break;
    }
   case 303:
    var $1790 = $1786 + 2 | 0;
    HEAP32[$1785 >> 2] = $1790;
    var $i31_0 = $i31_0 + 1 | 0;
    var $1781 = HEAP32[$min >> 2];
    __label__ = 301;
    break;
   case 304:
    var $1792;
    var $i32_0;
    if (($i32_0 | 0) > ($1792 | 0)) {
      var $1827 = $1792;
      __label__ = 314;
      break;
    } else {
      __label__ = 305;
      break;
    }
   case 305:
    var $1796 = HEAP32[$1 >> 2] + 20 | 0;
    var $1797 = HEAP32[$1796 >> 2];
    var $1798 = HEAP16[$1797 >> 1];
    var $1799 = __ZL11isSpaceChart($1798);
    if ($1799) {
      __label__ = 306;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 306:
    var $1801 = $1797 + 2 | 0;
    HEAP32[$1796 >> 2] = $1801;
    var $i32_0 = $i32_0 + 1 | 0;
    var $1792 = HEAP32[$min >> 2];
    __label__ = 304;
    break;
   case 307:
    var $1803;
    var $i33_0;
    if (($i33_0 | 0) > ($1803 | 0)) {
      var $1827 = $1803;
      __label__ = 314;
      break;
    } else {
      __label__ = 308;
      break;
    }
   case 308:
    var $1807 = HEAP32[$1 >> 2] + 20 | 0;
    var $1808 = HEAP32[$1807 >> 2];
    var $1809 = HEAP16[$1808 >> 1];
    var $1810 = __ZL10isWordChart($1809);
    if ($1810) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      __label__ = 309;
      break;
    }
   case 309:
    var $1812 = $1808 + 2 | 0;
    HEAP32[$1807 >> 2] = $1812;
    var $i33_0 = $i33_0 + 1 | 0;
    var $1803 = HEAP32[$min >> 2];
    __label__ = 307;
    break;
   case 310:
    var $1814;
    var $i34_0;
    if (($i34_0 | 0) > ($1814 | 0)) {
      var $1827 = $1814;
      __label__ = 314;
      break;
    } else {
      __label__ = 311;
      break;
    }
   case 311:
    var $1818 = HEAP32[$1 >> 2] + 20 | 0;
    var $1819 = HEAP32[$1818 >> 2];
    var $1820 = HEAP16[$1819 >> 1];
    var $1821 = __ZL10isWordChart($1820);
    if ($1821) {
      __label__ = 312;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 312:
    var $1823 = $1819 + 2 | 0;
    HEAP32[$1818 >> 2] = $1823;
    var $i34_0 = $i34_0 + 1 | 0;
    var $1814 = HEAP32[$min >> 2];
    __label__ = 310;
    break;
   case 313:
    var $1826 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $1826;
    __label__ = 410;
    break;
   case 314:
    var $1827;
    var $1828 = HEAPU32[$1 >> 2];
    if (($1827 | 0) == (HEAP32[$1828 + 76 >> 2] | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 315;
      break;
    }
   case 315:
    if ((HEAP8[$minimize] & 1) << 24 >> 24 == 0) {
      __label__ = 330;
      break;
    } else {
      __label__ = 316;
      break;
    }
   case 316:
    HEAP32[$1828 + 68 >> 2] = $1827;
    __label__ = 317;
    break;
   case 317:
    var $1839 = HEAP32[$1 >> 2];
    var $1841 = HEAP32[$1839 + 24 >> 2];
    var $1843 = HEAP32[$1839 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $1841, $1843, 48);
    __label__ = 7;
    break;
   case 318:
    var $1845 = HEAP32[$1 >> 2];
    if ((HEAP32[$1845 + 68 >> 2] | 0) < (HEAP32[$1845 + 76 >> 2] | 0)) {
      __label__ = 319;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 319:
    var $1852 = $1845 + 20 | 0;
    var $1853 = HEAPU32[$1852 >> 2];
    if ($1853 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 320;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 320:
    var $1857 = $1853 + 2 | 0;
    HEAP32[$1852 >> 2] = $1857;
    var $1858 = HEAPU16[$1853 >> 1];
    var $1859 = $1858 & 65535;
    var $1860 = HEAPU32[$1 >> 2];
    var $1862 = HEAP32[$1860 + 60 >> 2];
    if (($1862 | 0) == 9) {
      __label__ = 321;
      break;
    } else if (($1862 | 0) == 3) {
      __label__ = 322;
      break;
    } else if (($1862 | 0) == 4) {
      __label__ = 323;
      break;
    } else if (($1862 | 0) == 5) {
      __label__ = 324;
      break;
    } else if (($1862 | 0) == 6) {
      __label__ = 325;
      break;
    } else if (($1862 | 0) == 7) {
      __label__ = 326;
      break;
    } else if (($1862 | 0) == 8) {
      __label__ = 327;
      break;
    } else {
      __label__ = 328;
      break;
    }
   case 321:
    var $1864 = __ZL9isNewlinet($1858);
    if ($1864) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 322:
    var $1866 = __ZN3WTF12isASCIIDigitEi($1859);
    if ($1866) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 323:
    var $1868 = __ZN3WTF12isASCIIDigitEi($1859);
    if ($1868) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 324:
    var $1870 = __ZL11isSpaceChart($1858);
    if ($1870) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 325:
    var $1872 = __ZL11isSpaceChart($1858);
    if ($1872) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 326:
    var $1874 = __ZL10isWordChart($1858);
    if ($1874) {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    } else {
      __label__ = 329;
      break;
    }
   case 327:
    var $1876 = __ZL10isWordChart($1858);
    if ($1876) {
      __label__ = 329;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 328:
    var $1878 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $1878;
    __label__ = 410;
    break;
   case 329:
    var $1880 = $1860 + 68 | 0;
    var $1882 = HEAP32[$1880 >> 2] + 1 | 0;
    HEAP32[$1880 >> 2] = $1882;
    __label__ = 317;
    break;
   case 330:
    var $1885 = HEAP32[$1828 + 20 >> 2];
    HEAP32[$1828 + 44 >> 2] = $1885;
    var $1887 = HEAPU32[$1 >> 2];
    var $1889 = HEAP32[$1887 + 60 >> 2];
    if (($1889 | 0) == 9) {
      __label__ = 331;
      break;
    } else if (($1889 | 0) == 3) {
      __label__ = 336;
      break;
    } else if (($1889 | 0) == 4) {
      __label__ = 341;
      break;
    } else if (($1889 | 0) == 5) {
      __label__ = 346;
      break;
    } else if (($1889 | 0) == 6) {
      __label__ = 351;
      break;
    } else if (($1889 | 0) == 7) {
      __label__ = 356;
      break;
    } else if (($1889 | 0) == 8) {
      __label__ = 361;
      break;
    } else {
      __label__ = 366;
      break;
    }
   case 331:
    var $i36_0 = HEAP32[$min >> 2];
    var $1893 = $1887;
    __label__ = 332;
    break;
   case 332:
    var $1893;
    var $i36_0;
    if (($i36_0 | 0) < (HEAP32[$1893 + 76 >> 2] | 0)) {
      __label__ = 333;
      break;
    } else {
      var $2020 = $1893;
      __label__ = 367;
      break;
    }
   case 333:
    var $1898 = $1893 + 20 | 0;
    var $1899 = HEAPU32[$1898 >> 2];
    if ($1899 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 334;
      break;
    } else {
      var $2020 = $1893;
      __label__ = 367;
      break;
    }
   case 334:
    var $1903 = HEAP16[$1899 >> 1];
    var $1904 = __ZL9isNewlinet($1903);
    if ($1904) {
      var $2020 = $1893;
      __label__ = 367;
      break;
    } else {
      __label__ = 335;
      break;
    }
   case 335:
    HEAP32[$1898 >> 2] = $1899 + 2 | 0;
    var $i36_0 = $i36_0 + 1 | 0;
    var $1893 = HEAP32[$1 >> 2];
    __label__ = 332;
    break;
   case 336:
    var $i37_0 = HEAP32[$min >> 2];
    var $1911 = $1887;
    __label__ = 337;
    break;
   case 337:
    var $1911;
    var $i37_0;
    if (($i37_0 | 0) < (HEAP32[$1911 + 76 >> 2] | 0)) {
      __label__ = 338;
      break;
    } else {
      var $2020 = $1911;
      __label__ = 367;
      break;
    }
   case 338:
    var $1916 = $1911 + 20 | 0;
    var $1917 = HEAPU32[$1916 >> 2];
    if ($1917 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 339;
      break;
    } else {
      var $2020 = $1911;
      __label__ = 367;
      break;
    }
   case 339:
    var $1922 = HEAPU16[$1917 >> 1] & 65535;
    var $1923 = __ZN3WTF12isASCIIDigitEi($1922);
    if ($1923) {
      var $2020 = $1911;
      __label__ = 367;
      break;
    } else {
      __label__ = 340;
      break;
    }
   case 340:
    HEAP32[$1916 >> 2] = $1917 + 2 | 0;
    var $i37_0 = $i37_0 + 1 | 0;
    var $1911 = HEAP32[$1 >> 2];
    __label__ = 337;
    break;
   case 341:
    var $i39_0 = HEAP32[$min >> 2];
    var $1930 = $1887;
    __label__ = 342;
    break;
   case 342:
    var $1930;
    var $i39_0;
    if (($i39_0 | 0) < (HEAP32[$1930 + 76 >> 2] | 0)) {
      __label__ = 343;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 343:
    var $1935 = $1930 + 20 | 0;
    var $1936 = HEAPU32[$1935 >> 2];
    if ($1936 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 344;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 344:
    var $1941 = HEAPU16[$1936 >> 1] & 65535;
    var $1942 = __ZN3WTF12isASCIIDigitEi($1941);
    if ($1942) {
      __label__ = 345;
      break;
    } else {
      var $2020 = $1930;
      __label__ = 367;
      break;
    }
   case 345:
    HEAP32[$1935 >> 2] = $1936 + 2 | 0;
    var $i39_0 = $i39_0 + 1 | 0;
    var $1930 = HEAP32[$1 >> 2];
    __label__ = 342;
    break;
   case 346:
    var $i41_0 = HEAP32[$min >> 2];
    var $1949 = $1887;
    __label__ = 347;
    break;
   case 347:
    var $1949;
    var $i41_0;
    if (($i41_0 | 0) < (HEAP32[$1949 + 76 >> 2] | 0)) {
      __label__ = 348;
      break;
    } else {
      var $2020 = $1949;
      __label__ = 367;
      break;
    }
   case 348:
    var $1954 = $1949 + 20 | 0;
    var $1955 = HEAPU32[$1954 >> 2];
    if ($1955 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 349;
      break;
    } else {
      var $2020 = $1949;
      __label__ = 367;
      break;
    }
   case 349:
    var $1959 = HEAP16[$1955 >> 1];
    var $1960 = __ZL11isSpaceChart($1959);
    if ($1960) {
      var $2020 = $1949;
      __label__ = 367;
      break;
    } else {
      __label__ = 350;
      break;
    }
   case 350:
    HEAP32[$1954 >> 2] = $1955 + 2 | 0;
    var $i41_0 = $i41_0 + 1 | 0;
    var $1949 = HEAP32[$1 >> 2];
    __label__ = 347;
    break;
   case 351:
    var $i43_0 = HEAP32[$min >> 2];
    var $1967 = $1887;
    __label__ = 352;
    break;
   case 352:
    var $1967;
    var $i43_0;
    if (($i43_0 | 0) < (HEAP32[$1967 + 76 >> 2] | 0)) {
      __label__ = 353;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 353:
    var $1972 = $1967 + 20 | 0;
    var $1973 = HEAPU32[$1972 >> 2];
    if ($1973 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 354;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 354:
    var $1977 = HEAP16[$1973 >> 1];
    var $1978 = __ZL11isSpaceChart($1977);
    if ($1978) {
      __label__ = 355;
      break;
    } else {
      var $2020 = $1967;
      __label__ = 367;
      break;
    }
   case 355:
    HEAP32[$1972 >> 2] = $1973 + 2 | 0;
    var $i43_0 = $i43_0 + 1 | 0;
    var $1967 = HEAP32[$1 >> 2];
    __label__ = 352;
    break;
   case 356:
    var $i45_0 = HEAP32[$min >> 2];
    var $1985 = $1887;
    __label__ = 357;
    break;
   case 357:
    var $1985;
    var $i45_0;
    if (($i45_0 | 0) < (HEAP32[$1985 + 76 >> 2] | 0)) {
      __label__ = 358;
      break;
    } else {
      var $2020 = $1985;
      __label__ = 367;
      break;
    }
   case 358:
    var $1990 = $1985 + 20 | 0;
    var $1991 = HEAPU32[$1990 >> 2];
    if ($1991 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 359;
      break;
    } else {
      var $2020 = $1985;
      __label__ = 367;
      break;
    }
   case 359:
    var $1995 = HEAP16[$1991 >> 1];
    var $1996 = __ZL10isWordChart($1995);
    if ($1996) {
      var $2020 = $1985;
      __label__ = 367;
      break;
    } else {
      __label__ = 360;
      break;
    }
   case 360:
    HEAP32[$1990 >> 2] = $1991 + 2 | 0;
    var $i45_0 = $i45_0 + 1 | 0;
    var $1985 = HEAP32[$1 >> 2];
    __label__ = 357;
    break;
   case 361:
    var $i47_0 = HEAP32[$min >> 2];
    var $2003 = $1887;
    __label__ = 362;
    break;
   case 362:
    var $2003;
    var $i47_0;
    if (($i47_0 | 0) < (HEAP32[$2003 + 76 >> 2] | 0)) {
      __label__ = 363;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 363:
    var $2008 = $2003 + 20 | 0;
    var $2009 = HEAPU32[$2008 >> 2];
    if ($2009 >>> 0 < HEAPU32[$20 >> 2] >>> 0) {
      __label__ = 364;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 364:
    var $2013 = HEAP16[$2009 >> 1];
    var $2014 = __ZL10isWordChart($2013);
    if ($2014) {
      __label__ = 365;
      break;
    } else {
      var $2020 = $2003;
      __label__ = 367;
      break;
    }
   case 365:
    HEAP32[$2008 >> 2] = $2009 + 2 | 0;
    var $i47_0 = $i47_0 + 1 | 0;
    var $2003 = HEAP32[$1 >> 2];
    __label__ = 362;
    break;
   case 366:
    var $2019 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2019;
    __label__ = 410;
    break;
   case 367:
    var $2020;
    var $2022 = HEAP32[$2020 + 24 >> 2];
    var $2024 = HEAP32[$2020 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $2022, $2024, 52);
    __label__ = 7;
    break;
   case 368:
    var $2027 = HEAP32[$1 >> 2] + 20 | 0;
    var $2028 = HEAP32[$2027 >> 2];
    var $2029 = $2028 - 2 | 0;
    HEAP32[$2027 >> 2] = $2029;
    var $2030 = HEAP32[$1 >> 2];
    if (($2028 | 0) == (HEAP32[$2030 + 44 >> 2] | 0)) {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    } else {
      var $2020 = $2030;
      __label__ = 367;
      break;
    }
   case 369:
    var $2035 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2035;
    __label__ = 410;
    break;
   case 370:
    HEAP32[$26 + 80 >> 2] = $31 - 67 | 0;
    var $2039 = HEAP32[$1 >> 2];
    var $2041 = HEAP32[$2039 + 24 >> 2];
    __ZN10MatchFrame15extractBracketsEPKh($2039, $2041);
    var $2042 = HEAP32[$1 >> 2];
    var $2043 = $2042 + 80 | 0;
    var $2044 = HEAP32[$2043 >> 2];
    if (($2044 | 0) > 100) {
      __label__ = 371;
      break;
    } else {
      var $2053 = $2042;
      var $2052 = $2044;
      __label__ = 372;
      break;
    }
   case 371:
    var $2048 = HEAP32[$2042 + 24 >> 2];
    var $_val = HEAP8[$2048 + 7 | 0];
    var $_idx_val = HEAP8[$2048 + 8 | 0];
    var $2050 = __ZL13get2ByteValuePKh4462($_val, $_idx_val);
    HEAP32[$2043 >> 2] = $2050;
    var $_pre = HEAP32[$1 >> 2];
    var $2053 = $_pre;
    var $2052 = HEAP32[$_pre + 80 >> 2];
    __label__ = 372;
    break;
   case 372:
    var $2052;
    var $2053;
    HEAP32[$2053 + 84 >> 2] = $2052 << 1;
    var $2056 = HEAPU32[$1 >> 2];
    if ((HEAP32[$2056 + 84 >> 2] | 0) < (HEAP32[$15 >> 2] | 0)) {
      __label__ = 374;
      break;
    } else {
      __label__ = 373;
      break;
    }
   case 373:
    var $33 = $2056;
    var $32 = HEAP32[$2056 + 24 >> 2];
    __label__ = 5;
    break;
   case 374:
    var $2068 = HEAP32[HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$2056 + 80 >> 2] << 2) >> 2];
    HEAP32[$2056 + 56 >> 2] = $2068;
    var $2070 = HEAP32[$1 >> 2];
    var $2077 = HEAP32[$2070 + 20 >> 2] - HEAP32[$18 >> 2] >> 1;
    var $2083 = HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$2070 + 80 >> 2] << 2) | 0;
    HEAP32[$2083 >> 2] = $2077;
    var $2085 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$2085 >> 2] = 3;
    var $2086 = __ZN10LinearFlag12readAndClearEv($minSatNextBracket);
    HEAP8[HEAP32[$1 >> 2] + 104 | 0] = $2086 & 1;
    var $_pre84 = HEAPU32[$1 >> 2];
    var $2091 = $_pre84;
    var $2090 = HEAP32[$_pre84 + 24 >> 2];
    __label__ = 375;
    break;
   case 375:
    var $2090;
    var $2091;
    var $2095 = (HEAP8[$2091 + 104 | 0] & 1) << 24 >> 24 != 0;
    var $2098 = $2090 + (HEAP32[$2091 + 88 >> 2] + 3) | 0;
    var $2100 = HEAP32[$2091 + 32 >> 2];
    __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($stack, $2098, $2100, 1);
    var $2101 = HEAP32[$1 >> 2];
    __ZN10MatchFrame13startNewGroupEb($2101, $2095);
    __label__ = 7;
    break;
   case 376:
    var $2104 = HEAP32[$1 >> 2] + 88 | 0;
    HEAP32[$2104 >> 2] = 1;
    var $2106 = HEAP32[$1 >> 2] + 24 | 0;
    var $2107 = HEAP32[$2106 >> 2];
    var $_val33 = HEAP8[$2107 + 1 | 0];
    var $_idx34_val = HEAP8[$2107 + 2 | 0];
    var $_idx35_val = HEAP8[$2107 + 3 | 0];
    var $2109 = __ZL12getLinkValuePKh4461($_val33, $_idx34_val, $_idx35_val);
    var $2110 = $2107 + $2109 | 0;
    HEAP32[$2106 >> 2] = $2110;
    var $2111 = HEAPU32[$1 >> 2];
    var $2113 = HEAPU32[$2111 + 24 >> 2];
    if (HEAP8[$2113] << 24 >> 24 == 58) {
      var $2091 = $2111;
      var $2090 = $2113;
      __label__ = 375;
      break;
    } else {
      __label__ = 377;
      break;
    }
   case 377:
    var $2118 = HEAPU32[$2111 + 92 >> 2];
    if ($2118 >>> 0 < HEAPU32[$2111 + 96 >> 2] >>> 0) {
      var $i49_084 = $2118;
      __label__ = 378;
      break;
    } else {
      var $_lcssa83 = $2111;
      __label__ = 379;
      break;
    }
   case 378:
    var $i49_084;
    __ZN9MatchData13setOffsetPairEjii($md, $i49_084, -1, -1);
    var $2122 = $i49_084 + 1 | 0;
    var $2123 = HEAPU32[$1 >> 2];
    if ($2122 >>> 0 < HEAPU32[$2123 + 96 >> 2] >>> 0) {
      var $i49_084 = $2122;
      __label__ = 378;
      break;
    } else {
      var $_lcssa83 = $2123;
      __label__ = 379;
      break;
    }
   case 379:
    var $_lcssa83;
    var $2128 = HEAP32[$_lcssa83 + 56 >> 2];
    var $2134 = HEAP32[$17 >> 2] + (HEAP32[$16 >> 2] - HEAP32[$_lcssa83 + 80 >> 2] << 2) | 0;
    HEAP32[$2134 >> 2] = $2128;
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 380:
    var $isMatch_0;
    var $2137 = HEAP32[HEAP32[$1 >> 2] >> 2];
    if (($2137 | 0) == 1) {
      __label__ = 381;
      break;
    } else if (($2137 | 0) == 2) {
      __label__ = 382;
      break;
    } else if (($2137 | 0) == 6) {
      __label__ = 383;
      break;
    } else if (($2137 | 0) == 7) {
      __label__ = 385;
      break;
    } else if (($2137 | 0) == 14) {
      __label__ = 386;
      break;
    } else if (($2137 | 0) == 15) {
      __label__ = 387;
      break;
    } else if (($2137 | 0) == 16) {
      __label__ = 388;
      break;
    } else if (($2137 | 0) == 17) {
      __label__ = 389;
      break;
    } else if (($2137 | 0) == 18) {
      __label__ = 390;
      break;
    } else if (($2137 | 0) == 19) {
      __label__ = 391;
      break;
    } else if (($2137 | 0) == 20) {
      __label__ = 392;
      break;
    } else if (($2137 | 0) == 21) {
      __label__ = 393;
      break;
    } else if (($2137 | 0) == 22) {
      __label__ = 394;
      break;
    } else if (($2137 | 0) == 24) {
      __label__ = 395;
      break;
    } else if (($2137 | 0) == 26) {
      __label__ = 396;
      break;
    } else if (($2137 | 0) == 27) {
      __label__ = 397;
      break;
    } else if (($2137 | 0) == 28) {
      __label__ = 398;
      break;
    } else if (($2137 | 0) == 29) {
      __label__ = 399;
      break;
    } else if (($2137 | 0) == 30) {
      __label__ = 400;
      break;
    } else if (($2137 | 0) == 31) {
      __label__ = 401;
      break;
    } else if (($2137 | 0) == 38) {
      __label__ = 402;
      break;
    } else if (($2137 | 0) == 40) {
      __label__ = 403;
      break;
    } else if (($2137 | 0) == 42) {
      __label__ = 404;
      break;
    } else if (($2137 | 0) == 44) {
      __label__ = 405;
      break;
    } else if (($2137 | 0) == 48) {
      __label__ = 406;
      break;
    } else if (($2137 | 0) == 52) {
      __label__ = 407;
      break;
    } else if (($2137 | 0) == 0) {
      __label__ = 409;
      break;
    } else {
      __label__ = 408;
      break;
    }
   case 381:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 376;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 382:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 8;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 383:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $2144 = HEAPU32[$1 >> 2];
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 384;
      break;
    }
   case 384:
    var $116 = $2144;
    var $115 = HEAP8[HEAP32[$2144 + 24 >> 2]];
    __label__ = 16;
    break;
   case 385:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 22;
      break;
    } else {
      var $isMatch_0 = 0;
      __label__ = 380;
      break;
    }
   case 386:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 26;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 387:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 28;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 388:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 46;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 389:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 390:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 48;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 391:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    var $isMatch_0 = $isMatch_0;
    __label__ = 380;
    break;
   case 392:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 106;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 393:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 115;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 394:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 133;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 395:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 147;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 396:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 162;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 397:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 172;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 398:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 199;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 399:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 211;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 400:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 219;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 401:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 230;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 402:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 253;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 403:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 267;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 404:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 275;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 405:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 285;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 406:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 318;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 407:
    __ZN10MatchStack15popCurrentFrameEv($stack);
    if ($isMatch_0 << 24 >> 24 == 0) {
      __label__ = 368;
      break;
    } else {
      var $isMatch_0 = $isMatch_0;
      __label__ = 380;
      break;
    }
   case 408:
    var $2190 = __ZL10matchErroriR10MatchStack(-4, $stack);
    var $_0 = $2190;
    __label__ = 410;
    break;
   case 409:
    var $_0 = $isMatch_0 & 255;
    __label__ = 410;
    break;
   case 410:
    var $_0;
    __ZN10MatchStackD1Ev($stack);
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL5matchP11JSArenaPoolPKtPKhiR9MatchData["X"] = 1;

function __ZL9isNewlinet($nl) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($nl << 16 >> 16 == 10 || $nl << 16 >> 16 == 13 || $nl << 16 >> 16 == 8232 || $nl << 16 >> 16 == 8233) {
      var $2 = 1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $2 = 0;
    __label__ = 3;
    break;
   case 3:
    var $2;
    return $2;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2JS15PerfMeasurementD2Ev($this) {
  return;
}

function __ZN2JS15PerfMeasurement5startEv($this) {
  return;
}

function __ZN2JS15PerfMeasurement4stopEv($this) {
  return;
}

function __ZN2JS15PerfMeasurement19canMeasureSomethingEv() {
  return 0;
}

function __ZL13get2ByteValuePKh4462($opcodePtr_val, $opcodePtr_1_val) {
  return ($opcodePtr_val & 255) << 8 | $opcodePtr_1_val & 255;
}

function __ZN3WTF12isASCIIDigitEi($c) {
  return ($c - 48 | 0) >>> 0 < 10;
}

function __ZL13get3ByteValuePKh4465($opcodePtr_val, $opcodePtr_1_val, $opcodePtr_2_val) {
  return $opcodePtr_2_val & 255 | ($opcodePtr_val & 255) << 16 | ($opcodePtr_1_val & 255) << 8;
}

function __ZN10MatchFrame13startNewGroupEb($this, $minSatisfied) {
  var $1 = $this + 32 | 0;
  var $2 = HEAP32[$1 >> 2];
  var $3 = $this + 108 | 0;
  HEAP32[$3 >> 2] = $2;
  var $6 = HEAP32[$this + 20 >> 2];
  HEAP32[$this + 112 >> 2] = $6;
  HEAP8[$this + 116 | 0] = $minSatisfied & 1;
  HEAP32[$1 >> 2] = $3;
  return;
}

function __ZN10LinearFlag12readAndClearEv($this) {
  var $1 = $this | 0;
  var $4 = (HEAP8[$1] & 1) << 24 >> 24 != 0;
  HEAP8[$1] = 0;
  return $4;
}

function __ZN9MatchData13setOffsetPairEjii($this, $pairNum, $start, $end) {
  var $1 = $pairNum << 1;
  var $2 = $this | 0;
  var $4 = HEAP32[$2 >> 2] + ($1 << 2) | 0;
  HEAP32[$4 >> 2] = $start;
  var $7 = HEAP32[$2 >> 2] + (($1 | 1) << 2) | 0;
  HEAP32[$7 >> 2] = $end;
  return;
}

function __ZN10LinearFlag3setEv($this) {
  HEAP8[$this | 0] = 1;
  return;
}

function __ZN10MatchFrame14restoreOffsetsEiiPii($this, $minBracket, $limitBracket, $offsets, $offsetEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $limitBracket - $minBracket | 0;
    if (($1 | 0) > 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $3 = $this + 8 | 0;
    var $i_01 = 0;
    __label__ = 3;
    break;
   case 3:
    var $i_01;
    var $5 = $i_01 + $minBracket | 0;
    var $6 = $i_01 * 3 | 0;
    var $7 = HEAP32[$3 >> 2];
    var $9 = HEAP32[$7 + ($6 << 2) >> 2];
    var $12 = HEAP32[$7 + ($6 + 1 << 2) >> 2];
    var $15 = HEAP32[$7 + ($6 + 2 << 2) >> 2];
    var $16 = $5 << 1;
    HEAP32[$offsets + ($16 << 2) >> 2] = $9;
    HEAP32[$offsets + (($16 | 1) << 2) >> 2] = $12;
    HEAP32[$offsets + ($offsetEnd - $5 << 2) >> 2] = $15;
    var $22 = $i_01 + 1 | 0;
    if (($22 | 0) == ($1 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $i_01 = $22;
      __label__ = 3;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchFrame14clobberOffsetsEiiPii($this, $minBracket, $limitBracket, $offsets, $offsetEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $limitBracket - $minBracket | 0;
    if (($1 | 0) > 0) {
      var $i_01 = 0;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $i_01;
    var $4 = $i_01 + $minBracket << 1;
    HEAP32[$offsets + ($4 << 2) >> 2] = -1;
    HEAP32[$offsets + (($4 | 1) << 2) >> 2] = -1;
    var $8 = $i_01 + 1 | 0;
    if (($8 | 0) == ($1 | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $8;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL38repeatInformationFromInstructionOffsetsRbRiS0_($instructionOffset, $minimize, $minimumRepeats, $maximumRepeats) {
  var $1 = $instructionOffset << 16 >> 16;
  HEAP8[$minimize] = $instructionOffset & 255 & 1;
  var $3 = STRING_TABLE.__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35minimumRepeatsFromInstructionOffset + $1 | 0;
  HEAP32[$minimumRepeats >> 2] = HEAP8[$3] << 24 >> 24;
  var $7 = HEAP32[__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset + ($1 << 2) >> 2];
  HEAP32[$maximumRepeats >> 2] = $7;
  return;
}

function __ZL29getUTF8CharAndIncrementLengthRiPKhS_($c, $subjectPtr, $len) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU8[$subjectPtr] & 255;
    HEAP32[$c >> 2] = $2;
    if (($2 & 192 | 0) == 192) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $6 = STRING_TABLE._jsc_pcre_utf8_table4 + ($2 & 63) | 0;
    var $8 = HEAPU8[$6] & 255;
    var $9 = $8 * 6 | 0;
    var $13 = (HEAP32[_jsc_pcre_utf8_table3 + ($8 << 2) >> 2] & $2) << $9;
    HEAP32[$c >> 2] = $13;
    var $gcss_01 = $9;
    var $gcii_02 = 1;
    var $15 = $13;
    __label__ = 3;
    break;
   case 3:
    var $15;
    var $gcii_02;
    var $gcss_01;
    var $16 = $gcss_01 - 6 | 0;
    var $22 = (HEAPU8[$subjectPtr + $gcii_02 | 0] & 255 & 63) << $16 | $15;
    HEAP32[$c >> 2] = $22;
    var $23 = $gcii_02 + 1 | 0;
    if (($23 | 0) > ($8 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $gcss_01 = $16;
      var $gcii_02 = $23;
      var $15 = $22;
      __label__ = 3;
      break;
    }
   case 4:
    var $26 = HEAP32[$len >> 2] + $8 | 0;
    HEAP32[$len >> 2] = $26;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL15charTypeForCharh($c) {
  var $2 = STRING_TABLE._jsc_pcre_default_tables + (($c & 255) + 352) | 0;
  return HEAP8[$2];
}

function __ZN10MatchStack29canUseStackBufferForNextFrameEv($this) {
  return HEAPU32[$this + 1936 >> 2] >>> 0 < 16;
}

function __ZN10MatchFrame4initEP11JSArenaPool($this, $regExpPool) {
  HEAP32[$this + 16 >> 2] = $regExpPool;
  return;
}

function __ZN10MatchFrameC2Ev($this) {
  HEAP32[$this + 12 >> 2] = 0;
  HEAP32[$this + 16 >> 2] = 0;
  return;
}

function __ZN10LinearFlagC2Ev($this) {
  HEAP8[$this | 0] = 0;
  return;
}

function __Z22jsc_pcre_ucp_othercasej($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $bot_0_ph = 0;
    var $top_0_ph = 2963;
    __label__ = 2;
    break;
   case 2:
    var $top_0_ph;
    var $bot_0_ph;
    var $bot_0 = $bot_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $bot_0;
    if (($top_0_ph | 0) > ($bot_0 | 0)) {
      __label__ = 4;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 4:
    var $5 = $bot_0 + $top_0_ph >> 1;
    var $7 = HEAPU32[__ZL9ucp_table + ($5 << 3) >> 2];
    var $8 = $7 & 2097151;
    if (($8 | 0) == ($c | 0)) {
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if ($8 >>> 0 > $c >>> 0) {
      var $bot_0_ph = $bot_0;
      var $top_0_ph = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($7 & 15728640 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (((HEAP32[__ZL9ucp_table + ($5 << 3) + 4 >> 2] & 65535) + $8 | 0) >>> 0 < $c >>> 0) {
      __label__ = 8;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 8:
    var $bot_0 = $5 + 1 | 0;
    __label__ = 3;
    break;
   case 9:
    if (($7 & 15728640 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      var $_0 = -1;
      __label__ = 11;
      break;
    }
   case 10:
    var $26 = HEAP32[__ZL9ucp_table + ($5 << 3) + 4 >> 2];
    var $_ = ($26 & 32768 | 0) == 0 ? $26 & 65535 : $26 | -32768;
    var $33 = ($_ | 0) == 0 ? -1 : $_ + $c | 0;
    var $_0 = $33;
    __label__ = 11;
    break;
   case 11:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL28getUTF8CharAndAdvancePointerRiRPKh($c, $subjectPtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[$subjectPtr >> 2];
    var $2 = $1 + 1 | 0;
    HEAP32[$subjectPtr >> 2] = $2;
    var $4 = HEAPU8[$1] & 255;
    HEAP32[$c >> 2] = $4;
    if (($4 & 192 | 0) == 192) {
      __label__ = 2;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 2:
    var $8 = STRING_TABLE._jsc_pcre_utf8_table4 + ($4 & 63) | 0;
    var $10 = HEAPU8[$8] & 255;
    var $11 = $10 * 6 | 0;
    var $15 = (HEAP32[_jsc_pcre_utf8_table3 + ($10 << 2) >> 2] & $4) << $11;
    HEAP32[$c >> 2] = $15;
    var $gcaa_01 = $10;
    var $gcss_02 = $11;
    __label__ = 3;
    break;
   case 3:
    var $gcss_02;
    var $gcaa_01;
    var $17 = $gcaa_01 - 1 | 0;
    var $18 = $gcss_02 - 6 | 0;
    var $19 = HEAP32[$subjectPtr >> 2];
    var $20 = $19 + 1 | 0;
    HEAP32[$subjectPtr >> 2] = $20;
    var $26 = (HEAPU8[$19] & 255 & 63) << $18 | HEAP32[$c >> 2];
    HEAP32[$c >> 2] = $26;
    if (($17 | 0) > 0) {
      var $gcaa_01 = $17;
      var $gcss_02 = $18;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchStackC1EP11JSArenaPool($this, $regExpPool) {
  __ZN10MatchStackC2EP11JSArenaPool($this, $regExpPool);
  return;
}

function __ZN10LinearFlagC1Ev($this) {
  __ZN10LinearFlagC2Ev($this);
  return;
}

function __ZL10matchErroriR10MatchStack($errorCode, $stack) {
  __ZN10MatchStack12popAllFramesEv($stack);
  return $errorCode;
}

function __ZN10MatchFrame15extractBracketsEPKh($this, $instructionPtr) {
  var $_val = HEAP8[$instructionPtr + 4 | 0];
  var $_idx_val = HEAP8[$instructionPtr + 5 | 0];
  var $2 = __ZL13get2ByteValuePKh4462($_val, $_idx_val);
  HEAP32[$this + 92 >> 2] = $2 >>> 8 & 255;
  HEAP32[$this + 96 >> 2] = $2 & 255;
  return;
}

function __ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei($this, $instructionPtr, $bracketChain, $returnLocation) {
  var $1 = __ZN10MatchStack17allocateNextFrameEv($this);
  var $2 = $this + 1932 | 0;
  var $3 = HEAP32[$2 >> 2];
  HEAP32[$1 + 4 >> 2] = $3;
  var $7 = HEAP32[HEAP32[$2 >> 2] + 20 >> 2];
  HEAP32[$1 + 20 >> 2] = $7;
  var $11 = HEAP32[HEAP32[$2 >> 2] + 28 >> 2];
  HEAP32[$1 + 28 >> 2] = $11;
  HEAP32[$1 + 24 >> 2] = $instructionPtr;
  HEAP32[$1 + 32 >> 2] = $bracketChain;
  HEAP32[$1 >> 2] = $returnLocation;
  var $16 = $this + 1936 | 0;
  var $18 = HEAP32[$16 >> 2] + 1 | 0;
  HEAP32[$16 >> 2] = $18;
  HEAP32[$2 >> 2] = $1;
  return;
}

function __ZN10MatchStack15popCurrentFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1932 | 0;
    var $2 = HEAPU32[$1 >> 2];
    var $4 = HEAP32[$2 + 4 >> 2];
    HEAP32[$1 >> 2] = $4;
    var $5 = $this + 1936 | 0;
    var $6 = HEAPU32[$5 >> 2];
    if ($6 >>> 0 > 16) {
      __label__ = 2;
      break;
    } else {
      var $10 = $6;
      __label__ = 3;
      break;
    }
   case 2:
    __ZN2js10Foreground7delete_I10MatchFrameEEvPT_($2);
    var $10 = HEAP32[$5 >> 2];
    __label__ = 3;
    break;
   case 3:
    var $10;
    HEAP32[$5 >> 2] = $10 - 1 | 0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL12getLinkValuePKh4461($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL21getLinkValueAllowZeroPKh4464($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZL21advanceToEndOfBracketRPKh4463($opcodePtr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAP32[$opcodePtr >> 2];
    __label__ = 2;
    break;
   case 2:
    var $2;
    var $_val = HEAP8[$2 + 1 | 0];
    var $_idx_val = HEAP8[$2 + 2 | 0];
    var $_idx1_val = HEAP8[$2 + 3 | 0];
    var $4 = __ZL12getLinkValuePKh4461($_val, $_idx_val, $_idx1_val);
    var $5 = $2 + $4 | 0;
    HEAP32[$opcodePtr >> 2] = $5;
    if (HEAP8[$5] << 24 >> 24 == 58) {
      var $2 = $5;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchFrame11saveOffsetsEiiPii($this, $minBracket, $limitBracket, $offsets, $offsetEnd) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($minBracket | 0) == ($limitBracket | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $limitBracket - $minBracket | 0;
    var $4 = $3 * 12 | 0;
    var $5 = $this + 12 | 0;
    if (HEAPU32[$5 >> 2] >>> 0 < $4 >>> 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 3:
    var $10 = HEAPU32[$this + 16 >> 2];
    var $12 = HEAP32[$10 + 16 >> 2];
    var $14 = HEAP32[$10 + 24 >> 2];
    var $17 = $14 + $4 & ($14 ^ -1);
    var $18 = $12 + 12 | 0;
    var $19 = HEAPU32[$18 >> 2];
    var $21 = HEAPU32[$12 + 8 >> 2];
    if ($17 >>> 0 > $21 >>> 0 | $19 >>> 0 > ($21 - $17 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $26 = _JS_ArenaAllocate($10, $17);
    var $_p_0 = $26;
    __label__ = 6;
    break;
   case 5:
    var $29 = $17 + $19 | 0;
    HEAP32[$18 >> 2] = $29;
    var $_p_0 = $19;
    __label__ = 6;
    break;
   case 6:
    var $_p_0;
    HEAP32[$this + 8 >> 2] = $_p_0;
    HEAP32[$5 >> 2] = $4;
    __label__ = 7;
    break;
   case 7:
    if (($limitBracket | 0) == ($minBracket | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $34 = $this + 8 | 0;
    var $i_02 = 0;
    __label__ = 9;
    break;
   case 9:
    var $i_02;
    var $35 = $i_02 + $minBracket | 0;
    var $36 = $35 << 1;
    var $38 = HEAP32[$offsets + ($36 << 2) >> 2];
    var $41 = HEAP32[$offsets + (($36 | 1) << 2) >> 2];
    var $44 = HEAP32[$offsets + ($offsetEnd - $35 << 2) >> 2];
    var $45 = $i_02 * 3 | 0;
    var $47 = HEAP32[$34 >> 2] + ($45 << 2) | 0;
    HEAP32[$47 >> 2] = $38;
    var $50 = HEAP32[$34 >> 2] + ($45 + 1 << 2) | 0;
    HEAP32[$50 >> 2] = $41;
    var $53 = HEAP32[$34 >> 2] + ($45 + 2 << 2) | 0;
    HEAP32[$53 >> 2] = $44;
    var $54 = $i_02 + 1 | 0;
    if ($54 >>> 0 < $3 >>> 0) {
      var $i_02 = $54;
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN10MatchFrame11saveOffsetsEiiPii["X"] = 1;

function __ZL10isWordChart($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      var $8 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $c & 255;
    var $4 = __ZL15charTypeForCharh($3);
    var $8 = ($4 & 16) << 24 >> 24 != 0;
    __label__ = 3;
    break;
   case 3:
    var $8;
    return $8;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL11isSpaceChart($c) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($c & 65535) < 128) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = $c & 255;
    var $4 = __ZL15charTypeForCharh($3);
    if (($4 & 1) << 24 >> 24 == 0) {
      __label__ = 3;
      break;
    } else {
      var $10 = 1;
      __label__ = 4;
      break;
    }
   case 3:
    var $10 = $c << 16 >> 16 == 160;
    __label__ = 4;
    break;
   case 4:
    var $10;
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL8matchRefiPKtiRK9MatchData($offset, $subjectPtr, $length, $md) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $7 = HEAP32[$md + 16 >> 2] + (HEAP32[HEAP32[$md >> 2] + ($offset << 2) >> 2] << 1) | 0;
    if ((HEAP32[$md + 20 >> 2] - $subjectPtr >> 1 | 0) < ($length | 0)) {
      var $_0 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ((HEAP8[$md + 33 | 0] & 1) << 24 >> 24 == 0) {
      var $p_1 = $7;
      var $_1 = $subjectPtr;
      var $_13 = $length;
      __label__ = 5;
      break;
    } else {
      var $p_0 = $7;
      var $_01 = $subjectPtr;
      var $_02 = $length;
      __label__ = 3;
      break;
    }
   case 3:
    var $_02;
    var $_01;
    var $p_0;
    if (($_02 | 0) > 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 4:
    var $22 = $_02 - 1 | 0;
    var $23 = $p_0 + 2 | 0;
    var $24 = HEAPU16[$p_0 >> 1];
    var $25 = $24 & 65535;
    var $26 = __Z22jsc_pcre_ucp_othercasej($25);
    var $28 = HEAPU16[$_01 >> 1];
    if ($24 << 16 >> 16 == $28 << 16 >> 16 | ($26 | 0) == ($28 & 65535 | 0)) {
      var $p_0 = $23;
      var $_01 = $_01 + 2 | 0;
      var $_02 = $22;
      __label__ = 3;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 5:
    var $_13;
    var $_1;
    var $p_1;
    if (($_13 | 0) > 0) {
      __label__ = 6;
      break;
    } else {
      var $_0 = 1;
      __label__ = 7;
      break;
    }
   case 6:
    if (HEAP16[$p_1 >> 1] << 16 >> 16 == HEAP16[$_1 >> 1] << 16 >> 16) {
      var $p_1 = $p_1 + 2 | 0;
      var $_1 = $_1 + 2 | 0;
      var $_13 = $_13 - 1 | 0;
      __label__ = 5;
      break;
    } else {
      var $_0 = 0;
      __label__ = 7;
      break;
    }
   case 7:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZL8matchRefiPKtiRK9MatchData["X"] = 1;

function __ZN10MatchStackD1Ev($this) {
  __ZN10MatchStackD2Ev($this);
  return;
}

function __ZN10MatchStackD2Ev($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = HEAPU32[$this + 4 >> 2];
    var $4 = HEAPU32[$this >> 2];
    var $6 = HEAP32[$4 + 16 >> 2];
    if (($6 | 0) == ($4 | 0)) {
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = $2;
    var $12 = HEAP32[$6 + 4 >> 2];
    var $14 = $6 + 12 | 0;
    if (($10 - $12 | 0) >>> 0 > (HEAP32[$14 >> 2] - $12 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $20 = HEAP32[$4 + 24 >> 2];
    var $23 = $20 + $10 & ($20 ^ -1);
    HEAP32[$14 >> 2] = $23;
    __label__ = 5;
    break;
   case 4:
    _JS_ArenaRelease($4, $2);
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL21getLinkValueAllowZeroPKh4464($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val) {
  var $1 = __ZL13get3ByteValuePKh4465($opcodePtr_val1, $opcodePtr_1_val, $opcodePtr_2_val);
  return $1;
}

function __ZN2js10Foreground7delete_I10MatchFrameEEvPT_($p) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($p | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $p;
    _js_free4466($3);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_free4466($p) {
  _free($p);
  return;
}

function __ZN10MatchStack17allocateNextFrameEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __ZN10MatchStack29canUseStackBufferForNextFrameEv($this);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $_0 = HEAP32[$this + 1932 >> 2] + 120 | 0;
    __label__ = 4;
    break;
   case 3:
    var $7 = __ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v();
    var $9 = HEAP32[$this >> 2];
    __ZN10MatchFrame4initEP11JSArenaPool($7, $9);
    var $_0 = $7;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = _js_malloc4467();
    if (($1 | 0) == 0) {
      var $6 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = $1;
    __ZN10MatchFrameC1Ev($4);
    var $6 = $4;
    __label__ = 3;
    break;
   case 3:
    var $6;
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _js_malloc4467() {
  var $1 = _malloc(120);
  return $1;
}

function __ZN10MatchFrameC1Ev($this) {
  __ZN10MatchFrameC2Ev($this);
  return;
}

function __ZN10MatchStack12popAllFramesEv($this) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $this + 1936 | 0;
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    __ZN10MatchStack15popCurrentFrameEv($this);
    if ((HEAP32[$1 >> 2] | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN10MatchStackC2EP11JSArenaPool($this, $regExpPool) {
  HEAP32[$this >> 2] = $regExpPool;
  var $7 = HEAP32[HEAP32[$regExpPool + 16 >> 2] + 12 >> 2];
  HEAP32[$this + 4 >> 2] = $7;
  var $8 = $this + 8 | 0;
  var $9 = $this + 1928 | 0;
  __ZN10MatchFrameC1Ev($8);
  var $10 = $this + 128 | 0;
  __ZN10MatchFrameC1Ev($10);
  var $11 = $this + 248 | 0;
  __ZN10MatchFrameC1Ev($11);
  var $12 = $this + 368 | 0;
  __ZN10MatchFrameC1Ev($12);
  var $13 = $this + 488 | 0;
  __ZN10MatchFrameC1Ev($13);
  var $14 = $this + 608 | 0;
  __ZN10MatchFrameC1Ev($14);
  var $15 = $this + 728 | 0;
  __ZN10MatchFrameC1Ev($15);
  var $16 = $this + 848 | 0;
  __ZN10MatchFrameC1Ev($16);
  var $17 = $this + 968 | 0;
  __ZN10MatchFrameC1Ev($17);
  var $18 = $this + 1088 | 0;
  __ZN10MatchFrameC1Ev($18);
  var $19 = $this + 1208 | 0;
  __ZN10MatchFrameC1Ev($19);
  var $20 = $this + 1328 | 0;
  __ZN10MatchFrameC1Ev($20);
  var $21 = $this + 1448 | 0;
  __ZN10MatchFrameC1Ev($21);
  var $22 = $this + 1568 | 0;
  __ZN10MatchFrameC1Ev($22);
  var $23 = $this + 1688 | 0;
  __ZN10MatchFrameC1Ev($23);
  var $24 = $this + 1808 | 0;
  __ZN10MatchFrameC1Ev($24);
  HEAP32[$this + 1928 >> 2] = $9;
  HEAP32[$this + 1932 >> 2] = $8;
  HEAP32[$this + 1936 >> 2] = 1;
  __ZN10MatchFrame4initEP11JSArenaPool($8, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($10, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($11, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($12, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($13, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($14, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($15, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($16, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($17, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($18, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($19, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($20, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($21, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($22, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($23, $regExpPool);
  __ZN10MatchFrame4initEP11JSArenaPool($24, $regExpPool);
  return;
}

__ZN10MatchStackC2EP11JSArenaPool["X"] = 1;

function __Z15jsc_pcre_xclassiPKh($c, $data) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $x = __stackBase__ + 4;
    var $x1 = __stackBase__ + 8;
    var $y = __stackBase__ + 12;
    HEAP32[$1 >> 2] = $data;
    var $2 = HEAPU8[$data];
    var $5 = ($2 & 2) << 24 >> 24 == 0;
    if (($c | 0) < 256) {
      __label__ = 2;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 2:
    if ($5) {
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $storemerge = $data + 1 | 0;
    __label__ = 8;
    break;
   case 4:
    if ((HEAPU8[$data + ((($c | 0) / 8 & -1) + 1) | 0] & 255 & 1 << ($c & 7) | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 6:
    if ($5) {
      var $storemerge = $data + 1 | 0;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $storemerge = $data + 33 | 0;
    __label__ = 8;
    break;
   case 8:
    var $storemerge;
    HEAP32[$1 >> 2] = $storemerge;
    var $24 = $storemerge;
    __label__ = 9;
    break;
   case 9:
    var $24;
    HEAP32[$1 >> 2] = $24 + 1 | 0;
    var $26 = HEAP8[$24];
    if ($26 << 24 >> 24 == 1) {
      __label__ = 11;
      break;
    } else if ($26 << 24 >> 24 == 2) {
      __label__ = 13;
      break;
    } else if ($26 << 24 >> 24 == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $24 = HEAP32[$1 >> 2];
    __label__ = 9;
    break;
   case 11:
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($x, $1);
    if ((HEAP32[$x >> 2] | 0) == ($c | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 12:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 13:
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($x1, $1);
    __ZL28getUTF8CharAndAdvancePointerRiRPKh($y, $1);
    if ((HEAP32[$x1 >> 2] | 0) > ($c | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ((HEAP32[$y >> 2] | 0) < ($c | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $_0 = ($2 & 1) << 24 >> 24 == 0;
    __label__ = 17;
    break;
   case 16:
    var $_0 = ($2 & 1) << 24 >> 24 != 0;
    __label__ = 17;
    break;
   case 17:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

__Z15jsc_pcre_xclassiPKh["X"] = 1;

function __ZN2v88internal7ceilingEd($x) {
  var $1 = _ceil($x);
  return $1;
}

function __ZN2v88internal2OS5AbortEv() {
  var $1 = _raise(6);
  return;
}

function __ZN2JS15PerfMeasurementC2ENS0_9EventMaskE($this, $0) {
  HEAP32[$this >> 2] = 0;
  HEAP32[$this + 4 >> 2] = 0;
  var $5 = $this + 8 | 0;
  for (var $$dest = $5 >> 2, $$stop = $$dest + 22; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = -1;
  }
  return;
}

function __ZN2JS15PerfMeasurement5resetEv($this) {
  var $2 = $this + 8 | 0;
  for (var $$dest = $2 >> 2, $$stop = $$dest + 22; $$dest < $$stop; $$dest++) {
    HEAP32[$$dest] = -1;
  }
  return;
}

function _PRMJ_LocalGMTDifference() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tm = __stackBase__;
    var $1 = __ZL16ComputeLocalTimelP2tm(0, $tm);
    if ($1) {
      __label__ = 2;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 2:
    if ((HEAP32[$tm + 32 >> 2] | 0) > 0) {
      __label__ = 3;
      break;
    } else {
      var $day_0 = 0;
      __label__ = 4;
      break;
    }
   case 3:
    var $7 = __ZL16ComputeLocalTimelP2tm(15552e3, $tm);
    if ($7) {
      var $day_0 = 180;
      __label__ = 4;
      break;
    } else {
      var $_0 = 0;
      __label__ = 5;
      break;
    }
   case 4:
    var $day_0;
    var $17 = HEAP32[$tm + 8 >> 2] * -3600 + 86400 - HEAP32[$tm >> 2] + HEAP32[$tm + 4 >> 2] * -60 | 0;
    var $time_0 = (HEAP32[$tm + 28 >> 2] | 0) == ($day_0 | 0) ? $17 - 86400 | 0 : $17;
    var $_0 = $time_0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZL16ComputeLocalTimelP2tm($local, $ptm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $1 = __stackBase__;
  HEAP32[$1 >> 2] = $local;
  var $2 = _localtime_r($1, $ptm);
  var $3 = ($2 | 0) != 0;
  STACKTOP = __stackBase__;
  return $3;
}

function __ZN14DSTOffsetCache11sanityCheckEv($this) {
  return;
}

function __ZNK2v88internal6VectorIcE5startEv($this) {
  return HEAP32[$this >> 2];
}

function _PRMJ_Now() {
  var __stackBase__ = STACKTOP;
  STACKTOP += 8;
  var $tv = __stackBase__;
  var $1 = _gettimeofday($tv, 0);
  var $3 = HEAP32[$tv >> 2];
  var $4$0 = $3;
  var $4$1 = ($3 | 0) < 0 ? -1 : 0;
  var $5$0 = (i64Math.multiply($4$0, $4$1, 1e6, 0), i64Math.result[0]);
  var $5$1 = i64Math.result[1];
  var $7 = HEAP32[$tv + 4 >> 2];
  var $8$0 = $7;
  var $8$1 = ($7 | 0) < 0 ? -1 : 0;
  var $9$0 = (i64Math.add($5$0, $5$1, $8$0, $8$1), i64Math.result[0]);
  var $9$1 = i64Math.result[1];
  STACKTOP = __stackBase__;
  return [ $9$0, $9$1 ];
}

function _PRMJ_FormatTime($buf, $buflen, $fmt, $prtm) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 124;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $a = __stackBase__;
    var $td = __stackBase__ + 44;
    var $t = __stackBase__ + 88;
    var $real_year = __stackBase__ + 92;
    var $fake_year = __stackBase__ + 108;
    var $1 = $a;
    for (var $$dest = $1 >> 2, $$stop = $$dest + 11; $$dest < $$stop; $$dest++) {
      HEAP32[$$dest] = 0;
    }
    var $4 = HEAP8[$prtm + 4 | 0] << 24 >> 24;
    HEAP32[$a >> 2] = $4;
    var $8 = HEAP8[$prtm + 5 | 0] << 24 >> 24;
    HEAP32[$a + 4 >> 2] = $8;
    var $12 = HEAP8[$prtm + 6 | 0] << 24 >> 24;
    HEAP32[$a + 8 >> 2] = $12;
    var $16 = HEAP8[$prtm + 7 | 0] << 24 >> 24;
    HEAP32[$a + 12 >> 2] = $16;
    var $20 = HEAP8[$prtm + 8 | 0] << 24 >> 24;
    HEAP32[$a + 16 >> 2] = $20;
    var $24 = HEAP8[$prtm + 9 | 0] << 24 >> 24;
    HEAP32[$a + 24 >> 2] = $24;
    var $26 = $td;
    for (var $$dest = $26 >> 2, $$stop = $$dest + 11; $$dest < $$stop; $$dest++) {
      HEAP32[$$dest] = 0;
    }
    HEAP32[$td >> 2] = $4;
    HEAP32[$td + 4 >> 2] = $8;
    HEAP32[$td + 8 >> 2] = $12;
    HEAP32[$td + 12 >> 2] = $16;
    HEAP32[$td + 16 >> 2] = $20;
    HEAP32[$td + 24 >> 2] = $24;
    var $33 = $prtm + 12 | 0;
    var $35 = HEAP32[$33 >> 2] - 1900 | 0;
    HEAP32[$td + 20 >> 2] = $35;
    var $37 = $prtm + 16 | 0;
    HEAP32[$td + 28 >> 2] = HEAP16[$37 >> 1] << 16 >> 16;
    var $41 = $prtm + 18 | 0;
    HEAP32[$td + 32 >> 2] = HEAP8[$41] << 24 >> 24;
    var $45 = _mktime($td);
    HEAP32[$t >> 2] = $45;
    var $46 = _localtime_r($t, $td);
    var $48 = HEAP32[$td + 36 >> 2];
    HEAP32[$a + 36 >> 2] = $48;
    var $51 = HEAP32[$td + 40 >> 2];
    HEAP32[$a + 40 >> 2] = $51;
    var $53 = HEAPU32[$33 >> 2];
    var $_off = $53 - 1900 | 0;
    if ($_off >>> 0 > 8099) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $56 = ($53 | 0) % 100;
    var $57 = $56 + 9900 | 0;
    HEAP32[$a + 20 >> 2] = $56 + 8e3 | 0;
    var $fake_tm_year_0 = $57;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$a + 20 >> 2] = $_off;
    var $fake_tm_year_0 = 0;
    __label__ = 4;
    break;
   case 4:
    var $fake_tm_year_0;
    HEAP32[$a + 28 >> 2] = HEAP16[$37 >> 1] << 16 >> 16;
    HEAP32[$a + 32 >> 2] = HEAP8[$41] << 24 >> 24;
    var $69 = _strftime($buf, $buflen, $fmt, $a);
    if (($fake_tm_year_0 | 0) == 0 | ($69 | 0) == 0) {
      var $_0 = $69;
      __label__ = 9;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $73 = $real_year | 0;
    var $74 = HEAP32[$33 >> 2];
    var $75 = _sprintf($73, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $74, tempInt));
    var $76 = _strlen($73);
    var $77 = $fake_year | 0;
    var $78 = _sprintf($77, STRING_TABLE.__str4498 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $fake_tm_year_0, tempInt));
    var $79 = _strlen($77);
    var $80 = $76 - $79 | 0;
    var $p_0 = $buf;
    var $result_0 = $69;
    __label__ = 6;
    break;
   case 6:
    var $result_0;
    var $p_0;
    var $82 = _strstr($p_0, $77);
    if (($82 | 0) == 0) {
      var $_0 = $result_0;
      __label__ = 9;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $85 = $80 + $result_0 | 0;
    if (($85 | 0) < ($buflen | 0)) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 8:
    var $88 = $82 + $76 | 0;
    var $89 = $82 + $79 | 0;
    var $90 = _strlen($89);
    _llvm_memmove_p0i8_p0i8_i32($88, $89, $90, 1, 0);
    _memcpy($82, $73, $76, 1);
    HEAP8[$buf + $85 | 0] = 0;
    var $p_0 = $88;
    var $result_0 = $85;
    __label__ = 6;
    break;
   case 9:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_PRMJ_FormatTime["X"] = 1;

function __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx($this, $localTimeSeconds$0, $localTimeSeconds$1) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 44;
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $tm = __stackBase__;
    var $1 = $localTimeSeconds$0;
    var $2 = __ZL16ComputeLocalTimelP2tm($1, $tm);
    if ($2) {
      __label__ = 2;
      break;
    } else {
      var $_0$1 = 0;
      var $_0$0 = 0;
      __label__ = 3;
      break;
    }
   case 2:
    var $4 = _PRMJ_LocalGMTDifference();
    var $5$0 = $4;
    var $5$1 = ($4 | 0) < 0 ? -1 : 0;
    var $6$0 = (i64Math.subtract($localTimeSeconds$0, $localTimeSeconds$1, $5$0, $5$1), i64Math.result[0]);
    var $6$1 = i64Math.result[1];
    var $7$0 = (i64Math.modulo($6$0, $6$1, 86400, 0), i64Math.result[0]);
    var $7$1 = i64Math.result[1];
    var $19 = HEAP32[$tm >> 2] - $7$0 + HEAP32[$tm + 4 >> 2] * 60 + HEAP32[$tm + 8 >> 2] * 3600 | 0;
    var $_ = ($19 | 0) < 0 ? $19 + 86400 | 0 : $19;
    var $22$0 = $_;
    var $22$1 = ($_ | 0) < 0 ? -1 : 0;
    var $23$0 = (i64Math.multiply($22$0, $22$1, 1e3, 0), i64Math.result[0]);
    var $23$1 = i64Math.result[1];
    var $_0$1 = $23$1;
    var $_0$0 = $23$0;
    __label__ = 3;
    break;
   case 3:
    var $_0$0;
    var $_0$1;
    STACKTOP = __stackBase__;
    return [ $_0$0, $_0$1 ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext($this, $localTimeMilliseconds$0, $localTimeMilliseconds$1, $cx) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $$emscripten$temp$0$1 = 499;
    if (($localTimeMilliseconds$1 | 0) > ($$emscripten$temp$0$1 | 0) || ($localTimeMilliseconds$1 | 0) == ($$emscripten$temp$0$1 | 0) && $localTimeMilliseconds$0 >>> 0 > -1624447001 >>> 0) {
      var $localTimeSeconds_0$1 = 0;
      var $localTimeSeconds_0$0 = 2145859200;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3$0 = (i64Math.divide($localTimeMilliseconds$0, $localTimeMilliseconds$1, 1e3, 0), i64Math.result[0]);
    var $3$1 = i64Math.result[1];
    var $$emscripten$temp$2$1 = -1;
    if (($localTimeMilliseconds$1 | 0) < ($$emscripten$temp$2$1 | 0) || ($localTimeMilliseconds$1 | 0) == ($$emscripten$temp$2$1 | 0) && $localTimeMilliseconds$0 >>> 0 < -999 >>> 0) {
      __label__ = 3;
      break;
    } else {
      var $localTimeSeconds_0$1 = $3$1;
      var $localTimeSeconds_0$0 = $3$0;
      __label__ = 4;
      break;
    }
   case 3:
    var $localTimeSeconds_0$1 = 0;
    var $localTimeSeconds_0$0 = 86400;
    __label__ = 4;
    break;
   case 4:
    var $localTimeSeconds_0$0;
    var $localTimeSeconds_0$1;
    var $7 = $this + 8 | 0;
    var $st$3$0 = $7 | 0;
    var $8$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $7 + 4 | 0;
    var $8$1 = HEAP32[$st$3$1 >> 2];
    var $9 = ($8$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($8$1 | 0) == ($localTimeSeconds_0$1 | 0) && $8$0 >>> 0 > $localTimeSeconds_0$0 >>> 0;
    if ($9) {
      __label__ = 7;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = $this + 16 | 0;
    var $st$1$0 = $11 | 0;
    var $st$1$1 = $11 + 4 | 0;
    var $12$1 = HEAP32[$st$1$1 >> 2];
    if (($localTimeSeconds_0$1 | 0) > ($12$1 | 0) || ($localTimeSeconds_0$1 | 0) == ($12$1 | 0) && $localTimeSeconds_0$0 >>> 0 > HEAP32[$st$1$0 >> 2] >>> 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $15 = $this | 0;
    var $st$1$0 = $15 | 0;
    var $st$1$1 = $15 + 4 | 0;
    var $_0$1 = HEAP32[$st$1$1 >> 2];
    var $_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 25;
    break;
   case 7:
    var $18 = $this + 32 | 0;
    var $st$1$0 = $18 | 0;
    var $st$1$1 = $18 + 4 | 0;
    var $19$1 = HEAP32[$st$1$1 >> 2];
    var $_pre = $this + 40 | 0;
    if (($19$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($19$1 | 0) == ($localTimeSeconds_0$1 | 0) && HEAP32[$st$1$0 >> 2] >>> 0 > $localTimeSeconds_0$0 >>> 0) {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $st$0$0 = $_pre | 0;
    var $st$0$1 = $_pre + 4 | 0;
    var $22$1 = HEAP32[$st$0$1 >> 2];
    if (($localTimeSeconds_0$1 | 0) > ($22$1 | 0) || ($localTimeSeconds_0$1 | 0) == ($22$1 | 0) && $localTimeSeconds_0$0 >>> 0 > HEAP32[$st$0$0 >> 2] >>> 0) {
      var $_pre_phi = $_pre;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $25 = $this + 24 | 0;
    var $st$1$0 = $25 | 0;
    var $st$1$1 = $25 + 4 | 0;
    var $_0$1 = HEAP32[$st$1$1 >> 2];
    var $_0$0 = HEAP32[$st$1$0 >> 2];
    __label__ = 25;
    break;
   case 10:
    var $_pre_phi;
    var $27 = $this | 0;
    var $st$2$0 = $27 | 0;
    var $28$0 = HEAP32[$st$2$0 >> 2];
    var $st$2$1 = $27 + 4 | 0;
    var $28$1 = HEAP32[$st$2$1 >> 2];
    var $29 = $this + 24 | 0;
    var $st$7$0 = $29 | 0;
    HEAP32[$st$7$0 >> 2] = $28$0;
    var $st$7$1 = $29 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $28$1;
    var $st$11$0 = $18 | 0;
    HEAP32[$st$11$0 >> 2] = $8$0;
    var $st$11$1 = $18 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $8$1;
    var $30 = $this + 16 | 0;
    var $31$0 = HEAP32[$30 >> 2];
    var $31$1 = HEAP32[$30 + 4 >> 2];
    HEAP32[$_pre_phi >> 2] = $31$0;
    HEAP32[$_pre_phi + 4 >> 2] = $31$1;
    if ($9) {
      __label__ = 18;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $33$0 = (i64Math.add($31$0, $31$1, 2592e3, 0), i64Math.result[0]);
    var $33$1 = i64Math.result[1];
    var $$emscripten$temp$4$1 = 0;
    var $34 = ($33$1 | 0) < ($$emscripten$temp$4$1 | 0) || ($33$1 | 0) == ($$emscripten$temp$4$1 | 0) && $33$0 >>> 0 < 2145859200 >>> 0;
    var $35$0 = $34 ? $33$0 : 2145859200;
    var $35$1 = $34 ? $33$1 : 0;
    if (($35$1 | 0) < ($localTimeSeconds_0$1 | 0) || ($35$1 | 0) == ($localTimeSeconds_0$1 | 0) && $35$0 >>> 0 < $localTimeSeconds_0$0 >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $38 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $35$0, $35$1);
    var $38$0 = $38[0];
    var $38$1 = $38[1];
    var $st$3$0 = $27 | 0;
    var $39$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $27 + 4 | 0;
    var $39$1 = HEAP32[$st$3$1 >> 2];
    if ($38$0 == $39$0 && $38$1 == $39$1) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    var $st$0$0 = $30 | 0;
    HEAP32[$st$0$0 >> 2] = $35$0;
    var $st$0$1 = $30 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $35$1;
    var $_0$1 = $39$1;
    var $_0$0 = $39$0;
    __label__ = 25;
    break;
   case 14:
    var $43 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $43$0 = $43[0];
    var $43$1 = $43[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $43$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $43$1;
    if ($43$0 == $38$0 && $43$1 == $38$1) {
      __label__ = 15;
      break;
    } else {
      var $storemerge$1 = $localTimeSeconds_0$1;
      var $storemerge$0 = $localTimeSeconds_0$0;
      __label__ = 16;
      break;
    }
   case 15:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $storemerge$1 = $35$1;
    var $storemerge$0 = $35$0;
    __label__ = 16;
    break;
   case 16:
    var $storemerge$0;
    var $storemerge$1;
    var $st$2$0 = $30 | 0;
    HEAP32[$st$2$0 >> 2] = $storemerge$0;
    var $st$2$1 = $30 + 4 | 0;
    HEAP32[$st$2$1 >> 2] = $storemerge$1;
    var $_0$1 = $43$1;
    var $_0$0 = $43$0;
    __label__ = 25;
    break;
   case 17:
    var $48 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $48$0 = $48[0];
    var $48$1 = $48[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $48$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $48$1;
    var $st$7$0 = $30 | 0;
    HEAP32[$st$7$0 >> 2] = $localTimeSeconds_0$0;
    var $st$7$1 = $30 + 4 | 0;
    HEAP32[$st$7$1 >> 2] = $localTimeSeconds_0$1;
    var $st$11$0 = $7 | 0;
    HEAP32[$st$11$0 >> 2] = $localTimeSeconds_0$0;
    var $st$11$1 = $7 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $48$1;
    var $_0$0 = $48$0;
    __label__ = 25;
    break;
   case 18:
    var $50$0 = (i64Math.add($8$0, $8$1, -2592e3, -1), i64Math.result[0]);
    var $50$1 = i64Math.result[1];
    var $$emscripten$temp$7$1 = 0;
    var $51 = ($50$1 | 0) > ($$emscripten$temp$7$1 | 0) || ($50$1 | 0) == ($$emscripten$temp$7$1 | 0) && $50$0 >>> 0 > 0 >>> 0;
    var $52$0 = $51 ? $50$0 : 0;
    var $52$1 = $51 ? $50$1 : 0;
    if (($52$1 | 0) > ($localTimeSeconds_0$1 | 0) || ($52$1 | 0) == ($localTimeSeconds_0$1 | 0) && $52$0 >>> 0 > $localTimeSeconds_0$0 >>> 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $52$0, $52$1);
    var $55$0 = $55[0];
    var $55$1 = $55[1];
    var $st$3$0 = $27 | 0;
    var $56$0 = HEAP32[$st$3$0 >> 2];
    var $st$3$1 = $27 + 4 | 0;
    var $56$1 = HEAP32[$st$3$1 >> 2];
    if ($55$0 == $56$0 && $55$1 == $56$1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $52$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $52$1;
    var $_0$1 = $56$1;
    var $_0$0 = $56$0;
    __label__ = 25;
    break;
   case 21:
    var $60 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $60$0 = $60[0];
    var $60$1 = $60[1];
    var $st$3$0 = $27 | 0;
    HEAP32[$st$3$0 >> 2] = $60$0;
    var $st$3$1 = $27 + 4 | 0;
    HEAP32[$st$3$1 >> 2] = $60$1;
    if ($60$0 == $55$0 && $60$1 == $55$1) {
      __label__ = 22;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 22:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $52$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $52$1;
    var $st$4$0 = $30 | 0;
    HEAP32[$st$4$0 >> 2] = $localTimeSeconds_0$0;
    var $st$4$1 = $30 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $60$1;
    var $_0$0 = $60$0;
    __label__ = 25;
    break;
   case 23:
    var $st$0$0 = $7 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $7 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $_0$1 = $60$1;
    var $_0$0 = $60$0;
    __label__ = 25;
    break;
   case 24:
    var $st$0$0 = $30 | 0;
    HEAP32[$st$0$0 >> 2] = $localTimeSeconds_0$0;
    var $st$0$1 = $30 + 4 | 0;
    HEAP32[$st$0$1 >> 2] = $localTimeSeconds_0$1;
    var $st$4$0 = $7 | 0;
    HEAP32[$st$4$0 >> 2] = $localTimeSeconds_0$0;
    var $st$4$1 = $7 + 4 | 0;
    HEAP32[$st$4$1 >> 2] = $localTimeSeconds_0$1;
    var $65 = __ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx(undef, $localTimeSeconds_0$0, $localTimeSeconds_0$1);
    var $65$0 = $65[0];
    var $65$1 = $65[1];
    var $st$11$0 = $27 | 0;
    HEAP32[$st$11$0 >> 2] = $65$0;
    var $st$11$1 = $27 + 4 | 0;
    HEAP32[$st$11$1 >> 2] = $65$1;
    var $_0$1 = $65$1;
    var $_0$0 = $65$0;
    __label__ = 25;
    break;
   case 25:
    var $_0$0;
    var $_0$1;
    return [ $_0$0, $_0$1 ];
   default:
    assert(0, "bad label: " + __label__);
  }
}

__ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext["X"] = 1;

function __ZN2v88internal13StringBuilder9AddStringEPKc($this, $s) {
  var $1 = __ZN2v88internal9StrLengthEPKc($s);
  __ZN2v88internal13StringBuilder12AddSubstringEPKci($this, $s, $1);
  return;
}

function __ZN2v88internal13StringBuilder12AddSubstringEPKci($this, $s, $n) {
  var $1 = $this | 0;
  var $2 = $this + 8 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZNK2v88internal6VectorIcEixEi($1, $3);
  _memcpy($4, $s, $n, 1);
  var $6 = HEAP32[$2 >> 2] + $n | 0;
  HEAP32[$2 >> 2] = $6;
  return;
}

function __ZN2v88internal9StrLengthEPKc($string) {
  var $1 = _strlen($string);
  return $1;
}

function __ZN2v88internal13StringBuilder10AddIntegerEi($this, $n) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $ndigits_0 = 0;
    var $n2_0 = $n;
    __label__ = 2;
    break;
   case 2:
    var $n2_0;
    var $ndigits_0;
    var $2 = $ndigits_0 + 1 | 0;
    if (($n2_0 + 9 | 0) >>> 0 > 18) {
      var $ndigits_0 = $2;
      var $n2_0 = ($n2_0 | 0) / 10 & -1;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $6 = $this + 8 | 0;
    var $8 = HEAP32[$6 >> 2] + $2 | 0;
    HEAP32[$6 >> 2] = $8;
    var $9 = $this | 0;
    var $i_0 = $8;
    var $_0 = $n;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    var $i_0;
    var $13 = $_0 % 10 + 48 & 255;
    var $14 = $i_0 - 1 | 0;
    var $15 = __ZNK2v88internal6VectorIcEixEi($9, $14);
    HEAP8[$15] = $13;
    if (($_0 + 9 | 0) >>> 0 > 18) {
      var $i_0 = $14;
      var $_0 = ($_0 | 0) / 10 & -1;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilder10AddPaddingEci($this, $c, $count) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($count | 0) > 0) {
      var $i_01 = 0;
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $i_01;
    __ZN2v88internal13StringBuilder12AddCharacterEc($this, $c);
    var $2 = $i_01 + 1 | 0;
    if (($2 | 0) == ($count | 0)) {
      __label__ = 3;
      break;
    } else {
      var $i_01 = $2;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZN2v88internal13StringBuilder8FinalizeEv($this) {
  var $1 = $this | 0;
  var $2 = $this + 8 | 0;
  var $3 = HEAP32[$2 >> 2];
  var $4 = __ZNK2v88internal6VectorIcEixEi($1, $3);
  HEAP8[$4] = 0;
  HEAP32[$2 >> 2] = -1;
  var $5 = __ZNK2v88internal6VectorIcE5startEv($1);
  return $5;
}

function __ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_($v, $mode, $requested_digits, $buffer, $sign, $length, $point) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 16;
  var tempParam = $buffer;
  $buffer = STACKTOP;
  STACKTOP += 8;
  HEAP32[$buffer >> 2] = HEAP32[tempParam >> 2];
  HEAP32[$buffer + 4 >> 2] = HEAP32[tempParam + 4 >> 2];
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = __stackBase__;
    var $2 = __stackBase__ + 8;
    __ZN2v88internal6DoubleC1Ed($1, $v);
    var $3 = __ZNK2v88internal6Double4SignEv($1);
    if (($3 | 0) < 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    HEAP32[$sign >> 2] = 1;
    var $_01 = -$v;
    __label__ = 4;
    break;
   case 3:
    HEAP32[$sign >> 2] = 0;
    var $_01 = $v;
    __label__ = 4;
    break;
   case 4:
    var $_01;
    if ($_01 == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 5:
    var $11 = __ZNK2v88internal6VectorIcEixEi($buffer, 0);
    HEAP8[$11] = 48;
    var $12 = __ZNK2v88internal6VectorIcEixEi($buffer, 1);
    HEAP8[$12] = 0;
    HEAP32[$length >> 2] = 1;
    HEAP32[$point >> 2] = 1;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 6:
    if (($mode | 0) == 2 & ($requested_digits | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 7:
    var $17 = __ZNK2v88internal6VectorIcEixEi($buffer, 0);
    HEAP8[$17] = 0;
    HEAP32[$length >> 2] = 0;
    var $_0 = 1;
    __label__ = 10;
    break;
   case 8:
    if (($mode | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      var $_0 = 0;
      __label__ = 10;
      break;
    }
   case 9:
    var $20 = $buffer;
    var $21 = $2;
    var $22$0 = HEAP32[$20 >> 2];
    var $22$1 = HEAP32[$20 + 4 >> 2];
    HEAP32[$21 >> 2] = $22$0;
    HEAP32[$21 + 4 >> 2] = $22$1;
    var $23 = __ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_($_01, $2, $length, $point);
    var $_0 = $23;
    __label__ = 10;
    break;
   case 10:
    var $_0;
    STACKTOP = __stackBase__;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZNK2v88internal6Double4SignEv($this) {
  var $1 = __ZNK2v88internal6Double8AsUint64Ev($this);
  var $1$1 = $1[1];
  var $$emscripten$temp$0$1 = -1;
  var $3 = ($1$1 | 0) > ($$emscripten$temp$0$1 | 0) || ($1$1 | 0) == ($$emscripten$temp$0$1 | 0) && $1[0] >>> 0 > -1 >>> 0 ? 1 : -1;
  return $3;
}

function _malloc($bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($bytes >>> 0 < 245) {
      __label__ = 2;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 2:
    if ($bytes >>> 0 < 11) {
      var $8 = 16;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $8 = $bytes + 11 & -8;
    __label__ = 4;
    break;
   case 4:
    var $8;
    var $9 = $8 >>> 3;
    var $10 = HEAPU32[__gm_ >> 2];
    var $11 = $10 >>> ($9 >>> 0);
    if (($11 & 3 | 0) == 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $17 = ($11 & 1 ^ 1) + $9 | 0;
    var $18 = $17 << 1;
    var $20 = __gm_ + 40 + ($18 << 2) | 0;
    var $21 = __gm_ + 40 + ($18 + 2 << 2) | 0;
    var $22 = HEAPU32[$21 >> 2];
    var $23 = $22 + 8 | 0;
    var $24 = HEAPU32[$23 >> 2];
    if (($20 | 0) == ($24 | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    HEAP32[__gm_ >> 2] = $10 & (1 << $17 ^ -1);
    __label__ = 10;
    break;
   case 7:
    if ($24 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    HEAP32[$21 >> 2] = $24;
    HEAP32[$24 + 12 >> 2] = $20;
    __label__ = 10;
    break;
   case 9:
    _abort();
    throw "Reached an unreachable!";
   case 10:
    var $38 = $17 << 3;
    HEAP32[$22 + 4 >> 2] = $38 | 3;
    var $43 = $22 + ($38 | 4) | 0;
    var $45 = HEAP32[$43 >> 2] | 1;
    HEAP32[$43 >> 2] = $45;
    var $mem_0 = $23;
    __label__ = 38;
    break;
   case 11:
    if ($8 >>> 0 > HEAPU32[__gm_ + 8 >> 2] >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    }
   case 12:
    if (($11 | 0) == 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $54 = 2 << $9;
    var $57 = $11 << $9 & ($54 | -$54);
    var $60 = ($57 & -$57) - 1 | 0;
    var $62 = $60 >>> 12 & 16;
    var $63 = $60 >>> ($62 >>> 0);
    var $65 = $63 >>> 5 & 8;
    var $66 = $63 >>> ($65 >>> 0);
    var $68 = $66 >>> 2 & 4;
    var $69 = $66 >>> ($68 >>> 0);
    var $71 = $69 >>> 1 & 2;
    var $72 = $69 >>> ($71 >>> 0);
    var $74 = $72 >>> 1 & 1;
    var $80 = ($65 | $62 | $68 | $71 | $74) + ($72 >>> ($74 >>> 0)) | 0;
    var $81 = $80 << 1;
    var $83 = __gm_ + 40 + ($81 << 2) | 0;
    var $84 = __gm_ + 40 + ($81 + 2 << 2) | 0;
    var $85 = HEAPU32[$84 >> 2];
    var $86 = $85 + 8 | 0;
    var $87 = HEAPU32[$86 >> 2];
    if (($83 | 0) == ($87 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 14:
    HEAP32[__gm_ >> 2] = $10 & (1 << $80 ^ -1);
    __label__ = 18;
    break;
   case 15:
    if ($87 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    HEAP32[$84 >> 2] = $87;
    HEAP32[$87 + 12 >> 2] = $83;
    __label__ = 18;
    break;
   case 17:
    _abort();
    throw "Reached an unreachable!";
   case 18:
    var $101 = $80 << 3;
    var $102 = $101 - $8 | 0;
    HEAP32[$85 + 4 >> 2] = $8 | 3;
    var $105 = $85;
    var $107 = $105 + $8 | 0;
    HEAP32[$105 + ($8 | 4) >> 2] = $102 | 1;
    HEAP32[$105 + $101 >> 2] = $102;
    var $113 = HEAPU32[__gm_ + 8 >> 2];
    if (($113 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $116 = HEAP32[__gm_ + 20 >> 2];
    var $119 = $113 >>> 2 & 1073741822;
    var $121 = __gm_ + 40 + ($119 << 2) | 0;
    var $122 = HEAPU32[__gm_ >> 2];
    var $123 = 1 << ($113 >>> 3);
    if (($122 & $123 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 20:
    HEAP32[__gm_ >> 2] = $122 | $123;
    var $F4_0 = $121;
    var $_pre_phi = __gm_ + 40 + ($119 + 2 << 2) | 0;
    __label__ = 23;
    break;
   case 21:
    var $129 = __gm_ + 40 + ($119 + 2 << 2) | 0;
    var $130 = HEAPU32[$129 >> 2];
    if ($130 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      var $F4_0 = $130;
      var $_pre_phi = $129;
      __label__ = 23;
      break;
    }
   case 22:
    _abort();
    throw "Reached an unreachable!";
   case 23:
    var $_pre_phi;
    var $F4_0;
    HEAP32[$_pre_phi >> 2] = $116;
    HEAP32[$F4_0 + 12 >> 2] = $116;
    var $137 = $116 + 8 | 0;
    HEAP32[$137 >> 2] = $F4_0;
    var $138 = $116 + 12 | 0;
    HEAP32[$138 >> 2] = $121;
    __label__ = 24;
    break;
   case 24:
    HEAP32[__gm_ + 8 >> 2] = $102;
    HEAP32[__gm_ + 20 >> 2] = $107;
    var $mem_0 = $86;
    __label__ = 38;
    break;
   case 25:
    if ((HEAP32[__gm_ + 4 >> 2] | 0) == 0) {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $145 = _tmalloc_small($8);
    if (($145 | 0) == 0) {
      var $nb_0 = $8;
      __label__ = 30;
      break;
    } else {
      var $mem_0 = $145;
      __label__ = 38;
      break;
    }
   case 27:
    if ($bytes >>> 0 > 4294967231) {
      var $nb_0 = -1;
      __label__ = 30;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    var $151 = $bytes + 11 & -8;
    if ((HEAP32[__gm_ + 4 >> 2] | 0) == 0) {
      var $nb_0 = $151;
      __label__ = 30;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    var $155 = _tmalloc_large($151);
    if (($155 | 0) == 0) {
      var $nb_0 = $151;
      __label__ = 30;
      break;
    } else {
      var $mem_0 = $155;
      __label__ = 38;
      break;
    }
   case 30:
    var $nb_0;
    var $157 = HEAPU32[__gm_ + 8 >> 2];
    if ($nb_0 >>> 0 > $157 >>> 0) {
      __label__ = 35;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $160 = $157 - $nb_0 | 0;
    var $161 = HEAPU32[__gm_ + 20 >> 2];
    if ($160 >>> 0 > 15) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    var $164 = $161;
    HEAP32[__gm_ + 20 >> 2] = $164 + $nb_0 | 0;
    HEAP32[__gm_ + 8 >> 2] = $160;
    HEAP32[$nb_0 + ($164 + 4) >> 2] = $160 | 1;
    HEAP32[$164 + $157 >> 2] = $160;
    HEAP32[$161 + 4 >> 2] = $nb_0 | 3;
    __label__ = 34;
    break;
   case 33:
    HEAP32[__gm_ + 8 >> 2] = 0;
    HEAP32[__gm_ + 20 >> 2] = 0;
    HEAP32[$161 + 4 >> 2] = $157 | 3;
    var $179 = $157 + ($161 + 4) | 0;
    var $181 = HEAP32[$179 >> 2] | 1;
    HEAP32[$179 >> 2] = $181;
    __label__ = 34;
    break;
   case 34:
    var $mem_0 = $161 + 8 | 0;
    __label__ = 38;
    break;
   case 35:
    var $186 = HEAPU32[__gm_ + 12 >> 2];
    if ($nb_0 >>> 0 < $186 >>> 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    var $189 = $186 - $nb_0 | 0;
    HEAP32[__gm_ + 12 >> 2] = $189;
    var $190 = HEAPU32[__gm_ + 24 >> 2];
    var $191 = $190;
    HEAP32[__gm_ + 24 >> 2] = $191 + $nb_0 | 0;
    HEAP32[$nb_0 + ($191 + 4) >> 2] = $189 | 1;
    HEAP32[$190 + 4 >> 2] = $nb_0 | 3;
    var $mem_0 = $190 + 8 | 0;
    __label__ = 38;
    break;
   case 37:
    var $202 = _sys_alloc($nb_0);
    var $mem_0 = $202;
    __label__ = 38;
    break;
   case 38:
    var $mem_0;
    return $mem_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

Module["_malloc"] = _malloc;

_malloc["X"] = 1;

function _tmalloc_small($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAP32[__gm_ + 4 >> 2];
    var $4 = ($1 & -$1) - 1 | 0;
    var $6 = $4 >>> 12 & 16;
    var $7 = $4 >>> ($6 >>> 0);
    var $9 = $7 >>> 5 & 8;
    var $10 = $7 >>> ($9 >>> 0);
    var $12 = $10 >>> 2 & 4;
    var $13 = $10 >>> ($12 >>> 0);
    var $15 = $13 >>> 1 & 2;
    var $16 = $13 >>> ($15 >>> 0);
    var $18 = $16 >>> 1 & 1;
    var $26 = HEAPU32[__gm_ + 304 + (($9 | $6 | $12 | $15 | $18) + ($16 >>> ($18 >>> 0)) << 2) >> 2];
    var $v_0_ph = $26;
    var $rsize_0_ph = (HEAP32[$26 + 4 >> 2] & -8) - $nb | 0;
    __label__ = 2;
    break;
   case 2:
    var $rsize_0_ph;
    var $v_0_ph;
    var $t_0 = $v_0_ph;
    __label__ = 3;
    break;
   case 3:
    var $t_0;
    var $33 = HEAP32[$t_0 + 16 >> 2];
    if (($33 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      var $39 = $33;
      __label__ = 5;
      break;
    }
   case 4:
    var $37 = HEAP32[$t_0 + 20 >> 2];
    if (($37 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      var $39 = $37;
      __label__ = 5;
      break;
    }
   case 5:
    var $39;
    var $43 = (HEAP32[$39 + 4 >> 2] & -8) - $nb | 0;
    if ($43 >>> 0 < $rsize_0_ph >>> 0) {
      var $v_0_ph = $39;
      var $rsize_0_ph = $43;
      __label__ = 2;
      break;
    } else {
      var $t_0 = $39;
      __label__ = 3;
      break;
    }
   case 6:
    var $46 = $v_0_ph;
    var $47 = HEAPU32[__gm_ + 16 >> 2];
    if ($46 >>> 0 < $47 >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $50 = $46 + $nb | 0;
    var $51 = $50;
    if ($46 >>> 0 < $50 >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 8:
    var $55 = HEAPU32[$v_0_ph + 24 >> 2];
    var $57 = HEAPU32[$v_0_ph + 12 >> 2];
    if (($57 | 0) == ($v_0_ph | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $61 = HEAPU32[$v_0_ph + 8 >> 2];
    if ($61 >>> 0 < $47 >>> 0) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    HEAP32[$61 + 12 >> 2] = $57;
    HEAP32[$57 + 8 >> 2] = $61;
    var $R_1 = $57;
    __label__ = 19;
    break;
   case 11:
    _abort();
    throw "Reached an unreachable!";
   case 12:
    var $69 = $v_0_ph + 20 | 0;
    var $70 = HEAP32[$69 >> 2];
    if (($70 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $RP_0 = $69;
      var $R_0 = $70;
      __label__ = 14;
      break;
    }
   case 13:
    var $73 = $v_0_ph + 16 | 0;
    var $74 = HEAP32[$73 >> 2];
    if (($74 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 19;
      break;
    } else {
      var $RP_0 = $73;
      var $R_0 = $74;
      __label__ = 14;
      break;
    }
   case 14:
    var $R_0;
    var $RP_0;
    var $76 = $R_0 + 20 | 0;
    var $77 = HEAP32[$76 >> 2];
    if (($77 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $RP_0 = $76;
      var $R_0 = $77;
      __label__ = 14;
      break;
    }
   case 15:
    var $80 = $R_0 + 16 | 0;
    var $81 = HEAPU32[$80 >> 2];
    if (($81 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      var $RP_0 = $80;
      var $R_0 = $81;
      __label__ = 14;
      break;
    }
   case 16:
    if ($RP_0 >>> 0 < $47 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 19;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $R_1;
    if (($55 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $91 = $v_0_ph + 28 | 0;
    var $93 = __gm_ + 304 + (HEAP32[$91 >> 2] << 2) | 0;
    if (($v_0_ph | 0) == (HEAP32[$93 >> 2] | 0)) {
      __label__ = 21;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 21:
    HEAP32[$93 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 22:
    var $101 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$91 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $101;
    __label__ = 39;
    break;
   case 23:
    if ($55 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    var $107 = $55 + 16 | 0;
    if ((HEAP32[$107 >> 2] | 0) == ($v_0_ph | 0)) {
      __label__ = 25;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 25:
    HEAP32[$107 >> 2] = $R_1;
    __label__ = 28;
    break;
   case 26:
    HEAP32[$55 + 20 >> 2] = $R_1;
    __label__ = 28;
    break;
   case 27:
    _abort();
    throw "Reached an unreachable!";
   case 28:
    if (($R_1 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 29;
      break;
    }
   case 29:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 30:
    HEAP32[$R_1 + 24 >> 2] = $55;
    var $123 = HEAPU32[$v_0_ph + 16 >> 2];
    if (($123 | 0) == 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    if ($123 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 32;
      break;
    }
   case 32:
    HEAP32[$R_1 + 16 >> 2] = $123;
    HEAP32[$123 + 24 >> 2] = $R_1;
    __label__ = 34;
    break;
   case 33:
    _abort();
    throw "Reached an unreachable!";
   case 34:
    var $135 = HEAPU32[$v_0_ph + 20 >> 2];
    if (($135 | 0) == 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    if ($135 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    HEAP32[$R_1 + 20 >> 2] = $135;
    HEAP32[$135 + 24 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 37:
    _abort();
    throw "Reached an unreachable!";
   case 38:
    _abort();
    throw "Reached an unreachable!";
   case 39:
    if ($rsize_0_ph >>> 0 < 16) {
      __label__ = 40;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 40:
    var $149 = $rsize_0_ph + $nb | 0;
    HEAP32[$v_0_ph + 4 >> 2] = $149 | 3;
    var $153 = $149 + ($46 + 4) | 0;
    var $155 = HEAP32[$153 >> 2] | 1;
    HEAP32[$153 >> 2] = $155;
    __label__ = 48;
    break;
   case 41:
    HEAP32[$v_0_ph + 4 >> 2] = $nb | 3;
    HEAP32[$nb + ($46 + 4) >> 2] = $rsize_0_ph | 1;
    HEAP32[$46 + ($rsize_0_ph + $nb) >> 2] = $rsize_0_ph;
    var $164 = HEAPU32[__gm_ + 8 >> 2];
    if (($164 | 0) == 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $167 = HEAPU32[__gm_ + 20 >> 2];
    var $170 = $164 >>> 2 & 1073741822;
    var $172 = __gm_ + 40 + ($170 << 2) | 0;
    var $173 = HEAPU32[__gm_ >> 2];
    var $174 = 1 << ($164 >>> 3);
    if (($173 & $174 | 0) == 0) {
      __label__ = 43;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 43:
    HEAP32[__gm_ >> 2] = $173 | $174;
    var $F1_0 = $172;
    var $_pre_phi = __gm_ + 40 + ($170 + 2 << 2) | 0;
    __label__ = 46;
    break;
   case 44:
    var $180 = __gm_ + 40 + ($170 + 2 << 2) | 0;
    var $181 = HEAPU32[$180 >> 2];
    if ($181 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 45;
      break;
    } else {
      var $F1_0 = $181;
      var $_pre_phi = $180;
      __label__ = 46;
      break;
    }
   case 45:
    _abort();
    throw "Reached an unreachable!";
   case 46:
    var $_pre_phi;
    var $F1_0;
    HEAP32[$_pre_phi >> 2] = $167;
    HEAP32[$F1_0 + 12 >> 2] = $167;
    HEAP32[$167 + 8 >> 2] = $F1_0;
    HEAP32[$167 + 12 >> 2] = $172;
    __label__ = 47;
    break;
   case 47:
    HEAP32[__gm_ + 8 >> 2] = $rsize_0_ph;
    HEAP32[__gm_ + 20 >> 2] = $51;
    __label__ = 48;
    break;
   case 48:
    return $v_0_ph + 8 | 0;
   case 49:
    _abort();
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

_tmalloc_small["X"] = 1;

function _tmalloc_large($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = -$nb | 0;
    var $2 = $nb >>> 8;
    if (($2 | 0) == 0) {
      var $idx_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($nb >>> 0 > 16777215) {
      var $idx_0 = 31;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $9 = ($2 + 1048320 | 0) >>> 16 & 8;
    var $10 = $2 << $9;
    var $13 = ($10 + 520192 | 0) >>> 16 & 4;
    var $14 = $10 << $13;
    var $17 = ($14 + 245760 | 0) >>> 16 & 2;
    var $23 = 14 - ($13 | $9 | $17) + ($14 << $17 >>> 15) | 0;
    var $idx_0 = $nb >>> (($23 + 7 | 0) >>> 0) & 1 | $23 << 1;
    __label__ = 4;
    break;
   case 4:
    var $idx_0;
    var $31 = HEAPU32[__gm_ + 304 + ($idx_0 << 2) >> 2];
    if (($31 | 0) == 0) {
      var $v_2 = 0;
      var $rsize_2 = $1;
      var $t_1 = 0;
      __label__ = 12;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($idx_0 | 0) == 31) {
      var $39 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $39 = 25 - ($idx_0 >>> 1) | 0;
    __label__ = 7;
    break;
   case 7:
    var $39;
    var $v_0 = 0;
    var $rsize_0 = $1;
    var $t_0 = $31;
    var $sizebits_0 = $nb << $39;
    var $rst_0 = 0;
    __label__ = 8;
    break;
   case 8:
    var $rst_0;
    var $sizebits_0;
    var $t_0;
    var $rsize_0;
    var $v_0;
    var $44 = HEAP32[$t_0 + 4 >> 2] & -8;
    var $45 = $44 - $nb | 0;
    if ($45 >>> 0 < $rsize_0 >>> 0) {
      __label__ = 9;
      break;
    } else {
      var $v_1 = $v_0;
      var $rsize_1 = $rsize_0;
      __label__ = 10;
      break;
    }
   case 9:
    if (($44 | 0) == ($nb | 0)) {
      var $v_2 = $t_0;
      var $rsize_2 = $45;
      var $t_1 = $t_0;
      __label__ = 12;
      break;
    } else {
      var $v_1 = $t_0;
      var $rsize_1 = $45;
      __label__ = 10;
      break;
    }
   case 10:
    var $rsize_1;
    var $v_1;
    var $51 = HEAPU32[$t_0 + 20 >> 2];
    var $54 = HEAPU32[$t_0 + 16 + ($sizebits_0 >>> 31 << 2) >> 2];
    var $rst_1 = ($51 | 0) == 0 | ($51 | 0) == ($54 | 0) ? $rst_0 : $51;
    if (($54 | 0) == 0) {
      var $v_2 = $v_1;
      var $rsize_2 = $rsize_1;
      var $t_1 = $rst_1;
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $v_0 = $v_1;
    var $rsize_0 = $rsize_1;
    var $t_0 = $54;
    var $sizebits_0 = $sizebits_0 << 1;
    var $rst_0 = $rst_1;
    __label__ = 8;
    break;
   case 12:
    var $t_1;
    var $rsize_2;
    var $v_2;
    if (($t_1 | 0) == 0 & ($v_2 | 0) == 0) {
      __label__ = 13;
      break;
    } else {
      var $t_2_ph = $t_1;
      __label__ = 15;
      break;
    }
   case 13:
    var $63 = 2 << $idx_0;
    var $67 = HEAP32[__gm_ + 4 >> 2] & ($63 | -$63);
    if (($67 | 0) == 0) {
      var $t_2_ph = $t_1;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $72 = ($67 & -$67) - 1 | 0;
    var $74 = $72 >>> 12 & 16;
    var $75 = $72 >>> ($74 >>> 0);
    var $77 = $75 >>> 5 & 8;
    var $78 = $75 >>> ($77 >>> 0);
    var $80 = $78 >>> 2 & 4;
    var $81 = $78 >>> ($80 >>> 0);
    var $83 = $81 >>> 1 & 2;
    var $84 = $81 >>> ($83 >>> 0);
    var $86 = $84 >>> 1 & 1;
    var $t_2_ph = HEAP32[__gm_ + 304 + (($77 | $74 | $80 | $83 | $86) + ($84 >>> ($86 >>> 0)) << 2) >> 2];
    __label__ = 15;
    break;
   case 15:
    var $t_2_ph;
    if (($t_2_ph | 0) == 0) {
      var $rsize_3_lcssa = $rsize_2;
      var $v_3_lcssa = $v_2;
      __label__ = 18;
      break;
    } else {
      var $t_224 = $t_2_ph;
      var $rsize_325 = $rsize_2;
      var $v_326 = $v_2;
      __label__ = 16;
      break;
    }
   case 16:
    var $v_326;
    var $rsize_325;
    var $t_224;
    var $99 = (HEAP32[$t_224 + 4 >> 2] & -8) - $nb | 0;
    var $100 = $99 >>> 0 < $rsize_325 >>> 0;
    var $rsize_4 = $100 ? $99 : $rsize_325;
    var $v_4 = $100 ? $t_224 : $v_326;
    var $102 = HEAPU32[$t_224 + 16 >> 2];
    if (($102 | 0) == 0) {
      __label__ = 17;
      break;
    } else {
      var $t_224 = $102;
      var $rsize_325 = $rsize_4;
      var $v_326 = $v_4;
      __label__ = 16;
      break;
    }
   case 17:
    var $105 = HEAPU32[$t_224 + 20 >> 2];
    if (($105 | 0) == 0) {
      var $rsize_3_lcssa = $rsize_4;
      var $v_3_lcssa = $v_4;
      __label__ = 18;
      break;
    } else {
      var $t_224 = $105;
      var $rsize_325 = $rsize_4;
      var $v_326 = $v_4;
      __label__ = 16;
      break;
    }
   case 18:
    var $v_3_lcssa;
    var $rsize_3_lcssa;
    if (($v_3_lcssa | 0) == 0) {
      var $_0 = 0;
      __label__ = 81;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    if ($rsize_3_lcssa >>> 0 < (HEAP32[__gm_ + 8 >> 2] - $nb | 0) >>> 0) {
      __label__ = 20;
      break;
    } else {
      var $_0 = 0;
      __label__ = 81;
      break;
    }
   case 20:
    var $113 = $v_3_lcssa;
    var $114 = HEAPU32[__gm_ + 16 >> 2];
    if ($113 >>> 0 < $114 >>> 0) {
      __label__ = 80;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $117 = $113 + $nb | 0;
    var $118 = $117;
    if ($113 >>> 0 < $117 >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 80;
      break;
    }
   case 22:
    var $122 = HEAPU32[$v_3_lcssa + 24 >> 2];
    var $124 = HEAPU32[$v_3_lcssa + 12 >> 2];
    if (($124 | 0) == ($v_3_lcssa | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $128 = HEAPU32[$v_3_lcssa + 8 >> 2];
    if ($128 >>> 0 < $114 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$128 + 12 >> 2] = $124;
    HEAP32[$124 + 8 >> 2] = $128;
    var $R_1 = $124;
    __label__ = 33;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $136 = $v_3_lcssa + 20 | 0;
    var $137 = HEAP32[$136 >> 2];
    if (($137 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $RP_0 = $136;
      var $R_0 = $137;
      __label__ = 28;
      break;
    }
   case 27:
    var $140 = $v_3_lcssa + 16 | 0;
    var $141 = HEAP32[$140 >> 2];
    if (($141 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 33;
      break;
    } else {
      var $RP_0 = $140;
      var $R_0 = $141;
      __label__ = 28;
      break;
    }
   case 28:
    var $R_0;
    var $RP_0;
    var $143 = $R_0 + 20 | 0;
    var $144 = HEAP32[$143 >> 2];
    if (($144 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $RP_0 = $143;
      var $R_0 = $144;
      __label__ = 28;
      break;
    }
   case 29:
    var $147 = $R_0 + 16 | 0;
    var $148 = HEAPU32[$147 >> 2];
    if (($148 | 0) == 0) {
      __label__ = 30;
      break;
    } else {
      var $RP_0 = $147;
      var $R_0 = $148;
      __label__ = 28;
      break;
    }
   case 30:
    if ($RP_0 >>> 0 < $114 >>> 0) {
      __label__ = 32;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 33;
    break;
   case 32:
    _abort();
    throw "Reached an unreachable!";
   case 33:
    var $R_1;
    if (($122 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $158 = $v_3_lcssa + 28 | 0;
    var $160 = __gm_ + 304 + (HEAP32[$158 >> 2] << 2) | 0;
    if (($v_3_lcssa | 0) == (HEAP32[$160 >> 2] | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 35:
    HEAP32[$160 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 36:
    var $168 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$158 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $168;
    __label__ = 53;
    break;
   case 37:
    if ($122 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    var $174 = $122 + 16 | 0;
    if ((HEAP32[$174 >> 2] | 0) == ($v_3_lcssa | 0)) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[$174 >> 2] = $R_1;
    __label__ = 42;
    break;
   case 40:
    HEAP32[$122 + 20 >> 2] = $R_1;
    __label__ = 42;
    break;
   case 41:
    _abort();
    throw "Reached an unreachable!";
   case 42:
    if (($R_1 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 52;
      break;
    } else {
      __label__ = 44;
      break;
    }
   case 44:
    HEAP32[$R_1 + 24 >> 2] = $122;
    var $190 = HEAPU32[$v_3_lcssa + 16 >> 2];
    if (($190 | 0) == 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 45;
      break;
    }
   case 45:
    if ($190 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 47;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    HEAP32[$R_1 + 16 >> 2] = $190;
    HEAP32[$190 + 24 >> 2] = $R_1;
    __label__ = 48;
    break;
   case 47:
    _abort();
    throw "Reached an unreachable!";
   case 48:
    var $202 = HEAPU32[$v_3_lcssa + 20 >> 2];
    if (($202 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 49:
    if ($202 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    HEAP32[$R_1 + 20 >> 2] = $202;
    HEAP32[$202 + 24 >> 2] = $R_1;
    __label__ = 53;
    break;
   case 51:
    _abort();
    throw "Reached an unreachable!";
   case 52:
    _abort();
    throw "Reached an unreachable!";
   case 53:
    if ($rsize_3_lcssa >>> 0 < 16) {
      __label__ = 54;
      break;
    } else {
      __label__ = 55;
      break;
    }
   case 54:
    var $216 = $rsize_3_lcssa + $nb | 0;
    HEAP32[$v_3_lcssa + 4 >> 2] = $216 | 3;
    var $220 = $216 + ($113 + 4) | 0;
    var $222 = HEAP32[$220 >> 2] | 1;
    HEAP32[$220 >> 2] = $222;
    __label__ = 79;
    break;
   case 55:
    HEAP32[$v_3_lcssa + 4 >> 2] = $nb | 3;
    HEAP32[$nb + ($113 + 4) >> 2] = $rsize_3_lcssa | 1;
    HEAP32[$113 + ($rsize_3_lcssa + $nb) >> 2] = $rsize_3_lcssa;
    if ($rsize_3_lcssa >>> 0 < 256) {
      __label__ = 56;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 56:
    var $235 = $rsize_3_lcssa >>> 2 & 1073741822;
    var $237 = __gm_ + 40 + ($235 << 2) | 0;
    var $238 = HEAPU32[__gm_ >> 2];
    var $239 = 1 << ($rsize_3_lcssa >>> 3);
    if (($238 & $239 | 0) == 0) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    HEAP32[__gm_ >> 2] = $238 | $239;
    var $F5_0 = $237;
    var $_pre_phi = __gm_ + 40 + ($235 + 2 << 2) | 0;
    __label__ = 60;
    break;
   case 58:
    var $245 = __gm_ + 40 + ($235 + 2 << 2) | 0;
    var $246 = HEAPU32[$245 >> 2];
    if ($246 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 59;
      break;
    } else {
      var $F5_0 = $246;
      var $_pre_phi = $245;
      __label__ = 60;
      break;
    }
   case 59:
    _abort();
    throw "Reached an unreachable!";
   case 60:
    var $_pre_phi;
    var $F5_0;
    HEAP32[$_pre_phi >> 2] = $118;
    HEAP32[$F5_0 + 12 >> 2] = $118;
    HEAP32[$nb + ($113 + 8) >> 2] = $F5_0;
    HEAP32[$nb + ($113 + 12) >> 2] = $237;
    __label__ = 79;
    break;
   case 61:
    var $258 = $117;
    var $259 = $rsize_3_lcssa >>> 8;
    if (($259 | 0) == 0) {
      var $I7_0 = 0;
      __label__ = 64;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if ($rsize_3_lcssa >>> 0 > 16777215) {
      var $I7_0 = 31;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $266 = ($259 + 1048320 | 0) >>> 16 & 8;
    var $267 = $259 << $266;
    var $270 = ($267 + 520192 | 0) >>> 16 & 4;
    var $271 = $267 << $270;
    var $274 = ($271 + 245760 | 0) >>> 16 & 2;
    var $280 = 14 - ($270 | $266 | $274) + ($271 << $274 >>> 15) | 0;
    var $I7_0 = $rsize_3_lcssa >>> (($280 + 7 | 0) >>> 0) & 1 | $280 << 1;
    __label__ = 64;
    break;
   case 64:
    var $I7_0;
    var $287 = __gm_ + 304 + ($I7_0 << 2) | 0;
    HEAP32[$nb + ($113 + 28) >> 2] = $I7_0;
    var $290 = $nb + ($113 + 16) | 0;
    HEAP32[$nb + ($113 + 20) >> 2] = 0;
    HEAP32[$290 >> 2] = 0;
    var $294 = HEAP32[__gm_ + 4 >> 2];
    var $295 = 1 << $I7_0;
    if (($294 & $295 | 0) == 0) {
      __label__ = 65;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 65:
    var $299 = $294 | $295;
    HEAP32[__gm_ + 4 >> 2] = $299;
    HEAP32[$287 >> 2] = $258;
    HEAP32[$nb + ($113 + 24) >> 2] = $287;
    HEAP32[$nb + ($113 + 12) >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $258;
    __label__ = 79;
    break;
   case 66:
    var $308 = HEAP32[$287 >> 2];
    if (($I7_0 | 0) == 31) {
      var $314 = 0;
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $314 = 25 - ($I7_0 >>> 1) | 0;
    __label__ = 68;
    break;
   case 68:
    var $314;
    var $K12_0 = $rsize_3_lcssa << $314;
    var $T_0 = $308;
    __label__ = 69;
    break;
   case 69:
    var $T_0;
    var $K12_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($rsize_3_lcssa | 0)) {
      __label__ = 75;
      break;
    } else {
      __label__ = 70;
      break;
    }
   case 70:
    var $323 = $T_0 + 16 + ($K12_0 >>> 31 << 2) | 0;
    var $324 = HEAPU32[$323 >> 2];
    if (($324 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      __label__ = 71;
      break;
    }
   case 71:
    var $K12_0 = $K12_0 << 1;
    var $T_0 = $324;
    __label__ = 69;
    break;
   case 72:
    if ($323 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    HEAP32[$323 >> 2] = $258;
    HEAP32[$nb + ($113 + 24) >> 2] = $T_0;
    HEAP32[$nb + ($113 + 12) >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $258;
    __label__ = 79;
    break;
   case 74:
    _abort();
    throw "Reached an unreachable!";
   case 75:
    var $341 = $T_0 + 8 | 0;
    var $342 = HEAPU32[$341 >> 2];
    var $344 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $344 >>> 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    if ($342 >>> 0 < $344 >>> 0) {
      __label__ = 78;
      break;
    } else {
      __label__ = 77;
      break;
    }
   case 77:
    HEAP32[$342 + 12 >> 2] = $258;
    HEAP32[$341 >> 2] = $258;
    HEAP32[$nb + ($113 + 8) >> 2] = $342;
    HEAP32[$nb + ($113 + 12) >> 2] = $T_0;
    HEAP32[$nb + ($113 + 24) >> 2] = 0;
    __label__ = 79;
    break;
   case 78:
    _abort();
    throw "Reached an unreachable!";
   case 79:
    var $_0 = $v_3_lcssa + 8 | 0;
    __label__ = 81;
    break;
   case 80:
    _abort();
    throw "Reached an unreachable!";
   case 81:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_tmalloc_large["X"] = 1;

function _sys_alloc($nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    if ((HEAP32[__gm_ + 440 >> 2] & 4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 4:
    var $9 = HEAP32[__gm_ + 24 >> 2];
    if (($9 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $12 = $9;
    var $13 = _segment_holding($12);
    if (($13 | 0) == 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $15 = _sbrk(0);
    if (($15 | 0) == -1) {
      __label__ = 14;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $18 = HEAP32[_mparams + 8 >> 2];
    var $22 = $18 + ($nb + 47) & -$18;
    var $23 = $15;
    var $24 = HEAP32[_mparams + 4 >> 2];
    var $25 = $24 - 1 | 0;
    if (($25 & $23 | 0) == 0) {
      var $asize_0 = $22;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $asize_0 = $22 - $23 + ($25 + $23 & -$24) | 0;
    __label__ = 9;
    break;
   case 9:
    var $asize_0;
    if ($asize_0 >>> 0 < 2147483647) {
      __label__ = 10;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 10:
    var $37 = _sbrk($asize_0);
    if (($37 | 0) == ($15 | 0)) {
      var $tbase_0 = $15;
      var $asize_1 = $asize_0;
      var $br_0 = $37;
      __label__ = 13;
      break;
    } else {
      var $br_08 = $37;
      var $asize_19 = $asize_0;
      __label__ = 15;
      break;
    }
   case 11:
    var $41 = HEAP32[_mparams + 8 >> 2];
    var $46 = $nb + 47 - HEAP32[__gm_ + 12 >> 2] + $41 & -$41;
    if ($46 >>> 0 < 2147483647) {
      __label__ = 12;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 12:
    var $49 = _sbrk($46);
    if (($49 | 0) == (HEAP32[$13 >> 2] + HEAP32[$13 + 4 >> 2] | 0)) {
      var $tbase_0 = $49;
      var $asize_1 = $46;
      var $br_0 = $49;
      __label__ = 13;
      break;
    } else {
      var $br_08 = $49;
      var $asize_19 = $46;
      __label__ = 15;
      break;
    }
   case 13:
    var $br_0;
    var $asize_1;
    var $tbase_0;
    if (($tbase_0 | 0) == -1) {
      var $br_08 = $br_0;
      var $asize_19 = $asize_1;
      __label__ = 15;
      break;
    } else {
      var $tsize_220 = $asize_1;
      var $tbase_221 = $tbase_0;
      __label__ = 26;
      break;
    }
   case 14:
    var $59 = HEAP32[__gm_ + 440 >> 2] | 4;
    HEAP32[__gm_ + 440 >> 2] = $59;
    __label__ = 23;
    break;
   case 15:
    var $asize_19;
    var $br_08;
    var $60 = -$asize_19 | 0;
    if (($br_08 | 0) != -1 & $asize_19 >>> 0 < 2147483647) {
      __label__ = 16;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 16:
    if ($asize_19 >>> 0 < ($nb + 48 | 0) >>> 0) {
      __label__ = 17;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 17:
    var $67 = HEAP32[_mparams + 8 >> 2];
    var $72 = $nb + 47 - $asize_19 + $67 & -$67;
    if ($72 >>> 0 < 2147483647) {
      __label__ = 18;
      break;
    } else {
      var $asize_2 = $asize_19;
      __label__ = 21;
      break;
    }
   case 18:
    var $75 = _sbrk($72);
    if (($75 | 0) == -1) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $asize_2 = $72 + $asize_19 | 0;
    __label__ = 21;
    break;
   case 20:
    var $79 = _sbrk($60);
    __label__ = 22;
    break;
   case 21:
    var $asize_2;
    if (($br_08 | 0) == -1) {
      __label__ = 22;
      break;
    } else {
      var $tsize_220 = $asize_2;
      var $tbase_221 = $br_08;
      __label__ = 26;
      break;
    }
   case 22:
    var $84 = HEAP32[__gm_ + 440 >> 2] | 4;
    HEAP32[__gm_ + 440 >> 2] = $84;
    __label__ = 23;
    break;
   case 23:
    var $85 = HEAP32[_mparams + 8 >> 2];
    var $89 = $85 + ($nb + 47) & -$85;
    if ($89 >>> 0 < 2147483647) {
      __label__ = 24;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 24:
    var $92 = _sbrk($89);
    var $93 = _sbrk(0);
    if (($93 | 0) != -1 & ($92 | 0) != -1 & $92 >>> 0 < $93 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 25:
    var $98 = $93 - $92 | 0;
    if ($98 >>> 0 <= ($nb + 40 | 0) >>> 0 | ($92 | 0) == -1) {
      __label__ = 49;
      break;
    } else {
      var $tsize_220 = $98;
      var $tbase_221 = $92;
      __label__ = 26;
      break;
    }
   case 26:
    var $tbase_221;
    var $tsize_220;
    var $103 = HEAP32[__gm_ + 432 >> 2] + $tsize_220 | 0;
    HEAP32[__gm_ + 432 >> 2] = $103;
    if ($103 >>> 0 > HEAPU32[__gm_ + 436 >> 2] >>> 0) {
      __label__ = 27;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 27:
    HEAP32[__gm_ + 436 >> 2] = $103;
    __label__ = 28;
    break;
   case 28:
    var $108 = HEAPU32[__gm_ + 24 >> 2];
    if (($108 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      var $sp_0 = __gm_ + 444 | 0;
      __label__ = 32;
      break;
    }
   case 29:
    var $111 = HEAPU32[__gm_ + 16 >> 2];
    if (($111 | 0) == 0 | $tbase_221 >>> 0 < $111 >>> 0) {
      __label__ = 30;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 30:
    HEAP32[__gm_ + 16 >> 2] = $tbase_221;
    __label__ = 31;
    break;
   case 31:
    HEAP32[__gm_ + 444 >> 2] = $tbase_221;
    HEAP32[__gm_ + 448 >> 2] = $tsize_220;
    HEAP32[__gm_ + 456 >> 2] = 0;
    var $116 = HEAP32[_mparams >> 2];
    HEAP32[__gm_ + 36 >> 2] = $116;
    HEAP32[__gm_ + 32 >> 2] = -1;
    _init_bins();
    _init_top($tbase_221, $tsize_220 - 40 | 0);
    __label__ = 47;
    break;
   case 32:
    var $sp_0;
    if (($sp_0 | 0) == 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 33:
    var $122 = HEAPU32[$sp_0 >> 2];
    var $123 = $sp_0 + 4 | 0;
    var $124 = HEAPU32[$123 >> 2];
    var $125 = $122 + $124 | 0;
    if (($tbase_221 | 0) == ($125 | 0)) {
      __label__ = 35;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 34:
    var $sp_0 = HEAP32[$sp_0 + 8 >> 2];
    __label__ = 32;
    break;
   case 35:
    if ((HEAP32[$sp_0 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 36;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 36:
    var $135 = $108;
    if ($135 >>> 0 >= $122 >>> 0 & $135 >>> 0 < $125 >>> 0) {
      __label__ = 37;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 37:
    HEAP32[$123 >> 2] = $124 + $tsize_220 | 0;
    var $140 = HEAP32[__gm_ + 24 >> 2];
    var $142 = HEAP32[__gm_ + 12 >> 2] + $tsize_220 | 0;
    _init_top($140, $142);
    __label__ = 47;
    break;
   case 38:
    if ($tbase_221 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 39;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 39:
    HEAP32[__gm_ + 16 >> 2] = $tbase_221;
    __label__ = 40;
    break;
   case 40:
    var $146 = $tbase_221 + $tsize_220 | 0;
    var $sp_1 = __gm_ + 444 | 0;
    __label__ = 41;
    break;
   case 41:
    var $sp_1;
    if (($sp_1 | 0) == 0) {
      __label__ = 46;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    var $150 = $sp_1 | 0;
    var $151 = HEAPU32[$150 >> 2];
    if (($151 | 0) == ($146 | 0)) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    var $sp_1 = HEAP32[$sp_1 + 8 >> 2];
    __label__ = 41;
    break;
   case 44:
    if ((HEAP32[$sp_1 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 45:
    HEAP32[$150 >> 2] = $tbase_221;
    var $161 = $sp_1 + 4 | 0;
    var $163 = HEAP32[$161 >> 2] + $tsize_220 | 0;
    HEAP32[$161 >> 2] = $163;
    var $164 = _prepend_alloc($tbase_221, $151, $nb);
    var $_0 = $164;
    __label__ = 50;
    break;
   case 46:
    _add_segment($tbase_221, $tsize_220);
    __label__ = 47;
    break;
   case 47:
    var $166 = HEAPU32[__gm_ + 12 >> 2];
    if ($166 >>> 0 > $nb >>> 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 49;
      break;
    }
   case 48:
    var $169 = $166 - $nb | 0;
    HEAP32[__gm_ + 12 >> 2] = $169;
    var $170 = HEAPU32[__gm_ + 24 >> 2];
    var $171 = $170;
    HEAP32[__gm_ + 24 >> 2] = $171 + $nb | 0;
    HEAP32[$nb + ($171 + 4) >> 2] = $169 | 1;
    HEAP32[$170 + 4 >> 2] = $nb | 3;
    var $_0 = $170 + 8 | 0;
    __label__ = 50;
    break;
   case 49:
    var $181 = ___errno();
    HEAP32[$181 >> 2] = 12;
    var $_0 = 0;
    __label__ = 50;
    break;
   case 50:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_sys_alloc["X"] = 1;

function _sys_trim($pad) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    if ($pad >>> 0 < 4294967232) {
      __label__ = 4;
      break;
    } else {
      var $released_2 = 0;
      __label__ = 13;
      break;
    }
   case 4:
    var $7 = HEAPU32[__gm_ + 24 >> 2];
    if (($7 | 0) == 0) {
      var $released_2 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $11 = HEAPU32[__gm_ + 12 >> 2];
    if ($11 >>> 0 > ($pad + 40 | 0) >>> 0) {
      __label__ = 6;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 6:
    var $14 = HEAPU32[_mparams + 8 >> 2];
    var $17 = -40 - $pad - 1 + $11 + $14 | 0;
    var $18 = Math.floor(($17 >>> 0) / ($14 >>> 0));
    var $20 = ($18 - 1) * $14 | 0;
    var $21 = $7;
    var $22 = _segment_holding($21);
    if ((HEAP32[$22 + 12 >> 2] & 8 | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 7:
    var $28 = _sbrk(0);
    var $31 = $22 + 4 | 0;
    if (($28 | 0) == (HEAP32[$22 >> 2] + HEAP32[$31 >> 2] | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $_ = $20 >>> 0 > 2147483646 ? -2147483648 - $14 | 0 : $20;
    var $38 = -$_ | 0;
    var $39 = _sbrk($38);
    var $40 = _sbrk(0);
    if (($39 | 0) != -1 & $40 >>> 0 < $28 >>> 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 9:
    var $46 = $28 - $40 | 0;
    if (($28 | 0) == ($40 | 0)) {
      __label__ = 11;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $50 = HEAP32[$31 >> 2] - $46 | 0;
    HEAP32[$31 >> 2] = $50;
    var $52 = HEAP32[__gm_ + 432 >> 2] - $46 | 0;
    HEAP32[__gm_ + 432 >> 2] = $52;
    var $53 = HEAP32[__gm_ + 24 >> 2];
    var $55 = HEAP32[__gm_ + 12 >> 2] - $46 | 0;
    _init_top($53, $55);
    var $released_2 = ($28 | 0) != ($40 | 0);
    __label__ = 13;
    break;
   case 11:
    if (HEAPU32[__gm_ + 12 >> 2] >>> 0 > HEAPU32[__gm_ + 28 >> 2] >>> 0) {
      __label__ = 12;
      break;
    } else {
      var $released_2 = 0;
      __label__ = 13;
      break;
    }
   case 12:
    HEAP32[__gm_ + 28 >> 2] = -1;
    var $released_2 = 0;
    __label__ = 13;
    break;
   case 13:
    var $released_2;
    return $released_2 & 1;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_sys_trim["X"] = 1;

function _free($mem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($mem | 0) == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $mem - 8 | 0;
    var $4 = $3;
    var $5 = HEAPU32[__gm_ + 16 >> 2];
    if ($3 >>> 0 < $5 >>> 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $10 = HEAPU32[$mem - 4 >> 2];
    var $11 = $10 & 3;
    if (($11 | 0) == 1) {
      __label__ = 127;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $14 = $10 & -8;
    var $15 = $mem + ($14 - 8) | 0;
    var $16 = $15;
    if (($10 & 1 | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      var $p_0 = $4;
      var $psize_0 = $14;
      __label__ = 48;
      break;
    }
   case 5:
    var $21 = HEAPU32[$3 >> 2];
    if (($11 | 0) == 0) {
      __label__ = 128;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $_sum2 = -8 - $21 | 0;
    var $24 = $mem + $_sum2 | 0;
    var $25 = $24;
    var $26 = $21 + $14 | 0;
    if ($24 >>> 0 < $5 >>> 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    if (($25 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 46;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $32 = $21 >>> 3;
    if ($21 >>> 0 < 256) {
      __label__ = 9;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 9:
    var $37 = HEAPU32[$_sum2 + ($mem + 8) >> 2];
    var $40 = HEAPU32[$_sum2 + ($mem + 12) >> 2];
    if (($37 | 0) == ($40 | 0)) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    var $46 = HEAP32[__gm_ >> 2] & (1 << $32 ^ -1);
    HEAP32[__gm_ >> 2] = $46;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 11:
    var $51 = __gm_ + 40 + (($21 >>> 2 & 1073741822) << 2) | 0;
    if (($37 | 0) != ($51 | 0) & $37 >>> 0 < $5 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    if (($40 | 0) == ($51 | 0) | $40 >>> 0 >= $5 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 13:
    HEAP32[$37 + 12 >> 2] = $40;
    HEAP32[$40 + 8 >> 2] = $37;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 14:
    _abort();
    throw "Reached an unreachable!";
   case 15:
    var $62 = $24;
    var $65 = HEAPU32[$_sum2 + ($mem + 24) >> 2];
    var $68 = HEAPU32[$_sum2 + ($mem + 12) >> 2];
    if (($68 | 0) == ($62 | 0)) {
      __label__ = 19;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    var $73 = HEAPU32[$_sum2 + ($mem + 8) >> 2];
    if ($73 >>> 0 < $5 >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$73 + 12 >> 2] = $68;
    HEAP32[$68 + 8 >> 2] = $73;
    var $R_1 = $68;
    __label__ = 26;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $82 = $_sum2 + ($mem + 20) | 0;
    var $83 = HEAP32[$82 >> 2];
    if (($83 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      var $RP_0 = $82;
      var $R_0 = $83;
      __label__ = 21;
      break;
    }
   case 20:
    var $87 = $_sum2 + ($mem + 16) | 0;
    var $88 = HEAP32[$87 >> 2];
    if (($88 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 26;
      break;
    } else {
      var $RP_0 = $87;
      var $R_0 = $88;
      __label__ = 21;
      break;
    }
   case 21:
    var $R_0;
    var $RP_0;
    var $90 = $R_0 + 20 | 0;
    var $91 = HEAP32[$90 >> 2];
    if (($91 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      var $RP_0 = $90;
      var $R_0 = $91;
      __label__ = 21;
      break;
    }
   case 22:
    var $94 = $R_0 + 16 | 0;
    var $95 = HEAPU32[$94 >> 2];
    if (($95 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      var $RP_0 = $94;
      var $R_0 = $95;
      __label__ = 21;
      break;
    }
   case 23:
    if ($RP_0 >>> 0 < $5 >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 26;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $R_1;
    if (($65 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    var $106 = $_sum2 + ($mem + 28) | 0;
    var $108 = __gm_ + 304 + (HEAP32[$106 >> 2] << 2) | 0;
    if (($62 | 0) == (HEAP32[$108 >> 2] | 0)) {
      __label__ = 28;
      break;
    } else {
      __label__ = 30;
      break;
    }
   case 28:
    HEAP32[$108 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 29:
    var $116 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$106 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $116;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 30:
    if ($65 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 34;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $122 = $65 + 16 | 0;
    if ((HEAP32[$122 >> 2] | 0) == ($62 | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 33;
      break;
    }
   case 32:
    HEAP32[$122 >> 2] = $R_1;
    __label__ = 35;
    break;
   case 33:
    HEAP32[$65 + 20 >> 2] = $R_1;
    __label__ = 35;
    break;
   case 34:
    _abort();
    throw "Reached an unreachable!";
   case 35:
    if (($R_1 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 36;
      break;
    }
   case 36:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 37:
    HEAP32[$R_1 + 24 >> 2] = $65;
    var $139 = HEAPU32[$_sum2 + ($mem + 16) >> 2];
    if (($139 | 0) == 0) {
      __label__ = 41;
      break;
    } else {
      __label__ = 38;
      break;
    }
   case 38:
    if ($139 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 40;
      break;
    } else {
      __label__ = 39;
      break;
    }
   case 39:
    HEAP32[$R_1 + 16 >> 2] = $139;
    HEAP32[$139 + 24 >> 2] = $R_1;
    __label__ = 41;
    break;
   case 40:
    _abort();
    throw "Reached an unreachable!";
   case 41:
    var $152 = HEAPU32[$_sum2 + ($mem + 20) >> 2];
    if (($152 | 0) == 0) {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ($152 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    HEAP32[$R_1 + 20 >> 2] = $152;
    HEAP32[$152 + 24 >> 2] = $R_1;
    var $p_0 = $25;
    var $psize_0 = $26;
    __label__ = 48;
    break;
   case 44:
    _abort();
    throw "Reached an unreachable!";
   case 45:
    _abort();
    throw "Reached an unreachable!";
   case 46:
    var $165 = $mem + ($14 - 4) | 0;
    if ((HEAP32[$165 >> 2] & 3 | 0) == 3) {
      __label__ = 47;
      break;
    } else {
      var $p_0 = $25;
      var $psize_0 = $26;
      __label__ = 48;
      break;
    }
   case 47:
    HEAP32[__gm_ + 8 >> 2] = $26;
    var $171 = HEAP32[$165 >> 2] & -2;
    HEAP32[$165 >> 2] = $171;
    HEAP32[$_sum2 + ($mem + 4) >> 2] = $26 | 1;
    HEAP32[$15 >> 2] = $26;
    __label__ = 128;
    break;
   case 48:
    var $psize_0;
    var $p_0;
    var $177 = $p_0;
    if ($177 >>> 0 < $15 >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 127;
      break;
    }
   case 49:
    var $181 = $mem + ($14 - 4) | 0;
    var $182 = HEAPU32[$181 >> 2];
    if (($182 & 1 | 0) == 0) {
      __label__ = 127;
      break;
    } else {
      __label__ = 50;
      break;
    }
   case 50:
    if (($182 & 2 | 0) == 0) {
      __label__ = 51;
      break;
    } else {
      __label__ = 100;
      break;
    }
   case 51:
    if (($16 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 52;
      break;
    } else {
      __label__ = 56;
      break;
    }
   case 52:
    var $193 = HEAP32[__gm_ + 12 >> 2] + $psize_0 | 0;
    HEAP32[__gm_ + 12 >> 2] = $193;
    HEAP32[__gm_ + 24 >> 2] = $p_0;
    var $194 = $193 | 1;
    HEAP32[$p_0 + 4 >> 2] = $194;
    if (($p_0 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    HEAP32[__gm_ + 20 >> 2] = 0;
    HEAP32[__gm_ + 8 >> 2] = 0;
    __label__ = 54;
    break;
   case 54:
    if ($193 >>> 0 > HEAPU32[__gm_ + 28 >> 2] >>> 0) {
      __label__ = 55;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 55:
    var $203 = _sys_trim(0);
    __label__ = 128;
    break;
   case 56:
    if (($16 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 57;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 57:
    var $209 = HEAP32[__gm_ + 8 >> 2] + $psize_0 | 0;
    HEAP32[__gm_ + 8 >> 2] = $209;
    HEAP32[__gm_ + 20 >> 2] = $p_0;
    var $210 = $209 | 1;
    HEAP32[$p_0 + 4 >> 2] = $210;
    var $213 = $177 + $209 | 0;
    HEAP32[$213 >> 2] = $209;
    __label__ = 128;
    break;
   case 58:
    var $216 = ($182 & -8) + $psize_0 | 0;
    var $217 = $182 >>> 3;
    if ($182 >>> 0 < 256) {
      __label__ = 59;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 59:
    var $222 = HEAPU32[$mem + $14 >> 2];
    var $225 = HEAPU32[$mem + ($14 | 4) >> 2];
    if (($222 | 0) == ($225 | 0)) {
      __label__ = 60;
      break;
    } else {
      __label__ = 61;
      break;
    }
   case 60:
    var $231 = HEAP32[__gm_ >> 2] & (1 << $217 ^ -1);
    HEAP32[__gm_ >> 2] = $231;
    __label__ = 98;
    break;
   case 61:
    var $236 = __gm_ + 40 + (($182 >>> 2 & 1073741822) << 2) | 0;
    if (($222 | 0) == ($236 | 0)) {
      __label__ = 63;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 62:
    if ($222 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    if (($225 | 0) == ($236 | 0)) {
      __label__ = 65;
      break;
    } else {
      __label__ = 64;
      break;
    }
   case 64:
    if ($225 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 66;
      break;
    } else {
      __label__ = 65;
      break;
    }
   case 65:
    HEAP32[$222 + 12 >> 2] = $225;
    HEAP32[$225 + 8 >> 2] = $222;
    __label__ = 98;
    break;
   case 66:
    _abort();
    throw "Reached an unreachable!";
   case 67:
    var $251 = $15;
    var $254 = HEAPU32[$14 + ($mem + 16) >> 2];
    var $257 = HEAPU32[$mem + ($14 | 4) >> 2];
    if (($257 | 0) == ($251 | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 68;
      break;
    }
   case 68:
    var $262 = HEAPU32[$mem + $14 >> 2];
    if ($262 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    HEAP32[$262 + 12 >> 2] = $257;
    HEAP32[$257 + 8 >> 2] = $262;
    var $R7_1 = $257;
    __label__ = 78;
    break;
   case 70:
    _abort();
    throw "Reached an unreachable!";
   case 71:
    var $272 = $14 + ($mem + 12) | 0;
    var $273 = HEAP32[$272 >> 2];
    if (($273 | 0) == 0) {
      __label__ = 72;
      break;
    } else {
      var $RP9_0 = $272;
      var $R7_0 = $273;
      __label__ = 73;
      break;
    }
   case 72:
    var $277 = $14 + ($mem + 8) | 0;
    var $278 = HEAP32[$277 >> 2];
    if (($278 | 0) == 0) {
      var $R7_1 = 0;
      __label__ = 78;
      break;
    } else {
      var $RP9_0 = $277;
      var $R7_0 = $278;
      __label__ = 73;
      break;
    }
   case 73:
    var $R7_0;
    var $RP9_0;
    var $280 = $R7_0 + 20 | 0;
    var $281 = HEAP32[$280 >> 2];
    if (($281 | 0) == 0) {
      __label__ = 74;
      break;
    } else {
      var $RP9_0 = $280;
      var $R7_0 = $281;
      __label__ = 73;
      break;
    }
   case 74:
    var $284 = $R7_0 + 16 | 0;
    var $285 = HEAPU32[$284 >> 2];
    if (($285 | 0) == 0) {
      __label__ = 75;
      break;
    } else {
      var $RP9_0 = $284;
      var $R7_0 = $285;
      __label__ = 73;
      break;
    }
   case 75:
    if ($RP9_0 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 77;
      break;
    } else {
      __label__ = 76;
      break;
    }
   case 76:
    HEAP32[$RP9_0 >> 2] = 0;
    var $R7_1 = $R7_0;
    __label__ = 78;
    break;
   case 77:
    _abort();
    throw "Reached an unreachable!";
   case 78:
    var $R7_1;
    if (($254 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 79;
      break;
    }
   case 79:
    var $297 = $14 + ($mem + 20) | 0;
    var $299 = __gm_ + 304 + (HEAP32[$297 >> 2] << 2) | 0;
    if (($251 | 0) == (HEAP32[$299 >> 2] | 0)) {
      __label__ = 80;
      break;
    } else {
      __label__ = 82;
      break;
    }
   case 80:
    HEAP32[$299 >> 2] = $R7_1;
    if (($R7_1 | 0) == 0) {
      __label__ = 81;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 81:
    var $307 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$297 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $307;
    __label__ = 98;
    break;
   case 82:
    if ($254 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 86;
      break;
    } else {
      __label__ = 83;
      break;
    }
   case 83:
    var $313 = $254 + 16 | 0;
    if ((HEAP32[$313 >> 2] | 0) == ($251 | 0)) {
      __label__ = 84;
      break;
    } else {
      __label__ = 85;
      break;
    }
   case 84:
    HEAP32[$313 >> 2] = $R7_1;
    __label__ = 87;
    break;
   case 85:
    HEAP32[$254 + 20 >> 2] = $R7_1;
    __label__ = 87;
    break;
   case 86:
    _abort();
    throw "Reached an unreachable!";
   case 87:
    if (($R7_1 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 88;
      break;
    }
   case 88:
    if ($R7_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 97;
      break;
    } else {
      __label__ = 89;
      break;
    }
   case 89:
    HEAP32[$R7_1 + 24 >> 2] = $254;
    var $330 = HEAPU32[$14 + ($mem + 8) >> 2];
    if (($330 | 0) == 0) {
      __label__ = 93;
      break;
    } else {
      __label__ = 90;
      break;
    }
   case 90:
    if ($330 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 92;
      break;
    } else {
      __label__ = 91;
      break;
    }
   case 91:
    HEAP32[$R7_1 + 16 >> 2] = $330;
    HEAP32[$330 + 24 >> 2] = $R7_1;
    __label__ = 93;
    break;
   case 92:
    _abort();
    throw "Reached an unreachable!";
   case 93:
    var $343 = HEAPU32[$14 + ($mem + 12) >> 2];
    if (($343 | 0) == 0) {
      __label__ = 98;
      break;
    } else {
      __label__ = 94;
      break;
    }
   case 94:
    if ($343 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 96;
      break;
    } else {
      __label__ = 95;
      break;
    }
   case 95:
    HEAP32[$R7_1 + 20 >> 2] = $343;
    HEAP32[$343 + 24 >> 2] = $R7_1;
    __label__ = 98;
    break;
   case 96:
    _abort();
    throw "Reached an unreachable!";
   case 97:
    _abort();
    throw "Reached an unreachable!";
   case 98:
    HEAP32[$p_0 + 4 >> 2] = $216 | 1;
    HEAP32[$177 + $216 >> 2] = $216;
    if (($p_0 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 99;
      break;
    } else {
      var $psize_1 = $216;
      __label__ = 101;
      break;
    }
   case 99:
    HEAP32[__gm_ + 8 >> 2] = $216;
    __label__ = 128;
    break;
   case 100:
    HEAP32[$181 >> 2] = $182 & -2;
    HEAP32[$p_0 + 4 >> 2] = $psize_0 | 1;
    HEAP32[$177 + $psize_0 >> 2] = $psize_0;
    var $psize_1 = $psize_0;
    __label__ = 101;
    break;
   case 101:
    var $psize_1;
    if ($psize_1 >>> 0 < 256) {
      __label__ = 102;
      break;
    } else {
      __label__ = 107;
      break;
    }
   case 102:
    var $373 = $psize_1 >>> 2 & 1073741822;
    var $375 = __gm_ + 40 + ($373 << 2) | 0;
    var $376 = HEAPU32[__gm_ >> 2];
    var $377 = 1 << ($psize_1 >>> 3);
    if (($376 & $377 | 0) == 0) {
      __label__ = 103;
      break;
    } else {
      __label__ = 104;
      break;
    }
   case 103:
    HEAP32[__gm_ >> 2] = $376 | $377;
    var $F16_0 = $375;
    var $_pre_phi = __gm_ + 40 + ($373 + 2 << 2) | 0;
    __label__ = 106;
    break;
   case 104:
    var $383 = __gm_ + 40 + ($373 + 2 << 2) | 0;
    var $384 = HEAPU32[$383 >> 2];
    if ($384 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 105;
      break;
    } else {
      var $F16_0 = $384;
      var $_pre_phi = $383;
      __label__ = 106;
      break;
    }
   case 105:
    _abort();
    throw "Reached an unreachable!";
   case 106:
    var $_pre_phi;
    var $F16_0;
    HEAP32[$_pre_phi >> 2] = $p_0;
    HEAP32[$F16_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $F16_0;
    HEAP32[$p_0 + 12 >> 2] = $375;
    __label__ = 128;
    break;
   case 107:
    var $394 = $p_0;
    var $395 = $psize_1 >>> 8;
    if (($395 | 0) == 0) {
      var $I18_0 = 0;
      __label__ = 110;
      break;
    } else {
      __label__ = 108;
      break;
    }
   case 108:
    if ($psize_1 >>> 0 > 16777215) {
      var $I18_0 = 31;
      __label__ = 110;
      break;
    } else {
      __label__ = 109;
      break;
    }
   case 109:
    var $402 = ($395 + 1048320 | 0) >>> 16 & 8;
    var $403 = $395 << $402;
    var $406 = ($403 + 520192 | 0) >>> 16 & 4;
    var $407 = $403 << $406;
    var $410 = ($407 + 245760 | 0) >>> 16 & 2;
    var $416 = 14 - ($406 | $402 | $410) + ($407 << $410 >>> 15) | 0;
    var $I18_0 = $psize_1 >>> (($416 + 7 | 0) >>> 0) & 1 | $416 << 1;
    __label__ = 110;
    break;
   case 110:
    var $I18_0;
    var $423 = __gm_ + 304 + ($I18_0 << 2) | 0;
    HEAP32[$p_0 + 28 >> 2] = $I18_0;
    HEAP32[$p_0 + 20 >> 2] = 0;
    HEAP32[$p_0 + 16 >> 2] = 0;
    var $427 = HEAP32[__gm_ + 4 >> 2];
    var $428 = 1 << $I18_0;
    if (($427 & $428 | 0) == 0) {
      __label__ = 111;
      break;
    } else {
      __label__ = 112;
      break;
    }
   case 111:
    var $432 = $427 | $428;
    HEAP32[__gm_ + 4 >> 2] = $432;
    HEAP32[$423 >> 2] = $394;
    HEAP32[$p_0 + 24 >> 2] = $423;
    HEAP32[$p_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $p_0;
    __label__ = 125;
    break;
   case 112:
    var $437 = HEAP32[$423 >> 2];
    if (($I18_0 | 0) == 31) {
      var $443 = 0;
      __label__ = 114;
      break;
    } else {
      __label__ = 113;
      break;
    }
   case 113:
    var $443 = 25 - ($I18_0 >>> 1) | 0;
    __label__ = 114;
    break;
   case 114:
    var $443;
    var $K19_0 = $psize_1 << $443;
    var $T_0 = $437;
    __label__ = 115;
    break;
   case 115:
    var $T_0;
    var $K19_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($psize_1 | 0)) {
      __label__ = 121;
      break;
    } else {
      __label__ = 116;
      break;
    }
   case 116:
    var $452 = $T_0 + 16 + ($K19_0 >>> 31 << 2) | 0;
    var $453 = HEAPU32[$452 >> 2];
    if (($453 | 0) == 0) {
      __label__ = 118;
      break;
    } else {
      __label__ = 117;
      break;
    }
   case 117:
    var $K19_0 = $K19_0 << 1;
    var $T_0 = $453;
    __label__ = 115;
    break;
   case 118:
    if ($452 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 120;
      break;
    } else {
      __label__ = 119;
      break;
    }
   case 119:
    HEAP32[$452 >> 2] = $394;
    HEAP32[$p_0 + 24 >> 2] = $T_0;
    HEAP32[$p_0 + 12 >> 2] = $p_0;
    HEAP32[$p_0 + 8 >> 2] = $p_0;
    __label__ = 125;
    break;
   case 120:
    _abort();
    throw "Reached an unreachable!";
   case 121:
    var $467 = $T_0 + 8 | 0;
    var $468 = HEAPU32[$467 >> 2];
    var $470 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $470 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 122;
      break;
    }
   case 122:
    if ($468 >>> 0 < $470 >>> 0) {
      __label__ = 124;
      break;
    } else {
      __label__ = 123;
      break;
    }
   case 123:
    HEAP32[$468 + 12 >> 2] = $394;
    HEAP32[$467 >> 2] = $394;
    HEAP32[$p_0 + 8 >> 2] = $468;
    HEAP32[$p_0 + 12 >> 2] = $T_0;
    HEAP32[$p_0 + 24 >> 2] = 0;
    __label__ = 125;
    break;
   case 124:
    _abort();
    throw "Reached an unreachable!";
   case 125:
    var $482 = HEAP32[__gm_ + 32 >> 2] - 1 | 0;
    HEAP32[__gm_ + 32 >> 2] = $482;
    if (($482 | 0) == 0) {
      __label__ = 126;
      break;
    } else {
      __label__ = 128;
      break;
    }
   case 126:
    _release_unused_segments();
    __label__ = 128;
    break;
   case 127:
    _abort();
    throw "Reached an unreachable!";
   case 128:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

Module["_free"] = _free;

_free["X"] = 1;

function _malloc_footprint() {
  return HEAP32[__gm_ + 432 >> 2];
}

function _malloc_max_footprint() {
  return HEAP32[__gm_ + 436 >> 2];
}

function _release_unused_segments() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sp_01 = HEAP32[__gm_ + 452 >> 2];
    if (($sp_01 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $sp_02 = $sp_01;
      __label__ = 2;
      break;
    }
   case 2:
    var $sp_02;
    var $sp_0 = HEAP32[$sp_02 + 8 >> 2];
    if (($sp_0 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      var $sp_02 = $sp_0;
      __label__ = 2;
      break;
    }
   case 3:
    HEAP32[__gm_ + 32 >> 2] = -1;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _calloc($n_elements, $elem_size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($n_elements | 0) == 0) {
      var $req_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = $elem_size * $n_elements | 0;
    if (($elem_size | $n_elements) >>> 0 > 65535) {
      __label__ = 3;
      break;
    } else {
      var $req_0 = $3;
      __label__ = 5;
      break;
    }
   case 3:
    var $7 = Math.floor(($3 >>> 0) / ($n_elements >>> 0));
    if (($7 | 0) == ($elem_size | 0)) {
      var $req_0 = $3;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $req_0 = -1;
    __label__ = 5;
    break;
   case 5:
    var $req_0;
    var $11 = _malloc($req_0);
    if (($11 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ((HEAP32[$11 - 4 >> 2] & 3 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    _memset($11, 0, $req_0, 1);
    __label__ = 8;
    break;
   case 8:
    return $11;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _realloc($oldmem, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($oldmem | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _malloc($bytes);
    var $_0 = $3;
    __label__ = 4;
    break;
   case 3:
    var $5 = _internal_realloc($oldmem, $bytes);
    var $_0 = $5;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _memalign($alignment, $bytes) {
  var $1 = _internal_memalign($alignment, $bytes);
  return $1;
}

function _internal_memalign($alignment, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($alignment >>> 0 < 9) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = _malloc($bytes);
    var $_0 = $3;
    __label__ = 25;
    break;
   case 3:
    var $_01 = $alignment >>> 0 < 16 ? 16 : $alignment;
    if (($_01 - 1 & $_01 | 0) == 0) {
      var $_1 = $_01;
      __label__ = 6;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($_01 >>> 0 > 16) {
      var $a_08 = 16;
      __label__ = 5;
      break;
    } else {
      var $_1 = 16;
      __label__ = 6;
      break;
    }
   case 5:
    var $a_08;
    var $10 = $a_08 << 1;
    if ($10 >>> 0 < $_01 >>> 0) {
      var $a_08 = $10;
      __label__ = 5;
      break;
    } else {
      var $_1 = $10;
      __label__ = 6;
      break;
    }
   case 6:
    var $_1;
    if ((-64 - $_1 | 0) >>> 0 > $bytes >>> 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $15 = ___errno();
    HEAP32[$15 >> 2] = 12;
    var $_0 = 0;
    __label__ = 25;
    break;
   case 8:
    if ($bytes >>> 0 < 11) {
      var $22 = 16;
      __label__ = 10;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    var $22 = $bytes + 11 & -8;
    __label__ = 10;
    break;
   case 10:
    var $22;
    var $25 = _malloc($22 + ($_1 + 12) | 0);
    if (($25 | 0) == 0) {
      var $_0 = 0;
      __label__ = 25;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $28 = $25 - 8 | 0;
    if ((($25 >>> 0) % ($_1 >>> 0) | 0) == 0) {
      var $p_0_in = $28;
      var $leader_1 = 0;
      __label__ = 17;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $37 = $25 + ($_1 - 1) & -$_1;
    var $38 = $37 - 8 | 0;
    var $40 = $28;
    if (($38 - $40 | 0) >>> 0 > 15) {
      var $46 = $38;
      __label__ = 14;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    var $46 = $37 + ($_1 - 8) | 0;
    __label__ = 14;
    break;
   case 14:
    var $46;
    var $48 = $46 - $40 | 0;
    var $50 = $25 - 4 | 0;
    var $51 = HEAP32[$50 >> 2];
    var $53 = ($51 & -8) - $48 | 0;
    if (($51 & 3 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 15:
    var $59 = HEAP32[$28 >> 2] + $48 | 0;
    HEAP32[$46 >> 2] = $59;
    HEAP32[$46 + 4 >> 2] = $53;
    var $p_0_in = $46;
    var $leader_1 = 0;
    __label__ = 17;
    break;
   case 16:
    var $65 = $46 + 4 | 0;
    var $69 = $53 | HEAP32[$65 >> 2] & 1 | 2;
    HEAP32[$65 >> 2] = $69;
    var $71 = $53 + ($46 + 4) | 0;
    var $73 = HEAP32[$71 >> 2] | 1;
    HEAP32[$71 >> 2] = $73;
    var $77 = $48 | HEAP32[$50 >> 2] & 1 | 2;
    HEAP32[$50 >> 2] = $77;
    var $79 = $25 + ($48 - 4) | 0;
    var $81 = HEAP32[$79 >> 2] | 1;
    HEAP32[$79 >> 2] = $81;
    var $p_0_in = $46;
    var $leader_1 = $25;
    __label__ = 17;
    break;
   case 17:
    var $leader_1;
    var $p_0_in;
    var $83 = $p_0_in + 4 | 0;
    var $84 = HEAPU32[$83 >> 2];
    if (($84 & 3 | 0) == 0) {
      var $trailer_0 = 0;
      __label__ = 20;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $88 = $84 & -8;
    if ($88 >>> 0 > ($22 + 16 | 0) >>> 0) {
      __label__ = 19;
      break;
    } else {
      var $trailer_0 = 0;
      __label__ = 20;
      break;
    }
   case 19:
    var $92 = $88 - $22 | 0;
    HEAP32[$83 >> 2] = $22 | $84 & 1 | 2;
    HEAP32[$p_0_in + ($22 | 4) >> 2] = $92 | 3;
    var $100 = $p_0_in + ($88 | 4) | 0;
    var $102 = HEAP32[$100 >> 2] | 1;
    HEAP32[$100 >> 2] = $102;
    var $trailer_0 = $22 + ($p_0_in + 8) | 0;
    __label__ = 20;
    break;
   case 20:
    var $trailer_0;
    if (($leader_1 | 0) == 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    _free($leader_1);
    __label__ = 22;
    break;
   case 22:
    if (($trailer_0 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    _free($trailer_0);
    __label__ = 24;
    break;
   case 24:
    var $_0 = $p_0_in + 8 | 0;
    __label__ = 25;
    break;
   case 25:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_internal_memalign["X"] = 1;

function _independent_calloc($n_elements, $elem_size, $chunks) {
  var __stackBase__ = STACKTOP;
  STACKTOP += 4;
  var $sz = __stackBase__;
  HEAP32[$sz >> 2] = $elem_size;
  var $1 = _ialloc($n_elements, $sz, 3, $chunks);
  STACKTOP = __stackBase__;
  return $1;
}

function _ialloc($n_elements, $sizes, $opts, $chunks) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $6 = ($n_elements | 0) == 0;
    if (($chunks | 0) == 0) {
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    if ($6) {
      var $_0 = $chunks;
      __label__ = 29;
      break;
    } else {
      var $marray_0 = $chunks;
      var $array_size_0 = 0;
      __label__ = 9;
      break;
    }
   case 5:
    if ($6) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $10 = _malloc(0);
    var $_0 = $10;
    __label__ = 29;
    break;
   case 7:
    var $13 = $n_elements << 2;
    if ($13 >>> 0 < 11) {
      var $marray_0 = 0;
      var $array_size_0 = 16;
      __label__ = 9;
      break;
    } else {
      __label__ = 8;
      break;
    }
   case 8:
    var $marray_0 = 0;
    var $array_size_0 = $13 + 11 & -8;
    __label__ = 9;
    break;
   case 9:
    var $array_size_0;
    var $marray_0;
    if (($opts & 1 | 0) == 0) {
      __label__ = 10;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 10:
    if ($6) {
      var $element_size_0 = 0;
      var $contents_size_1 = 0;
      __label__ = 17;
      break;
    } else {
      var $contents_size_07 = 0;
      var $i_08 = 0;
      __label__ = 14;
      break;
    }
   case 11:
    var $22 = HEAPU32[$sizes >> 2];
    if ($22 >>> 0 < 11) {
      var $28 = 16;
      __label__ = 13;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 12:
    var $28 = $22 + 11 & -8;
    __label__ = 13;
    break;
   case 13:
    var $28;
    var $element_size_0 = $28;
    var $contents_size_1 = $28 * $n_elements | 0;
    __label__ = 17;
    break;
   case 14:
    var $i_08;
    var $contents_size_07;
    var $31 = HEAPU32[$sizes + ($i_08 << 2) >> 2];
    if ($31 >>> 0 < 11) {
      var $37 = 16;
      __label__ = 16;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    var $37 = $31 + 11 & -8;
    __label__ = 16;
    break;
   case 16:
    var $37;
    var $38 = $37 + $contents_size_07 | 0;
    var $39 = $i_08 + 1 | 0;
    if (($39 | 0) == ($n_elements | 0)) {
      var $element_size_0 = 0;
      var $contents_size_1 = $38;
      __label__ = 17;
      break;
    } else {
      var $contents_size_07 = $38;
      var $i_08 = $39;
      __label__ = 14;
      break;
    }
   case 17:
    var $contents_size_1;
    var $element_size_0;
    var $43 = _malloc($array_size_0 - 4 + $contents_size_1 | 0);
    if (($43 | 0) == 0) {
      var $_0 = 0;
      __label__ = 29;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $46 = $43 - 8 | 0;
    var $50 = HEAP32[$43 - 4 >> 2] & -8;
    if (($opts & 2 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    var $55 = -4 - $array_size_0 + $50 | 0;
    _memset($43, 0, $55, 1);
    __label__ = 20;
    break;
   case 20:
    if (($marray_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      var $marray_1 = $marray_0;
      var $remainder_size_0 = $50;
      __label__ = 22;
      break;
    }
   case 21:
    var $61 = $43 + $contents_size_1 | 0;
    var $62 = $50 - $contents_size_1 | 3;
    HEAP32[$43 + ($contents_size_1 - 4) >> 2] = $62;
    var $marray_1 = $61;
    var $remainder_size_0 = $contents_size_1;
    __label__ = 22;
    break;
   case 22:
    var $remainder_size_0;
    var $marray_1;
    HEAP32[$marray_1 >> 2] = $43;
    var $66 = $n_elements - 1 | 0;
    if (($66 | 0) == 0) {
      var $p_0_in_lcssa = $46;
      var $remainder_size_1_lcssa = $remainder_size_0;
      __label__ = 28;
      break;
    } else {
      __label__ = 23;
      break;
    }
   case 23:
    var $68 = ($element_size_0 | 0) == 0;
    var $p_0_in3 = $46;
    var $remainder_size_14 = $remainder_size_0;
    var $i_15 = 0;
    __label__ = 24;
    break;
   case 24:
    var $i_15;
    var $remainder_size_14;
    var $p_0_in3;
    if ($68) {
      __label__ = 25;
      break;
    } else {
      var $size_0 = $element_size_0;
      __label__ = 27;
      break;
    }
   case 25:
    var $72 = HEAPU32[$sizes + ($i_15 << 2) >> 2];
    if ($72 >>> 0 < 11) {
      var $size_0 = 16;
      __label__ = 27;
      break;
    } else {
      __label__ = 26;
      break;
    }
   case 26:
    var $size_0 = $72 + 11 & -8;
    __label__ = 27;
    break;
   case 27:
    var $size_0;
    var $78 = $remainder_size_14 - $size_0 | 0;
    HEAP32[$p_0_in3 + 4 >> 2] = $size_0 | 3;
    var $82 = $p_0_in3 + $size_0 | 0;
    var $83 = $i_15 + 1 | 0;
    HEAP32[$marray_1 + ($83 << 2) >> 2] = $size_0 + ($p_0_in3 + 8) | 0;
    if (($83 | 0) == ($66 | 0)) {
      var $p_0_in_lcssa = $82;
      var $remainder_size_1_lcssa = $78;
      __label__ = 28;
      break;
    } else {
      var $p_0_in3 = $82;
      var $remainder_size_14 = $78;
      var $i_15 = $83;
      __label__ = 24;
      break;
    }
   case 28:
    var $remainder_size_1_lcssa;
    var $p_0_in_lcssa;
    HEAP32[$p_0_in_lcssa + 4 >> 2] = $remainder_size_1_lcssa | 3;
    var $_0 = $marray_1;
    __label__ = 29;
    break;
   case 29:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_ialloc["X"] = 1;

function _independent_comalloc($n_elements, $sizes, $chunks) {
  var $1 = _ialloc($n_elements, $sizes, 0, $chunks);
  return $1;
}

function _valloc($bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAP32[_mparams + 4 >> 2];
    var $6 = _memalign($5, $bytes);
    return $6;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _pvalloc($bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAP32[_mparams + 4 >> 2];
    var $9 = $bytes - 1 + $5 & -$5;
    var $10 = _memalign($5, $9);
    return $10;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _malloc_trim($pad) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = _sys_trim($pad);
    return $5;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _mallinfo($agg_result) {
  _internal_mallinfo($agg_result);
  return;
}

function _internal_mallinfo($agg_result) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAPU32[__gm_ + 24 >> 2];
    if (($5 | 0) == 0) {
      var $nm_0_0 = 0;
      var $nm_1_0 = 0;
      var $nm_9_0 = 0;
      var $nm_8_0 = 0;
      var $nm_4_0 = 0;
      var $nm_5_0 = 0;
      var $nm_7_0 = 0;
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAPU32[__gm_ + 12 >> 2];
    var $9 = $8 + 40 | 0;
    var $s_02 = __gm_ + 444 | 0;
    var $sum_03 = $9;
    var $mfree_04 = $9;
    var $nfree_05 = 1;
    __label__ = 5;
    break;
   case 5:
    var $nfree_05;
    var $mfree_04;
    var $sum_03;
    var $s_02;
    var $12 = HEAPU32[$s_02 >> 2];
    var $14 = $12 + 8 | 0;
    if (($14 & 7 | 0) == 0) {
      var $21 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $21 = -$14 & 7;
    __label__ = 7;
    break;
   case 7:
    var $21;
    var $23 = $s_02 + 4 | 0;
    var $q_0_in = $12 + $21 | 0;
    var $nfree_1 = $nfree_05;
    var $mfree_1 = $mfree_04;
    var $sum_1 = $sum_03;
    __label__ = 8;
    break;
   case 8:
    var $sum_1;
    var $mfree_1;
    var $nfree_1;
    var $q_0_in;
    if ($q_0_in >>> 0 < $12 >>> 0) {
      __label__ = 14;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($q_0_in >>> 0 >= ($12 + HEAP32[$23 >> 2] | 0) >>> 0 | ($q_0_in | 0) == ($5 | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $34 = HEAP32[$q_0_in + 4 >> 2];
    if (($34 | 0) == 7) {
      __label__ = 14;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $37 = $34 & -8;
    var $38 = $37 + $sum_1 | 0;
    if (($34 & 3 | 0) == 1) {
      __label__ = 12;
      break;
    } else {
      var $nfree_2 = $nfree_1;
      var $mfree_2 = $mfree_1;
      __label__ = 13;
      break;
    }
   case 12:
    var $nfree_2 = $nfree_1 + 1 | 0;
    var $mfree_2 = $37 + $mfree_1 | 0;
    __label__ = 13;
    break;
   case 13:
    var $mfree_2;
    var $nfree_2;
    var $q_0_in = $q_0_in + $37 | 0;
    var $nfree_1 = $nfree_2;
    var $mfree_1 = $mfree_2;
    var $sum_1 = $38;
    __label__ = 8;
    break;
   case 14:
    var $47 = HEAPU32[$s_02 + 8 >> 2];
    if (($47 | 0) == 0) {
      __label__ = 15;
      break;
    } else {
      var $s_02 = $47;
      var $sum_03 = $sum_1;
      var $mfree_04 = $mfree_1;
      var $nfree_05 = $nfree_1;
      __label__ = 5;
      break;
    }
   case 15:
    var $50 = HEAP32[__gm_ + 432 >> 2];
    var $nm_0_0 = $sum_1;
    var $nm_1_0 = $nfree_1;
    var $nm_9_0 = $8;
    var $nm_8_0 = $mfree_1;
    var $nm_4_0 = $50 - $sum_1 | 0;
    var $nm_5_0 = HEAP32[__gm_ + 436 >> 2];
    var $nm_7_0 = $50 - $mfree_1 | 0;
    __label__ = 16;
    break;
   case 16:
    var $nm_7_0;
    var $nm_5_0;
    var $nm_4_0;
    var $nm_8_0;
    var $nm_9_0;
    var $nm_1_0;
    var $nm_0_0;
    HEAP32[$agg_result >> 2] = $nm_0_0;
    HEAP32[$agg_result + 4 >> 2] = $nm_1_0;
    HEAP32[$agg_result + 8 >> 2] = 0;
    HEAP32[$agg_result + 12 >> 2] = 0;
    HEAP32[$agg_result + 16 >> 2] = $nm_4_0;
    HEAP32[$agg_result + 20 >> 2] = $nm_5_0;
    HEAP32[$agg_result + 24 >> 2] = 0;
    HEAP32[$agg_result + 28 >> 2] = $nm_7_0;
    HEAP32[$agg_result + 32 >> 2] = $nm_8_0;
    HEAP32[$agg_result + 36 >> 2] = $nm_9_0;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_internal_mallinfo["X"] = 1;

function _malloc_stats() {
  _internal_malloc_stats();
  return;
}

function _internal_malloc_stats() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    var $5 = HEAPU32[__gm_ + 24 >> 2];
    if (($5 | 0) == 0) {
      var $maxfp_0 = 0;
      var $fp_0 = 0;
      var $used_3 = 0;
      __label__ = 13;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $8 = HEAP32[__gm_ + 436 >> 2];
    var $9 = HEAPU32[__gm_ + 432 >> 2];
    var $s_03 = __gm_ + 444 | 0;
    var $used_04 = $9 - 40 - HEAP32[__gm_ + 12 >> 2] | 0;
    __label__ = 5;
    break;
   case 5:
    var $used_04;
    var $s_03;
    var $14 = HEAPU32[$s_03 >> 2];
    var $16 = $14 + 8 | 0;
    if (($16 & 7 | 0) == 0) {
      var $23 = 0;
      __label__ = 7;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $23 = -$16 & 7;
    __label__ = 7;
    break;
   case 7:
    var $23;
    var $25 = $s_03 + 4 | 0;
    var $q_0_in = $14 + $23 | 0;
    var $used_1 = $used_04;
    __label__ = 8;
    break;
   case 8:
    var $used_1;
    var $q_0_in;
    if ($q_0_in >>> 0 < $14 >>> 0) {
      __label__ = 12;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 9:
    if ($q_0_in >>> 0 >= ($14 + HEAP32[$25 >> 2] | 0) >>> 0 | ($q_0_in | 0) == ($5 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 10:
    var $36 = HEAP32[$q_0_in + 4 >> 2];
    if (($36 | 0) == 7) {
      __label__ = 12;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $40 = $36 & -8;
    var $used_2 = ($36 & 3 | 0) == 1 ? $used_1 - $40 | 0 : $used_1;
    var $q_0_in = $q_0_in + $40 | 0;
    var $used_1 = $used_2;
    __label__ = 8;
    break;
   case 12:
    var $44 = HEAPU32[$s_03 + 8 >> 2];
    if (($44 | 0) == 0) {
      var $maxfp_0 = $8;
      var $fp_0 = $9;
      var $used_3 = $used_1;
      __label__ = 13;
      break;
    } else {
      var $s_03 = $44;
      var $used_04 = $used_1;
      __label__ = 5;
      break;
    }
   case 13:
    var $used_3;
    var $fp_0;
    var $maxfp_0;
    var $48 = HEAP32[HEAP32[__impure_ptr >> 2] + 12 >> 2];
    var $49 = _fprintf($48, STRING_TABLE.__str293 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $maxfp_0, tempInt));
    var $52 = HEAP32[HEAP32[__impure_ptr >> 2] + 12 >> 2];
    var $53 = _fprintf($52, STRING_TABLE.__str1294 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $fp_0, tempInt));
    var $56 = HEAP32[HEAP32[__impure_ptr >> 2] + 12 >> 2];
    var $57 = _fprintf($56, STRING_TABLE.__str2295 | 0, (tempInt = STACKTOP, STACKTOP += 4, HEAP32[tempInt >> 2] = $used_3, tempInt));
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_internal_malloc_stats["X"] = 1;

function _mallopt($param_number, $value) {
  var $1 = _change_mparam($param_number, $value);
  return $1;
}

function _change_mparam($param_number, $value) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    _init_mparams();
    __label__ = 3;
    break;
   case 3:
    if (($param_number | 0) == -1) {
      __label__ = 4;
      break;
    } else if (($param_number | 0) == -2) {
      __label__ = 5;
      break;
    } else if (($param_number | 0) == -3) {
      __label__ = 8;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 4:
    HEAP32[_mparams + 16 >> 2] = $value;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 5:
    if (HEAPU32[_mparams + 4 >> 2] >>> 0 > $value >>> 0) {
      var $_0 = 0;
      __label__ = 9;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if (($value - 1 & $value | 0) == 0) {
      __label__ = 7;
      break;
    } else {
      var $_0 = 0;
      __label__ = 9;
      break;
    }
   case 7:
    HEAP32[_mparams + 8 >> 2] = $value;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 8:
    HEAP32[_mparams + 12 >> 2] = $value;
    var $_0 = 1;
    __label__ = 9;
    break;
   case 9:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _internal_realloc($oldmem, $bytes) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ($bytes >>> 0 > 4294967231) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    var $3 = ___errno();
    HEAP32[$3 >> 2] = 12;
    var $_0 = 0;
    __label__ = 23;
    break;
   case 3:
    var $5 = $oldmem - 8 | 0;
    var $6 = $5;
    var $8 = $oldmem - 4 | 0;
    var $9 = HEAPU32[$8 >> 2];
    var $10 = $9 & -8;
    var $_sum = $10 - 8 | 0;
    var $12 = $oldmem + $_sum | 0;
    if ($5 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $16 = $9 & 3;
    if (($16 | 0) != 1 & ($_sum | 0) > -8) {
      __label__ = 5;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 5:
    var $21 = $oldmem + ($10 - 4) | 0;
    if ((HEAP32[$21 >> 2] & 1 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    if ($bytes >>> 0 < 11) {
      var $31 = 16;
      __label__ = 8;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 7:
    var $31 = $bytes + 11 & -8;
    __label__ = 8;
    break;
   case 8:
    var $31;
    if (($16 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 9:
    var $34 = _mmap_resize($6, $31);
    var $extra_0 = 0;
    var $newp_0 = $34;
    __label__ = 17;
    break;
   case 10:
    if ($10 >>> 0 < $31 >>> 0) {
      __label__ = 13;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 11:
    var $38 = $10 - $31 | 0;
    if ($38 >>> 0 > 15) {
      __label__ = 12;
      break;
    } else {
      var $extra_0 = 0;
      var $newp_0 = $6;
      __label__ = 17;
      break;
    }
   case 12:
    HEAP32[$8 >> 2] = $31 | $9 & 1 | 2;
    HEAP32[$oldmem + ($31 - 4) >> 2] = $38 | 3;
    var $48 = HEAP32[$21 >> 2] | 1;
    HEAP32[$21 >> 2] = $48;
    var $extra_0 = $oldmem + $31 | 0;
    var $newp_0 = $6;
    __label__ = 17;
    break;
   case 13:
    if (($12 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 14;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 14:
    var $55 = HEAP32[__gm_ + 12 >> 2] + $10 | 0;
    if ($55 >>> 0 > $31 >>> 0) {
      __label__ = 15;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 15:
    var $58 = $55 - $31 | 0;
    var $60 = $oldmem + ($31 - 8) | 0;
    HEAP32[$8 >> 2] = $31 | $9 & 1 | 2;
    var $66 = $58 | 1;
    HEAP32[$oldmem + ($31 - 4) >> 2] = $66;
    HEAP32[__gm_ + 24 >> 2] = $60;
    HEAP32[__gm_ + 12 >> 2] = $58;
    var $extra_0 = 0;
    var $newp_0 = $6;
    __label__ = 17;
    break;
   case 16:
    _abort();
    throw "Reached an unreachable!";
   case 17:
    var $newp_0;
    var $extra_0;
    if (($newp_0 | 0) == 0) {
      __label__ = 21;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    if (($extra_0 | 0) == 0) {
      __label__ = 20;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 19:
    _free($extra_0);
    __label__ = 20;
    break;
   case 20:
    var $_0 = $newp_0 + 8 | 0;
    __label__ = 23;
    break;
   case 21:
    var $75 = _malloc($bytes);
    if (($75 | 0) == 0) {
      var $_0 = 0;
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $81 = (HEAP32[$8 >> 2] & 3 | 0) == 0 ? 8 : 4;
    var $82 = $10 - $81 | 0;
    var $84 = $82 >>> 0 < $bytes >>> 0 ? $82 : $bytes;
    _memcpy($75, $oldmem, $84, 1);
    _free($oldmem);
    var $_0 = $75;
    __label__ = 23;
    break;
   case 23:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_internal_realloc["X"] = 1;

function _init_mparams() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if ((HEAP32[_mparams >> 2] | 0) == 0) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 2:
    var $4 = _sysconf(8);
    if (($4 - 1 & $4 | 0) == 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    _abort();
    throw "Reached an unreachable!";
   case 4:
    HEAP32[_mparams + 8 >> 2] = $4;
    HEAP32[_mparams + 4 >> 2] = $4;
    HEAP32[_mparams + 12 >> 2] = -1;
    HEAP32[_mparams + 16 >> 2] = 2097152;
    HEAP32[_mparams + 20 >> 2] = 0;
    HEAP32[__gm_ + 440 >> 2] = 0;
    var $10 = _time(0);
    HEAP32[_mparams >> 2] = $10 & -16 ^ 1431655768;
    __label__ = 5;
    break;
   case 5:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _malloc_usable_size($mem) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($mem | 0) == 0) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $5 = HEAP32[$mem - 4 >> 2];
    var $6 = $5 & 3;
    if (($6 | 0) == 1) {
      var $_0 = 0;
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    var $11 = ($6 | 0) == 0 ? 8 : 4;
    var $_0 = ($5 & -8) - $11 | 0;
    __label__ = 4;
    break;
   case 4:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _mmap_resize($oldp, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $3 = HEAP32[$oldp + 4 >> 2] & -8;
    if ($nb >>> 0 < 256) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    if ($3 >>> 0 < ($nb + 4 | 0) >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($3 - $nb | 0) >>> 0 > HEAP32[_mparams + 8 >> 2] << 1 >>> 0) {
      __label__ = 4;
      break;
    } else {
      var $_0 = $oldp;
      __label__ = 5;
      break;
    }
   case 4:
    var $_0 = 0;
    __label__ = 5;
    break;
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _segment_holding($addr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $sp_0 = __gm_ + 444 | 0;
    __label__ = 2;
    break;
   case 2:
    var $sp_0;
    var $3 = HEAPU32[$sp_0 >> 2];
    if ($3 >>> 0 > $addr >>> 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 3:
    if (($3 + HEAP32[$sp_0 + 4 >> 2] | 0) >>> 0 > $addr >>> 0) {
      var $_0 = $sp_0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $12 = HEAPU32[$sp_0 + 8 >> 2];
    if (($12 | 0) == 0) {
      var $_0 = 0;
      __label__ = 5;
      break;
    } else {
      var $sp_0 = $12;
      __label__ = 2;
      break;
    }
   case 5:
    var $_0;
    return $_0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _init_top($p, $psize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = $p;
    var $3 = $p + 8 | 0;
    if (($3 & 7 | 0) == 0) {
      var $10 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $10 = -$3 & 7;
    __label__ = 3;
    break;
   case 3:
    var $10;
    var $13 = $psize - $10 | 0;
    HEAP32[__gm_ + 24 >> 2] = $1 + $10 | 0;
    HEAP32[__gm_ + 12 >> 2] = $13;
    HEAP32[$10 + ($1 + 4) >> 2] = $13 | 1;
    HEAP32[$psize + ($1 + 4) >> 2] = 40;
    var $19 = HEAP32[_mparams + 16 >> 2];
    HEAP32[__gm_ + 28 >> 2] = $19;
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _init_bins() {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $i_02 = 0;
    __label__ = 2;
    break;
   case 2:
    var $i_02;
    var $2 = $i_02 << 1;
    var $4 = __gm_ + 40 + ($2 << 2) | 0;
    HEAP32[__gm_ + 40 + ($2 + 3 << 2) >> 2] = $4;
    HEAP32[__gm_ + 40 + ($2 + 2 << 2) >> 2] = $4;
    var $7 = $i_02 + 1 | 0;
    if (($7 | 0) == 32) {
      __label__ = 3;
      break;
    } else {
      var $i_02 = $7;
      __label__ = 2;
      break;
    }
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function _prepend_alloc($newbase, $oldbase, $nb) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = $newbase + 8 | 0;
    if (($2 & 7 | 0) == 0) {
      var $9 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $9 = -$2 & 7;
    __label__ = 3;
    break;
   case 3:
    var $9;
    var $10 = $newbase + $9 | 0;
    var $12 = $oldbase + 8 | 0;
    if (($12 & 7 | 0) == 0) {
      var $19 = 0;
      __label__ = 5;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    var $19 = -$12 & 7;
    __label__ = 5;
    break;
   case 5:
    var $19;
    var $20 = $oldbase + $19 | 0;
    var $21 = $20;
    var $_sum = $9 + $nb | 0;
    var $25 = $newbase + $_sum | 0;
    var $26 = $25;
    var $27 = $20 - $10 - $nb | 0;
    HEAP32[$9 + ($newbase + 4) >> 2] = $nb | 3;
    if (($21 | 0) == (HEAP32[__gm_ + 24 >> 2] | 0)) {
      __label__ = 6;
      break;
    } else {
      __label__ = 7;
      break;
    }
   case 6:
    var $35 = HEAP32[__gm_ + 12 >> 2] + $27 | 0;
    HEAP32[__gm_ + 12 >> 2] = $35;
    HEAP32[__gm_ + 24 >> 2] = $26;
    var $36 = $35 | 1;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $36;
    __label__ = 75;
    break;
   case 7:
    if (($21 | 0) == (HEAP32[__gm_ + 20 >> 2] | 0)) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $44 = HEAP32[__gm_ + 8 >> 2] + $27 | 0;
    HEAP32[__gm_ + 8 >> 2] = $44;
    HEAP32[__gm_ + 20 >> 2] = $26;
    var $45 = $44 | 1;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $45;
    var $49 = $newbase + ($44 + $_sum) | 0;
    HEAP32[$49 >> 2] = $44;
    __label__ = 75;
    break;
   case 9:
    var $53 = HEAPU32[$19 + ($oldbase + 4) >> 2];
    if (($53 & 3 | 0) == 1) {
      __label__ = 10;
      break;
    } else {
      var $oldfirst_0 = $21;
      var $qsize_0 = $27;
      __label__ = 51;
      break;
    }
   case 10:
    var $57 = $53 & -8;
    var $58 = $53 >>> 3;
    if ($53 >>> 0 < 256) {
      __label__ = 11;
      break;
    } else {
      __label__ = 19;
      break;
    }
   case 11:
    var $63 = HEAPU32[$oldbase + ($19 | 8) >> 2];
    var $66 = HEAPU32[$19 + ($oldbase + 12) >> 2];
    if (($63 | 0) == ($66 | 0)) {
      __label__ = 12;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 12:
    var $72 = HEAP32[__gm_ >> 2] & (1 << $58 ^ -1);
    HEAP32[__gm_ >> 2] = $72;
    __label__ = 50;
    break;
   case 13:
    var $77 = __gm_ + 40 + (($53 >>> 2 & 1073741822) << 2) | 0;
    if (($63 | 0) == ($77 | 0)) {
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    if ($63 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 15;
      break;
    }
   case 15:
    if (($66 | 0) == ($77 | 0)) {
      __label__ = 17;
      break;
    } else {
      __label__ = 16;
      break;
    }
   case 16:
    if ($66 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 18;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 17:
    HEAP32[$63 + 12 >> 2] = $66;
    HEAP32[$66 + 8 >> 2] = $63;
    __label__ = 50;
    break;
   case 18:
    _abort();
    throw "Reached an unreachable!";
   case 19:
    var $92 = $20;
    var $95 = HEAPU32[$oldbase + ($19 | 24) >> 2];
    var $98 = HEAPU32[$19 + ($oldbase + 12) >> 2];
    if (($98 | 0) == ($92 | 0)) {
      __label__ = 23;
      break;
    } else {
      __label__ = 20;
      break;
    }
   case 20:
    var $103 = HEAPU32[$oldbase + ($19 | 8) >> 2];
    if ($103 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 22;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    HEAP32[$103 + 12 >> 2] = $98;
    HEAP32[$98 + 8 >> 2] = $103;
    var $R_1 = $98;
    __label__ = 30;
    break;
   case 22:
    _abort();
    throw "Reached an unreachable!";
   case 23:
    var $_sum67 = $19 | 16;
    var $113 = $_sum67 + ($oldbase + 4) | 0;
    var $114 = HEAP32[$113 >> 2];
    if (($114 | 0) == 0) {
      __label__ = 24;
      break;
    } else {
      var $RP_0 = $113;
      var $R_0 = $114;
      __label__ = 25;
      break;
    }
   case 24:
    var $118 = $oldbase + $_sum67 | 0;
    var $119 = HEAP32[$118 >> 2];
    if (($119 | 0) == 0) {
      var $R_1 = 0;
      __label__ = 30;
      break;
    } else {
      var $RP_0 = $118;
      var $R_0 = $119;
      __label__ = 25;
      break;
    }
   case 25:
    var $R_0;
    var $RP_0;
    var $121 = $R_0 + 20 | 0;
    var $122 = HEAP32[$121 >> 2];
    if (($122 | 0) == 0) {
      __label__ = 26;
      break;
    } else {
      var $RP_0 = $121;
      var $R_0 = $122;
      __label__ = 25;
      break;
    }
   case 26:
    var $125 = $R_0 + 16 | 0;
    var $126 = HEAPU32[$125 >> 2];
    if (($126 | 0) == 0) {
      __label__ = 27;
      break;
    } else {
      var $RP_0 = $125;
      var $R_0 = $126;
      __label__ = 25;
      break;
    }
   case 27:
    if ($RP_0 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$RP_0 >> 2] = 0;
    var $R_1 = $R_0;
    __label__ = 30;
    break;
   case 29:
    _abort();
    throw "Reached an unreachable!";
   case 30:
    var $R_1;
    if (($95 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 31;
      break;
    }
   case 31:
    var $138 = $19 + ($oldbase + 28) | 0;
    var $140 = __gm_ + 304 + (HEAP32[$138 >> 2] << 2) | 0;
    if (($92 | 0) == (HEAP32[$140 >> 2] | 0)) {
      __label__ = 32;
      break;
    } else {
      __label__ = 34;
      break;
    }
   case 32:
    HEAP32[$140 >> 2] = $R_1;
    if (($R_1 | 0) == 0) {
      __label__ = 33;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 33:
    var $148 = HEAP32[__gm_ + 4 >> 2] & (1 << HEAP32[$138 >> 2] ^ -1);
    HEAP32[__gm_ + 4 >> 2] = $148;
    __label__ = 50;
    break;
   case 34:
    if ($95 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 38;
      break;
    } else {
      __label__ = 35;
      break;
    }
   case 35:
    var $154 = $95 + 16 | 0;
    if ((HEAP32[$154 >> 2] | 0) == ($92 | 0)) {
      __label__ = 36;
      break;
    } else {
      __label__ = 37;
      break;
    }
   case 36:
    HEAP32[$154 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 37:
    HEAP32[$95 + 20 >> 2] = $R_1;
    __label__ = 39;
    break;
   case 38:
    _abort();
    throw "Reached an unreachable!";
   case 39:
    if (($R_1 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 40;
      break;
    }
   case 40:
    if ($R_1 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 49;
      break;
    } else {
      __label__ = 41;
      break;
    }
   case 41:
    HEAP32[$R_1 + 24 >> 2] = $95;
    var $_sum3132 = $19 | 16;
    var $171 = HEAPU32[$oldbase + $_sum3132 >> 2];
    if (($171 | 0) == 0) {
      __label__ = 45;
      break;
    } else {
      __label__ = 42;
      break;
    }
   case 42:
    if ($171 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 44;
      break;
    } else {
      __label__ = 43;
      break;
    }
   case 43:
    HEAP32[$R_1 + 16 >> 2] = $171;
    HEAP32[$171 + 24 >> 2] = $R_1;
    __label__ = 45;
    break;
   case 44:
    _abort();
    throw "Reached an unreachable!";
   case 45:
    var $184 = HEAPU32[$_sum3132 + ($oldbase + 4) >> 2];
    if (($184 | 0) == 0) {
      __label__ = 50;
      break;
    } else {
      __label__ = 46;
      break;
    }
   case 46:
    if ($184 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 48;
      break;
    } else {
      __label__ = 47;
      break;
    }
   case 47:
    HEAP32[$R_1 + 20 >> 2] = $184;
    HEAP32[$184 + 24 >> 2] = $R_1;
    __label__ = 50;
    break;
   case 48:
    _abort();
    throw "Reached an unreachable!";
   case 49:
    _abort();
    throw "Reached an unreachable!";
   case 50:
    var $oldfirst_0 = $oldbase + ($57 | $19) | 0;
    var $qsize_0 = $57 + $27 | 0;
    __label__ = 51;
    break;
   case 51:
    var $qsize_0;
    var $oldfirst_0;
    var $200 = $oldfirst_0 + 4 | 0;
    var $202 = HEAP32[$200 >> 2] & -2;
    HEAP32[$200 >> 2] = $202;
    HEAP32[$_sum + ($newbase + 4) >> 2] = $qsize_0 | 1;
    HEAP32[$newbase + ($qsize_0 + $_sum) >> 2] = $qsize_0;
    if ($qsize_0 >>> 0 < 256) {
      __label__ = 52;
      break;
    } else {
      __label__ = 57;
      break;
    }
   case 52:
    var $212 = $qsize_0 >>> 2 & 1073741822;
    var $214 = __gm_ + 40 + ($212 << 2) | 0;
    var $215 = HEAPU32[__gm_ >> 2];
    var $216 = 1 << ($qsize_0 >>> 3);
    if (($215 & $216 | 0) == 0) {
      __label__ = 53;
      break;
    } else {
      __label__ = 54;
      break;
    }
   case 53:
    HEAP32[__gm_ >> 2] = $215 | $216;
    var $F4_0 = $214;
    var $_pre_phi = __gm_ + 40 + ($212 + 2 << 2) | 0;
    __label__ = 56;
    break;
   case 54:
    var $222 = __gm_ + 40 + ($212 + 2 << 2) | 0;
    var $223 = HEAPU32[$222 >> 2];
    if ($223 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 55;
      break;
    } else {
      var $F4_0 = $223;
      var $_pre_phi = $222;
      __label__ = 56;
      break;
    }
   case 55:
    _abort();
    throw "Reached an unreachable!";
   case 56:
    var $_pre_phi;
    var $F4_0;
    HEAP32[$_pre_phi >> 2] = $26;
    HEAP32[$F4_0 + 12 >> 2] = $26;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $F4_0;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $214;
    __label__ = 75;
    break;
   case 57:
    var $235 = $25;
    var $236 = $qsize_0 >>> 8;
    if (($236 | 0) == 0) {
      var $I7_0 = 0;
      __label__ = 60;
      break;
    } else {
      __label__ = 58;
      break;
    }
   case 58:
    if ($qsize_0 >>> 0 > 16777215) {
      var $I7_0 = 31;
      __label__ = 60;
      break;
    } else {
      __label__ = 59;
      break;
    }
   case 59:
    var $243 = ($236 + 1048320 | 0) >>> 16 & 8;
    var $244 = $236 << $243;
    var $247 = ($244 + 520192 | 0) >>> 16 & 4;
    var $248 = $244 << $247;
    var $251 = ($248 + 245760 | 0) >>> 16 & 2;
    var $257 = 14 - ($247 | $243 | $251) + ($248 << $251 >>> 15) | 0;
    var $I7_0 = $qsize_0 >>> (($257 + 7 | 0) >>> 0) & 1 | $257 << 1;
    __label__ = 60;
    break;
   case 60:
    var $I7_0;
    var $264 = __gm_ + 304 + ($I7_0 << 2) | 0;
    HEAP32[$_sum + ($newbase + 28) >> 2] = $I7_0;
    var $267 = $_sum + ($newbase + 16) | 0;
    HEAP32[$_sum + ($newbase + 20) >> 2] = 0;
    HEAP32[$267 >> 2] = 0;
    var $271 = HEAP32[__gm_ + 4 >> 2];
    var $272 = 1 << $I7_0;
    if (($271 & $272 | 0) == 0) {
      __label__ = 61;
      break;
    } else {
      __label__ = 62;
      break;
    }
   case 61:
    var $276 = $271 | $272;
    HEAP32[__gm_ + 4 >> 2] = $276;
    HEAP32[$264 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 24) >> 2] = $264;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $235;
    __label__ = 75;
    break;
   case 62:
    var $285 = HEAP32[$264 >> 2];
    if (($I7_0 | 0) == 31) {
      var $291 = 0;
      __label__ = 64;
      break;
    } else {
      __label__ = 63;
      break;
    }
   case 63:
    var $291 = 25 - ($I7_0 >>> 1) | 0;
    __label__ = 64;
    break;
   case 64:
    var $291;
    var $K8_0 = $qsize_0 << $291;
    var $T_0 = $285;
    __label__ = 65;
    break;
   case 65:
    var $T_0;
    var $K8_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($qsize_0 | 0)) {
      __label__ = 71;
      break;
    } else {
      __label__ = 66;
      break;
    }
   case 66:
    var $300 = $T_0 + 16 + ($K8_0 >>> 31 << 2) | 0;
    var $301 = HEAPU32[$300 >> 2];
    if (($301 | 0) == 0) {
      __label__ = 68;
      break;
    } else {
      __label__ = 67;
      break;
    }
   case 67:
    var $K8_0 = $K8_0 << 1;
    var $T_0 = $301;
    __label__ = 65;
    break;
   case 68:
    if ($300 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 70;
      break;
    } else {
      __label__ = 69;
      break;
    }
   case 69:
    HEAP32[$300 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 24) >> 2] = $T_0;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $235;
    __label__ = 75;
    break;
   case 70:
    _abort();
    throw "Reached an unreachable!";
   case 71:
    var $318 = $T_0 + 8 | 0;
    var $319 = HEAPU32[$318 >> 2];
    var $321 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $321 >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 72;
      break;
    }
   case 72:
    if ($319 >>> 0 < $321 >>> 0) {
      __label__ = 74;
      break;
    } else {
      __label__ = 73;
      break;
    }
   case 73:
    HEAP32[$319 + 12 >> 2] = $235;
    HEAP32[$318 >> 2] = $235;
    HEAP32[$_sum + ($newbase + 8) >> 2] = $319;
    HEAP32[$_sum + ($newbase + 12) >> 2] = $T_0;
    HEAP32[$_sum + ($newbase + 24) >> 2] = 0;
    __label__ = 75;
    break;
   case 74:
    _abort();
    throw "Reached an unreachable!";
   case 75:
    return $newbase + ($9 | 8) | 0;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_prepend_alloc["X"] = 1;

function __ZNKSt9bad_alloc4whatEv($this) {
  return STRING_TABLE.__str3296 | 0;
}

function __ZNKSt20bad_array_new_length4whatEv($this) {
  return STRING_TABLE.__str14297 | 0;
}

function __ZSt15get_new_handlerv() {
  var $1 = (tempValue = HEAP32[__ZL13__new_handler >> 2], HEAP32[__ZL13__new_handler >> 2] = tempValue + 0, tempValue);
  return $1;
}

function __ZSt15set_new_handlerPFvvE($handler) {
  var $1 = $handler;
  var $2 = (tempValue = HEAP32[__ZL13__new_handler >> 2], HEAP32[__ZL13__new_handler >> 2] = $1, tempValue);
  return $2;
}

function __ZNSt9bad_allocC2Ev($this) {
  HEAP32[$this >> 2] = __ZTVSt9bad_alloc + 8 | 0;
  return;
}

function __ZdlPv($ptr) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    if (($ptr | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    _free($ptr);
    __label__ = 3;
    break;
   case 3:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZdlPvRKSt9nothrow_t($ptr, $0) {
  __ZdlPv($ptr);
  return;
}

function __ZdaPv($ptr) {
  __ZdlPv($ptr);
  return;
}

function __ZdaPvRKSt9nothrow_t($ptr, $0) {
  __ZdaPv($ptr);
  return;
}

function __ZNSt9bad_allocD0Ev($this) {
  __ZNSt9bad_allocD2Ev($this);
  var $1 = $this;
  __ZdlPv($1);
  return;
}

function __ZNSt9bad_allocD2Ev($this) {
  var $1 = $this | 0;
  __ZNSt9exceptionD2Ev($1);
  return;
}

function __ZNSt20bad_array_new_lengthC2Ev($this) {
  var $1 = $this | 0;
  __ZNSt9bad_allocC2Ev($1);
  HEAP32[$this >> 2] = __ZTVSt20bad_array_new_length + 8 | 0;
  return;
}

function __ZNSt20bad_array_new_lengthD0Ev($this) {
  var $1 = $this | 0;
  __ZNSt9bad_allocD2Ev($1);
  var $2 = $this;
  __ZdlPv($2);
  return;
}

function _add_segment($tbase, $tsize) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = HEAPU32[__gm_ + 24 >> 2];
    var $2 = $1;
    var $3 = _segment_holding($2);
    var $5 = HEAP32[$3 >> 2];
    var $7 = HEAP32[$3 + 4 >> 2];
    var $8 = $5 + $7 | 0;
    var $10 = $5 + ($7 - 39) | 0;
    if (($10 & 7 | 0) == 0) {
      var $17 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $17 = -$10 & 7;
    __label__ = 3;
    break;
   case 3:
    var $17;
    var $18 = $5 + ($7 - 47 + $17) | 0;
    var $22 = $18 >>> 0 < ($1 + 16 | 0) >>> 0 ? $2 : $18;
    var $23 = $22 + 8 | 0;
    var $24 = $23;
    var $25 = $tbase;
    var $26 = $tsize - 40 | 0;
    _init_top($25, $26);
    var $28 = $22 + 4 | 0;
    HEAP32[$28 >> 2] = 27;
    HEAP32[$23 >> 2] = HEAP32[__gm_ + 444 >> 2];
    HEAP32[$23 + 4 >> 2] = HEAP32[__gm_ + 448 >> 2];
    HEAP32[$23 + 8 >> 2] = HEAP32[__gm_ + 452 >> 2];
    HEAP32[$23 + 12 >> 2] = HEAP32[__gm_ + 456 >> 2];
    HEAP32[__gm_ + 444 >> 2] = $tbase;
    HEAP32[__gm_ + 448 >> 2] = $tsize;
    HEAP32[__gm_ + 456 >> 2] = 0;
    HEAP32[__gm_ + 452 >> 2] = $24;
    var $30 = $22 + 28 | 0;
    HEAP32[$30 >> 2] = 7;
    if (($22 + 32 | 0) >>> 0 < $8 >>> 0) {
      var $33 = $30;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $33;
    var $34 = $33 + 4 | 0;
    HEAP32[$34 >> 2] = 7;
    if (($33 + 8 | 0) >>> 0 < $8 >>> 0) {
      var $33 = $34;
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    if (($22 | 0) == ($2 | 0)) {
      __label__ = 30;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 6:
    var $42 = $22 - $1 | 0;
    var $43 = $2 + $42 | 0;
    var $45 = $42 + ($2 + 4) | 0;
    var $47 = HEAP32[$45 >> 2] & -2;
    HEAP32[$45 >> 2] = $47;
    var $48 = $42 | 1;
    HEAP32[$1 + 4 >> 2] = $48;
    var $50 = $43;
    HEAP32[$50 >> 2] = $42;
    if ($42 >>> 0 < 256) {
      __label__ = 7;
      break;
    } else {
      __label__ = 12;
      break;
    }
   case 7:
    var $55 = $42 >>> 2 & 1073741822;
    var $57 = __gm_ + 40 + ($55 << 2) | 0;
    var $58 = HEAPU32[__gm_ >> 2];
    var $59 = 1 << ($42 >>> 3);
    if (($58 & $59 | 0) == 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 9;
      break;
    }
   case 8:
    var $63 = $58 | $59;
    HEAP32[__gm_ >> 2] = $63;
    var $F_0 = $57;
    var $_pre_phi = __gm_ + 40 + ($55 + 2 << 2) | 0;
    __label__ = 11;
    break;
   case 9:
    var $65 = __gm_ + 40 + ($55 + 2 << 2) | 0;
    var $66 = HEAPU32[$65 >> 2];
    if ($66 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 10;
      break;
    } else {
      var $F_0 = $66;
      var $_pre_phi = $65;
      __label__ = 11;
      break;
    }
   case 10:
    _abort();
    throw "Reached an unreachable!";
   case 11:
    var $_pre_phi;
    var $F_0;
    HEAP32[$_pre_phi >> 2] = $1;
    HEAP32[$F_0 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $F_0;
    HEAP32[$1 + 12 >> 2] = $57;
    __label__ = 30;
    break;
   case 12:
    var $76 = $1;
    var $77 = $42 >>> 8;
    if (($77 | 0) == 0) {
      var $I1_0 = 0;
      __label__ = 15;
      break;
    } else {
      __label__ = 13;
      break;
    }
   case 13:
    if ($42 >>> 0 > 16777215) {
      var $I1_0 = 31;
      __label__ = 15;
      break;
    } else {
      __label__ = 14;
      break;
    }
   case 14:
    var $84 = ($77 + 1048320 | 0) >>> 16 & 8;
    var $85 = $77 << $84;
    var $88 = ($85 + 520192 | 0) >>> 16 & 4;
    var $89 = $85 << $88;
    var $92 = ($89 + 245760 | 0) >>> 16 & 2;
    var $98 = 14 - ($88 | $84 | $92) + ($89 << $92 >>> 15) | 0;
    var $I1_0 = $42 >>> (($98 + 7 | 0) >>> 0) & 1 | $98 << 1;
    __label__ = 15;
    break;
   case 15:
    var $I1_0;
    var $105 = __gm_ + 304 + ($I1_0 << 2) | 0;
    HEAP32[$1 + 28 >> 2] = $I1_0;
    HEAP32[$1 + 20 >> 2] = 0;
    HEAP32[$1 + 16 >> 2] = 0;
    var $109 = HEAP32[__gm_ + 4 >> 2];
    var $110 = 1 << $I1_0;
    if (($109 & $110 | 0) == 0) {
      __label__ = 16;
      break;
    } else {
      __label__ = 17;
      break;
    }
   case 16:
    var $114 = $109 | $110;
    HEAP32[__gm_ + 4 >> 2] = $114;
    HEAP32[$105 >> 2] = $76;
    HEAP32[$1 + 24 >> 2] = $105;
    HEAP32[$1 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $1;
    __label__ = 30;
    break;
   case 17:
    var $119 = HEAP32[$105 >> 2];
    if (($I1_0 | 0) == 31) {
      var $125 = 0;
      __label__ = 19;
      break;
    } else {
      __label__ = 18;
      break;
    }
   case 18:
    var $125 = 25 - ($I1_0 >>> 1) | 0;
    __label__ = 19;
    break;
   case 19:
    var $125;
    var $K2_0 = $42 << $125;
    var $T_0 = $119;
    __label__ = 20;
    break;
   case 20:
    var $T_0;
    var $K2_0;
    if ((HEAP32[$T_0 + 4 >> 2] & -8 | 0) == ($42 | 0)) {
      __label__ = 26;
      break;
    } else {
      __label__ = 21;
      break;
    }
   case 21:
    var $134 = $T_0 + 16 + ($K2_0 >>> 31 << 2) | 0;
    var $135 = HEAPU32[$134 >> 2];
    if (($135 | 0) == 0) {
      __label__ = 23;
      break;
    } else {
      __label__ = 22;
      break;
    }
   case 22:
    var $K2_0 = $K2_0 << 1;
    var $T_0 = $135;
    __label__ = 20;
    break;
   case 23:
    if ($134 >>> 0 < HEAPU32[__gm_ + 16 >> 2] >>> 0) {
      __label__ = 25;
      break;
    } else {
      __label__ = 24;
      break;
    }
   case 24:
    HEAP32[$134 >> 2] = $76;
    HEAP32[$1 + 24 >> 2] = $T_0;
    HEAP32[$1 + 12 >> 2] = $1;
    HEAP32[$1 + 8 >> 2] = $1;
    __label__ = 30;
    break;
   case 25:
    _abort();
    throw "Reached an unreachable!";
   case 26:
    var $149 = $T_0 + 8 | 0;
    var $150 = HEAPU32[$149 >> 2];
    var $152 = HEAPU32[__gm_ + 16 >> 2];
    if ($T_0 >>> 0 < $152 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 27;
      break;
    }
   case 27:
    if ($150 >>> 0 < $152 >>> 0) {
      __label__ = 29;
      break;
    } else {
      __label__ = 28;
      break;
    }
   case 28:
    HEAP32[$150 + 12 >> 2] = $76;
    HEAP32[$149 >> 2] = $76;
    HEAP32[$1 + 8 >> 2] = $150;
    HEAP32[$1 + 12 >> 2] = $T_0;
    HEAP32[$1 + 24 >> 2] = 0;
    __label__ = 30;
    break;
   case 29:
    _abort();
    throw "Reached an unreachable!";
   case 30:
    return;
   default:
    assert(0, "bad label: " + __label__);
  }
}

_add_segment["X"] = 1;

function __Znwj($size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $_0_ph = ($size | 0) == 0 ? 1 : $size;
    __label__ = 2;
    break;
   case 2:
    var $2 = _malloc($_0_ph);
    if (($2 | 0) == 0) {
      __label__ = 3;
      break;
    } else {
      __label__ = 10;
      break;
    }
   case 3:
    var $5 = __ZSt15get_new_handlerv();
    if (($5 | 0) == 0) {
      __label__ = 9;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 4:
    ((function() {
      try {
        __THREW__ = false;
        return FUNCTION_TABLE[$5]();
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      __label__ = 2;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 5:
    var $lpad_loopexit = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $lpad_phi = $lpad_loopexit;
    __label__ = 7;
    break;
   case 6:
    var $lpad_nonloopexit = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $lpad_phi = $lpad_nonloopexit;
    __label__ = 7;
    break;
   case 7:
    var $lpad_phi;
    var $9 = $lpad_phi.f1;
    if (($9 | 0) < 0) {
      __label__ = 8;
      break;
    } else {
      __label__ = 11;
      break;
    }
   case 8:
    var $12 = $lpad_phi.f0;
    ___cxa_call_unexpected($12);
    throw "Reached an unreachable!";
   case 9:
    var $14 = ___cxa_allocate_exception(4);
    var $15 = $14;
    __ZNSt9bad_allocC2Ev($15);
    ((function() {
      try {
        __THREW__ = false;
        return ___cxa_throw($14, __ZTISt9bad_alloc, 302);
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      __label__ = 12;
      break;
    } else {
      __label__ = 6;
      break;
    }
   case 10:
    return $2;
   case 11:
    Module.print("Resuming exception");
    throw HEAP32[_llvm_eh_exception.buf >> 2];
   case 12:
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZnwjRKSt9nothrow_t($size, $0) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $2 = (function() {
      try {
        __THREW__ = false;
        return __Znwj($size);
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    })();
    if (!__THREW__) {
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $4 = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], [ 0 ]);
    var $5 = $4.f0;
    var $6 = ___cxa_begin_catch($5);
    ((function() {
      try {
        __THREW__ = false;
        return ___cxa_end_catch();
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      var $p_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $p_0;
    return $p_0;
   case 4:
    var $9 = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $10 = $9.f0;
    ___cxa_call_unexpected($10);
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __Znaj($size) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = (function() {
      try {
        __THREW__ = false;
        return __Znwj($size);
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    })();
    if (!__THREW__) {
      __label__ = 2;
      break;
    } else {
      __label__ = 3;
      break;
    }
   case 2:
    return $1;
   case 3:
    var $4 = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $5 = $4.f1;
    if (($5 | 0) < 0) {
      __label__ = 4;
      break;
    } else {
      __label__ = 5;
      break;
    }
   case 4:
    var $8 = $4.f0;
    ___cxa_call_unexpected($8);
    throw "Reached an unreachable!";
   case 5:
    Module.print("Resuming exception");
    throw HEAP32[_llvm_eh_exception.buf >> 2];
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZnajRKSt9nothrow_t($size, $nothrow) {
  var __label__;
  __label__ = 1;
  while (1) switch (__label__) {
   case 1:
    var $1 = (function() {
      try {
        __THREW__ = false;
        return __Znaj($size);
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    })();
    if (!__THREW__) {
      var $p_0 = $1;
      __label__ = 3;
      break;
    } else {
      __label__ = 2;
      break;
    }
   case 2:
    var $3 = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], [ 0 ]);
    var $4 = $3.f0;
    var $5 = ___cxa_begin_catch($4);
    ((function() {
      try {
        __THREW__ = false;
        return ___cxa_end_catch();
      } catch (e) {
        if (typeof e != "number") throw e;
        if (ABORT) throw e;
        __THREW__ = true;
        Module.print("Exception: " + e + ", currently at: " + (new Error).stack);
        return null;
      }
    }))();
    if (!__THREW__) {
      var $p_0 = 0;
      __label__ = 3;
      break;
    } else {
      __label__ = 4;
      break;
    }
   case 3:
    var $p_0;
    return $p_0;
   case 4:
    var $8 = ___cxa_find_matching_catch(HEAP32[_llvm_eh_exception.buf >> 2], HEAP32[_llvm_eh_exception.buf + 4 >> 2], []);
    var $9 = $8.f0;
    ___cxa_call_unexpected($9);
    throw "Reached an unreachable!";
   default:
    assert(0, "bad label: " + __label__);
  }
}

function __ZSt17__throw_bad_allocv() {
  var $1 = ___cxa_allocate_exception(4);
  var $2 = $1;
  __ZNSt9bad_allocC2Ev($2);
  ___cxa_throw($1, __ZTISt9bad_alloc, 302);
  throw "Reached an unreachable!";
}

var i64Math = (function() {
  var goog = {
    math: {}
  };
  goog.math.Long = (function(low, high) {
    this.low_ = low | 0;
    this.high_ = high | 0;
  });
  goog.math.Long.IntCache_ = {};
  goog.math.Long.fromInt = (function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  });
  goog.math.Long.fromNumber = (function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(value % goog.math.Long.TWO_PWR_32_DBL_ | 0, value / goog.math.Long.TWO_PWR_32_DBL_ | 0);
    }
  });
  goog.math.Long.fromBits = (function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  });
  goog.math.Long.fromString = (function(str, opt_radix) {
    if (str.length == 0) {
      throw Error("number format error: empty string");
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error("radix out of range: " + radix);
    }
    if (str.charAt(0) == "-") {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf("-") >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  });
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  goog.math.Long.TWO_PWR_32_DBL_ = goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  goog.math.Long.TWO_PWR_31_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ / 2;
  goog.math.Long.TWO_PWR_48_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  goog.math.Long.TWO_PWR_64_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  goog.math.Long.TWO_PWR_63_DBL_ = goog.math.Long.TWO_PWR_64_DBL_ / 2;
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  goog.math.Long.MAX_VALUE = goog.math.Long.fromBits(4294967295 | 0, 2147483647 | 0);
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 2147483648 | 0);
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  goog.math.Long.prototype.toInt = (function() {
    return this.low_;
  });
  goog.math.Long.prototype.toNumber = (function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ + this.getLowBitsUnsigned();
  });
  goog.math.Long.prototype.toString = (function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error("radix out of range: " + radix);
    }
    if (this.isZero()) {
      return "0";
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return "-" + this.negate().toString(radix);
      }
    }
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = "";
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = "0" + digits;
        }
        result = "" + digits + result;
      }
    }
  });
  goog.math.Long.prototype.getHighBits = (function() {
    return this.high_;
  });
  goog.math.Long.prototype.getLowBits = (function() {
    return this.low_;
  });
  goog.math.Long.prototype.getLowBitsUnsigned = (function() {
    return this.low_ >= 0 ? this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  });
  goog.math.Long.prototype.getNumBitsAbs = (function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & 1 << bit) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  });
  goog.math.Long.prototype.isZero = (function() {
    return this.high_ == 0 && this.low_ == 0;
  });
  goog.math.Long.prototype.isNegative = (function() {
    return this.high_ < 0;
  });
  goog.math.Long.prototype.isOdd = (function() {
    return (this.low_ & 1) == 1;
  });
  goog.math.Long.prototype.equals = (function(other) {
    return this.high_ == other.high_ && this.low_ == other.low_;
  });
  goog.math.Long.prototype.notEquals = (function(other) {
    return this.high_ != other.high_ || this.low_ != other.low_;
  });
  goog.math.Long.prototype.lessThan = (function(other) {
    return this.compare(other) < 0;
  });
  goog.math.Long.prototype.lessThanOrEqual = (function(other) {
    return this.compare(other) <= 0;
  });
  goog.math.Long.prototype.greaterThan = (function(other) {
    return this.compare(other) > 0;
  });
  goog.math.Long.prototype.greaterThanOrEqual = (function(other) {
    return this.compare(other) >= 0;
  });
  goog.math.Long.prototype.compare = (function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  });
  goog.math.Long.prototype.negate = (function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  });
  goog.math.Long.prototype.add = (function(other) {
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 65535;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 65535;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 65535;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 65535;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 65535;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c48 += a48 + b48;
    c48 &= 65535;
    return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32);
  });
  goog.math.Long.prototype.subtract = (function(other) {
    return this.add(other.negate());
  });
  goog.math.Long.prototype.multiply = (function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) && other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 65535;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 65535;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 65535;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 65535;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 65535;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 65535;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 65535;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 65535;
    return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32);
  });
  goog.math.Long.prototype.div = (function(other) {
    if (other.isZero()) {
      throw Error("division by zero");
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) || other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = log2 <= 48 ? 1 : Math.pow(2, log2 - 48);
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  });
  goog.math.Long.prototype.modulo = (function(other) {
    return this.subtract(this.div(other).multiply(other));
  });
  goog.math.Long.prototype.not = (function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  });
  goog.math.Long.prototype.and = (function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_, this.high_ & other.high_);
  });
  goog.math.Long.prototype.or = (function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_, this.high_ | other.high_);
  });
  goog.math.Long.prototype.xor = (function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_, this.high_ ^ other.high_);
  });
  goog.math.Long.prototype.shiftLeft = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(low << numBits, high << numBits | low >>> 32 - numBits);
      } else {
        return goog.math.Long.fromBits(0, low << numBits - 32);
      }
    }
  });
  goog.math.Long.prototype.shiftRight = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >> numBits);
      } else {
        return goog.math.Long.fromBits(high >> numBits - 32, high >= 0 ? 0 : -1);
      }
    }
  });
  goog.math.Long.prototype.shiftRightUnsigned = (function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> numBits - 32, 0);
      }
    }
  });
  var navigator = {
    appName: "Modern Browser"
  };
  var dbits;
  var canary = 0xdeadbeefcafe;
  var j_lm = (canary & 16777215) == 15715070;
  function BigInteger(a, b, c) {
    if (a != null) if ("number" == typeof a) this.fromNumber(a, b, c); else if (b == null && "string" != typeof a) this.fromString(a, 256); else this.fromString(a, b);
  }
  function nbi() {
    return new BigInteger(null);
  }
  function am1(i, x, w, j, c, n) {
    while (--n >= 0) {
      var v = x * this[i++] + w[j] + c;
      c = Math.floor(v / 67108864);
      w[j++] = v & 67108863;
    }
    return c;
  }
  function am2(i, x, w, j, c, n) {
    var xl = x & 32767, xh = x >> 15;
    while (--n >= 0) {
      var l = this[i] & 32767;
      var h = this[i++] >> 15;
      var m = xh * l + h * xl;
      l = xl * l + ((m & 32767) << 15) + w[j] + (c & 1073741823);
      c = (l >>> 30) + (m >>> 15) + xh * h + (c >>> 30);
      w[j++] = l & 1073741823;
    }
    return c;
  }
  function am3(i, x, w, j, c, n) {
    var xl = x & 16383, xh = x >> 14;
    while (--n >= 0) {
      var l = this[i] & 16383;
      var h = this[i++] >> 14;
      var m = xh * l + h * xl;
      l = xl * l + ((m & 16383) << 14) + w[j] + c;
      c = (l >> 28) + (m >> 14) + xh * h;
      w[j++] = l & 268435455;
    }
    return c;
  }
  if (j_lm && navigator.appName == "Microsoft Internet Explorer") {
    BigInteger.prototype.am = am2;
    dbits = 30;
  } else if (j_lm && navigator.appName != "Netscape") {
    BigInteger.prototype.am = am1;
    dbits = 26;
  } else {
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = (1 << dbits) - 1;
  BigInteger.prototype.DV = 1 << dbits;
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2, BI_FP);
  BigInteger.prototype.F1 = BI_FP - dbits;
  BigInteger.prototype.F2 = 2 * dbits - BI_FP;
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array;
  var rr, vv;
  rr = "0".charCodeAt(0);
  for (vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for (vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for (vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) {
    return BI_RM.charAt(n);
  }
  function intAt(s, i) {
    var c = BI_RC[s.charCodeAt(i)];
    return c == null ? -1 : c;
  }
  function bnpCopyTo(r) {
    for (var i = this.t - 1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  function bnpFromInt(x) {
    this.t = 1;
    this.s = x < 0 ? -1 : 0;
    if (x > 0) this[0] = x; else if (x < -1) this[0] = x + DV; else this.t = 0;
  }
  function nbv(i) {
    var r = nbi();
    r.fromInt(i);
    return r;
  }
  function bnpFromString(s, b) {
    var k;
    if (b == 16) k = 4; else if (b == 8) k = 3; else if (b == 256) k = 8; else if (b == 2) k = 1; else if (b == 32) k = 5; else if (b == 4) k = 2; else {
      this.fromRadix(s, b);
      return;
    }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while (--i >= 0) {
      var x = k == 8 ? s[i] & 255 : intAt(s, i);
      if (x < 0) {
        if (s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if (sh == 0) this[this.t++] = x; else if (sh + k > this.DB) {
        this[this.t - 1] |= (x & (1 << this.DB - sh) - 1) << sh;
        this[this.t++] = x >> this.DB - sh;
      } else this[this.t - 1] |= x << sh;
      sh += k;
      if (sh >= this.DB) sh -= this.DB;
    }
    if (k == 8 && (s[0] & 128) != 0) {
      this.s = -1;
      if (sh > 0) this[this.t - 1] |= (1 << this.DB - sh) - 1 << sh;
    }
    this.clamp();
    if (mi) BigInteger.ZERO.subTo(this, this);
  }
  function bnpClamp() {
    var c = this.s & this.DM;
    while (this.t > 0 && this[this.t - 1] == c) --this.t;
  }
  function bnToString(b) {
    if (this.s < 0) return "-" + this.negate().toString(b);
    var k;
    if (b == 16) k = 4; else if (b == 8) k = 3; else if (b == 2) k = 1; else if (b == 32) k = 5; else if (b == 4) k = 2; else return this.toRadix(b);
    var km = (1 << k) - 1, d, m = false, r = "", i = this.t;
    var p = this.DB - i * this.DB % k;
    if (i-- > 0) {
      if (p < this.DB && (d = this[i] >> p) > 0) {
        m = true;
        r = int2char(d);
      }
      while (i >= 0) {
        if (p < k) {
          d = (this[i] & (1 << p) - 1) << k - p;
          d |= this[--i] >> (p += this.DB - k);
        } else {
          d = this[i] >> (p -= k) & km;
          if (p <= 0) {
            p += this.DB;
            --i;
          }
        }
        if (d > 0) m = true;
        if (m) r += int2char(d);
      }
    }
    return m ? r : "0";
  }
  function bnNegate() {
    var r = nbi();
    BigInteger.ZERO.subTo(this, r);
    return r;
  }
  function bnAbs() {
    return this.s < 0 ? this.negate() : this;
  }
  function bnCompareTo(a) {
    var r = this.s - a.s;
    if (r != 0) return r;
    var i = this.t;
    r = i - a.t;
    if (r != 0) return r;
    while (--i >= 0) if ((r = this[i] - a[i]) != 0) return r;
    return 0;
  }
  function nbits(x) {
    var r = 1, t;
    if ((t = x >>> 16) != 0) {
      x = t;
      r += 16;
    }
    if ((t = x >> 8) != 0) {
      x = t;
      r += 8;
    }
    if ((t = x >> 4) != 0) {
      x = t;
      r += 4;
    }
    if ((t = x >> 2) != 0) {
      x = t;
      r += 2;
    }
    if ((t = x >> 1) != 0) {
      x = t;
      r += 1;
    }
    return r;
  }
  function bnBitLength() {
    if (this.t <= 0) return 0;
    return this.DB * (this.t - 1) + nbits(this[this.t - 1] ^ this.s & this.DM);
  }
  function bnpDLShiftTo(n, r) {
    var i;
    for (i = this.t - 1; i >= 0; --i) r[i + n] = this[i];
    for (i = n - 1; i >= 0; --i) r[i] = 0;
    r.t = this.t + n;
    r.s = this.s;
  }
  function bnpDRShiftTo(n, r) {
    for (var i = n; i < this.t; ++i) r[i - n] = this[i];
    r.t = Math.max(this.t - n, 0);
    r.s = this.s;
  }
  function bnpLShiftTo(n, r) {
    var bs = n % this.DB;
    var cbs = this.DB - bs;
    var bm = (1 << cbs) - 1;
    var ds = Math.floor(n / this.DB), c = this.s << bs & this.DM, i;
    for (i = this.t - 1; i >= 0; --i) {
      r[i + ds + 1] = this[i] >> cbs | c;
      c = (this[i] & bm) << bs;
    }
    for (i = ds - 1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t + ds + 1;
    r.s = this.s;
    r.clamp();
  }
  function bnpRShiftTo(n, r) {
    r.s = this.s;
    var ds = Math.floor(n / this.DB);
    if (ds >= this.t) {
      r.t = 0;
      return;
    }
    var bs = n % this.DB;
    var cbs = this.DB - bs;
    var bm = (1 << bs) - 1;
    r[0] = this[ds] >> bs;
    for (var i = ds + 1; i < this.t; ++i) {
      r[i - ds - 1] |= (this[i] & bm) << cbs;
      r[i - ds] = this[i] >> bs;
    }
    if (bs > 0) r[this.t - ds - 1] |= (this.s & bm) << cbs;
    r.t = this.t - ds;
    r.clamp();
  }
  function bnpSubTo(a, r) {
    var i = 0, c = 0, m = Math.min(a.t, this.t);
    while (i < m) {
      c += this[i] - a[i];
      r[i++] = c & this.DM;
      c >>= this.DB;
    }
    if (a.t < this.t) {
      c -= a.s;
      while (i < this.t) {
        c += this[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += this.s;
    } else {
      c += this.s;
      while (i < a.t) {
        c -= a[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = c < 0 ? -1 : 0;
    if (c < -1) r[i++] = this.DV + c; else if (c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  function bnpMultiplyTo(a, r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i + y.t;
    while (--i >= 0) r[i] = 0;
    for (i = 0; i < y.t; ++i) r[i + x.t] = x.am(0, y[i], r, i, 0, x.t);
    r.s = 0;
    r.clamp();
    if (this.s != a.s) BigInteger.ZERO.subTo(r, r);
  }
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2 * x.t;
    while (--i >= 0) r[i] = 0;
    for (i = 0; i < x.t - 1; ++i) {
      var c = x.am(i, x[i], r, 2 * i, 0, 1);
      if ((r[i + x.t] += x.am(i + 1, 2 * x[i], r, 2 * i + 1, c, x.t - i - 1)) >= x.DV) {
        r[i + x.t] -= x.DV;
        r[i + x.t + 1] = 1;
      }
    }
    if (r.t > 0) r[r.t - 1] += x.am(i, x[i], r, 2 * i, 0, 1);
    r.s = 0;
    r.clamp();
  }
  function bnpDivRemTo(m, q, r) {
    var pm = m.abs();
    if (pm.t <= 0) return;
    var pt = this.abs();
    if (pt.t < pm.t) {
      if (q != null) q.fromInt(0);
      if (r != null) this.copyTo(r);
      return;
    }
    if (r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB - nbits(pm[pm.t - 1]);
    if (nsh > 0) {
      pm.lShiftTo(nsh, y);
      pt.lShiftTo(nsh, r);
    } else {
      pm.copyTo(y);
      pt.copyTo(r);
    }
    var ys = y.t;
    var y0 = y[ys - 1];
    if (y0 == 0) return;
    var yt = y0 * (1 << this.F1) + (ys > 1 ? y[ys - 2] >> this.F2 : 0);
    var d1 = this.FV / yt, d2 = (1 << this.F1) / yt, e = 1 << this.F2;
    var i = r.t, j = i - ys, t = q == null ? nbi() : q;
    y.dlShiftTo(j, t);
    if (r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t, r);
    }
    BigInteger.ONE.dlShiftTo(ys, t);
    t.subTo(y, y);
    while (y.t < ys) y[y.t++] = 0;
    while (--j >= 0) {
      var qd = r[--i] == y0 ? this.DM : Math.floor(r[i] * d1 + (r[i - 1] + e) * d2);
      if ((r[i] += y.am(0, qd, r, j, 0, ys)) < qd) {
        y.dlShiftTo(j, t);
        r.subTo(t, r);
        while (r[i] < --qd) r.subTo(t, r);
      }
    }
    if (q != null) {
      r.drShiftTo(ys, q);
      if (ts != ms) BigInteger.ZERO.subTo(q, q);
    }
    r.t = ys;
    r.clamp();
    if (nsh > 0) r.rShiftTo(nsh, r);
    if (ts < 0) BigInteger.ZERO.subTo(r, r);
  }
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a, null, r);
    if (this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r, r);
    return r;
  }
  function Classic(m) {
    this.m = m;
  }
  function cConvert(x) {
    if (x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m); else return x;
  }
  function cRevert(x) {
    return x;
  }
  function cReduce(x) {
    x.divRemTo(this.m, null, x);
  }
  function cMulTo(x, y, r) {
    x.multiplyTo(y, r);
    this.reduce(r);
  }
  function cSqrTo(x, r) {
    x.squareTo(r);
    this.reduce(r);
  }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  function bnpInvDigit() {
    if (this.t < 1) return 0;
    var x = this[0];
    if ((x & 1) == 0) return 0;
    var y = x & 3;
    y = y * (2 - (x & 15) * y) & 15;
    y = y * (2 - (x & 255) * y) & 255;
    y = y * (2 - ((x & 65535) * y & 65535)) & 65535;
    y = y * (2 - x * y % this.DV) % this.DV;
    return y > 0 ? this.DV - y : -y;
  }
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp & 32767;
    this.mph = this.mp >> 15;
    this.um = (1 << m.DB - 15) - 1;
    this.mt2 = 2 * m.t;
  }
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t, r);
    r.divRemTo(this.m, null, r);
    if (x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r, r);
    return r;
  }
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  function montReduce(x) {
    while (x.t <= this.mt2) x[x.t++] = 0;
    for (var i = 0; i < this.m.t; ++i) {
      var j = x[i] & 32767;
      var u0 = j * this.mpl + ((j * this.mph + (x[i] >> 15) * this.mpl & this.um) << 15) & x.DM;
      j = i + this.m.t;
      x[j] += this.m.am(0, u0, x, i, 0, this.m.t);
      while (x[j] >= x.DV) {
        x[j] -= x.DV;
        x[++j]++;
      }
    }
    x.clamp();
    x.drShiftTo(this.m.t, x);
    if (x.compareTo(this.m) >= 0) x.subTo(this.m, x);
  }
  function montSqrTo(x, r) {
    x.squareTo(r);
    this.reduce(r);
  }
  function montMulTo(x, y, r) {
    x.multiplyTo(y, r);
    this.reduce(r);
  }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  function bnpIsEven() {
    return (this.t > 0 ? this[0] & 1 : this.s) == 0;
  }
  function bnpExp(e, z) {
    if (e > 4294967295 || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e) - 1;
    g.copyTo(r);
    while (--i >= 0) {
      z.sqrTo(r, r2);
      if ((e & 1 << i) > 0) z.mulTo(r2, g, r); else {
        var t = r;
        r = r2;
        r2 = t;
      }
    }
    return z.revert(r);
  }
  function bnModPowInt(e, m) {
    var z;
    if (e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e, z);
  }
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  function bnpFromRadix(s, b) {
    this.fromInt(0);
    if (b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b, cs), mi = false, j = 0, w = 0;
    for (var i = 0; i < s.length; ++i) {
      var x = intAt(s, i);
      if (x < 0) {
        if (s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b * w + x;
      if (++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w, 0);
        j = 0;
        w = 0;
      }
    }
    if (j > 0) {
      this.dMultiply(Math.pow(b, j));
      this.dAddOffset(w, 0);
    }
    if (mi) BigInteger.ZERO.subTo(this, this);
  }
  function bnpChunkSize(r) {
    return Math.floor(Math.LN2 * this.DB / Math.log(r));
  }
  function bnSigNum() {
    if (this.s < 0) return -1; else if (this.t <= 0 || this.t == 1 && this[0] <= 0) return 0; else return 1;
  }
  function bnpDMultiply(n) {
    this[this.t] = this.am(0, n - 1, this, 0, 0, this.t);
    ++this.t;
    this.clamp();
  }
  function bnpDAddOffset(n, w) {
    if (n == 0) return;
    while (this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while (this[w] >= this.DV) {
      this[w] -= this.DV;
      if (++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  function bnpToRadix(b) {
    if (b == null) b = 10;
    if (this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b, cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d, y, z);
    while (y.signum() > 0) {
      r = (a + z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d, y, z);
    }
    return z.intValue().toString(b) + r;
  }
  function bnIntValue() {
    if (this.s < 0) {
      if (this.t == 1) return this[0] - this.DV; else if (this.t == 0) return -1;
    } else if (this.t == 1) return this[0]; else if (this.t == 0) return 0;
    return (this[1] & (1 << 32 - this.DB) - 1) << this.DB | this[0];
  }
  function bnpAddTo(a, r) {
    var i = 0, c = 0, m = Math.min(a.t, this.t);
    while (i < m) {
      c += this[i] + a[i];
      r[i++] = c & this.DM;
      c >>= this.DB;
    }
    if (a.t < this.t) {
      c += a.s;
      while (i < this.t) {
        c += this[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += this.s;
    } else {
      c += this.s;
      while (i < a.t) {
        c += a[i];
        r[i++] = c & this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = c < 0 ? -1 : 0;
    if (c > 0) r[i++] = c; else if (c < -1) r[i++] = this.DV + c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  var Wrapper = {
    result: [ 0, 0 ],
    add: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.add(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    subtract: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.subtract(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    multiply: (function(xl, xh, yl, yh) {
      var x = new goog.math.Long(xl, xh);
      var y = new goog.math.Long(yl, yh);
      var ret = x.multiply(y);
      Wrapper.result[0] = ret.low_;
      Wrapper.result[1] = ret.high_;
    }),
    makeTwo32: (function() {
      Wrapper.two32 = new BigInteger;
      Wrapper.two32.fromString("4294967296", 10);
    }),
    lh2bignum: (function(l, h) {
      var a = new BigInteger;
      a.fromString(h.toString(), 10);
      var b = new BigInteger;
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger;
      c.fromString(l.toString(), 10);
      var d = new BigInteger;
      c.addTo(b, d);
      return d;
    }),
    divide: (function(xl, xh, yl, yh, unsigned) {
      if (!Wrapper.two32) Wrapper.makeTwo32();
      if (!unsigned) {
        var x = new goog.math.Long(xl, xh);
        var y = new goog.math.Long(yl, yh);
        var ret = x.div(y);
        Wrapper.result[0] = ret.low_;
        Wrapper.result[1] = ret.high_;
      } else {
        var x = Wrapper.lh2bignum(xl >>> 0, xh >>> 0);
        var y = Wrapper.lh2bignum(yl >>> 0, yh >>> 0);
        var z = new BigInteger;
        x.divRemTo(y, z, null);
        var l = new BigInteger;
        var h = new BigInteger;
        z.divRemTo(Wrapper.two32, h, l);
        Wrapper.result[0] = parseInt(l.toString()) | 0;
        Wrapper.result[1] = parseInt(h.toString()) | 0;
      }
    }),
    modulo: (function(xl, xh, yl, yh, unsigned) {
      if (!Wrapper.two32) Wrapper.makeTwo32();
      if (!unsigned) {
        var x = new goog.math.Long(xl, xh);
        var y = new goog.math.Long(yl, yh);
        var ret = x.modulo(y);
        Wrapper.result[0] = ret.low_;
        Wrapper.result[1] = ret.high_;
      } else {
        var x = Wrapper.lh2bignum(xl >>> 0, xh >>> 0);
        var y = Wrapper.lh2bignum(yl >>> 0, yh >>> 0);
        var z = new BigInteger;
        x.divRemTo(y, null, z);
        var l = new BigInteger;
        var h = new BigInteger;
        z.divRemTo(Wrapper.two32, h, l);
        Wrapper.result[0] = parseInt(l.toString()) | 0;
        Wrapper.result[1] = parseInt(h.toString()) | 0;
      }
    }),
    stringify: (function(l, h, unsigned) {
      var ret = (new goog.math.Long(l, h)).toString();
      if (unsigned && ret[0] == "-") {
        if (!Wrapper.two64) {
          Wrapper.two64 = new BigInteger;
          Wrapper.two64.fromString("18446744073709551616", 10);
        }
        var bignum = new BigInteger;
        bignum.fromString(ret, 10);
        ret = new BigInteger;
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    })
  };
  return Wrapper;
})();

var _llvm_dbg_declare;

function _memcpy(dest, src, num, align) {
  if (num >= 20 && src % 2 == dest % 2) {
    if (src % 4 == dest % 4) {
      var stop = src + num;
      while (src % 4) {
        HEAP8[dest++] = HEAP8[src++];
      }
      var src4 = src >> 2, dest4 = dest >> 2, stop4 = stop >> 2;
      while (src4 < stop4) {
        HEAP32[dest4++] = HEAP32[src4++];
      }
      src = src4 << 2;
      dest = dest4 << 2;
      while (src < stop) {
        HEAP8[dest++] = HEAP8[src++];
      }
    } else {
      var stop = src + num;
      if (src % 2) {
        HEAP8[dest++] = HEAP8[src++];
      }
      var src2 = src >> 1, dest2 = dest >> 1, stop2 = stop >> 1;
      while (src2 < stop2) {
        HEAP16[dest2++] = HEAP16[src2++];
      }
      src = src2 << 1;
      dest = dest2 << 1;
      if (src < stop) {
        HEAP8[dest++] = HEAP8[src++];
      }
    }
  } else {
    while (num--) {
      HEAP8[dest++] = HEAP8[src++];
    }
  }
}

var _llvm_memcpy_p0i8_p0i8_i32 = _memcpy;

function _strlen(ptr) {
  return String_len(ptr);
}

function _llvm_ctlz_i32(x) {
  for (var i = 0; i < 32; i++) {
    if ((x & 1 << 31 - i) != 0) {
      return i;
    }
  }
  return 32;
}

function _memset(ptr, value, num, align) {
  if (num >= 20) {
    var stop = ptr + num;
    while (ptr % 4) {
      HEAP8[ptr++] = value;
    }
    if (value < 0) value += 256;
    var ptr4 = ptr >> 2, stop4 = stop >> 2, value4 = value | value << 8 | value << 16 | value << 24;
    while (ptr4 < stop4) {
      HEAP32[ptr4++] = value4;
    }
    ptr = ptr4 << 2;
    while (ptr < stop) {
      HEAP8[ptr++] = value;
    }
  } else {
    while (num--) {
      HEAP8[ptr++] = value;
    }
  }
}

var _llvm_memset_p0i8_i32 = _memset;

function ___cxa_pure_virtual() {
  ABORT = true;
  throw "Pure virtual function called!";
}

var ERRNO_CODES = {
  E2BIG: 7,
  EACCES: 13,
  EADDRINUSE: 98,
  EADDRNOTAVAIL: 99,
  EAFNOSUPPORT: 97,
  EAGAIN: 11,
  EALREADY: 114,
  EBADF: 9,
  EBADMSG: 74,
  EBUSY: 16,
  ECANCELED: 125,
  ECHILD: 10,
  ECONNABORTED: 103,
  ECONNREFUSED: 111,
  ECONNRESET: 104,
  EDEADLK: 35,
  EDESTADDRREQ: 89,
  EDOM: 33,
  EDQUOT: 122,
  EEXIST: 17,
  EFAULT: 14,
  EFBIG: 27,
  EHOSTUNREACH: 113,
  EIDRM: 43,
  EILSEQ: 84,
  EINPROGRESS: 115,
  EINTR: 4,
  EINVAL: 22,
  EIO: 5,
  EISCONN: 106,
  EISDIR: 21,
  ELOOP: 40,
  EMFILE: 24,
  EMLINK: 31,
  EMSGSIZE: 90,
  EMULTIHOP: 72,
  ENAMETOOLONG: 36,
  ENETDOWN: 100,
  ENETRESET: 102,
  ENETUNREACH: 101,
  ENFILE: 23,
  ENOBUFS: 105,
  ENODATA: 61,
  ENODEV: 19,
  ENOENT: 2,
  ENOEXEC: 8,
  ENOLCK: 37,
  ENOLINK: 67,
  ENOMEM: 12,
  ENOMSG: 42,
  ENOPROTOOPT: 92,
  ENOSPC: 28,
  ENOSR: 63,
  ENOSTR: 60,
  ENOSYS: 38,
  ENOTCONN: 107,
  ENOTDIR: 20,
  ENOTEMPTY: 39,
  ENOTRECOVERABLE: 131,
  ENOTSOCK: 88,
  ENOTSUP: 95,
  ENOTTY: 25,
  ENXIO: 6,
  EOVERFLOW: 75,
  EOWNERDEAD: 130,
  EPERM: 1,
  EPIPE: 32,
  EPROTO: 71,
  EPROTONOSUPPORT: 93,
  EPROTOTYPE: 91,
  ERANGE: 34,
  EROFS: 30,
  ESPIPE: 29,
  ESRCH: 3,
  ESTALE: 116,
  ETIME: 62,
  ETIMEDOUT: 110,
  ETXTBSY: 26,
  EWOULDBLOCK: 11,
  EXDEV: 18
};

function ___setErrNo(value) {
  if (!___setErrNo.ret) ___setErrNo.ret = allocate([ 0 ], "i32", ALLOC_STATIC);
  HEAP32[___setErrNo.ret >> 2] = value;
  return value;
}

var _stdin = 0;

var _stdout = 0;

var _stderr = 0;

var __impure_ptr = 0;

var FS = {
  currentPath: "/",
  nextInode: 2,
  streams: [ null ],
  ignorePermissions: true,
  absolutePath: (function(relative, base) {
    if (typeof relative !== "string") return null;
    if (base === undefined) base = FS.currentPath;
    if (relative && relative[0] == "/") base = "";
    var full = base + "/" + relative;
    var parts = full.split("/").reverse();
    var absolute = [ "" ];
    while (parts.length) {
      var part = parts.pop();
      if (part == "" || part == ".") {} else if (part == "..") {
        if (absolute.length > 1) absolute.pop();
      } else {
        absolute.push(part);
      }
    }
    return absolute.length == 1 ? "/" : absolute.join("/");
  }),
  analyzePath: (function(path, dontResolveLastLink, linksVisited) {
    var ret = {
      isRoot: false,
      exists: false,
      error: 0,
      name: null,
      path: null,
      object: null,
      parentExists: false,
      parentPath: null,
      parentObject: null
    };
    path = FS.absolutePath(path);
    if (path == "/") {
      ret.isRoot = true;
      ret.exists = ret.parentExists = true;
      ret.name = "/";
      ret.path = ret.parentPath = "/";
      ret.object = ret.parentObject = FS.root;
    } else if (path !== null) {
      linksVisited = linksVisited || 0;
      path = path.slice(1).split("/");
      var current = FS.root;
      var traversed = [ "" ];
      while (path.length) {
        if (path.length == 1 && current.isFolder) {
          ret.parentExists = true;
          ret.parentPath = traversed.length == 1 ? "/" : traversed.join("/");
          ret.parentObject = current;
          ret.name = path[0];
        }
        var target = path.shift();
        if (!current.isFolder) {
          ret.error = ERRNO_CODES.ENOTDIR;
          break;
        } else if (!current.read) {
          ret.error = ERRNO_CODES.EACCES;
          break;
        } else if (!current.contents.hasOwnProperty(target)) {
          ret.error = ERRNO_CODES.ENOENT;
          break;
        }
        current = current.contents[target];
        if (current.link && !(dontResolveLastLink && path.length == 0)) {
          if (linksVisited > 40) {
            ret.error = ERRNO_CODES.ELOOP;
            break;
          }
          var link = FS.absolutePath(current.link, traversed.join("/"));
          ret = FS.analyzePath([ link ].concat(path).join("/"), dontResolveLastLink, linksVisited + 1);
          return ret;
        }
        traversed.push(target);
        if (path.length == 0) {
          ret.exists = true;
          ret.path = traversed.join("/");
          ret.object = current;
        }
      }
    }
    return ret;
  }),
  findObject: (function(path, dontResolveLastLink) {
    FS.ensureRoot();
    var ret = FS.analyzePath(path, dontResolveLastLink);
    if (ret.exists) {
      return ret.object;
    } else {
      ___setErrNo(ret.error);
      return null;
    }
  }),
  createObject: (function(parent, name, properties, canRead, canWrite) {
    if (!parent) parent = "/";
    if (typeof parent === "string") parent = FS.findObject(parent);
    if (!parent) {
      ___setErrNo(ERRNO_CODES.EACCES);
      throw new Error("Parent path must exist.");
    }
    if (!parent.isFolder) {
      ___setErrNo(ERRNO_CODES.ENOTDIR);
      throw new Error("Parent must be a folder.");
    }
    if (!parent.write && !FS.ignorePermissions) {
      ___setErrNo(ERRNO_CODES.EACCES);
      throw new Error("Parent folder must be writeable.");
    }
    if (!name || name == "." || name == "..") {
      ___setErrNo(ERRNO_CODES.ENOENT);
      throw new Error("Name must not be empty.");
    }
    if (parent.contents.hasOwnProperty(name)) {
      ___setErrNo(ERRNO_CODES.EEXIST);
      throw new Error("Can't overwrite object.");
    }
    parent.contents[name] = {
      read: canRead === undefined ? true : canRead,
      write: canWrite === undefined ? false : canWrite,
      timestamp: Date.now(),
      inodeNumber: FS.nextInode++
    };
    for (var key in properties) {
      if (properties.hasOwnProperty(key)) {
        parent.contents[name][key] = properties[key];
      }
    }
    return parent.contents[name];
  }),
  createFolder: (function(parent, name, canRead, canWrite) {
    var properties = {
      isFolder: true,
      isDevice: false,
      contents: {}
    };
    return FS.createObject(parent, name, properties, canRead, canWrite);
  }),
  createPath: (function(parent, path, canRead, canWrite) {
    var current = FS.findObject(parent);
    if (current === null) throw new Error("Invalid parent.");
    path = path.split("/").reverse();
    while (path.length) {
      var part = path.pop();
      if (!part) continue;
      if (!current.contents.hasOwnProperty(part)) {
        FS.createFolder(current, part, canRead, canWrite);
      }
      current = current.contents[part];
    }
    return current;
  }),
  createFile: (function(parent, name, properties, canRead, canWrite) {
    properties.isFolder = false;
    return FS.createObject(parent, name, properties, canRead, canWrite);
  }),
  createDataFile: (function(parent, name, data, canRead, canWrite) {
    if (typeof data === "string") {
      var dataArray = new Array(data.length);
      for (var i = 0, len = data.length; i < len; ++i) dataArray[i] = data.charCodeAt(i);
      data = dataArray;
    }
    var properties = {
      isDevice: false,
      contents: data
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createLazyFile: (function(parent, name, url, canRead, canWrite) {
    var properties = {
      isDevice: false,
      url: url
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createLink: (function(parent, name, target, canRead, canWrite) {
    var properties = {
      isDevice: false,
      link: target
    };
    return FS.createFile(parent, name, properties, canRead, canWrite);
  }),
  createDevice: (function(parent, name, input, output) {
    if (!(input || output)) {
      throw new Error("A device must have at least one callback defined.");
    }
    var ops = {
      isDevice: true,
      input: input,
      output: output
    };
    return FS.createFile(parent, name, ops, Boolean(input), Boolean(output));
  }),
  forceLoadFile: (function(obj) {
    if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
    var success = true;
    if (typeof XMLHttpRequest !== "undefined") {
      assert("Cannot do synchronous binary XHRs in modern browsers. Use --embed-file or --preload-file in emcc");
    } else if (Module["read"]) {
      try {
        obj.contents = intArrayFromString(Module["read"](obj.url), true);
      } catch (e) {
        success = false;
      }
    } else {
      throw new Error("Cannot load without read() or XMLHttpRequest.");
    }
    if (!success) ___setErrNo(ERRNO_CODES.EIO);
    return success;
  }),
  ensureRoot: (function() {
    if (FS.root) return;
    FS.root = {
      read: true,
      write: true,
      isFolder: true,
      isDevice: false,
      timestamp: Date.now(),
      inodeNumber: 1,
      contents: {}
    };
  }),
  init: (function(input, output, error) {
    assert(!FS.init.initialized, "FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)");
    FS.init.initialized = true;
    FS.ensureRoot();
    input = input || Module["stdin"];
    output = output || Module["stdout"];
    error = error || Module["stderr"];
    var stdinOverridden = true, stdoutOverridden = true, stderrOverridden = true;
    if (!input) {
      stdinOverridden = false;
      input = (function() {
        if (!input.cache || !input.cache.length) {
          var result;
          if (typeof window != "undefined" && typeof window.prompt == "function") {
            result = window.prompt("Input: ");
          } else if (typeof readline == "function") {
            result = readline();
          }
          if (!result) result = "";
          input.cache = intArrayFromString(result + "\n", true);
        }
        return input.cache.shift();
      });
    }
    function simpleOutput(val) {
      if (val === null || val === "\n".charCodeAt(0)) {
        output.printer(output.buffer.join(""));
        output.buffer = [];
      } else {
        output.buffer.push(String.fromCharCode(val));
      }
    }
    if (!output) {
      stdoutOverridden = false;
      output = simpleOutput;
    }
    if (!output.printer) output.printer = Module["print"];
    if (!output.buffer) output.buffer = [];
    if (!error) {
      stderrOverridden = false;
      error = simpleOutput;
    }
    if (!error.printer) error.printer = Module["print"];
    if (!error.buffer) error.buffer = [];
    FS.createFolder("/", "tmp", true, true);
    var devFolder = FS.createFolder("/", "dev", true, true);
    var stdin = FS.createDevice(devFolder, "stdin", input);
    var stdout = FS.createDevice(devFolder, "stdout", null, output);
    var stderr = FS.createDevice(devFolder, "stderr", null, error);
    FS.createDevice(devFolder, "tty", input, output);
    FS.streams[1] = {
      path: "/dev/stdin",
      object: stdin,
      position: 0,
      isRead: true,
      isWrite: false,
      isAppend: false,
      isTerminal: !stdinOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    FS.streams[2] = {
      path: "/dev/stdout",
      object: stdout,
      position: 0,
      isRead: false,
      isWrite: true,
      isAppend: false,
      isTerminal: !stdoutOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    FS.streams[3] = {
      path: "/dev/stderr",
      object: stderr,
      position: 0,
      isRead: false,
      isWrite: true,
      isAppend: false,
      isTerminal: !stderrOverridden,
      error: false,
      eof: false,
      ungotten: []
    };
    _stdin = allocate([ 1 ], "void*", ALLOC_STATIC);
    _stdout = allocate([ 2 ], "void*", ALLOC_STATIC);
    _stderr = allocate([ 3 ], "void*", ALLOC_STATIC);
    FS.createPath("/", "dev/shm/tmp", true, true);
    FS.streams[_stdin] = FS.streams[1];
    FS.streams[_stdout] = FS.streams[2];
    FS.streams[_stderr] = FS.streams[3];
    __impure_ptr = allocate([ allocate([ 0, 0, 0, 0, _stdin, 0, 0, 0, _stdout, 0, 0, 0, _stderr, 0, 0, 0 ], "void*", ALLOC_STATIC) ], "void*", ALLOC_STATIC);
  }),
  quit: (function() {
    if (!FS.init.initialized) return;
    if (FS.streams[2] && FS.streams[2].object.output.buffer.length > 0) FS.streams[2].object.output("\n".charCodeAt(0));
    if (FS.streams[3] && FS.streams[3].object.output.buffer.length > 0) FS.streams[3].object.output("\n".charCodeAt(0));
  }),
  standardizePath: (function(path) {
    if (path.substr(0, 2) == "./") path = path.substr(2);
    return path;
  }),
  deleteFile: (function(path) {
    var path = FS.analyzePath(path);
    if (!path.parentExists || !path.exists) {
      throw "Invalid path " + path;
    }
    delete path.parentObject.contents[path.name];
  })
};

function _mmap(start, num, prot, flags, stream, offset) {
  if (stream == -1) {
    var ptr = _malloc(num);
    _memset(ptr, 0, num);
    return ptr;
  }
  var info = FS.streams[stream];
  if (!info) return -1;
  var contents = info.object.contents;
  contents = Array.prototype.slice.call(contents, offset, offset + num);
  return allocate(contents, "i8", ALLOC_NORMAL);
}

function _munmap(start, num) {
  _free(start);
  return 0;
}

function _fflush(stream) {
  var flush = (function(filedes) {
    if (filedes in FS.streams && FS.streams[filedes].object.output) {
      if (!FS.streams[filedes].isTerminal) {
        FS.streams[filedes].object.output(null);
      }
    }
  });
  try {
    if (stream === 0) {
      for (var i in FS.streams) flush(i);
    } else {
      flush(stream);
    }
    return 0;
  } catch (e) {
    ___setErrNo(ERRNO_CODES.EIO);
    return -1;
  }
}

function _pwrite(fildes, buf, nbyte, offset) {
  var stream = FS.streams[fildes];
  if (!stream || stream.object.isDevice) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isWrite) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (stream.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else if (nbyte < 0 || offset < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var contents = stream.object.contents;
    while (contents.length < offset) contents.push(0);
    for (var i = 0; i < nbyte; i++) {
      contents[offset + i] = HEAPU8[buf + i];
    }
    stream.object.timestamp = Date.now();
    return i;
  }
}

function _write(fildes, buf, nbyte) {
  var stream = FS.streams[fildes];
  if (!stream) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isWrite) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (nbyte < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    if (stream.object.isDevice) {
      if (stream.object.output) {
        for (var i = 0; i < nbyte; i++) {
          try {
            stream.object.output(HEAP8[buf + i]);
          } catch (e) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
        }
        stream.object.timestamp = Date.now();
        return i;
      } else {
        ___setErrNo(ERRNO_CODES.ENXIO);
        return -1;
      }
    } else {
      var bytesWritten = _pwrite(fildes, buf, nbyte, stream.position);
      if (bytesWritten != -1) stream.position += bytesWritten;
      return bytesWritten;
    }
  }
}

function _fwrite(ptr, size, nitems, stream) {
  var bytesToWrite = nitems * size;
  if (bytesToWrite == 0) return 0;
  var bytesWritten = _write(stream, ptr, bytesToWrite);
  if (bytesWritten == -1) {
    if (FS.streams[stream]) FS.streams[stream].error = true;
    return -1;
  } else {
    return Math.floor(bytesWritten / size);
  }
}

function __formatString(format, varargs) {
  var textIndex = format;
  var argIndex = 0;
  function getNextArg(type) {
    var ret;
    if (type === "double") {
      ret = (tempDoubleI32[0] = HEAP32[varargs + argIndex >> 2], tempDoubleI32[1] = HEAP32[varargs + argIndex + 4 >> 2], tempDoubleF64[0]);
    } else if (type == "i64") {
      ret = [ HEAP32[varargs + argIndex >> 2], HEAP32[varargs + argIndex + 4 >> 2] ];
    } else {
      type = "i32";
      ret = HEAP32[varargs + argIndex >> 2];
    }
    argIndex += Runtime.getNativeFieldSize(type);
    return ret;
  }
  var ret = [];
  var curr, next, currArg;
  while (1) {
    var startTextIndex = textIndex;
    curr = HEAP8[textIndex];
    if (curr === 0) break;
    next = HEAP8[textIndex + 1];
    if (curr == "%".charCodeAt(0)) {
      var flagAlwaysSigned = false;
      var flagLeftAlign = false;
      var flagAlternative = false;
      var flagZeroPad = false;
      flagsLoop : while (1) {
        switch (next) {
         case "+".charCodeAt(0):
          flagAlwaysSigned = true;
          break;
         case "-".charCodeAt(0):
          flagLeftAlign = true;
          break;
         case "#".charCodeAt(0):
          flagAlternative = true;
          break;
         case "0".charCodeAt(0):
          if (flagZeroPad) {
            break flagsLoop;
          } else {
            flagZeroPad = true;
            break;
          }
         default:
          break flagsLoop;
        }
        textIndex++;
        next = HEAP8[textIndex + 1];
      }
      var width = 0;
      if (next == "*".charCodeAt(0)) {
        width = getNextArg("i32");
        textIndex++;
        next = HEAP8[textIndex + 1];
      } else {
        while (next >= "0".charCodeAt(0) && next <= "9".charCodeAt(0)) {
          width = width * 10 + (next - "0".charCodeAt(0));
          textIndex++;
          next = HEAP8[textIndex + 1];
        }
      }
      var precisionSet = false;
      if (next == ".".charCodeAt(0)) {
        var precision = 0;
        precisionSet = true;
        textIndex++;
        next = HEAP8[textIndex + 1];
        if (next == "*".charCodeAt(0)) {
          precision = getNextArg("i32");
          textIndex++;
        } else {
          while (1) {
            var precisionChr = HEAP8[textIndex + 1];
            if (precisionChr < "0".charCodeAt(0) || precisionChr > "9".charCodeAt(0)) break;
            precision = precision * 10 + (precisionChr - "0".charCodeAt(0));
            textIndex++;
          }
        }
        next = HEAP8[textIndex + 1];
      } else {
        var precision = 6;
      }
      var argSize;
      switch (String.fromCharCode(next)) {
       case "h":
        var nextNext = HEAP8[textIndex + 2];
        if (nextNext == "h".charCodeAt(0)) {
          textIndex++;
          argSize = 1;
        } else {
          argSize = 2;
        }
        break;
       case "l":
        var nextNext = HEAP8[textIndex + 2];
        if (nextNext == "l".charCodeAt(0)) {
          textIndex++;
          argSize = 8;
        } else {
          argSize = 4;
        }
        break;
       case "L":
       case "q":
       case "j":
        argSize = 8;
        break;
       case "z":
       case "t":
       case "I":
        argSize = 4;
        break;
       default:
        argSize = null;
      }
      if (argSize) textIndex++;
      next = HEAP8[textIndex + 1];
      if ([ "d", "i", "u", "o", "x", "X", "p" ].indexOf(String.fromCharCode(next)) != -1) {
        var signed = next == "d".charCodeAt(0) || next == "i".charCodeAt(0);
        argSize = argSize || 4;
        var currArg = getNextArg("i" + argSize * 8);
        var origArg = currArg;
        var argText;
        if (argSize == 8) {
          currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == "u".charCodeAt(0));
        }
        if (argSize <= 4) {
          var limit = Math.pow(256, argSize) - 1;
          currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
        }
        var currAbsArg = Math.abs(currArg);
        var prefix = "";
        if (next == "d".charCodeAt(0) || next == "i".charCodeAt(0)) {
          if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1]); else argText = reSign(currArg, 8 * argSize, 1).toString(10);
        } else if (next == "u".charCodeAt(0)) {
          if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else argText = unSign(currArg, 8 * argSize, 1).toString(10);
          currArg = Math.abs(currArg);
        } else if (next == "o".charCodeAt(0)) {
          argText = (flagAlternative ? "0" : "") + currAbsArg.toString(8);
        } else if (next == "x".charCodeAt(0) || next == "X".charCodeAt(0)) {
          prefix = flagAlternative ? "0x" : "";
          if (currArg < 0) {
            currArg = -currArg;
            argText = (currAbsArg - 1).toString(16);
            var buffer = [];
            for (var i = 0; i < argText.length; i++) {
              buffer.push((15 - parseInt(argText[i], 16)).toString(16));
            }
            argText = buffer.join("");
            while (argText.length < argSize * 2) argText = "f" + argText;
          } else {
            argText = currAbsArg.toString(16);
          }
          if (next == "X".charCodeAt(0)) {
            prefix = prefix.toUpperCase();
            argText = argText.toUpperCase();
          }
        } else if (next == "p".charCodeAt(0)) {
          if (currAbsArg === 0) {
            argText = "(nil)";
          } else {
            prefix = "0x";
            argText = currAbsArg.toString(16);
          }
        }
        if (precisionSet) {
          while (argText.length < precision) {
            argText = "0" + argText;
          }
        }
        if (flagAlwaysSigned) {
          if (currArg < 0) {
            prefix = "-" + prefix;
          } else {
            prefix = "+" + prefix;
          }
        }
        while (prefix.length + argText.length < width) {
          if (flagLeftAlign) {
            argText += " ";
          } else {
            if (flagZeroPad) {
              argText = "0" + argText;
            } else {
              prefix = " " + prefix;
            }
          }
        }
        argText = prefix + argText;
        argText.split("").forEach((function(chr) {
          ret.push(chr.charCodeAt(0));
        }));
      } else if ([ "f", "F", "e", "E", "g", "G" ].indexOf(String.fromCharCode(next)) != -1) {
        var currArg = getNextArg("double");
        var argText;
        if (isNaN(currArg)) {
          argText = "nan";
          flagZeroPad = false;
        } else if (!isFinite(currArg)) {
          argText = (currArg < 0 ? "-" : "") + "inf";
          flagZeroPad = false;
        } else {
          var isGeneral = false;
          var effectivePrecision = Math.min(precision, 20);
          if (next == "g".charCodeAt(0) || next == "G".charCodeAt(0)) {
            isGeneral = true;
            precision = precision || 1;
            var exponent = parseInt(currArg.toExponential(effectivePrecision).split("e")[1], 10);
            if (precision > exponent && exponent >= -4) {
              next = (next == "g".charCodeAt(0) ? "f" : "F").charCodeAt(0);
              precision -= exponent + 1;
            } else {
              next = (next == "g".charCodeAt(0) ? "e" : "E").charCodeAt(0);
              precision--;
            }
            effectivePrecision = Math.min(precision, 20);
          }
          if (next == "e".charCodeAt(0) || next == "E".charCodeAt(0)) {
            argText = currArg.toExponential(effectivePrecision);
            if (/[eE][-+]\d$/.test(argText)) {
              argText = argText.slice(0, -1) + "0" + argText.slice(-1);
            }
          } else if (next == "f".charCodeAt(0) || next == "F".charCodeAt(0)) {
            argText = currArg.toFixed(effectivePrecision);
          }
          var parts = argText.split("e");
          if (isGeneral && !flagAlternative) {
            while (parts[0].length > 1 && parts[0].indexOf(".") != -1 && (parts[0].slice(-1) == "0" || parts[0].slice(-1) == ".")) {
              parts[0] = parts[0].slice(0, -1);
            }
          } else {
            if (flagAlternative && argText.indexOf(".") == -1) parts[0] += ".";
            while (precision > effectivePrecision++) parts[0] += "0";
          }
          argText = parts[0] + (parts.length > 1 ? "e" + parts[1] : "");
          if (next == "E".charCodeAt(0)) argText = argText.toUpperCase();
          if (flagAlwaysSigned && currArg >= 0) {
            argText = "+" + argText;
          }
        }
        while (argText.length < width) {
          if (flagLeftAlign) {
            argText += " ";
          } else {
            if (flagZeroPad && (argText[0] == "-" || argText[0] == "+")) {
              argText = argText[0] + "0" + argText.slice(1);
            } else {
              argText = (flagZeroPad ? "0" : " ") + argText;
            }
          }
        }
        if (next < "a".charCodeAt(0)) argText = argText.toUpperCase();
        argText.split("").forEach((function(chr) {
          ret.push(chr.charCodeAt(0));
        }));
      } else if (next == "s".charCodeAt(0)) {
        var arg = getNextArg("i8*");
        var copiedString;
        if (arg) {
          copiedString = String_copy(arg);
          if (precisionSet && copiedString.length > precision) {
            copiedString = copiedString.slice(0, precision);
          }
        } else {
          copiedString = intArrayFromString("(null)", true);
        }
        if (!flagLeftAlign) {
          while (copiedString.length < width--) {
            ret.push(" ".charCodeAt(0));
          }
        }
        ret = ret.concat(copiedString);
        if (flagLeftAlign) {
          while (copiedString.length < width--) {
            ret.push(" ".charCodeAt(0));
          }
        }
      } else if (next == "c".charCodeAt(0)) {
        if (flagLeftAlign) ret.push(getNextArg("i8"));
        while (--width > 0) {
          ret.push(" ".charCodeAt(0));
        }
        if (!flagLeftAlign) ret.push(getNextArg("i8"));
      } else if (next == "n".charCodeAt(0)) {
        var ptr = getNextArg("i32*");
        HEAP32[ptr >> 2] = ret.length;
      } else if (next == "%".charCodeAt(0)) {
        ret.push(curr);
      } else {
        for (var i = startTextIndex; i < textIndex + 2; i++) {
          ret.push(HEAP8[i]);
        }
      }
      textIndex += 2;
    } else {
      ret.push(curr);
      textIndex += 1;
    }
  }
  return ret;
}

function _fprintf(stream, format, varargs) {
  var result = __formatString(format, varargs);
  var stack = Runtime.stackSave();
  var ret = _fwrite(allocate(result, "i8", ALLOC_STACK), 1, result.length, stream);
  Runtime.stackRestore(stack);
  return ret;
}

var _llvm_va_start;

var _vfprintf = _fprintf;

function _llvm_va_end() {}

function ___fpclassifyf(x) {
  if (isNaN(x)) return 0;
  if (!isFinite(x)) return 1;
  if (x == 0) return 2;
  return 4;
}

var ___fpclassifyd = ___fpclassifyf;

function _memcmp(p1, p2, num) {
  for (var i = 0; i < num; i++) {
    var v1 = HEAP8[p1 + i];
    var v2 = HEAP8[p2 + i];
    if (v1 != v2) return v1 > v2 ? 1 : -1;
  }
  return 0;
}

function _isspace(chr) {
  return chr in {
    32: 0,
    9: 0,
    10: 0,
    11: 0,
    12: 0,
    13: 0
  };
}

function _strncmp(px, py, n) {
  var i = 0;
  while (i < n) {
    var x = HEAP8[px + i];
    var y = HEAP8[py + i];
    if (x == y && x == 0) return 0;
    if (x == 0) return -1;
    if (y == 0) return 1;
    if (x == y) {
      i++;
      continue;
    } else {
      return x > y ? 1 : -1;
    }
  }
  return 0;
}

function _strcmp(px, py) {
  return _strncmp(px, py, TOTAL_MEMORY);
}

var ___dirent_struct_layout = null;

function _open(path, oflag, varargs) {
  var mode = HEAP32[varargs >> 2];
  var accessMode = oflag & 3;
  var isWrite = accessMode != 0;
  var isRead = accessMode != 1;
  var isCreate = Boolean(oflag & 512);
  var isExistCheck = Boolean(oflag & 2048);
  var isTruncate = Boolean(oflag & 1024);
  var isAppend = Boolean(oflag & 8);
  var origPath = path;
  path = FS.analyzePath(Pointer_stringify(path));
  if (!path.parentExists) {
    ___setErrNo(path.error);
    return -1;
  }
  var target = path.object || null;
  var finalPath;
  if (target) {
    if (isCreate && isExistCheck) {
      ___setErrNo(ERRNO_CODES.EEXIST);
      return -1;
    }
    if ((isWrite || isCreate || isTruncate) && target.isFolder) {
      ___setErrNo(ERRNO_CODES.EISDIR);
      return -1;
    }
    if (isRead && !target.read || isWrite && !target.write) {
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    }
    if (isTruncate && !target.isDevice) {
      target.contents = [];
    } else {
      if (!FS.forceLoadFile(target)) {
        ___setErrNo(ERRNO_CODES.EIO);
        return -1;
      }
    }
    finalPath = path.path;
  } else {
    if (!isCreate) {
      ___setErrNo(ERRNO_CODES.ENOENT);
      return -1;
    }
    if (!path.parentObject.write) {
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    }
    target = FS.createDataFile(path.parentObject, path.name, [], mode & 256, mode & 128);
    finalPath = path.parentPath + "/" + path.name;
  }
  var id = FS.streams.length;
  if (target.isFolder) {
    var entryBuffer = 0;
    if (___dirent_struct_layout) {
      entryBuffer = _malloc(___dirent_struct_layout.__size__);
    }
    var contents = [];
    for (var key in target.contents) contents.push(key);
    FS.streams[id] = {
      path: finalPath,
      object: target,
      position: -2,
      isRead: true,
      isWrite: false,
      isAppend: false,
      error: false,
      eof: false,
      ungotten: [],
      contents: contents,
      currentEntry: entryBuffer
    };
  } else {
    FS.streams[id] = {
      path: finalPath,
      object: target,
      position: 0,
      isRead: isRead,
      isWrite: isWrite,
      isAppend: isAppend,
      error: false,
      eof: false,
      ungotten: []
    };
  }
  return id;
}

function _fopen(filename, mode) {
  var flags;
  mode = Pointer_stringify(mode);
  if (mode[0] == "r") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 0;
    }
  } else if (mode[0] == "w") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 1;
    }
    flags |= 512;
    flags |= 1024;
  } else if (mode[0] == "a") {
    if (mode.indexOf("+") != -1) {
      flags = 2;
    } else {
      flags = 1;
    }
    flags |= 512;
    flags |= 8;
  } else {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return 0;
  }
  var ret = _open(filename, flags, allocate([ 511, 0, 0, 0 ], "i32", ALLOC_STACK));
  return ret == -1 ? 0 : ret;
}

function _close(fildes) {
  if (FS.streams[fildes]) {
    if (FS.streams[fildes].currentEntry) {
      _free(FS.streams[fildes].currentEntry);
    }
    delete FS.streams[fildes];
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fsync(fildes) {
  if (FS.streams[fildes]) {
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fclose(stream) {
  _fsync(stream);
  return _close(stream);
}

var ___stat_struct_layout = {
  __size__: 72,
  st_dev: 0,
  st_ino: 4,
  st_mode: 8,
  st_nlink: 12,
  st_uid: 16,
  st_gid: 20,
  st_rdev: 24,
  st_size: 28,
  st_atime: 32,
  st_spare1: 36,
  st_mtime: 40,
  st_spare2: 44,
  st_ctime: 48,
  st_spare3: 52,
  st_blksize: 56,
  st_blocks: 60,
  st_spare4: 64
};

function _stat(path, buf, dontResolveLastLink) {
  var obj = FS.findObject(Pointer_stringify(path), dontResolveLastLink);
  if (obj === null || !FS.forceLoadFile(obj)) return -1;
  var offsets = ___stat_struct_layout;
  HEAP32[buf + offsets.st_nlink >> 2] = 1;
  HEAP32[buf + offsets.st_uid >> 2] = 0;
  HEAP32[buf + offsets.st_gid >> 2] = 0;
  HEAP32[buf + offsets.st_blksize >> 2] = 4096;
  HEAP32[buf + offsets.st_ino >> 2] = obj.inodeNumber;
  var time = Math.floor(obj.timestamp / 1e3);
  if (offsets.st_atime === undefined) {
    offsets.st_atime = offsets.st_atim.tv_sec;
    offsets.st_mtime = offsets.st_mtim.tv_sec;
    offsets.st_ctime = offsets.st_ctim.tv_sec;
    var nanosec = obj.timestamp % 1e3 * 1e3;
    HEAP32[buf + offsets.st_atim.tv_nsec >> 2] = nanosec;
    HEAP32[buf + offsets.st_mtim.tv_nsec >> 2] = nanosec;
    HEAP32[buf + offsets.st_ctim.tv_nsec >> 2] = nanosec;
  }
  HEAP32[buf + offsets.st_atime >> 2] = time;
  HEAP32[buf + offsets.st_mtime >> 2] = time;
  HEAP32[buf + offsets.st_ctime >> 2] = time;
  var mode = 0;
  var size = 0;
  var blocks = 0;
  var dev = 0;
  var rdev = 0;
  if (obj.isDevice) {
    dev = rdev = obj.inodeNumber;
    size = blocks = 0;
    mode = 8192;
  } else {
    dev = 1;
    rdev = 0;
    if (obj.isFolder) {
      size = 4096;
      blocks = 1;
      mode = 16384;
    } else {
      var data = obj.contents || obj.link;
      size = data.length;
      blocks = Math.ceil(data.length / 4096);
      mode = obj.link === undefined ? 32768 : 40960;
    }
  }
  HEAP32[buf + offsets.st_dev >> 2] = dev;
  HEAP32[buf + offsets.st_rdev >> 2] = rdev;
  HEAP32[buf + offsets.st_size >> 2] = size;
  HEAP32[buf + offsets.st_blocks >> 2] = blocks;
  if (obj.read) mode |= 365;
  if (obj.write) mode |= 146;
  HEAP32[buf + offsets.st_mode >> 2] = mode;
  return 0;
}

function _fstat(fildes, buf) {
  if (!FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else {
    var pathArray = intArrayFromString(FS.streams[fildes].path);
    return _stat(allocate(pathArray, "i8", ALLOC_STACK), buf);
  }
}

function _fileno(stream) {
  return stream;
}

function _pread(fildes, buf, nbyte, offset) {
  var stream = FS.streams[fildes];
  if (!stream || stream.object.isDevice) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isRead) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (stream.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else if (nbyte < 0 || offset < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var bytesRead = 0;
    while (stream.ungotten.length && nbyte > 0) {
      HEAP8[buf++] = stream.ungotten.pop();
      nbyte--;
      bytesRead++;
    }
    var contents = stream.object.contents;
    var size = Math.min(contents.length - offset, nbyte);
    for (var i = 0; i < size; i++) {
      HEAP8[buf + i] = contents[offset + i];
      bytesRead++;
    }
    return bytesRead;
  }
}

function _read(fildes, buf, nbyte) {
  var stream = FS.streams[fildes];
  if (!stream) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (!stream.isRead) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (nbyte < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var bytesRead;
    if (stream.object.isDevice) {
      if (stream.object.input) {
        bytesRead = 0;
        while (stream.ungotten.length && nbyte > 0) {
          HEAP8[buf++] = stream.ungotten.pop();
          nbyte--;
          bytesRead++;
        }
        for (var i = 0; i < nbyte; i++) {
          try {
            var result = stream.object.input();
          } catch (e) {
            ___setErrNo(ERRNO_CODES.EIO);
            return -1;
          }
          if (result === null || result === undefined) break;
          bytesRead++;
          HEAP8[buf + i] = result;
        }
        return bytesRead;
      } else {
        ___setErrNo(ERRNO_CODES.ENXIO);
        return -1;
      }
    } else {
      var ungotSize = stream.ungotten.length;
      bytesRead = _pread(fildes, buf, nbyte, stream.position);
      if (bytesRead != -1) {
        stream.position += stream.ungotten.length - ungotSize + bytesRead;
      }
      return bytesRead;
    }
  }
}

function _fgetc(stream) {
  if (!(stream in FS.streams)) return -1;
  var streamObj = FS.streams[stream];
  if (streamObj.eof || streamObj.error) return -1;
  var ret = _read(stream, _fgetc.ret, 1);
  if (ret == 0) {
    streamObj.eof = true;
    return -1;
  } else if (ret == -1) {
    streamObj.error = true;
    return -1;
  } else {
    return HEAP8[_fgetc.ret];
  }
}

var _getc_unlocked = _fgetc;

function _memmove(dest, src, num, align) {
  if (src < dest && dest < src + num) {
    src += num;
    dest += num;
    while (num--) {
      dest--;
      src--;
      HEAP8[dest] = HEAP8[src];
    }
  } else {
    _memcpy(dest, src, num, align);
  }
}

var _llvm_memmove_p0i8_p0i8_i32 = _memmove;

function _fmod(x, y) {
  return x % y;
}

var _floor = Math.floor;

var _ceil = Math.ceil;

function _time(ptr) {
  var ret = Math.floor(Date.now() / 1e3);
  if (ptr) {
    HEAP32[ptr >> 2] = ret;
  }
  return ret;
}

function _isalpha(chr) {
  return chr >= "a".charCodeAt(0) && chr <= "z".charCodeAt(0) || chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0);
}

function _strcpy(pdest, psrc) {
  var i = 0;
  do {
    HEAP8[pdest + i] = HEAP8[psrc + i];
    i++;
  } while (HEAP8[psrc + i - 1] != 0);
  return pdest;
}

function ___errno_location() {
  return ___setErrNo.ret;
}

var ___errno = ___errno_location;

var _setjmp;

function _printf(format, varargs) {
  var stdout = HEAP32[_stdout >> 2];
  return _fprintf(stdout, format, varargs);
}

var _environ = null;

var ___environ = null;

function ___buildEnvironment(env) {
  var MAX_ENV_VALUES = 64;
  var TOTAL_ENV_SIZE = 1024;
  var poolPtr;
  var envPtr;
  if (_environ === null) {
    ENV["USER"] = "root";
    ENV["PATH"] = "/";
    ENV["PWD"] = "/";
    ENV["HOME"] = "/home/emscripten";
    ENV["LANG"] = "en_US.UTF-8";
    ENV["_"] = "./this.program";
    poolPtr = allocate(TOTAL_ENV_SIZE, "i8", ALLOC_STATIC);
    envPtr = allocate(MAX_ENV_VALUES * 4, "i8*", ALLOC_STATIC);
    HEAP32[envPtr >> 2] = poolPtr;
    _environ = allocate([ envPtr ], "i8**", ALLOC_STATIC);
    ___environ = _environ;
  } else {
    envPtr = HEAP32[_environ >> 2];
    poolPtr = HEAP32[envPtr >> 2];
  }
  var strings = [];
  var totalSize = 0;
  for (var key in env) {
    if (typeof env[key] === "string") {
      var line = key + "=" + env[key];
      strings.push(line);
      totalSize += line.length;
    }
  }
  if (totalSize > TOTAL_ENV_SIZE) {
    throw new Error("Environment size exceeded TOTAL_ENV_SIZE!");
  }
  var ptrSize = 4;
  for (var i = 0; i < strings.length; i++) {
    var line = strings[i];
    for (var j = 0; j < line.length; j++) {
      HEAP8[poolPtr + j] = line.charCodeAt(j);
    }
    HEAP8[poolPtr + j] = 0;
    HEAP32[envPtr + i * ptrSize >> 2] = poolPtr;
    poolPtr += line.length + 1;
  }
  HEAP32[envPtr + strings.length * ptrSize >> 2] = 0;
}

var ENV = {};

function _getenv(name) {
  if (name === 0) return 0;
  name = Pointer_stringify(name);
  if (!ENV.hasOwnProperty(name)) return 0;
  if (_getenv.ret) _free(_getenv.ret);
  _getenv.ret = allocate(intArrayFromString(ENV[name]), "i8", ALLOC_NORMAL);
  return _getenv.ret;
}

function _strstr(ptr1, ptr2) {
  var str1 = Pointer_stringify(ptr1);
  var str2 = Pointer_stringify(ptr2);
  var ret = str1.search(str2);
  return ret >= 0 ? ptr1 + ret : 0;
}

var _fabs = Math.abs;

function _copysign(a, b) {
  if (a < 0 === b < 0) return a;
  return -a;
}

var _sqrt = Math.sqrt;

var _llvm_pow_f64 = Math.pow;

var _tan = Math.tan;

var _sin = Math.sin;

var _log = Math.log;

var _exp = Math.exp;

var _cos = Math.cos;

var _atan2 = Math.atan2;

var _atan = Math.atan;

var _asin = Math.asin;

var _acos = Math.acos;

function _pthread_self() {
  return 0;
}

function _pthread_attr_init(attr) {
  return 0;
}

function _pthread_getattr_np(thread, attr) {
  return 0;
}

function _pthread_attr_getstack(attr, stackaddr, stacksize) {
  HEAP32[stackaddr >> 2] = STACK_ROOT;
  HEAP32[stacksize >> 2] = TOTAL_STACK;
  return 0;
}

function _pthread_attr_destroy(attr) {
  return 0;
}

function _localeconv() {
  var me = _localeconv;
  if (!me.ret) {
    me.ret = allocate([ allocate(intArrayFromString("."), "i8", ALLOC_NORMAL) ], "i8*", ALLOC_NORMAL);
  }
  return me.ret;
}

function _isxdigit(chr) {
  return chr >= "0".charCodeAt(0) && chr <= "9".charCodeAt(0) || chr >= "a".charCodeAt(0) && chr <= "f".charCodeAt(0) || chr >= "A".charCodeAt(0) && chr <= "F".charCodeAt(0);
}

function _tolower(chr) {
  if (chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0)) {
    return chr - "A".charCodeAt(0) + "a".charCodeAt(0);
  } else {
    return chr;
  }
}

function _isprint(chr) {
  return 31 < chr && chr < 127;
}

function _snprintf(s, n, format, varargs) {
  var result = __formatString(format, varargs);
  var limit = n === undefined ? result.length : Math.min(result.length, n - 1);
  for (var i = 0; i < limit; i++) {
    HEAP8[s + i] = result[i];
  }
  HEAP8[s + i] = 0;
  return result.length;
}

function _sprintf(s, format, varargs) {
  return _snprintf(s, undefined, format, varargs);
}

function _llvm_va_copy(ppdest, ppsrc) {
  HEAP8[ppdest] = HEAP8[ppsrc];
  HEAP8[ppdest + 1] = HEAP8[ppsrc + 1];
  HEAP8[ppdest + 2] = HEAP8[ppsrc + 2];
  HEAP8[ppdest + 3] = HEAP8[ppsrc + 3];
}

var _llvm_memset_p0i8_i64 = _memset;

function _ungetc(c, stream) {
  if (stream in FS.streams) {
    c = unSign(c & 255);
    FS.streams[stream].ungotten.push(c);
    return c;
  } else {
    return -1;
  }
}

function _fputc(c, stream) {
  var chr = unSign(c & 255);
  HEAP8[_fputc.ret] = chr;
  var ret = _write(stream, _fputc.ret, 1);
  if (ret == -1) {
    if (stream in FS.streams) FS.streams[stream].error = true;
    return -1;
  } else {
    return chr;
  }
}

var _raise;

function _log10(x) {
  return Math.log(x) / Math.LN10;
}

function _gettimeofday(ptr) {
  var indexes = Runtime.calculateStructAlignment({
    fields: [ "i32", "i32" ]
  });
  var now = Date.now();
  HEAP32[ptr + indexes[0] >> 2] = Math.floor(now / 1e3);
  HEAP32[ptr + indexes[1] >> 2] = Math.floor((now - 1e3 * Math.floor(now / 1e3)) * 1e3);
  return 0;
}

var ___tm_struct_layout = {
  __size__: 44,
  tm_sec: 0,
  tm_min: 4,
  tm_hour: 8,
  tm_mday: 12,
  tm_mon: 16,
  tm_year: 20,
  tm_wday: 24,
  tm_yday: 28,
  tm_isdst: 32,
  tm_gmtoff: 36,
  tm_zone: 40
};

var __tzname = null;

var __daylight = null;

var __timezone = null;

function _tzset() {
  if (__tzname) return;
  __timezone = _malloc(4);
  HEAP32[__timezone >> 2] = -(new Date).getTimezoneOffset() * 60;
  __daylight = _malloc(4);
  var winter = new Date(2e3, 0, 1);
  var summer = new Date(2e3, 6, 1);
  HEAP32[__daylight >> 2] = Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  var winterName = "GMT";
  var summerName = "GMT";
  var winterNamePtr = allocate(intArrayFromString(winterName), "i8", ALLOC_NORMAL);
  var summerNamePtr = allocate(intArrayFromString(summerName), "i8", ALLOC_NORMAL);
  __tzname = _malloc(2 * 4);
  HEAP32[__tzname >> 2] = winterNamePtr;
  HEAP32[__tzname + 4 >> 2] = summerNamePtr;
}

function _mktime(tmPtr) {
  _tzset();
  var offsets = ___tm_struct_layout;
  var year = HEAP32[tmPtr + offsets.tm_year >> 2];
  var timestamp = (new Date(year >= 1900 ? year : year + 1900, HEAP32[tmPtr + offsets.tm_mon >> 2], HEAP32[tmPtr + offsets.tm_mday >> 2], HEAP32[tmPtr + offsets.tm_hour >> 2], HEAP32[tmPtr + offsets.tm_min >> 2], HEAP32[tmPtr + offsets.tm_sec >> 2], 0)).getTime() / 1e3;
  HEAP32[tmPtr + offsets.tm_wday >> 2] = (new Date(timestamp)).getDay();
  var yday = Math.round((timestamp - (new Date(year, 0, 1)).getTime()) / (1e3 * 60 * 60 * 24));
  HEAP32[tmPtr + offsets.tm_yday >> 2] = yday;
  return timestamp;
}

var ___tm_timezones = {};

function _localtime_r(time, tmPtr) {
  _tzset();
  var offsets = ___tm_struct_layout;
  var date = new Date(HEAP32[time >> 2] * 1e3);
  HEAP32[tmPtr + offsets.tm_sec >> 2] = date.getSeconds();
  HEAP32[tmPtr + offsets.tm_min >> 2] = date.getMinutes();
  HEAP32[tmPtr + offsets.tm_hour >> 2] = date.getHours();
  HEAP32[tmPtr + offsets.tm_mday >> 2] = date.getDate();
  HEAP32[tmPtr + offsets.tm_mon >> 2] = date.getMonth();
  HEAP32[tmPtr + offsets.tm_year >> 2] = date.getFullYear() - 1900;
  HEAP32[tmPtr + offsets.tm_wday >> 2] = date.getDay();
  var start = new Date(date.getFullYear(), 0, 1);
  var yday = Math.floor((date.getTime() - start.getTime()) / (1e3 * 60 * 60 * 24));
  HEAP32[tmPtr + offsets.tm_yday >> 2] = yday;
  HEAP32[tmPtr + offsets.tm_gmtoff >> 2] = start.getTimezoneOffset() * 60;
  var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
  HEAP32[tmPtr + offsets.tm_isdst >> 2] = dst;
  var timezone = "GMT";
  if (!(timezone in ___tm_timezones)) {
    ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), "i8", ALLOC_NORMAL);
  }
  HEAP32[tmPtr + offsets.tm_zone >> 2] = ___tm_timezones[timezone];
  return tmPtr;
}

function _strftime(s, maxsize, format, timeptr) {
  return 0;
}

function _abort() {
  ABORT = true;
  throw "abort() at " + (new Error).stack;
}

function _sysconf(name) {
  switch (name) {
   case 8:
    return PAGE_SIZE;
   case 54:
   case 56:
   case 21:
   case 61:
   case 63:
   case 22:
   case 67:
   case 23:
   case 24:
   case 25:
   case 26:
   case 27:
   case 69:
   case 28:
   case 101:
   case 70:
   case 71:
   case 29:
   case 30:
   case 199:
   case 75:
   case 76:
   case 32:
   case 43:
   case 44:
   case 80:
   case 46:
   case 47:
   case 45:
   case 48:
   case 49:
   case 42:
   case 82:
   case 33:
   case 7:
   case 108:
   case 109:
   case 107:
   case 112:
   case 119:
   case 121:
    return 200809;
   case 13:
   case 104:
   case 94:
   case 95:
   case 34:
   case 35:
   case 77:
   case 81:
   case 83:
   case 84:
   case 85:
   case 86:
   case 87:
   case 88:
   case 89:
   case 90:
   case 91:
   case 94:
   case 95:
   case 110:
   case 111:
   case 113:
   case 114:
   case 115:
   case 116:
   case 117:
   case 118:
   case 120:
   case 40:
   case 16:
   case 79:
   case 19:
    return -1;
   case 92:
   case 93:
   case 5:
   case 72:
   case 6:
   case 74:
   case 92:
   case 93:
   case 96:
   case 97:
   case 98:
   case 99:
   case 102:
   case 103:
   case 105:
    return 1;
   case 38:
   case 66:
   case 50:
   case 51:
   case 4:
    return 1024;
   case 15:
   case 64:
   case 41:
    return 32;
   case 55:
   case 37:
   case 17:
    return 2147483647;
   case 18:
   case 1:
    return 47839;
   case 59:
   case 57:
    return 99;
   case 68:
   case 58:
    return 2048;
   case 0:
    return 2097152;
   case 3:
    return 65536;
   case 14:
    return 32768;
   case 73:
    return 32767;
   case 39:
    return 16384;
   case 60:
    return 1e3;
   case 106:
    return 700;
   case 52:
    return 256;
   case 62:
    return 255;
   case 2:
    return 100;
   case 65:
    return 64;
   case 36:
    return 20;
   case 100:
    return 16;
   case 20:
    return 6;
   case 53:
    return 4;
  }
  ___setErrNo(ERRNO_CODES.EINVAL);
  return -1;
}

function _sbrk(bytes) {
  var self = _sbrk;
  if (!self.called) {
    STATICTOP = alignMemoryPage(STATICTOP);
    self.called = true;
  }
  var ret = STATICTOP;
  if (bytes != 0) Runtime.staticAlloc(bytes);
  return ret;
}

function ___gxx_personality_v0() {}

function ___cxa_allocate_exception(size) {
  return _malloc(size);
}

function _llvm_eh_exception() {
  return HEAP32[_llvm_eh_exception.buf >> 2];
}

function __ZSt18uncaught_exceptionv() {
  return !!__ZSt18uncaught_exceptionv.uncaught_exception;
}

function ___cxa_is_number_type(type) {
  var isNumber = false;
  try {
    if (type == __ZTIi) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIl) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIx) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTIf) isNumber = true;
  } catch (e) {}
  try {
    if (type == __ZTId) isNumber = true;
  } catch (e) {}
  return isNumber;
}

function ___cxa_does_inherit(definiteType, possibilityType, possibility) {
  if (possibility == 0) return false;
  if (possibilityType == 0 || possibilityType == definiteType) return true;
  var possibility_type_info;
  if (___cxa_is_number_type(possibilityType)) {
    possibility_type_info = possibilityType;
  } else {
    var possibility_type_infoAddr = HEAP32[possibilityType >> 2] - 8;
    possibility_type_info = HEAP32[possibility_type_infoAddr >> 2];
  }
  switch (possibility_type_info) {
   case 0:
    var definite_type_infoAddr = HEAP32[definiteType >> 2] - 8;
    var definite_type_info = HEAP32[definite_type_infoAddr >> 2];
    if (definite_type_info == 0) {
      var defPointerBaseAddr = definiteType + 8;
      var defPointerBaseType = HEAP32[defPointerBaseAddr >> 2];
      var possPointerBaseAddr = possibilityType + 8;
      var possPointerBaseType = HEAP32[possPointerBaseAddr >> 2];
      return ___cxa_does_inherit(defPointerBaseType, possPointerBaseType, possibility);
    } else return false;
   case 1:
    return false;
   case 2:
    var parentTypeAddr = possibilityType + 8;
    var parentType = HEAP32[parentTypeAddr >> 2];
    return ___cxa_does_inherit(definiteType, parentType, possibility);
   default:
    return false;
  }
}

function ___cxa_find_matching_catch(thrown, throwntype, typeArray) {
  if (throwntype != 0 && !___cxa_is_number_type(throwntype)) {
    var throwntypeInfoAddr = HEAP32[throwntype >> 2] - 8;
    var throwntypeInfo = HEAP32[throwntypeInfoAddr >> 2];
    if (throwntypeInfo == 0) thrown = HEAP32[thrown >> 2];
  }
  for (var i = 0; i < typeArray.length; i++) {
    if (___cxa_does_inherit(typeArray[i], throwntype, thrown)) return {
      f0: thrown,
      f1: typeArray[i]
    };
  }
  return {
    f0: thrown,
    f1: throwntype
  };
}

function ___cxa_throw(ptr, type, destructor) {
  if (!___cxa_throw.initialized) {
    try {
      HEAP32[__ZTVN10__cxxabiv119__pointer_type_infoE >> 2] = 0;
    } catch (e) {}
    try {
      HEAP32[__ZTVN10__cxxabiv117__class_type_infoE >> 2] = 1;
    } catch (e) {}
    try {
      HEAP32[__ZTVN10__cxxabiv120__si_class_type_infoE >> 2] = 2;
    } catch (e) {}
    ___cxa_throw.initialized = true;
  }
  Module.printErr("Compiled code throwing an exception, " + [ ptr, type, destructor ] + ", at " + (new Error).stack);
  HEAP32[_llvm_eh_exception.buf >> 2] = ptr;
  HEAP32[_llvm_eh_exception.buf + 4 >> 2] = type;
  HEAP32[_llvm_eh_exception.buf + 8 >> 2] = destructor;
  if (!("uncaught_exception" in __ZSt18uncaught_exceptionv)) {
    __ZSt18uncaught_exceptionv.uncaught_exception = 1;
  } else {
    __ZSt18uncaught_exceptionv.uncaught_exception++;
  }
  throw ptr;
}

function ___cxa_call_unexpected(exception) {
  ABORT = true;
  throw exception;
}

function ___cxa_begin_catch(ptr) {
  __ZSt18uncaught_exceptionv.uncaught_exception--;
  return ptr;
}

function ___cxa_free_exception(ptr) {
  return _free(ptr);
}

function ___cxa_end_catch() {
  if (___cxa_end_catch.rethrown) {
    ___cxa_end_catch.rethrown = false;
    return;
  }
  __THREW__ = false;
  HEAP32[_llvm_eh_exception.buf + 4 >> 2] = 0;
  var ptr = HEAP32[_llvm_eh_exception.buf >> 2];
  var destructor = HEAP32[_llvm_eh_exception.buf + 8 >> 2];
  if (destructor) {
    FUNCTION_TABLE[destructor](ptr);
    HEAP32[_llvm_eh_exception.buf + 8 >> 2] = 0;
  }
  if (ptr) {
    ___cxa_free_exception(ptr);
    HEAP32[_llvm_eh_exception.buf >> 2] = 0;
  }
}

var __ZNSt9exceptionD2Ev;

function _llvm_uadd_with_overflow_i32(x, y) {
  x = x >>> 0;
  y = y >>> 0;
  return {
    f0: x + y >>> 0,
    f1: x + y > 4294967295
  };
}

function _putchar(c) {
  return _fputc(c, HEAP32[_stdout >> 2]);
}

function _memchr(ptr, chr, num) {
  chr = unSign(chr);
  for (var i = 0; i < num; i++) {
    if (HEAP8[ptr] == chr) return ptr;
    ptr++;
  }
  return 0;
}

function _fputs(s, stream) {
  return _write(stream, s, _strlen(s));
}

function _puts(s) {
  var stdout = HEAP32[_stdout >> 2];
  var ret = _fputs(s, stdout);
  if (ret < 0) {
    return ret;
  } else {
    var newlineRet = _fputc("\n".charCodeAt(0), stdout);
    return newlineRet < 0 ? -1 : ret + 1;
  }
}

function _opendir(dirname) {
  var path = FS.absolutePath(Pointer_stringify(dirname));
  if (path === null) {
    ___setErrNo(ERRNO_CODES.ENOENT);
    return 0;
  }
  var target = FS.findObject(path);
  if (target === null) return 0;
  if (!target.isFolder) {
    ___setErrNo(ERRNO_CODES.ENOTDIR);
    return 0;
  } else if (!target.read) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return 0;
  }
  var id = FS.streams.length;
  var contents = [];
  for (var key in target.contents) contents.push(key);
  FS.streams[id] = {
    path: path,
    object: target,
    position: -2,
    isRead: true,
    isWrite: false,
    isAppend: false,
    error: false,
    eof: false,
    ungotten: [],
    contents: contents,
    currentEntry: _malloc(___dirent_struct_layout.__size__)
  };
  return id;
}

function _closedir(dirp) {
  if (!FS.streams[dirp] || !FS.streams[dirp].object.isFolder) {
    return ___setErrNo(ERRNO_CODES.EBADF);
  } else {
    _free(FS.streams[dirp].currentEntry);
    delete FS.streams[dirp];
    return 0;
  }
}

function _telldir(dirp) {
  if (!FS.streams[dirp] || !FS.streams[dirp].object.isFolder) {
    return ___setErrNo(ERRNO_CODES.EBADF);
  } else {
    return FS.streams[dirp].position;
  }
}

function _seekdir(dirp, loc) {
  if (!FS.streams[dirp] || !FS.streams[dirp].object.isFolder) {
    ___setErrNo(ERRNO_CODES.EBADF);
  } else {
    var entries = 0;
    for (var key in FS.streams[dirp].contents) entries++;
    if (loc >= entries) {
      ___setErrNo(ERRNO_CODES.EINVAL);
    } else {
      FS.streams[dirp].position = loc;
    }
  }
}

function _rewinddir(dirp) {
  _seekdir(dirp, -2);
}

function _readdir_r(dirp, entry, result) {
  if (!FS.streams[dirp] || !FS.streams[dirp].object.isFolder) {
    return ___setErrNo(ERRNO_CODES.EBADF);
  }
  var stream = FS.streams[dirp];
  var loc = stream.position;
  var entries = 0;
  for (var key in stream.contents) entries++;
  if (loc < -2 || loc >= entries) {
    HEAP32[result >> 2] = 0;
  } else {
    var name, inode, type;
    if (loc === -2) {
      name = ".";
      inode = 1;
      type = 4;
    } else if (loc === -1) {
      name = "..";
      inode = 1;
      type = 4;
    } else {
      var object;
      name = stream.contents[loc];
      object = stream.object.contents[name];
      inode = object.inodeNumber;
      type = object.isDevice ? 2 : object.isFolder ? 4 : object.link !== undefined ? 10 : 8;
    }
    stream.position++;
    var offsets = ___dirent_struct_layout;
    HEAP32[entry + offsets.d_ino >> 2] = inode;
    HEAP32[entry + offsets.d_off >> 2] = stream.position;
    HEAP32[entry + offsets.d_reclen >> 2] = name.length + 1;
    for (var i = 0; i < name.length; i++) {
      HEAP8[entry + offsets.d_name + i] = name.charCodeAt(i);
    }
    HEAP8[entry + offsets.d_name + i] = 0;
    HEAP8[entry + offsets.d_type] = type;
    HEAP32[result >> 2] = entry;
  }
  return 0;
}

function _readdir(dirp) {
  if (!FS.streams[dirp] || !FS.streams[dirp].object.isFolder) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return 0;
  } else {
    if (!_readdir.result) _readdir.result = _malloc(4);
    _readdir_r(dirp, FS.streams[dirp].currentEntry, _readdir.result);
    if (HEAP32[_readdir.result >> 2] === 0) {
      return 0;
    } else {
      return FS.streams[dirp].currentEntry;
    }
  }
}

var ___01readdir64_ = _readdir;

var ___utimbuf_struct_layout = null;

function _utime(path, times) {
  var time;
  if (times) {
    var offset = ___utimbuf_struct_layout.modtime;
    time = HEAP32[times + offset >> 2];
    time *= 1e3;
  } else {
    time = Date.now();
  }
  var file = FS.findObject(Pointer_stringify(path));
  if (file === null) return -1;
  if (!file.write) {
    ___setErrNo(ERRNO_CODES.EPERM);
    return -1;
  }
  file.timestamp = time;
  return 0;
}

function ___libgenSplitName(path) {
  if (path === 0 || HEAP8[path] === 0) {
    var me = ___libgenSplitName;
    if (!me.ret) {
      me.ret = allocate([ ".".charCodeAt(0), 0 ], "i8", ALLOC_NORMAL);
    }
    return [ me.ret, -1 ];
  } else {
    var slash = "/".charCodeAt(0);
    var allSlashes = true;
    var slashPositions = [];
    for (var i = 0; HEAP8[path + i] !== 0; i++) {
      if (HEAP8[path + i] === slash) {
        slashPositions.push(i);
      } else {
        allSlashes = false;
      }
    }
    var length = i;
    if (allSlashes) {
      HEAP8[path + 1] = 0;
      return [ path, -1 ];
    } else {
      while (slashPositions.length && slashPositions[slashPositions.length - 1] == length - 1) {
        HEAP8[path + slashPositions.pop(i)] = 0;
        length--;
      }
      return [ path, slashPositions.pop() ];
    }
  }
}

function _basename(path) {
  var result = ___libgenSplitName(path);
  return result[0] + result[1] + 1;
}

var ___xpg_basename = _basename;

function _dirname(path) {
  var result = ___libgenSplitName(path);
  if (result[1] == 0) {
    HEAP8[result[0] + 1] = 0;
  } else if (result[1] !== -1) {
    HEAP8[result[0] + result[1]] = 0;
  }
  return result[0];
}

function _lstat(path, buf) {
  return _stat(path, buf, true);
}

function _mknod(path, mode, dev) {
  if (dev !== 0 || !(mode & 49152)) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    var properties = {
      contents: [],
      isFolder: Boolean(mode & 16384)
    };
    path = FS.analyzePath(Pointer_stringify(path));
    try {
      FS.createObject(path.parentObject, path.name, properties, mode & 256, mode & 128);
      return 0;
    } catch (e) {
      return -1;
    }
  }
}

function _mkdir(path, mode) {
  return _mknod(path, 16384 | mode & 384, 0);
}

function _mkfifo(path, mode) {
  ___setErrNo(ERRNO_CODES.EROFS);
  return -1;
}

function _chmod(path, mode) {
  var obj = FS.findObject(Pointer_stringify(path));
  if (obj === null) return -1;
  obj.read = mode & 256;
  obj.write = mode & 128;
  obj.timestamp = Date.now();
  return 0;
}

function _fchmod(fildes, mode) {
  if (!FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else {
    var pathArray = intArrayFromString(FS.streams[fildes].path);
    return _chmod(allocate(pathArray, "i8", ALLOC_STACK), mode);
  }
}

function _umask(newMask) {
  if (_umask.cmask === undefined) _umask.cmask = 511;
  var oldMask = _umask.cmask;
  _umask.cmask = newMask;
  return oldMask;
}

var _stat64 = _stat;

var _fstat64 = _fstat;

var ___01fstat64_ = _fstat;

var ___01stat64_ = _stat;

var ___01lstat64_ = _lstat;

var ___statvfs_struct_layout = null;

function _statvfs(path, buf) {
  var offsets = ___statvfs_struct_layout;
  HEAP32[buf + offsets.f_bsize >> 2] = 4096;
  HEAP32[buf + offsets.f_frsize >> 2] = 4096;
  HEAP32[buf + offsets.f_blocks >> 2] = 1e6;
  HEAP32[buf + offsets.f_bfree >> 2] = 5e5;
  HEAP32[buf + offsets.f_bavail >> 2] = 5e5;
  HEAP32[buf + offsets.f_files >> 2] = FS.nextInode;
  HEAP32[buf + offsets.f_ffree >> 2] = 1e6;
  HEAP32[buf + offsets.f_favail >> 2] = 1e6;
  HEAP32[buf + offsets.f_fsid >> 2] = 42;
  HEAP32[buf + offsets.f_flag >> 2] = 2;
  HEAP32[buf + offsets.f_namemax >> 2] = 255;
  return 0;
}

function _fstatvfs(fildes, buf) {
  return _statvfs(0, buf);
}

var ___01statvfs64_ = _statvfs;

var ___01fstatvfs64_ = _fstatvfs;

var ___flock_struct_layout = null;

function _creat(path, mode) {
  return _open(path, 1 | 512 | 1024, allocate([ mode, 0, 0, 0 ], "i32", ALLOC_STACK));
}

function _fcntl(fildes, cmd, varargs) {
  if (!(fildes in FS.streams)) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
  var stream = FS.streams[fildes];
  switch (cmd) {
   case 0:
    var arg = HEAP32[varargs >> 2];
    if (arg < 0) {
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
    var newStream = {};
    for (var member in stream) {
      newStream[member] = stream[member];
    }
    if (arg in FS.streams) arg = FS.streams.length;
    FS.streams[arg] = newStream;
    return arg;
   case 1:
   case 2:
    return 0;
   case 3:
    var flags = 0;
    if (stream.isRead && stream.isWrite) flags = 2; else if (!stream.isRead && stream.isWrite) flags = 1; else if (stream.isRead && !stream.isWrite) flags = 0;
    if (stream.isAppend) flags |= 8;
    return flags;
   case 4:
    var arg = HEAP32[varargs >> 2];
    stream.isAppend = Boolean(arg | 8);
    return 0;
   case 7:
   case 20:
    var arg = HEAP32[varargs >> 2];
    var offset = ___flock_struct_layout.l_type;
    HEAP16[arg + offset >> 1] = 3;
    return 0;
   case 8:
   case 9:
   case 21:
   case 22:
    return 0;
   case 6:
   case 5:
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
   default:
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  return -1;
}

function _posix_fadvise(fd, offset, len, advice) {
  return 0;
}

var _posix_madvise = _posix_fadvise;

function _posix_fallocate(fd, offset, len) {
  if (!(fd in FS.streams) || FS.streams[fd].link || FS.streams[fd].isFolder || FS.streams[fd].isDevice) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
  var contents = FS.streams[fd].object.contents;
  var limit = offset + len;
  while (limit > contents.length) contents.push(0);
  return 0;
}

var ___pollfd_struct_layout = null;

function _poll(fds, nfds, timeout) {
  var offsets = ___pollfd_struct_layout;
  var nonzero = 0;
  for (var i = 0; i < nfds; i++) {
    var pollfd = fds + ___pollfd_struct_layout.__size__ * i;
    var fd = HEAP32[pollfd + offsets.fd >> 2];
    var events = HEAP16[pollfd + offsets.events >> 1];
    var revents = 0;
    if (fd in FS.streams) {
      var stream = FS.streams[fd];
      if (events & 1) revents |= 1;
      if (events & 2) revents |= 2;
    } else {
      if (events & 4) revents |= 4;
    }
    if (revents) nonzero++;
    HEAP16[pollfd + offsets.revents >> 1] = revents;
  }
  return nonzero;
}

function _access(path, amode) {
  path = Pointer_stringify(path);
  var target = FS.findObject(path);
  if (target === null) return -1;
  if (amode & 2 && !target.write || (amode & 1 || amode & 4) && !target.read) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else {
    return 0;
  }
}

function _chdir(path) {
  if (typeof path !== "string") path = Pointer_stringify(path);
  path = FS.analyzePath(path);
  if (!path.exists) {
    ___setErrNo(path.error);
    return -1;
  } else if (!path.object.isFolder) {
    ___setErrNo(ERRNO_CODES.ENOTDIR);
    return -1;
  } else {
    FS.currentPath = path.path;
    return 0;
  }
}

function _chown(path, owner, group, dontResolveLastLink) {
  if (typeof path !== "string") path = Pointer_stringify(path);
  var target = FS.findObject(path, dontResolveLastLink);
  if (target === null) return -1;
  target.timestamp = Date.now();
  return 0;
}

function _chroot(path) {
  ___setErrNo(ERRNO_CODES.EACCES);
  return -1;
}

function _dup(fildes) {
  return _fcntl(fildes, 0, allocate([ 0, 0, 0, 0 ], "i32", ALLOC_STACK));
}

function _dup2(fildes, fildes2) {
  if (fildes2 < 0) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  } else if (fildes === fildes2 && FS.streams[fildes]) {
    return fildes;
  } else {
    _close(fildes2);
    return _fcntl(fildes, 0, allocate([ fildes2, 0, 0, 0 ], "i32", ALLOC_STACK));
  }
}

function _fchown(fildes, owner, group) {
  if (FS.streams[fildes]) {
    return _chown(FS.streams[fildes].path, owner, group);
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fchdir(fildes) {
  if (FS.streams[fildes]) {
    return _chdir(FS.streams[fildes].path);
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _ctermid(s) {
  if (!_ctermid.ret) {
    var arr = intArrayFromString("/dev/tty");
    _ctermid.ret = allocate(arr, "i8", ALLOC_NORMAL);
  }
  return s ? _strcpy(s, _ctermid.ret) : _ctermid.ret;
}

function _crypt(key, salt) {
  ___setErrNo(ERRNO_CODES.ENOSYS);
  return 0;
}

function _encrypt(block, edflag) {
  ___setErrNo(ERRNO_CODES.ENOSYS);
}

function _fpathconf(fildes, name) {
  switch (name) {
   case 0:
    return 32e3;
   case 1:
   case 2:
   case 3:
    return 255;
   case 4:
   case 5:
   case 18:
   case 19:
   case 15:
    return 4096;
   case 6:
   case 7:
   case 13:
    return 1;
   case 8:
    return 0;
   case 11:
   case 9:
   case 10:
   case 100:
   case 16:
   case 17:
   case 14:
    return -1;
   case 12:
    return 64;
  }
  ___setErrNo(ERRNO_CODES.EINVAL);
  return -1;
}

var _pathconf = _fpathconf;

var _fdatasync = _fsync;

function _truncate(path, length) {
  if (length < 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    if (typeof path !== "string") path = Pointer_stringify(path);
    var target = FS.findObject(path);
    if (target === null) return -1;
    if (target.isFolder) {
      ___setErrNo(ERRNO_CODES.EISDIR);
      return -1;
    } else if (target.isDevice) {
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    } else if (!target.write) {
      ___setErrNo(ERRNO_CODES.EACCES);
      return -1;
    } else {
      var contents = target.contents;
      if (length < contents.length) contents.length = length; else while (length > contents.length) contents.push(0);
      target.timestamp = Date.now();
      return 0;
    }
  }
}

function _ftruncate(fildes, length) {
  if (FS.streams[fildes] && FS.streams[fildes].isWrite) {
    return _truncate(FS.streams[fildes].path, length);
  } else if (FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _getcwd(buf, size) {
  if (size == 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return 0;
  } else if (size < FS.currentPath.length + 1) {
    ___setErrNo(ERRNO_CODES.ERANGE);
    return 0;
  } else {
    for (var i = 0; i < FS.currentPath.length; i++) {
      HEAP8[buf + i] = FS.currentPath.charCodeAt(i);
    }
    HEAP8[buf + i] = 0;
    return buf;
  }
}

function _getwd(path_name) {
  return _getcwd(path_name, 4096);
}

function _isatty(fildes) {
  if (!FS.streams[fildes]) {
    ___setErrNo(ERRNO_CODES.EBADF);
    return 0;
  }
  if (FS.streams[fildes].isTerminal) return 1;
  ___setErrNo(ERRNO_CODES.ENOTTY);
  return 0;
}

function _lchown(path, owner, group) {
  return _chown(path, owner, group, true);
}

function _link(path1, path2) {
  ___setErrNo(ERRNO_CODES.EMLINK);
  return -1;
}

function _lockf(fildes, func, size) {
  if (FS.streams[fildes]) {
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _lseek(fildes, offset, whence) {
  if (FS.streams[fildes] && !FS.streams[fildes].isDevice) {
    var stream = FS.streams[fildes];
    var position = offset;
    if (whence === 1) {
      position += stream.position;
    } else if (whence === 2) {
      position += stream.object.contents.length;
    }
    if (position < 0) {
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    } else {
      stream.ungotten = [];
      stream.position = position;
      return position;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _pipe(fildes) {
  ___setErrNo(ERRNO_CODES.ENOSYS);
  return -1;
}

function _sync() {}

function _rmdir(path) {
  path = FS.analyzePath(Pointer_stringify(path));
  if (!path.parentExists || !path.exists) {
    ___setErrNo(path.error);
    return -1;
  } else if (!path.object.write || path.isRoot) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else if (!path.object.isFolder) {
    ___setErrNo(ERRNO_CODES.ENOTDIR);
    return -1;
  } else {
    for (var i in path.object.contents) {
      ___setErrNo(ERRNO_CODES.ENOTEMPTY);
      return -1;
    }
    if (path.path == FS.currentPath) {
      ___setErrNo(ERRNO_CODES.EBUSY);
      return -1;
    } else {
      delete path.parentObject.contents[path.name];
      return 0;
    }
  }
}

function _unlink(path) {
  path = FS.analyzePath(Pointer_stringify(path));
  if (!path.parentExists || !path.exists) {
    ___setErrNo(path.error);
    return -1;
  } else if (path.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else if (!path.object.write) {
    ___setErrNo(ERRNO_CODES.EACCES);
    return -1;
  } else {
    delete path.parentObject.contents[path.name];
    return 0;
  }
}

function _ttyname_r(fildes, name, namesize) {
  var stream = FS.streams[fildes];
  if (!stream) {
    return ___setErrNo(ERRNO_CODES.EBADF);
  } else {
    var object = stream.object;
    if (!object.isDevice || !object.input || !object.output) {
      return ___setErrNo(ERRNO_CODES.ENOTTY);
    } else {
      var ret = stream.path;
      if (namesize < ret.length + 1) {
        return ___setErrNo(ERRNO_CODES.ERANGE);
      } else {
        for (var i = 0; i < ret.length; i++) {
          HEAP8[name + i] = ret.charCodeAt(i);
        }
        HEAP8[name + i] = 0;
        return 0;
      }
    }
  }
}

function _ttyname(fildes) {
  if (!_ttyname.ret) _ttyname.ret = _malloc(256);
  return _ttyname_r(fildes, _ttyname.ret, 256) ? 0 : _ttyname.ret;
}

function _symlink(path1, path2) {
  var path = FS.analyzePath(Pointer_stringify(path2), true);
  if (!path.parentExists) {
    ___setErrNo(path.error);
    return -1;
  } else if (path.exists) {
    ___setErrNo(ERRNO_CODES.EEXIST);
    return -1;
  } else {
    FS.createLink(path.parentPath, path.name, Pointer_stringify(path1), true, true);
    return 0;
  }
}

function _readlink(path, buf, bufsize) {
  var target = FS.findObject(Pointer_stringify(path), true);
  if (target === null) return -1;
  if (target.link !== undefined) {
    var length = Math.min(bufsize - 1, target.link.length);
    for (var i = 0; i < length; i++) {
      HEAP8[buf + i] = target.link.charCodeAt(i);
    }
    if (bufsize - 1 > length) HEAP8[buf + i] = 0;
    return i;
  } else {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
}

function _alarm(seconds) {
  return 0;
}

var _ualarm = _alarm;

function _confstr(name, buf, len) {
  var value;
  switch (name) {
   case 0:
    value = ENV["PATH"] || "/";
    break;
   case 17:
    value = "POSIX_V6_ILP32_OFF32\nPOSIX_V6_ILP32_OFFBIG";
    break;
   case 42:
    value = "glibc 2.14";
    break;
   case 43:
    value = "";
    break;
   case 3:
   case 7:
   case 9:
   case 10:
   case 11:
   case 13:
   case 14:
   case 15:
    value = "";
    break;
   case 1:
   case 2:
   case 6:
    value = "-m32";
    break;
   case 5:
    value = "-m32 -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64";
    break;
   default:
    ___setErrNo(ERRNO_CODES.EINVAL);
    return 0;
  }
  if (len == 0 || buf == 0) {
    return value.length + 1;
  } else {
    var length = Math.min(len, value.length);
    for (var i = 0; i < length; i++) {
      HEAP8[buf + i] = value.charCodeAt(i);
    }
    if (len > length) HEAP8[buf + i++] = 0;
    return i;
  }
}

function _execl() {
  ___setErrNo(ERRNO_CODES.ENOEXEC);
  return -1;
}

var _execle = _execl;

var _execlp = _execl;

var _execv = _execl;

var _execve = _execl;

var _execvp = _execl;

function __exit(status) {
  exitRuntime();
  ABORT = true;
  throw "exit(" + status + ") called, at " + (new Error).stack;
}

function _fork() {
  ___setErrNo(ERRNO_CODES.EAGAIN);
  return -1;
}

var _vfork = _fork;

function _getgid() {
  return 0;
}

var _getegid = _getgid;

var _getuid = _getgid;

var _geteuid = _getgid;

var _getpgrp = _getgid;

var _getpid = _getgid;

var _getppid = _getgid;

function _getresuid(ruid, euid, suid) {
  HEAP32[ruid >> 2] = 0;
  HEAP32[euid >> 2] = 0;
  HEAP32[suid >> 2] = 0;
  return 0;
}

var _getresgid = _getresuid;

function _getgroups(gidsetsize, grouplist) {
  if (gidsetsize < 1) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else {
    HEAP32[grouplist >> 2] = 0;
    return 1;
  }
}

function _gethostid() {
  return 42;
}

function _gethostname(name, namelen) {
  var host = "emscripten";
  if (typeof window !== "undefined" && window.location.host) {
    host = window.location.host;
  }
  var length = Math.min(namelen, host.length);
  for (var i = 0; i < length; i++) {
    HEAP8[name + i] = host.charCodeAt(i);
  }
  if (namelen > length) {
    HEAP8[name + i] = 0;
    return 0;
  } else {
    ___setErrNo(ERRNO_CODES.ENAMETOOLONG);
    return -1;
  }
}

function _getlogin_r(name, namesize) {
  var ret = "root";
  if (namesize < ret.length + 1) {
    return ___setErrNo(ERRNO_CODES.ERANGE);
  } else {
    for (var i = 0; i < ret.length; i++) {
      HEAP8[name + i] = ret.charCodeAt(i);
    }
    HEAP8[name + i] = 0;
    return 0;
  }
}

function _getlogin() {
  if (!_getlogin.ret) _getlogin.ret = _malloc(8);
  return _getlogin_r(_getlogin.ret, 8) ? 0 : _getlogin.ret;
}

function _getpagesize() {
  return PAGE_SIZE;
}

function _getopt(argc, argv, optstring) {
  return -1;
}

function _getpgid(pid) {
  return 0;
}

var _getsid = _getpgid;

function _nice(incr) {
  ___setErrNo(ERRNO_CODES.EPERM);
  return 0;
}

function _pause() {
  ___setErrNo(ERRNO_CODES.EINTR);
  return -1;
}

function _setgid(gid) {
  ___setErrNo(ERRNO_CODES.EPERM);
  return -1;
}

var _setegid = _setgid;

var _setuid = _setgid;

var _seteuid = _setgid;

var _setsid = _setgid;

var _setpgrp = _setgid;

function _setpgid(pid, pgid) {
  ___setErrNo(ERRNO_CODES.EPERM);
  return -1;
}

var _setregid = _setpgid;

var _setreuid = _setpgid;

var _setresuid = _setpgid;

var _setresgid = _setpgid;

function _usleep(useconds) {
  var msec = useconds / 1e3;
  var start = Date.now();
  while (Date.now() - start < msec) {}
  return 0;
}

function _sleep(seconds) {
  return _usleep(seconds * 1e6);
}

function _swab(src, dest, nbytes) {
  if (nbytes < 0) return;
  nbytes -= nbytes % 2;
  for (var i = 0; i < nbytes; i += 2) {
    var first = HEAP8[src + i];
    var second = HEAP8[src + i + 1];
    HEAP8[dest + i] = second;
    HEAP8[dest + i + 1] = first;
  }
}

function _tcgetpgrp(fildes) {
  return 0;
}

function _tcsetpgrp(fildes, pgid_id) {
  ___setErrNo(ERRNO_CODES.EINVAL);
  return -1;
}

var _open64 = _open;

var _lseek64 = _lseek;

var _ftruncate64 = _ftruncate;

var ___01open64_ = _open;

var ___01lseek64_ = _lseek;

var ___01truncate64_ = _truncate;

var ___01ftruncate64_ = _ftruncate;

function __isFloat(text) {
  return !!/^[+-]?[0-9]*\.?[0-9]+([eE][+-]?[0-9]+)?$/.exec(text);
}

function __scanString(format, get, unget, varargs) {
  format = Pointer_stringify(format);
  var formatIndex = 0;
  var argsi = 0;
  var fields = 0;
  var argIndex = 0;
  for (var formatIndex = 0; formatIndex < format.length; formatIndex++) {
    if (next <= 0) return fields;
    var next = get();
    if (next <= 0) return fields;
    if (format[formatIndex] === "%") {
      formatIndex++;
      var maxSpecifierStart = formatIndex;
      while (format[formatIndex].charCodeAt(0) >= "0".charCodeAt(0) && format[formatIndex].charCodeAt(0) <= "9".charCodeAt(0)) {
        formatIndex++;
      }
      var max_;
      if (formatIndex != maxSpecifierStart) {
        max_ = parseInt(format.slice(maxSpecifierStart, formatIndex), 10);
      }
      var long_ = false;
      if (format[formatIndex] == "l") {
        long_ = true;
        formatIndex++;
      }
      var type = format[formatIndex];
      formatIndex++;
      var curr = 0;
      var buffer = [];
      if (type == "f") {
        var last = -1;
        while (next > 0) {
          buffer.push(String.fromCharCode(next));
          if (__isFloat(buffer.join(""))) {
            last = buffer.length;
          }
          next = get();
        }
        while (buffer.length > last) {
          buffer.pop();
          unget();
        }
      } else {
        while ((curr < max_ || isNaN(max_)) && next > 0) {
          if (type === "d" && next >= "0".charCodeAt(0) && next <= "9".charCodeAt(0) || type === "x" && (next >= "0".charCodeAt(0) && next <= "9".charCodeAt(0) || next >= "a".charCodeAt(0) && next <= "f".charCodeAt(0) || next >= "A".charCodeAt(0) && next <= "F".charCodeAt(0)) || type === "s" && next != " ".charCodeAt(0) && next != "\t".charCodeAt(0) && next != "\n".charCodeAt(0) && (formatIndex >= format.length || next !== format[formatIndex].charCodeAt(0))) {
            buffer.push(String.fromCharCode(next));
            next = get();
            curr++;
          } else {
            break;
          }
        }
      }
      if (buffer.length === 0) return 0;
      var text = buffer.join("");
      var argPtr = HEAP32[varargs + argIndex >> 2];
      argIndex += Runtime.getNativeFieldSize("void*");
      switch (type) {
       case "d":
        HEAP32[argPtr >> 2] = parseInt(text, 10);
        break;
       case "x":
        HEAP32[argPtr >> 2] = parseInt(text, 16);
        break;
       case "f":
        if (long_) {
          tempDoubleF64[0] = parseFloat(text), HEAP32[argPtr >> 2] = tempDoubleI32[0], HEAP32[argPtr + 4 >> 2] = tempDoubleI32[1];
        } else {
          HEAPF32[argPtr >> 2] = parseFloat(text);
        }
        break;
       case "s":
        var array = intArrayFromString(text);
        for (var j = 0; j < array.length; j++) {
          HEAP8[argPtr + j] = array[j];
        }
        break;
      }
      fields++;
    } else {
      if (format[formatIndex].charCodeAt(0) !== next) {
        unget(next);
        return fields;
      }
    }
  }
  return fields;
}

function _clearerr(stream) {
  if (stream in FS.streams) FS.streams[stream].error = false;
}

function _fdopen(fildes, mode) {
  if (fildes in FS.streams) {
    var stream = FS.streams[fildes];
    mode = Pointer_stringify(mode);
    if (mode.indexOf("w") != -1 && !stream.isWrite || mode.indexOf("r") != -1 && !stream.isRead || mode.indexOf("a") != -1 && !stream.isAppend || mode.indexOf("+") != -1 && (!stream.isRead || !stream.isWrite)) {
      ___setErrNo(ERRNO_CODES.EINVAL);
      return 0;
    } else {
      stream.error = false;
      stream.eof = false;
      return fildes;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return 0;
  }
}

function _feof(stream) {
  return Number(stream in FS.streams && FS.streams[stream].eof);
}

function _ferror(stream) {
  return Number(stream in FS.streams && FS.streams[stream].error);
}

var _getc = _fgetc;

function _getchar() {
  return _fgetc(HEAP32[_stdin >> 2]);
}

function _fgetpos(stream, pos) {
  if (stream in FS.streams) {
    stream = FS.streams[stream];
    if (stream.object.isDevice) {
      ___setErrNo(ERRNO_CODES.ESPIPE);
      return -1;
    } else {
      HEAP32[pos >> 2] = stream.position;
      var state = (stream.eof ? 1 : 0) + (stream.error ? 2 : 0);
      HEAP32[pos + 4 >> 2] = state;
      return 0;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _fgets(s, n, stream) {
  if (!(stream in FS.streams)) return 0;
  var streamObj = FS.streams[stream];
  if (streamObj.error || streamObj.eof) return 0;
  var byte_;
  for (var i = 0; i < n - 1 && byte_ != "\n".charCodeAt(0); i++) {
    byte_ = _fgetc(stream);
    if (byte_ == -1) {
      if (streamObj.error) return 0; else if (streamObj.eof) break;
    }
    HEAP8[s + i] = byte_;
  }
  HEAP8[s + i] = 0;
  return s;
}

function _gets(s) {
  return _fgets(s, 1e6, HEAP32[_stdin >> 2]);
}

function _ftrylockfile() {
  return 0;
}

var _flockfile = _ftrylockfile;

var _funlockfile = _ftrylockfile;

var _putc = _fputc;

var _putc_unlocked = _fputc;

var _putchar_unlocked = _putchar;

function _fread(ptr, size, nitems, stream) {
  var bytesToRead = nitems * size;
  if (bytesToRead == 0) return 0;
  var bytesRead = _read(stream, ptr, bytesToRead);
  var streamObj = FS.streams[stream];
  if (bytesRead == -1) {
    if (streamObj) streamObj.error = true;
    return -1;
  } else {
    if (bytesRead < bytesToRead) streamObj.eof = true;
    return Math.floor(bytesRead / size);
  }
}

function _freopen(filename, mode, stream) {
  if (!filename) {
    if (!(stream in FS.streams)) {
      ___setErrNo(ERRNO_CODES.EBADF);
      return 0;
    }
    if (_freopen.buffer) _free(_freopen.buffer);
    filename = intArrayFromString(FS.streams[stream].path);
    filename = allocate(filename, "i8", ALLOC_NORMAL);
  }
  _fclose(stream);
  return _fopen(filename, mode);
}

function _fseek(stream, offset, whence) {
  var ret = _lseek(stream, offset, whence);
  if (ret == -1) {
    return -1;
  } else {
    FS.streams[stream].eof = false;
    return 0;
  }
}

var _fseeko = _fseek;

var _fseeko64 = _fseek;

function _fsetpos(stream, pos) {
  if (stream in FS.streams) {
    if (FS.streams[stream].object.isDevice) {
      ___setErrNo(ERRNO_CODES.EPIPE);
      return -1;
    } else {
      FS.streams[stream].position = HEAP32[pos >> 2];
      var state = HEAP32[pos + 4 >> 2];
      FS.streams[stream].eof = Boolean(state & 1);
      FS.streams[stream].error = Boolean(state & 2);
      return 0;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

function _ftell(stream) {
  if (stream in FS.streams) {
    stream = FS.streams[stream];
    if (stream.object.isDevice) {
      ___setErrNo(ERRNO_CODES.ESPIPE);
      return -1;
    } else {
      return stream.position;
    }
  } else {
    ___setErrNo(ERRNO_CODES.EBADF);
    return -1;
  }
}

var _ftello = _ftell;

var _ftello64 = _ftell;

function _popen(command, mode) {
  ___setErrNo(ERRNO_CODES.EMFILE);
  return 0;
}

function _pclose(stream) {
  ___setErrNo(ERRNO_CODES.ECHILD);
  return -1;
}

var ERRNO_MESSAGES = {
  1: "Operation not permitted",
  2: "No such file or directory",
  3: "No such process",
  4: "Interrupted system call",
  5: "Input/output error",
  6: "No such device or address",
  8: "Exec format error",
  9: "Bad file descriptor",
  10: "No child processes",
  11: "Resource temporarily unavailable",
  12: "Cannot allocate memory",
  13: "Permission denied",
  14: "Bad address",
  16: "Device or resource busy",
  17: "File exists",
  18: "Invalid cross-device link",
  19: "No such device",
  20: "Not a directory",
  21: "Is a directory",
  22: "Invalid argument",
  23: "Too many open files in system",
  24: "Too many open files",
  25: "Inappropriate ioctl for device",
  26: "Text file busy",
  27: "File too large",
  28: "No space left on device",
  29: "Illegal seek",
  30: "Read-only file system",
  31: "Too many links",
  32: "Broken pipe",
  33: "Numerical argument out of domain",
  34: "Numerical result out of range",
  35: "Resource deadlock avoided",
  36: "File name too long",
  37: "No locks available",
  38: "Function not implemented",
  39: "Directory not empty",
  40: "Too many levels of symbolic links",
  42: "No message of desired type",
  43: "Identifier removed",
  60: "Device not a stream",
  61: "No data available",
  62: "Timer expired",
  63: "Out of streams resources",
  67: "Link has been severed",
  71: "Protocol error",
  72: "Multihop attempted",
  74: "Bad message",
  75: "Value too large for defined data type",
  84: "Invalid or incomplete multibyte or wide character",
  88: "Socket operation on non-socket",
  89: "Destination address required",
  90: "Message too long",
  91: "Protocol wrong type for socket",
  92: "Protocol not available",
  93: "Protocol not supported",
  95: "Operation not supported",
  97: "Address family not supported by protocol",
  98: "Address already in use",
  99: "Cannot assign requested address",
  100: "Network is down",
  101: "Network is unreachable",
  102: "Network dropped connection on reset",
  103: "Software caused connection abort",
  104: "Connection reset by peer",
  105: "No buffer space available",
  106: "Transport endpoint is already connected",
  107: "Transport endpoint is not connected",
  110: "Connection timed out",
  111: "Connection refused",
  113: "No route to host",
  114: "Operation already in progress",
  115: "Operation now in progress",
  116: "Stale NFS file handle",
  122: "Disk quota exceeded",
  125: "Operation canceled",
  130: "Owner died",
  131: "State not recoverable"
};

function _strerror_r(errnum, strerrbuf, buflen) {
  if (errnum in ERRNO_MESSAGES) {
    if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
      return ___setErrNo(ERRNO_CODES.ERANGE);
    } else {
      var msg = ERRNO_MESSAGES[errnum];
      for (var i = 0; i < msg.length; i++) {
        HEAP8[strerrbuf + i] = msg.charCodeAt(i);
      }
      HEAP8[strerrbuf + i] = 0;
      return 0;
    }
  } else {
    return ___setErrNo(ERRNO_CODES.EINVAL);
  }
}

function _strerror(errnum) {
  if (!_strerror.buffer) _strerror.buffer = _malloc(256);
  _strerror_r(errnum, _strerror.buffer, 256);
  return _strerror.buffer;
}

function _perror(s) {
  if (s) {
    _puts(s);
    _putc(":".charCodeAt(0));
    _putc(" ".charCodeAt(0));
  }
  var errnum = HEAP32[___errno_location() >> 2];
  _puts(_strerror(errnum));
}

function _remove(path) {
  var ret = _unlink(path);
  if (ret == -1) ret = _rmdir(path);
  return ret;
}

function _rename(old, new_) {
  var oldObj = FS.analyzePath(Pointer_stringify(old));
  var newObj = FS.analyzePath(Pointer_stringify(new_));
  if (newObj.path == oldObj.path) {
    return 0;
  } else if (!oldObj.exists) {
    ___setErrNo(oldObj.error);
    return -1;
  } else if (oldObj.isRoot || oldObj.path == FS.currentPath) {
    ___setErrNo(ERRNO_CODES.EBUSY);
    return -1;
  } else if (newObj.path && newObj.path.indexOf(oldObj.path) == 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  } else if (newObj.exists && newObj.object.isFolder) {
    ___setErrNo(ERRNO_CODES.EISDIR);
    return -1;
  } else {
    delete oldObj.parentObject.contents[oldObj.name];
    newObj.parentObject.contents[newObj.name] = oldObj.object;
    return 0;
  }
}

function _rewind(stream) {
  _fseek(stream, 0, 0);
  if (stream in FS.streams) FS.streams[stream].error = false;
}

function _setvbuf(stream, buf, type, size) {
  return 0;
}

function _setbuf(stream, buf) {
  if (buf) _setvbuf(stream, buf, 0, 8192); else _setvbuf(stream, buf, 2, 8192);
}

function _tmpnam(s, dir, prefix) {
  var folder = FS.findObject(dir || "/tmp");
  if (!folder || !folder.isFolder) {
    dir = "/tmp";
    folder = FS.findObject(dir);
    if (!folder || !folder.isFolder) return 0;
  }
  var name = prefix || "file";
  do {
    name += String.fromCharCode(65 + Math.floor(Math.random() * 25));
  } while (name in folder.contents);
  var result = dir + "/" + name;
  if (!_tmpnam.buffer) _tmpnam.buffer = _malloc(256);
  if (!s) s = _tmpnam.buffer;
  for (var i = 0; i < result.length; i++) {
    HEAP8[s + i] = result.charCodeAt(i);
  }
  HEAP8[s + i] = 0;
  return s;
}

function _tempnam(dir, pfx) {
  return _tmpnam(0, Pointer_stringify(dir), Pointer_stringify(pfx));
}

function _tmpfile() {
  if (_tmpfile.mode) {
    _tmpfile.mode = allocate(intArrayFromString("w+"), "i8", ALLOC_NORMAL);
  }
  return _fopen(_tmpnam(0), _tmpfile.mode);
}

function _system(command) {
  ___setErrNo(ERRNO_CODES.EAGAIN);
  return -1;
}

function _fscanf(stream, format, varargs) {
  if (stream in FS.streams) {
    var get = (function() {
      return _fgetc(stream);
    });
    var unget = (function(c) {
      return _ungetc(c, stream);
    });
    return __scanString(format, get, unget, varargs);
  } else {
    return -1;
  }
}

function _scanf(format, varargs) {
  var stdin = HEAP32[_stdin >> 2];
  return _fscanf(stdin, format, varargs);
}

function _sscanf(s, format, varargs) {
  var index = 0;
  var get = (function() {
    return HEAP8[s + index++];
  });
  var unget = (function() {
    index--;
  });
  return __scanString(format, get, unget, varargs);
}

var _vsnprintf = _snprintf;

var _vprintf = _printf;

var _vsprintf = _sprintf;

var _vscanf = _scanf;

var _vfscanf = _fscanf;

var _vsscanf = _sscanf;

var _fopen64 = _fopen;

var ___01fopen64_ = _fopen;

var ___01freopen64_ = _freopen;

var ___01fseeko64_ = _fseek;

var ___01ftello64_ = _ftell;

var ___01tmpfile64_ = _tmpfile;

var ___isoc99_fscanf = _fscanf;

var __IO_getc = _getc;

var __IO_putc = _putc;

var __ZNSo3putEc = _putchar;

function __ZNSo5flushEv() {
  _fflush(HEAP32[_stdout >> 2]);
}

var ___01mmap64_ = _mmap;

var __Znam = _malloc;

var __Znwm = _malloc;

var _abs = Math.abs;

function _isdigit(chr) {
  return chr >= "0".charCodeAt(0) && chr <= "9".charCodeAt(0);
}

function _atoi(s) {
  var c;
  while ((c = HEAP8[s]) && _isspace(c)) s++;
  if (!c || !_isdigit(c)) return 0;
  var e = s;
  while ((c = HEAP8[e]) && _isdigit(c)) e++;
  return Math.floor(Number(Pointer_stringify(s).substr(0, e - s)));
}

function _exit(status) {
  __exit(status);
}

function _atexit(func, arg) {
  __ATEXIT__.unshift({
    func: func,
    arg: arg
  });
}

var ___cxa_atexit = _atexit;

function _bsearch(key, base, num, size, compar) {
  var cmp = FUNCTION_TABLE[compar];
  var left = 0;
  var right = num;
  var mid, test, addr;
  while (left < right) {
    mid = left + right >>> 1;
    addr = base + mid * size;
    test = cmp(key, addr);
    if (test < 0) {
      right = mid;
    } else if (test > 0) {
      left = mid + 1;
    } else {
      return addr;
    }
  }
  return 0;
}

function _strtod(str, endptr) {
  while (_isspace(HEAP8[str])) str++;
  var multiplier = 1;
  if (HEAP8[str] == "-".charCodeAt(0)) {
    multiplier = -1;
    str++;
  } else if (HEAP8[str] == "+".charCodeAt(0)) {
    str++;
  }
  var chr;
  var ret = 0;
  while (1) {
    chr = HEAP8[str];
    if (!_isdigit(chr)) break;
    ret = ret * 10 + chr - "0".charCodeAt(0);
    str++;
  }
  if (HEAP8[str] == ".".charCodeAt(0)) {
    str++;
    var mul = 1 / 10;
    while (1) {
      chr = HEAP8[str];
      if (!_isdigit(chr)) break;
      ret += mul * (chr - "0".charCodeAt(0));
      mul /= 10;
      str++;
    }
  }
  chr = HEAP8[str];
  if (chr == "e".charCodeAt(0) || chr == "E".charCodeAt(0)) {
    str++;
    var exponent = 0;
    var expNegative = false;
    chr = HEAP8[str];
    if (chr == "-".charCodeAt(0)) {
      expNegative = true;
      str++;
    } else if (chr == "+".charCodeAt(0)) {
      str++;
    }
    chr = HEAP8[str];
    while (1) {
      if (!_isdigit(chr)) break;
      exponent = exponent * 10 + chr - "0".charCodeAt(0);
      str++;
      chr = HEAP8[str];
    }
    if (expNegative) exponent = -exponent;
    ret *= Math.pow(10, exponent);
  }
  if (endptr) {
    HEAP32[endptr >> 2] = str;
  }
  return ret * multiplier;
}

function __parseInt(str, endptr, base, min, max, bits, unsign) {
  while (_isspace(HEAP8[str])) str++;
  var multiplier = 1;
  if (HEAP8[str] == "-".charCodeAt(0)) {
    multiplier = -1;
    str++;
  } else if (HEAP8[str] == "+".charCodeAt(0)) {
    str++;
  }
  var finalBase = base;
  if (!finalBase) {
    if (HEAP8[str] == "0".charCodeAt(0)) {
      if (HEAP8[str + 1] == "x".charCodeAt(0) || HEAP8[str + 1] == "X".charCodeAt(0)) {
        finalBase = 16;
        str += 2;
      } else {
        finalBase = 8;
        str++;
      }
    }
  }
  if (!finalBase) finalBase = 10;
  var chr;
  var ret = 0;
  while ((chr = HEAP8[str]) != 0) {
    var digit = parseInt(String.fromCharCode(chr), finalBase);
    if (isNaN(digit)) {
      break;
    } else {
      ret = ret * finalBase + digit;
      str++;
    }
  }
  ret *= multiplier;
  if (endptr) {
    HEAP32[endptr >> 2] = str;
  }
  if (unsign) {
    if (Math.abs(ret) > max) {
      ret = max;
      ___setErrNo(ERRNO_CODES.ERANGE);
    } else {
      ret = unSign(ret, bits);
    }
  }
  if (ret > max || ret < min) {
    ret = ret > max ? max : min;
    ___setErrNo(ERRNO_CODES.ERANGE);
  }
  if (bits == 64) {
    ret = [ ret >>> 0, Math.min(Math.floor(ret / 4294967296), 4294967295) ];
  }
  return ret;
}

function _strtoll(str, endptr, base) {
  return __parseInt(str, endptr, base, -0x7ffffffffffffc00, 0x7ffffffffffffc00, 64);
}

var _strtoll_l = _strtoll;

function _strtol(str, endptr, base) {
  return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);
}

var _strtol_l = _strtol;

function _strtoul(str, endptr, base) {
  return __parseInt(str, endptr, base, 0, 4294967295, 32, true);
}

var _strtoul_l = _strtoul;

function _strtoull(str, endptr, base) {
  return __parseInt(str, endptr, base, 0, 0x10000000000000000, 64, true);
}

var _strtoull_l = _strtoull;

function _atof(ptr) {
  var str = Pointer_stringify(ptr);
  var ret = parseFloat(str);
  return isNaN(ret) ? 0 : ret;
}

function _qsort(base, num, size, comparator) {
  if (num == 0 || size == 0) return;
  comparator = FUNCTION_TABLE[comparator];
  var keys = [];
  for (var i = 0; i < num; i++) keys.push(i);
  keys.sort((function(a, b) {
    return comparator(base + a * size, base + b * size);
  }));
  var temp = _malloc(num * size);
  _memcpy(temp, base, num * size);
  for (var i = 0; i < num; i++) {
    if (keys[i] == i) continue;
    _memcpy(base + i * size, temp + keys[i] * size, size);
  }
  _free(temp);
}

function _clearenv(name) {
  ENV = {};
  ___buildEnvironment(ENV);
  return 0;
}

function _setenv(envname, envval, overwrite) {
  if (envname === 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  var name = Pointer_stringify(envname);
  var val = Pointer_stringify(envval);
  if (name === "" || name.indexOf("=") !== -1) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  if (ENV.hasOwnProperty(name) && !overwrite) return 0;
  ENV[name] = val;
  ___buildEnvironment(ENV);
  return 0;
}

function _unsetenv(name) {
  if (name === 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  name = Pointer_stringify(name);
  if (name === "" || name.indexOf("=") !== -1) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  if (ENV.hasOwnProperty(name)) {
    delete ENV[name];
    ___buildEnvironment(ENV);
  }
  return 0;
}

function _putenv(string) {
  if (string === 0) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  string = Pointer_stringify(string);
  var splitPoint = string.indexOf("=");
  if (string === "" || string.indexOf("=") === -1) {
    ___setErrNo(ERRNO_CODES.EINVAL);
    return -1;
  }
  var name = string.slice(0, splitPoint);
  var value = string.slice(splitPoint + 1);
  if (!(name in ENV) || ENV[name] !== value) {
    ENV[name] = value;
    ___buildEnvironment(ENV);
  }
  return 0;
}

function _getloadavg(loadavg, nelem) {
  var limit = Math.min(nelem, 3);
  var doubleSize = 8;
  for (var i = 0; i < limit; i++) {
    tempDoubleF64[0] = .1, HEAP32[loadavg + i * doubleSize >> 2] = tempDoubleI32[0], HEAP32[loadavg + i * doubleSize + 4 >> 2] = tempDoubleI32[1];
  }
  return limit;
}

var ___rand_state = 42;

function _srand(seed) {
  ___rand_state = seed;
}

function _rand() {
  ___rand_state = (1103515245 * ___rand_state + 12345) % 4294967296;
  return ___rand_state & 2147483647;
}

function _rand_r(seed) {
  var state = HEAP32[seed >> 2];
  state = (1103515245 * state + 12345) % 4294967296;
  HEAP32[seed >> 2] = state;
  return state & 2147483647;
}

function _realpath(file_name, resolved_name) {
  var absolute = FS.analyzePath(Pointer_stringify(file_name));
  if (absolute.error) {
    ___setErrNo(absolute.error);
    return 0;
  } else {
    var size = Math.min(4095, absolute.path.length);
    for (var i = 0; i < size; i++) {
      HEAP8[resolved_name + i] = absolute.path.charCodeAt(i);
    }
    HEAP8[resolved_name + size] = 0;
    return resolved_name;
  }
}

function _mbtowc(pwc, pmb, maxx) {
  if (!pmb) return 0;
  maxx = Math.min(85, maxx);
  var i;
  for (i = 0; i < maxx; i++) {
    var curr = HEAP8[pmb];
    if (pwc) {
      HEAP8[pwc] = curr;
      HEAP8[pwc + 1] = 0;
      pwc += 2;
    }
    pmb++;
    if (!curr) break;
  }
  return i;
}

function _wcrtomb(s, wc, ps) {
  if (s) {
    HEAP8[s] = wc;
  }
  return 1;
}

var _llvm_memcpy_i32 = _memcpy;

var _llvm_memcpy_i64 = _memcpy;

var _llvm_memcpy_p0i8_p0i8_i64 = _memcpy;

var _llvm_memmove_i32 = _memmove;

var _llvm_memmove_i64 = _memmove;

var _llvm_memmove_p0i8_p0i8_i64 = _memmove;

var _llvm_memset_i32 = _memset;

function _mblen() {
  return 1;
}

function _strspn(pstr, pset) {
  var str = String_copy(pstr, true);
  var set = String_copy(pset);
  var i = 0;
  while (set.indexOf(str[i]) != -1) i++;
  return i;
}

function _strcspn(pstr, pset) {
  var str = String_copy(pstr, true);
  var set = String_copy(pset, true);
  var i = 0;
  while (set.indexOf(str[i]) == -1) i++;
  return i;
}

function _stpcpy(pdest, psrc) {
  var i = 0;
  do {
    HEAP8[pdest + i] = HEAP8[psrc + i];
    i++;
  } while (HEAP8[psrc + i - 1] != 0);
  return pdest + i - 1;
}

function _strncpy(pdest, psrc, num) {
  var padding = false, curr;
  for (var i = 0; i < num; i++) {
    curr = padding ? 0 : HEAP8[psrc + i];
    HEAP8[pdest + i] = curr;
    padding = padding || HEAP8[psrc + i] == 0;
  }
  return pdest;
}

function _strcat(pdest, psrc) {
  var len = _strlen(pdest);
  var i = 0;
  do {
    HEAP8[pdest + len + i] = HEAP8[psrc + i];
    i++;
  } while (HEAP8[psrc + i - 1] != 0);
  return pdest;
}

function _strncat(pdest, psrc, num) {
  var len = _strlen(pdest);
  var i = 0;
  while (1) {
    HEAP8[pdest + len + i] = HEAP8[psrc + i];
    if (HEAP8[pdest + len + i] == 0) break;
    i++;
    if (i == num) {
      HEAP8[pdest + len + i] = 0;
      break;
    }
  }
  return pdest;
}

var _strcoll = _strcmp;

function _strncasecmp(px, py, n) {
  var i = 0;
  while (i < n) {
    var x = _tolower(HEAP8[px + i]);
    var y = _tolower(HEAP8[py + i]);
    if (x == y && x == 0) return 0;
    if (x == 0) return -1;
    if (y == 0) return 1;
    if (x == y) {
      i++;
      continue;
    } else {
      return x > y ? 1 : -1;
    }
  }
  return 0;
}

function _strcasecmp(px, py) {
  return _strncasecmp(px, py, TOTAL_MEMORY);
}

function _strchr(ptr, chr) {
  ptr--;
  do {
    ptr++;
    var val = HEAP8[ptr];
    if (val == chr) return ptr;
  } while (val);
  return 0;
}

function _strrchr(ptr, chr) {
  var ptr2 = ptr + _strlen(ptr);
  do {
    if (HEAP8[ptr2] == chr) return ptr2;
    ptr2--;
  } while (ptr2 >= ptr);
  return 0;
}

function _strdup(ptr) {
  var len = String_len(ptr);
  var newStr = _malloc(len + 1);
  _memcpy(newStr, ptr, len, 1);
  HEAP8[newStr + len] = 0;
  return newStr;
}

function _strpbrk(ptr1, ptr2) {
  var searchSet = Runtime.set.apply(null, String_copy(ptr2));
  while (HEAP8[ptr1]) {
    if (HEAP8[ptr1] in searchSet) return ptr1;
    ptr1++;
  }
  return 0;
}

var ___strtok_state = 0;

function _strtok_r(s, delim, lasts) {
  var skip_leading_delim = 1;
  var spanp;
  var c, sc;
  var tok;
  if (s == 0 && (s = getValue(lasts, "i8*")) == 0) {
    return 0;
  }
  cont : while (1) {
    c = getValue(s++, "i8");
    for (spanp = delim; (sc = getValue(spanp++, "i8")) != 0; ) {
      if (c == sc) {
        if (skip_leading_delim) {
          continue cont;
        } else {
          setValue(lasts, s, "i8*");
          setValue(s - 1, 0, "i8");
          return s - 1;
        }
      }
    }
    break;
  }
  if (c == 0) {
    setValue(lasts, 0, "i8*");
    return 0;
  }
  tok = s - 1;
  for (;;) {
    c = getValue(s++, "i8");
    spanp = delim;
    do {
      if ((sc = getValue(spanp++, "i8")) == c) {
        if (c == 0) {
          s = 0;
        } else {
          setValue(s - 1, 0, "i8");
        }
        setValue(lasts, s, "i8*");
        return tok;
      }
    } while (sc != 0);
  }
  abort("strtok_r error!");
}

function _strtok(s, delim) {
  return _strtok_r(s, delim, ___strtok_state);
}

function _isascii(chr) {
  return chr >= 0 && (chr & 128) == 0;
}

function _toascii(chr) {
  return chr & 127;
}

function _toupper(chr) {
  if (chr >= "a".charCodeAt(0) && chr <= "z".charCodeAt(0)) {
    return chr - "a".charCodeAt(0) + "A".charCodeAt(0);
  } else {
    return chr;
  }
}

var __toupper = _toupper;

var __tolower = _tolower;

function _islower(chr) {
  return chr >= "a".charCodeAt(0) && chr <= "z".charCodeAt(0);
}

function _isupper(chr) {
  return chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0);
}

var _isdigit_l = _isdigit;

var _isxdigit_l = _isxdigit;

function _isalnum(chr) {
  return chr >= "0".charCodeAt(0) && chr <= "9".charCodeAt(0) || chr >= "a".charCodeAt(0) && chr <= "z".charCodeAt(0) || chr >= "A".charCodeAt(0) && chr <= "Z".charCodeAt(0);
}

function _ispunct(chr) {
  return chr >= "!".charCodeAt(0) && chr <= "/".charCodeAt(0) || chr >= ":".charCodeAt(0) && chr <= "@".charCodeAt(0) || chr >= "[".charCodeAt(0) && chr <= "`".charCodeAt(0) || chr >= "{".charCodeAt(0) && chr <= "~".charCodeAt(0);
}

function _isblank(chr) {
  return chr == " ".charCodeAt(0) || chr == "\t".charCodeAt(0);
}

function _iscntrl(chr) {
  return 0 <= chr && chr <= 31 || chr === 127;
}

var _isgraph = _isprint;

function ___ctype_b_loc() {
  var me = ___ctype_b_loc;
  if (!me.ret) {
    var values = [ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 8195, 8194, 8194, 8194, 8194, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 24577, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 55304, 55304, 55304, 55304, 55304, 55304, 55304, 55304, 55304, 55304, 49156, 49156, 49156, 49156, 49156, 49156, 49156, 54536, 54536, 54536, 54536, 54536, 54536, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 50440, 49156, 49156, 49156, 49156, 49156, 49156, 54792, 54792, 54792, 54792, 54792, 54792, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 50696, 49156, 49156, 49156, 49156, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ];
    var i16size = 2;
    var arr = _malloc(values.length * i16size);
    for (var i = 0; i < values.length; i++) {
      HEAP16[arr + i * i16size >> 1] = values[i];
    }
    me.ret = allocate([ arr + 128 * i16size ], "i16*", ALLOC_NORMAL);
  }
  return me.ret;
}

function ___ctype_tolower_loc() {
  var me = ___ctype_tolower_loc;
  if (!me.ret) {
    var values = [ 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255 ];
    var i32size = 4;
    var arr = _malloc(values.length * i32size);
    for (var i = 0; i < values.length; i++) {
      HEAP32[arr + i * i32size >> 2] = values[i];
    }
    me.ret = allocate([ arr + 128 * i32size ], "i32*", ALLOC_NORMAL);
  }
  return me.ret;
}

function ___ctype_toupper_loc() {
  var me = ___ctype_toupper_loc;
  if (!me.ret) {
    var values = [ 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255 ];
    var i32size = 4;
    var arr = _malloc(values.length * i32size);
    for (var i = 0; i < values.length; i++) {
      HEAP32[arr + i * i32size >> 2] = values[i];
    }
    me.ret = allocate([ arr + 128 * i32size ], "i32*", ALLOC_NORMAL);
  }
  return me.ret;
}

function _llvm_bswap_i32(x) {
  x = unSign(x, 32);
  var bytes = [];
  for (var i = 0; i < 4; i++) {
    bytes[i] = x & 255;
    x >>= 8;
  }
  var ret = 0;
  for (i = 0; i < 4; i++) {
    ret <<= 8;
    ret += bytes[i];
  }
  return ret;
}

function ___assert_fail(condition, file, line) {
  ABORT = true;
  throw "Assertion failed: " + Pointer_stringify(condition);
}

function ___assert_func(filename, line, func, condition) {
  throw "Assertion failed: " + Pointer_stringify(condition) + ", at: " + [ Pointer_stringify(filename), line, Pointer_stringify(func) ];
}

function ___cxa_guard_acquire(variable) {
  if (!HEAP8[variable]) {
    HEAP8[variable] = 1;
    return 1;
  }
  return 0;
}

function ___cxa_guard_release() {}

function ___cxa_guard_abort() {}

var __ZTVN10__cxxabiv119__pointer_type_infoE = [ 0 ];

var __ZTVN10__cxxabiv117__class_type_infoE = [ 1 ];

var __ZTVN10__cxxabiv120__si_class_type_infoE = [ 2 ];

function ___cxa_rethrow() {
  ___cxa_end_catch.rethrown = true;
  throw HEAP32[_llvm_eh_exception.buf >> 2];
}

var _llvm_eh_selector__jsargs = true;

function _llvm_eh_selector(unused_exception_value, personality) {
  var type = HEAP32[_llvm_eh_exception.buf + 4 >> 2];
  for (var i = 2; i < arguments.length; i++) {
    if (arguments[i] == type) return type;
  }
  return 0;
}

function _llvm_eh_typeid_for(type) {
  return type;
}

function ___cxa_get_exception_ptr(ptr) {
  return ptr;
}

function __Unwind_Resume_or_Rethrow(ptr) {
  throw ptr;
}

function __Unwind_RaiseException(ptr) {
  throw ptr;
}

function __Unwind_DeleteException(ptr) {}

var _terminate = ___cxa_call_unexpected;

var __ZTIi = [ 0 ];

var __ZTIl = [ 0 ];

var __ZTIx = [ 0 ];

var __ZTIf = [ 0 ];

var __ZTId = [ 0 ];

var __ZTIc = [ 0 ];

var __ZTIv = [ 0 ];

var __ZTIPv = [ 0 ];

function _llvm_umul_with_overflow_i32(x, y) {
  x = x >>> 0;
  y = y >>> 0;
  return {
    f0: x * y >>> 0,
    f1: x * y > 4294967295
  };
}

function _llvm_stacksave() {
  var self = _llvm_stacksave;
  if (!self.LLVM_SAVEDSTACKS) {
    self.LLVM_SAVEDSTACKS = [];
  }
  self.LLVM_SAVEDSTACKS.push(Runtime.stackSave());
  return self.LLVM_SAVEDSTACKS.length - 1;
}

function _llvm_stackrestore(p) {
  var self = _llvm_stacksave;
  var ret = self.LLVM_SAVEDSTACKS[p];
  self.LLVM_SAVEDSTACKS.splice(p, 1);
  Runtime.stackRestore(ret);
}

function _llvm_flt_rounds() {
  return -1;
}

function _llvm_memory_barrier() {}

function _llvm_atomic_load_add_i32_p0i32(ptr, delta) {
  var ret = HEAP32[ptr >> 2];
  HEAP32[ptr >> 2] = ret + delta;
  return ret;
}

function _llvm_lifetime_start() {}

function _llvm_lifetime_end() {}

var _cosf = Math.cos;

var _sinf = Math.sin;

var _tanf = Math.tan;

var _acosf = Math.acos;

var _asinf = Math.asin;

var _atanf = Math.atan;

var _atan2f = Math.atan2;

var _expf = Math.exp;

var _logf = Math.log;

var _sqrtf = Math.sqrt;

var _fabsf = Math.abs;

var _ceilf = Math.ceil;

var _floorf = Math.floor;

var _pow = Math.pow;

var _powf = Math.powf;

var _llvm_sqrt_f32 = Math.sqrt;

var _llvm_sqrt_f64 = Math.sqrt;

var _llvm_pow_f32 = Math.pow;

var _llvm_log_f32 = Math.log;

var _llvm_log_f64 = Math.log;

var _llvm_exp_f32 = Math.exp;

var _llvm_exp_f64 = Math.exp;

function _ldexp(x, exp_) {
  return x * Math.pow(2, exp_);
}

var _ldexpf = _ldexp;

var _scalb = _ldexp;

var _scalbn = _ldexp;

var _scalbnf = _ldexp;

var _scalbln = _ldexp;

var _scalblnf = _ldexp;

function _cbrt(x) {
  return Math.pow(x, 1 / 3);
}

var _cbrtf = _cbrt;

var _cbrtl = _cbrt;

function _modf(x, intpart) {
  tempDoubleF64[0] = Math.floor(x), HEAP32[intpart >> 2] = tempDoubleI32[0], HEAP32[intpart + 4 >> 2] = tempDoubleI32[1];
  return x - (tempDoubleI32[0] = HEAP32[intpart >> 2], tempDoubleI32[1] = HEAP32[intpart + 4 >> 2], tempDoubleF64[0]);
}

function _modff(x, intpart) {
  HEAPF32[intpart >> 2] = Math.floor(x);
  return x - HEAPF32[intpart >> 2];
}

function _frexp(x, exp_addr) {
  var sig = 0, exp_ = 0;
  if (x !== 0) {
    var raw_exp = Math.log(x) / Math.log(2);
    exp_ = Math.ceil(raw_exp);
    if (exp_ === raw_exp) exp_ += 1;
    sig = x / Math.pow(2, exp_);
  }
  HEAP32[exp_addr >> 2] = exp_;
  return sig;
}

var _frexpf = _frexp;

function _finite(x) {
  return isFinite(x);
}

var ___finite = _finite;

function _isinf(x) {
  return !isNaN(x) && !isFinite(x);
}

var ___isinf = _isinf;

function _isnan(x) {
  return isNaN(x);
}

var ___isnan = _isnan;

var _copysignf = _copysign;

function _hypot(a, b) {
  return Math.sqrt(a * a + b * b);
}

var _hypotf = _hypot;

function _sinh(x) {
  var p = Math.pow(Math.E, x);
  return (p - 1 / p) / 2;
}

var _sinhf = _sinh;

function _cosh(x) {
  var p = Math.pow(Math.E, x);
  return (p + 1 / p) / 2;
}

var _coshf = _cosh;

function _tanh(x) {
  return _sinh(x) / _cosh(x);
}

var _tanhf = _tanh;

function _asinh(x) {
  return Math.log(x + Math.sqrt(x * x + 1));
}

var _asinhf = _asinh;

function _acosh(x) {
  return Math.log(x * 1 + Math.sqrt(x * x - 1));
}

var _acoshf = _acosh;

function _atanh(x) {
  return Math.log((1 + x) / (1 - x)) / 2;
}

var _atanhf = _atanh;

function _exp2(x) {
  return Math.pow(2, x);
}

var _exp2f = _exp2;

function _expm1(x) {
  return Math.exp(x) - 1;
}

var _expm1f = _expm1;

function _round(x) {
  return x < 0 ? -Math.round(-x) : Math.round(x);
}

var _roundf = _round;

var _lround = _round;

var _lroundf = _round;

var _llround = _round;

var _llroundf = _round;

function _rint(x) {
  return x > 0 ? -Math.round(-x) : Math.round(x);
}

var _rintf = _rint;

var _lrint = _rint;

var _lrintf = _rint;

var _llrint = _rint;

var _llrintf = _rint;

var _nearbyint = _rint;

var _nearbyintf = _rint;

function _trunc(x) {
  return x < 0 ? Math.ceil(x) : Math.floor(x);
}

var _truncf = _trunc;

function _fdim(x, y) {
  return x > y ? x - y : 0;
}

var _fdimf = _fdim;

function _fmax(x, y) {
  return isNaN(x) ? y : isNaN(y) ? x : Math.max(x, y);
}

var _fmaxf = _fmax;

function _fmin(x, y) {
  return isNaN(x) ? y : isNaN(y) ? x : Math.max(x, y);
}

var _fminf = _fmin;

function _fma(x, y, z) {
  return x * y + z;
}

var _fmaf = _fma;

var _fmodf = _fmod;

var _remainder = _fmod;

var _remainderf = _fmod;

var _log10f = _log10;

function _log1p(x) {
  return Math.log(1 + x);
}

var _log1pf = _log1p;

function _log2(x) {
  return Math.log(x) / Math.LN2;
}

var _log2f = _log2;

function _nan(x) {
  return NaN;
}

var _nanf = _nan;

function _sincos(x, sine, cosine) {
  var sineVal = Math.sin(x), cosineVal = Math.cos(x);
  tempDoubleF64[0] = sineVal, HEAP32[sine >> 2] = tempDoubleI32[0], HEAP32[sine + 4 >> 2] = tempDoubleI32[1];
  tempDoubleF64[0] = cosineVal, HEAP32[cosine >> 2] = tempDoubleI32[0], HEAP32[cosine + 4 >> 2] = tempDoubleI32[1];
}

function _sincosf(x, sine, cosine) {
  var sineVal = Math.sin(x), cosineVal = Math.cos(x);
  HEAPF32[sine >> 2] = sineVal;
  HEAPF32[cosine >> 2] = cosineVal;
}

var ___div_t_struct_layout = {
  __size__: 8,
  quot: 0,
  rem: 4
};

function _div(divt, numer, denom) {
  var quot = Math.floor(numer / denom);
  var rem = numer - quot * denom;
  var offset = ___div_t_struct_layout.rem;
  HEAP32[divt >> 2] = quot;
  HEAP32[divt + offset >> 2] = rem;
  return divt;
}

var ___utsname_struct_layout = null;

function _uname(name) {
  function copyString(element, value) {
    var offset = ___utsname_struct_layout[element];
    for (var i = 0; i < value.length; i++) {
      HEAP8[name + offset + i] = value.charCodeAt(i);
    }
    HEAP8[name + offset + i] = 0;
  }
  if (name === 0) {
    return -1;
  } else {
    copyString("sysname", "Emscripten");
    copyString("nodename", "emscripten");
    copyString("release", "1.0");
    copyString("version", "#1");
    copyString("machine", "x86-JS");
    return 0;
  }
}

var DLFCN_DATA = {
  error: null,
  errorMsg: null,
  loadedLibs: {},
  loadedLibNames: {}
};

function _dlopen(filename, flag) {
  filename = (ENV["LD_LIBRARY_PATH"] || "/") + Pointer_stringify(filename);
  if (DLFCN_DATA.loadedLibNames[filename]) {
    var handle = DLFCN_DATA.loadedLibNames[filename];
    DLFCN_DATA.loadedLibs[handle].refcount++;
    return handle;
  }
  var target = FS.findObject(filename);
  if (!target || target.isFolder || target.isDevice) {
    DLFCN_DATA.errorMsg = "Could not find dynamic lib: " + filename;
    return 0;
  } else {
    FS.forceLoadFile(target);
    var lib_data = intArrayToString(target.contents);
  }
  try {
    var lib_module = eval(lib_data)(FUNCTION_TABLE.length);
  } catch (e) {
    DLFCN_DATA.errorMsg = "Could not evaluate dynamic lib: " + filename;
    return 0;
  }
  var handle = 1;
  for (var key in DLFCN_DATA.loadedLibs) {
    if (DLFCN_DATA.loadedLibs.hasOwnProperty(key)) handle++;
  }
  DLFCN_DATA.loadedLibs[handle] = {
    refcount: 1,
    name: filename,
    module: lib_module,
    cached_functions: {}
  };
  DLFCN_DATA.loadedLibNames[filename] = handle;
  if (flag & 256) {
    for (var ident in lib_module) {
      if (lib_module.hasOwnProperty(ident)) {
        Module[ident] = lib_module[ident];
      }
    }
  }
  return handle;
}

function _dlclose(handle) {
  if (!DLFCN_DATA.loadedLibs[handle]) {
    DLFCN_DATA.errorMsg = "Tried to dlclose() unopened handle: " + handle;
    return 1;
  } else {
    var lib_record = DLFCN_DATA.loadedLibs[handle];
    if (lib_record.refcount-- == 0) {
      delete DLFCN_DATA.loadedLibNames[lib_record.name];
      delete DLFCN_DATA.loadedLibs[handle];
    }
    return 0;
  }
}

function _dlsym(handle, symbol) {
  symbol = "_" + Pointer_stringify(symbol);
  if (!DLFCN_DATA.loadedLibs[handle]) {
    DLFCN_DATA.errorMsg = "Tried to dlsym() from an unopened handle: " + handle;
    return 0;
  } else {
    var lib = DLFCN_DATA.loadedLibs[handle];
    if (!lib.module.hasOwnProperty(symbol)) {
      DLFCN_DATA.errorMsg = 'Tried to lookup unknown symbol "' + symbol + '" in dynamic lib: ' + lib.name;
      return 0;
    } else {
      if (lib.cached_functions.hasOwnProperty(symbol)) {
        return lib.cached_functions[symbol];
      } else {
        var result = lib.module[symbol];
        if (typeof result == "function") {
          FUNCTION_TABLE.push(result);
          FUNCTION_TABLE.push(0);
          result = FUNCTION_TABLE.length - 2;
          lib.cached_functions = result;
        }
        return result;
      }
    }
  }
}

function _dlerror() {
  if (DLFCN_DATA.errorMsg === null) {
    return 0;
  } else {
    if (DLFCN_DATA.error) _free(DLFCN_DATA.error);
    var msgArr = intArrayFromString(DLFCN_DATA.errorMsg);
    DLFCN_DATA.error = allocate(msgArr, "i8", ALLOC_NORMAL);
    DLFCN_DATA.errorMsg = null;
    return DLFCN_DATA.error;
  }
}

function _getpwuid(uid) {
  return 0;
}

function _clock() {
  if (_clock.start === undefined) _clock.start = Date.now();
  return Math.floor((Date.now() - _clock.start) * (1e3 / 1e3));
}

function _difftime(time1, time0) {
  return time1 - time0;
}

var ___tm_current = 0;

var ___tm_formatted = 0;

var _timelocal = _mktime;

function _gmtime_r(time, tmPtr) {
  var date = new Date(HEAP32[time >> 2] * 1e3);
  var offsets = ___tm_struct_layout;
  HEAP32[tmPtr + offsets.tm_sec >> 2] = date.getUTCSeconds();
  HEAP32[tmPtr + offsets.tm_min >> 2] = date.getUTCMinutes();
  HEAP32[tmPtr + offsets.tm_hour >> 2] = date.getUTCHours();
  HEAP32[tmPtr + offsets.tm_mday >> 2] = date.getUTCDate();
  HEAP32[tmPtr + offsets.tm_mon >> 2] = date.getUTCMonth();
  HEAP32[tmPtr + offsets.tm_year >> 2] = date.getUTCFullYear() - 1900;
  HEAP32[tmPtr + offsets.tm_wday >> 2] = date.getUTCDay();
  HEAP32[tmPtr + offsets.tm_gmtoff >> 2] = 0;
  HEAP32[tmPtr + offsets.tm_isdst >> 2] = 0;
  var start = new Date(date.getFullYear(), 0, 1);
  var yday = Math.round((date.getTime() - start.getTime()) / (1e3 * 60 * 60 * 24));
  HEAP32[tmPtr + offsets.tm_yday >> 2] = yday;
  var timezone = "GMT";
  if (!(timezone in ___tm_timezones)) {
    ___tm_timezones[timezone] = allocate(intArrayFromString(timezone), "i8", ALLOC_NORMAL);
  }
  HEAP32[tmPtr + offsets.tm_zone >> 2] = ___tm_timezones[timezone];
  return tmPtr;
}

function _gmtime(time) {
  if (!___tm_current) ___tm_current = _malloc(___tm_struct_layout.__size__);
  return _gmtime_r(time, ___tm_current);
}

function _timegm(tmPtr) {
  _tzset();
  var offset = HEAP32[__timezone >> 2];
  var daylight = HEAP32[__daylight >> 2];
  daylight = daylight == 1 ? 60 * 60 : 0;
  var ret = _mktime(tmPtr) + offset - daylight;
  return ret;
}

function _localtime(time) {
  if (!___tm_current) ___tm_current = _malloc(___tm_struct_layout.__size__);
  return _localtime_r(time, ___tm_current);
}

function _asctime_r(tmPtr, buf) {
  var date = new Date(_mktime(tmPtr) * 1e3);
  var formatted = date.toString();
  var datePart = formatted.replace(/\d{4}.*/, "").replace(/ 0/, "  ");
  var timePart = formatted.match(/\d{2}:\d{2}:\d{2}/)[0];
  formatted = datePart + timePart + " " + date.getFullYear() + "\n";
  formatted.split("").forEach((function(chr, index) {
    HEAP8[buf + index] = chr.charCodeAt(0);
  }));
  HEAP8[buf + 25] = 0;
  return buf;
}

function _asctime(tmPtr) {
  if (!___tm_formatted) ___tm_formatted = _malloc(26);
  return _asctime_r(tmPtr, ___tm_formatted);
}

function _ctime(timer) {
  return _asctime(_localtime(timer));
}

function _ctime_r(timer, buf) {
  return _asctime_r(_localtime_r(timer, ___tm_current), buf);
}

function _dysize(year) {
  var leap = year % 4 == 0 && (year % 100 != 0 || year % 400 == 0);
  return leap ? 366 : 365;
}

function _stime(when) {
  ___setErrNo(ERRNO_CODES.EPERM);
  return -1;
}

var _strftime_l = _strftime;

function _strptime(buf, format, tm) {
  return 0;
}

var _strptime_l = _strptime;

function _getdate(string) {
  return 0;
}

var ___timespec_struct_layout = null;

function _clock_gettime(clk_id, tp) {
  HEAP32[tp + ___timespec_struct_layout.tv_sec >> 2] = 0;
  HEAP32[tp + ___timespec_struct_layout.tv_nsec >> 2] = 0;
  return 0;
}

function _clock_settime(clk_id, tp) {
  return 0;
}

function _clock_getres(clk_id, res) {
  HEAP32[res + ___timespec_struct_layout.tv_sec >> 2] = 1;
  HEAP32[res + ___timespec_struct_layout.tv_nsec >> 2] = 0;
  return 0;
}

var ___tms_struct_layout = null;

function _times(buffer) {
  if (buffer !== 0) {
    memset(buffer, 0, ___tms_struct_layout.__size__);
  }
  return 0;
}

function _makedev(maj, min) {
  return 0;
}

var _gnu_dev_makedev = _makedev;

function _major(dev) {
  return 0;
}

var _gnu_dev_major = _major;

function _minor(dev) {
  return 0;
}

var _gnu_dev_minor = _minor;

function _longjmp(env, value) {
  throw {
    longjmp: true,
    label: HEAP32[env >> 2],
    value: value || 1
  };
}

function _signal(sig, func) {
  return 0;
}

function _sigemptyset(set) {
  HEAP32[set >> 2] = 0;
  HEAP32[set + 4 >> 2] = 0;
  HEAP32[set + 8 >> 2] = 0;
  HEAP32[set + 12 >> 2] = 0;
  return 0;
}

var _sigfillset = _sigemptyset;

var _sigdelset = _sigemptyset;

function _sigaction(set) {
  return 0;
}

var _sigprocmask = _sigaction;

function ___libc_current_sigrtmin() {
  return 0;
}

function ___libc_current_sigrtmax() {
  return 0;
}

function _kill(pid, sig) {
  ___setErrNo(ERRNO_CODES.EPERM);
  return -1;
}

var _killpg = _kill;

function _wait(stat_loc) {
  ___setErrNo(ERRNO_CODES.ECHILD);
  return -1;
}

var _waitid = _wait;

var _waitpid = _wait;

var _wait3 = _wait;

var _wait4 = _wait;

function _newlocale(mask, locale, base) {
  return 0;
}

function _uselocale(locale) {
  return 0;
}

function _setlocale(category, locale) {
  if (!_setlocale.ret) _setlocale.ret = allocate([ 0 ], "i8", ALLOC_NORMAL);
  return _setlocale.ret;
}

function _nl_langinfo(item) {
  var result;
  switch (item) {
   case 0:
    result = "ANSI_X3.4-1968";
    break;
   case 1:
    result = "%a %b %e %H:%M:%S %Y";
    break;
   case 2:
    result = "%m/%d/%y";
    break;
   case 3:
    result = "%H:%M:%S";
    break;
   case 4:
    result = "%I:%M:%S %p";
    break;
   case 5:
    result = "AM";
    break;
   case 6:
    result = "PM";
    break;
   case 7:
    result = "Sunday";
    break;
   case 8:
    result = "Monday";
    break;
   case 9:
    result = "Tuesday";
    break;
   case 10:
    result = "Wednesday";
    break;
   case 11:
    result = "Thursday";
    break;
   case 12:
    result = "Friday";
    break;
   case 13:
    result = "Saturday";
    break;
   case 14:
    result = "Sun";
    break;
   case 15:
    result = "Mon";
    break;
   case 16:
    result = "Tue";
    break;
   case 17:
    result = "Wed";
    break;
   case 18:
    result = "Thu";
    break;
   case 19:
    result = "Fri";
    break;
   case 20:
    result = "Sat";
    break;
   case 21:
    result = "January";
    break;
   case 22:
    result = "February";
    break;
   case 23:
    result = "March";
    break;
   case 24:
    result = "April";
    break;
   case 25:
    result = "May";
    break;
   case 26:
    result = "June";
    break;
   case 27:
    result = "July";
    break;
   case 28:
    result = "August";
    break;
   case 29:
    result = "September";
    break;
   case 30:
    result = "October";
    break;
   case 31:
    result = "November";
    break;
   case 32:
    result = "December";
    break;
   case 33:
    result = "Jan";
    break;
   case 34:
    result = "Feb";
    break;
   case 35:
    result = "Mar";
    break;
   case 36:
    result = "Apr";
    break;
   case 37:
    result = "May";
    break;
   case 38:
    result = "Jun";
    break;
   case 39:
    result = "Jul";
    break;
   case 40:
    result = "Aug";
    break;
   case 41:
    result = "Sep";
    break;
   case 42:
    result = "Oct";
    break;
   case 43:
    result = "Nov";
    break;
   case 44:
    result = "Dec";
    break;
   case 49:
    result = "";
    break;
   case 50:
    result = ".";
    break;
   case 51:
    result = "";
    break;
   case 52:
    result = "^[yY]";
    break;
   case 53:
    result = "^[nN]";
    break;
   case 56:
    result = "-";
    break;
   case 45:
   case 46:
   case 47:
   case 48:
   default:
    result = "";
    break;
  }
  var me = _nl_langinfo;
  if (!me.ret) me.ret = _malloc(32);
  for (var i = 0; i < result.length; i++) {
    HEAP8[me.ret + i] = result.charCodeAt(i);
  }
  HEAP8[me.ret + i] = 0;
  return me.ret;
}

var ___rlimit_struct_layout = null;

function _getrlimit(resource, rlp) {
  HEAP32[rlp + ___rlimit_struct_layout.rlim_cur >> 2] = -1;
  HEAP32[rlp + ___rlimit_struct_layout.rlim_max >> 2] = -1;
  return 0;
}

function _setrlimit(resource, rlp) {
  return 0;
}

var ___01getrlimit64_ = _getrlimit;

var ___rusage_struct_layout = null;

function _getrusage(resource, rlp) {
  var timeval = Runtime.calculateStructAlignment({
    fields: [ "i32", "i32" ]
  });
  HEAP32[rlp + ___rusage_struct_layout.ru_utime + timeval[0] >> 2] = 1;
  HEAP32[rlp + ___rusage_struct_layout.ru_utime + timeval[1] >> 2] = 2;
  HEAP32[rlp + ___rusage_struct_layout.ru_stime + timeval[0] >> 2] = 3;
  HEAP32[rlp + ___rusage_struct_layout.ru_stime + timeval[1] >> 2] = 4;
  return 0;
}

function _pthread_mutex_init() {}

function _pthread_mutex_destroy() {}

function _pthread_mutexattr_init() {}

function _pthread_mutexattr_settype() {}

function _pthread_mutexattr_destroy() {}

function _pthread_mutex_lock() {}

function _pthread_mutex_unlock() {}

function _pthread_cond_broadcast() {}

function _pthread_once(ptr, func) {
  if (!_pthread_once.seen) _pthread_once.seen = {};
  if (ptr in _pthread_once.seen) return;
  FUNCTION_TABLE[func]();
  _pthread_once.seen[ptr] = 1;
}

function _pthread_key_create(key, destructor) {
  if (!_pthread_key_create.keys) _pthread_key_create.keys = {};
  _pthread_key_create.keys[key] = null;
}

function _pthread_getspecific(key) {
  return _pthread_key_create.keys[key];
}

function _pthread_setspecific(key, value) {
  _pthread_key_create.keys[key] = value;
}

function _posix_memalign(memptr, alignment, size) {
  var ptr = _memalign(alignment, size);
  HEAP32[memptr >> 2] = ptr;
  return 0;
}

function _htonl(value) {
  return ((value & 255) << 24) + ((value & 65280) << 8) + ((value & 16711680) >> 8) + ((value & 4278190080) >> 24);
}

function _htons(value) {
  return ((value & 255) << 8) + ((value & 65280) >> 8);
}

var _ntohl = _htonl;

var _ntohs = _htons;

function _emscripten_run_script(ptr) {
  eval(Pointer_stringify(ptr));
}

function _emscripten_run_script_int(ptr) {
  return eval(Pointer_stringify(ptr));
}

var Profiling = {
  max_: 0,
  times: null,
  invalid: 0,
  dump: (function() {
    if (Profiling.invalid) {
      Module.printErr("Invalid # of calls to Profiling begin and end!");
      return;
    }
    Module.printErr("Profiling data:");
    for (var i = 0; i < Profiling.max_; i++) {
      Module.printErr("Block " + i + ": " + Profiling.times[i]);
    }
  })
};

function _EMSCRIPTEN_PROFILE_INIT(max_) {
  Profiling.max_ = max_;
  Profiling.times = new Array(max_);
  for (var i = 0; i < max_; i++) Profiling.times[i] = 0;
}

function _emscripten_set_main_loop(func, fps) {
  Module["noExitRuntime"] = true;
  fps = fps || 60;
  _emscripten_set_main_loop.cancel = false;
  var jsFunc = FUNCTION_TABLE[func];
  function doOne() {
    if (_emscripten_set_main_loop.cancel) return;
    jsFunc();
    setTimeout(doOne, 1e3 / fps);
  }
  setTimeout(doOne, 1e3 / fps);
}

function _emscripten_cancel_main_loop(func) {
  _emscripten_set_main_loop.cancel = true;
}

function _emscripten_async_call(func, millis) {
  Module["noExitRuntime"] = true;
  setTimeout((function() {
    FUNCTION_TABLE[func]();
  }), millis);
}

var Browser = {
  createContext: (function(canvas, useWebGL) {
    try {
      var ctx = canvas.getContext(useWebGL ? "experimental-webgl" : "2d");
      if (!ctx) throw ":(";
    } catch (e) {
      Module.print("Could not create canvas - " + e);
      return null;
    }
    if (useWebGL) {
      canvas.style.backgroundColor = "black";
    }
    return ctx;
  })
};

var SDL = {
  defaults: {
    width: 320,
    height: 200,
    copyOnLock: true
  },
  version: null,
  surfaces: {},
  events: [],
  audios: [ null ],
  fonts: [ null ],
  keyboardState: null,
  startTime: null,
  mouseX: 0,
  mouseY: 0,
  DOMEventToSDLEvent: {
    keydown: 768,
    keyup: 769,
    mousedown: 1025,
    mouseup: 1026,
    mousemove: 1024
  },
  keyCodes: {
    16: 304,
    17: 305,
    18: 308,
    33: 1099,
    34: 1102,
    37: 1104,
    38: 1106,
    39: 1103,
    40: 1105,
    109: 45
  },
  scanCodes: {
    9: 43,
    13: 40,
    32: 44,
    47: 56,
    48: 30,
    49: 31,
    50: 32,
    51: 33,
    52: 34,
    53: 35,
    54: 36,
    55: 37,
    56: 38,
    57: 39,
    92: 49,
    97: 4,
    98: 5,
    99: 6,
    100: 7,
    101: 8,
    102: 9,
    103: 10,
    104: 11,
    105: 12,
    106: 13,
    107: 14,
    108: 15,
    109: 16,
    110: 17,
    111: 18,
    112: 19,
    113: 20,
    114: 21,
    115: 22,
    116: 23,
    117: 24,
    118: 25,
    119: 26,
    120: 27,
    121: 28,
    122: 29,
    1103: 79,
    1104: 80,
    1105: 81,
    1106: 82
  },
  structs: {
    Rect: {
      __size__: 16,
      x: 0,
      y: 4,
      w: 8,
      h: 12
    },
    PixelFormat: {
      __size__: 36,
      format: 0,
      palette: 4,
      BitsPerPixel: 8,
      BytesPerPixel: 9,
      padding1: 10,
      padding2: 11,
      Rmask: 12,
      Gmask: 16,
      Bmask: 20,
      Amask: 24,
      Rloss: 28,
      Gloss: 29,
      Bloss: 30,
      Aloss: 31,
      Rshift: 32,
      Gshift: 33,
      Bshift: 34,
      Ashift: 35
    },
    KeyboardEvent: {
      __size__: 16,
      type: 0,
      windowID: 4,
      state: 8,
      repeat: 9,
      padding2: 10,
      padding3: 11,
      keysym: 12
    },
    keysym: {
      __size__: 16,
      scancode: 0,
      sym: 4,
      mod: 8,
      unicode: 12
    },
    MouseMotionEvent: {
      __size__: 28,
      type: 0,
      windowID: 4,
      state: 8,
      padding1: 9,
      padding2: 10,
      padding3: 11,
      x: 12,
      y: 16,
      xrel: 20,
      yrel: 24
    },
    MouseButtonEvent: {
      __size__: 20,
      type: 0,
      windowID: 4,
      button: 8,
      state: 9,
      padding1: 10,
      padding2: 11,
      x: 12,
      y: 16
    },
    AudioSpec: {
      __size__: 24,
      freq: 0,
      format: 4,
      channels: 6,
      silence: 7,
      samples: 8,
      size: 12,
      callback: 16,
      userdata: 20
    },
    version: {
      __size__: 3,
      major: 0,
      minor: 1,
      patch: 2
    }
  },
  loadRect: (function(rect) {
    return {
      x: HEAP32[rect + SDL.structs.Rect.x >> 2],
      y: HEAP32[rect + SDL.structs.Rect.y >> 2],
      w: HEAP32[rect + SDL.structs.Rect.w >> 2],
      h: HEAP32[rect + SDL.structs.Rect.h >> 2]
    };
  }),
  loadColorToCSSRGB: (function(color) {
    var rgba = HEAP32[color >> 2];
    return "rgb(" + (rgba & 255) + "," + (rgba >> 8 & 255) + "," + (rgba >> 16 & 255) + ")";
  }),
  loadColorToCSSRGBA: (function(color) {
    var rgba = HEAP32[color >> 2];
    return "rgba(" + (rgba & 255) + "," + (rgba >> 8 & 255) + "," + (rgba >> 16 & 255) + "," + (rgba >> 24 & 255) / 255 + ")";
  }),
  translateColorToCSSRGBA: (function(rgba) {
    return "rgba(" + (rgba >> 24 & 255) + "," + (rgba >> 16 & 255) + "," + (rgba >> 8 & 255) + "," + (rgba & 255) / 255 + ")";
  }),
  translateRGBAToCSSRGBA: (function(r, g, b, a) {
    return "rgba(" + r + "," + g + "," + b + "," + a / 255 + ")";
  }),
  makeSurface: (function(width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
    flags = flags || 0;
    var surf = _malloc(14 * Runtime.QUANTUM_SIZE);
    var buffer = _malloc(width * height * 4);
    var pixelFormat = _malloc(18 * Runtime.QUANTUM_SIZE);
    flags |= 1;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 0 >> 2] = flags;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 1 >> 2] = pixelFormat;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 2 >> 2] = width;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 3 >> 2] = height;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 4 >> 2] = width * 4;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 5 >> 2] = buffer;
    HEAP32[surf + Runtime.QUANTUM_SIZE * 6 >> 2] = 0;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.format >> 2] = -2042224636;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.palette >> 2] = 0;
    HEAP8[pixelFormat + SDL.structs.PixelFormat.BitsPerPixel] = 32;
    HEAP8[pixelFormat + SDL.structs.PixelFormat.BytesPerPixel] = 4;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.Rmask >> 2] = rmask || 255;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.Gmask >> 2] = gmask || 65280;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.Bmask >> 2] = bmask || 16711680;
    HEAP32[pixelFormat + SDL.structs.PixelFormat.Amask >> 2] = amask || 4278190080;
    var useWebGL = (flags & 67108864) != 0;
    var canvas;
    if (!usePageCanvas) {
      canvas = document.createElement("canvas");
      canvas.width = width;
      canvas.height = height;
    } else {
      canvas = Module["canvas"];
    }
    var ctx = Browser.createContext(canvas, useWebGL);
    if (usePageCanvas) {
      Module.ctx = ctx;
    }
    SDL.surfaces[surf] = {
      width: width,
      height: height,
      canvas: canvas,
      ctx: ctx,
      surf: surf,
      buffer: buffer,
      pixelFormat: pixelFormat,
      alpha: 255,
      flags: flags,
      locked: 0,
      usePageCanvas: usePageCanvas,
      source: source
    };
    return surf;
  }),
  freeSurface: (function(surf) {
    _free(SDL.surfaces[surf].buffer);
    _free(SDL.surfaces[surf].pixelFormat);
    _free(surf);
    SDL.surfaces[surf] = null;
  }),
  receiveEvent: (function(event) {
    switch (event.type) {
     case "keydown":
     case "keyup":
     case "mousedown":
     case "mouseup":
     case "mousemove":
      SDL.events.push(event);
      if (event.keyCode >= 37 && event.keyCode <= 40 || event.keyCode == 32 || event.keyCode == 33 || event.keyCode == 34) {
        event.preventDefault();
      }
      break;
    }
    return false;
  }),
  makeCEvent: (function(event, ptr) {
    if (typeof event === "number") {
      _memcpy(ptr, event, SDL.structs.KeyboardEvent.__size__);
      return;
    }
    switch (event.type) {
     case "keydown":
     case "keyup":
      {
        var down = event.type === "keydown";
        var key = SDL.keyCodes[event.keyCode] || event.keyCode;
        if (key >= 65 && key <= 90) {
          key = String.fromCharCode(key).toLowerCase().charCodeAt(0);
        }
        var scan = SDL.scanCodes[key] || key;
        HEAP32[ptr + SDL.structs.KeyboardEvent.type >> 2] = SDL.DOMEventToSDLEvent[event.type];
        HEAP8[ptr + SDL.structs.KeyboardEvent.state] = down ? 1 : 0;
        HEAP8[ptr + SDL.structs.KeyboardEvent.repeat] = 0;
        HEAP32[ptr + SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.scancode >> 2] = scan;
        HEAP32[ptr + SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.sym >> 2] = key;
        HEAP32[ptr + SDL.structs.KeyboardEvent.keysym + SDL.structs.keysym.mod >> 2] = 0;
        HEAP8[SDL.keyboardState + SDL.keyCodes[event.keyCode] || event.keyCode] = event.type == "keydown";
        break;
      }
     case "mousedown":
     case "mouseup":
     case "mousemove":
      {
        var x = event.pageX - Module["canvas"].offsetLeft;
        var y = event.pageY - Module["canvas"].offsetTop;
        if (event.type != "mousemove") {
          var down = event.type === "mousedown";
          HEAP32[ptr + SDL.structs.MouseButtonEvent.type >> 2] = SDL.DOMEventToSDLEvent[event.type];
          HEAP8[ptr + SDL.structs.MouseButtonEvent.button] = event.button + 1;
          HEAP8[ptr + SDL.structs.MouseButtonEvent.state] = down ? 1 : 0;
          HEAP32[ptr + SDL.structs.MouseButtonEvent.x >> 2] = x;
          HEAP32[ptr + SDL.structs.MouseButtonEvent.y >> 2] = y;
        } else {
          HEAP32[ptr + SDL.structs.MouseMotionEvent.type >> 2] = SDL.DOMEventToSDLEvent[event.type];
          HEAP8[ptr + SDL.structs.MouseMotionEvent.button] = event.button;
          HEAP8[ptr + SDL.structs.MouseMotionEvent.state] = down ? 1 : 0;
          HEAP32[ptr + SDL.structs.MouseMotionEvent.x >> 2] = x;
          HEAP32[ptr + SDL.structs.MouseMotionEvent.y >> 2] = y;
          HEAP32[ptr + SDL.structs.MouseMotionEvent.xrel >> 2] = x - SDL.mouseX;
          HEAP32[ptr + SDL.structs.MouseMotionEvent.yrel >> 2] = y - SDL.mouseY;
        }
        SDL.mouseX = x;
        SDL.mouseY = y;
        break;
      }
     default:
      throw "Unhandled SDL event: " + event.type;
    }
  }),
  estimateTextWidth: (function(fontData, text) {
    var h = fontData.size;
    var fontString = h + "px sans-serif";
    var tempCtx = SDL.surfaces[SDL.screen].ctx;
    tempCtx.save();
    tempCtx.font = fontString;
    var ret = tempCtx.measureText(text).width | 0;
    tempCtx.restore();
    return ret;
  }),
  debugSurface: (function(surfData) {
    console.log("dumping surface " + [ surfData.surf, surfData.source, surfData.width, surfData.height ]);
    var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
    var data = image.data;
    var num = Math.min(surfData.width, surfData.height);
    for (var i = 0; i < num; i++) {
      console.log("   diagonal " + i + ":" + [ data[i * surfData.width * 4 + i * 4 + 0], data[i * surfData.width * 4 + i * 4 + 1], data[i * surfData.width * 4 + i * 4 + 2], data[i * surfData.width * 4 + i * 4 + 3] ]);
    }
  })
};

function _SDL_Linked_Version() {
  if (SDL.version === null) {
    SDL.version = _malloc(SDL.structs.version.__size__);
    HEAP8[SDL.version + SDL.structs.version.major] = 1;
    HEAP8[SDL.version + SDL.structs.version.minor] = 3;
    HEAP8[SDL.version + SDL.structs.version.patch] = 0;
  }
  return SDL.version;
}

function _SDL_Init(what) {
  SDL.startTime = Date.now();
  [ "keydown", "keyup" ].forEach((function(event) {
    addEventListener(event, SDL.receiveEvent, true);
  }));
  SDL.keyboardState = _malloc(65536);
  _memset(SDL.keyboardState, 0, 65536);
  return 0;
}

function _SDL_WasInit() {
  if (SDL.startTime === null) {
    _SDL_Init();
  }
  return 1;
}

function _SDL_GetVideoInfo() {
  var ret = _malloc(5 * Runtime.QUANTUM_SIZE);
  HEAP32[ret + Runtime.QUANTUM_SIZE * 0 >> 2] = 0;
  HEAP32[ret + Runtime.QUANTUM_SIZE * 1 >> 2] = 0;
  HEAP32[ret + Runtime.QUANTUM_SIZE * 2 >> 2] = 0;
  HEAP32[ret + Runtime.QUANTUM_SIZE * 3 >> 2] = SDL.defaults.width;
  HEAP32[ret + Runtime.QUANTUM_SIZE * 4 >> 2] = SDL.defaults.height;
  return ret;
}

function _SDL_ListModes(format, flags) {
  return -1;
}

function _SDL_SetVideoMode(width, height, depth, flags) {
  [ "mousedown", "mouseup", "mousemove" ].forEach((function(event) {
    Module["canvas"].addEventListener(event, SDL.receiveEvent, true);
  }));
  Module["canvas"].width = width;
  Module["canvas"].height = height;
  return SDL.screen = SDL.makeSurface(width, height, flags, true, "screen");
}

function _SDL_Quit() {
  for (var i = 0; i < SDL.audios; i++) {
    SDL.audios[i].pause();
  }
  Module.print("SDL_Quit called (and ignored)");
}

function _SDL_LockSurface(surf) {
  var surfData = SDL.surfaces[surf];
  surfData.locked++;
  if (surfData.locked > 1) return 0;
  if (!surfData.image) {
    surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
    if (surf == SDL.screen) {
      var data = surfData.image.data;
      var num = data.length;
      for (var i = 0; i < num / 4; i++) {
        data[i * 4 + 3] = 255;
      }
    }
  }
  if (SDL.defaults.copyOnLock) {
    HEAPU8.set(surfData.image.data, surfData.buffer);
  }
  HEAP32[surf + 5 * Runtime.QUANTUM_SIZE >> 2] = surfData.buffer;
  return 0;
}

function _SDL_UnlockSurface(surf) {
  var surfData = SDL.surfaces[surf];
  surfData.locked--;
  if (surfData.locked > 0) return;
  var num = surfData.image.data.length;
  if (!surfData.colors) {
    var data = surfData.image.data;
    var buffer = surfData.buffer;
    assert(buffer % 4 == 0, "Invalid buffer offset: " + buffer);
    var src = buffer >> 2;
    var dst = 0;
    var isScreen = surf == SDL.screen;
    while (dst < num) {
      var val = HEAP32[src];
      data[dst] = val & 255;
      data[dst + 1] = val >> 8 & 255;
      data[dst + 2] = val >> 16 & 255;
      data[dst + 3] = isScreen ? 255 : val >> 24 & 255;
      src++;
      dst += 4;
    }
  } else {
    var width = Module["canvas"].width;
    var height = Module["canvas"].height;
    var s = surfData.buffer;
    var data = surfData.image.data;
    var colors = surfData.colors;
    for (var y = 0; y < height; y++) {
      var base = y * width * 4;
      for (var x = 0; x < width; x++) {
        var val = HEAP8[s++] & 255;
        var color = colors[val] || [ Math.floor(Math.random() * 255), Math.floor(Math.random() * 255), Math.floor(Math.random() * 255) ];
        var start = base + x * 4;
        data[start] = color[0];
        data[start + 1] = color[1];
        data[start + 2] = color[2];
      }
      s += width * 3;
    }
  }
  surfData.ctx.putImageData(surfData.image, 0, 0);
}

function _SDL_Flip(surf) {}

function _SDL_UpdateRect(surf, x, y, w, h) {}

function _SDL_Delay(delay) {
  throw "SDL_Delay called! Potential infinite loop, quitting. " + (new Error).stack;
}

function _SDL_WM_SetCaption(title, icon) {
  title = title && Pointer_stringify(title);
  icon = icon && Pointer_stringify(icon);
}

function _SDL_EnableKeyRepeat(delay, interval) {}

function _SDL_GetKeyboardState() {
  return SDL.keyboardState;
}

function _SDL_GetMouseState(x, y) {
  if (x) HEAP32[x >> 2] = SDL.mouseX;
  if (y) HEAP32[y >> 2] = SDL.mouseY;
  return 0;
}

function _SDL_WarpMouse(x, y) {
  SDL.events.push({
    type: "mousemove",
    pageX: x + Module["canvas"].offsetLeft,
    pageY: y + Module["canvas"].offsetTop
  });
}

function _SDL_ShowCursor() {}

function _SDL_GetError() {
  return allocate(intArrayFromString("SDL is cool"), "i8");
}

function _SDL_CreateRGBSurface(flags, width, height, depth, rmask, gmask, bmask, amask) {
  return SDL.makeSurface(width, height, flags, false, "CreateRGBSurface", rmask, gmask, bmask, amask);
}

function _SDL_DisplayFormatAlpha(surf) {
  var oldData = SDL.surfaces[surf];
  var ret = SDL.makeSurface(oldData.width, oldData.height, oldData.flags, false, "copy:" + oldData.source);
  var newData = SDL.surfaces[ret];
  newData.ctx.drawImage(oldData.canvas, 0, 0);
  return ret;
}

function _SDL_FreeSurface(surf) {
  if (surf) SDL.freeSurface(surf);
}

function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
  var srcData = SDL.surfaces[src];
  var dstData = SDL.surfaces[dst];
  var sr, dr;
  if (srcrect) {
    sr = SDL.loadRect(srcrect);
  } else {
    sr = {
      x: 0,
      y: 0,
      w: srcData.width,
      h: srcData.height
    };
  }
  if (dstrect) {
    dr = SDL.loadRect(dstrect);
  } else {
    dr = {
      x: 0,
      y: 0,
      w: -1,
      h: -1
    };
  }
  dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, sr.w, sr.h);
  if (dst != SDL.screen) {
    console.log("WARNING: copying canvas data to memory for compatibility");
    _SDL_LockSurface(dst);
    dstData.locked--;
  }
  return 0;
}

function _SDL_FillRect(surf, rect, color) {
  var surfData = SDL.surfaces[surf];
  assert(!surfData.locked);
  var r = SDL.loadRect(rect);
  surfData.ctx.save();
  surfData.ctx.fillStyle = SDL.translateColorToCSSRGBA(color);
  surfData.ctx.fillRect(r.x, r.y, r.w, r.h);
  surfData.ctx.restore();
}

function _SDL_BlitSurface(src, srcrect, dst, dstrect) {
  return _SDL_UpperBlit(src, srcrect, dst, dstrect);
}

function _SDL_SetAlpha(surf, flag, alpha) {
  SDL.surfaces[surf].alpha = alpha;
}

function _SDL_GetTicks() {
  return Math.floor(Date.now() - SDL.startTime);
}

function _SDL_PollEvent(ptr) {
  if (SDL.events.length === 0) return 0;
  if (ptr) {
    SDL.makeCEvent(SDL.events.shift(), ptr);
  }
  return 1;
}

function _SDL_PushEvent(ptr) {
  SDL.events.push(ptr);
  return 0;
}

function _SDL_PeepEvents(events, numEvents, action, from, to) {
  switch (action) {
   case 2:
    {
      assert(numEvents == 1);
      var got = 0;
      while (SDL.events.length > 0 && numEvents > 0) {
        var type = SDL.DOMEventToSDLEvent[SDL.events[0].type];
        if (type < from || type > to) break;
        SDL.makeCEvent(SDL.events.shift(), events);
        got++;
        numEvents--;
      }
      return got;
    }
   default:
    throw "SDL_PeepEvents does not yet support that action: " + action;
  }
}

function _SDL_PumpEvents() {}

function _SDL_SetColors(surf, colors, firstColor, nColors) {
  var surfData = SDL.surfaces[surf];
  surfData.colors = [];
  for (var i = firstColor; i < nColors; i++) {
    surfData.colors[i] = Array_copy(colors + i * 4, colors + i * 4 + 4);
  }
  return 1;
}

function _SDL_MapRGB(fmt, r, g, b) {
  return r + (g << 8) + (b << 16);
}

function _SDL_WM_GrabInput() {}

function _IMG_Load(filename) {
  filename = FS.standardizePath(Pointer_stringify(filename));
  var raw = preloadedImages[filename];
  if (!raw) {
    Module.printErr("Cannot find preloaded image " + filename);
    return 0;
  }
  var surf = SDL.makeSurface(raw.width, raw.height, 0, false, "load:" + filename);
  var surfData = SDL.surfaces[surf];
  surfData.ctx.drawImage(raw, 0, 0, raw.width, raw.height, 0, 0, raw.width, raw.height);
  _SDL_LockSurface(surf);
  surfData.locked--;
  return surf;
}

var _SDL_LoadBMP = _IMG_Load;

function _SDL_OpenAudio(desired, obtained) {
  assert(obtained === 0, "Cannot return obtained SDL audio params");
  SDL.audio = {
    freq: HEAPU32[desired + SDL.structs.AudioSpec.freq >> 2],
    format: HEAPU16[desired + SDL.structs.AudioSpec.format >> 1],
    channels: HEAPU8[desired + SDL.structs.AudioSpec.channels],
    samples: HEAPU16[desired + SDL.structs.AudioSpec.samples >> 1],
    callback: HEAPU32[desired + SDL.structs.AudioSpec.callback >> 2],
    userdata: HEAPU32[desired + SDL.structs.AudioSpec.userdata >> 2],
    paused: true,
    timer: null
  };
  var totalSamples = SDL.audio.samples * SDL.audio.channels;
  SDL.audio.bufferSize = totalSamples * 2;
  SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
  SDL.audio.caller = (function() {
    FUNCTION_TABLE[SDL.audio.callback](SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize);
    SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
  });
  try {
    SDL.audio.mozOutput = new Audio;
    SDL.audio.mozOutput["mozSetup"](SDL.audio.channels, SDL.audio.freq);
    SDL.audio.mozBuffer = new Float32Array(totalSamples);
    SDL.audio.pushAudio = (function(ptr, size) {
      var mozBuffer = SDL.audio.mozBuffer;
      for (var i = 0; i < totalSamples; i++) {
        mozBuffer[i] = HEAP16[ptr + i * 2 >> 1] / 32768;
      }
      SDL.audio.mozOutput["mozWriteAudio"](mozBuffer);
    });
  } catch (e) {
    SDL.audio = null;
  }
  if (!SDL.audio) return -1;
  return 0;
}

function _SDL_PauseAudio(pauseOn) {
  if (SDL.audio.paused !== pauseOn) {
    SDL.audio.timer = pauseOn ? SDL.audio.timer && clearInterval(SDL.audio.timer) : setInterval(SDL.audio.caller, 1 / 35);
  }
  SDL.audio.paused = pauseOn;
}

function _SDL_CloseAudio() {
  if (SDL.audio) {
    _SDL_PauseAudio(1);
    _free(SDL.audio.buffer);
    SDL.audio = null;
  }
}

function _SDL_LockAudio() {}

function _SDL_UnlockAudio() {}

function _SDL_CreateMutex() {
  return 0;
}

function _SDL_LockMutex() {}

function _SDL_UnlockMutex() {}

function _SDL_DestroyMutex() {}

function _SDL_CreateCond() {
  return 0;
}

function _SDL_CondSignal() {}

function _SDL_CondWait() {}

function _SDL_DestroyCond() {}

function _Mix_OpenAudio(frequency, format, channels, chunksize) {
  return 0;
}

var _Mix_CloseAudio = _SDL_CloseAudio;

function _Mix_AllocateChannels(num) {
  return num;
}

function _Mix_ChannelFinished(func) {
  SDL.channelFinished = func;
}

function _Mix_HookMusicFinished(func) {
  SDL.hookMusicFinished = func;
}

function _Mix_VolumeMusic(func) {
  return 0;
}

function _Mix_LoadWAV_RW(filename, freesrc) {
  filename = FS.standardizePath(Pointer_stringify(filename));
  var raw = preloadedAudios[filename];
  if (!raw) {
    Module.printErr("Cannot find preloaded audio " + filename);
    return 0;
  }
  var id = SDL.audios.length;
  SDL.audios.push({
    source: filename,
    audio: raw
  });
  return id;
}

function _Mix_FreeChunk(id) {
  SDL.audios[id].audio.pause();
  SDL.audios[id] = null;
}

function _Mix_PlayChannel(channel, id, loops) {
  var audio = SDL.audios[id].audio;
  if (!audio) return 0;
  if (audio.currentTime) audio.src = audio.src;
  audio.play();
  return 1;
}

var _Mix_PlayChannelTimed = _Mix_PlayChannel;

var _Mix_LoadMUS = _Mix_LoadWAV_RW;

var _Mix_FreeMusic = _Mix_FreeChunk;

function _Mix_PlayMusic(id, loops) {
  loops = Math.max(loops, 1);
  var audio = SDL.audios[id].audio;
  if (!audio) return 0;
  audio.loop = loops != 1;
  audio.play();
  SDL.music = audio;
  return 0;
}

function _Mix_PauseMusic(id) {
  var audio = SDL.audios[id];
  if (!audio) return 0;
  audio.audio.pause();
  return 0;
}

function _Mix_ResumeMusic(id) {
  var audio = SDL.audios[id];
  if (!audio) return 0;
  audio.audio.play();
  return 0;
}

function _Mix_HaltMusic() {
  var audio = SDL.music;
  if (!audio) return 0;
  audio.src = audio.src;
  audio.pause();
  SDL.music = null;
  if (SDL.hookMusicFinished) {
    FUNCTION_TABLE[SDL.hookMusicFinished]();
  }
  return 0;
}

var _Mix_FadeInMusicPos = _Mix_PlayMusic;

var _Mix_FadeOutMusic = _Mix_HaltMusic;

function _TTF_Init() {
  return 0;
}

function _TTF_OpenFont(filename, size) {
  filename = FS.standardizePath(Pointer_stringify(filename));
  var id = SDL.fonts.length;
  SDL.fonts.push({
    name: filename,
    size: size
  });
  return id;
}

function _TTF_RenderText_Solid(font, text, color) {
  text = Pointer_stringify(text) || " ";
  var fontData = SDL.fonts[font];
  var w = SDL.estimateTextWidth(fontData, text);
  var h = fontData.size;
  var color = SDL.loadColorToCSSRGB(color);
  var fontString = h + "px sans-serif";
  var surf = SDL.makeSurface(w, h, 0, false, "text:" + text);
  var surfData = SDL.surfaces[surf];
  surfData.ctx.save();
  surfData.ctx.fillStyle = color;
  surfData.ctx.font = fontString;
  surfData.ctx.textBaseline = "top";
  surfData.ctx.fillText(text, 0, 0);
  surfData.ctx.restore();
  return surf;
}

var _TTF_RenderText_Blended = _TTF_RenderText_Solid;

var _TTF_RenderText_Shaded = _TTF_RenderText_Solid;

function _TTF_SizeText(font, text, w, h) {
  var fontData = SDL.fonts[font];
  if (w) {
    HEAP32[w >> 2] = SDL.estimateTextWidth(fontData, Pointer_stringify(text));
  }
  if (h) {
    HEAP32[h >> 2] = fontData.size;
  }
  return 0;
}

function _TTF_FontAscent(font) {
  var fontData = SDL.fonts[font];
  return Math.floor(fontData.size * .98);
}

function _TTF_FontDescent(font) {
  var fontData = SDL.fonts[font];
  return Math.floor(fontData.size * .02);
}

function _boxRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
  var surfData = SDL.surfaces[surf];
  assert(!surfData.locked);
  surfData.ctx.save();
  surfData.ctx.fillStyle = SDL.translateRGBAToCSSRGBA(r, g, b, a);
  surfData.ctx.fillRect(x1, y1, x2 - x1, y2 - y1);
  surfData.ctx.restore();
}

function _rectangleRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
  var surfData = SDL.surfaces[surf];
  assert(!surfData.locked);
  surfData.ctx.save();
  surfData.ctx.strokeStyle = SDL.translateRGBAToCSSRGBA(r, g, b, a);
  surfData.ctx.strokeRect(x1, y1, x2 - x1, y2 - y1);
  surfData.ctx.restore();
}

function _lineRGBA(surf, x1, y1, x2, y2, r, g, b, a) {
  var surfData = SDL.surfaces[surf];
  assert(!surfData.locked);
  surfData.ctx.save();
  surfData.ctx.strokeStyle = SDL.translateRGBAToCSSRGBA(r, g, b, a);
  surfData.ctx.beginPath();
  surfData.ctx.moveTo(x1, y1);
  surfData.ctx.lineTo(x2, y2);
  surfData.ctx.stroke();
  surfData.ctx.restore();
}

function _pixelRGBA(surf, x1, y1, r, g, b, a) {
  _boxRGBA(surf, x1, y1, x1, y1, r, g, b, a);
}

function _SDL_GL_SetAttribute(attr, value) {
  console.log("TODO: SDL_GL_SetAttribute");
}

var GL = {
  counter: 1,
  buffers: {},
  programs: {},
  framebuffers: {},
  renderbuffers: {},
  textures: {},
  uniforms: {},
  shaders: {},
  packAlignment: 4,
  unpackAlignment: 4,
  scan: (function(table, object) {
    for (var item in table) {
      if (table[item] == object) return item;
    }
    return 0;
  }),
  findToken: (function(source, token) {
    function isIdentChar(ch) {
      if (ch >= 48 && ch <= 57) return true;
      if (ch >= 65 && ch <= 90) return true;
      if (ch >= 97 && ch <= 122) return true;
      return false;
    }
    var i = -1;
    do {
      i = source.indexOf(token, i + 1);
      if (i < 0) {
        break;
      }
      if (i > 0 && isIdentChar(source[i - 1])) {
        continue;
      }
      i += token.length;
      if (i < source.length - 1 && isIdentChar(source[i + 1])) {
        continue;
      }
      return true;
    } while (true);
    return false;
  }),
  getSource: (function(shader, count, string, length) {
    var source = "";
    for (var i = 0; i < count; ++i) {
      var frag;
      if (length) {
        var len = HEAP32[length + i * 4 >> 2];
        if (len < 0) {
          frag = Pointer_stringify(HEAP32[string + i * 4 >> 2]);
        } else {
          frag = Pointer_stringify(HEAP32[string + i * 4 >> 2], len);
        }
      } else {
        frag = Pointer_stringify(HEAP32[string + i * 4 >> 2]);
      }
      source += frag;
    }
    type = Module.ctx.getShaderParameter(GL.shaders[shader], 35663);
    if (type == 35632) {
      if (GL.findToken(source, "dFdx") || GL.findToken(source, "dFdy") || GL.findToken(source, "fwidth")) {
        source = "#extension GL_OES_standard_derivatives : enable\n" + source;
        var extension = Module.ctx.getExtension("OES_standard_derivatives");
      }
    }
    return source;
  }),
  computeImageSize: (function(width, height, sizePerPixel, alignment) {
    function roundedToNextMultipleOf(x, y) {
      return Math.floor((x + y - 1) / y) * y;
    }
    var plainRowSize = width * sizePerPixel;
    var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
    return height <= 0 ? 0 : (height - 1) * alignedRowSize + plainRowSize;
  })
};

function _glPixelStorei(pname, param) {
  if (pname == 3333) {
    GL.packAlignment = param;
  } else if (pname == 3317) {
    GL.unpackAlignment = param;
  }
  Module.ctx.pixelStorei(pname, param);
}

function _glGetString(name_) {
  switch (name_) {
   case 7936:
   case 7937:
   case 7938:
    return allocate(intArrayFromString(Module.ctx.getParameter(name_)), "i8", ALLOC_NORMAL);
   case 7939:
    return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(" ")), "i8", ALLOC_NORMAL);
   default:
    throw "Failure: Invalid glGetString value: " + name_;
  }
}

function _glGetIntegerv(name_, p) {
  var result = Module.ctx.getParameter(name_);
  switch (typeof result) {
   case "number":
    HEAP32[p >> 2] = result;
    break;
   case "boolean":
    HEAP8[p] = result ? 1 : 0;
    break;
   case "string":
    throw "Native code calling glGetIntegerv(" + name_ + ") on a name which returns a string!";
   case "object":
    if (result === null) {
      HEAP32[p >> 2] = 0;
    } else if (result instanceof Float32Array || result instanceof Uint32Array || result instanceof Int32Array || result instanceof Array) {
      for (var i = 0; i < result.length; ++i) {
        HEAP32[p + i * 4 >> 2] = result[i];
      }
    } else if (result instanceof WebGLBuffer) {
      HEAP32[p >> 2] = GL.scan(GL.buffers, result);
    } else if (result instanceof WebGLProgram) {
      HEAP32[p >> 2] = GL.scan(GL.programs, result);
    } else if (result instanceof WebGLFramebuffer) {
      HEAP32[p >> 2] = GL.scan(GL.framebuffers, result);
    } else if (result instanceof WebGLRenderbuffer) {
      HEAP32[p >> 2] = GL.scan(GL.renderbuffers, result);
    } else if (result instanceof WebGLTexture) {
      HEAP32[p >> 2] = GL.scan(GL.textures, result);
    } else {
      throw "Unknown object returned from WebGL getParameter";
    }
    break;
   case "undefined":
    throw "Native code calling glGetIntegerv(" + name_ + ") and it returns undefined";
   default:
    throw "Why did we hit the default case?";
  }
}

function _glGetFloatv(name_, p) {
  var result = Module.ctx.getParameter(name_);
  switch (typeof result) {
   case "number":
    HEAPF32[p >> 2] = result;
    break;
   case "boolean":
    HEAPF32[p >> 2] = result ? 1 : 0;
    break;
   case "string":
    HEAPF32[p >> 2] = 0;
   case "object":
    if (result === null) {
      throw "Native code calling glGetFloatv(" + name_ + ") and it returns null";
    } else if (result instanceof Float32Array || result instanceof Uint32Array || result instanceof Int32Array || result instanceof Array) {
      for (var i = 0; i < result.length; ++i) {
        HEAPF32[p + i * 4 >> 2] = result[i];
      }
    } else if (result instanceof WebGLBuffer) {
      HEAPF32[p >> 2] = GL.scan(GL.buffers, result);
    } else if (result instanceof WebGLProgram) {
      HEAPF32[p >> 2] = GL.scan(GL.programs, result);
    } else if (result instanceof WebGLFramebuffer) {
      HEAPF32[p >> 2] = GL.scan(GL.framebuffers, result);
    } else if (result instanceof WebGLRenderbuffer) {
      HEAPF32[p >> 2] = GL.scan(GL.renderbuffers, result);
    } else if (result instanceof WebGLTexture) {
      HEAPF32[p >> 2] = GL.scan(GL.textures, result);
    } else {
      throw "Unknown object returned from WebGL getParameter";
    }
    break;
   case "undefined":
    throw "Native code calling glGetFloatv(" + name_ + ") and it returns undefined";
   default:
    throw "Why did we hit the default case?";
  }
}

function _glGetBooleanv(name_, p) {
  var result = Module.ctx.getParameter(name_);
  switch (typeof result) {
   case "number":
    HEAP8[p] = result != 0;
    break;
   case "boolean":
    HEAP8[p] = result != 0;
    break;
   case "string":
    throw "Native code calling glGetBooleanv(" + name_ + ") on a name which returns a string!";
   case "object":
    if (result === null) {
      HEAP8[p] = 0;
    } else if (result instanceof Float32Array || result instanceof Uint32Array || result instanceof Int32Array || result instanceof Array) {
      for (var i = 0; i < result.length; ++i) {
        HEAP8[p + i] = result[i] != 0;
      }
    } else if (result instanceof WebGLBuffer || result instanceof WebGLProgram || result instanceof WebGLFramebuffer || result instanceof WebGLRenderbuffer || result instanceof WebGLTexture) {
      HEAP8[p] = 1;
    } else {
      throw "Unknown object returned from WebGL getParameter";
    }
    break;
   case "undefined":
    throw "Unknown object returned from WebGL getParameter";
   default:
    throw "Why did we hit the default case?";
  }
}

function _glGenTextures(n, textures) {
  for (var i = 0; i < n; i++) {
    var id = GL.counter++;
    GL.textures[id] = Module.ctx.createTexture();
    HEAP32[textures + i * 4 >> 2] = id;
  }
}

function _glDeleteTextures(n, textures) {
  for (var i = 0; i < n; i++) {
    var id = HEAP32[textures + i * 4 >> 2];
    Module.ctx.deleteTexture(GL.textures[id]);
    GL.textures[id] = null;
  }
}

function _glCompressedTexImage2D(target, level, internalformat, width, height, border, imageSize, data) {
  if (data) {
    data = HEAPU8.subarray(data, data + imageSize);
  } else {
    data = null;
  }
  Module.ctx.compressedTexImage2D(target, level, internalformat, width, height, border, data);
}

function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
  if (data) {
    data = HEAPU8.subarray(data, data + imageSize);
  } else {
    data = null;
  }
  Module.ctx.compressedTexSubImage2D(target, level, xoffset, yoffset, width, height, data);
}

function _glTexImage2D(target, level, internalformat, width, height, border, format, type, pixels) {
  if (pixels) {
    var sizePerPixel;
    switch (type) {
     case 5121:
      switch (format) {
       case 6406:
       case 6409:
        sizePerPixel = 1;
        break;
       case 6407:
        sizePerPixel = 3;
        break;
       case 6408:
        sizePerPixel = 4;
        break;
       case 6410:
        sizePerPixel = 2;
        break;
       default:
        throw "Invalid format (" + format + ") passed to glTexImage2D";
      }
      break;
     case 33635:
     case 32819:
     case 32820:
      sizePerPixel = 2;
      break;
     default:
      throw "Invalid type (" + type + ") passed to glTexImage2D";
    }
    var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
    pixels = HEAPU8.subarray(pixels, pixels + bytes);
  } else {
    pixels = null;
  }
  Module.ctx.texImage2D(target, level, internalformat, width, height, border, format, type, pixels);
}

function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
  if (pixels) {
    var sizePerPixel;
    switch (type) {
     case 5121:
      switch (format) {
       case 6406:
       case 6409:
        sizePerPixel = 1;
        break;
       case 6407:
        sizePerPixel = 3;
        break;
       case 6408:
        sizePerPixel = 4;
        break;
       case 6410:
        sizePerPixel = 2;
        break;
       default:
        throw "Invalid format (" + format + ") passed to glTexSubImage2D";
      }
      break;
     case 33635:
     case 32819:
     case 32820:
      sizePerPixel = 2;
      break;
     default:
      throw "Invalid type (" + type + ") passed to glTexSubImage2D";
    }
    var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
    pixels = HEAPU8.subarray(pixels, pixels + bytes);
  } else {
    pixels = null;
  }
  Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
}

function _glReadPixels(x, y, width, height, format, type, pixels) {
  Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels));
}

function _glBindTexture(target, texture) {
  Module.ctx.bindTexture(target, GL.textures[texture]);
}

function _glGetTexParameterfv(target, pname, params) {
  HEAPF32[params >> 2] = Module.getTexParameter(target, pname);
}

function _glGetTexParameteriv(target, pname, params) {
  HEAP32[params >> 2] = Module.getTexParameter(target, pname);
}

function _glIsTexture(texture) {
  var fb = GL.textures[texture];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isTexture(fb);
}

function _glGenBuffers(n, buffers) {
  for (var i = 0; i < n; i++) {
    var id = GL.counter++;
    GL.buffers[id] = Module.ctx.createBuffer();
    HEAP32[buffers + i * 4 >> 2] = id;
  }
}

function _glDeleteBuffers(n, buffers) {
  for (var i = 0; i < n; i++) {
    var id = HEAP32[buffers + i * 4 >> 2];
    Module.ctx.deleteBuffer(GL.buffers[id]);
    GL.buffers[id] = null;
  }
}

function _glGetBufferParameteriv(target, value, data) {
  HEAP32[data >> 2] = Module.ctx.getBufferParameter(target, value);
}

function _glBufferData(target, size, data, usage) {
  Module.ctx.bufferData(target, HEAPU8.subarray(data, data + size), usage);
}

function _glBufferSubData(target, offset, size, data) {
  var floatArray = HEAPF32.subarray(data >> 2, data + size >> 2);
  Module.ctx.bufferSubData(target, offset, floatArray);
}

function _glIsBuffer(buffer) {
  var fb = GL.buffers[buffer];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isBuffer(fb);
}

function _glGenRenderbuffers(n, renderbuffers) {
  for (var i = 0; i < n; i++) {
    var id = GL.counter++;
    GL.renderbuffers[id] = Module.ctx.createRenderbuffer();
    HEAP32[renderbuffers + i * 4 >> 2] = id;
  }
}

function _glDeleteRenderbuffers(n, renderbuffers) {
  for (var i = 0; i < n; i++) {
    var id = HEAP32[renderbuffers + i * 4 >> 2];
    Module.ctx.deleteRenderbuffer(GL.renderbuffers[id]);
    GL.renderbuffers[id];
  }
}

function _glBindRenderbuffer(target, renderbuffer) {
  Module.ctx.bindRenderbuffer(target, GL.renderbuffers[renderbuffer]);
}

function _glGetRenderbufferParameteriv(target, pname, params) {
  HEAP32[params >> 2] = Module.ctx.getRenderbufferParameter(target, pname);
}

function _glIsRenderbuffer(renderbuffer) {
  var fb = GL.renderbuffers[renderbuffer];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isRenderbuffer(fb);
}

function _glGetUniformfv(program, location, params) {
  var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
  if (typeof data == "number") {
    HEAPF32[params >> 2] = data;
  } else {
    for (var i = 0; i < data.length; i++) {
      HEAPF32[params + i >> 2] = data[i];
    }
  }
}

function _glGetUniformiv(program, location, params) {
  var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
  if (typeof data == "number" || typeof data == "boolean") {
    HEAP32[params >> 2] = data;
  } else {
    for (var i = 0; i < data.length; i++) {
      HEAP32[params + i >> 2] = data[i];
    }
  }
}

function _glGetUniformLocation(program, name) {
  name = Pointer_stringify(name);
  var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
  if (!loc) return -1;
  var id = GL.counter++;
  GL.uniforms[id] = loc;
  return id;
}

function _glGetVertexAttribfv(index, pname, params) {
  var data = Module.ctx.getVertexAttrib(index, pname);
  if (typeof data == "number") {
    HEAPF32[params >> 2] = data;
  } else {
    for (var i = 0; i < data.length; i++) {
      HEAPF32[params + i >> 2] = data[i];
    }
  }
}

function _glGetVertexAttribiv(index, pname, params) {
  var data = Module.ctx.getVertexAttrib(index, pname);
  if (typeof data == "number" || typeof data == "boolean") {
    HEAP32[params >> 2] = data;
  } else {
    for (var i = 0; i < data.length; i++) {
      HEAP32[params + i >> 2] = data[i];
    }
  }
}

function _glGetVertexAttribPointerv(index, pname, pointer) {
  HEAP32[pointer >> 2] = Module.ctx.getVertexAttribOffset(index, pname);
}

function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
  program = GL.programs[program];
  var info = Module.ctx.getActiveUniform(program, index);
  var infoname = info.name.slice(0, bufSize - 1);
  writeStringToMemory(infoname, name);
  if (length) {
    HEAP32[length >> 2] = infoname.length;
  }
  if (size) {
    HEAP32[size >> 2] = info.size;
  }
  if (type) {
    HEAP32[type >> 2] = info.type;
  }
}

function _glUniform1f(location, v0) {
  location = GL.uniforms[location];
  Module.ctx.uniform1f(location, v0);
}

function _glUniform2f(location, v0, v1) {
  location = GL.uniforms[location];
  Module.ctx.uniform2f(location, v0, v1);
}

function _glUniform3f(location, v0, v1, v2) {
  location = GL.uniforms[location];
  Module.ctx.uniform3f(location, v0, v1, v2);
}

function _glUniform4f(location, v0, v1, v2, v3) {
  location = GL.uniforms[location];
  Module.ctx.uniform4f(location, v0, v1, v2, v3);
}

function _glUniform1i(location, v0) {
  location = GL.uniforms[location];
  Module.ctx.uniform1i(location, v0);
}

function _glUniform2i(location, v0, v1) {
  location = GL.uniforms[location];
  Module.ctx.uniform2i(location, v0, v1);
}

function _glUniform3i(location, v0, v1, v2) {
  location = GL.uniforms[location];
  Module.ctx.uniform3i(location, v0, v1, v2);
}

function _glUniform4i(location, v0, v1, v2, v3) {
  location = GL.uniforms[location];
  Module.ctx.uniform4i(location, v0, v1, v2, v3);
}

function _glUniform1iv(location, count, value) {
  location = GL.uniforms[location];
  value = HEAP32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform1iv(location, value);
}

function _glUniform2iv(location, count, value) {
  location = GL.uniforms[location];
  count *= 2;
  value = HEAP32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform2iv(location, value);
}

function _glUniform3iv(location, count, value) {
  location = GL.uniforms[location];
  count *= 3;
  value = HEAP32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform3iv(location, value);
}

function _glUniform4iv(location, count, value) {
  location = GL.uniforms[location];
  count *= 4;
  value = HEAP32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform4iv(location, value);
}

function _glUniform1fv(location, count, value) {
  location = GL.uniforms[location];
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform1fv(location, value);
}

function _glUniform2fv(location, count, value) {
  location = GL.uniforms[location];
  count *= 2;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform2fv(location, value);
}

function _glUniform3fv(location, count, value) {
  location = GL.uniforms[location];
  count *= 3;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform3fv(location, value);
}

function _glUniform4fv(location, count, value) {
  location = GL.uniforms[location];
  count *= 4;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniform4fv(location, value);
}

function _glUniformMatrix2fv(location, count, transpose, value) {
  location = GL.uniforms[location];
  count *= 4;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniformMatrix2fv(location, transpose, value);
}

function _glUniformMatrix3fv(location, count, transpose, value) {
  location = GL.uniforms[location];
  count *= 9;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniformMatrix3fv(location, transpose, value);
}

function _glUniformMatrix4fv(location, count, transpose, value) {
  location = GL.uniforms[location];
  count *= 16;
  value = HEAPF32.subarray(value >> 2, value + count * 4 >> 2);
  Module.ctx.uniformMatrix4fv(location, transpose, value);
}

function _glBindBuffer(target, buffer) {
  Module.ctx.bindBuffer(target, GL.buffers[buffer]);
}

function _glVertexAttrib1fv(index, v) {
  v = HEAPF32.subarray(v >> 2, v + 1 * 4 >> 2);
  Module.ctx.vertexAttrib1fv(index, v);
}

function _glVertexAttrib2fv(index, v) {
  v = HEAPF32.subarray(v >> 2, v + 2 * 4 >> 2);
  Module.ctx.vertexAttrib2fv(index, v);
}

function _glVertexAttrib3fv(index, v) {
  v = HEAPF32.subarray(v >> 2, v + 3 * 4 >> 2);
  Module.ctx.vertexAttrib3fv(index, v);
}

function _glVertexAttrib4fv(index, v) {
  v = HEAPF32.subarray(v >> 2, v + 4 * 4 >> 2);
  Module.ctx.vertexAttrib4fv(index, v);
}

function _glGetAttribLocation(program, name) {
  program = GL.programs[program];
  name = Pointer_stringify(name);
  return Module.ctx.getAttribLocation(program, name);
}

function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
  program = GL.programs[program];
  var info = Module.ctx.getActiveAttrib(program, index);
  var infoname = info.name.slice(0, bufSize - 1);
  writeStringToMemory(infoname, name);
  if (length) {
    HEAP32[length >> 2] = infoname.length;
  }
  if (size) {
    HEAP32[size >> 2] = info.size;
  }
  if (type) {
    HEAP32[type >> 2] = info.type;
  }
}

function _glCreateShader(shaderType) {
  var id = GL.counter++;
  GL.shaders[id] = Module.ctx.createShader(shaderType);
  return id;
}

function _glDeleteShader(shader) {
  Module.ctx.deleteShader(GL.shaders[shader]);
  GL.shaders[shader] = null;
}

function _glDetachShader(program, shader) {
  Module.ctx.detachShader(GL.programs[program], GL.shaders[shader]);
}

function _glGetAttachedShaders(program, maxCount, count, shaders) {
  var result = Module.ctx.getAttachedShaders(GL.programs[program]);
  var len = result.length;
  if (len > maxCount) {
    len = maxCount;
  }
  HEAP32[count >> 2] = len;
  for (var i = 0; i < len; ++i) {
    HEAP32[shaders + i * 4 >> 2] = GL.shaders[result[i]];
  }
}

function _glShaderSource(shader, count, string, length) {
  var source = GL.getSource(shader, count, string, length);
  Module.ctx.shaderSource(GL.shaders[shader], source);
}

function _glGetShaderSource(shader, bufSize, length, source) {
  var result = Module.ctx.getShaderSource(GL.shaders[shader]);
  result.slice(0, bufSize - 1);
  writeStringToMemory(result, source);
  if (length) {
    HEAP32[length >> 2] = result.length;
  }
}

function _glCompileShader(shader) {
  Module.ctx.compileShader(GL.shaders[shader]);
}

function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
  var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
  if (!log) {
    log = "";
  }
  log = log.substr(0, maxLength - 1);
  writeStringToMemory(log, infoLog);
  if (length) {
    HEAP32[length >> 2] = log.length;
  }
}

function _glGetShaderiv(shader, pname, p) {
  HEAP32[p >> 2] = Module.ctx.getShaderParameter(GL.shaders[shader], pname);
}

function _glGetProgramiv(program, pname, p) {
  HEAP32[p >> 2] = Module.ctx.getProgramParameter(GL.programs[program], pname);
}

function _glIsShader(shader) {
  var fb = GL.shaders[shader];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isShader(fb);
}

function _glCreateProgram() {
  var id = GL.counter++;
  GL.programs[id] = Module.ctx.createProgram();
  return id;
}

function _glDeleteProgram(program) {
  Module.ctx.deleteProgram(GL.programs[program]);
  GL.programs[program] = null;
}

function _glAttachShader(program, shader) {
  Module.ctx.attachShader(GL.programs[program], GL.shaders[shader]);
}

function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
  var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
  HEAP32[range >> 2] = result.rangeMin;
  HEAP32[range + 4 >> 2] = result.rangeMax;
  HEAP32[precision >> 2] = result.precision;
}

function _glLinkProgram(program) {
  Module.ctx.linkProgram(GL.programs[program]);
}

function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
  var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
  if (!log) {
    log = "";
  }
  log = log.substr(0, maxLength - 1);
  writeStringToMemory(log, infoLog);
  if (length) {
    HEAP32[length >> 2] = log.length;
  }
}

function _glUseProgram(program) {
  Module.ctx.useProgram(GL.programs[program]);
}

function _glValidateProgram(program) {
  Module.ctx.validateProgram(GL.programs[program]);
}

function _glIsProgram(program) {
  var fb = GL.programs[program];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isProgram(fb);
}

function _glBindAttribLocation(program, index, name) {
  name = Pointer_stringify(name);
  Module.ctx.bindAttribLocation(GL.programs[program], index, name);
}

function _glBindFramebuffer(target, framebuffer) {
  Module.ctx.bindFramebuffer(target, GL.framebuffers[framebuffer]);
}

function _glGenFramebuffers(n, ids) {
  for (var i = 0; i < n; ++i) {
    var id = GL.counter++;
    GL.framebuffers[id] = Module.ctx.createFramebuffer();
    HEAP32[ids + i * 4 >> 2] = id;
  }
}

function _glDeleteFramebuffers(n, framebuffers) {
  for (var i = 0; i < n; ++i) {
    var id = HEAP32[framebuffers + i * 4 >> 2];
    Module.ctx.deleteFramebuffer(GL.framebuffers[id]);
    GL.framebuffers[id] = null;
  }
}

function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
  Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget, GL.renderbuffers[renderbuffer]);
}

function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
  Module.ctx.framebufferTexture2D(target, attachment, textarget, GL.textures[texture], level);
}

function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
  var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
  HEAP32[params >> 2] = params;
}

function _glIsFramebuffer(framebuffer) {
  var fb = GL.framebuffers[framebuffer];
  if (typeof fb == "undefined") {
    return 0;
  }
  return Module.ctx.isFramebuffer(fb);
}

var GLImmediate = {
  maxElements: 1024,
  vertexData: null,
  tempData: null,
  indexData: null,
  vertexCounter: 0,
  mode: 0,
  renderers: {},
  renderer: null,
  matrix: {
    m: null,
    p: null
  },
  matrixStack: {
    m: [],
    p: []
  },
  currentMatrix: "m",
  tempMatrix: null,
  initMatrixLibrary: (function() {
    GL.immediate.matrix["m"] = GL.immediate.matrix.lib.mat4.create();
    GL.immediate.matrix["p"] = GL.immediate.matrix.lib.mat4.create();
    GL.immediate.currentMatrix = GL.immediate.matrix.lib.mat4.create();
  }),
  TEXTURE: 0,
  VERTEX: 1,
  NUM_ATTRIBUTES: 2,
  ATTRIBUTE_BY_NAME: {
    T: 0,
    V: 1
  },
  totalEnabledClientAttributes: 0,
  enabledClientAttributes: [ 0, 0 ],
  clientAttributes: [ null, null ],
  setClientAttribute: (function(which, name, size, type, stride, pointer) {
    this.clientAttributes[which] = {
      size: size,
      type: type,
      stride: stride,
      pointer: pointer,
      name: name + size
    };
  }),
  setRenderer: (function(renderer) {
    this.renderer = renderer;
    if (this.renderers[renderer]) return;
    var vertexSize = 0, positionSize = 0, positionOffset = 0, textureSize = 0, textureOffset = 0;
    for (var i = 0; i < renderer.length; i += 2) {
      var which = renderer[i];
      var size = parseInt(renderer[i + 1]);
      if (which == "V") {
        positionSize = size;
        positionOffset = vertexSize;
      } else if (which == "T") {
        textureSize = size;
        textureOffset = vertexSize;
      } else {
        throw "Cannot create shader rendederer for " + renderer;
      }
      vertexSize += size * 4;
    }
    assert(positionSize > 0);
    assert(textureSize > 0);
    this.renderers[renderer] = {
      vertexSize: vertexSize,
      init: (function() {
        this.vertexShader = Module.ctx.createShader(Module.ctx.VERTEX_SHADER);
        var zero = positionSize == 2 ? "0, " : "";
        Module.ctx.shaderSource(this.vertexShader, "attribute vec" + positionSize + " a_position;  \n                                                        attribute vec2 a_texCoord;  \n                                                        varying vec2 v_texCoord;    \n                                                        uniform mat4 u_modelView;   \n                                                        uniform mat4 u_projection;  \n                                                        void main()                 \n                                                        {                           \n                                                          gl_Position = u_projection * (u_modelView * vec4(a_position, " + zero + "1.0)); \n                                                          v_texCoord = a_texCoord;  \n                                                        }                           \n");
        Module.ctx.compileShader(this.vertexShader);
        this.fragmentShader = Module.ctx.createShader(Module.ctx.FRAGMENT_SHADER);
        Module.ctx.shaderSource(this.fragmentShader, "precision mediump float;                            \n                                                          varying vec2 v_texCoord;                            \n                                                          uniform sampler2D s_texture;                        \n                                                          void main()                                         \n                                                          {                                                   \n                                                            gl_FragColor = texture2D( s_texture, v_texCoord );\n                                                          }                                                   \n");
        Module.ctx.compileShader(this.fragmentShader);
        this.program = Module.ctx.createProgram();
        Module.ctx.attachShader(this.program, this.vertexShader);
        Module.ctx.attachShader(this.program, this.fragmentShader);
        Module.ctx.linkProgram(this.program);
        this.positionLocation = Module.ctx.getAttribLocation(this.program, "a_position");
        this.texCoordLocation = Module.ctx.getAttribLocation(this.program, "a_texCoord");
        this.textureLocation = Module.ctx.getUniformLocation(this.program, "s_texture");
        this.modelViewLocation = Module.ctx.getUniformLocation(this.program, "u_modelView");
        this.projectionLocation = Module.ctx.getUniformLocation(this.program, "u_projection");
      }),
      prepare: (function() {
        Module.ctx.vertexAttribPointer(this.texCoordLocation, textureSize, Module.ctx.FLOAT, false, vertexSize, textureOffset);
        Module.ctx.vertexAttribPointer(this.positionLocation, positionSize, Module.ctx.FLOAT, false, vertexSize, positionOffset);
        Module.ctx.enableVertexAttribArray(this.texCoordLocation);
        Module.ctx.enableVertexAttribArray(this.positionLocation);
        var texture = Module.ctx.getParameter(Module.ctx.TEXTURE_BINDING_2D);
        Module.ctx.activeTexture(Module.ctx.TEXTURE0);
        Module.ctx.bindTexture(Module.ctx.TEXTURE_2D, texture);
        Module.ctx.uniform1i(this.textureLocation, 0);
        Module.ctx.uniformMatrix4fv(this.modelViewLocation, false, GL.immediate.matrix["m"]);
        Module.ctx.uniformMatrix4fv(this.projectionLocation, false, GL.immediate.matrix["p"]);
      })
    };
    this.renderers[renderer].init();
  }),
  initted: false,
  init: (function() {
    Module.printErr("WARNING: using emscripten GL immediate mode emulation. This is very limited in what it supports");
    GL.immediate.initted = true;
    this.tempData = new Float32Array(this.maxElements);
    this.indexData = new Uint16Array(this.maxElements);
    this.vertexObject = Module.ctx.createBuffer();
    this.indexObject = Module.ctx.createBuffer();
    _glDrawArrays = (function(mode, first, count) {
      if (GL.immediate.totalEnabledClientAttributes == 0) {
        Module.ctx.drawArrays(mode, first, count);
        return;
      }
      var stride = 0, bytes = 0, attributes = [], start, renderer = "";
      for (var i = 0; i < GL.immediate.NUM_ATTRIBUTES; i++) {
        if (GL.immediate.enabledClientAttributes[i]) attributes.push(GL.immediate.clientAttributes[i]);
      }
      attributes.sort((function(x, y) {
        return x.pointer - y.pointer;
      }));
      start = attributes[0].pointer;
      for (var i = 0; i < attributes.length; i++) {
        var attribute = attributes[i];
        stride = attribute.stride;
        bytes += attribute.size * 4 * count;
        renderer += attribute.name;
      }
      for (var i = 0; i < attributes.length; i++) {
        var attribute = attributes[i];
        attribute.offset = attribute.pointer - start;
      }
      GL.immediate.vertexData = HEAPF32.subarray(start >> 2, start + bytes >> 2);
      GL.immediate.vertexCounter = bytes / 4;
      GL.immediate.mode = mode;
      GL.immediate.setRenderer(renderer);
      GL.immediate.flush();
    });
  }),
  flush: (function() {
    var renderer = this.renderers[this.renderer];
    var numVertexes = 4 * this.vertexCounter / renderer.vertexSize;
    assert(numVertexes % 1 == 0);
    var numIndexes = 0;
    if (GL.immediate.mode == 7) {
      var numQuads = numVertexes / 4;
      assert(numQuads % 1 == 0);
      for (var i = 0; i < numQuads; i++) {
        var start = i * 4;
        GL.immediate.indexData[numIndexes++] = start;
        GL.immediate.indexData[numIndexes++] = start + 1;
        GL.immediate.indexData[numIndexes++] = start + 2;
        GL.immediate.indexData[numIndexes++] = start;
        GL.immediate.indexData[numIndexes++] = start + 2;
        GL.immediate.indexData[numIndexes++] = start + 3;
      }
    } else if (GL.immediate.mode == 5) {
      var numTriangles = numVertexes - 2;
      assert(numTriangles > 0);
      for (var i = 0; i < numTriangles; i++) {
        if (i % 2 == 0) {
          GL.immediate.indexData[numIndexes++] = i;
          GL.immediate.indexData[numIndexes++] = i + 1;
          GL.immediate.indexData[numIndexes++] = i + 2;
        } else {
          GL.immediate.indexData[numIndexes++] = i + 1;
          GL.immediate.indexData[numIndexes++] = i;
          GL.immediate.indexData[numIndexes++] = i + 2;
        }
      }
    } else {
      throw "unsupported immediate mode " + GL.immediate.mode;
    }
    assert(numIndexes < GL.immediate.maxElements, "too many immediate mode indexes");
    Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, this.vertexObject);
    Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, this.vertexData.subarray(0, this.vertexCounter), Module.ctx.STATIC_DRAW);
    Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, this.indexObject);
    Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, this.indexData.subarray(0, numIndexes), Module.ctx.STATIC_DRAW);
    Module.ctx.useProgram(renderer.program);
    Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, this.vertexObject);
    renderer.prepare();
    Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, this.indexObject);
    Module.ctx.drawElements(Module.ctx.TRIANGLES, numIndexes, Module.ctx.UNSIGNED_SHORT, 0);
    this.vertexCounter = 0;
  })
};

GL.immediate = GLImmediate;

GL.immediate.matrix.lib = (function() {
  var vec3 = {};
  var mat3 = {};
  var mat4 = {};
  var quat4 = {};
  var MatrixArray = Float32Array;
  vec3.create = (function(vec) {
    var dest = new MatrixArray(3);
    if (vec) {
      dest[0] = vec[0];
      dest[1] = vec[1];
      dest[2] = vec[2];
    } else {
      dest[0] = dest[1] = dest[2] = 0;
    }
    return dest;
  });
  vec3.set = (function(vec, dest) {
    dest[0] = vec[0];
    dest[1] = vec[1];
    dest[2] = vec[2];
    return dest;
  });
  vec3.add = (function(vec, vec2, dest) {
    if (!dest || vec === dest) {
      vec[0] += vec2[0];
      vec[1] += vec2[1];
      vec[2] += vec2[2];
      return vec;
    }
    dest[0] = vec[0] + vec2[0];
    dest[1] = vec[1] + vec2[1];
    dest[2] = vec[2] + vec2[2];
    return dest;
  });
  vec3.subtract = (function(vec, vec2, dest) {
    if (!dest || vec === dest) {
      vec[0] -= vec2[0];
      vec[1] -= vec2[1];
      vec[2] -= vec2[2];
      return vec;
    }
    dest[0] = vec[0] - vec2[0];
    dest[1] = vec[1] - vec2[1];
    dest[2] = vec[2] - vec2[2];
    return dest;
  });
  vec3.multiply = (function(vec, vec2, dest) {
    if (!dest || vec === dest) {
      vec[0] *= vec2[0];
      vec[1] *= vec2[1];
      vec[2] *= vec2[2];
      return vec;
    }
    dest[0] = vec[0] * vec2[0];
    dest[1] = vec[1] * vec2[1];
    dest[2] = vec[2] * vec2[2];
    return dest;
  });
  vec3.negate = (function(vec, dest) {
    if (!dest) {
      dest = vec;
    }
    dest[0] = -vec[0];
    dest[1] = -vec[1];
    dest[2] = -vec[2];
    return dest;
  });
  vec3.scale = (function(vec, val, dest) {
    if (!dest || vec === dest) {
      vec[0] *= val;
      vec[1] *= val;
      vec[2] *= val;
      return vec;
    }
    dest[0] = vec[0] * val;
    dest[1] = vec[1] * val;
    dest[2] = vec[2] * val;
    return dest;
  });
  vec3.normalize = (function(vec, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0], y = vec[1], z = vec[2], len = Math.sqrt(x * x + y * y + z * z);
    if (!len) {
      dest[0] = 0;
      dest[1] = 0;
      dest[2] = 0;
      return dest;
    } else if (len === 1) {
      dest[0] = x;
      dest[1] = y;
      dest[2] = z;
      return dest;
    }
    len = 1 / len;
    dest[0] = x * len;
    dest[1] = y * len;
    dest[2] = z * len;
    return dest;
  });
  vec3.cross = (function(vec, vec2, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0], y = vec[1], z = vec[2], x2 = vec2[0], y2 = vec2[1], z2 = vec2[2];
    dest[0] = y * z2 - z * y2;
    dest[1] = z * x2 - x * z2;
    dest[2] = x * y2 - y * x2;
    return dest;
  });
  vec3.length = (function(vec) {
    var x = vec[0], y = vec[1], z = vec[2];
    return Math.sqrt(x * x + y * y + z * z);
  });
  vec3.dot = (function(vec, vec2) {
    return vec[0] * vec2[0] + vec[1] * vec2[1] + vec[2] * vec2[2];
  });
  vec3.direction = (function(vec, vec2, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0] - vec2[0], y = vec[1] - vec2[1], z = vec[2] - vec2[2], len = Math.sqrt(x * x + y * y + z * z);
    if (!len) {
      dest[0] = 0;
      dest[1] = 0;
      dest[2] = 0;
      return dest;
    }
    len = 1 / len;
    dest[0] = x * len;
    dest[1] = y * len;
    dest[2] = z * len;
    return dest;
  });
  vec3.lerp = (function(vec, vec2, lerp, dest) {
    if (!dest) {
      dest = vec;
    }
    dest[0] = vec[0] + lerp * (vec2[0] - vec[0]);
    dest[1] = vec[1] + lerp * (vec2[1] - vec[1]);
    dest[2] = vec[2] + lerp * (vec2[2] - vec[2]);
    return dest;
  });
  vec3.dist = (function(vec, vec2) {
    var x = vec2[0] - vec[0], y = vec2[1] - vec[1], z = vec2[2] - vec[2];
    return Math.sqrt(x * x + y * y + z * z);
  });
  vec3.unproject = (function(vec, view, proj, viewport, dest) {
    if (!dest) {
      dest = vec;
    }
    var m = mat4.create();
    var v = new MatrixArray(4);
    v[0] = (vec[0] - viewport[0]) * 2 / viewport[2] - 1;
    v[1] = (vec[1] - viewport[1]) * 2 / viewport[3] - 1;
    v[2] = 2 * vec[2] - 1;
    v[3] = 1;
    mat4.multiply(proj, view, m);
    if (!mat4.inverse(m)) {
      return null;
    }
    mat4.multiplyVec4(m, v);
    if (v[3] === 0) {
      return null;
    }
    dest[0] = v[0] / v[3];
    dest[1] = v[1] / v[3];
    dest[2] = v[2] / v[3];
    return dest;
  });
  vec3.str = (function(vec) {
    return "[" + vec[0] + ", " + vec[1] + ", " + vec[2] + "]";
  });
  mat3.create = (function(mat) {
    var dest = new MatrixArray(9);
    if (mat) {
      dest[0] = mat[0];
      dest[1] = mat[1];
      dest[2] = mat[2];
      dest[3] = mat[3];
      dest[4] = mat[4];
      dest[5] = mat[5];
      dest[6] = mat[6];
      dest[7] = mat[7];
      dest[8] = mat[8];
    }
    return dest;
  });
  mat3.set = (function(mat, dest) {
    dest[0] = mat[0];
    dest[1] = mat[1];
    dest[2] = mat[2];
    dest[3] = mat[3];
    dest[4] = mat[4];
    dest[5] = mat[5];
    dest[6] = mat[6];
    dest[7] = mat[7];
    dest[8] = mat[8];
    return dest;
  });
  mat3.identity = (function(dest) {
    if (!dest) {
      dest = mat3.create();
    }
    dest[0] = 1;
    dest[1] = 0;
    dest[2] = 0;
    dest[3] = 0;
    dest[4] = 1;
    dest[5] = 0;
    dest[6] = 0;
    dest[7] = 0;
    dest[8] = 1;
    return dest;
  });
  mat3.transpose = (function(mat, dest) {
    if (!dest || mat === dest) {
      var a01 = mat[1], a02 = mat[2], a12 = mat[5];
      mat[1] = mat[3];
      mat[2] = mat[6];
      mat[3] = a01;
      mat[5] = mat[7];
      mat[6] = a02;
      mat[7] = a12;
      return mat;
    }
    dest[0] = mat[0];
    dest[1] = mat[3];
    dest[2] = mat[6];
    dest[3] = mat[1];
    dest[4] = mat[4];
    dest[5] = mat[7];
    dest[6] = mat[2];
    dest[7] = mat[5];
    dest[8] = mat[8];
    return dest;
  });
  mat3.toMat4 = (function(mat, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    dest[15] = 1;
    dest[14] = 0;
    dest[13] = 0;
    dest[12] = 0;
    dest[11] = 0;
    dest[10] = mat[8];
    dest[9] = mat[7];
    dest[8] = mat[6];
    dest[7] = 0;
    dest[6] = mat[5];
    dest[5] = mat[4];
    dest[4] = mat[3];
    dest[3] = 0;
    dest[2] = mat[2];
    dest[1] = mat[1];
    dest[0] = mat[0];
    return dest;
  });
  mat3.str = (function(mat) {
    return "[" + mat[0] + ", " + mat[1] + ", " + mat[2] + ", " + mat[3] + ", " + mat[4] + ", " + mat[5] + ", " + mat[6] + ", " + mat[7] + ", " + mat[8] + "]";
  });
  mat4.create = (function(mat) {
    var dest = new MatrixArray(16);
    if (mat) {
      dest[0] = mat[0];
      dest[1] = mat[1];
      dest[2] = mat[2];
      dest[3] = mat[3];
      dest[4] = mat[4];
      dest[5] = mat[5];
      dest[6] = mat[6];
      dest[7] = mat[7];
      dest[8] = mat[8];
      dest[9] = mat[9];
      dest[10] = mat[10];
      dest[11] = mat[11];
      dest[12] = mat[12];
      dest[13] = mat[13];
      dest[14] = mat[14];
      dest[15] = mat[15];
    }
    return dest;
  });
  mat4.set = (function(mat, dest) {
    dest[0] = mat[0];
    dest[1] = mat[1];
    dest[2] = mat[2];
    dest[3] = mat[3];
    dest[4] = mat[4];
    dest[5] = mat[5];
    dest[6] = mat[6];
    dest[7] = mat[7];
    dest[8] = mat[8];
    dest[9] = mat[9];
    dest[10] = mat[10];
    dest[11] = mat[11];
    dest[12] = mat[12];
    dest[13] = mat[13];
    dest[14] = mat[14];
    dest[15] = mat[15];
    return dest;
  });
  mat4.identity = (function(dest) {
    if (!dest) {
      dest = mat4.create();
    }
    dest[0] = 1;
    dest[1] = 0;
    dest[2] = 0;
    dest[3] = 0;
    dest[4] = 0;
    dest[5] = 1;
    dest[6] = 0;
    dest[7] = 0;
    dest[8] = 0;
    dest[9] = 0;
    dest[10] = 1;
    dest[11] = 0;
    dest[12] = 0;
    dest[13] = 0;
    dest[14] = 0;
    dest[15] = 1;
    return dest;
  });
  mat4.transpose = (function(mat, dest) {
    if (!dest || mat === dest) {
      var a01 = mat[1], a02 = mat[2], a03 = mat[3], a12 = mat[6], a13 = mat[7], a23 = mat[11];
      mat[1] = mat[4];
      mat[2] = mat[8];
      mat[3] = mat[12];
      mat[4] = a01;
      mat[6] = mat[9];
      mat[7] = mat[13];
      mat[8] = a02;
      mat[9] = a12;
      mat[11] = mat[14];
      mat[12] = a03;
      mat[13] = a13;
      mat[14] = a23;
      return mat;
    }
    dest[0] = mat[0];
    dest[1] = mat[4];
    dest[2] = mat[8];
    dest[3] = mat[12];
    dest[4] = mat[1];
    dest[5] = mat[5];
    dest[6] = mat[9];
    dest[7] = mat[13];
    dest[8] = mat[2];
    dest[9] = mat[6];
    dest[10] = mat[10];
    dest[11] = mat[14];
    dest[12] = mat[3];
    dest[13] = mat[7];
    dest[14] = mat[11];
    dest[15] = mat[15];
    return dest;
  });
  mat4.determinant = (function(mat) {
    var a00 = mat[0], a01 = mat[1], a02 = mat[2], a03 = mat[3], a10 = mat[4], a11 = mat[5], a12 = mat[6], a13 = mat[7], a20 = mat[8], a21 = mat[9], a22 = mat[10], a23 = mat[11], a30 = mat[12], a31 = mat[13], a32 = mat[14], a33 = mat[15];
    return a30 * a21 * a12 * a03 - a20 * a31 * a12 * a03 - a30 * a11 * a22 * a03 + a10 * a31 * a22 * a03 + a20 * a11 * a32 * a03 - a10 * a21 * a32 * a03 - a30 * a21 * a02 * a13 + a20 * a31 * a02 * a13 + a30 * a01 * a22 * a13 - a00 * a31 * a22 * a13 - a20 * a01 * a32 * a13 + a00 * a21 * a32 * a13 + a30 * a11 * a02 * a23 - a10 * a31 * a02 * a23 - a30 * a01 * a12 * a23 + a00 * a31 * a12 * a23 + a10 * a01 * a32 * a23 - a00 * a11 * a32 * a23 - a20 * a11 * a02 * a33 + a10 * a21 * a02 * a33 + a20 * a01 * a12 * a33 - a00 * a21 * a12 * a33 - a10 * a01 * a22 * a33 + a00 * a11 * a22 * a33;
  });
  mat4.inverse = (function(mat, dest) {
    if (!dest) {
      dest = mat;
    }
    var a00 = mat[0], a01 = mat[1], a02 = mat[2], a03 = mat[3], a10 = mat[4], a11 = mat[5], a12 = mat[6], a13 = mat[7], a20 = mat[8], a21 = mat[9], a22 = mat[10], a23 = mat[11], a30 = mat[12], a31 = mat[13], a32 = mat[14], a33 = mat[15], b00 = a00 * a11 - a01 * a10, b01 = a00 * a12 - a02 * a10, b02 = a00 * a13 - a03 * a10, b03 = a01 * a12 - a02 * a11, b04 = a01 * a13 - a03 * a11, b05 = a02 * a13 - a03 * a12, b06 = a20 * a31 - a21 * a30, b07 = a20 * a32 - a22 * a30, b08 = a20 * a33 - a23 * a30, b09 = a21 * a32 - a22 * a31, b10 = a21 * a33 - a23 * a31, b11 = a22 * a33 - a23 * a32, d = b00 * b11 - b01 * b10 + b02 * b09 + b03 * b08 - b04 * b07 + b05 * b06, invDet;
    if (!d) {
      return null;
    }
    invDet = 1 / d;
    dest[0] = (a11 * b11 - a12 * b10 + a13 * b09) * invDet;
    dest[1] = (-a01 * b11 + a02 * b10 - a03 * b09) * invDet;
    dest[2] = (a31 * b05 - a32 * b04 + a33 * b03) * invDet;
    dest[3] = (-a21 * b05 + a22 * b04 - a23 * b03) * invDet;
    dest[4] = (-a10 * b11 + a12 * b08 - a13 * b07) * invDet;
    dest[5] = (a00 * b11 - a02 * b08 + a03 * b07) * invDet;
    dest[6] = (-a30 * b05 + a32 * b02 - a33 * b01) * invDet;
    dest[7] = (a20 * b05 - a22 * b02 + a23 * b01) * invDet;
    dest[8] = (a10 * b10 - a11 * b08 + a13 * b06) * invDet;
    dest[9] = (-a00 * b10 + a01 * b08 - a03 * b06) * invDet;
    dest[10] = (a30 * b04 - a31 * b02 + a33 * b00) * invDet;
    dest[11] = (-a20 * b04 + a21 * b02 - a23 * b00) * invDet;
    dest[12] = (-a10 * b09 + a11 * b07 - a12 * b06) * invDet;
    dest[13] = (a00 * b09 - a01 * b07 + a02 * b06) * invDet;
    dest[14] = (-a30 * b03 + a31 * b01 - a32 * b00) * invDet;
    dest[15] = (a20 * b03 - a21 * b01 + a22 * b00) * invDet;
    return dest;
  });
  mat4.toRotationMat = (function(mat, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    dest[0] = mat[0];
    dest[1] = mat[1];
    dest[2] = mat[2];
    dest[3] = mat[3];
    dest[4] = mat[4];
    dest[5] = mat[5];
    dest[6] = mat[6];
    dest[7] = mat[7];
    dest[8] = mat[8];
    dest[9] = mat[9];
    dest[10] = mat[10];
    dest[11] = mat[11];
    dest[12] = 0;
    dest[13] = 0;
    dest[14] = 0;
    dest[15] = 1;
    return dest;
  });
  mat4.toMat3 = (function(mat, dest) {
    if (!dest) {
      dest = mat3.create();
    }
    dest[0] = mat[0];
    dest[1] = mat[1];
    dest[2] = mat[2];
    dest[3] = mat[4];
    dest[4] = mat[5];
    dest[5] = mat[6];
    dest[6] = mat[8];
    dest[7] = mat[9];
    dest[8] = mat[10];
    return dest;
  });
  mat4.toInverseMat3 = (function(mat, dest) {
    var a00 = mat[0], a01 = mat[1], a02 = mat[2], a10 = mat[4], a11 = mat[5], a12 = mat[6], a20 = mat[8], a21 = mat[9], a22 = mat[10], b01 = a22 * a11 - a12 * a21, b11 = -a22 * a10 + a12 * a20, b21 = a21 * a10 - a11 * a20, d = a00 * b01 + a01 * b11 + a02 * b21, id;
    if (!d) {
      return null;
    }
    id = 1 / d;
    if (!dest) {
      dest = mat3.create();
    }
    dest[0] = b01 * id;
    dest[1] = (-a22 * a01 + a02 * a21) * id;
    dest[2] = (a12 * a01 - a02 * a11) * id;
    dest[3] = b11 * id;
    dest[4] = (a22 * a00 - a02 * a20) * id;
    dest[5] = (-a12 * a00 + a02 * a10) * id;
    dest[6] = b21 * id;
    dest[7] = (-a21 * a00 + a01 * a20) * id;
    dest[8] = (a11 * a00 - a01 * a10) * id;
    return dest;
  });
  mat4.multiply = (function(mat, mat2, dest) {
    if (!dest) {
      dest = mat;
    }
    var a00 = mat[0], a01 = mat[1], a02 = mat[2], a03 = mat[3], a10 = mat[4], a11 = mat[5], a12 = mat[6], a13 = mat[7], a20 = mat[8], a21 = mat[9], a22 = mat[10], a23 = mat[11], a30 = mat[12], a31 = mat[13], a32 = mat[14], a33 = mat[15], b00 = mat2[0], b01 = mat2[1], b02 = mat2[2], b03 = mat2[3], b10 = mat2[4], b11 = mat2[5], b12 = mat2[6], b13 = mat2[7], b20 = mat2[8], b21 = mat2[9], b22 = mat2[10], b23 = mat2[11], b30 = mat2[12], b31 = mat2[13], b32 = mat2[14], b33 = mat2[15];
    dest[0] = b00 * a00 + b01 * a10 + b02 * a20 + b03 * a30;
    dest[1] = b00 * a01 + b01 * a11 + b02 * a21 + b03 * a31;
    dest[2] = b00 * a02 + b01 * a12 + b02 * a22 + b03 * a32;
    dest[3] = b00 * a03 + b01 * a13 + b02 * a23 + b03 * a33;
    dest[4] = b10 * a00 + b11 * a10 + b12 * a20 + b13 * a30;
    dest[5] = b10 * a01 + b11 * a11 + b12 * a21 + b13 * a31;
    dest[6] = b10 * a02 + b11 * a12 + b12 * a22 + b13 * a32;
    dest[7] = b10 * a03 + b11 * a13 + b12 * a23 + b13 * a33;
    dest[8] = b20 * a00 + b21 * a10 + b22 * a20 + b23 * a30;
    dest[9] = b20 * a01 + b21 * a11 + b22 * a21 + b23 * a31;
    dest[10] = b20 * a02 + b21 * a12 + b22 * a22 + b23 * a32;
    dest[11] = b20 * a03 + b21 * a13 + b22 * a23 + b23 * a33;
    dest[12] = b30 * a00 + b31 * a10 + b32 * a20 + b33 * a30;
    dest[13] = b30 * a01 + b31 * a11 + b32 * a21 + b33 * a31;
    dest[14] = b30 * a02 + b31 * a12 + b32 * a22 + b33 * a32;
    dest[15] = b30 * a03 + b31 * a13 + b32 * a23 + b33 * a33;
    return dest;
  });
  mat4.multiplyVec3 = (function(mat, vec, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0], y = vec[1], z = vec[2];
    dest[0] = mat[0] * x + mat[4] * y + mat[8] * z + mat[12];
    dest[1] = mat[1] * x + mat[5] * y + mat[9] * z + mat[13];
    dest[2] = mat[2] * x + mat[6] * y + mat[10] * z + mat[14];
    return dest;
  });
  mat4.multiplyVec4 = (function(mat, vec, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0], y = vec[1], z = vec[2], w = vec[3];
    dest[0] = mat[0] * x + mat[4] * y + mat[8] * z + mat[12] * w;
    dest[1] = mat[1] * x + mat[5] * y + mat[9] * z + mat[13] * w;
    dest[2] = mat[2] * x + mat[6] * y + mat[10] * z + mat[14] * w;
    dest[3] = mat[3] * x + mat[7] * y + mat[11] * z + mat[15] * w;
    return dest;
  });
  mat4.translate = (function(mat, vec, dest) {
    var x = vec[0], y = vec[1], z = vec[2], a00, a01, a02, a03, a10, a11, a12, a13, a20, a21, a22, a23;
    if (!dest || mat === dest) {
      mat[12] = mat[0] * x + mat[4] * y + mat[8] * z + mat[12];
      mat[13] = mat[1] * x + mat[5] * y + mat[9] * z + mat[13];
      mat[14] = mat[2] * x + mat[6] * y + mat[10] * z + mat[14];
      mat[15] = mat[3] * x + mat[7] * y + mat[11] * z + mat[15];
      return mat;
    }
    a00 = mat[0];
    a01 = mat[1];
    a02 = mat[2];
    a03 = mat[3];
    a10 = mat[4];
    a11 = mat[5];
    a12 = mat[6];
    a13 = mat[7];
    a20 = mat[8];
    a21 = mat[9];
    a22 = mat[10];
    a23 = mat[11];
    dest[0] = a00;
    dest[1] = a01;
    dest[2] = a02;
    dest[3] = a03;
    dest[4] = a10;
    dest[5] = a11;
    dest[6] = a12;
    dest[7] = a13;
    dest[8] = a20;
    dest[9] = a21;
    dest[10] = a22;
    dest[11] = a23;
    dest[12] = a00 * x + a10 * y + a20 * z + mat[12];
    dest[13] = a01 * x + a11 * y + a21 * z + mat[13];
    dest[14] = a02 * x + a12 * y + a22 * z + mat[14];
    dest[15] = a03 * x + a13 * y + a23 * z + mat[15];
    return dest;
  });
  mat4.scale = (function(mat, vec, dest) {
    var x = vec[0], y = vec[1], z = vec[2];
    if (!dest || mat === dest) {
      mat[0] *= x;
      mat[1] *= x;
      mat[2] *= x;
      mat[3] *= x;
      mat[4] *= y;
      mat[5] *= y;
      mat[6] *= y;
      mat[7] *= y;
      mat[8] *= z;
      mat[9] *= z;
      mat[10] *= z;
      mat[11] *= z;
      return mat;
    }
    dest[0] = mat[0] * x;
    dest[1] = mat[1] * x;
    dest[2] = mat[2] * x;
    dest[3] = mat[3] * x;
    dest[4] = mat[4] * y;
    dest[5] = mat[5] * y;
    dest[6] = mat[6] * y;
    dest[7] = mat[7] * y;
    dest[8] = mat[8] * z;
    dest[9] = mat[9] * z;
    dest[10] = mat[10] * z;
    dest[11] = mat[11] * z;
    dest[12] = mat[12];
    dest[13] = mat[13];
    dest[14] = mat[14];
    dest[15] = mat[15];
    return dest;
  });
  mat4.rotate = (function(mat, angle, axis, dest) {
    var x = axis[0], y = axis[1], z = axis[2], len = Math.sqrt(x * x + y * y + z * z), s, c, t, a00, a01, a02, a03, a10, a11, a12, a13, a20, a21, a22, a23, b00, b01, b02, b10, b11, b12, b20, b21, b22;
    if (!len) {
      return null;
    }
    if (len !== 1) {
      len = 1 / len;
      x *= len;
      y *= len;
      z *= len;
    }
    s = Math.sin(angle);
    c = Math.cos(angle);
    t = 1 - c;
    a00 = mat[0];
    a01 = mat[1];
    a02 = mat[2];
    a03 = mat[3];
    a10 = mat[4];
    a11 = mat[5];
    a12 = mat[6];
    a13 = mat[7];
    a20 = mat[8];
    a21 = mat[9];
    a22 = mat[10];
    a23 = mat[11];
    b00 = x * x * t + c;
    b01 = y * x * t + z * s;
    b02 = z * x * t - y * s;
    b10 = x * y * t - z * s;
    b11 = y * y * t + c;
    b12 = z * y * t + x * s;
    b20 = x * z * t + y * s;
    b21 = y * z * t - x * s;
    b22 = z * z * t + c;
    if (!dest) {
      dest = mat;
    } else if (mat !== dest) {
      dest[12] = mat[12];
      dest[13] = mat[13];
      dest[14] = mat[14];
      dest[15] = mat[15];
    }
    dest[0] = a00 * b00 + a10 * b01 + a20 * b02;
    dest[1] = a01 * b00 + a11 * b01 + a21 * b02;
    dest[2] = a02 * b00 + a12 * b01 + a22 * b02;
    dest[3] = a03 * b00 + a13 * b01 + a23 * b02;
    dest[4] = a00 * b10 + a10 * b11 + a20 * b12;
    dest[5] = a01 * b10 + a11 * b11 + a21 * b12;
    dest[6] = a02 * b10 + a12 * b11 + a22 * b12;
    dest[7] = a03 * b10 + a13 * b11 + a23 * b12;
    dest[8] = a00 * b20 + a10 * b21 + a20 * b22;
    dest[9] = a01 * b20 + a11 * b21 + a21 * b22;
    dest[10] = a02 * b20 + a12 * b21 + a22 * b22;
    dest[11] = a03 * b20 + a13 * b21 + a23 * b22;
    return dest;
  });
  mat4.rotateX = (function(mat, angle, dest) {
    var s = Math.sin(angle), c = Math.cos(angle), a10 = mat[4], a11 = mat[5], a12 = mat[6], a13 = mat[7], a20 = mat[8], a21 = mat[9], a22 = mat[10], a23 = mat[11];
    if (!dest) {
      dest = mat;
    } else if (mat !== dest) {
      dest[0] = mat[0];
      dest[1] = mat[1];
      dest[2] = mat[2];
      dest[3] = mat[3];
      dest[12] = mat[12];
      dest[13] = mat[13];
      dest[14] = mat[14];
      dest[15] = mat[15];
    }
    dest[4] = a10 * c + a20 * s;
    dest[5] = a11 * c + a21 * s;
    dest[6] = a12 * c + a22 * s;
    dest[7] = a13 * c + a23 * s;
    dest[8] = a10 * -s + a20 * c;
    dest[9] = a11 * -s + a21 * c;
    dest[10] = a12 * -s + a22 * c;
    dest[11] = a13 * -s + a23 * c;
    return dest;
  });
  mat4.rotateY = (function(mat, angle, dest) {
    var s = Math.sin(angle), c = Math.cos(angle), a00 = mat[0], a01 = mat[1], a02 = mat[2], a03 = mat[3], a20 = mat[8], a21 = mat[9], a22 = mat[10], a23 = mat[11];
    if (!dest) {
      dest = mat;
    } else if (mat !== dest) {
      dest[4] = mat[4];
      dest[5] = mat[5];
      dest[6] = mat[6];
      dest[7] = mat[7];
      dest[12] = mat[12];
      dest[13] = mat[13];
      dest[14] = mat[14];
      dest[15] = mat[15];
    }
    dest[0] = a00 * c + a20 * -s;
    dest[1] = a01 * c + a21 * -s;
    dest[2] = a02 * c + a22 * -s;
    dest[3] = a03 * c + a23 * -s;
    dest[8] = a00 * s + a20 * c;
    dest[9] = a01 * s + a21 * c;
    dest[10] = a02 * s + a22 * c;
    dest[11] = a03 * s + a23 * c;
    return dest;
  });
  mat4.rotateZ = (function(mat, angle, dest) {
    var s = Math.sin(angle), c = Math.cos(angle), a00 = mat[0], a01 = mat[1], a02 = mat[2], a03 = mat[3], a10 = mat[4], a11 = mat[5], a12 = mat[6], a13 = mat[7];
    if (!dest) {
      dest = mat;
    } else if (mat !== dest) {
      dest[8] = mat[8];
      dest[9] = mat[9];
      dest[10] = mat[10];
      dest[11] = mat[11];
      dest[12] = mat[12];
      dest[13] = mat[13];
      dest[14] = mat[14];
      dest[15] = mat[15];
    }
    dest[0] = a00 * c + a10 * s;
    dest[1] = a01 * c + a11 * s;
    dest[2] = a02 * c + a12 * s;
    dest[3] = a03 * c + a13 * s;
    dest[4] = a00 * -s + a10 * c;
    dest[5] = a01 * -s + a11 * c;
    dest[6] = a02 * -s + a12 * c;
    dest[7] = a03 * -s + a13 * c;
    return dest;
  });
  mat4.frustum = (function(left, right, bottom, top, near, far, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    var rl = right - left, tb = top - bottom, fn = far - near;
    dest[0] = near * 2 / rl;
    dest[1] = 0;
    dest[2] = 0;
    dest[3] = 0;
    dest[4] = 0;
    dest[5] = near * 2 / tb;
    dest[6] = 0;
    dest[7] = 0;
    dest[8] = (right + left) / rl;
    dest[9] = (top + bottom) / tb;
    dest[10] = -(far + near) / fn;
    dest[11] = -1;
    dest[12] = 0;
    dest[13] = 0;
    dest[14] = -(far * near * 2) / fn;
    dest[15] = 0;
    return dest;
  });
  mat4.perspective = (function(fovy, aspect, near, far, dest) {
    var top = near * Math.tan(fovy * Math.PI / 360), right = top * aspect;
    return mat4.frustum(-right, right, -top, top, near, far, dest);
  });
  mat4.ortho = (function(left, right, bottom, top, near, far, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    var rl = right - left, tb = top - bottom, fn = far - near;
    dest[0] = 2 / rl;
    dest[1] = 0;
    dest[2] = 0;
    dest[3] = 0;
    dest[4] = 0;
    dest[5] = 2 / tb;
    dest[6] = 0;
    dest[7] = 0;
    dest[8] = 0;
    dest[9] = 0;
    dest[10] = -2 / fn;
    dest[11] = 0;
    dest[12] = -(left + right) / rl;
    dest[13] = -(top + bottom) / tb;
    dest[14] = -(far + near) / fn;
    dest[15] = 1;
    return dest;
  });
  mat4.lookAt = (function(eye, center, up, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    var x0, x1, x2, y0, y1, y2, z0, z1, z2, len, eyex = eye[0], eyey = eye[1], eyez = eye[2], upx = up[0], upy = up[1], upz = up[2], centerx = center[0], centery = center[1], centerz = center[2];
    if (eyex === centerx && eyey === centery && eyez === centerz) {
      return mat4.identity(dest);
    }
    z0 = eyex - centerx;
    z1 = eyey - centery;
    z2 = eyez - centerz;
    len = 1 / Math.sqrt(z0 * z0 + z1 * z1 + z2 * z2);
    z0 *= len;
    z1 *= len;
    z2 *= len;
    x0 = upy * z2 - upz * z1;
    x1 = upz * z0 - upx * z2;
    x2 = upx * z1 - upy * z0;
    len = Math.sqrt(x0 * x0 + x1 * x1 + x2 * x2);
    if (!len) {
      x0 = 0;
      x1 = 0;
      x2 = 0;
    } else {
      len = 1 / len;
      x0 *= len;
      x1 *= len;
      x2 *= len;
    }
    y0 = z1 * x2 - z2 * x1;
    y1 = z2 * x0 - z0 * x2;
    y2 = z0 * x1 - z1 * x0;
    len = Math.sqrt(y0 * y0 + y1 * y1 + y2 * y2);
    if (!len) {
      y0 = 0;
      y1 = 0;
      y2 = 0;
    } else {
      len = 1 / len;
      y0 *= len;
      y1 *= len;
      y2 *= len;
    }
    dest[0] = x0;
    dest[1] = y0;
    dest[2] = z0;
    dest[3] = 0;
    dest[4] = x1;
    dest[5] = y1;
    dest[6] = z1;
    dest[7] = 0;
    dest[8] = x2;
    dest[9] = y2;
    dest[10] = z2;
    dest[11] = 0;
    dest[12] = -(x0 * eyex + x1 * eyey + x2 * eyez);
    dest[13] = -(y0 * eyex + y1 * eyey + y2 * eyez);
    dest[14] = -(z0 * eyex + z1 * eyey + z2 * eyez);
    dest[15] = 1;
    return dest;
  });
  mat4.fromRotationTranslation = (function(quat, vec, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    var x = quat[0], y = quat[1], z = quat[2], w = quat[3], x2 = x + x, y2 = y + y, z2 = z + z, xx = x * x2, xy = x * y2, xz = x * z2, yy = y * y2, yz = y * z2, zz = z * z2, wx = w * x2, wy = w * y2, wz = w * z2;
    dest[0] = 1 - (yy + zz);
    dest[1] = xy + wz;
    dest[2] = xz - wy;
    dest[3] = 0;
    dest[4] = xy - wz;
    dest[5] = 1 - (xx + zz);
    dest[6] = yz + wx;
    dest[7] = 0;
    dest[8] = xz + wy;
    dest[9] = yz - wx;
    dest[10] = 1 - (xx + yy);
    dest[11] = 0;
    dest[12] = vec[0];
    dest[13] = vec[1];
    dest[14] = vec[2];
    dest[15] = 1;
    return dest;
  });
  mat4.str = (function(mat) {
    return "[" + mat[0] + ", " + mat[1] + ", " + mat[2] + ", " + mat[3] + ", " + mat[4] + ", " + mat[5] + ", " + mat[6] + ", " + mat[7] + ", " + mat[8] + ", " + mat[9] + ", " + mat[10] + ", " + mat[11] + ", " + mat[12] + ", " + mat[13] + ", " + mat[14] + ", " + mat[15] + "]";
  });
  quat4.create = (function(quat) {
    var dest = new MatrixArray(4);
    if (quat) {
      dest[0] = quat[0];
      dest[1] = quat[1];
      dest[2] = quat[2];
      dest[3] = quat[3];
    }
    return dest;
  });
  quat4.set = (function(quat, dest) {
    dest[0] = quat[0];
    dest[1] = quat[1];
    dest[2] = quat[2];
    dest[3] = quat[3];
    return dest;
  });
  quat4.calculateW = (function(quat, dest) {
    var x = quat[0], y = quat[1], z = quat[2];
    if (!dest || quat === dest) {
      quat[3] = -Math.sqrt(Math.abs(1 - x * x - y * y - z * z));
      return quat;
    }
    dest[0] = x;
    dest[1] = y;
    dest[2] = z;
    dest[3] = -Math.sqrt(Math.abs(1 - x * x - y * y - z * z));
    return dest;
  });
  quat4.dot = (function(quat, quat2) {
    return quat[0] * quat2[0] + quat[1] * quat2[1] + quat[2] * quat2[2] + quat[3] * quat2[3];
  });
  quat4.inverse = (function(quat, dest) {
    var q0 = quat[0], q1 = quat[1], q2 = quat[2], q3 = quat[3], dot = q0 * q0 + q1 * q1 + q2 * q2 + q3 * q3, invDot = dot ? 1 / dot : 0;
    if (!dest || quat === dest) {
      quat[0] *= -invDot;
      quat[1] *= -invDot;
      quat[2] *= -invDot;
      quat[3] *= invDot;
      return quat;
    }
    dest[0] = -quat[0] * invDot;
    dest[1] = -quat[1] * invDot;
    dest[2] = -quat[2] * invDot;
    dest[3] = quat[3] * invDot;
    return dest;
  });
  quat4.conjugate = (function(quat, dest) {
    if (!dest || quat === dest) {
      quat[0] *= -1;
      quat[1] *= -1;
      quat[2] *= -1;
      return quat;
    }
    dest[0] = -quat[0];
    dest[1] = -quat[1];
    dest[2] = -quat[2];
    dest[3] = quat[3];
    return dest;
  });
  quat4.length = (function(quat) {
    var x = quat[0], y = quat[1], z = quat[2], w = quat[3];
    return Math.sqrt(x * x + y * y + z * z + w * w);
  });
  quat4.normalize = (function(quat, dest) {
    if (!dest) {
      dest = quat;
    }
    var x = quat[0], y = quat[1], z = quat[2], w = quat[3], len = Math.sqrt(x * x + y * y + z * z + w * w);
    if (len === 0) {
      dest[0] = 0;
      dest[1] = 0;
      dest[2] = 0;
      dest[3] = 0;
      return dest;
    }
    len = 1 / len;
    dest[0] = x * len;
    dest[1] = y * len;
    dest[2] = z * len;
    dest[3] = w * len;
    return dest;
  });
  quat4.add = (function(quat, quat2, dest) {
    if (!dest || quat === dest) {
      quat[0] += quat2[0];
      quat[1] += quat2[1];
      quat[2] += quat2[2];
      quat[3] += quat2[3];
      return quat;
    }
    dest[0] = quat[0] + quat2[0];
    dest[1] = quat[1] + quat2[1];
    dest[2] = quat[2] + quat2[2];
    dest[3] = quat[3] + quat2[3];
    return dest;
  });
  quat4.multiply = (function(quat, quat2, dest) {
    if (!dest) {
      dest = quat;
    }
    var qax = quat[0], qay = quat[1], qaz = quat[2], qaw = quat[3], qbx = quat2[0], qby = quat2[1], qbz = quat2[2], qbw = quat2[3];
    dest[0] = qax * qbw + qaw * qbx + qay * qbz - qaz * qby;
    dest[1] = qay * qbw + qaw * qby + qaz * qbx - qax * qbz;
    dest[2] = qaz * qbw + qaw * qbz + qax * qby - qay * qbx;
    dest[3] = qaw * qbw - qax * qbx - qay * qby - qaz * qbz;
    return dest;
  });
  quat4.multiplyVec3 = (function(quat, vec, dest) {
    if (!dest) {
      dest = vec;
    }
    var x = vec[0], y = vec[1], z = vec[2], qx = quat[0], qy = quat[1], qz = quat[2], qw = quat[3], ix = qw * x + qy * z - qz * y, iy = qw * y + qz * x - qx * z, iz = qw * z + qx * y - qy * x, iw = -qx * x - qy * y - qz * z;
    dest[0] = ix * qw + iw * -qx + iy * -qz - iz * -qy;
    dest[1] = iy * qw + iw * -qy + iz * -qx - ix * -qz;
    dest[2] = iz * qw + iw * -qz + ix * -qy - iy * -qx;
    return dest;
  });
  quat4.scale = (function(quat, val, dest) {
    if (!dest || quat === dest) {
      quat[0] *= val;
      quat[1] *= val;
      quat[2] *= val;
      quat[3] *= val;
      return quat;
    }
    dest[0] = quat[0] * val;
    dest[1] = quat[1] * val;
    dest[2] = quat[2] * val;
    dest[3] = quat[3] * val;
    return dest;
  });
  quat4.toMat3 = (function(quat, dest) {
    if (!dest) {
      dest = mat3.create();
    }
    var x = quat[0], y = quat[1], z = quat[2], w = quat[3], x2 = x + x, y2 = y + y, z2 = z + z, xx = x * x2, xy = x * y2, xz = x * z2, yy = y * y2, yz = y * z2, zz = z * z2, wx = w * x2, wy = w * y2, wz = w * z2;
    dest[0] = 1 - (yy + zz);
    dest[1] = xy + wz;
    dest[2] = xz - wy;
    dest[3] = xy - wz;
    dest[4] = 1 - (xx + zz);
    dest[5] = yz + wx;
    dest[6] = xz + wy;
    dest[7] = yz - wx;
    dest[8] = 1 - (xx + yy);
    return dest;
  });
  quat4.toMat4 = (function(quat, dest) {
    if (!dest) {
      dest = mat4.create();
    }
    var x = quat[0], y = quat[1], z = quat[2], w = quat[3], x2 = x + x, y2 = y + y, z2 = z + z, xx = x * x2, xy = x * y2, xz = x * z2, yy = y * y2, yz = y * z2, zz = z * z2, wx = w * x2, wy = w * y2, wz = w * z2;
    dest[0] = 1 - (yy + zz);
    dest[1] = xy + wz;
    dest[2] = xz - wy;
    dest[3] = 0;
    dest[4] = xy - wz;
    dest[5] = 1 - (xx + zz);
    dest[6] = yz + wx;
    dest[7] = 0;
    dest[8] = xz + wy;
    dest[9] = yz - wx;
    dest[10] = 1 - (xx + yy);
    dest[11] = 0;
    dest[12] = 0;
    dest[13] = 0;
    dest[14] = 0;
    dest[15] = 1;
    return dest;
  });
  quat4.slerp = (function(quat, quat2, slerp, dest) {
    if (!dest) {
      dest = quat;
    }
    var cosHalfTheta = quat[0] * quat2[0] + quat[1] * quat2[1] + quat[2] * quat2[2] + quat[3] * quat2[3], halfTheta, sinHalfTheta, ratioA, ratioB;
    if (Math.abs(cosHalfTheta) >= 1) {
      if (dest !== quat) {
        dest[0] = quat[0];
        dest[1] = quat[1];
        dest[2] = quat[2];
        dest[3] = quat[3];
      }
      return dest;
    }
    halfTheta = Math.acos(cosHalfTheta);
    sinHalfTheta = Math.sqrt(1 - cosHalfTheta * cosHalfTheta);
    if (Math.abs(sinHalfTheta) < .001) {
      dest[0] = quat[0] * .5 + quat2[0] * .5;
      dest[1] = quat[1] * .5 + quat2[1] * .5;
      dest[2] = quat[2] * .5 + quat2[2] * .5;
      dest[3] = quat[3] * .5 + quat2[3] * .5;
      return dest;
    }
    ratioA = Math.sin((1 - slerp) * halfTheta) / sinHalfTheta;
    ratioB = Math.sin(slerp * halfTheta) / sinHalfTheta;
    dest[0] = quat[0] * ratioA + quat2[0] * ratioB;
    dest[1] = quat[1] * ratioA + quat2[1] * ratioB;
    dest[2] = quat[2] * ratioA + quat2[2] * ratioB;
    dest[3] = quat[3] * ratioA + quat2[3] * ratioB;
    return dest;
  });
  quat4.str = (function(quat) {
    return "[" + quat[0] + ", " + quat[1] + ", " + quat[2] + ", " + quat[3] + "]";
  });
  return {
    vec3: vec3,
    mat3: mat3,
    mat4: mat4,
    quat4: quat4
  };
})();

GL.immediate.initMatrixLibrary();

var GLImmediateSetup = {};

function _glBegin(mode) {
  if (!GL.immediate.initted) GL.immediate.init();
  GL.immediate.mode = mode;
  GL.immediate.renderer = null;
  GL.immediate.vertexData = GL.immediate.tempData;
}

function _glEnd() {
  GL.immediate.flush();
  GL.immediate.mode = 0;
}

function _glVertex3f(x, y, z) {
  GL.immediate.vertexData[GL.immediate.vertexCounter++] = x;
  GL.immediate.vertexData[GL.immediate.vertexCounter++] = y;
  GL.immediate.vertexData[GL.immediate.vertexCounter++] = z || 0;
  if (!GL.immediate.renderer) {
    GL.immediate.setRenderer("T2V3");
  }
}

var _glVertex2f = _glVertex3f;

function _glTexCoord2i(u, v) {
  GL.immediate.vertexData[GL.immediate.vertexCounter++] = u;
  GL.immediate.vertexData[GL.immediate.vertexCounter++] = v;
}

var _glTexCoord2f = _glTexCoord2i;

function _glTexCoord2fv(v) {
  _glTexCoord2f(HEAPF32[v >> 2], HEAPF32[v + 4 >> 2]);
}

function _glColor4b() {}

var _glColor4s = _glColor4b;

var _glColor4i = _glColor4b;

var _glColor4f = _glColor4b;

var _glColor4d = _glColor4b;

var _glColor4ub = _glColor4b;

var _glColor4us = _glColor4b;

var _glColor4ui = _glColor4b;

function _glColor3b(r, g, b) {
  _glColor4b(r, g, b, 1);
}

var _glColor3s = _glColor3b;

var _glColor3i = _glColor3b;

var _glColor3f = _glColor3b;

var _glColor3d = _glColor3b;

var _glColor3ub = _glColor3b;

var _glColor3us = _glColor3b;

var _glColor3ui = _glColor3b;

function _glColor3fv() {}

function _glEnableClientState(cap, disable) {
  if (!GL.immediate.initted) GL.immediate.init();
  switch (cap) {
   case 32888:
    GL.immediate.enabledClientAttributes[GL.immediate.TEXTURE] = !disable;
    break;
   case 32884:
    GL.immediate.enabledClientAttributes[GL.immediate.VERTEX] = !disable;
    break;
   default:
    throw "unhandled clientstate: " + cap;
  }
  if (!disable) {
    GL.immediate.totalEnabledClientAttributes++;
  } else {
    GL.immediate.totalEnabledClientAttributes--;
  }
}

function _glDisableClientState(cap) {
  _glEnableClientState(cap, 1);
}

function _glTexCoordPointer(size, type, stride, pointer) {
  GL.immediate.setClientAttribute(GL.immediate.TEXTURE, "T", size, type, stride, pointer);
}

function _glVertexPointer(size, type, stride, pointer) {
  GL.immediate.setClientAttribute(GL.immediate.VERTEX, "V", size, type, stride, pointer);
}

function _glMatrixMode(mode) {
  if (mode == 5888) {
    GL.immediate.currentMatrix = "m";
  } else if (mode == 5889) {
    GL.immediate.currentMatrix = "p";
  } else {
    throw "Wrong mode " + mode + " passed to glMatrixMode";
  }
}

function _glPushMatrix() {
  GL.immediate.matrixStack[GL.immediate.currentMatrix].push(Array.prototype.slice.call(GL.immediate.matrix[GL.immediate.currentMatrix]));
}

function _glPopMatrix() {
  GL.immediate.matrix[GL.immediate.currentMatrix] = GL.immediate.matrixStack[GL.immediate.currentMatrix].pop();
}

function _glLoadIdentity() {
  GL.immediate.matrix.lib.mat4.identity(GL.immediate.matrix[GL.immediate.currentMatrix]);
}

function _glLoadMatrixd(matrix) {
  GL.immediate.matrix.lib.mat4.set(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF64.subarray(matrix >> 3, matrix + 16 * 8 >> 3));
}

function _glLoadMatrixf(matrix) {
  GL.immediate.matrix.lib.mat4.set(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF32.subarray(matrix >> 2, matrix + 16 * 4 >> 2));
}

function _glLoadTransposeMatrixd(matrix) {
  GL.immediate.matrix.lib.mat4.set(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF64.subarray(matrix >> 3, matrix + 16 * 8 >> 3));
  GL.immediate.matrix.lib.mat4.transpose(GL.immediate.matrix[GL.immediate.currentMatrix]);
}

function _glLoadTransposeMatrixf(matrix) {
  GL.immediate.matrix.lib.mat4.set(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF32.subarray(matrix >> 2, matrix + 16 * 4 >> 2));
  GL.immediate.matrix.lib.mat4.transpose(GL.immediate.matrix[GL.immediate.currentMatrix]);
}

function _glMultMatrixd(matrix) {
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF64.subarray(matrix >> 3, matrix + 16 * 8 >> 3));
}

function _glMultMatrixf(matrix) {
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], HEAPF32.subarray(matrix >> 2, matrix + 16 * 4 >> 2));
}

function _glMultTransposeMatrixd(matrix) {
  var colMajor = GL.immediate.matrix.lib.mat4.create();
  GL.immediate.matrix.lib.mat4.set(colMajor, HEAPF64.subarray(matrix >> 3, matrix + 16 * 8 >> 3));
  GL.immediate.matrix.lib.mat4.transpose(colMajor);
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], colMajor);
}

function _glMultTransposeMatrixf(matrix) {
  var colMajor = GL.immediate.matrix.lib.mat4.create();
  GL.immediate.matrix.lib.mat4.set(colMajor, HEAPF32.subarray(matrix >> 2, matrix + 16 * 4 >> 2));
  GL.immediate.matrix.lib.mat4.transpose(colMajor);
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], colMajor);
}

function _glFrustum(left, right, bottom, top_, nearVal, farVal) {
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], GL.immediate.matrix.lib.mat4.frustum(left, right, bottom, top_, nearVal, farVal));
}

function _glOrtho(left, right, bottom, top_, nearVal, farVal) {
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], GL.immediate.matrix.lib.mat4.ortho(left, right, bottom, top_, nearVal, farVal));
}

function _glScaled(x, y, z) {
  GL.immediate.matrix.lib.mat4.scale(GL.immediate.matrix[GL.immediate.currentMatrix], [ x, y, z ]);
}

var _glScalef = _glScaled;

function _glTranslated(x, y, z) {
  GL.immediate.matrix.lib.mat4.translate(GL.immediate.matrix[GL.immediate.currentMatrix], [ x, y, z ]);
}

var _glTranslatef = _glTranslated;

function _glRotated(angle, x, y, z) {
  GL.immediate.matrix.lib.mat4.rotate(GL.immediate.matrix[GL.immediate.currentMatrix], angle, [ x, y, z ]);
}

var _glRotatef = _glRotated;

function _gluPerspective(fov, aspect, near, far) {
  GL.immediate.matrix.lib.mat4.multiply(GL.immediate.matrix[GL.immediate.currentMatrix], GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far, GL.immediate.currentMatrix));
}

function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
  GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ ex, ey, ez ], [ cx, cy, cz ], [ ux, uy, uz ]);
}

function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
  var inVec = new Float32Array(4);
  var outVec = new Float32Array(4);
  GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray(model >> 3, model + 16 * 8 >> 3), [ objX, objY, objZ, 1 ], outVec);
  GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray(proj >> 3, proj + 16 * 8 >> 3), outVec, inVec);
  if (inVec[3] == 0) {
    return 0;
  }
  inVec[0] /= inVec[3];
  inVec[1] /= inVec[3];
  inVec[2] /= inVec[3];
  inVec[0] = inVec[0] * .5 + .5;
  inVec[1] = inVec[1] * .5 + .5;
  inVec[2] = inVec[2] * .5 + .5;
  inVec[0] = inVec[0] * HEAP32[view + 2 * 4 >> 2] + HEAP32[view + 0 * 4 >> 2];
  inVec[1] = inVec[1] * HEAP32[view + 3 * 4 >> 2] + HEAP32[view + 1 * 4 >> 2];
  tempDoubleF64[0] = inVec[0], HEAP32[winX >> 2] = tempDoubleI32[0], HEAP32[winX + 4 >> 2] = tempDoubleI32[1];
  tempDoubleF64[0] = inVec[1], HEAP32[winY >> 2] = tempDoubleI32[0], HEAP32[winY + 4 >> 2] = tempDoubleI32[1];
  tempDoubleF64[0] = inVec[2], HEAP32[winZ >> 2] = tempDoubleI32[0], HEAP32[winZ + 4 >> 2] = tempDoubleI32[1];
  return 1;
}

function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
  var result = GL.immediate.matrix.lib.mat4.unproject([ winX, winY, winZ ], HEAPF64.subarray(model >> 3, model + 16 * 8 >> 3), HEAPF64.subarray(proj >> 3, proj + 16 * 8 >> 3), HEAP32.subarray(view >> 2, view + 4 * 4 >> 2));
  if (result === null) {
    return 0;
  }
  tempDoubleF64[0] = result[0], HEAP32[objX >> 2] = tempDoubleI32[0], HEAP32[objX + 4 >> 2] = tempDoubleI32[1];
  tempDoubleF64[0] = result[1], HEAP32[objY >> 2] = tempDoubleI32[0], HEAP32[objY + 4 >> 2] = tempDoubleI32[1];
  tempDoubleF64[0] = result[2], HEAP32[objZ >> 2] = tempDoubleI32[0], HEAP32[objZ + 4 >> 2] = tempDoubleI32[1];
  return 1;
}

function _glShadeModel() {}

function _glFogi() {}

function _glFogfv() {}

function _glGetError() {}

function _glFinish() {}

function _glFlush() {}

function _glClearDepth(x0) {
  Module.ctx.clearDepth(x0);
}

function _glClearDepthf(x0) {
  Module.ctx.clearDepth(x0);
}

function _glDepthFunc(x0) {
  Module.ctx.depthFunc(x0);
}

function _glEnable(x0) {
  Module.ctx.enable(x0);
}

function _glDisable(x0) {
  Module.ctx.disable(x0);
}

function _glFrontFace(x0) {
  Module.ctx.frontFace(x0);
}

function _glCullFace(x0) {
  Module.ctx.cullFace(x0);
}

function _glClear(x0) {
  Module.ctx.clear(x0);
}

function _glEnableVertexAttribArray(x0) {
  Module.ctx.enableVertexAttribArray(x0);
}

function _glDisableVertexAttribArray(x0) {
  Module.ctx.disableVertexAttribArray(x0);
}

function _glLineWidth(x0) {
  Module.ctx.lineWidth(x0);
}

function _glClearStencil(x0) {
  Module.ctx.clearStencil(x0);
}

function _glDepthMask(x0) {
  Module.ctx.depthMask(x0);
}

function _glStencilMask(x0) {
  Module.ctx.stencilMask(x0);
}

function _glCheckFramebufferStatus(x0) {
  return Module.ctx.checkFramebufferStatus(x0);
}

function _glGenerateMipmap(x0) {
  Module.ctx.generateMipmap(x0);
}

function _glActiveTexture(x0) {
  Module.ctx.activeTexture(x0);
}

function _glBlendEquation(x0) {
  Module.ctx.blendEquation(x0);
}

function _glPolygonOffset(x0) {
  Module.ctx.polygonOffset(x0);
}

function _glHint(x0) {
  Module.ctx.hint(x0);
}

function _glSampleCoverage(x0) {
  Module.ctx.sampleCoverage(x0);
}

function _glIsEnabled(x0) {
  return Module.ctx.isEnabled(x0);
}

function _glBlendFunc(x0, x1) {
  Module.ctx.blendFunc(x0, x1);
}

function _glBlendEquationSeparate(x0, x1) {
  Module.ctx.blendEquationSeparate(x0, x1);
}

function _glDepthRange(x0, x1) {
  Module.ctx.depthRange(x0, x1);
}

function _glDepthRangef(x0, x1) {
  Module.ctx.depthRange(x0, x1);
}

function _glStencilMaskSeparate(x0, x1) {
  Module.ctx.stencilMaskSeparate(x0, x1);
}

function _glTexParameteri(x0, x1, x2) {
  Module.ctx.texParameteri(x0, x1, x2);
}

function _glTexParameterf(x0, x1, x2) {
  Module.ctx.texParameterf(x0, x1, x2);
}

function _glDrawArrays(x0, x1, x2) {
  Module.ctx.drawArrays(x0, x1, x2);
}

function _glVertexAttrib2f(x0, x1, x2) {
  Module.ctx.vertexAttrib2f(x0, x1, x2);
}

function _glStencilFunc(x0, x1, x2) {
  Module.ctx.stencilFunc(x0, x1, x2);
}

function _glStencilOp(x0, x1, x2) {
  Module.ctx.stencilOp(x0, x1, x2);
}

function _glViewport(x0, x1, x2, x3) {
  Module.ctx.viewport(x0, x1, x2, x3);
}

function _glClearColor(x0, x1, x2, x3) {
  Module.ctx.clearColor(x0, x1, x2, x3);
}

function _glScissor(x0, x1, x2, x3) {
  Module.ctx.scissor(x0, x1, x2, x3);
}

function _glVertexAttrib3f(x0, x1, x2, x3) {
  Module.ctx.vertexAttrib3f(x0, x1, x2, x3);
}

function _glColorMask(x0, x1, x2, x3) {
  Module.ctx.colorMask(x0, x1, x2, x3);
}

function _glDrawElements(x0, x1, x2, x3) {
  Module.ctx.drawElements(x0, x1, x2, x3);
}

function _glRenderbufferStorage(x0, x1, x2, x3) {
  Module.ctx.renderbufferStorage(x0, x1, x2, x3);
}

function _glBlendFuncSeparate(x0, x1, x2, x3) {
  Module.ctx.blendFuncSeparate(x0, x1, x2, x3);
}

function _glBlendColor(x0, x1, x2, x3) {
  Module.ctx.blendColor(x0, x1, x2, x3);
}

function _glStencilFuncSeparate(x0, x1, x2, x3) {
  Module.ctx.stencilFuncSeparate(x0, x1, x2, x3);
}

function _glStencilOpSeparate(x0, x1, x2, x3) {
  Module.ctx.stencilOpSeparate(x0, x1, x2, x3);
}

function _glVertexAttrib4f(x0, x1, x2, x3, x4) {
  Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4);
}

function _glVertexAttribPointer(x0, x1, x2, x3, x4, x5) {
  Module.ctx.vertexAttribPointer(x0, x1, x2, x3, x4, x5);
}

function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
  Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7);
}

function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) {
  Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7);
}

var GLEmulation = {
  init: (function() {
    Module.printErr("WARNING: using emscripten GL emulation. This is a collection of limited workarounds, do not expect it to work");
    _glEnable = (function(cap) {
      if (cap == 3553) return;
      if (cap == 2848) return;
      if (cap == 2912) return;
      Module.ctx.enable(cap);
    });
    _glDisable = (function(cap) {
      if (cap == 3553) return;
      if (cap == 2848) return;
      if (cap == 2912) return;
      Module.ctx.disable(cap);
    });
    var glGetIntegerv = _glGetIntegerv;
    _glGetIntegerv = (function(pname, params) {
      switch (pname) {
       case 34018:
        pname = Module.ctx.MAX_TEXTURE_IMAGE_UNITS;
        break;
       case 35658:
        {
          var result = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_UNIFORM_VECTORS);
          HEAP32[params >> 2] = result * 4;
          return;
        }
       case 35657:
        {
          var result = Module.ctx.getParameter(Module.ctx.MAX_FRAGMENT_UNIFORM_VECTORS);
          HEAP32[params >> 2] = result * 4;
          return;
        }
       case 35659:
        {
          var result = Module.ctx.getParameter(Module.ctx.MAX_VARYING_VECTORS);
          HEAP32[params >> 2] = result * 4;
          return;
        }
       case 34929:
        pname = Module.ctx.MAX_COMBINED_TEXTURE_IMAGE_UNITS;
        break;
      }
      glGetIntegerv(pname, params);
    });
    GL.shaderTypes = {};
    GL.shaderSources = {};
    GL.shaderOriginalSources = {};
    var glCreateShader = _glCreateShader;
    _glCreateShader = (function(shaderType) {
      var id = glCreateShader(shaderType);
      GL.shaderTypes[id] = shaderType;
      return id;
    });
    var glShaderSource = _glShaderSource;
    _glShaderSource = (function(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      GL.shaderOriginalSources[shader] = source;
      if (GL.shaderTypes[shader] == Module.ctx.VERTEX_SHADER) {
        source = "attribute vec4 a_position; \n                      uniform mat4 u_modelView;  \n                      uniform mat4 u_projection; \n" + source.replace(/ftransform\(\)/g, "u_projection * u_modelView * a_position").replace(/gl_Vertex/g, "a_position").replace(/gl_ModelViewMatrix/g, "u_modelView").replace(/gl_ProjectionMatrix/g, "u_projection").replace(/gl_ModelViewProjectionMatrix/g, "u_modelView * u_projection").replace(/gl_ModelViewMatrixTranspose\[2\]/g, "vec3(u_modelView[0][0], u_modelView[1][0], u_modelView[2][0])");
        for (var i = 0; i <= 6; i++) {
          var old = source;
          source = source.replace(new RegExp("gl_TexCoord\\[" + i + "\\]", "g"), "v_texCoord" + i).replace(new RegExp("gl_MultiTexCoord" + i, "g"), "a_texCoord" + i);
          if (source != old) {
            source = "attribute vec4 a_texCoord" + i + "; \n                          varying vec4 v_texCoord" + i + ";   \n" + source;
          }
        }
        if (source.indexOf("gl_Color") >= 0) {
          source = "attribute vec4 a_color; \n                        varying vec4 v_color;   \n" + source.replace(/gl_Color/g, "a_color").replace(/gl_FrontColor/g, "v_color");
        }
        if (source.indexOf("gl_FogFragCoord") >= 0) {
          source = "varying float v_fogCoord;   \n" + source.replace(/gl_FogFragCoord/g, "v_fogCoord");
        }
      } else {
        for (var i = 0; i <= 6; i++) {
          var old = 0;
          source = source.replace(new RegExp("gl_TexCoord\\[" + i + "\\]", "g"), "v_texCoord" + i);
          if (source != old) {
            source = "varying vec4 v_texCoord" + i + ";   \n" + source;
          }
        }
        if (source.indexOf("gl_Color") >= 0) {
          source = "varying vec4 v_color; \n" + source.replace(/gl_Color/g, "v_color");
        }
        source = source.replace(/gl_Fog.color/g, "vec4(0.0)");
        source = "precision mediump float;\n" + source;
      }
      GL.shaderSources[shader] = source;
      Module.ctx.shaderSource(GL.shaders[shader], source);
    });
    var glCompileShader = _glCompileShader;
    _glCompileShader = (function(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
      if (!Module.ctx.getShaderParameter(GL.shaders[shader], Module.ctx.COMPILE_STATUS)) {
        console.log("Failed to compile shader: " + Module.ctx.getShaderInfoLog(GL.shaders[shader]));
        console.log("Type: " + GL.shaderTypes[shader]);
        console.log("Original source: " + GL.shaderOriginalSources[shader]);
        console.log("Source: " + GL.shaderSources[shader]);
        throw "Shader compilation halt";
      }
    });
  }),
  procReplacements: {
    glCreateShaderObjectARB: "glCreateShader",
    glCreateProgramObjectARB: "glCreateProgram",
    glAttachObjectARB: "glAttachShader",
    glUseProgramObjectARB: "glUseProgram"
  },
  procs: {
    glDeleteObjectARB: (function(id) {
      if (GL.programs[id]) {
        _glDeleteProgram(id);
      } else if (GL.shaders[id]) {
        _glDeleteShader(id);
      } else {
        console.log("WARNING: deleteObjectARB received invalid id: " + id);
      }
    }),
    glGetObjectParameterivARB: (function(id, type, result) {
      if (GL.programs[id]) {
        if (type == 35716) {
          HEAP32[result >> 2] = Module.ctx.getProgramInfoLog(GL.programs[id]).length;
          return;
        }
        _glGetProgramiv(id, type, result);
      } else if (GL.shaders[id]) {
        if (type == 35716) {
          HEAP32[result >> 2] = Module.ctx.getShaderInfoLog(GL.shaders[id]).length;
          return;
        }
        _glGetShaderiv(id, type, result);
      } else {
        console.log("WARNING: getObjectParameterivARB received invalid id: " + id);
      }
    }),
    glGetInfoLogARB: (function(id, maxLength, length, infoLog) {
      if (GL.programs[id]) {
        _glGetProgramInfoLog(id, maxLength, length, infoLog);
      } else if (GL.shaders[id]) {
        _glGetShaderInfoLog(id, maxLength, length, infoLog);
      } else {
        console.log("WARNING: getObjectParameterivARB received invalid id: " + id);
      }
    }),
    glBindProgramARB: (function(type, id) {
      assert(id == 0);
    })
  },
  getProcAddress: (function(name) {
    name = GLEmulation.procReplacements[name] || name;
    var func = GLEmulation.procs[name];
    if (!func) {
      try {
        try {
          func = eval("_" + name);
        } catch (e) {
          if (name.substr(-3) == "ARB") name = name.substr(0, name.length - 3);
          func = eval("_" + name);
        }
      } catch (e) {
        console.log("WARNING: getProcAddress failed for " + name);
        func = (function() {
          console.log("WARNING: empty replacement for " + name + " called, no-op");
          return 0;
        });
      }
    }
    return Runtime.addFunction(func);
  })
};

function _SDL_GL_GetProcAddress(name_) {
  return GLEmulation.getProcAddress(Pointer_stringify(name_));
}

function _SDL_GL_SwapBuffers() {}

function _SDL_InitSubSystem(flags) {
  return 0;
}

function _SDL_NumJoysticks() {
  return 0;
}

function _SDL_RWFromFile(filename, mode) {
  return filename;
}

function _SDL_EnableUNICODE(on) {
  var ret = SDL.unicode || 0;
  SDL.unicode = on;
  return ret;
}

function _SDL_AddTimer(interval, callback, param) {
  return window.setTimeout((function() {
    FUNCTION_TABLE[callback](interval, param);
  }), interval);
}

function _SDL_RemoveTimer(id) {
  window.clearTimeout(id);
  return true;
}

var GLUT = {
  initTime: null,
  idleFunc: null,
  displayFunc: null,
  keyboardFunc: null,
  keyboardUpFunc: null,
  specialFunc: null,
  specialUpFunc: null,
  reshapeFunc: null,
  motionFunc: null,
  passiveMotionFunc: null,
  mouseFunc: null,
  lastX: 0,
  lastY: 0,
  buttons: 0,
  modifiers: 0,
  initWindowWidth: 256,
  initWindowHeight: 256,
  windowX: 0,
  windowY: 0,
  windowWidth: 0,
  windowHeight: 0,
  savePosition: (function(event) {
    GLUT.lastX = event["clientX"] - Module["canvas"].offsetLeft;
    GLUT.lastY = event["clientY"] - Module["canvas"].offsetTop;
  }),
  saveModifiers: (function(event) {
    GLUT.modifiers = 0;
    if (event["shiftKey"]) GLUT.modifiers += 1;
    if (event["ctrlKey"]) GLUT.modifiers += 2;
    if (event["altKey"]) GLUT.modifiers += 4;
  }),
  onMousemove: (function(event) {
    var newX = event["clientX"] - Module["canvas"].offsetLeft;
    var newY = event["clientY"] - Module["canvas"].offsetTop;
    if (newX == GLUT.lastX && newY == GLUT.lastY) return;
    GLUT.savePosition(event);
    if (GLUT.buttons == 0 && event.target == Module["canvas"] && GLUT.passiveMotionFunc) {
      event.preventDefault();
      GLUT.saveModifiers(event);
      FUNCTION_TABLE[GLUT.passiveMotionFunc](GLUT.lastX, GLUT.lastY);
    } else if (GLUT.buttons != 0 && GLUT.motionFunc) {
      event.preventDefault();
      GLUT.saveModifiers(event);
      FUNCTION_TABLE[GLUT.motionFunc](GLUT.lastX, GLUT.lastY);
    }
  }),
  getSpecialKey: (function(keycode) {
    var key = null;
    switch (keycode) {
     case 112:
      key = 1;
      break;
     case 113:
      key = 2;
      break;
     case 114:
      key = 3;
      break;
     case 115:
      key = 4;
      break;
     case 116:
      key = 5;
      break;
     case 117:
      key = 6;
      break;
     case 118:
      key = 7;
      break;
     case 119:
      key = 8;
      break;
     case 120:
      key = 9;
      break;
     case 121:
      key = 10;
      break;
     case 122:
      key = 11;
      break;
     case 123:
      key = 12;
      break;
     case 37:
      key = 100;
      break;
     case 38:
      key = 101;
      break;
     case 39:
      key = 102;
      break;
     case 40:
      key = 103;
      break;
     case 33:
      key = 104;
      break;
     case 34:
      key = 105;
      break;
     case 36:
      key = 106;
      break;
     case 35:
      key = 107;
      break;
     case 45:
      key = 108;
      break;
     case 16:
     case 5:
      key = 112;
      break;
     case 6:
      key = 113;
      break;
     case 17:
     case 3:
      key = 114;
      break;
     case 4:
      key = 115;
      break;
     case 18:
     case 2:
      key = 116;
      break;
     case 1:
      key = 117;
      break;
    }
    return key;
  }),
  getASCIIKey: (function(event) {
    if (event["ctrlKey"] || event["altKey"] || event["metaKey"]) return null;
    var keycode = event["keyCode"];
    if (48 <= keycode && keycode <= 57) return keycode;
    if (65 <= keycode && keycode <= 90) return event["shiftKey"] ? keycode : keycode + 32;
    if (106 <= keycode && keycode <= 111) return keycode - 106 + 42;
    switch (keycode) {
     case 27:
     case 32:
     case 61:
      return keycode;
    }
    var s = event["shiftKey"];
    switch (keycode) {
     case 186:
      return s ? 58 : 59;
     case 187:
      return s ? 43 : 61;
     case 188:
      return s ? 60 : 44;
     case 189:
      return s ? 95 : 45;
     case 190:
      return s ? 62 : 46;
     case 191:
      return s ? 63 : 47;
     case 219:
      return s ? 123 : 91;
     case 220:
      return s ? 124 : 47;
     case 221:
      return s ? 125 : 93;
     case 222:
      return s ? 34 : 39;
    }
    return null;
  }),
  onKeydown: (function(event) {
    if (GLUT.specialFunc || GLUT.keyboardFunc) {
      var key = GLUT.getSpecialKey(event["keyCode"]);
      if (key !== null) {
        if (GLUT.specialFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          FUNCTION_TABLE[GLUT.specialFunc](key, GLUT.lastX, GLUT.lastY);
        }
      } else {
        key = GLUT.getASCIIKey(event);
        if (key !== null && GLUT.keyboardFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          FUNCTION_TABLE[GLUT.keyboardFunc](key, GLUT.lastX, GLUT.lastY);
        }
      }
    }
  }),
  onKeyup: (function(event) {
    if (GLUT.specialUpFunc || GLUT.keyboardUpFunc) {
      var key = GLUT.getSpecialKey(event["keyCode"]);
      if (key !== null) {
        if (GLUT.specialUpFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          FUNCTION_TABLE[GLUT.specialUpFunc](key, GLUT.lastX, GLUT.lastY);
        }
      } else {
        key = GLUT.getASCIIKey(event);
        if (key !== null && GLUT.keyboardUpFunc) {
          event.preventDefault();
          GLUT.saveModifiers(event);
          FUNCTION_TABLE[GLUT.keyboardUpFunc](key, GLUT.lastX, GLUT.lastY);
        }
      }
    }
  }),
  onMouseButtonDown: (function(event) {
    GLUT.savePosition(event);
    GLUT.buttons |= 1 << event["button"];
    if (event.target == Module["canvas"] && GLUT.mouseFunc) {
      try {
        event.target.setCapture();
      } catch (e) {}
      event.preventDefault();
      GLUT.saveModifiers(event);
      FUNCTION_TABLE[GLUT.mouseFunc](event["button"], 0, GLUT.lastX, GLUT.lastY);
    }
  }),
  onMouseButtonUp: (function(event) {
    GLUT.savePosition(event);
    GLUT.buttons &= ~(1 << event["button"]);
    if (GLUT.mouseFunc) {
      event.preventDefault();
      GLUT.saveModifiers(event);
      FUNCTION_TABLE[GLUT.mouseFunc](event["button"], 1, GLUT.lastX, GLUT.lastY);
    }
  }),
  onFullScreenEventChange: (function(event) {
    var width;
    var height;
    if (document.fullScreen || document.mozFullScreen || document.webkitIsFullScreen) {
      width = screen["width"];
      height = screen["height"];
    } else {
      width = GLUT.windowWidth;
      height = GLUT.windowHeight;
      document.removeEventListener("fullscreenchange", GLUT.onFullScreenEventChange, true);
      document.removeEventListener("mozfullscreenchange", GLUT.onFullScreenEventChange, true);
      document.removeEventListener("webkitfullscreenchange", GLUT.onFullScreenEventChange, true);
    }
    Module["canvas"].width = width;
    Module["canvas"].height = height;
    if (GLUT.reshapeFunc) {
      FUNCTION_TABLE[GLUT.reshapeFunc](width, height);
    }
    _glutPostRedisplay();
  }),
  requestFullScreen: (function() {
    var RFS = Module["canvas"]["requestFullscreen"] || Module["canvas"]["requestFullScreen"] || Module["canvas"]["mozRequestFullScreen"] || Module["canvas"]["webkitRequestFullScreen"] || (function() {});
    RFS.apply(Module["canvas"], []);
  }),
  cancelFullScreen: (function() {
    var CFS = document["exitFullscreen"] || document["cancelFullScreen"] || document["mozCancelFullScreen"] || document["webkitCancelFullScreen"] || (function() {});
    CFS.apply(document, []);
  }),
  requestAnimationFrame: (function(func) {
    var RAF = window["requestAnimationFrame"] || window["mozRequestAnimationFrame"] || window["webkitRequestAnimationFrame"] || window["msRequestAnimationFrame"] || window["setTimeout"];
    RAF.apply(window, [ func ]);
  })
};

function _glutGetModifiers() {
  return GLUT.modifiers;
}

function _glutInit(argcp, argv) {
  GLUT.initTime = Date.now();
}

function _glutInitWindowSize(width, height) {
  Module["canvas"].width = GLUT.initWindowWidth = width;
  Module["canvas"].height = GLUT.initWindowHeight = height;
}

function _glutInitWindowPosition(x, y) {}

function _glutGet(type) {
  switch (type) {
   case 100:
    return 0;
   case 101:
    return 0;
   case 102:
    return Module["canvas"].width;
   case 103:
    return Module["canvas"].height;
   case 500:
    return 0;
   case 501:
    return 0;
   case 502:
    return GLUT.initWindowWidth;
   case 503:
    return GLUT.initWindowHeight;
   case 700:
    var now = Date.now();
    return now - GLUT.initTime;
   default:
    throw "glutGet(" + type + ") not implemented yet";
  }
}

function _glutIdleFunc(func) {
  var callback = (function() {
    if (GLUT.idleFunc) {
      FUNCTION_TABLE[GLUT.idleFunc]();
      window.setTimeout(callback, 0);
    }
  });
  if (!GLUT.idleFunc) window.setTimeout(callback, 0);
  GLUT.idleFunc = func;
}

function _glutTimerFunc(msec, func, value) {
  window.setTimeout((function() {
    FUNCTION_TABLE[func](value);
  }), msec);
}

function _glutDisplayFunc(func) {
  GLUT.displayFunc = func;
}

function _glutKeyboardFunc(func) {
  GLUT.keyboardFunc = func;
}

function _glutKeyboardUpFunc(func) {
  GLUT.keyboardUpFunc = func;
}

function _glutSpecialFunc(func) {
  GLUT.specialFunc = func;
}

function _glutSpecialUpFunc(func) {
  GLUT.specialUpFunc = func;
}

function _glutReshapeFunc(func) {
  GLUT.reshapeFunc = func;
}

function _glutMotionFunc(func) {
  GLUT.motionFunc = func;
}

function _glutPassiveMotionFunc(func) {
  GLUT.passiveMotionFunc = func;
}

function _glutMouseFunc(func) {
  GLUT.mouseFunc = func;
}

function _glutCreateWindow(name) {
  Module.ctx = Browser.createContext(Module["canvas"], true);
  return 1;
}

function _glutPostRedisplay() {
  if (GLUT.displayFunc) {
    GLUT.requestAnimationFrame(FUNCTION_TABLE[GLUT.displayFunc]);
  }
}

function _glutReshapeWindow(width, height) {
  GLUT.cancelFullScreen();
  Module["canvas"].width = width;
  Module["canvas"].height = height;
  if (GLUT.reshapeFunc) {
    FUNCTION_TABLE[GLUT.reshapeFunc](width, height);
  }
  _glutPostRedisplay();
}

function _glutPositionWindow(x, y) {
  GLUT.cancelFullScreen();
  _glutPostRedisplay();
}

function _glutFullScreen() {
  GLUT.windowX = 0;
  GLUT.windowY = 0;
  GLUT.windowWidth = Module["canvas"].width;
  GLUT.windowHeight = Module["canvas"].height;
  document.addEventListener("fullscreenchange", GLUT.onFullScreenEventChange, true);
  document.addEventListener("mozfullscreenchange", GLUT.onFullScreenEventChange, true);
  document.addEventListener("webkitfullscreenchange", GLUT.onFullScreenEventChange, true);
  GLUT.requestFullScreen();
}

function _glutInitDisplayMode(mode) {}

function _glutSwapBuffers() {}

function _glutMainLoop() {
  window.addEventListener("keydown", GLUT.onKeydown, true);
  window.addEventListener("keyup", GLUT.onKeyup, true);
  window.addEventListener("mousemove", GLUT.onMousemove, true);
  window.addEventListener("mousedown", GLUT.onMouseButtonDown, true);
  window.addEventListener("mouseup", GLUT.onMouseButtonUp, true);
  __ATEXIT__.push({
    func: (function() {
      window.removeEventListener("keydown", GLUT.onKeydown, true);
      window.removeEventListener("keyup", GLUT.onKeyup, true);
      window.removeEventListener("mousemove", GLUT.onMousemove, true);
      window.removeEventListener("mousedown", GLUT.onMouseButtonDown, true);
      window.removeEventListener("mouseup", GLUT.onMouseButtonUp, true);
      Module["canvas"].width = Module["canvas"].height = 1;
    })
  });
  _glutReshapeWindow(Module["canvas"].width, Module["canvas"].height);
  _glutPostRedisplay();
  throw "GLUT mainloop called, simulating infinite loop by throwing so we get right into the JS event loop";
}

function _XOpenDisplay() {
  return 1;
}

function _XCreateWindow(display, parent, x, y, width, height, border_width, depth, class_, visual, valuemask, attributes) {
  Module["canvas"].width = width;
  Module["canvas"].height = height;
  return 2;
}

function _XChangeWindowAttributes() {}

function _XSetWMHints() {}

function _XMapWindow() {}

function _XStoreName() {}

function _XInternAtom(display, name_, hmm) {
  return 0;
}

function _XSendEvent() {}

function _XPending(display) {
  return 0;
}

function _eglGetDisplay(x_display) {
  return 3;
}

function _eglInitialize(display, majorVersion, minorVersion) {
  return 1;
}

function _eglGetConfigs(display, hmm1, hmm2, numConfigs) {
  return 1;
}

function _eglChooseConfig(display, attribList, config, hmm, numConfigs) {
  return 1;
}

function _eglCreateWindowSurface(display, config, hWnd, hmm) {
  return 4;
}

function _eglCreateContext(display, config, hmm, contextAttribs) {
  _glutCreateWindow();
  return 1;
}

function _eglMakeCurrent(display, surface, surface_, context) {
  return 1;
}

function _eglSwapBuffers() {}

__ATINIT__.unshift({
  func: (function() {
    if (!Module["noFSInit"] && !FS.init.initialized) FS.init();
  })
});

__ATMAIN__.push({
  func: (function() {
    FS.ignorePermissions = false;
  })
});

__ATEXIT__.push({
  func: (function() {
    FS.quit();
  })
});

___setErrNo(0);

_fgetc.ret = allocate([ 0 ], "i8", ALLOC_STATIC);

___buildEnvironment(ENV);

_fputc.ret = allocate([ 0 ], "i8", ALLOC_STATIC);

_llvm_eh_exception.buf = allocate(12, "void*", ALLOC_STATIC);

GLEmulation.init();

Module.callMain = function callMain(args) {
  var argc = args.length + 1;
  function pad() {
    for (var i = 0; i < 4 - 1; i++) {
      argv.push(0);
    }
  }
  var argv = [ allocate(intArrayFromString("/bin/this.program"), "i8", ALLOC_STATIC) ];
  pad();
  for (var i = 0; i < argc - 1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), "i8", ALLOC_STATIC));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, "i32", ALLOC_STATIC);
  return _main(argc, argv, 0);
};

var _DebuggerFrame_class;

var _DebuggerObject_class;

var __ZN2js8Debugger7jsclassE;

var __ZN2js8Debugger10propertiesE;

var __ZN2js8Debugger7methodsE;

var _DebuggerScript_class;

var __ZL25DebuggerScript_properties;

var __ZL22DebuggerScript_methods;

var _DebuggerArguments_class;

var __ZL24DebuggerFrame_properties;

var __ZL21DebuggerFrame_methods;

var __ZL25DebuggerObject_properties;

var __ZL22DebuggerObject_methods;

var __ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE;

var __ZTVN2js11WeakMapBaseE;

var __ZN2jsL21GlobalDebuggees_classE;

var __ZN16JSExternalString14str_finalizersE;

var __ZN2js7unicode11js_charinfoE;

var __ZN2js7unicode6index1E;

var __ZN2js7unicode6index2E;

var _stdout;

var _stderr;

var __ZL33fatal_error_handler_nesting_depth;

var __ZN2v88internalL14kCachedPowers8E;

var _JSVAL_NULL;

var _JSVAL_ZERO;

var _JSVAL_ONE;

var _JSVAL_FALSE;

var _JSVAL_TRUE;

var _JSVAL_VOID;

var __ZL22js_NewRuntimeWasCalled_b;

var __ZL6v2smap;

var _js_dummy_class;

var __ZL20standard_class_atoms;

var __ZL20standard_class_names;

var __ZL22object_prototype_names;

var __ZL15prop_iter_class;

var _stdin;

var _js_CStringsAreUTF8;

var __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix;

var __ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix;

__ATINIT__ = __ATINIT__.concat([ {
  func: __GLOBAL__I_a
}, {
  func: __GLOBAL__I_a891
} ]);

var __ZN2js10ArrayClassE;

var __ZN2js14SlowArrayClassE;

var __ZL13array_methods;

var __ZL20array_static_methods;

var __ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma;

var __ZN11JSAtomState17commonAtomsOffsetE;

var __ZN11JSAtomState15lazyAtomsOffsetE;

var _js_common_atom_names;

var _js_common_atom_count;

var __ZN2js12BooleanClassE;

var __ZL15boolean_methods;

var _js_ErrorFormatString;

var __ZN2js5crashL8gGCStackE;

var __ZN2js5crashL11gErrorStackE;

var __ZN2js5crashL11gRingBufferE;

var __ZN2js9DateClassE;

var __ZL19date_static_methods;

var __ZL12date_methods;

var __ZL8LocalTZA;

var __ZL15firstDayOfMonth;

var __ZL16yearStartingWith;

var __ZL3wtb;

var __ZL3ttb;

var __ZL4days;

var __ZL6months;

var _js_NullDebugHooks;

var __ZL10gLastError;

var __ZL8stub_ops;

var _tens;

var _bigtens;

var _p05;

var _tinytens;

var _js_SrcNoteSpec;

var __ZL13statementName;

var __ZN2js10ErrorClassE;

var __ZL17exception_methods;

var __ZN2js26StrictArgumentsObjectClassE;

var __ZN2js26NormalArgumentsObjectClassE;

var __ZN2js12DeclEnvClassE;

var __ZN2js9CallClassE;

var __ZL15poisonPillProps;

var __ZN2js13FunctionClassE;

var __ZN2js16function_methodsE;

var __ZN2js2gc16slotsToThingKindE;

var __ZN2js2gc5Arena10ThingSizesE;

var __ZN2js2gc5Arena17FirstThingOffsetsE;

var __ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map;

var __ZN2js8gcReasonE;

var __ZN2js9gcReasonsE;

var __ZN2js13newChunkCountE;

var __ZN2js17destroyChunkCountE;

var __ZL19defaultHashAllocOps;

var __ZN2js5types15emptyTypeObjectE;

var __ZTV18TypeConstraintProp;

var __ZTV22TypeConstraintCallProp;

var __ZTV24TypeConstraintSetElement;

var __ZTV18TypeConstraintCall;

var __ZTV19TypeConstraintArith;

var __ZTV27TypeConstraintTransformThis;

var __ZTV27TypeConstraintPropagateThis;

var __ZTV26TypeConstraintFreezeGlobal;

var __ZTVN2js5types14TypeConstraintE;

var __ZTV31TypeConstraintFreezeOwnProperty;

var __ZTV31TypeConstraintFreezeObjectFlags;

var __ZTV34TypeConstraintFreezeObjectFlagsSet;

var __ZTV27TypeConstraintFreezeTypeTag;

var __ZTV20TypeConstraintFreeze;

var __ZTV27TypeConstraintLazyArguments;

var __ZTV27TypeConstraintSubsetBarrier;

var __ZTV29TypeConstraintFilterPrimitive;

var __ZTV20TypeConstraintSubset;

var __ZTV33TypeConstraintClearDefiniteSingle;

var __ZTV33TypeConstraintClearDefiniteSetter;

var __ZZL15InferSpewActiveN2js5types11SpewChannelEE6active;

var __ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b;

var _js_NoSuchMethodClass;

var __ZTV23GenericInterruptEnablerIiE;

var __ZTVN2js17InterpreterFrames20InterruptEnablerBaseE;

var __ZN2js13IteratorClassE;

var _sCustomIteratorCount;

var __ZL16iterator_methods;

var __ZN2js18StopIterationClassE;

var __ZN2js14GeneratorClassE;

var __ZL17generator_methods;

var __ZN2js9MathClassE;

var __ZL19math_static_methods;

var __ZL14math_constants;

var __ZL16number_functions;

var __ZN2js11NumberClassE;

var __ZL14number_methods;

var _js_NaN;

var _js_PositiveInfinity;

var _js_NegativeInfinity;

var __ZL16number_constants;

var __ZN2js5Shape15sharedNonNativeE;

var __ZN2js11ObjectClassE;

var _object_props;

var _sSetProtoCalled;

var _object_methods;

var _object_static_methods;

var __ZN2js9WithClassE;

var __ZN2js10BlockClassE;

var __ZL19lazy_prototype_init;

var __ZN2js9JSONClassE;

var __ZL19json_static_methods;

var _js_CodeSpec;

var _js_NumCodeSpecs;

var __ZL9CodeToken;

var __ZL10var_prefix;

var _table;

var __ZL6pm_fns;

var __ZL8pm_class;

var __ZL8pm_props;

var __ZL9pm_consts;

var __str23014;

var __ZN2js6Probes15ProfilingActiveE;

var __ZTVN2js14JSProxyHandlerE;

var __ZL27sScriptedProxyHandlerFamily;

var __ZTV22JSScriptedProxyHandler;

var __ZN22JSScriptedProxyHandler9singletonE;

var __ZN2js16ObjectProxyClassE;

var __ZN2js21OuterWindowProxyClassE;

var __ZN2js18FunctionProxyClassE;

var __ZL14static_methods;

var __ZN2js19CallableObjectClassE;

var __ZN2js10ProxyClassE;

var __str93064;

var __ZN2js8aopNamesE;

var __ZN2js10binopNamesE;

var __ZN2js9unopNamesE;

var __ZN2js13nodeTypeNamesE;

var __ZN2js13callbackNamesE;

var __ZL14static_methods3391;

var __ZN2js20regexp_statics_classE;

var __ZL19regexp_static_props;

var __ZN2js11RegExpClassE;

var __ZL14regexp_methods;

var __ZL8keywords;

var __ZN2js11ScriptClassE;

var __ZL16string_functions;

var _js_empty_ucstr;

var _js_EmptySubString;

var __ZN2js11StringClassE;

var __ZL14string_methods;

var __ZL21string_static_methods;

var __ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr;

var __ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table;

var __ZL21js_uriUnescaped_ucstr;

var __ZL29js_uriReservedPlusPound_ucstr;

var __ZN2js11ArrayBuffer9slowClassE;

var __ZN2js16ArrayBufferClassE;

var __ZN2js11ArrayBuffer7jspropsE;

var __ZN2js10TypedArray7jspropsE;

var __ZN9Int8Array7jsfuncsE;

var __ZN10Uint8Array7jsfuncsE;

var __ZN10Int16Array7jsfuncsE;

var __ZN11Uint16Array7jsfuncsE;

var __ZN10Int32Array7jsfuncsE;

var __ZN11Uint32Array7jsfuncsE;

var __ZN12Float32Array7jsfuncsE;

var __ZN12Float64Array7jsfuncsE;

var __ZN17Uint8ClampedArray7jsfuncsE;

var __ZN2js10TypedArray11fastClassesE;

var __ZN2js10TypedArray11slowClassesE;

var __ZN2js12WeakMapClassE;

var __ZL16weak_map_methods;

var __ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE;

var __ZL14sWrapperFamily;

var __ZTV9JSWrapper;

var __ZN9JSWrapper9singletonE;

var __ZN25JSCrossCompartmentWrapper9singletonE;

var __ZTV25JSCrossCompartmentWrapper;

var __ZL10xdrmem_ops;

var __ZZ11JS_XDRBytesE6padbuf;

var _sE4XObjectsCreated;

var __ZN2js14NamespaceClassE;

var __ZL17namespace_methods;

var __ZN2js10QNameClassE;

var __ZN2js18AttributeNameClassE;

var __ZN2js12AnyNameClassE;

var __ZL13qname_methods;

var __ZL16xml_static_props;

var __ZN2js8XMLClassE;

var _js_xml_class_str;

var __ZL11xml_methods;

var __ZL18xml_static_methods;

var __ZL15namespace_props;

var _js_XMLFilterClass;

var __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr;

var __ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr;

var __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr;

var __ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr;

var __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr;

var __ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr;

var __ZL11qname_props;

var __ZL7escapes;

var __ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset;

var _jsc_pcre_utf8_table1;

var _jsc_pcre_utf8_table2;

var _jsc_pcre_utf8_table3;

var __ZL9ucp_table;

var __gm_;

var _mparams;

var __impure_ptr;

var __ZSt7nothrow;

var __ZL13__new_handler;

var __ZTVSt9bad_alloc;

var __ZTVSt20bad_array_new_length;

var __ZTVN10__cxxabiv120__si_class_type_infoE;

var __ZTISt9exception;

var __ZTISt9bad_alloc;

var __ZTISt20bad_array_new_length;

var __ZN2js14BreakpointSiteC1EP8JSScriptPh;

var __ZN2js10BreakpointC1EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject;

var __ZN2js8DebuggerC1EP9JSContextP8JSObject;

var __ZN2js8DebuggerD1Ev;

var __ZN2js10StackSpaceC1Ev;

var __ZN2js10StackSpaceD1Ev;

var __ZN2js12ContextStackC1EP9JSContext;

var __ZN2js12ContextStackD1Ev;

var __ZN2js9StackIterC1EP9JSContextNS0_11SavedOptionE;

var __ZN2js13AllFramesIterC1ERNS_10StackSpaceE;

var __ZN9JSRuntimeC1Ev;

var __ZN9JSRuntimeD1Ev;

var __ZN2js7SCInputC1EP9JSContextPKyj;

var __ZN2js8SCOutputC1EP9JSContext;

var __ZN2js10ThreadDataC1Ev;

var __ZN2js10ThreadDataD1Ev;

var __ZN9JSContextC1EP9JSRuntime;

var __ZN9JSContextD1Ev;

var __ZN13JSCompartmentC1EP9JSRuntime;

var __ZN13JSCompartmentD1Ev;

var __ZN2js5crash5StackC1Ey;

var __ZN2js5crash4RingC1Ey;

var __ZN15JSCodeGeneratorC1EPN2js6ParserEj;

var __ZN15JSCodeGeneratorD1Ev;

var __ZN2JS23AutoPreserveCompartmentC1EP9JSContext;

var __ZN2JS23AutoPreserveCompartmentD1Ev;

var __ZN2JS21AutoSwitchCompartmentC1EP9JSContextP13JSCompartment;

var __ZN2JS21AutoSwitchCompartmentC1EP9JSContextP8JSObject;

var __ZN2JS21AutoSwitchCompartmentD1Ev;

var __ZN2js8GCMarkerC1EP9JSContext;

var __ZN2js8GCMarkerD1Ev;

var __ZN13AutoGCSessionC1EP9JSContext;

var __ZN13AutoGCSessionD1Ev;

var __ZN2js7GCTimerC1EP9JSRuntimeP13JSCompartment;

var __ZN2js5types17TypeScriptNestingD1Ev;

var __ZN2js5types15TypeCompartmentD1Ev;

var __ZN2js9MathCacheC1Ev;

var __ZN2js12ToCStringBufC1Ev;

var __ZN2js12ToCStringBufD1Ev;

var __ZN2js8PropDescC1Ev;

var __ZN2js6ParserC1EP9JSContextP12JSPrincipalsPNS_10StackFrameEb;

var __ZN2js6ParserD1Ev;

var __ZN2js8CompilerC1EP9JSContextP12JSPrincipalsPNS_10StackFrameE;

var __ZN2js14JSProxyHandlerD1Ev;

var __ZN22JSScriptedProxyHandlerC1Ev;

var __ZN22JSScriptedProxyHandlerD1Ev;

var __ZN22JSScriptedProxyHandlerD2Ev;

var __ZN2js11TokenStreamC1EP9JSContext;

var __ZN2js11TokenStreamD1Ev;

var __ZN2js11ArrayBufferD1Ev;

var __ZN9JSWrapperC1Ej;

var __ZN9JSWrapperD1Ev;

var __ZN2js10ForceFrameC1EP9JSContextP8JSObject;

var __ZN2js10ForceFrameD1Ev;

var __ZN2js15AutoCompartmentC1EP9JSContextP8JSObject;

var __ZN2js15AutoCompartmentD1Ev;

var __ZN2js11ErrorCopierD1Ev;

var __ZN25JSCrossCompartmentWrapperC1Ej;

var __ZN25JSCrossCompartmentWrapperD1Ev;

var __ZN25JSCrossCompartmentWrapperD2Ev;

var __ZN2js14XDRScriptStateC1EP10JSXDRState;

var __ZN2js14XDRScriptStateD1Ev;

var __ZN2JS15PerfMeasurementC1ENS0_9EventMaskE;

var __ZN2JS15PerfMeasurementD1Ev;

var __ZNSt9bad_allocC1Ev;

var __ZNSt9bad_allocD1Ev;

var __ZNSt20bad_array_new_lengthC1Ev;

var __ZNSt20bad_array_new_lengthD1Ev;

var __ZNSt20bad_array_new_lengthD2Ev;

_DebuggerFrame_class = allocate([ 0, 0, 0, 0, 769, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_DebuggerObject_class = allocate([ 0, 0, 0, 0, 257, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 304, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4 = allocate([ 104, 105, 116, 0 ], "i8", ALLOC_STATIC);

__ZN2js8Debugger7jsclassE = allocate([ 0, 0, 0, 0, 1793, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 308, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str11 = allocate([ 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12 = allocate([ 103, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14 = allocate([ 115, 101, 116, 32, 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15 = allocate([ 103, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17 = allocate([ 115, 101, 116, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18 = allocate([ 103, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 115, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20 = allocate([ 115, 101, 116, 32, 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21 = allocate([ 117, 110, 99, 97, 117, 103, 104, 116, 69, 120, 99, 101, 112, 116, 105, 111, 110, 72, 111, 111, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 97, 100, 100, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23 = allocate([ 97, 100, 100, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 114, 101, 109, 111, 118, 101, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25 = allocate([ 114, 101, 109, 111, 118, 101, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 104, 97, 115, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27 = allocate([ 104, 97, 115, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28 = allocate([ 103, 101, 116, 68, 101, 98, 117, 103, 103, 101, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29 = allocate([ 103, 101, 116, 78, 101, 119, 101, 115, 116, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30 = allocate([ 99, 108, 101, 97, 114, 65, 108, 108, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31 = allocate([ 101, 110, 97, 98, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32 = allocate([ 111, 110, 68, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33 = allocate([ 111, 110, 69, 120, 99, 101, 112, 116, 105, 111, 110, 85, 110, 119, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34 = allocate([ 111, 110, 78, 101, 119, 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35 = allocate([ 111, 110, 69, 110, 116, 101, 114, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2js8Debugger10propertiesE = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 310, 0, 0, 0, 312, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 314, 0, 0, 0, 316, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 318, 0, 0, 0, 320, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 322, 0, 0, 0, 324, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 326, 0, 0, 0, 328, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 330, 0, 0, 0, 332, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8Debugger7methodsE = allocate([ 0, 0, 0, 0, 334, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 336, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 338, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 340, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 342, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 344, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_DebuggerScript_class = allocate([ 0, 0, 0, 0, 513, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 346, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str37 = allocate([ 117, 114, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38 = allocate([ 115, 116, 97, 114, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39 = allocate([ 108, 105, 110, 101, 67, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40 = allocate([ 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

__ZL25DebuggerScript_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 348, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 350, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 352, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 354, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str41 = allocate([ 103, 101, 116, 67, 104, 105, 108, 100, 83, 99, 114, 105, 112, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42 = allocate([ 103, 101, 116, 65, 108, 108, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43 = allocate([ 103, 101, 116, 76, 105, 110, 101, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44 = allocate([ 103, 101, 116, 79, 102, 102, 115, 101, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str45 = allocate([ 115, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46 = allocate([ 103, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47 = allocate([ 99, 108, 101, 97, 114, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL22DebuggerScript_methods = allocate([ 0, 0, 0, 0, 356, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 358, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 360, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 362, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 364, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 366, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 368, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 370, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str48 = allocate([ 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

_DebuggerArguments_class = allocate([ 0, 0, 0, 0, 256, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str52 = allocate([ 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54 = allocate([ 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55 = allocate([ 111, 108, 100, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59 = allocate([ 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

__ZL24DebuggerFrame_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 372, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 374, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 378, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 380, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 382, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 384, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 386, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 388, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 390, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 392, 0, 0, 0, 394, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str61 = allocate([ 101, 118, 97, 108, 87, 105, 116, 104, 66, 105, 110, 100, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

__ZL21DebuggerFrame_methods = allocate([ 0, 0, 0, 0, 396, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 398, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str63 = allocate([ 112, 114, 111, 116, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65 = allocate([ 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67 = allocate([ 112, 97, 114, 97, 109, 101, 116, 101, 114, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

__ZL25DebuggerObject_properties = allocate([ 0, 0, 0, 0, 0, 72, 0, 0, 400, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 402, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 404, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 406, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 408, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 0, 0, 410, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str72 = allocate([ 100, 101, 108, 101, 116, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

__ZL22DebuggerObject_methods = allocate([ 0, 0, 0, 0, 412, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 414, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 416, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 418, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 420, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 422, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 424, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 426, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 428, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 430, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 432, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 434, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 436, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZTVN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 438, 0, 0, 0, 440, 0, 0, 0, 442, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js11WeakMapBaseE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str82 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89 = allocate([ 103, 101, 116, 32, 115, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90 = allocate([ 103, 101, 116, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91 = allocate([ 103, 101, 116, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92 = allocate([ 103, 101, 116, 32, 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93 = allocate([ 103, 101, 116, 32, 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94 = allocate([ 103, 101, 116, 32, 112, 114, 111, 116, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 101, 118, 97, 108, 87, 105, 116, 104, 66, 105, 110, 100, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 32, 101, 118, 97, 108, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100 = allocate([ 115, 116, 97, 99, 107, 32, 102, 114, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 70, 114, 97, 109, 101, 46, 115, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102 = allocate([ 115, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103 = allocate([ 103, 101, 116, 32, 111, 110, 83, 116, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104 = allocate([ 103, 101, 116, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str105 = allocate([ 103, 101, 116, 32, 116, 104, 105, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str106 = allocate([ 103, 101, 116, 32, 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str107 = allocate([ 103, 101, 116, 32, 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str108 = allocate([ 103, 101, 116, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str109 = allocate([ 103, 101, 116, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str110 = allocate([ 103, 101, 116, 32, 99, 97, 108, 108, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111 = allocate([ 103, 101, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112 = allocate([ 103, 101, 116, 65, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113 = allocate([ 103, 101, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 99, 108, 101, 97, 114, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str115 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 115, 101, 116, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str116 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 103, 101, 116, 79, 102, 102, 115, 101, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str117 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 83, 99, 114, 105, 112, 116, 46, 103, 101, 116, 76, 105, 110, 101, 79, 102, 102, 115, 101, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str118 = allocate([ 103, 101, 116, 32, 108, 105, 110, 101, 67, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str119 = allocate([ 103, 101, 116, 32, 115, 116, 97, 114, 116, 76, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str120 = allocate([ 103, 101, 116, 32, 117, 114, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122 = allocate([ 71, 108, 111, 98, 97, 108, 68, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2jsL21GlobalDebuggees_classE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 446, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str156 = allocate([ 65, 98, 111, 117, 116, 32, 116, 111, 32, 100, 101, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 110, 118, 97, 108, 105, 100, 32, 115, 108, 111, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1157 = allocate([ 47, 100, 105, 115, 107, 47, 108, 111, 99, 97, 108, 47, 106, 116, 101, 114, 114, 97, 99, 101, 47, 98, 117, 105, 108, 100, 98, 111, 116, 47, 115, 108, 97, 118, 101, 47, 106, 115, 95, 106, 115, 95, 66, 117, 105, 108, 100, 95, 65, 108, 108, 47, 98, 117, 105, 108, 100, 47, 98, 117, 105, 108, 100, 101, 114, 47, 98, 117, 105, 108, 100, 47, 109, 111, 122, 105, 108, 108, 97, 45, 99, 101, 110, 116, 114, 97, 108, 47, 106, 115, 47, 115, 114, 99, 47, 118, 109, 47, 83, 116, 97, 99, 107, 46, 99, 112, 112, 0 ], "i8", ALLOC_STATIC);

__ZN16JSExternalString14str_finalizersE = allocate(32, "*", ALLOC_STATIC);

STRING_TABLE.__ZN2js13StaticStrings11toSmallCharE = allocate([ 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 255, 255, 255, 255, 255, 255, 255, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255 ], "i8", ALLOC_STATIC);

__ZN2js7unicode11js_charinfoE = allocate([ 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, undef, 0, 0, 0, 0, 4, undef, 0, 0, 32, 0, 2, undef, -32, 0, 0, 0, 2, undef, 0, 0, 0, 0, 2, undef, 743, 0, 0, 0, 2, undef, 121, 0, 0, 0, 2, undef, 0, 0, 1, 0, 2, undef, -1, 0, 0, 0, 2, undef, 0, 0, -199, 0, 2, undef, -232, 0, 0, 0, 2, undef, 0, 0, -121, 0, 2, undef, -300, 0, 0, 0, 2, undef, 195, 0, 0, 0, 2, undef, 0, 0, 210, 0, 2, undef, 0, 0, 206, 0, 2, undef, 0, 0, 205, 0, 2, undef, 0, 0, 79, 0, 2, undef, 0, 0, 202, 0, 2, undef, 0, 0, 203, 0, 2, undef, 0, 0, 207, 0, 2, undef, 97, 0, 0, 0, 2, undef, 0, 0, 211, 0, 2, undef, 0, 0, 209, 0, 2, undef, 163, 0, 0, 0, 2, undef, 0, 0, 213, 0, 2, undef, 130, 0, 0, 0, 2, undef, 0, 0, 214, 0, 2, undef, 0, 0, 218, 0, 2, undef, 0, 0, 217, 0, 2, undef, 0, 0, 219, 0, 2, undef, 56, 0, 0, 0, 2, undef, 0, 0, 2, 0, 2, undef, -1, 0, 1, 0, 2, undef, -2, 0, 0, 0, 2, undef, -79, 0, 0, 0, 2, undef, 0, 0, -97, 0, 2, undef, 0, 0, -56, 0, 2, undef, 0, 0, -130, 0, 2, undef, 0, 0, 10795, 0, 2, undef, 0, 0, -163, 0, 2, undef, 0, 0, 10792, 0, 2, undef, 10815, 0, 0, 0, 2, undef, 0, 0, -195, 0, 2, undef, 0, 0, 69, 0, 2, undef, 0, 0, 71, 0, 2, undef, 10783, 0, 0, 0, 2, undef, 10780, 0, 0, 0, 2, undef, 10782, 0, 0, 0, 2, undef, -210, 0, 0, 0, 2, undef, -206, 0, 0, 0, 2, undef, -205, 0, 0, 0, 2, undef, -202, 0, 0, 0, 2, undef, -203, 0, 0, 0, 2, undef, -207, 0, 0, 0, 2, undef, -22643, 0, 613, 0, 10, undef, -209, 0, 0, 0, 2, undef, -211, 0, 0, 0, 2, undef, 10743, 0, 0, 0, 2, undef, 10749, 0, 0, 0, 2, undef, -213, 0, 0, 0, 2, undef, -214, 0, 0, 0, 2, undef, 10727, 0, 0, 0, 2, undef, -218, 0, 0, 0, 2, undef, -69, 0, 0, 0, 2, undef, -217, 0, 0, 0, 2, undef, -71, 0, 0, 0, 2, undef, -219, 0, 0, 0, 2, undef, 84, 0, 0, 0, 4, undef, 0, 0, 38, 0, 2, undef, 0, 0, 37, 0, 2, undef, 0, 0, 64, 0, 2, undef, 0, 0, 63, 0, 2, undef, -38, 0, 0, 0, 2, undef, -37, 0, 0, 0, 2, undef, -31, 0, 0, 0, 2, undef, -64, 0, 0, 0, 2, undef, -63, 0, 0, 0, 2, undef, 0, 0, 8, 0, 2, undef, -62, 0, 0, 0, 2, undef, -57, 0, 0, 0, 2, undef, -47, 0, 0, 0, 2, undef, -54, 0, 0, 0, 2, undef, -8, 0, 0, 0, 2, undef, -86, 0, 0, 0, 2, undef, -80, 0, 0, 0, 2, undef, 7, 0, 0, 0, 2, undef, 0, 0, -60, 0, 2, undef, -96, 0, 0, 0, 2, undef, 0, 0, -7, 0, 2, undef, 0, 0, 80, 0, 2, undef, 0, 0, 0, 0, 16, undef, 0, 0, 15, 0, 2, undef, -15, 0, 0, 0, 2, undef, 0, 0, 48, 0, 2, undef, -48, 0, 0, 0, 2, undef, 0, 0, 0, 0, 36, undef, 0, 0, 7264, 0, 2, undef, -22659, 0, 7545, 0, 10, undef, 3814, 0, 0, 0, 2, undef, -59, 0, 0, 0, 2, undef, 0, 0, -7615, 0, 2, undef, 8, 0, 0, 0, 2, undef, 0, 0, -8, 0, 2, undef, 74, 0, 0, 0, 2, undef, 86, 0, 0, 0, 2, undef, 100, 0, 0, 0, 2, undef, 128, 0, 0, 0, 2, undef, 112, 0, 0, 0, 2, undef, 126, 0, 0, 0, 2, undef, 9, 0, 0, 0, 2, undef, 0, 0, -74, 0, 2, undef, 0, 0, -9, 0, 2, undef, -7205, 0, 0, 0, 2, undef, 0, 0, -86, 0, 2, undef, 0, 0, -100, 0, 2, undef, 0, 0, -112, 0, 2, undef, 0, 0, -128, 0, 2, undef, 0, 0, -126, 0, 2, undef, 0, 0, -7517, 0, 2, undef, 0, 0, -8383, 0, 2, undef, 0, 0, -8262, 0, 2, undef, 0, 0, 28, 0, 2, undef, -28, 0, 0, 0, 2, undef, 0, 0, 16, 0, 2, undef, -16, 0, 0, 0, 2, undef, 0, 0, 26, 0, 0, undef, -26, 0, 0, 0, 0, undef, 0, 0, -10743, 0, 2, undef, 0, 0, -3814, 0, 2, undef, 0, 0, -10727, 0, 2, undef, -10795, 0, 0, 0, 2, undef, -10792, 0, 0, 0, 2, undef, 0, 0, -10780, 0, 2, undef, 0, 0, -10749, 0, 2, undef, 0, 0, -10783, 0, 2, undef, 0, 0, -10782, 0, 2, undef, 0, 0, -10815, 0, 2, undef, -7264, 0, 0, 0, 2, undef ], [ "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8", "i16", 0, "i16", 0, "i8", "i8" ], ALLOC_STATIC);

__ZN2js7unicode6index1E = allocate([ 0, 0, 1, 0, 2, 0, 3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0, 10, 0, 11, 0, 12, 0, 13, 0, 14, 0, 15, 0, 16, 0, 17, 0, 18, 0, 19, 0, 20, 0, 21, 0, 22, 0, 23, 0, 24, 0, 25, 0, 26, 0, 27, 0, 28, 0, 29, 0, 30, 0, 31, 0, 32, 0, 33, 0, 34, 0, 34, 0, 35, 0, 36, 0, 37, 0, 38, 0, 39, 0, 40, 0, 41, 0, 42, 0, 43, 0, 44, 0, 45, 0, 46, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 65, 0, 66, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 91, 0, 92, 0, 34, 0, 93, 0, 94, 0, 95, 0, 96, 0, 97, 0, 98, 0, 34, 0, 99, 0, 26, 0, 100, 0, 26, 0, 101, 0, 102, 0, 102, 0, 103, 0, 102, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 115, 0, 116, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 117, 0, 118, 0, 102, 0, 119, 0, 120, 0, 121, 0, 122, 0, 123, 0, 124, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 125, 0, 74, 0, 126, 0, 127, 0, 128, 0, 26, 0, 129, 0, 130, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 85, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 131, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 132, 0, 133, 0, 26, 0, 26, 0, 26, 0, 26, 0, 134, 0, 135, 0, 136, 0, 137, 0, 138, 0, 139, 0, 140, 0, 141, 0, 142, 0, 143, 0, 144, 0, 145, 0, 146, 0, 147, 0, 148, 0, 149, 0, 150, 0, 151, 0, 152, 0, 153, 0, 154, 0, 34, 0, 34, 0, 155, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 26, 0, 156, 0, 157, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 34, 0, 26, 0, 26, 0, 26, 0, 26, 0, 158, 0, 158, 0, 26, 0, 159, 0, 160, 0, 161, 0, 162, 0, 163, 0, 26, 0, 26, 0, 26, 0, 26, 0, 164, 0, 165, 0, 166, 0, 167, 0, 168, 0, 169, 0, 26, 0, 170, 0, 171, 0, 172, 0, 173, 0, 174, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js7unicode6index2E = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 5, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 7, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 10, 0, 11, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 12, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 13, 0, 14, 0, 15, 0, 8, 0, 9, 0, 8, 0, 9, 0, 16, 0, 8, 0, 9, 0, 17, 0, 17, 0, 8, 0, 9, 0, 5, 0, 18, 0, 19, 0, 20, 0, 8, 0, 9, 0, 17, 0, 21, 0, 22, 0, 23, 0, 24, 0, 8, 0, 9, 0, 25, 0, 5, 0, 23, 0, 26, 0, 27, 0, 28, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 29, 0, 8, 0, 9, 0, 29, 0, 5, 0, 5, 0, 8, 0, 9, 0, 29, 0, 8, 0, 9, 0, 30, 0, 30, 0, 8, 0, 9, 0, 8, 0, 9, 0, 31, 0, 8, 0, 9, 0, 5, 0, 5, 0, 8, 0, 9, 0, 5, 0, 32, 0, 5, 0, 5, 0, 5, 0, 5, 0, 33, 0, 34, 0, 35, 0, 33, 0, 34, 0, 35, 0, 33, 0, 34, 0, 35, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 36, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 33, 0, 34, 0, 35, 0, 8, 0, 9, 0, 37, 0, 38, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 39, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 40, 0, 8, 0, 9, 0, 41, 0, 42, 0, 43, 0, 43, 0, 8, 0, 9, 0, 44, 0, 45, 0, 46, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 47, 0, 48, 0, 49, 0, 50, 0, 51, 0, 5, 0, 52, 0, 52, 0, 5, 0, 53, 0, 5, 0, 54, 0, 5, 0, 5, 0, 5, 0, 5, 0, 52, 0, 5, 0, 5, 0, 55, 0, 5, 0, 56, 0, 5, 0, 5, 0, 57, 0, 58, 0, 5, 0, 59, 0, 5, 0, 5, 0, 5, 0, 58, 0, 5, 0, 60, 0, 61, 0, 5, 0, 5, 0, 62, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 63, 0, 5, 0, 5, 0, 64, 0, 5, 0, 5, 0, 64, 0, 5, 0, 5, 0, 5, 0, 5, 0, 64, 0, 65, 0, 66, 0, 66, 0, 67, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 68, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 69, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 8, 0, 9, 0, 0, 0, 0, 0, 5, 0, 27, 0, 27, 0, 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 71, 0, 71, 0, 71, 0, 0, 0, 72, 0, 0, 0, 73, 0, 73, 0, 5, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 74, 0, 75, 0, 75, 0, 75, 0, 5, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 76, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 77, 0, 78, 0, 78, 0, 79, 0, 80, 0, 81, 0, 5, 0, 5, 0, 5, 0, 82, 0, 83, 0, 84, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 85, 0, 86, 0, 87, 0, 5, 0, 88, 0, 89, 0, 0, 0, 8, 0, 9, 0, 90, 0, 8, 0, 9, 0, 5, 0, 39, 0, 39, 0, 39, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 91, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 86, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 92, 0, 92, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 93, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 94, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 97, 0, 0, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 5, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 2, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 0, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 5, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 98, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 1, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 1, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 97, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 99, 0, 5, 0, 5, 0, 5, 0, 100, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 101, 0, 5, 0, 5, 0, 102, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 0, 0, 0, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 0, 0, 0, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 0, 0, 0, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 0, 0, 0, 0, 5, 0, 103, 0, 5, 0, 103, 0, 5, 0, 103, 0, 5, 0, 103, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 105, 0, 105, 0, 106, 0, 106, 0, 106, 0, 106, 0, 107, 0, 107, 0, 108, 0, 108, 0, 109, 0, 109, 0, 110, 0, 110, 0, 0, 0, 0, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 103, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 104, 0, 103, 0, 103, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 104, 0, 104, 0, 112, 0, 112, 0, 113, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 115, 0, 115, 0, 115, 0, 115, 0, 113, 0, 0, 0, 0, 0, 0, 0, 103, 0, 103, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 104, 0, 104, 0, 116, 0, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 0, 103, 0, 5, 0, 5, 0, 5, 0, 87, 0, 5, 0, 5, 0, 104, 0, 104, 0, 117, 0, 117, 0, 90, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 111, 0, 5, 0, 0, 0, 5, 0, 5, 0, 118, 0, 118, 0, 119, 0, 119, 0, 113, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 92, 0, 92, 0, 92, 0, 92, 0, 2, 0, 92, 0, 92, 0, 92, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 120, 0, 0, 0, 5, 0, 0, 0, 121, 0, 122, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 123, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 125, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 126, 0, 5, 0, 5, 0, 5, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 127, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 95, 0, 0, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 96, 0, 0, 0, 8, 0, 9, 0, 129, 0, 130, 0, 131, 0, 132, 0, 133, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 134, 0, 135, 0, 136, 0, 137, 0, 5, 0, 8, 0, 9, 0, 5, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 138, 0, 138, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 139, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 2, 0, 92, 0, 92, 0, 92, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 8, 0, 9, 0, 8, 0, 9, 0, 99, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 5, 0, 0, 0, 0, 0, 8, 0, 9, 0, 56, 0, 5, 0, 0, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 8, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 97, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 97, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 97, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 97, 0, 97, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 97, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 5, 0, 2, 0, 2, 0, 2, 0, 5, 0, 5, 0, 2, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 2, 0, 2, 0, 5, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 2, 0, 97, 0, 97, 0, 0, 0, 97, 0, 2, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 2, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL33fatal_error_handler_nesting_depth = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str182 = allocate([ 10, 10, 35, 10, 35, 32, 70, 97, 116, 97, 108, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 37, 115, 44, 32, 108, 105, 110, 101, 32, 37, 100, 10, 35, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1183 = allocate([ 10, 35, 10, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1185 = allocate([ 45, 73, 110, 102, 105, 110, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3187 = allocate([ 48, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2v88internalL14kCachedPowers8E = allocate([ 1025131999, 0, 0, 0, 3860516611, 0, 0, 0, -1087, 0, -308, 0, 3348809418, 0, 0, 0, 2876309015, 0, 0, 0, -1060, 0, -300, 0, 3200048207, 0, 0, 0, 4286034428, 0, 0, 0, -1034, 0, -292, 0, 1097586188, 0, 0, 0, 3193344495, 0, 0, 0, -1007, 0, -284, 0, 2424306748, 0, 0, 0, 2379227053, 0, 0, 0, -980, 0, -276, 0, 827693699, 0, 0, 0, 3545324584, 0, 0, 0, -954, 0, -268, 0, 2913388981, 0, 0, 0, 2641472655, 0, 0, 0, -927, 0, -260, 0, 602835915, 0, 0, 0, 3936100983, 0, 0, 0, -901, 0, -252, 0, 1081627501, 0, 0, 0, 2932623761, 0, 0, 0, -874, 0, -244, 0, 1572261463, 0, 0, 0, 2184974969, 0, 0, 0, -847, 0, -236, 0, 1308317239, 0, 0, 0, 3255866422, 0, 0, 0, -821, 0, -228, 0, 944281679, 0, 0, 0, 2425809519, 0, 0, 0, -794, 0, -220, 0, 629291719, 0, 0, 0, 3614737867, 0, 0, 0, -768, 0, -212, 0, 2545915892, 0, 0, 0, 2693189581, 0, 0, 0, -741, 0, -204, 0, 388672741, 0, 0, 0, 4013165208, 0, 0, 0, -715, 0, -196, 0, 708162190, 0, 0, 0, 2990041083, 0, 0, 0, -688, 0, -188, 0, 3536207675, 0, 0, 0, 2227754207, 0, 0, 0, -661, 0, -180, 0, 450088378, 0, 0, 0, 3319612455, 0, 0, 0, -635, 0, -172, 0, 3139815830, 0, 0, 0, 2473304014, 0, 0, 0, -608, 0, -164, 0, 2103616900, 0, 0, 0, 3685510180, 0, 0, 0, -582, 0, -156, 0, 224385782, 0, 0, 0, 2745919064, 0, 0, 0, -555, 0, -148, 0, 3737383206, 0, 0, 0, 4091738259, 0, 0, 0, -529, 0, -140, 0, 2868871352, 0, 0, 0, 3048582568, 0, 0, 0, -502, 0, -132, 0, 1820084875, 0, 0, 0, 2271371013, 0, 0, 0, -475, 0, -124, 0, 885076051, 0, 0, 0, 3384606560, 0, 0, 0, -449, 0, -116, 0, 2444895829, 0, 0, 0, 2521728396, 0, 0, 0, -422, 0, -108, 0, 1881767613, 0, 0, 0, 3757668132, 0, 0, 0, -396, 0, -100, 0, 3102062735, 0, 0, 0, 2799680927, 0, 0, 0, -369, 0, -92, 0, 2289335700, 0, 0, 0, 4171849679, 0, 0, 0, -343, 0, -84, 0, 2410191823, 0, 0, 0, 3108270227, 0, 0, 0, -316, 0, -76, 0, 3205436779, 0, 0, 0, 2315841784, 0, 0, 0, -289, 0, -68, 0, 1697722806, 0, 0, 0, 3450873173, 0, 0, 0, -263, 0, -60, 0, 3497754540, 0, 0, 0, 2571100870, 0, 0, 0, -236, 0, -52, 0, 707476230, 0, 0, 0, 3831238852, 0, 0, 0, -210, 0, -44, 0, 1769181907, 0, 0, 0, 2854495385, 0, 0, 0, -183, 0, -36, 0, 2197867022, 0, 0, 0, 4253529586, 0, 0, 0, -157, 0, -28, 0, 2450594539, 0, 0, 0, 3169126500, 0, 0, 0, -130, 0, -20, 0, 1867548876, 0, 0, 0, 2361183241, 0, 0, 0, -103, 0, -12, 0, 3793315116, 0, 0, 0, 3518437208, 0, 0, 0, -77, 0, -4, 0, 0, 0, 0, 0, 262144e4, 0, 0, 0, -50, 0, 4, 0, 0, 0, 0, 0, 390625e4, 0, 0, 0, -24, 0, 12, 0, 2892103680, 0, 0, 0, 2910383045, 0, 0, 0, 3, 0, 20, 0, 4170451332, 0, 0, 0, 2168404344, 0, 0, 0, 30, 0, 28, 0, 3372684723, 0, 0, 0, 3231174267, 0, 0, 0, 56, 0, 36, 0, 2078956656, 0, 0, 0, 2407412430, 0, 0, 0, 83, 0, 44, 0, 2884206696, 0, 0, 0, 3587324068, 0, 0, 0, 109, 0, 52, 0, 395977285, 0, 0, 0, 2672764710, 0, 0, 0, 136, 0, 60, 0, 3569679143, 0, 0, 0, 3982729777, 0, 0, 0, 162, 0, 68, 0, 2361961896, 0, 0, 0, 2967364920, 0, 0, 0, 189, 0, 76, 0, 447440347, 0, 0, 0, 2210859150, 0, 0, 0, 216, 0, 84, 0, 1114709402, 0, 0, 0, 3294436857, 0, 0, 0, 242, 0, 92, 0, 2786846552, 0, 0, 0, 2454546732, 0, 0, 0, 269, 0, 100, 0, 443583978, 0, 0, 0, 3657559652, 0, 0, 0, 295, 0, 108, 0, 2599384906, 0, 0, 0, 2725094297, 0, 0, 0, 322, 0, 116, 0, 3028118405, 0, 0, 0, 4060706939, 0, 0, 0, 348, 0, 124, 0, 2044532855, 0, 0, 0, 3025462433, 0, 0, 0, 375, 0, 132, 0, 1536935362, 0, 0, 0, 2254145170, 0, 0, 0, 402, 0, 140, 0, 3365297469, 0, 0, 0, 3358938053, 0, 0, 0, 428, 0, 148, 0, 4204241075, 0, 0, 0, 2502603868, 0, 0, 0, 455, 0, 156, 0, 2577424355, 0, 0, 0, 3729170365, 0, 0, 0, 481, 0, 164, 0, 3677981733, 0, 0, 0, 2778448436, 0, 0, 0, 508, 0, 172, 0, 2744688476, 0, 0, 0, 4140210802, 0, 0, 0, 534, 0, 180, 0, 1424604878, 0, 0, 0, 3084697427, 0, 0, 0, 561, 0, 188, 0, 4062331362, 0, 0, 0, 2298278679, 0, 0, 0, 588, 0, 196, 0, 3546052773, 0, 0, 0, 3424702107, 0, 0, 0, 614, 0, 204, 0, 2065781727, 0, 0, 0, 2551601907, 0, 0, 0, 641, 0, 212, 0, 2535403578, 0, 0, 0, 3802183132, 0, 0, 0, 667, 0, 220, 0, 1558426518, 0, 0, 0, 2832847187, 0, 0, 0, 694, 0, 228, 0, 2762425404, 0, 0, 0, 4221271257, 0, 0, 0, 720, 0, 236, 0, 2812560400, 0, 0, 0, 3145092172, 0, 0, 0, 747, 0, 244, 0, 3057687578, 0, 0, 0, 2343276271, 0, 0, 0, 774, 0, 252, 0, 2790753324, 0, 0, 0, 3491753744, 0, 0, 0, 800, 0, 260, 0, 3918606633, 0, 0, 0, 2601559269, 0, 0, 0, 827, 0, 268, 0, 2711358621, 0, 0, 0, 3876625403, 0, 0, 0, 853, 0, 276, 0, 1648096297, 0, 0, 0, 2888311001, 0, 0, 0, 880, 0, 284, 0, 2057817989, 0, 0, 0, 2151959390, 0, 0, 0, 907, 0, 292, 0, 61660461, 0, 0, 0, 3206669376, 0, 0, 0, 933, 0, 300, 0, 1581580175, 0, 0, 0, 2389154863, 0, 0, 0, 960, 0, 308, 0, 2626467905, 0, 0, 0, 3560118173, 0, 0, 0, 986, 0, 316, 0, 3034782633, 0, 0, 0, 2652494738, 0, 0, 0, 1013, 0, 324, 0, 3135207385, 0, 0, 0, 3952525166, 0, 0, 0, 1039, 0, 332, 0, 2616258155, 0, 0, 0, 2944860731, 0, 0, 0, 1066, 0, 340, 0 ], [ "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_JSVAL_NULL = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_ZERO = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_ONE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_FALSE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_TRUE = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_JSVAL_VOID = allocate(8, [ "i64", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL22js_NewRuntimeWasCalled_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str9202 = allocate([ 49, 46, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10203 = allocate([ 49, 46, 49, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11204 = allocate([ 49, 46, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12205 = allocate([ 49, 46, 51, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13206 = allocate([ 49, 46, 52, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14207 = allocate([ 69, 67, 77, 65, 118, 51, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15208 = allocate([ 49, 46, 53, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16209 = allocate([ 49, 46, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17210 = allocate([ 49, 46, 55, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18211 = allocate([ 49, 46, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19212 = allocate([ 69, 67, 77, 65, 118, 53, 0 ], "i8", ALLOC_STATIC);

__ZL6v2smap = allocate([ 100, 0, 0, 0, 0, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 130, 0, 0, 0, 0, 0, 0, 0, 140, 0, 0, 0, 0, 0, 0, 0, 148, 0, 0, 0, 0, 0, 0, 0, 150, 0, 0, 0, 0, 0, 0, 0, 160, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 180, 0, 0, 0, 0, 0, 0, 0, 185, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0 ], [ "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str20213 = allocate([ 117, 110, 107, 110, 111, 119, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21214 = allocate([ 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 45, 67, 32, 49, 46, 56, 46, 53, 43, 32, 50, 48, 49, 49, 45, 48, 52, 45, 49, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22215 = allocate([ 106, 100, 117, 109, 109, 121, 0 ], "i8", ALLOC_STATIC);

_js_dummy_class = allocate([ 0, 0, 0, 0, 292608, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL20standard_class_atoms = allocate([ 448, 0, 0, 0, 80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 76, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 450, 0, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 452, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 454, 0, 0, 0, 96, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 456, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 108, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 464, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 466, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 468, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 470, 0, 0, 0, 124, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 472, 0, 0, 0, 164, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 474, 0, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 478, 0, 0, 0, 216, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL20standard_class_names = allocate([ 44, 0, 0, 0, 264, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 432, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 428, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 588, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 584, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 608, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 458, 0, 0, 0, 612, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 576, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 620, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 552, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 568, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 556, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 572, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 460, 0, 0, 0, 624, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 132, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 140, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 144, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 148, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 152, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 462, 0, 0, 0, 156, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 466, 0, 0, 0, 548, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 466, 0, 0, 0, 596, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 472, 0, 0, 0, 160, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 172, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 176, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 180, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 188, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 200, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 476, 0, 0, 0, 204, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 480, 0, 0, 0, 208, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL22object_prototype_names = allocate([ 44, 0, 0, 0, 344, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 372, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 376, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 368, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 384, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 632, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 628, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 580, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 592, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 616, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 560, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 564, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 600, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 604, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str23216 = allocate([ 80, 114, 111, 112, 101, 114, 116, 121, 73, 116, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZL15prop_iter_class = allocate([ 0, 0, 0, 0, 257, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 482, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str25218 = allocate([ 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26219 = allocate([ 78, 111, 32, 115, 117, 99, 104, 32, 102, 105, 108, 101, 32, 111, 114, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

_js_CStringsAreUTF8 = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str29222 = allocate([ 74, 83, 69, 120, 99, 101, 112, 116, 105, 111, 110, 83, 116, 97, 116, 101, 46, 101, 120, 99, 101, 112, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE6prefix = allocate([ 94, 0, 40, 0, 63, 0, 58, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamEE7postfix = allocate([ 41, 0 ], [ "i16", 0 ], ALLOC_STATIC);

__ZN2js10ArrayClassE = allocate([ 0, 0, 0, 0, 50855937, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 486, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 488, 0, 0, 0, 488, 0, 0, 0, 490, 0, 0, 0, 492, 0, 0, 0, 494, 0, 0, 0, 494, 0, 0, 0, 496, 0, 0, 0, 498, 0, 0, 0, 500, 0, 0, 0, 502, 0, 0, 0, 504, 0, 0, 0, 506, 0, 0, 0, 508, 0, 0, 0, 508, 0, 0, 0, 510, 0, 0, 0, 512, 0, 0, 0, 514, 0, 0, 0, 514, 0, 0, 0, 516, 0, 0, 0, 518, 0, 0, 0, 520, 0, 0, 0, 520, 0, 0, 0, 522, 0, 0, 0, 524, 0, 0, 0, 526, 0, 0, 0, 526, 0, 0, 0, 528, 0, 0, 0, 530, 0, 0, 0, 0, 0, 0, 0, 532, 0, 0, 0, 534, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js14SlowArrayClassE = allocate([ 0, 0, 0, 0, 50331649, 0, 0, 0, 536, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2319 = allocate([ 114, 101, 118, 101, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3320 = allocate([ 115, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4321 = allocate([ 112, 117, 115, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5322 = allocate([ 112, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6323 = allocate([ 115, 104, 105, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7324 = allocate([ 117, 110, 115, 104, 105, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8325 = allocate([ 115, 112, 108, 105, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13330 = allocate([ 102, 111, 114, 69, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14331 = allocate([ 109, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15332 = allocate([ 114, 101, 100, 117, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16333 = allocate([ 114, 101, 100, 117, 99, 101, 82, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18335 = allocate([ 115, 111, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19336 = allocate([ 101, 118, 101, 114, 121, 0 ], "i8", ALLOC_STATIC);

__ZL13array_methods = allocate([ 0, 0, 0, 0, 538, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 540, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 542, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 544, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 546, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 140, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 130, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 132, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 548, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 550, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 552, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 554, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 556, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 558, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 560, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 562, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 564, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 566, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 568, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 570, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 572, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 574, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str20337 = allocate([ 105, 115, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZL20array_static_methods = allocate([ 0, 0, 0, 0, 576, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueEE5comma = allocate([ 44 ], [ "i16", 0, 0, 0, 0 ], ALLOC_STATIC);

__ZN11JSAtomState17commonAtomsOffsetE = allocate([ 24 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

__ZN11JSAtomState15lazyAtomsOffsetE = allocate([ 548 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE._js_Null_str = allocate([ 78, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Object_str = allocate([ 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Function_str = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Array_str = allocate([ 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Boolean_str = allocate([ 66, 111, 111, 108, 101, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_JSON_str = allocate([ 74, 83, 79, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Date_str = allocate([ 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Math_str = allocate([ 77, 97, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Number_str = allocate([ 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_String_str = allocate([ 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_RegExp_str = allocate([ 82, 101, 103, 69, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_XML_str = allocate([ 88, 77, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Namespace_str = allocate([ 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_QName_str = allocate([ 81, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Error_str = allocate([ 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_InternalError_str = allocate([ 73, 110, 116, 101, 114, 110, 97, 108, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_EvalError_str = allocate([ 69, 118, 97, 108, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_RangeError_str = allocate([ 82, 97, 110, 103, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_ReferenceError_str = allocate([ 82, 101, 102, 101, 114, 101, 110, 99, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_SyntaxError_str = allocate([ 83, 121, 110, 116, 97, 120, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_TypeError_str = allocate([ 84, 121, 112, 101, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_URIError_str = allocate([ 85, 82, 73, 69, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Iterator_str = allocate([ 73, 116, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_StopIteration_str = allocate([ 83, 116, 111, 112, 73, 116, 101, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_ArrayBuffer_str = allocate([ 65, 114, 114, 97, 121, 66, 117, 102, 102, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Int8Array_str = allocate([ 73, 110, 116, 56, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Uint8Array_str = allocate([ 85, 105, 110, 116, 56, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Int16Array_str = allocate([ 73, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Uint16Array_str = allocate([ 85, 105, 110, 116, 49, 54, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Int32Array_str = allocate([ 73, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Uint32Array_str = allocate([ 85, 105, 110, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Float32Array_str = allocate([ 70, 108, 111, 97, 116, 51, 50, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Float64Array_str = allocate([ 70, 108, 111, 97, 116, 54, 52, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Uint8ClampedArray_str = allocate([ 85, 105, 110, 116, 56, 67, 108, 97, 109, 112, 101, 100, 65, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Proxy_str = allocate([ 80, 114, 111, 120, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_AnyName_str = allocate([ 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_WeakMap_str = allocate([ 87, 101, 97, 107, 77, 97, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6436 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 78, 117, 108, 108, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7437 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 85, 110, 100, 101, 102, 105, 110, 101, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8438 = allocate([ 40, 118, 111, 105, 100, 32, 48, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9439 = allocate([ 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14444 = allocate([ 98, 117, 105, 108, 100, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15445 = allocate([ 64, 109, 111, 122, 105, 108, 108, 97, 46, 111, 114, 103, 47, 106, 115, 47, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18448 = allocate([ 103, 101, 116, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22452 = allocate([ 101, 110, 117, 109, 101, 114, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23453 = allocate([ 102, 105, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25455 = allocate([ 104, 97, 115, 79, 119, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27457 = allocate([ 105, 116, 101, 114, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

_js_common_atom_names = allocate(524, "*", ALLOC_STATIC);

_js_common_atom_count = allocate([ 131 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE._js_anonymous_str = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_apply_str = allocate([ 97, 112, 112, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_arguments_str = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_arity_str = allocate([ 97, 114, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_BYTES_PER_ELEMENT_str = allocate([ 66, 89, 84, 69, 83, 95, 80, 69, 82, 95, 69, 76, 69, 77, 69, 78, 84, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_call_str = allocate([ 99, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_callee_str = allocate([ 99, 97, 108, 108, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_caller_str = allocate([ 99, 97, 108, 108, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_class_prototype_str = allocate([ 112, 114, 111, 116, 111, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_constructor_str = allocate([ 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_each_str = allocate([ 101, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_eval_str = allocate([ 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_fileName_str = allocate([ 102, 105, 108, 101, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_get_str = allocate([ 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_getter_str = allocate([ 103, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_global_str = allocate([ 103, 108, 111, 98, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_ignoreCase_str = allocate([ 105, 103, 110, 111, 114, 101, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_index_str = allocate([ 105, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_input_str = allocate([ 105, 110, 112, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_iterator_str = allocate([ 95, 95, 105, 116, 101, 114, 97, 116, 111, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_join_str = allocate([ 106, 111, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lastIndex_str = allocate([ 108, 97, 115, 116, 73, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_length_str = allocate([ 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lineNumber_str = allocate([ 108, 105, 110, 101, 78, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_message_str = allocate([ 109, 101, 115, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_multiline_str = allocate([ 109, 117, 108, 116, 105, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_name_str = allocate([ 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_next_str = allocate([ 110, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_noSuchMethod_str = allocate([ 95, 95, 110, 111, 83, 117, 99, 104, 77, 101, 116, 104, 111, 100, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_object_str = allocate([ 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_proto_str = allocate([ 95, 95, 112, 114, 111, 116, 111, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_setter_str = allocate([ 115, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_set_str = allocate([ 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_source_str = allocate([ 115, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_stack_str = allocate([ 115, 116, 97, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_sticky_str = allocate([ 115, 116, 105, 99, 107, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toGMTString_str = allocate([ 116, 111, 71, 77, 84, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toLocaleString_str = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toSource_str = allocate([ 116, 111, 83, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toString_str = allocate([ 116, 111, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toUTCString_str = allocate([ 116, 111, 85, 84, 67, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_undefined_str = allocate([ 117, 110, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_valueOf_str = allocate([ 118, 97, 108, 117, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_toJSON_str = allocate([ 116, 111, 74, 83, 79, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_enumerable_str = allocate([ 101, 110, 117, 109, 101, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_configurable_str = allocate([ 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_writable_str = allocate([ 119, 114, 105, 116, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_value_str = allocate([ 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_test_str = allocate([ 116, 101, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_etago_str = allocate([ 60, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_namespace_str = allocate([ 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_ptagc_str = allocate([ 47, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_qualifier_str = allocate([ 58, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_space_str = allocate([ 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_stago_str = allocate([ 60, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_star_str = allocate([ 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_starQualifier_str = allocate([ 42, 58, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_tagc_str = allocate([ 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_xml_str = allocate([ 120, 109, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_close_str = allocate([ 99, 108, 111, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_send_str = allocate([ 115, 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

__ZN2js12BooleanClassE = allocate([ 0, 0, 0, 0, 67109120, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL15boolean_methods = allocate([ 0, 0, 0, 0, 578, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 580, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 582, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str3529 = allocate([ 40, 110, 101, 119, 32, 66, 111, 111, 108, 101, 97, 110, 40, 37, 115, 41, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str573 = allocate([ 116, 114, 117, 110, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1574 = allocate([ 111, 98, 106, 101, 99, 116, 32, 103, 114, 97, 112, 104, 32, 116, 111, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2575 = allocate([ 117, 110, 114, 101, 99, 111, 103, 110, 105, 122, 101, 100, 32, 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3576 = allocate([ 115, 116, 114, 105, 110, 103, 32, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4577 = allocate([ 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5578 = allocate([ 114, 101, 103, 101, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6579 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 105, 110, 112, 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7580 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2647 = allocate([ 79, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3648 = allocate([ 78, 111, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 101, 114, 114, 111, 114, 32, 110, 117, 109, 98, 101, 114, 32, 37, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6651 = allocate([ 60, 69, 114, 114, 111, 114, 32, 35, 48, 32, 105, 115, 32, 114, 101, 115, 101, 114, 118, 101, 100, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7652 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8653 = allocate([ 110, 111, 116, 104, 105, 110, 103, 32, 97, 99, 116, 105, 118, 101, 32, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9654 = allocate([ 123, 48, 125, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 123, 49, 125, 32, 97, 114, 103, 117, 109, 101, 110, 116, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10655 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 109, 97, 116, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11656 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 116, 121, 112, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12657 = allocate([ 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 115, 105, 122, 101, 32, 111, 118, 101, 114, 102, 108, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13658 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 39, 48, 120, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14659 = allocate([ 123, 48, 125, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 123, 49, 125, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 32, 105, 110, 99, 111, 109, 112, 97, 116, 105, 98, 108, 101, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15660 = allocate([ 123, 48, 125, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16661 = allocate([ 99, 97, 110, 39, 116, 32, 97, 108, 105, 97, 115, 32, 123, 48, 125, 32, 116, 111, 32, 123, 49, 125, 32, 105, 110, 32, 99, 108, 97, 115, 115, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17662 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 115, 99, 114, 105, 112, 116, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18663 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 65, 114, 114, 97, 121, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 115, 111, 114, 116, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19664 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 110, 111, 32, 105, 110, 100, 101, 120, 32, 102, 111, 114, 32, 97, 116, 111, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20665 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 108, 105, 116, 101, 114, 97, 108, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21666 = allocate([ 99, 97, 110, 39, 116, 32, 119, 97, 116, 99, 104, 32, 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 111, 98, 106, 101, 99, 116, 115, 32, 111, 102, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22667 = allocate([ 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 99, 111, 109, 112, 105, 108, 105, 110, 103, 32, 123, 48, 125, 58, 32, 115, 116, 97, 99, 107, 32, 117, 110, 100, 101, 114, 102, 108, 111, 119, 32, 97, 116, 32, 112, 99, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23668 = allocate([ 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24669 = allocate([ 111, 117, 116, 32, 111, 102, 32, 108, 111, 99, 97, 108, 32, 114, 111, 111, 116, 32, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25670 = allocate([ 123, 48, 125, 32, 105, 115, 32, 114, 101, 97, 100, 45, 111, 110, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26671 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27672 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 32, 105, 115, 32, 110, 111, 110, 45, 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 32, 97, 110, 100, 32, 99, 97, 110, 39, 116, 32, 98, 101, 32, 100, 101, 108, 101, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28673 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29674 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30675 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31676 = allocate([ 123, 48, 125, 32, 110, 101, 115, 116, 101, 100, 32, 116, 111, 111, 32, 100, 101, 101, 112, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32677 = allocate([ 116, 111, 111, 32, 109, 117, 99, 104, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33678 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 39, 105, 110, 39, 32, 111, 112, 101, 114, 97, 110, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34679 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 110, 101, 119, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 114, 101, 115, 117, 108, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35680 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 35, 123, 48, 125, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str36681 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 117, 115, 101, 32, 35, 123, 48, 125, 35, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str37682 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 39, 105, 110, 115, 116, 97, 110, 99, 101, 111, 102, 39, 32, 111, 112, 101, 114, 97, 110, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str38683 = allocate([ 117, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39684 = allocate([ 114, 97, 100, 105, 120, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 105, 110, 116, 101, 103, 101, 114, 32, 97, 116, 32, 108, 101, 97, 115, 116, 32, 50, 32, 97, 110, 100, 32, 110, 111, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 51, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40685 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 108, 101, 116, 32, 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41686 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 97, 110, 32, 105, 110, 116, 101, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42687 = allocate([ 99, 121, 99, 108, 105, 99, 32, 123, 48, 125, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43688 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 109, 112, 105, 108, 101, 32, 111, 118, 101, 114, 32, 97, 32, 115, 99, 114, 105, 112, 116, 32, 116, 104, 97, 116, 32, 105, 115, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44689 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str45690 = allocate([ 123, 48, 125, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46691 = allocate([ 99, 97, 110, 39, 116, 32, 102, 105, 110, 100, 32, 99, 108, 97, 115, 115, 32, 105, 100, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47692 = allocate([ 99, 97, 110, 39, 116, 32, 88, 68, 82, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str48693 = allocate([ 98, 121, 116, 101, 99, 111, 100, 101, 32, 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 32, 40, 108, 105, 109, 105, 116, 32, 123, 49, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str49694 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 102, 111, 114, 109, 97, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str50695 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51696 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52697 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 113, 117, 97, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53698 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 109, 105, 110, 105, 109, 117, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54699 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55700 = allocate([ 109, 97, 120, 105, 109, 117, 109, 32, 123, 48, 125, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 32, 109, 105, 110, 105, 109, 117, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str56701 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 61, 32, 105, 110, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57702 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str58703 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 108, 101, 116, 32, 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59704 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 108, 101, 116, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str60705 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 112, 97, 114, 101, 110, 116, 104, 101, 116, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61706 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62707 = allocate([ 116, 114, 97, 105, 108, 105, 110, 103, 32, 92, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63708 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 114, 97, 110, 103, 101, 32, 105, 110, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64709 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 102, 108, 97, 103, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65710 = allocate([ 110, 111, 32, 105, 110, 112, 117, 116, 32, 102, 111, 114, 32, 47, 123, 48, 125, 47, 123, 49, 125, 123, 50, 125, 123, 51, 125, 123, 52, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str66711 = allocate([ 99, 97, 110, 39, 116, 32, 111, 112, 101, 110, 32, 123, 48, 125, 58, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67712 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 97, 114, 114, 97, 121, 32, 112, 97, 115, 115, 101, 100, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 97, 112, 112, 108, 121, 32, 105, 115, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str68713 = allocate([ 117, 110, 109, 97, 116, 99, 104, 101, 100, 32, 41, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str70715 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 115, 101, 101, 107, 32, 98, 101, 121, 111, 110, 100, 32, 115, 116, 97, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71716 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 115, 101, 101, 107, 32, 98, 101, 121, 111, 110, 100, 32, 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72717 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 101, 110, 100, 45, 98, 97, 115, 101, 100, 32, 115, 101, 101, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73718 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 115, 101, 101, 107, 32, 119, 104, 101, 110, 99, 101, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74719 = allocate([ 98, 97, 100, 32, 115, 99, 114, 105, 112, 116, 32, 88, 68, 82, 32, 109, 97, 103, 105, 99, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str75720 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str76721 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str77722 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str78723 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str79724 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str80725 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81726 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82727 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 105, 115, 32, 109, 105, 120, 101, 100, 32, 119, 105, 116, 104, 32, 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 112, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83728 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 32, 97, 102, 116, 101, 114, 32, 46, 32, 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84729 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 105, 110, 32, 105, 110, 100, 101, 120, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str85730 = allocate([ 88, 77, 76, 32, 99, 97, 110, 39, 116, 32, 98, 101, 32, 116, 104, 101, 32, 119, 104, 111, 108, 101, 32, 112, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str86731 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 115, 119, 105, 116, 99, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str87732 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 115, 119, 105, 116, 99, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88733 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 115, 119, 105, 116, 99, 104, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89734 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 97, 102, 116, 101, 114, 32, 99, 97, 115, 101, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90735 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 119, 104, 105, 108, 101, 32, 97, 102, 116, 101, 114, 32, 100, 111, 45, 108, 111, 111, 112, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91736 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92737 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93738 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94739 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 45, 108, 111, 111, 112, 32, 99, 111, 110, 116, 114, 111, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str95740 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96741 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97742 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str98743 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 105, 110, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99744 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100745 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101746 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102747 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 123, 32, 98, 101, 102, 111, 114, 101, 32, 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103748 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104749 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 99, 97, 116, 99, 104, 32, 111, 114, 32, 102, 105, 110, 97, 108, 108, 121, 32, 97, 102, 116, 101, 114, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str105750 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 40, 32, 98, 101, 102, 111, 114, 101, 32, 119, 105, 116, 104, 45, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str106751 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 119, 105, 116, 104, 45, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str107752 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 105, 110, 32, 99, 111, 109, 112, 111, 117, 110, 100, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str108753 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str109754 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 105, 110, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str110755 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 97, 102, 116, 101, 114, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111756 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 97, 102, 116, 101, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112757 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 58, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113758 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114759 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 41, 32, 105, 110, 32, 112, 97, 114, 101, 110, 116, 104, 101, 116, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str115760 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 59, 32, 98, 101, 102, 111, 114, 101, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str116761 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 108, 119, 97, 121, 115, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str117762 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 102, 111, 114, 109, 97, 108, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str118763 = allocate([ 116, 101, 115, 116, 32, 102, 111, 114, 32, 101, 113, 117, 97, 108, 105, 116, 121, 32, 40, 61, 61, 41, 32, 109, 105, 115, 116, 121, 112, 101, 100, 32, 97, 115, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 40, 61, 41, 63, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str119764 = allocate([ 99, 97, 110, 39, 116, 32, 97, 99, 99, 101, 115, 115, 32, 111, 112, 116, 105, 109, 105, 122, 101, 100, 32, 99, 108, 111, 115, 117, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str120765 = allocate([ 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 115, 119, 105, 116, 99, 104, 32, 100, 101, 102, 97, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121766 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 115, 119, 105, 116, 99, 104, 32, 99, 97, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122767 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 119, 105, 116, 99, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 47, 105, 110, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124 = allocate([ 99, 97, 116, 99, 104, 32, 97, 102, 116, 101, 114, 32, 117, 110, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str125 = allocate([ 99, 97, 116, 99, 104, 32, 119, 105, 116, 104, 111, 117, 116, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str126 = allocate([ 102, 105, 110, 97, 108, 108, 121, 32, 119, 105, 116, 104, 111, 117, 116, 32, 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str127 = allocate([ 108, 97, 98, 101, 108, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str128 = allocate([ 117, 110, 108, 97, 98, 101, 108, 101, 100, 32, 98, 114, 101, 97, 107, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 110, 115, 105, 100, 101, 32, 108, 111, 111, 112, 32, 111, 114, 32, 115, 119, 105, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str129 = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 105, 110, 115, 105, 100, 101, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str130 = allocate([ 123, 48, 125, 32, 110, 111, 116, 32, 105, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 32, 123, 48, 125, 32, 114, 101, 100, 101, 99, 108, 97, 114, 101, 115, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str134 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str135 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str136 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 123, 48, 125, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str137 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str138 = allocate([ 123, 48, 125, 32, 105, 115, 32, 97, 32, 114, 101, 115, 101, 114, 118, 101, 100, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str139 = allocate([ 115, 121, 110, 116, 97, 120, 32, 101, 114, 114, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str140 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str141 = allocate([ 39, 112, 114, 111, 116, 111, 116, 121, 112, 101, 39, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 111, 102, 32, 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 101, 120, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143 = allocate([ 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str145 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 101, 115, 32, 105, 110, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str146 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 99, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str147 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str148 = allocate([ 98, 97, 100, 32, 99, 108, 111, 110, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 115, 99, 111, 112, 101, 32, 99, 104, 97, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str149 = allocate([ 111, 118, 101, 114, 108, 97, 114, 103, 101, 32, 115, 104, 97, 114, 112, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str150 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str151 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 108, 101, 103, 97, 108, 32, 69, 67, 77, 65, 45, 50, 54, 50, 32, 111, 99, 116, 97, 108, 32, 99, 111, 110, 115, 116, 97, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100, 32, 100, 105, 114, 101, 99, 116, 108, 121, 44, 32, 97, 110, 100, 32, 110, 111, 116, 32, 98, 121, 32, 119, 97, 121, 32, 111, 102, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 102, 32, 97, 110, 111, 116, 104, 101, 114, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153 = allocate([ 117, 110, 99, 97, 117, 103, 104, 116, 32, 101, 120, 99, 101, 112, 116, 105, 111, 110, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str154 = allocate([ 110, 111, 110, 45, 111, 99, 116, 97, 108, 32, 100, 105, 103, 105, 116, 32, 105, 110, 32, 97, 110, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 116, 104, 97, 116, 32, 100, 111, 101, 115, 110, 39, 116, 32, 109, 97, 116, 99, 104, 32, 97, 32, 98, 97, 99, 107, 45, 114, 101, 102, 101, 114, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str155 = allocate([ 98, 97, 99, 107, 45, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 101, 120, 99, 101, 101, 100, 115, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 99, 97, 112, 116, 117, 114, 105, 110, 103, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str156768 = allocate([ 112, 114, 101, 99, 105, 115, 105, 111, 110, 32, 123, 48, 125, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str157 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 123, 48, 125, 32, 117, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str158 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 114, 97, 121, 32, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str159 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 115, 99, 114, 105, 98, 101, 32, 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 32, 111, 102, 32, 99, 108, 97, 115, 115, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str160 = allocate([ 115, 101, 99, 111, 110, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 46, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161 = allocate([ 114, 101, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 123, 48, 125, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 116, 111, 32, 117, 110, 100, 101, 99, 108, 97, 114, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str163 = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 108, 119, 97, 121, 115, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str164 = allocate([ 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 32, 123, 48, 125, 32, 117, 115, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str165 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 85, 82, 73, 32, 115, 101, 113, 117, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str166 = allocate([ 115, 101, 116, 116, 105, 110, 103, 32, 97, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 116, 104, 97, 116, 32, 104, 97, 115, 32, 111, 110, 108, 121, 32, 97, 32, 103, 101, 116, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str167 = allocate([ 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 115, 116, 97, 114, 116, 115, 32, 105, 109, 109, 101, 100, 105, 97, 116, 101, 108, 121, 32, 97, 102, 116, 101, 114, 32, 110, 117, 109, 101, 114, 105, 99, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str168 = allocate([ 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str169 = allocate([ 117, 115, 101, 108, 101, 115, 115, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str170 = allocate([ 114, 101, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 102, 111, 114, 109, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str171 = allocate([ 99, 97, 110, 39, 116, 32, 115, 117, 112, 112, 108, 121, 32, 102, 108, 97, 103, 115, 32, 119, 104, 101, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 110, 103, 32, 111, 110, 101, 32, 82, 101, 103, 69, 120, 112, 32, 102, 114, 111, 109, 32, 97, 110, 111, 116, 104, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172 = allocate([ 114, 101, 115, 101, 114, 118, 101, 100, 32, 115, 108, 111, 116, 32, 105, 110, 100, 101, 120, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 99, 111, 100, 101, 32, 74, 83, 80, 114, 105, 110, 99, 105, 112, 97, 108, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str174769 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 97, 108, 32, 123, 48, 125, 32, 111, 98, 106, 101, 99, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str175 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 99, 97, 116, 99, 104, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str176 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 109, 97, 114, 107, 117, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str177 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 88, 77, 76, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str178 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 102, 97, 117, 108, 116, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str179 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str180 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 93, 32, 97, 102, 116, 101, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str181 = allocate([ 97, 108, 114, 101, 97, 100, 121, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182770 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 125, 32, 105, 110, 32, 88, 77, 76, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str184771 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str185 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str186 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 88, 77, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str187 = allocate([ 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 123, 48, 125, 32, 116, 111, 32, 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str188772 = allocate([ 97, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 115, 101, 110, 100, 32, 123, 48, 125, 32, 116, 111, 32, 110, 101, 119, 98, 111, 114, 110, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str189 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 61, 32, 105, 110, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str190 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str191 = allocate([ 88, 77, 76, 32, 116, 97, 103, 32, 110, 97, 109, 101, 32, 109, 105, 115, 109, 97, 116, 99, 104, 32, 40, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 48, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 116, 97, 103, 32, 115, 121, 110, 116, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 108, 105, 115, 116, 32, 115, 121, 110, 116, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str194 = allocate([ 123, 48, 125, 32, 123, 49, 125, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 32, 105, 110, 99, 111, 109, 112, 97, 116, 105, 98, 108, 101, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str195 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 88, 77, 76, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str196 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 88, 77, 76, 32, 115, 111, 117, 114, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str197 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 88, 77, 76, 32, 101, 110, 116, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str198773 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 113, 117, 97, 108, 105, 102, 105, 101, 100, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str199 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 102, 111, 114, 32, 101, 97, 99, 104, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str200 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 123, 48, 125, 32, 105, 110, 32, 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str201 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 88, 77, 76, 32, 101, 110, 116, 105, 116, 121, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 88, 77, 76, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203 = allocate([ 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 88, 77, 76, 32, 110, 97, 109, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str204 = allocate([ 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 88, 77, 76, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str205 = allocate([ 116, 111, 111, 32, 109, 97, 110, 121, 32, 108, 111, 99, 97, 108, 32, 118, 97, 114, 105, 97, 98, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str206 = allocate([ 97, 114, 114, 97, 121, 32, 105, 110, 105, 116, 105, 97, 108, 105, 115, 101, 114, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str207 = allocate([ 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 116, 111, 111, 32, 99, 111, 109, 112, 108, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str208 = allocate([ 98, 117, 102, 102, 101, 114, 32, 116, 111, 111, 32, 115, 109, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str209 = allocate([ 98, 97, 100, 32, 115, 117, 114, 114, 111, 103, 97, 116, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str210 = allocate([ 85, 84, 70, 45, 56, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 123, 48, 125, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str211 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 85, 84, 70, 45, 56, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 97, 116, 32, 111, 102, 102, 115, 101, 116, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212 = allocate([ 74, 83, 95, 82, 101, 112, 111, 114, 116, 69, 114, 114, 111, 114, 32, 119, 97, 115, 32, 99, 97, 108, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213 = allocate([ 119, 114, 111, 110, 103, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 32, 99, 97, 108, 108, 101, 100, 32, 102, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str214 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 48, 125, 32, 114, 101, 116, 117, 114, 110, 115, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str215 = allocate([ 97, 110, 111, 110, 121, 109, 111, 117, 115, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 114, 101, 116, 117, 114, 110, 115, 32, 97, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str216 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 32, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str217 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 105, 110, 32, 97, 102, 116, 101, 114, 32, 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str218 = allocate([ 116, 114, 97, 112, 32, 123, 49, 125, 32, 102, 111, 114, 32, 123, 48, 125, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 97, 32, 112, 114, 105, 109, 105, 116, 105, 118, 101, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str219 = allocate([ 107, 101, 121, 119, 111, 114, 100, 32, 105, 115, 32, 117, 115, 101, 100, 32, 97, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str220 = allocate([ 121, 105, 101, 108, 100, 32, 102, 114, 111, 109, 32, 99, 108, 111, 115, 105, 110, 103, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str221 = allocate([ 123, 48, 125, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 112, 97, 114, 101, 110, 116, 104, 101, 115, 105, 122, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 114, 97, 121, 32, 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 32, 108, 101, 102, 116, 45, 104, 97, 110, 100, 32, 115, 105, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223 = allocate([ 88, 77, 76, 32, 102, 105, 108, 116, 101, 114, 32, 105, 115, 32, 97, 112, 112, 108, 105, 101, 100, 32, 116, 111, 32, 110, 111, 110, 45, 88, 77, 76, 32, 118, 97, 108, 117, 101, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str224 = allocate([ 114, 101, 100, 117, 99, 101, 32, 111, 102, 32, 101, 109, 112, 116, 121, 32, 97, 114, 114, 97, 121, 32, 119, 105, 116, 104, 32, 110, 111, 32, 105, 110, 105, 116, 105, 97, 108, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str225 = allocate([ 99, 97, 110, 39, 116, 32, 99, 97, 108, 108, 32, 123, 48, 125, 32, 109, 101, 116, 104, 111, 100, 32, 111, 110, 32, 97, 110, 32, 88, 77, 76, 32, 108, 105, 115, 116, 32, 119, 105, 116, 104, 32, 123, 49, 125, 32, 101, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str226 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 108, 101, 116, 101, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str227 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 47, 100, 101, 99, 114, 101, 109, 101, 110, 116, 32, 111, 112, 101, 114, 97, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str228 = allocate([ 123, 48, 125, 32, 105, 115, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str229 = allocate([ 108, 101, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 110, 111, 116, 32, 100, 105, 114, 101, 99, 116, 108, 121, 32, 119, 105, 116, 104, 105, 110, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str230 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str231 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 111, 110, 32, 105, 110, 100, 101, 120, 101, 100, 32, 97, 114, 114, 97, 121, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232 = allocate([ 101, 118, 97, 108, 32, 97, 99, 99, 101, 112, 116, 115, 32, 111, 110, 108, 121, 32, 111, 110, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 32, 119, 104, 101, 110, 32, 99, 97, 108, 108, 105, 110, 103, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 123, 49, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str234 = allocate([ 74, 83, 79, 78, 46, 112, 97, 114, 115, 101, 58, 32, 123, 48, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str235 = allocate([ 74, 83, 79, 78, 46, 115, 116, 114, 105, 110, 103, 105, 102, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str236 = allocate([ 118, 97, 108, 117, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 114, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str237 = allocate([ 118, 97, 108, 117, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 110, 111, 110, 45, 110, 117, 108, 108, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str238 = allocate([ 111, 99, 116, 97, 108, 32, 108, 105, 116, 101, 114, 97, 108, 115, 32, 97, 110, 100, 32, 111, 99, 116, 97, 108, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 115, 32, 97, 114, 101, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str239 = allocate([ 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 32, 109, 97, 121, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 119, 105, 116, 104, 39, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str240 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 123, 48, 125, 32, 97, 112, 112, 101, 97, 114, 115, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 99, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str241 = allocate([ 97, 112, 112, 108, 121, 105, 110, 103, 32, 116, 104, 101, 32, 39, 100, 101, 108, 101, 116, 101, 39, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 116, 111, 32, 97, 110, 32, 117, 110, 113, 117, 97, 108, 105, 102, 105, 101, 100, 32, 110, 97, 109, 101, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 32, 116, 111, 32, 123, 48, 125, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243 = allocate([ 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 123, 48, 125, 32, 105, 115, 32, 100, 101, 112, 114, 101, 99, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str244 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 115, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 115, 112, 101, 99, 105, 102, 121, 32, 97, 32, 118, 97, 108, 117, 101, 32, 111, 114, 32, 98, 101, 32, 119, 114, 105, 116, 97, 98, 108, 101, 32, 119, 104, 101, 110, 32, 97, 32, 103, 101, 116, 116, 101, 114, 32, 111, 114, 32, 115, 101, 116, 116, 101, 114, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str245 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str246 = allocate([ 99, 97, 110, 39, 116, 32, 114, 101, 100, 101, 102, 105, 110, 101, 32, 110, 111, 110, 45, 99, 111, 110, 102, 105, 103, 117, 114, 97, 98, 108, 101, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 39, 123, 48, 125, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str247 = allocate([ 99, 97, 110, 39, 116, 32, 97, 100, 100, 32, 101, 108, 101, 109, 101, 110, 116, 115, 32, 112, 97, 115, 116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 105, 102, 32, 105, 116, 115, 32, 108, 101, 110, 103, 116, 104, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 117, 110, 119, 114, 105, 116, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str248 = allocate([ 100, 101, 102, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 108, 101, 110, 103, 116, 104, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 111, 110, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 105, 115, 32, 110, 111, 116, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str249 = allocate([ 99, 97, 110, 39, 116, 32, 100, 101, 102, 105, 110, 101, 32, 97, 114, 114, 97, 121, 32, 105, 110, 100, 101, 120, 32, 112, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str250 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 111, 114, 32, 111, 117, 116, 45, 111, 102, 45, 114, 97, 110, 103, 101, 32, 105, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str251 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 62, 61, 32, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253 = allocate([ 99, 97, 108, 108, 32, 116, 111, 32, 70, 117, 110, 99, 116, 105, 111, 110, 40, 41, 32, 98, 108, 111, 99, 107, 101, 100, 32, 98, 121, 32, 67, 83, 80, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str254 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 39, 115, 32, 123, 48, 125, 32, 102, 105, 101, 108, 100, 32, 105, 115, 32, 110, 101, 105, 116, 104, 101, 114, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 110, 111, 114, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str255 = allocate([ 112, 114, 111, 120, 121, 32, 119, 97, 115, 32, 102, 105, 120, 101, 100, 32, 119, 104, 105, 108, 101, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 116, 104, 101, 32, 104, 97, 110, 100, 108, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str256 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 101, 118, 97, 108, 32, 115, 99, 111, 112, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str257 = allocate([ 123, 48, 125, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 123, 49, 125, 32, 97, 114, 103, 117, 109, 101, 110, 116, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str258 = allocate([ 39, 99, 97, 108, 108, 101, 114, 39, 44, 32, 39, 99, 97, 108, 108, 101, 101, 39, 44, 32, 97, 110, 100, 32, 39, 97, 114, 103, 117, 109, 101, 110, 116, 115, 39, 32, 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 32, 109, 97, 121, 32, 110, 111, 116, 32, 98, 101, 32, 97, 99, 99, 101, 115, 115, 101, 100, 32, 111, 110, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 111, 114, 32, 116, 104, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 32, 111, 98, 106, 101, 99, 116, 115, 32, 102, 111, 114, 32, 99, 97, 108, 108, 115, 32, 116, 111, 32, 116, 104, 101, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str259 = allocate([ 116, 111, 73, 83, 79, 83, 116, 114, 105, 110, 103, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 110, 111, 116, 32, 99, 97, 108, 108, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str260 = allocate([ 98, 97, 100, 32, 112, 97, 114, 115, 101, 32, 110, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261 = allocate([ 123, 48, 125, 58, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 123, 49, 125, 44, 32, 103, 111, 116, 32, 123, 50, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262 = allocate([ 97, 99, 99, 101, 115, 115, 32, 116, 111, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 97, 108, 108, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 105, 115, 32, 99, 101, 110, 115, 111, 114, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 99, 97, 110, 32, 98, 101, 32, 99, 97, 108, 108, 101, 100, 32, 111, 110, 108, 121, 32, 105, 110, 32, 100, 101, 98, 117, 103, 32, 109, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str264 = allocate([ 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 32, 109, 97, 121, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 117, 110, 112, 97, 114, 101, 110, 116, 104, 101, 115, 105, 122, 101, 100, 32, 108, 101, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str265 = allocate([ 99, 97, 110, 39, 116, 32, 99, 104, 97, 110, 103, 101, 32, 111, 98, 106, 101, 99, 116, 39, 115, 32, 101, 120, 116, 101, 110, 115, 105, 98, 105, 108, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str266 = allocate([ 98, 97, 100, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 100, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 100, 97, 116, 97, 32, 40, 123, 48, 125, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str267 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 116, 121, 112, 101, 32, 102, 111, 114, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str268 = allocate([ 114, 101, 99, 117, 114, 115, 105, 118, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str269 = allocate([ 99, 97, 110, 39, 116, 32, 119, 114, 97, 112, 32, 88, 77, 76, 32, 111, 98, 106, 101, 99, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str270 = allocate([ 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 100, 32, 99, 108, 111, 110, 101, 32, 118, 101, 114, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str271 = allocate([ 99, 97, 110, 39, 116, 32, 99, 108, 111, 110, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272 = allocate([ 110, 111, 110, 45, 110, 97, 116, 105, 118, 101, 32, 115, 99, 111, 112, 101, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273 = allocate([ 105, 110, 32, 115, 116, 114, 105, 99, 116, 32, 109, 111, 100, 101, 32, 99, 111, 100, 101, 44, 32, 102, 117, 110, 99, 116, 105, 111, 110, 115, 32, 109, 97, 121, 32, 98, 101, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 111, 110, 108, 121, 32, 97, 116, 32, 116, 111, 112, 32, 108, 101, 118, 101, 108, 32, 111, 114, 32, 105, 109, 109, 101, 100, 105, 97, 116, 101, 108, 121, 32, 119, 105, 116, 104, 105, 110, 32, 97, 110, 111, 116, 104, 101, 114, 32, 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str274 = allocate([ 102, 111, 114, 45, 105, 110, 32, 108, 111, 111, 112, 32, 108, 101, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 109, 97, 121, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 97, 110, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str275 = allocate([ 97, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 114, 117, 110, 32, 99, 111, 109, 112, 105, 108, 101, 45, 97, 110, 100, 45, 103, 111, 32, 115, 99, 114, 105, 112, 116, 32, 111, 110, 32, 97, 32, 99, 108, 101, 97, 114, 101, 100, 32, 115, 99, 111, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str276 = allocate([ 109, 97, 108, 102, 111, 114, 109, 101, 100, 32, 123, 48, 125, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str277 = allocate([ 105, 108, 108, 101, 103, 97, 108, 32, 117, 115, 101, 32, 111, 102, 32, 123, 48, 125, 32, 105, 110, 32, 103, 101, 110, 101, 114, 97, 116, 111, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str278 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 111, 102, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 116, 111, 32, 97, 110, 32, 88, 77, 76, 32, 118, 97, 108, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str279 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 97, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str280 = allocate([ 123, 48, 125, 58, 32, 97, 114, 103, 117, 109, 101, 110, 116, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 102, 114, 111, 109, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str281 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 32, 114, 101, 115, 117, 109, 112, 116, 105, 111, 110, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 44, 32, 123, 116, 104, 114, 111, 119, 58, 32, 118, 97, 108, 125, 44, 32, 123, 114, 101, 116, 117, 114, 110, 58, 32, 118, 97, 108, 125, 44, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282 = allocate([ 118, 97, 108, 117, 101, 32, 97, 115, 115, 105, 103, 110, 101, 100, 32, 116, 111, 32, 123, 48, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283 = allocate([ 123, 48, 125, 32, 105, 115, 32, 110, 111, 116, 32, 108, 105, 118, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str284 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 32, 98, 101, 108, 111, 110, 103, 115, 32, 116, 111, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 68, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str285 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 46, 112, 114, 111, 116, 111, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 68, 101, 98, 117, 103, 103, 101, 114, 46, 79, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str286 = allocate([ 99, 97, 110, 110, 111, 116, 32, 100, 101, 98, 117, 103, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 32, 115, 97, 109, 101, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 97, 115, 32, 100, 101, 98, 117, 103, 103, 101, 114, 32, 111, 114, 32, 97, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 116, 104, 97, 116, 32, 105, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 98, 117, 103, 103, 105, 110, 103, 32, 116, 104, 101, 32, 100, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str287 = allocate([ 99, 97, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 100, 101, 98, 117, 103, 103, 105, 110, 103, 58, 32, 97, 32, 100, 101, 98, 117, 103, 103, 101, 101, 32, 115, 99, 114, 105, 112, 116, 32, 105, 115, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str288 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 115, 99, 114, 105, 112, 116, 32, 111, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str289 = allocate([ 105, 110, 118, 97, 108, 105, 100, 32, 108, 105, 110, 101, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str290 = allocate([ 99, 97, 110, 39, 116, 32, 115, 101, 116, 32, 98, 114, 101, 97, 107, 112, 111, 105, 110, 116, 58, 32, 115, 99, 114, 105, 112, 116, 32, 103, 108, 111, 98, 97, 108, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 100, 101, 98, 117, 103, 103, 101, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str291 = allocate([ 123, 48, 125, 58, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 32, 46, 123, 49, 125, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 105, 115, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 105, 110, 32, 97, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 99, 111, 109, 112, 97, 114, 116, 109, 101, 110, 116, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292 = allocate([ 115, 116, 97, 99, 107, 32, 102, 114, 97, 109, 101, 32, 105, 115, 32, 110, 111, 116, 32, 114, 117, 110, 110, 105, 110, 103, 32, 74, 97, 118, 97, 83, 99, 114, 105, 112, 116, 32, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

_js_ErrorFormatString = allocate([ 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 5, 0, 5, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 3, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 4, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 3, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 3, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 1, 0, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js5crashL8gGCStackE = allocate(32840, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js5crashL11gErrorStackE = allocate(32840, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js5crashL11gRingBufferE = allocate(32800, [ "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i64", 0, 0, 0, "i32", 0, 0, 0, "i64", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__ZN2js5crashL12crash_cookieE = allocate([ 42, 74, 42, 83, 42, 67, 82, 65, 83, 72, 68, 65, 84, 65, 42, 0 ], "i8", ALLOC_STATIC);

__ZN2js9DateClassE = allocate([ 0, 0, 0, 0, 100665600, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 584, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str894 = allocate([ 85, 84, 67, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2896 = allocate([ 110, 111, 119, 0 ], "i8", ALLOC_STATIC);

__ZL19date_static_methods = allocate([ 0, 0, 0, 0, 586, 0, 0, 0, 7, 0, 4096, 0, 0, 0, 0, 0, 588, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 590, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str3897 = allocate([ 103, 101, 116, 84, 105, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4898 = allocate([ 103, 101, 116, 84, 105, 109, 101, 122, 111, 110, 101, 79, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str5899 = allocate([ 103, 101, 116, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str6900 = allocate([ 103, 101, 116, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str7901 = allocate([ 103, 101, 116, 85, 84, 67, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str8902 = allocate([ 103, 101, 116, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str9903 = allocate([ 103, 101, 116, 85, 84, 67, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str10904 = allocate([ 103, 101, 116, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11905 = allocate([ 103, 101, 116, 85, 84, 67, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12906 = allocate([ 103, 101, 116, 68, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13907 = allocate([ 103, 101, 116, 85, 84, 67, 68, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14908 = allocate([ 103, 101, 116, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str15909 = allocate([ 103, 101, 116, 85, 84, 67, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str16910 = allocate([ 103, 101, 116, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str17911 = allocate([ 103, 101, 116, 85, 84, 67, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str18912 = allocate([ 103, 101, 116, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str19913 = allocate([ 103, 101, 116, 85, 84, 67, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str20914 = allocate([ 103, 101, 116, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21915 = allocate([ 103, 101, 116, 85, 84, 67, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22916 = allocate([ 115, 101, 116, 84, 105, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23917 = allocate([ 115, 101, 116, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str24918 = allocate([ 115, 101, 116, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str25919 = allocate([ 115, 101, 116, 85, 84, 67, 70, 117, 108, 108, 89, 101, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str26920 = allocate([ 115, 101, 116, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str27921 = allocate([ 115, 101, 116, 85, 84, 67, 77, 111, 110, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str28922 = allocate([ 115, 101, 116, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str29923 = allocate([ 115, 101, 116, 85, 84, 67, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str30924 = allocate([ 115, 101, 116, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31925 = allocate([ 115, 101, 116, 85, 84, 67, 72, 111, 117, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32926 = allocate([ 115, 101, 116, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33927 = allocate([ 115, 101, 116, 85, 84, 67, 77, 105, 110, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str34928 = allocate([ 115, 101, 116, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str35929 = allocate([ 115, 101, 116, 85, 84, 67, 83, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str36930 = allocate([ 115, 101, 116, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str37931 = allocate([ 115, 101, 116, 85, 84, 67, 77, 105, 108, 108, 105, 115, 101, 99, 111, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str39933 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 68, 97, 116, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str40934 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 84, 105, 109, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41935 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 70, 111, 114, 109, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42936 = allocate([ 116, 111, 68, 97, 116, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43937 = allocate([ 116, 111, 84, 105, 109, 101, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44938 = allocate([ 116, 111, 73, 83, 79, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL12date_methods = allocate([ 0, 0, 0, 0, 592, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 594, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 596, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 598, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 600, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 602, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 604, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 606, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 608, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 610, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 612, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 614, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 616, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 618, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 620, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 622, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 622, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 624, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 624, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 626, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 628, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 630, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 632, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 634, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 636, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 638, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 640, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 642, 0, 0, 0, 4, 0, 4096, 0, 0, 0, 0, 0, 644, 0, 0, 0, 4, 0, 4096, 0, 0, 0, 0, 0, 646, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 648, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 650, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 652, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 654, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 656, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 658, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 660, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 662, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 664, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 666, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 668, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 670, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 672, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 674, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 676, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 678, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 680, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL8LocalTZA = allocate(1, "double", ALLOC_STATIC);

__ZL15firstDayOfMonth = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 90, 0, 0, 0, 0, 0, 0, 0, 120, 0, 0, 0, 0, 0, 0, 0, 151, 0, 0, 0, 0, 0, 0, 0, 181, 0, 0, 0, 0, 0, 0, 0, 212, 0, 0, 0, 0, 0, 0, 0, 243, 0, 0, 0, 0, 0, 0, 0, 273, 0, 0, 0, 0, 0, 0, 0, 304, 0, 0, 0, 0, 0, 0, 0, 334, 0, 0, 0, 0, 0, 0, 0, 365, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 91, 0, 0, 0, 0, 0, 0, 0, 121, 0, 0, 0, 0, 0, 0, 0, 152, 0, 0, 0, 0, 0, 0, 0, 182, 0, 0, 0, 0, 0, 0, 0, 213, 0, 0, 0, 0, 0, 0, 0, 244, 0, 0, 0, 0, 0, 0, 0, 274, 0, 0, 0, 0, 0, 0, 0, 305, 0, 0, 0, 0, 0, 0, 0, 335, 0, 0, 0, 0, 0, 0, 0, 366, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

__ZL16yearStartingWith = allocate([ 1978, 0, 0, 0, 1973, 0, 0, 0, 1974, 0, 0, 0, 1975, 0, 0, 0, 1981, 0, 0, 0, 1971, 0, 0, 0, 1977, 0, 0, 0, 1984, 0, 0, 0, 1996, 0, 0, 0, 1980, 0, 0, 0, 1992, 0, 0, 0, 1976, 0, 0, 0, 1988, 0, 0, 0, 1972, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL3wtb = allocate(128, "*", ALLOC_STATIC);

__ZL3ttb = allocate([ -1, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 1e4, 0, 0, 0, 1e4, 0, 0, 0, 1e4, 0, 0, 0, 10300, 0, 0, 0, 10240, 0, 0, 0, 10360, 0, 0, 0, 10300, 0, 0, 0, 10420, 0, 0, 0, 10360, 0, 0, 0, 10480, 0, 0, 0, 10420, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str45939 = allocate([ 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str46940 = allocate([ 112, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str47941 = allocate([ 109, 111, 110, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str48942 = allocate([ 116, 117, 101, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str49943 = allocate([ 119, 101, 100, 110, 101, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str50944 = allocate([ 116, 104, 117, 114, 115, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51945 = allocate([ 102, 114, 105, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52946 = allocate([ 115, 97, 116, 117, 114, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53947 = allocate([ 115, 117, 110, 100, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54948 = allocate([ 106, 97, 110, 117, 97, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str55949 = allocate([ 102, 101, 98, 114, 117, 97, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str56950 = allocate([ 109, 97, 114, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str57951 = allocate([ 97, 112, 114, 105, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str58952 = allocate([ 109, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str59953 = allocate([ 106, 117, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str60954 = allocate([ 106, 117, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61955 = allocate([ 97, 117, 103, 117, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62956 = allocate([ 115, 101, 112, 116, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63957 = allocate([ 111, 99, 116, 111, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64958 = allocate([ 110, 111, 118, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str65959 = allocate([ 100, 101, 99, 101, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str66960 = allocate([ 103, 109, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str67961 = allocate([ 117, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str68962 = allocate([ 117, 116, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str69963 = allocate([ 101, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str70964 = allocate([ 101, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71965 = allocate([ 99, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72966 = allocate([ 99, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73967 = allocate([ 109, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74968 = allocate([ 109, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str75969 = allocate([ 112, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str76970 = allocate([ 112, 100, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_NaN_date_str = allocate([ 73, 110, 118, 97, 108, 105, 100, 32, 68, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str77971 = allocate([ 40, 37, 90, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str78972 = allocate([ 37, 115, 32, 37, 115, 32, 37, 46, 50, 100, 32, 37, 46, 52, 100, 32, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 37, 43, 46, 52, 100, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

__ZL4days = allocate(28, "*", ALLOC_STATIC);

__ZL6months = allocate(48, "*", ALLOC_STATIC);

STRING_TABLE.__str81975 = allocate([ 37, 115, 32, 37, 115, 32, 37, 46, 50, 100, 32, 37, 46, 52, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82976 = allocate([ 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 37, 43, 46, 52, 100, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83977 = allocate([ 74, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84978 = allocate([ 70, 101, 98, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str85979 = allocate([ 77, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str86980 = allocate([ 65, 112, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str87981 = allocate([ 77, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str88982 = allocate([ 74, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str89983 = allocate([ 74, 117, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str90984 = allocate([ 65, 117, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91985 = allocate([ 83, 101, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92986 = allocate([ 79, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93987 = allocate([ 78, 111, 118, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94988 = allocate([ 68, 101, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str95989 = allocate([ 83, 117, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str96990 = allocate([ 77, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str97991 = allocate([ 84, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str98992 = allocate([ 87, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str99993 = allocate([ 84, 104, 117, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str100994 = allocate([ 70, 114, 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101995 = allocate([ 83, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103997 = allocate([ 37, 46, 52, 100, 45, 37, 46, 50, 100, 45, 37, 46, 50, 100, 84, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 46, 37, 46, 51, 100, 90, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104998 = allocate([ 37, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1061000 = allocate([ 37, 88, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1081002 = allocate([ 37, 115, 44, 32, 37, 46, 50, 100, 32, 37, 115, 32, 37, 46, 52, 100, 32, 37, 46, 50, 100, 58, 37, 46, 50, 100, 58, 37, 46, 50, 100, 32, 71, 77, 84, 0 ], "i8", ALLOC_STATIC);

_js_NullDebugHooks = allocate(72, "*", ALLOC_STATIC);

__ZL10gLastError = allocate(2e3, "i8", ALLOC_STATIC);

__ZL8stub_ops = allocate([ 682, 0, 0, 0, 684, 0, 0, 0, 686, 0, 0, 0, 688, 0, 0, 0, 690, 0, 0, 0, 692, 0, 0, 0, 694, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL9dtoaModes = allocate([ 0, 0, 3, 2, 2 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1096 = allocate([ 101, 37, 43, 100, 0 ], "i8", ALLOC_STATIC);

_tens = allocate([ 1, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 1e3, 0, 0, 0, 0, 0, 0, 0, 1e4, 0, 0, 0, 0, 0, 0, 0, 1e5, 0, 0, 0, 0, 0, 0, 0, 1e6, 0, 0, 0, 0, 0, 0, 0, 1e7, 0, 0, 0, 0, 0, 0, 0, 1e8, 0, 0, 0, 0, 0, 0, 0, 1e9, 0, 0, 0, 0, 0, 0, 0, 1e10, 0, 0, 0, 0, 0, 0, 0, 1e11, 0, 0, 0, 0, 0, 0, 0, 1e12, 0, 0, 0, 0, 0, 0, 0, 1e13, 0, 0, 0, 0, 0, 0, 0, 1e14, 0, 0, 0, 0, 0, 0, 0, 1e15, 0, 0, 0, 0, 0, 0, 0, 1e16, 0, 0, 0, 0, 0, 0, 0, 1e17, 0, 0, 0, 0, 0, 0, 0, 1e18, 0, 0, 0, 0, 0, 0, 0, 1e19, 0, 0, 0, 0, 0, 0, 0, 1e20, 0, 0, 0, 0, 0, 0, 0, 1e+21, 0, 0, 0, 0, 0, 0, 0, 1e+22, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

_bigtens = allocate([ 1e16, 0, 0, 0, 0, 0, 0, 0, 1e+32, 0, 0, 0, 0, 0, 0, 0, 1e+64, 0, 0, 0, 0, 0, 0, 0, 1e+128, 0, 0, 0, 0, 0, 0, 0, 1e+256, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

_p05 = allocate([ 5, 0, 0, 0, 25, 0, 0, 0, 125, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_tinytens = allocate([ 1e-16, 0, 0, 0, 0, 0, 0, 0, 1e-32, 0, 0, 0, 0, 0, 0, 0, 1e-64, 0, 0, 0, 0, 0, 0, 0, 1e-128, 0, 0, 0, 0, 0, 0, 0, 8.112963841460668e-225, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0, "double", 0, 0, 0, 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str11107 = allocate([ 35, 100, 101, 112, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41110 = allocate([ 105, 102, 45, 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81114 = allocate([ 100, 101, 99, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91115 = allocate([ 112, 99, 100, 101, 108, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101116 = allocate([ 97, 115, 115, 105, 103, 110, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111117 = allocate([ 99, 111, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121118 = allocate([ 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131119 = allocate([ 104, 105, 100, 100, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str141120 = allocate([ 112, 99, 98, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161122 = allocate([ 108, 97, 98, 101, 108, 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str171123 = allocate([ 101, 110, 100, 98, 114, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str181124 = allocate([ 98, 114, 101, 97, 107, 50, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str191125 = allocate([ 99, 111, 110, 116, 50, 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str211127 = allocate([ 102, 117, 110, 99, 100, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str231129 = allocate([ 101, 120, 116, 101, 110, 100, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str241130 = allocate([ 110, 101, 119, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str251131 = allocate([ 115, 101, 116, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261132 = allocate([ 120, 100, 101, 108, 116, 97, 0 ], "i8", ALLOC_STATIC);

_js_SrcNoteSpec = allocate([ 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 2, 0, 1, undef, 0, 0, 0, 0, 3, 1, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 1, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, -1, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 2, 0, 1, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 1, 0, 1, undef, 0, 0, 0, 0, -1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 1, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, undef ], [ "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL13statementName = allocate(60, "*", ALLOC_STATIC);

STRING_TABLE.__str271135 = allocate([ 108, 97, 98, 101, 108, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str281136 = allocate([ 105, 102, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str291137 = allocate([ 101, 108, 115, 101, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str301138 = allocate([ 100, 101, 115, 116, 114, 117, 99, 116, 117, 114, 105, 110, 103, 32, 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str311139 = allocate([ 115, 119, 105, 116, 99, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL21js_with_statement_str = allocate([ 119, 105, 116, 104, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str331141 = allocate([ 99, 97, 116, 99, 104, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str341142 = allocate([ 116, 114, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL20js_finally_block_str = allocate([ 102, 105, 110, 97, 108, 108, 121, 32, 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str351143 = allocate([ 100, 111, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str361144 = allocate([ 102, 111, 114, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str371145 = allocate([ 102, 111, 114, 47, 105, 110, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str381146 = allocate([ 119, 104, 105, 108, 101, 32, 108, 111, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str401148 = allocate([ 115, 116, 100, 105, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js10ErrorClassE = allocate([ 0, 0, 0, 0, 234881029, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 696, 0, 0, 0, 88, 0, 0, 0, 698, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 700, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17exception_methods = allocate([ 0, 0, 0, 0, 702, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 704, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str1193 = allocate([ 117, 110, 107, 110, 111, 119, 110, 32, 40, 99, 97, 110, 39, 116, 32, 99, 111, 110, 118, 101, 114, 116, 32, 116, 111, 32, 115, 116, 114, 105, 110, 103, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31196 = allocate([ 91, 117, 110, 107, 110, 111, 119, 110, 32, 102, 117, 110, 99, 116, 105, 111, 110, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41197 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

__ZN2js26StrictArgumentsObjectClassE = allocate([ 0, 0, 0, 0, 16777733, 0, 0, 0, 10, 0, 0, 0, 706, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 708, 0, 0, 0, 710, 0, 0, 0, 88, 0, 0, 0, 712, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 714, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js26NormalArgumentsObjectClassE = allocate([ 0, 0, 0, 0, 16777733, 0, 0, 0, 10, 0, 0, 0, 706, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 716, 0, 0, 0, 718, 0, 0, 0, 88, 0, 0, 0, 712, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 714, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str1263 = allocate([ 65, 114, 103, 117, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

__ZN2js12DeclEnvClassE = allocate([ 0, 0, 0, 0, 16777217, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str11264 = allocate([ 67, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

__ZN2js9CallClassE = allocate([ 0, 0, 0, 0, 131589, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 720, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 722, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL15poisonPillProps = allocate([ 228, 0, 248, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js13FunctionClassE = allocate([ 0, 0, 0, 0, 33554965, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 724, 0, 0, 0, 726, 0, 0, 0, 88, 0, 0, 0, 728, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 730, 0, 0, 0, 732, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str31270 = allocate([ 98, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41271 = allocate([ 105, 115, 71, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js16function_methodsE = allocate([ 0, 0, 0, 0, 734, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 736, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 738, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 740, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 742, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 744, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js2gc16slotsToThingKindE = allocate([ 0, 0, 0, 0, 2, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0, 0, 4, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 6, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 8, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js2gc5Arena10ThingSizesE = allocate([ 40, 0, 0, 0, 40, 0, 0, 0, 56, 0, 0, 0, 56, 0, 0, 0, 72, 0, 0, 0, 72, 0, 0, 0, 104, 0, 0, 0, 104, 0, 0, 0, 136, 0, 0, 0, 136, 0, 0, 0, 168, 0, 0, 0, 168, 0, 0, 0, 80, 0, 0, 0, 104, 0, 0, 0, 40, 0, 0, 0, 32, 0, 0, 0, 72, 0, 0, 0, 32, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js2gc5Arena17FirstThingOffsetsE = allocate([ 16, 0, 0, 0, 16, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 40, 0, 0, 0, 40, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0, 64, 0, 0, 0, 64, 0, 0, 0, 16, 0, 0, 0, 40, 0, 0, 0, 16, 0, 0, 0, 32, 0, 0, 0, 64, 0, 0, 0, 32, 0, 0, 0, 16, 0, 0, 0, 16, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindEE3map = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8gcReasonE = allocate([ 10 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str1551 = allocate([ 32, 32, 65, 80, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11552 = allocate([ 77, 97, 121, 98, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str21553 = allocate([ 76, 97, 115, 116, 67, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31554 = allocate([ 68, 101, 115, 116, 67, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41555 = allocate([ 67, 111, 109, 112, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51556 = allocate([ 76, 97, 115, 116, 68, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61557 = allocate([ 77, 97, 108, 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71558 = allocate([ 82, 101, 102, 105, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81559 = allocate([ 67, 104, 117, 110, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91560 = allocate([ 83, 104, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101561 = allocate([ 32, 32, 78, 111, 110, 101, 0 ], "i8", ALLOC_STATIC);

__ZN2js9gcReasonsE = allocate(44, "*", ALLOC_STATIC);

__ZN2js13newChunkCountE = allocate(1, "i32", ALLOC_STATIC);

__ZN2js17destroyChunkCountE = allocate(1, "i32", ALLOC_STATIC);

__ZL19defaultHashAllocOps = allocate([ 746, 0, 0, 0, 748, 0, 0, 0, 750, 0, 0, 0, 752, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str1568 = allocate([ 91, 105, 110, 102, 101, 114, 32, 102, 97, 105, 108, 117, 114, 101, 93, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str11569 = allocate([ 47, 100, 105, 115, 107, 47, 108, 111, 99, 97, 108, 47, 106, 116, 101, 114, 114, 97, 99, 101, 47, 98, 117, 105, 108, 100, 98, 111, 116, 47, 115, 108, 97, 118, 101, 47, 106, 115, 95, 106, 115, 95, 66, 117, 105, 108, 100, 95, 65, 108, 108, 47, 98, 117, 105, 108, 100, 47, 98, 117, 105, 108, 100, 101, 114, 47, 98, 117, 105, 108, 100, 47, 109, 111, 122, 105, 108, 108, 97, 45, 99, 101, 110, 116, 114, 97, 108, 47, 106, 115, 47, 115, 114, 99, 47, 106, 115, 105, 110, 102, 101, 114, 46, 99, 112, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str31571 = allocate([ 32, 91, 111, 119, 110, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str41572 = allocate([ 32, 91, 99, 111, 110, 102, 105, 103, 117, 114, 101, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str51573 = allocate([ 32, 91, 100, 101, 102, 105, 110, 105, 116, 101, 58, 37, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str61574 = allocate([ 32, 109, 105, 115, 115, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str71575 = allocate([ 32, 117, 110, 107, 110, 111, 119, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str81576 = allocate([ 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str91577 = allocate([ 32, 118, 111, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str101578 = allocate([ 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str111579 = allocate([ 32, 98, 111, 111, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str121580 = allocate([ 32, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str131581 = allocate([ 32, 102, 108, 111, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str141582 = allocate([ 32, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str151583 = allocate([ 32, 108, 97, 122, 121, 97, 114, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str161584 = allocate([ 32, 111, 98, 106, 101, 99, 116, 91, 37, 117, 93, 0 ], "i8", ALLOC_STATIC);

__ZN2js5types15emptyTypeObjectE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33488904, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str231593 = allocate([ 67, 111, 117, 110, 116, 115, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str261596 = allocate([ 32, 40, 37, 117, 32, 111, 118, 101, 114, 41, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str271597 = allocate([ 82, 101, 99, 111, 109, 112, 105, 108, 97, 116, 105, 111, 110, 115, 58, 32, 37, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str311601 = allocate([ 37, 115, 32, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str331603 = allocate([ 32, 112, 97, 99, 107, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str341604 = allocate([ 32, 100, 101, 110, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str351605 = allocate([ 32, 116, 121, 112, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str361606 = allocate([ 32, 117, 110, 105, 110, 108, 105, 110, 101, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str371607 = allocate([ 32, 115, 112, 101, 99, 105, 97, 108, 69, 113, 117, 97, 108, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str381608 = allocate([ 32, 105, 116, 101, 114, 97, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str401610 = allocate([ 32, 123, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str411611 = allocate([ 10, 32, 32, 32, 32, 37, 115, 58, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str471617 = allocate([ 85, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 37, 48, 50, 120, 32, 97, 116, 32, 35, 37, 117, 58, 37, 48, 53, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str481618 = allocate([ 85, 110, 107, 110, 111, 119, 110, 32, 98, 121, 116, 101, 99, 111, 100, 101, 32, 37, 48, 50, 120, 0 ], "i8", ALLOC_STATIC);

__ZTV18TypeConstraintProp = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 754, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV22TypeConstraintCallProp = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 760, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV24TypeConstraintSetElement = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 762, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV18TypeConstraintCall = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 764, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV19TypeConstraintArith = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 766, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintTransformThis = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 768, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintPropagateThis = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 770, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV26TypeConstraintFreezeGlobal = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 772, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js5types14TypeConstraintE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV31TypeConstraintFreezeOwnProperty = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 774, 0, 0, 0, 776, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV31TypeConstraintFreezeObjectFlags = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 778, 0, 0, 0, 756, 0, 0, 0, 780, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV34TypeConstraintFreezeObjectFlagsSet = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 782, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintFreezeTypeTag = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 784, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV20TypeConstraintFreeze = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 786, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintLazyArguments = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 788, 0, 0, 0, 756, 0, 0, 0, 790, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV27TypeConstraintSubsetBarrier = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 792, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV29TypeConstraintFilterPrimitive = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 794, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV20TypeConstraintSubset = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 796, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV33TypeConstraintClearDefiniteSingle = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 798, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTV33TypeConstraintClearDefiniteSetter = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 800, 0, 0, 0, 756, 0, 0, 0, 758, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZZL15InferSpewActiveN2js5types11SpewChannelEE6active = allocate(2, "i8", ALLOC_STATIC);

__ZZL15InferSpewActiveN2js5types11SpewChannelEE7checked_b = allocate(1, "i1", ALLOC_STATIC);

STRING_TABLE.__str741644 = allocate([ 73, 78, 70, 69, 82, 70, 76, 65, 71, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str751645 = allocate([ 111, 112, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str761646 = allocate([ 114, 101, 115, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str771647 = allocate([ 102, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str781648 = allocate([ 40, 109, 105, 115, 115, 105, 110, 103, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1777 = allocate([ 78, 111, 83, 117, 99, 104, 77, 101, 116, 104, 111, 100, 0 ], "i8", ALLOC_STATIC);

_js_NoSuchMethodClass = allocate([ 0, 0, 0, 0, 131584, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 802, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZTV23GenericInterruptEnablerIiE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 804, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZTVN2js17InterpreterFrames20InterruptEnablerBaseE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 444, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZN2js13IteratorClassE = allocate([ 0, 0, 0, 0, 369098769, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 806, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 808, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 810, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_sCustomIteratorCount = allocate(1, "i32", ALLOC_STATIC);

__ZL16iterator_methods = allocate([ 0, 0, 0, 0, 812, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js18StopIterationClassE = allocate([ 0, 0, 0, 0, 387973120, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 814, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str31916 = allocate([ 71, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js14GeneratorClassE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 816, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 818, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 810, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17generator_methods = allocate([ 0, 0, 0, 0, 820, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 822, 0, 0, 0, 1, 0, 4102, 0, 0, 0, 0, 0, 824, 0, 0, 0, 1, 0, 4102, 0, 0, 0, 0, 0, 826, 0, 0, 0, 0, 0, 4102, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js9MathClassE = allocate([ 0, 0, 0, 0, 117440512, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2000 = allocate([ 97, 98, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12001 = allocate([ 97, 99, 111, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22002 = allocate([ 97, 115, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32003 = allocate([ 97, 116, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42004 = allocate([ 97, 116, 97, 110, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52005 = allocate([ 99, 101, 105, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62006 = allocate([ 99, 111, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72007 = allocate([ 101, 120, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82008 = allocate([ 102, 108, 111, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92009 = allocate([ 108, 111, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102010 = allocate([ 109, 97, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112011 = allocate([ 109, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122012 = allocate([ 112, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132013 = allocate([ 114, 97, 110, 100, 111, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142014 = allocate([ 114, 111, 117, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152015 = allocate([ 115, 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162016 = allocate([ 115, 113, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172017 = allocate([ 116, 97, 110, 0 ], "i8", ALLOC_STATIC);

__ZL19math_static_methods = allocate([ 0, 0, 0, 0, 828, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 830, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 832, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 834, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 836, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 838, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 840, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 842, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 844, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 846, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 848, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 850, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 852, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 854, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 856, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 858, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 860, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 862, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 864, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL14math_constants = allocate([ 2.718281828459045, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.4426950408889634, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .4342944819032518, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .6931471805599453, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2.302585092994046, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3.141592653589793, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.4142135623730951, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, .7071067811865476, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str182018 = allocate([ 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192019 = allocate([ 76, 79, 71, 50, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202020 = allocate([ 76, 79, 71, 49, 48, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212021 = allocate([ 76, 78, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222022 = allocate([ 76, 78, 49, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232023 = allocate([ 80, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242024 = allocate([ 83, 81, 82, 84, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252025 = allocate([ 83, 81, 82, 84, 49, 95, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_Infinity_str = allocate([ 73, 110, 102, 105, 110, 105, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_NaN_str = allocate([ 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isNaN_str = allocate([ 105, 115, 78, 97, 78, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isFinite_str = allocate([ 105, 115, 70, 105, 110, 105, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_parseFloat_str = allocate([ 112, 97, 114, 115, 101, 70, 108, 111, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_parseInt_str = allocate([ 112, 97, 114, 115, 101, 73, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16number_functions = allocate([ 0, 0, 0, 0, 866, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 868, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 870, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 872, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js11NumberClassE = allocate([ 0, 0, 0, 0, 134217984, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str2072 = allocate([ 116, 111, 70, 105, 120, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12073 = allocate([ 116, 111, 69, 120, 112, 111, 110, 101, 110, 116, 105, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22074 = allocate([ 116, 111, 80, 114, 101, 99, 105, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZL14number_methods = allocate([ 0, 0, 0, 0, 874, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 876, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 878, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 194, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 880, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 882, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 884, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_js_NaN = allocate(1, "double", ALLOC_STATIC);

_js_PositiveInfinity = allocate(1, "double", ALLOC_STATIC);

_js_NegativeInfinity = allocate(1, "double", ALLOC_STATIC);

__ZL16number_constants = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1.7976931348623157e+308, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "double", 0, 0, 0, 0, 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str32081 = allocate([ 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42082 = allocate([ 46, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52083 = allocate([ 3, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62084 = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72085 = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82086 = allocate([ 80, 79, 83, 73, 84, 73, 86, 69, 95, 73, 78, 70, 73, 78, 73, 84, 89, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92087 = allocate([ 78, 69, 71, 65, 84, 73, 86, 69, 95, 73, 78, 70, 73, 78, 73, 84, 89, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102088 = allocate([ 77, 65, 88, 95, 86, 65, 76, 85, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112089 = allocate([ 77, 73, 78, 95, 86, 65, 76, 85, 69, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122090 = allocate([ 40, 110, 101, 119, 32, 37, 115, 40, 37, 115, 41, 41, 0 ], "i8", ALLOC_STATIC);

__ZN2js5Shape15sharedNonNativeE = allocate([ -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i8", "i8", "i16", 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11ObjectClassE = allocate([ 0, 0, 0, 0, 16777216, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

_object_props = allocate([ 0, 0, 0, 0, 0, 68, 0, 0, 886, 0, 0, 0, 888, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

_sSetProtoCalled = allocate(1, "i32", ALLOC_STATIC);

STRING_TABLE.__str12178 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22179 = allocate([ 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32180 = allocate([ 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42181 = allocate([ 98, 111, 111, 108, 101, 97, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_defineGetter_str = allocate([ 95, 95, 100, 101, 102, 105, 110, 101, 71, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_defineSetter_str = allocate([ 95, 95, 100, 101, 102, 105, 110, 101, 83, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lookupGetter_str = allocate([ 95, 95, 108, 111, 111, 107, 117, 112, 71, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lookupSetter_str = allocate([ 95, 95, 108, 111, 111, 107, 117, 112, 83, 101, 116, 116, 101, 114, 95, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_watch_str = allocate([ 119, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_unwatch_str = allocate([ 117, 110, 119, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_hasOwnProperty_str = allocate([ 104, 97, 115, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isPrototypeOf_str = allocate([ 105, 115, 80, 114, 111, 116, 111, 116, 121, 112, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_propertyIsEnumerable_str = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 73, 115, 69, 110, 117, 109, 101, 114, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

_object_methods = allocate([ 0, 0, 0, 0, 890, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 892, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 894, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 896, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 898, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 900, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 902, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 904, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 906, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 908, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 910, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 912, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 914, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str92206 = allocate([ 103, 101, 116, 80, 114, 111, 116, 111, 116, 121, 112, 101, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102207 = allocate([ 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112208 = allocate([ 107, 101, 121, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122209 = allocate([ 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132210 = allocate([ 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152212 = allocate([ 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162213 = allocate([ 105, 115, 69, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172214 = allocate([ 112, 114, 101, 118, 101, 110, 116, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182215 = allocate([ 102, 114, 101, 101, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192216 = allocate([ 105, 115, 70, 114, 111, 122, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202217 = allocate([ 115, 101, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212218 = allocate([ 105, 115, 83, 101, 97, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

_object_static_methods = allocate([ 0, 0, 0, 0, 916, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 918, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 920, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 922, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 924, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 926, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 928, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 930, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 932, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 934, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 936, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 938, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 940, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str222221 = allocate([ 87, 105, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZN2js9WithClassE = allocate([ 0, 0, 0, 0, 131585, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 942, 0, 0, 0, 942, 0, 0, 0, 944, 0, 0, 0, 946, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 948, 0, 0, 0, 950, 0, 0, 0, 952, 0, 0, 0, 954, 0, 0, 0, 956, 0, 0, 0, 956, 0, 0, 0, 958, 0, 0, 0, 960, 0, 0, 0, 962, 0, 0, 0, 962, 0, 0, 0, 964, 0, 0, 0, 966, 0, 0, 0, 968, 0, 0, 0, 968, 0, 0, 0, 970, 0, 0, 0, 972, 0, 0, 0, 974, 0, 0, 0, 974, 0, 0, 0, 976, 0, 0, 0, 978, 0, 0, 0, 980, 0, 0, 0, 982, 0, 0, 0, 0, 0, 0, 0, 984, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str232224 = allocate([ 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

__ZN2js10BlockClassE = allocate([ 0, 0, 0, 0, 131329, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL19lazy_prototype_init = allocate([ 986, 0, 0, 0, 44, 0, 0, 0, 448, 0, 0, 0, 450, 0, 0, 0, 452, 0, 0, 0, 474, 0, 0, 0, 454, 0, 0, 0, 456, 0, 0, 0, 458, 0, 0, 0, 460, 0, 0, 0, 464, 0, 0, 0, 466, 0, 0, 0, 468, 0, 0, 0, 470, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 462, 0, 0, 0, 472, 0, 0, 0, 472, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 476, 0, 0, 0, 480, 0, 0, 0, 986, 0, 0, 0, 478, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str242227 = allocate([ 112, 114, 105, 109, 105, 116, 105, 118, 101, 32, 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262229 = allocate([ 37, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str322235 = allocate([ 79, 98, 106, 101, 99, 116, 46, 105, 115, 83, 101, 97, 108, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str352238 = allocate([ 79, 98, 106, 101, 99, 116, 46, 115, 101, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str362239 = allocate([ 79, 98, 106, 101, 99, 116, 46, 112, 114, 101, 118, 101, 110, 116, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str372240 = allocate([ 79, 98, 106, 101, 99, 116, 46, 102, 114, 101, 101, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str382241 = allocate([ 79, 98, 106, 101, 99, 116, 46, 105, 115, 69, 120, 116, 101, 110, 115, 105, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str392242 = allocate([ 79, 98, 106, 101, 99, 116, 46, 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 78, 97, 109, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str402243 = allocate([ 79, 98, 106, 101, 99, 116, 46, 99, 114, 101, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str412244 = allocate([ 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 32, 111, 114, 32, 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str422245 = allocate([ 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str432246 = allocate([ 79, 98, 106, 101, 99, 116, 46, 100, 101, 102, 105, 110, 101, 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str442247 = allocate([ 79, 98, 106, 101, 99, 116, 46, 107, 101, 121, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str452248 = allocate([ 79, 98, 106, 101, 99, 116, 46, 103, 101, 116, 79, 119, 110, 80, 114, 111, 112, 101, 114, 116, 121, 68, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str472250 = allocate([ 99, 97, 108, 108, 32, 116, 111, 32, 101, 118, 97, 108, 40, 41, 32, 98, 108, 111, 99, 107, 101, 100, 32, 98, 121, 32, 67, 83, 80, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsEE20TWO_ARGUMENT_WARNING = allocate([ 83, 117, 112, 112, 111, 114, 116, 32, 102, 111, 114, 32, 101, 118, 97, 108, 40, 99, 111, 100, 101, 44, 32, 115, 99, 111, 112, 101, 79, 98, 106, 101, 99, 116, 41, 32, 104, 97, 115, 32, 98, 101, 101, 110, 32, 114, 101, 109, 111, 118, 101, 100, 46, 32, 85, 115, 101, 32, 124, 119, 105, 116, 104, 32, 40, 115, 99, 111, 112, 101, 79, 98, 106, 101, 99, 116, 41, 32, 101, 118, 97, 108, 40, 99, 111, 100, 101, 41, 59, 124, 32, 105, 110, 115, 116, 101, 97, 100, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2js9JSONClassE = allocate([ 0, 0, 0, 0, 83886080, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str12532 = allocate([ 115, 116, 114, 105, 110, 103, 105, 102, 121, 0 ], "i8", ALLOC_STATIC);

__ZL19json_static_methods = allocate([ 0, 0, 0, 0, 988, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 990, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 992, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str52536 = allocate([ 92, 117, 48, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2606 = allocate([ 110, 111, 32, 110, 117, 109, 98, 101, 114, 32, 97, 102, 116, 101, 114, 32, 109, 105, 110, 117, 115, 32, 115, 105, 103, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12607 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 110, 45, 100, 105, 103, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22608 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 100, 101, 99, 105, 109, 97, 108, 32, 112, 111, 105, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32609 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str42610 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 101, 120, 112, 111, 110, 101, 110, 116, 32, 105, 110, 100, 105, 99, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52611 = allocate([ 109, 105, 115, 115, 105, 110, 103, 32, 100, 105, 103, 105, 116, 115, 32, 97, 102, 116, 101, 114, 32, 101, 120, 112, 111, 110, 101, 110, 116, 32, 115, 105, 103, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62612 = allocate([ 101, 120, 112, 111, 110, 101, 110, 116, 32, 112, 97, 114, 116, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 97, 32, 110, 117, 109, 98, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72613 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82614 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 107, 101, 121, 119, 111, 114, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92615 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102616 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 105, 108, 101, 32, 114, 101, 97, 100, 105, 110, 103, 32, 111, 98, 106, 101, 99, 116, 32, 99, 111, 110, 116, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112617 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 111, 114, 32, 39, 125, 39, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122618 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 101, 110, 32, 39, 44, 39, 32, 111, 114, 32, 39, 93, 39, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132619 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 93, 39, 32, 97, 102, 116, 101, 114, 32, 97, 114, 114, 97, 121, 32, 101, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142620 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 119, 104, 101, 110, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152621 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 100, 111, 117, 98, 108, 101, 45, 113, 117, 111, 116, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162622 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 119, 104, 101, 110, 32, 39, 58, 39, 32, 119, 97, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172623 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 58, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182624 = allocate([ 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192625 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 125, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 118, 97, 108, 117, 101, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202626 = allocate([ 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 44, 39, 32, 111, 114, 32, 39, 125, 39, 32, 97, 102, 116, 101, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 45, 118, 97, 108, 117, 101, 32, 112, 97, 105, 114, 32, 105, 110, 32, 111, 98, 106, 101, 99, 116, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212627 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 32, 110, 97, 109, 101, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 100, 111, 117, 98, 108, 101, 45, 113, 117, 111, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222628 = allocate([ 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 110, 45, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 97, 102, 116, 101, 114, 32, 74, 83, 79, 78, 32, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232629 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242630 = allocate([ 98, 97, 100, 32, 99, 111, 110, 116, 114, 111, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 105, 110, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252631 = allocate([ 98, 97, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 105, 110, 32, 115, 116, 114, 105, 110, 103, 32, 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262632 = allocate([ 98, 97, 100, 32, 85, 110, 105, 99, 111, 100, 101, 32, 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272633 = allocate([ 98, 97, 100, 32, 101, 115, 99, 97, 112, 101, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282634 = allocate([ 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

_js_CodeSpec = allocate([ 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 1, 1, 1, 0, 1048576, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 3, 1, 0, 4, 16385, 0, 0, 0, 3, 1, 0, 0, 1048577, 0, 0, 0, 1, 0, 1, 18, 0, 0, 0, 0, 1, 2, 2, 0, 0, 0, 0, 0, 3, -1, 0, 0, 3, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 1, 2, 4, 0, 0, 0, 0, 0, 3, 1, 1, 3, 290, 0, 0, 0, 1, 2, 1, 7, 65536, 0, 0, 0, 1, 2, 1, 8, 65536, 0, 0, 0, 1, 2, 1, 9, 65536, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 12, 65536, 0, 0, 0, 1, 2, 1, 13, 65536, 0, 0, 0, 1, 2, 1, 13, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 2, 1, 14, 65536, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 3, 0, 1, 15, 546, 0, 0, 0, 3, 1, 1, 15, 578, 0, 0, 0, 1, 2, 1, 15, 608, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 1, 1, 1, 15, 0, 0, 0, 0, 4, 0, 1, 15, 146802722, 0, 0, 0, 4, 1, 1, 15, 146802754, 0, 0, 0, 2, 2, 1, 15, 142608480, 0, 0, 0, 4, 0, 1, 15, 146801698, 0, 0, 0, 4, 1, 1, 15, 146801730, 0, 0, 0, 2, 2, 1, 15, 142607456, 0, 0, 0, 4, 0, 1, 15, 146806818, 0, 0, 0, 4, 1, 1, 15, 146806850, 0, 0, 0, 2, 2, 1, 15, 142612576, 0, 0, 0, 4, 0, 1, 15, 146805794, 0, 0, 0, 4, 1, 1, 15, 146805826, 0, 0, 0, 2, 2, 1, 15, 142611552, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 2, 1, 18, 67174496, 0, 0, 0, 1, 3, 1, 3, 16736, 0, 0, 0, 3, 0, 2, 19, 67633186, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 1, 19, 67108898, 0, 0, 0, 3, 0, 1, 16, 2, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 1, 0, 1, 16, 0, 0, 0, 0, 1, 0, 1, 16, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 3, 1, 0, 5, 81921, 0, 0, 0, 3, 1, 0, 6, 81921, 0, 0, 0, -1, 1, 0, 0, 1064964, 0, 0, 0, -1, 1, 0, 0, 1064965, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 2, 1, 10, 81920, 0, 0, 0, 1, 1, 2, 18, 0, 0, 0, 0, 2, 1, 1, 0, 13, 0, 0, 0, 1, 1, 2, 0, 0, 0, 0, 0, 2, 0, 1, 0, 13, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 3, -1, 1, 17, 69206019, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 38, 0, 0, 0, 3, 1, 1, 3, 294, 0, 0, 0, 3, 0, 1, 19, 39, 0, 0, 0, 3, 1, 1, 3, 16679, 0, 0, 0, 3, 0, 1, 16, 3, 0, 0, 0, 3, 0, 1, 19, 13, 0, 0, 0, 4, 0, 1, 19, 12, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 0, 0, 19, 0, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 3, 1, 3, 16736, 0, 0, 0, 5, 0, 0, 0, 16777236, 0, 0, 0, 5, 0, 1, 0, 16777236, 0, 0, 0, 3, 0, 1, 15, 12584998, 0, 0, 0, 3, 0, 1, 15, 12583974, 0, 0, 0, 3, 0, 1, 15, 12589094, 0, 0, 0, 3, 0, 1, 15, 12588070, 0, 0, 0, 3, 0, 1, 15, 12584999, 0, 0, 0, 3, 0, 1, 15, 12583975, 0, 0, 0, 3, 0, 1, 15, 12589095, 0, 0, 0, 3, 0, 1, 15, 12588071, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 0, 0, 0, 0, 3, 0, 2, 19, 0, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 1, 0, 290, 0, 0, 0, 3, 2, 1, 3, 16674, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 2, 1, 11, 65536, 0, 0, 0, 1, 2, 1, 11, 4259840, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0, 1048576, 0, 0, 0, 3, 2, 1, 0, 8388609, 0, 0, 0, 3, 1, 0, 0, 1, 0, 0, 0, 3, -1, 1, 18, 69206019, 0, 0, 0, 1, 3, 0, 3, 4194560, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 131087, 0, 0, 0, 3, 0, 0, 0, 131074, 0, 0, 0, 3, 0, 0, 0, 131074, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 3, 1, 0, 3, 295, 0, 0, 0, 2, 0, 0, 0, 8388621, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 3, 0, 1, 19, 67108899, 0, 0, 0, 3, 0, 2, 19, 67633187, 0, 0, 0, 3, 0, 1, 18, 38, 0, 0, 0, 1, 0, 1, 18, 0, 0, 0, 0, 5, 0, 0, 0, 4325392, 0, 0, 0, 5, 0, 0, 0, 9, 0, 0, 0, 5, 1, 0, 4, 16393, 0, 0, 0, 5, 1, 0, 0, 1048585, 0, 0, 0, 5, 1, 0, 5, 16393, 0, 0, 0, 5, 1, 0, 6, 16393, 0, 0, 0, 5, 0, 0, 0, 9, 0, 0, 0, 5, 2, 1, 0, 9, 0, 0, 0, 5, 1, 0, 0, 9, 0, 0, 0, -1, 1, 0, 0, 1064970, 0, 0, 0, -1, 1, 0, 0, 1064971, 0, 0, 0, 3, 0, 0, 0, 32769, 0, 0, 0, 3, 1, 0, 0, 32769, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 19, 100663330, 0, 0, 0, 3, 2, 1, 3, 33571106, 0, 0, 0, 4, 0, 1, 15, 180357154, 0, 0, 0, 4, 0, 1, 15, 180356130, 0, 0, 0, 4, 0, 1, 15, 180361250, 0, 0, 0, 4, 0, 1, 15, 180360226, 0, 0, 0, 3, 0, 1, 19, 17, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 19, 128, 0, 0, 0, 3, 0, 1, 19, 130, 0, 0, 0, 3, 1, 1, 19, 130, 0, 0, 0, 1, 2, 1, 0, 128, 0, 0, 0, 1, 1, 1, 19, 128, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 2, 1, 13, 0, 0, 0, 0, 1, 2, 1, 13, 0, 0, 0, 0, 1, 1, 2, 3, 256, 0, 0, 0, 1, 3, 1, 3, 16640, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 2, 1, 18, 0, 0, 0, 0, 3, 1, 1, 0, 1, 0, 0, 0, 3, 2, 1, 18, 1, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 1, 1, 19, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 3, 0, 1, 19, 2, 0, 0, 0, 3, 1, 1, 19, 2, 0, 0, 0, 1, 2, 1, 15, 608, 0, 0, 0, 3, 1, 2, 18, 80216130, 0, 0, 0, 3, 0, 0, 0, 15, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 4, 0, 1, 16, 12, 0, 0, 0, 2, 0, 0, 0, 262157, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 18, 67698784, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 1, 1, 2, 19, 524288, 0, 0, 0, 1, 1, 1, 15, 16384, 0, 0, 0, 3, 0, -1, 0, 15, 0, 0, 0, 5, -1, 0, 0, 3, 0, 0, 0, 3, 1, 1, 0, 16385, 0, 0, 0, 2, 1, 1, 0, 18, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 3, 1, 0, 3, 7, 0, 0, 0, 1, 0, 1, 19, 0, 0, 0, 0, 1, 3, 0, 3, 256, 0, 0, 0, 5, -1, 1, 3, 3, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 1, 0, 0, 0, 262144, 0, 0, 0, 3, 0, 2, 19, 101187618, 0, 0, 0, 3, 0, 2, 19, 524327, 0, 0, 0, 3, 0, 2, 19, 524326, 0, 0, 0, 3, 0, 1, 0, 33554722, 0, 0, 0, 2, 0, 1, 16, 18, 0, 0, 0, 5, 0, 1, 16, 14, 0, 0, 0, 3, 1, 1, 18, 67108930, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 131087, 0, 0, 0, 5, 0, 0, 0, 4325392, 0, 0, 0, 3, 0, 1, 19, 15, 0, 0, 0, 3, 0, 0, 0, 3, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 3, 2, 1, 3, 16706, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 16777219, 0, 0, 0, 1, 1, 1, 0, 0, 0, 0, 0 ], [ "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0, "i8", "i8", "i8", "i8", "i32", 0, 0, 0 ], ALLOC_STATIC);

_js_NumCodeSpecs = allocate([ 232 ], [ "i32", 0, 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str192692 = allocate([ 45, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202693 = allocate([ 43, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252698 = allocate([ 60, 110, 101, 120, 116, 62, 0 ], "i8", ALLOC_STATIC);

__ZL9CodeToken = allocate(928, "*", ALLOC_STATIC);

STRING_TABLE._js_EscapeMap = allocate([ 8, 98, 12, 102, 10, 110, 13, 114, 9, 116, 11, 118, 34, 34, 39, 39, 92, 92, 0, 48 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262699 = allocate([ 37, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15native_code_str = allocate([ 9, 91, 110, 97, 116, 105, 118, 101, 32, 99, 111, 100, 101, 93, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282701 = allocate([ 9, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292702 = allocate([ 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str302703 = allocate([ 37, 115, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str312704 = allocate([ 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str322705 = allocate([ 9, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str332706 = allocate([ 44, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str342707 = allocate([ 41, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str352708 = allocate([ 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str362709 = allocate([ 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str382711 = allocate([ 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str392712 = allocate([ 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16exception_cookie = allocate([ 47, 42, 69, 88, 67, 69, 80, 84, 73, 79, 78, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16retsub_pc_cookie = allocate([ 47, 42, 82, 69, 84, 83, 85, 66, 95, 80, 67, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14forelem_cookie = allocate([ 47, 42, 70, 79, 82, 69, 76, 69, 77, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE11with_cookie = allocate([ 47, 42, 87, 73, 84, 72, 42, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE13predot_format = allocate([ 37, 115, 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE14postdot_format = allocate([ 37, 115, 46, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE15preindex_format = allocate([ 37, 115, 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE16postindex_format = allocate([ 37, 115, 91, 37, 115, 93, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE9ss_format = allocate([ 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL9DecompileP11SprintStackPhi4JSOpE10sss_format = allocate([ 37, 115, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str402713 = allocate([ 37, 115, 32, 37, 115, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str412714 = allocate([ 9, 100, 111, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str422715 = allocate([ 9, 125, 32, 119, 104, 105, 108, 101, 32, 40, 37, 115, 41, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str432716 = allocate([ 9, 102, 111, 114, 32, 40, 37, 115, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str442717 = allocate([ 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str452718 = allocate([ 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str462719 = allocate([ 9, 125, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str472720 = allocate([ 9, 37, 115, 58, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str482721 = allocate([ 9, 37, 115, 58, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str492722 = allocate([ 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str512724 = allocate([ 10, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str522725 = allocate([ 9, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str532726 = allocate([ 9, 116, 114, 121, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str542727 = allocate([ 9, 125, 32, 102, 105, 110, 97, 108, 108, 121, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str552728 = allocate([ 37, 115, 91, 93, 32, 61, 32, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str562729 = allocate([ 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str572730 = allocate([ 9, 108, 101, 116, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str582731 = allocate([ 9, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str592732 = allocate([ 37, 115, 44, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str602733 = allocate([ 108, 101, 116, 32, 40, 37, 115, 41, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str612734 = allocate([ 108, 101, 116, 32, 40, 37, 115, 41, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str622735 = allocate([ 9, 40, 37, 115, 41, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str632736 = allocate([ 9, 119, 105, 116, 104, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str642737 = allocate([ 9, 125, 32, 99, 97, 116, 99, 104, 32, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str652738 = allocate([ 32, 105, 102, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str662739 = allocate([ 40, 37, 115, 41, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str672740 = allocate([ 9, 37, 115, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str682741 = allocate([ 37, 115, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str692742 = allocate([ 37, 115, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str702743 = allocate([ 32, 37, 115, 32, 40, 37, 115, 32, 105, 110, 32, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_for_each_str = allocate([ 102, 111, 114, 32, 101, 97, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str712744 = allocate([ 9, 37, 115, 32, 40, 37, 115, 37, 115, 32, 105, 110, 32, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str722745 = allocate([ 9, 119, 104, 105, 108, 101, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str732746 = allocate([ 9, 99, 111, 110, 116, 105, 110, 117, 101, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str742747 = allocate([ 9, 99, 111, 110, 116, 105, 110, 117, 101, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str752748 = allocate([ 9, 98, 114, 101, 97, 107, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str762749 = allocate([ 9, 98, 114, 101, 97, 107, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str772750 = allocate([ 32, 105, 102, 32, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str782751 = allocate([ 32, 105, 102, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str792752 = allocate([ 9, 105, 102, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str802753 = allocate([ 9, 125, 32, 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str812754 = allocate([ 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str822755 = allocate([ 37, 115, 32, 63, 32, 37, 115, 32, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str842757 = allocate([ 37, 115, 32, 37, 115, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str852758 = allocate([ 37, 42, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str872760 = allocate([ 37, 115, 37, 115, 32, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str882761 = allocate([ 37, 115, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str892762 = allocate([ 37, 115, 32, 37, 115, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str902763 = allocate([ 37, 115, 32, 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str912764 = allocate([ 37, 115, 32, 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str922765 = allocate([ 37, 115, 32, 37, 115, 46, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL13js_incop_strs = allocate([ 43, 43, 0, 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str932766 = allocate([ 37, 115, 91, 37, 115, 93, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str942767 = allocate([ 37, 115, 46, 37, 115, 32, 37, 115, 61, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str952768 = allocate([ 37, 115, 91, 37, 100, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str982771 = allocate([ 9, 99, 97, 115, 101, 32, 37, 115, 58, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str992772 = allocate([ 35, 37, 117, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1002773 = allocate([ 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1012774 = allocate([ 123, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1022775 = allocate([ 37, 115, 37, 115, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1032776 = allocate([ 37, 115, 37, 115, 37, 115, 32, 37, 115, 37, 115, 37, 46, 42, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1052778 = allocate([ 37, 115, 37, 115, 37, 115, 58, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1062779 = allocate([ 35, 37, 117, 61, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1072780 = allocate([ 35, 37, 117, 35, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1082781 = allocate([ 9, 100, 101, 98, 117, 103, 103, 101, 114, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1092782 = allocate([ 9, 37, 115, 32, 37, 115, 32, 37, 115, 32, 61, 32, 37, 115, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1102783 = allocate([ 64, 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1112784 = allocate([ 64, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1122785 = allocate([ 37, 115, 58, 58, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1132786 = allocate([ 37, 115, 58, 58, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1142787 = allocate([ 64, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1152788 = allocate([ 37, 115, 61, 34, 37, 115, 34, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1162789 = allocate([ 37, 115, 61, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1172790 = allocate([ 123, 37, 115, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1182791 = allocate([ 60, 62, 37, 115, 60, 47, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1192792 = allocate([ 37, 115, 46, 40, 37, 115, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1202793 = allocate([ 37, 115, 46, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1212794 = allocate([ 60, 33, 91, 67, 68, 65, 84, 65, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1222795 = allocate([ 93, 93, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1232796 = allocate([ 60, 33, 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1242797 = allocate([ 45, 45, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1252798 = allocate([ 60, 63, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1262799 = allocate([ 63, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1272800 = allocate([ 9, 115, 119, 105, 116, 99, 104, 32, 40, 37, 115, 41, 32, 123, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1282801 = allocate([ 9, 37, 115, 58, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1292802 = allocate([ 45, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1302803 = allocate([ 48, 32, 47, 32, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1312804 = allocate([ 49, 32, 47, 32, 45, 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1322805 = allocate([ 49, 32, 47, 32, 48, 0 ], "i8", ALLOC_STATIC);

__ZL10var_prefix = allocate(12, "*", ALLOC_STATIC);

STRING_TABLE.__str1332806 = allocate([ 118, 97, 114, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1342807 = allocate([ 99, 111, 110, 115, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1352808 = allocate([ 108, 101, 116, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1362809 = allocate([ 37, 115, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1372810 = allocate([ 93, 32, 61, 32, 91, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1382811 = allocate([ 44, 32, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1392812 = allocate([ 37, 115, 46, 37, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1402813 = allocate([ 37, 115, 91, 37, 115, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1412814 = allocate([ 37, 103, 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1422815 = allocate([ 58, 32, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1432816 = allocate([ 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1442817 = allocate([ 9, 47, 42, 32, 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 32, 42, 47, 32, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1452818 = allocate([ 9, 34, 117, 115, 101, 32, 115, 116, 114, 105, 99, 116, 34, 59, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1462819 = allocate([ 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1472820 = allocate([ 92, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1482821 = allocate([ 92, 120, 37, 48, 50, 88, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1492822 = allocate([ 92, 117, 37, 48, 52, 88, 0 ], "i8", ALLOC_STATIC);

_table = allocate(24, "*", ALLOC_STATIC);

STRING_TABLE.__str22883 = allocate([ 110, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str52886 = allocate([ 111, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL14incop_name_str = allocate([ 105, 110, 99, 114, 101, 109, 101, 110, 116, 0, 100, 101, 99, 114, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL15js_variable_str = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str12967 = allocate([ 115, 116, 111, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str22968 = allocate([ 114, 101, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str32969 = allocate([ 99, 97, 110, 77, 101, 97, 115, 117, 114, 101, 83, 111, 109, 101, 116, 104, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL6pm_fns = allocate([ 0, 0, 0, 0, 994, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 996, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 998, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 1e3, 0, 0, 0, 0, 0, 4166, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str42970 = allocate([ 80, 101, 114, 102, 77, 101, 97, 115, 117, 114, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL8pm_class = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1002, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL8pm_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 1004, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1006, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1008, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1010, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1012, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1014, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1016, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1018, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1020, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1022, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1024, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1026, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZL9pm_consts = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 256, 0, 0, 0, 0, 0, 0, 0, 512, 0, 0, 0, 0, 0, 0, 0, 1024, 0, 0, 0, 0, 0, 0, 0, 2047, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str52971 = allocate([ 67, 80, 85, 95, 67, 89, 67, 76, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str62972 = allocate([ 73, 78, 83, 84, 82, 85, 67, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str72973 = allocate([ 67, 65, 67, 72, 69, 95, 82, 69, 70, 69, 82, 69, 78, 67, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str82974 = allocate([ 67, 65, 67, 72, 69, 95, 77, 73, 83, 83, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str92975 = allocate([ 66, 82, 65, 78, 67, 72, 95, 73, 78, 83, 84, 82, 85, 67, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str102976 = allocate([ 66, 82, 65, 78, 67, 72, 95, 77, 73, 83, 83, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str112977 = allocate([ 66, 85, 83, 95, 67, 89, 67, 76, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str122978 = allocate([ 80, 65, 71, 69, 95, 70, 65, 85, 76, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str132979 = allocate([ 77, 65, 74, 79, 82, 95, 80, 65, 71, 69, 95, 70, 65, 85, 76, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str142980 = allocate([ 67, 79, 78, 84, 69, 88, 84, 95, 83, 87, 73, 84, 67, 72, 69, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str152981 = allocate([ 67, 80, 85, 95, 77, 73, 71, 82, 65, 84, 73, 79, 78, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str162982 = allocate([ 65, 76, 76, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str172983 = allocate([ 78, 85, 77, 95, 77, 69, 65, 83, 85, 82, 65, 66, 76, 69, 95, 69, 86, 69, 78, 84, 83, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str182984 = allocate([ 99, 112, 117, 95, 99, 121, 99, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str192985 = allocate([ 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str202986 = allocate([ 99, 97, 99, 104, 101, 95, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str212987 = allocate([ 99, 97, 99, 104, 101, 95, 109, 105, 115, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str222988 = allocate([ 98, 114, 97, 110, 99, 104, 95, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str232989 = allocate([ 98, 114, 97, 110, 99, 104, 95, 109, 105, 115, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str242990 = allocate([ 98, 117, 115, 95, 99, 121, 99, 108, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str252991 = allocate([ 112, 97, 103, 101, 95, 102, 97, 117, 108, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str262992 = allocate([ 109, 97, 106, 111, 114, 95, 112, 97, 103, 101, 95, 102, 97, 117, 108, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str272993 = allocate([ 99, 111, 110, 116, 101, 120, 116, 95, 115, 119, 105, 116, 99, 104, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str282994 = allocate([ 99, 112, 117, 95, 109, 105, 103, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str292995 = allocate([ 101, 118, 101, 110, 116, 115, 77, 101, 97, 115, 117, 114, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str302996 = allocate([ 117, 0 ], "i8", ALLOC_STATIC);

__str23014 = allocate(2, "i8", ALLOC_STATIC);

STRING_TABLE.__ZN2js6Probes8nullNameE = allocate([ 40, 110, 117, 108, 108, 41, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZN2js6Probes13anonymousNameE = allocate([ 40, 97, 110, 111, 110, 121, 109, 111, 117, 115, 41, 0 ], "i8", ALLOC_STATIC);

__ZN2js6Probes15ProfilingActiveE = allocate([ 1 ], [ "i8", 0, 0, 0, 0 ], ALLOC_STATIC);

__ZTVN2js14JSProxyHandlerE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1028, 0, 0, 0, 1030, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 444, 0, 0, 0, 1032, 0, 0, 0, 1034, 0, 0, 0, 1036, 0, 0, 0, 1038, 0, 0, 0, 1040, 0, 0, 0, 1042, 0, 0, 0, 1044, 0, 0, 0, 1046, 0, 0, 0, 1048, 0, 0, 0, 1050, 0, 0, 0, 1052, 0, 0, 0, 1054, 0, 0, 0, 1056, 0, 0, 0, 1058, 0, 0, 0, 1060, 0, 0, 0, 1062, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str3048 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 70, 117, 110, 99, 116, 105, 111, 110, 93, 0 ], "i8", ALLOC_STATIC);

__ZL27sScriptedProxyHandlerFamily = allocate(1, "i32", ALLOC_STATIC);

__ZTV22JSScriptedProxyHandler = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1028, 0, 0, 0, 1064, 0, 0, 0, 1066, 0, 0, 0, 1068, 0, 0, 0, 1070, 0, 0, 0, 1072, 0, 0, 0, 1074, 0, 0, 0, 1076, 0, 0, 0, 1078, 0, 0, 0, 1080, 0, 0, 0, 1082, 0, 0, 0, 1084, 0, 0, 0, 1086, 0, 0, 0, 1088, 0, 0, 0, 1090, 0, 0, 0, 1044, 0, 0, 0, 1046, 0, 0, 0, 1048, 0, 0, 0, 1050, 0, 0, 0, 1052, 0, 0, 0, 1054, 0, 0, 0, 1056, 0, 0, 0, 1058, 0, 0, 0, 1060, 0, 0, 0, 1062, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZN22JSScriptedProxyHandler9singletonE = allocate(8, "*", ALLOC_STATIC);

__ZN2js16ObjectProxyClassE = allocate([ 0, 0, 0, 0, 525056, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 1092, 0, 0, 0, 1094, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1096, 0, 0, 0, 1098, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1100, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 1116, 0, 0, 0, 1118, 0, 0, 0, 1120, 0, 0, 0, 1120, 0, 0, 0, 1122, 0, 0, 0, 1124, 0, 0, 0, 1126, 0, 0, 0, 1126, 0, 0, 0, 1128, 0, 0, 0, 1130, 0, 0, 0, 1132, 0, 0, 0, 1132, 0, 0, 0, 1134, 0, 0, 0, 1136, 0, 0, 0, 1138, 0, 0, 0, 1138, 0, 0, 0, 1140, 0, 0, 0, 1142, 0, 0, 0, 0, 0, 0, 0, 1144, 0, 0, 0, 1146, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js21OuterWindowProxyClassE = allocate([ 0, 0, 0, 0, 525056, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1094, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1098, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1148, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1100, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 1116, 0, 0, 0, 1118, 0, 0, 0, 1120, 0, 0, 0, 1120, 0, 0, 0, 1122, 0, 0, 0, 1124, 0, 0, 0, 1126, 0, 0, 0, 1126, 0, 0, 0, 1128, 0, 0, 0, 1130, 0, 0, 0, 1132, 0, 0, 0, 1132, 0, 0, 0, 1134, 0, 0, 0, 1136, 0, 0, 0, 1138, 0, 0, 0, 1138, 0, 0, 0, 1140, 0, 0, 0, 1142, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js18FunctionProxyClassE = allocate([ 0, 0, 0, 0, 525568, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1150, 0, 0, 0, 1152, 0, 0, 0, 0, 0, 0, 0, 730, 0, 0, 0, 1154, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1100, 0, 0, 0, 1100, 0, 0, 0, 1102, 0, 0, 0, 1104, 0, 0, 0, 1106, 0, 0, 0, 1106, 0, 0, 0, 1108, 0, 0, 0, 1110, 0, 0, 0, 1112, 0, 0, 0, 1114, 0, 0, 0, 1116, 0, 0, 0, 1118, 0, 0, 0, 1120, 0, 0, 0, 1120, 0, 0, 0, 1122, 0, 0, 0, 1124, 0, 0, 0, 1126, 0, 0, 0, 1126, 0, 0, 0, 1128, 0, 0, 0, 1130, 0, 0, 0, 1132, 0, 0, 0, 1132, 0, 0, 0, 1134, 0, 0, 0, 1136, 0, 0, 0, 1138, 0, 0, 0, 1138, 0, 0, 0, 1140, 0, 0, 0, 1142, 0, 0, 0, 0, 0, 0, 0, 1144, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str53058 = allocate([ 99, 114, 101, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63059 = allocate([ 99, 114, 101, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZL14static_methods = allocate([ 0, 0, 0, 0, 1156, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1158, 0, 0, 0, 3, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js19CallableObjectClassE = allocate([ 0, 0, 0, 0, 512, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1160, 0, 0, 0, 1162, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js10ProxyClassE = allocate([ 0, 0, 0, 0, 570425344, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__str93064 = allocate(1, "i8", ALLOC_STATIC);

STRING_TABLE.__str3152 = allocate([ 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13153 = allocate([ 43, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23154 = allocate([ 45, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33155 = allocate([ 42, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43156 = allocate([ 47, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53157 = allocate([ 37, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63158 = allocate([ 60, 60, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73159 = allocate([ 62, 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83160 = allocate([ 62, 62, 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93161 = allocate([ 124, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103162 = allocate([ 94, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113163 = allocate([ 38, 61, 0 ], "i8", ALLOC_STATIC);

__ZN2js8aopNamesE = allocate(48, "*", ALLOC_STATIC);

STRING_TABLE.__str123164 = allocate([ 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133165 = allocate([ 33, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143166 = allocate([ 61, 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153167 = allocate([ 33, 61, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173169 = allocate([ 60, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193171 = allocate([ 62, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203172 = allocate([ 60, 60, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213173 = allocate([ 62, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223174 = allocate([ 62, 62, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233175 = allocate([ 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243176 = allocate([ 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263178 = allocate([ 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273179 = allocate([ 37, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283180 = allocate([ 124, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293181 = allocate([ 94, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str303182 = allocate([ 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str333185 = allocate([ 46, 46, 0 ], "i8", ALLOC_STATIC);

__ZN2js10binopNamesE = allocate(88, "*", ALLOC_STATIC);

STRING_TABLE.__str353187 = allocate([ 33, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str363188 = allocate([ 126, 0 ], "i8", ALLOC_STATIC);

__ZN2js9unopNamesE = allocate(28, "*", ALLOC_STATIC);

STRING_TABLE.__str393191 = allocate([ 80, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str403192 = allocate([ 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str413193 = allocate([ 76, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str423194 = allocate([ 80, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str433195 = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str443196 = allocate([ 86, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str453197 = allocate([ 86, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str463198 = allocate([ 83, 101, 113, 117, 101, 110, 99, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str473199 = allocate([ 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str483200 = allocate([ 85, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str493201 = allocate([ 66, 105, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str503202 = allocate([ 65, 115, 115, 105, 103, 110, 109, 101, 110, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str513203 = allocate([ 76, 111, 103, 105, 99, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str523204 = allocate([ 85, 112, 100, 97, 116, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str533205 = allocate([ 78, 101, 119, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str543206 = allocate([ 67, 97, 108, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str553207 = allocate([ 77, 101, 109, 98, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str563208 = allocate([ 70, 117, 110, 99, 116, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str573209 = allocate([ 65, 114, 114, 97, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str583210 = allocate([ 79, 98, 106, 101, 99, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str593211 = allocate([ 84, 104, 105, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str603212 = allocate([ 71, 114, 97, 112, 104, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str613213 = allocate([ 71, 114, 97, 112, 104, 73, 110, 100, 101, 120, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str623214 = allocate([ 67, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str633215 = allocate([ 71, 101, 110, 101, 114, 97, 116, 111, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str643216 = allocate([ 89, 105, 101, 108, 100, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str653217 = allocate([ 76, 101, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str663218 = allocate([ 69, 109, 112, 116, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str673219 = allocate([ 66, 108, 111, 99, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str683220 = allocate([ 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str693221 = allocate([ 76, 97, 98, 101, 108, 101, 100, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str703222 = allocate([ 73, 102, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str713223 = allocate([ 83, 119, 105, 116, 99, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str723224 = allocate([ 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str733225 = allocate([ 68, 111, 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str743226 = allocate([ 70, 111, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str753227 = allocate([ 70, 111, 114, 73, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str763228 = allocate([ 66, 114, 101, 97, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str773229 = allocate([ 67, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str783230 = allocate([ 87, 105, 116, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str793231 = allocate([ 82, 101, 116, 117, 114, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str803232 = allocate([ 84, 114, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str813233 = allocate([ 84, 104, 114, 111, 119, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str823234 = allocate([ 68, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str833235 = allocate([ 76, 101, 116, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str843236 = allocate([ 83, 119, 105, 116, 99, 104, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str853237 = allocate([ 67, 97, 116, 99, 104, 67, 108, 97, 117, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str863238 = allocate([ 67, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str873239 = allocate([ 65, 114, 114, 97, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str883240 = allocate([ 79, 98, 106, 101, 99, 116, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str893241 = allocate([ 88, 77, 76, 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str903242 = allocate([ 88, 77, 76, 65, 116, 116, 114, 105, 98, 117, 116, 101, 83, 101, 108, 101, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str913243 = allocate([ 88, 77, 76, 69, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str923244 = allocate([ 88, 77, 76, 70, 105, 108, 116, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str933245 = allocate([ 88, 77, 76, 68, 101, 102, 97, 117, 108, 116, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str943246 = allocate([ 88, 77, 76, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str953247 = allocate([ 88, 77, 76, 70, 117, 110, 99, 116, 105, 111, 110, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str963248 = allocate([ 88, 77, 76, 69, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str973249 = allocate([ 88, 77, 76, 84, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str993251 = allocate([ 88, 77, 76, 83, 116, 97, 114, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1003252 = allocate([ 88, 77, 76, 69, 110, 100, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1013253 = allocate([ 88, 77, 76, 80, 111, 105, 110, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1023254 = allocate([ 88, 77, 76, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1033255 = allocate([ 88, 77, 76, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1043256 = allocate([ 88, 77, 76, 67, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1053257 = allocate([ 88, 77, 76, 67, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1063258 = allocate([ 88, 77, 76, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js13nodeTypeNamesE = allocate(280, "*", ALLOC_STATIC);

STRING_TABLE.__str1073259 = allocate([ 112, 114, 111, 103, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1083260 = allocate([ 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1093261 = allocate([ 108, 105, 116, 101, 114, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1103262 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1113263 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1123264 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1133265 = allocate([ 118, 97, 114, 105, 97, 98, 108, 101, 68, 101, 99, 108, 97, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1143266 = allocate([ 115, 101, 113, 117, 101, 110, 99, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1153267 = allocate([ 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1163268 = allocate([ 117, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1173269 = allocate([ 98, 105, 110, 97, 114, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1183270 = allocate([ 97, 115, 115, 105, 103, 110, 109, 101, 110, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1193271 = allocate([ 108, 111, 103, 105, 99, 97, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1203272 = allocate([ 117, 112, 100, 97, 116, 101, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1213273 = allocate([ 110, 101, 119, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1223274 = allocate([ 99, 97, 108, 108, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1233275 = allocate([ 109, 101, 109, 98, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1243276 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1253277 = allocate([ 97, 114, 114, 97, 121, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1263278 = allocate([ 111, 98, 106, 101, 99, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1273279 = allocate([ 116, 104, 105, 115, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1283280 = allocate([ 103, 114, 97, 112, 104, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1293281 = allocate([ 103, 114, 97, 112, 104, 73, 110, 100, 101, 120, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1303282 = allocate([ 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1313283 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1323284 = allocate([ 121, 105, 101, 108, 100, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1333285 = allocate([ 108, 101, 116, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1343286 = allocate([ 101, 109, 112, 116, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1353287 = allocate([ 98, 108, 111, 99, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1363288 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1373289 = allocate([ 108, 97, 98, 101, 108, 101, 100, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1383290 = allocate([ 105, 102, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1393291 = allocate([ 115, 119, 105, 116, 99, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1403292 = allocate([ 119, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1413293 = allocate([ 100, 111, 87, 104, 105, 108, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1423294 = allocate([ 102, 111, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1433295 = allocate([ 102, 111, 114, 73, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1443296 = allocate([ 98, 114, 101, 97, 107, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1453297 = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1463298 = allocate([ 119, 105, 116, 104, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1473299 = allocate([ 114, 101, 116, 117, 114, 110, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1483300 = allocate([ 116, 114, 121, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1493301 = allocate([ 116, 104, 114, 111, 119, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1503302 = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1513303 = allocate([ 108, 101, 116, 83, 116, 97, 116, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1523304 = allocate([ 115, 119, 105, 116, 99, 104, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1533305 = allocate([ 99, 97, 116, 99, 104, 67, 108, 97, 117, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1543306 = allocate([ 99, 111, 109, 112, 114, 101, 104, 101, 110, 115, 105, 111, 110, 66, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1553307 = allocate([ 97, 114, 114, 97, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1563308 = allocate([ 111, 98, 106, 101, 99, 116, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1573309 = allocate([ 112, 114, 111, 112, 101, 114, 116, 121, 80, 97, 116, 116, 101, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1583310 = allocate([ 120, 109, 108, 65, 110, 121, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1593311 = allocate([ 120, 109, 108, 65, 116, 116, 114, 105, 98, 117, 116, 101, 83, 101, 108, 101, 99, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1603312 = allocate([ 120, 109, 108, 69, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1613313 = allocate([ 120, 109, 108, 70, 105, 108, 116, 101, 114, 69, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1623314 = allocate([ 120, 109, 108, 68, 101, 102, 97, 117, 108, 116, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1633315 = allocate([ 120, 109, 108, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1643316 = allocate([ 120, 109, 108, 70, 117, 110, 99, 116, 105, 111, 110, 81, 117, 97, 108, 105, 102, 105, 101, 100, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1653317 = allocate([ 120, 109, 108, 69, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1663318 = allocate([ 120, 109, 108, 84, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1673319 = allocate([ 120, 109, 108, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1683320 = allocate([ 120, 109, 108, 83, 116, 97, 114, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1693321 = allocate([ 120, 109, 108, 69, 110, 100, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1703322 = allocate([ 120, 109, 108, 80, 111, 105, 110, 116, 84, 97, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1713323 = allocate([ 120, 109, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1723324 = allocate([ 120, 109, 108, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1733325 = allocate([ 120, 109, 108, 67, 100, 97, 116, 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1743326 = allocate([ 120, 109, 108, 67, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1753327 = allocate([ 120, 109, 108, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

__ZN2js13callbackNamesE = allocate(280, "*", ALLOC_STATIC);

STRING_TABLE.__str1763328 = allocate([ 116, 121, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1773329 = allocate([ 115, 116, 97, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1783330 = allocate([ 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1793331 = allocate([ 99, 111, 108, 117, 109, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1803332 = allocate([ 101, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1823334 = allocate([ 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1833335 = allocate([ 98, 111, 100, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1843336 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1863338 = allocate([ 99, 111, 110, 115, 101, 113, 117, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1873339 = allocate([ 97, 108, 116, 101, 114, 110, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1883340 = allocate([ 108, 97, 98, 101, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1893341 = allocate([ 97, 114, 103, 117, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1903342 = allocate([ 105, 110, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1913343 = allocate([ 117, 112, 100, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1923344 = allocate([ 108, 101, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1933345 = allocate([ 114, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1963348 = allocate([ 100, 105, 115, 99, 114, 105, 109, 105, 110, 97, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1973349 = allocate([ 99, 97, 115, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1983350 = allocate([ 108, 101, 120, 105, 99, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1993351 = allocate([ 98, 108, 111, 99, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2003352 = allocate([ 104, 97, 110, 100, 108, 101, 114, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2013353 = allocate([ 102, 105, 110, 97, 108, 105, 122, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2023354 = allocate([ 111, 112, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2033355 = allocate([ 112, 114, 101, 102, 105, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2043356 = allocate([ 43, 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2053357 = allocate([ 45, 45, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2063358 = allocate([ 124, 124, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2073359 = allocate([ 38, 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2083360 = allocate([ 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2113363 = allocate([ 99, 111, 109, 112, 117, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2133365 = allocate([ 107, 101, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2153367 = allocate([ 107, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2183370 = allocate([ 112, 114, 111, 112, 101, 114, 116, 105, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2193371 = allocate([ 98, 108, 111, 99, 107, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2203372 = allocate([ 102, 105, 108, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2223374 = allocate([ 104, 101, 97, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2263378 = allocate([ 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2273379 = allocate([ 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2283380 = allocate([ 112, 97, 114, 97, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2293381 = allocate([ 103, 117, 97, 114, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2313383 = allocate([ 112, 97, 114, 97, 109, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2323384 = allocate([ 103, 101, 110, 101, 114, 97, 116, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2343386 = allocate([ 97, 116, 116, 114, 105, 98, 117, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2353387 = allocate([ 99, 111, 110, 116, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2363388 = allocate([ 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2373389 = allocate([ 116, 97, 114, 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2383390 = allocate([ 112, 97, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

__ZL14static_methods3391 = allocate([ 0, 0, 0, 0, 1164, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str2393392 = allocate([ 82, 101, 102, 108, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2403393 = allocate([ 82, 101, 102, 108, 101, 99, 116, 46, 112, 97, 114, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2433396 = allocate([ 110, 111, 116, 32, 97, 110, 32, 111, 98, 106, 101, 99, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3439 = allocate([ 82, 101, 103, 69, 120, 112, 83, 116, 97, 116, 105, 99, 115, 0 ], "i8", ALLOC_STATIC);

__ZN2js20regexp_statics_classE = allocate([ 0, 0, 0, 0, 1, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1166, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1168, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str33444 = allocate([ 108, 97, 115, 116, 77, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43445 = allocate([ 108, 97, 115, 116, 80, 97, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53446 = allocate([ 108, 101, 102, 116, 67, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63447 = allocate([ 114, 105, 103, 104, 116, 67, 111, 110, 116, 101, 120, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73448 = allocate([ 36, 49, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83449 = allocate([ 36, 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93450 = allocate([ 36, 51, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103451 = allocate([ 36, 52, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113452 = allocate([ 36, 53, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123453 = allocate([ 36, 54, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133454 = allocate([ 36, 55, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143455 = allocate([ 36, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153456 = allocate([ 36, 57, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str163457 = allocate([ 36, 95, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173458 = allocate([ 36, 42, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183459 = allocate([ 36, 38, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193460 = allocate([ 36, 43, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203461 = allocate([ 36, 96, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213462 = allocate([ 36, 39, 0 ], "i8", ALLOC_STATIC);

__ZL19regexp_static_props = allocate([ 0, 0, 0, 0, 0, 69, 0, 0, 1170, 0, 0, 0, 1172, 0, 0, 0, 0, 0, 0, 0, 0, 69, 0, 0, 1174, 0, 0, 0, 1176, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1180, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1182, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1186, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1188, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1190, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1194, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1196, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1198, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1200, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1202, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 1170, 0, 0, 0, 1172, 0, 0, 0, 0, 0, 0, 0, 0, 68, 0, 0, 1174, 0, 0, 0, 1176, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1178, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1180, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1182, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 1184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11RegExpClassE = allocate([ 0, 0, 0, 0, 167773697, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1204, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1206, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str223465 = allocate([ 47, 40, 63, 58, 41, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233466 = allocate([ 99, 111, 109, 112, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243467 = allocate([ 101, 120, 101, 99, 0 ], "i8", ALLOC_STATIC);

__ZL14regexp_methods = allocate([ 0, 0, 0, 0, 1208, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1208, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1210, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1212, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1214, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE._js_false_str = allocate([ 102, 97, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_true_str = allocate([ 116, 114, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_null_str = allocate([ 110, 117, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_break_str = allocate([ 98, 114, 101, 97, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_case_str = allocate([ 99, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_catch_str = allocate([ 99, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_continue_str = allocate([ 99, 111, 110, 116, 105, 110, 117, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_debugger_str = allocate([ 100, 101, 98, 117, 103, 103, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_default_str = allocate([ 100, 101, 102, 97, 117, 108, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_delete_str = allocate([ 100, 101, 108, 101, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_do_str = allocate([ 100, 111, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_else_str = allocate([ 101, 108, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_finally_str = allocate([ 102, 105, 110, 97, 108, 108, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_for_str = allocate([ 102, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_function_str = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_if_str = allocate([ 105, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_in_str = allocate([ 105, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_instanceof_str = allocate([ 105, 110, 115, 116, 97, 110, 99, 101, 111, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_new_str = allocate([ 110, 101, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_return_str = allocate([ 114, 101, 116, 117, 114, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_switch_str = allocate([ 115, 119, 105, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_this_str = allocate([ 116, 104, 105, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_throw_str = allocate([ 116, 104, 114, 111, 119, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_try_str = allocate([ 116, 114, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_typeof_str = allocate([ 116, 121, 112, 101, 111, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_var_str = allocate([ 118, 97, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_void_str = allocate([ 118, 111, 105, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_while_str = allocate([ 119, 104, 105, 108, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_with_str = allocate([ 119, 105, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_class_str = allocate([ 99, 108, 97, 115, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_enum_str = allocate([ 101, 110, 117, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_export_str = allocate([ 101, 120, 112, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_extends_str = allocate([ 101, 120, 116, 101, 110, 100, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_import_str = allocate([ 105, 109, 112, 111, 114, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_super_str = allocate([ 115, 117, 112, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_const_str = allocate([ 99, 111, 110, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_let_str = allocate([ 108, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_yield_str = allocate([ 121, 105, 101, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_implements_str = allocate([ 105, 109, 112, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_interface_str = allocate([ 105, 110, 116, 101, 114, 102, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_package_str = allocate([ 112, 97, 99, 107, 97, 103, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_private_str = allocate([ 112, 114, 105, 118, 97, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_protected_str = allocate([ 112, 114, 111, 116, 101, 99, 116, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_public_str = allocate([ 112, 117, 98, 108, 105, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_static_str = allocate([ 115, 116, 97, 116, 105, 99, 0 ], "i8", ALLOC_STATIC);

__ZL8keywords = allocate([ 0, 0, 0, 0, 33, 0, 0, 0, 66, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 67, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 64, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 54, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 50, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 55, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 113, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 57, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 49, 0, 0, 0, 82, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 65, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 53, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 129, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 86, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 81, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 77, 0, 0, 0, 0, 0, 0, 0, 170, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str3585 = allocate([ 64, 108, 105, 110, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13586 = allocate([ 64, 115, 111, 117, 114, 99, 101, 77, 97, 112, 112, 105, 110, 103, 85, 82, 76, 61, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL14firstCharKinds = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 11, 10, 10, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 5, 0, 2, 0, 0, 5, 1, 1, 0, 8, 1, 0, 3, 0, 9, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 1, 0, 4, 0, 1, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 0, 1, 0, 2, 0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 0, 1, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23587 = allocate([ 85, 110, 105, 99, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33588 = allocate([ 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43589 = allocate([ 48, 56, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53590 = allocate([ 48, 57, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63591 = allocate([ 35, 37, 117, 37, 99, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str3667 = allocate([ 35, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23669 = allocate([ 83, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ScriptClassE = allocate([ 0, 0, 0, 0, 16777217, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1216, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str33670 = allocate([ 115, 99, 114, 105, 112, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_escape_str = allocate([ 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_unescape_str = allocate([ 117, 110, 101, 115, 99, 97, 112, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_uneval_str = allocate([ 117, 110, 101, 118, 97, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_decodeURI_str = allocate([ 100, 101, 99, 111, 100, 101, 85, 82, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_encodeURI_str = allocate([ 101, 110, 99, 111, 100, 101, 85, 82, 73, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_decodeURIComponent_str = allocate([ 100, 101, 99, 111, 100, 101, 85, 82, 73, 67, 111, 109, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_encodeURIComponent_str = allocate([ 101, 110, 99, 111, 100, 101, 85, 82, 73, 67, 111, 109, 112, 111, 110, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16string_functions = allocate([ 0, 0, 0, 0, 1218, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1220, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1222, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1224, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1226, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1228, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1230, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

_js_empty_ucstr = allocate(2, "i16", ALLOC_STATIC);

_js_EmptySubString = allocate(8, [ "i32", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js11StringClassE = allocate([ 0, 0, 0, 0, 150995460, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 1232, 0, 0, 0, 1234, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str3763 = allocate([ 113, 117, 111, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str13764 = allocate([ 115, 117, 98, 115, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str23765 = allocate([ 116, 111, 76, 111, 119, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str33766 = allocate([ 116, 111, 85, 112, 112, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43767 = allocate([ 99, 104, 97, 114, 65, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str53768 = allocate([ 99, 104, 97, 114, 67, 111, 100, 101, 65, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str63769 = allocate([ 105, 110, 100, 101, 120, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str73770 = allocate([ 108, 97, 115, 116, 73, 110, 100, 101, 120, 79, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str83771 = allocate([ 116, 114, 105, 109, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str93772 = allocate([ 116, 114, 105, 109, 76, 101, 102, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str103773 = allocate([ 116, 114, 105, 109, 82, 105, 103, 104, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str113774 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 76, 111, 119, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str123775 = allocate([ 116, 111, 76, 111, 99, 97, 108, 101, 85, 112, 112, 101, 114, 67, 97, 115, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str133776 = allocate([ 108, 111, 99, 97, 108, 101, 67, 111, 109, 112, 97, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str143777 = allocate([ 109, 97, 116, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str153778 = allocate([ 115, 101, 97, 114, 99, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173780 = allocate([ 115, 112, 108, 105, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183781 = allocate([ 115, 117, 98, 115, 116, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str193782 = allocate([ 99, 111, 110, 99, 97, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str203783 = allocate([ 115, 108, 105, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str213784 = allocate([ 98, 111, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str223785 = allocate([ 105, 116, 97, 108, 105, 99, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str233786 = allocate([ 102, 105, 120, 101, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str243787 = allocate([ 102, 111, 110, 116, 115, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str253788 = allocate([ 102, 111, 110, 116, 99, 111, 108, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str263789 = allocate([ 108, 105, 110, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str273790 = allocate([ 97, 110, 99, 104, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str283791 = allocate([ 115, 116, 114, 105, 107, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str293792 = allocate([ 115, 109, 97, 108, 108, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str303793 = allocate([ 98, 105, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str313794 = allocate([ 98, 108, 105, 110, 107, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str323795 = allocate([ 115, 117, 112, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str333796 = allocate([ 115, 117, 98, 0 ], "i8", ALLOC_STATIC);

__ZL14string_methods = allocate([ 0, 0, 0, 0, 1236, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1238, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 192, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 192, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1240, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1242, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1244, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1246, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1248, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1250, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1252, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1254, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1256, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1258, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1260, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1262, 0, 0, 0, 0, 0, 4104, 0, 0, 0, 0, 0, 1264, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1266, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1268, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 142, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1270, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1272, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1274, 0, 0, 0, 1, 0, 4104, 0, 0, 0, 0, 0, 1276, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1278, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1280, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1282, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1284, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1286, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1288, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1290, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1292, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1294, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1296, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1298, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1300, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1302, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str343797 = allocate([ 102, 114, 111, 109, 67, 104, 97, 114, 67, 111, 100, 101, 0 ], "i8", ALLOC_STATIC);

__ZL21string_static_methods = allocate([ 0, 0, 0, 0, 1304, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZ16js_ValueToSourceP9JSContextRKN2JS5ValueEE17js_negzero_ucNstr = allocate([ 45, 0, 48, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str363799 = allocate([ 48, 120, 37, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isidstart = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isident = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isspace = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZZL17Utf8ToOneUcs4CharPKhiE12minucs4Table = allocate([ 128, 0, 0, 0, 2048, 0, 0, 0, 65536, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZL21js_uriUnescaped_ucstr = allocate([ 48, 0, 49, 0, 50, 0, 51, 0, 52, 0, 53, 0, 54, 0, 55, 0, 56, 0, 57, 0, 65, 0, 66, 0, 67, 0, 68, 0, 69, 0, 70, 0, 71, 0, 72, 0, 73, 0, 74, 0, 75, 0, 76, 0, 77, 0, 78, 0, 79, 0, 80, 0, 81, 0, 82, 0, 83, 0, 84, 0, 85, 0, 86, 0, 87, 0, 88, 0, 89, 0, 90, 0, 97, 0, 98, 0, 99, 0, 100, 0, 101, 0, 102, 0, 103, 0, 104, 0, 105, 0, 106, 0, 107, 0, 108, 0, 109, 0, 110, 0, 111, 0, 112, 0, 113, 0, 114, 0, 115, 0, 116, 0, 117, 0, 118, 0, 119, 0, 120, 0, 121, 0, 122, 0, 45, 0, 95, 0, 46, 0, 33, 0, 126, 0, 42, 0, 39, 0, 40, 0, 41, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueEE9HexDigits = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70, 0 ], "i8", ALLOC_STATIC);

__ZL29js_uriReservedPlusPound_ucstr = allocate([ 59, 0, 47, 0, 63, 0, 58, 0, 64, 0, 38, 0, 61, 0, 43, 0, 36, 0, 44, 0, 35, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str383807 = allocate([ 97, 32, 110, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str403809 = allocate([ 97, 32, 104, 114, 101, 102, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str413810 = allocate([ 102, 111, 110, 116, 32, 99, 111, 108, 111, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str423811 = allocate([ 102, 111, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str433812 = allocate([ 102, 111, 110, 116, 32, 115, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str443813 = allocate([ 116, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str453814 = allocate([ 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str463815 = allocate([ 98, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str473816 = allocate([ 40, 110, 101, 119, 32, 83, 116, 114, 105, 110, 103, 40, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE6digits = allocate([ 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL10str_escapeP9JSContextjPN2JS5ValueEE17shouldPassThrough = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ArrayBuffer9slowClassE = allocate([ 0, 0, 0, 0, 402657281, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js16ArrayBufferClassE = allocate([ 0, 0, 0, 0, 403181569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1308, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1310, 0, 0, 0, 1310, 0, 0, 0, 1312, 0, 0, 0, 1314, 0, 0, 0, 1316, 0, 0, 0, 1316, 0, 0, 0, 1318, 0, 0, 0, 1320, 0, 0, 0, 1322, 0, 0, 0, 1324, 0, 0, 0, 1326, 0, 0, 0, 1328, 0, 0, 0, 1330, 0, 0, 0, 1330, 0, 0, 0, 1332, 0, 0, 0, 1334, 0, 0, 0, 1336, 0, 0, 0, 1336, 0, 0, 0, 1338, 0, 0, 0, 1340, 0, 0, 0, 1342, 0, 0, 0, 1342, 0, 0, 0, 1344, 0, 0, 0, 1346, 0, 0, 0, 1348, 0, 0, 0, 1348, 0, 0, 0, 1350, 0, 0, 0, 1352, 0, 0, 0, 1354, 0, 0, 0, 1356, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str23955 = allocate([ 98, 121, 116, 101, 76, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZN2js11ArrayBuffer7jspropsE = allocate([ 0, 0, 0, 0, -1, 70, 0, 0, 1358, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str33956 = allocate([ 98, 121, 116, 101, 79, 102, 102, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str43957 = allocate([ 98, 117, 102, 102, 101, 114, 0 ], "i8", ALLOC_STATIC);

__ZN2js10TypedArray7jspropsE = allocate([ 0, 0, 0, 0, -1, 70, 0, 0, 1360, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1362, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1364, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, -1, 70, 0, 0, 1366, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str53958 = allocate([ 115, 117, 98, 97, 114, 114, 97, 121, 0 ], "i8", ALLOC_STATIC);

__ZN9Int8Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1368, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1370, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Uint8Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1372, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1374, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Int16Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1376, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1378, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN11Uint16Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1380, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1382, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN10Int32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1384, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1386, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN11Uint32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1388, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1390, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN12Float32Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1392, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1394, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN12Float64Array7jsfuncsE = allocate([ 0, 0, 0, 0, 1396, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1398, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN17Uint8ClampedArray7jsfuncsE = allocate([ 0, 0, 0, 0, 1400, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 1402, 0, 0, 0, 2, 0, 4104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js10TypedArray11fastClassesE = allocate([ 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1404, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1412, 0, 0, 0, 1412, 0, 0, 0, 1414, 0, 0, 0, 1416, 0, 0, 0, 1418, 0, 0, 0, 1420, 0, 0, 0, 1422, 0, 0, 0, 1424, 0, 0, 0, 1426, 0, 0, 0, 1426, 0, 0, 0, 1428, 0, 0, 0, 1430, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1444, 0, 0, 0, 1444, 0, 0, 0, 1446, 0, 0, 0, 1448, 0, 0, 0, 1450, 0, 0, 0, 1452, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1454, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1456, 0, 0, 0, 1456, 0, 0, 0, 1458, 0, 0, 0, 1460, 0, 0, 0, 1462, 0, 0, 0, 1464, 0, 0, 0, 1466, 0, 0, 0, 1468, 0, 0, 0, 1470, 0, 0, 0, 1470, 0, 0, 0, 1472, 0, 0, 0, 1474, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1476, 0, 0, 0, 1476, 0, 0, 0, 1478, 0, 0, 0, 1480, 0, 0, 0, 1482, 0, 0, 0, 1484, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1486, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1488, 0, 0, 0, 1488, 0, 0, 0, 1490, 0, 0, 0, 1492, 0, 0, 0, 1494, 0, 0, 0, 1496, 0, 0, 0, 1498, 0, 0, 0, 1500, 0, 0, 0, 1502, 0, 0, 0, 1502, 0, 0, 0, 1504, 0, 0, 0, 1506, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1508, 0, 0, 0, 1508, 0, 0, 0, 1510, 0, 0, 0, 1512, 0, 0, 0, 1514, 0, 0, 0, 1516, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1518, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1520, 0, 0, 0, 1520, 0, 0, 0, 1522, 0, 0, 0, 1524, 0, 0, 0, 1526, 0, 0, 0, 1528, 0, 0, 0, 1530, 0, 0, 0, 1532, 0, 0, 0, 1534, 0, 0, 0, 1534, 0, 0, 0, 1536, 0, 0, 0, 1538, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1540, 0, 0, 0, 1540, 0, 0, 0, 1542, 0, 0, 0, 1544, 0, 0, 0, 1546, 0, 0, 0, 1548, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1550, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1552, 0, 0, 0, 1552, 0, 0, 0, 1554, 0, 0, 0, 1556, 0, 0, 0, 1558, 0, 0, 0, 1560, 0, 0, 0, 1562, 0, 0, 0, 1564, 0, 0, 0, 1566, 0, 0, 0, 1566, 0, 0, 0, 1568, 0, 0, 0, 1570, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1572, 0, 0, 0, 1572, 0, 0, 0, 1574, 0, 0, 0, 1576, 0, 0, 0, 1578, 0, 0, 0, 1580, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1582, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1584, 0, 0, 0, 1584, 0, 0, 0, 1586, 0, 0, 0, 1588, 0, 0, 0, 1590, 0, 0, 0, 1592, 0, 0, 0, 1594, 0, 0, 0, 1596, 0, 0, 0, 1598, 0, 0, 0, 1598, 0, 0, 0, 1600, 0, 0, 0, 1602, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1604, 0, 0, 0, 1604, 0, 0, 0, 1606, 0, 0, 0, 1608, 0, 0, 0, 1610, 0, 0, 0, 1612, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1614, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1616, 0, 0, 0, 1616, 0, 0, 0, 1618, 0, 0, 0, 1620, 0, 0, 0, 1622, 0, 0, 0, 1624, 0, 0, 0, 1626, 0, 0, 0, 1628, 0, 0, 0, 1630, 0, 0, 0, 1630, 0, 0, 0, 1632, 0, 0, 0, 1634, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1636, 0, 0, 0, 1636, 0, 0, 0, 1638, 0, 0, 0, 1640, 0, 0, 0, 1642, 0, 0, 0, 1644, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1646, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1648, 0, 0, 0, 1648, 0, 0, 0, 1650, 0, 0, 0, 1652, 0, 0, 0, 1654, 0, 0, 0, 1656, 0, 0, 0, 1658, 0, 0, 0, 1660, 0, 0, 0, 1662, 0, 0, 0, 1662, 0, 0, 0, 1664, 0, 0, 0, 1666, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1668, 0, 0, 0, 1668, 0, 0, 0, 1670, 0, 0, 0, 1672, 0, 0, 0, 1674, 0, 0, 0, 1676, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 525569, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1678, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1406, 0, 0, 0, 1406, 0, 0, 0, 1408, 0, 0, 0, 1410, 0, 0, 0, 1680, 0, 0, 0, 1680, 0, 0, 0, 1682, 0, 0, 0, 1684, 0, 0, 0, 1686, 0, 0, 0, 1688, 0, 0, 0, 1690, 0, 0, 0, 1692, 0, 0, 0, 1694, 0, 0, 0, 1694, 0, 0, 0, 1696, 0, 0, 0, 1698, 0, 0, 0, 1432, 0, 0, 0, 1432, 0, 0, 0, 1434, 0, 0, 0, 1436, 0, 0, 0, 1438, 0, 0, 0, 1438, 0, 0, 0, 1440, 0, 0, 0, 1442, 0, 0, 0, 1700, 0, 0, 0, 1700, 0, 0, 0, 1702, 0, 0, 0, 1704, 0, 0, 0, 1706, 0, 0, 0, 1708, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js10TypedArray11slowClassesE = allocate([ 0, 0, 0, 0, 419431681, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 436208897, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 452986113, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 469763329, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 486540545, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 503317761, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 520094977, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 536872193, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 553649409, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8", "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str163973 = allocate([ 49, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str173974 = allocate([ 50, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str183975 = allocate([ 115, 105, 122, 101, 32, 97, 110, 100, 32, 99, 111, 117, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str4046 = allocate([ 65, 115, 115, 101, 114, 116, 105, 111, 110, 32, 102, 97, 105, 108, 117, 114, 101, 58, 32, 37, 115, 44, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0 ], "i8", ALLOC_STATIC);

__ZN2js12WeakMapClassE = allocate([ 0, 0, 0, 0, 603979777, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1710, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1712, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str14078 = allocate([ 104, 97, 115, 0 ], "i8", ALLOC_STATIC);

__ZL16weak_map_methods = allocate([ 0, 0, 0, 0, 1714, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1716, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1718, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1720, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str54082 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 115, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64083 = allocate([ 48, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str74084 = allocate([ 115, 0 ], "i8", ALLOC_STATIC);

__ZTVN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1722, 0, 0, 0, 1724, 0, 0, 0, 1726, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str104087 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 100, 101, 108, 101, 116, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114088 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 103, 101, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124089 = allocate([ 87, 101, 97, 107, 77, 97, 112, 46, 104, 97, 115, 0 ], "i8", ALLOC_STATIC);

__ZL14sWrapperFamily = allocate(1, "i32", ALLOC_STATIC);

__ZTV9JSWrapper = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1728, 0, 0, 0, 1730, 0, 0, 0, 1732, 0, 0, 0, 1734, 0, 0, 0, 1736, 0, 0, 0, 1738, 0, 0, 0, 1740, 0, 0, 0, 1742, 0, 0, 0, 1744, 0, 0, 0, 1746, 0, 0, 0, 1748, 0, 0, 0, 1750, 0, 0, 0, 1752, 0, 0, 0, 1754, 0, 0, 0, 1756, 0, 0, 0, 1758, 0, 0, 0, 1760, 0, 0, 0, 1762, 0, 0, 0, 1764, 0, 0, 0, 1766, 0, 0, 0, 1768, 0, 0, 0, 1770, 0, 0, 0, 1058, 0, 0, 0, 1772, 0, 0, 0, 1062, 0, 0, 0, 1774, 0, 0, 0, 1776, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str4127 = allocate([ 91, 111, 98, 106, 101, 99, 116, 32, 79, 98, 106, 101, 99, 116, 93, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str14128 = allocate([ 102, 117, 110, 99, 116, 105, 111, 110, 32, 40, 41, 32, 123, 10, 32, 32, 32, 32, 91, 110, 97, 116, 105, 118, 101, 32, 99, 111, 100, 101, 93, 10, 125, 0 ], "i8", ALLOC_STATIC);

__ZN9JSWrapper9singletonE = allocate(12, [ "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZN25JSCrossCompartmentWrapper9singletonE = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

__ZTV25JSCrossCompartmentWrapper = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 1728, 0, 0, 0, 1778, 0, 0, 0, 1780, 0, 0, 0, 1782, 0, 0, 0, 1784, 0, 0, 0, 1786, 0, 0, 0, 1788, 0, 0, 0, 1790, 0, 0, 0, 1744, 0, 0, 0, 1792, 0, 0, 0, 1794, 0, 0, 0, 1796, 0, 0, 0, 1798, 0, 0, 0, 1800, 0, 0, 0, 1802, 0, 0, 0, 1804, 0, 0, 0, 1806, 0, 0, 0, 1808, 0, 0, 0, 1764, 0, 0, 0, 1810, 0, 0, 0, 1812, 0, 0, 0, 1814, 0, 0, 0, 1058, 0, 0, 0, 1816, 0, 0, 0, 1062, 0, 0, 0, 1774, 0, 0, 0, 1776, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

__ZL10xdrmem_ops = allocate([ 1818, 0, 0, 0, 1820, 0, 0, 0, 1822, 0, 0, 0, 1824, 0, 0, 0, 1826, 0, 0, 0, 1828, 0, 0, 0, 1830, 0, 0, 0, 1832, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZZ11JS_XDRBytesE6padbuf = allocate(3, "i8", ALLOC_STATIC);

STRING_TABLE._js_AttributeName_str = allocate([ 65, 116, 116, 114, 105, 98, 117, 116, 101, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_isXMLName_str = allocate([ 105, 115, 88, 77, 76, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_XMLList_str = allocate([ 88, 77, 76, 76, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_amp_entity_str = allocate([ 38, 97, 109, 112, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_gt_entity_str = allocate([ 38, 103, 116, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_lt_entity_str = allocate([ 38, 108, 116, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._js_quot_entity_str = allocate([ 38, 113, 117, 111, 116, 59, 0 ], "i8", ALLOC_STATIC);

_sE4XObjectsCreated = allocate(1, "i32", ALLOC_STATIC);

__ZN2js14NamespaceClassE = allocate([ 0, 0, 0, 0, 201327360, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1834, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL17namespace_methods = allocate([ 0, 0, 0, 0, 1836, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZN2js10QNameClassE = allocate([ 0, 0, 0, 0, 218104576, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1838, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js18AttributeNameClassE = allocate([ 0, 0, 0, 0, 131840, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZN2js12AnyNameClassE = allocate([ 0, 0, 0, 0, 131840, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1306, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZL13qname_methods = allocate([ 0, 0, 0, 0, 1840, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL21js_ignoreComments_str = allocate([ 105, 103, 110, 111, 114, 101, 67, 111, 109, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str = allocate([ 105, 103, 110, 111, 114, 101, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL23js_ignoreWhitespace_str = allocate([ 105, 103, 110, 111, 114, 101, 87, 104, 105, 116, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL21js_prettyPrinting_str = allocate([ 112, 114, 101, 116, 116, 121, 80, 114, 105, 110, 116, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL19js_prettyIndent_str = allocate([ 112, 114, 101, 116, 116, 121, 73, 110, 100, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

__ZL16xml_static_props = allocate([ 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

__ZN2js8XMLClassE = allocate([ 0, 0, 0, 0, 184549377, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 1842, 0, 0, 0, 1844, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1846, 0, 0, 0, 1848, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, undef, 0, 0, 1850, 0, 0, 0, 1850, 0, 0, 0, 1852, 0, 0, 0, 1854, 0, 0, 0, 1856, 0, 0, 0, 1856, 0, 0, 0, 1858, 0, 0, 0, 1860, 0, 0, 0, 1862, 0, 0, 0, 1864, 0, 0, 0, 1866, 0, 0, 0, 1868, 0, 0, 0, 1870, 0, 0, 0, 1870, 0, 0, 0, 1872, 0, 0, 0, 1874, 0, 0, 0, 1876, 0, 0, 0, 1876, 0, 0, 0, 1878, 0, 0, 0, 1880, 0, 0, 0, 1882, 0, 0, 0, 1882, 0, 0, 0, 1884, 0, 0, 0, 1886, 0, 0, 0, 1888, 0, 0, 0, 1888, 0, 0, 0, 1890, 0, 0, 0, 1892, 0, 0, 0, 1894, 0, 0, 0, 1896, 0, 0, 0, 1898, 0, 0, 0, 0, 0, 0, 0, 1900, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

STRING_TABLE.__str34249 = allocate([ 108, 105, 115, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str44250 = allocate([ 101, 108, 101, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str54251 = allocate([ 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 45, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str64252 = allocate([ 99, 111, 109, 109, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

_js_xml_class_str = allocate(24, "*", ALLOC_STATIC);

STRING_TABLE.__str74253 = allocate([ 97, 100, 100, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str84254 = allocate([ 97, 112, 112, 101, 110, 100, 67, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str94255 = allocate([ 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str104256 = allocate([ 99, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str114257 = allocate([ 99, 104, 105, 108, 100, 73, 110, 100, 101, 120, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str124258 = allocate([ 99, 104, 105, 108, 100, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str134259 = allocate([ 99, 111, 109, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str144260 = allocate([ 99, 111, 110, 116, 97, 105, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str154261 = allocate([ 99, 111, 112, 121, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str164262 = allocate([ 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str174263 = allocate([ 101, 108, 101, 109, 101, 110, 116, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str194265 = allocate([ 104, 97, 115, 67, 111, 109, 112, 108, 101, 120, 67, 111, 110, 116, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str204266 = allocate([ 104, 97, 115, 83, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str214267 = allocate([ 105, 110, 83, 99, 111, 112, 101, 78, 97, 109, 101, 115, 112, 97, 99, 101, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str224268 = allocate([ 105, 110, 115, 101, 114, 116, 67, 104, 105, 108, 100, 65, 102, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str234269 = allocate([ 105, 110, 115, 101, 114, 116, 67, 104, 105, 108, 100, 66, 101, 102, 111, 114, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL16js_localName_str = allocate([ 108, 111, 99, 97, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str244270 = allocate([ 110, 97, 109, 101, 115, 112, 97, 99, 101, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str254271 = allocate([ 110, 111, 100, 101, 75, 105, 110, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str264272 = allocate([ 110, 111, 114, 109, 97, 108, 105, 122, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL17js_xml_parent_str = allocate([ 112, 97, 114, 101, 110, 116, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str274273 = allocate([ 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str284274 = allocate([ 112, 114, 101, 112, 101, 110, 100, 67, 104, 105, 108, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str304276 = allocate([ 114, 101, 109, 111, 118, 101, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str314277 = allocate([ 114, 101, 112, 108, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str324278 = allocate([ 115, 101, 116, 67, 104, 105, 108, 100, 114, 101, 110, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str334279 = allocate([ 115, 101, 116, 76, 111, 99, 97, 108, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str344280 = allocate([ 115, 101, 116, 78, 97, 109, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str354281 = allocate([ 115, 101, 116, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL18js_toXMLString_str = allocate([ 116, 111, 88, 77, 76, 83, 116, 114, 105, 110, 103, 0 ], "i8", ALLOC_STATIC);

__ZL11xml_methods = allocate([ 0, 0, 0, 0, 1902, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1904, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1906, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1908, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1910, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1912, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1914, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1916, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1918, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1920, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1922, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1924, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1926, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1928, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1930, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1932, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1934, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1936, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1938, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1940, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1942, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1944, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1946, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1948, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1950, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1952, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1954, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1956, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1958, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1960, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1962, 0, 0, 0, 2, 0, 4096, 0, 0, 0, 0, 0, 1964, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1966, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1968, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1970, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1972, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1974, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1976, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1978, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1980, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__str364282 = allocate([ 115, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str374283 = allocate([ 115, 101, 116, 83, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str384284 = allocate([ 100, 101, 102, 97, 117, 108, 116, 83, 101, 116, 116, 105, 110, 103, 115, 0 ], "i8", ALLOC_STATIC);

__ZL18xml_static_methods = allocate([ 0, 0, 0, 0, 1982, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 1984, 0, 0, 0, 1, 0, 4096, 0, 0, 0, 0, 0, 1986, 0, 0, 0, 0, 0, 4096, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0, "*", 0, 0, 0, "*", 0, 0, 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZL15namespace_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 1988, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1990, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str444290 = allocate([ 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 115, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 109, 101, 116, 104, 111, 100, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str454291 = allocate([ 88, 77, 76, 70, 105, 108, 116, 101, 114, 0 ], "i8", ALLOC_STATIC);

_js_XMLFilterClass = allocate([ 0, 0, 0, 0, 131073, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 10, 0, 0, 0, 12, 0, 0, 0, 146, 0, 0, 0, 186, 0, 0, 0, 88, 0, 0, 0, 1992, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1994, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", "i8", "i8", "i8", "i8", "i8", "i8" ], ALLOC_STATIC);

__ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_prefix_ucNstr = allocate([ 60, 0, 63, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_E16pi_suffix_ucNstr = allocate([ 63, 0, 62, 0 ], [ "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_prefix_ucNstr = allocate([ 60, 0, 33, 0, 45, 0, 45, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSStringE21comment_suffix_ucNstr = allocate([ 45, 0, 45, 0, 62, 0 ], [ "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_prefix_ucNstr = allocate([ 60, 0, 33, 0, 91, 0, 67, 0, 68, 0, 65, 0, 84, 0, 65, 0, 91, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

__ZZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSStringE19cdata_suffix_ucNstr = allocate([ 93, 0, 93, 0, 62, 0 ], [ "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6prefix = allocate([ 60, 112, 97, 114, 101, 110, 116, 32, 120, 109, 108, 110, 115, 61, 34, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6middle = allocate([ 34, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZZL14ParseXMLSourceP9JSContextP8JSStringE6suffix = allocate([ 60, 47, 112, 97, 114, 101, 110, 116, 62, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL17xml_namespace_str = allocate([ 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL19xmlns_namespace_str = allocate([ 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 47, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str464292 = allocate([ 32, 120, 109, 108, 110, 115, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str494295 = allocate([ 97, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZL23js_leftcurly_entity_str = allocate([ 38, 35, 49, 50, 51, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str504296 = allocate([ 38, 35, 120, 65, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str514297 = allocate([ 38, 35, 120, 68, 59, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str524298 = allocate([ 38, 35, 120, 57, 59, 0 ], "i8", ALLOC_STATIC);

__ZL11qname_props = allocate([ 0, 0, 0, 0, 0, 71, 0, 0, 1996, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 71, 0, 0, 1998, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 ], [ "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i8", "i8", 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__ZL10js_uri_str = allocate([ 117, 114, 105, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str544300 = allocate([ 37, 117, 0 ], "i8", ALLOC_STATIC);

__ZL7escapes = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 59, 0, 60, 0, 61, 0, 62, 0, 63, 0, 64, 0, 0, 0, -1, 0, 0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0, -7, 0, 0, 0, 0, 0, 0, 0, 91, 0, 92, 0, 93, 0, 94, 0, 95, 0, 96, 0, 7, 0, -2, 0, 0, 0, -4, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 13, 0, -6, 0, 9, 0, 0, 0, 11, 0, -8, 0, 0, 0, 0, 0, 0, 0 ], [ "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0, "i16", 0 ], ALLOC_STATIC);

STRING_TABLE.__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35minimumRepeatsFromInstructionOffset = allocate([ 0, 0, 1, 1, 0, 0 ], "i8", ALLOC_STATIC);

__ZZL38repeatInformationFromInstructionOffsetsRbRiS0_E35maximumRepeatsFromInstructionOffset = allocate([ 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 2147483647, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table1 = allocate([ 127, 0, 0, 0, 2047, 0, 0, 0, 65535, 0, 0, 0, 2097151, 0, 0, 0, 67108863, 0, 0, 0, 2147483647, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table2 = allocate([ 0, 0, 0, 0, 192, 0, 0, 0, 224, 0, 0, 0, 240, 0, 0, 0, 248, 0, 0, 0, 252, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_jsc_pcre_utf8_table3 = allocate([ 255, 0, 0, 0, 31, 0, 0, 0, 15, 0, 0, 0, 7, 0, 0, 0, 3, 0, 0, 0, 1, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE._jsc_pcre_utf8_table4 = allocate([ 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5 ], "i8", ALLOC_STATIC);

STRING_TABLE._jsc_pcre_default_tables = allocate([ 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 91, 92, 93, 94, 95, 96, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 123, 124, 125, 126, 127, 0, 62, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 3, 254, 255, 255, 135, 254, 255, 255, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 24, 24, 24, 24, 24, 24, 24, 24, 24, 0, 0, 0, 0, 0, 0, 0, 24, 24, 24, 24, 24, 24, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 0, 0, 0, 0, 16, 0, 24, 24, 24, 24, 24, 24, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 16, 0, 0, 0, 0, 0 ], "i8", ALLOC_STATIC);

__ZL9ucp_table = allocate([ 159383552, 0, 0, 0, 31, 0, 0, 0, 150994976, 0, 0, 0, 1946157056, 0, 0, 0, 159383585, 0, 0, 0, 1409286146, 0, 0, 0, 150994980, 0, 0, 0, 1543503872, 0, 0, 0, 159383589, 0, 0, 0, 1409286146, 0, 0, 0, 150994984, 0, 0, 0, 1476395008, 0, 0, 0, 150994985, 0, 0, 0, 1207959552, 0, 0, 0, 150994986, 0, 0, 0, 1409286144, 0, 0, 0, 150994987, 0, 0, 0, 1677721600, 0, 0, 0, 150994988, 0, 0, 0, 1409286144, 0, 0, 0, 150994989, 0, 0, 0, 1140850688, 0, 0, 0, 159383598, 0, 0, 0, 1409286145, 0, 0, 0, 159383600, 0, 0, 0, 872415241, 0, 0, 0, 159383610, 0, 0, 0, 1409286145, 0, 0, 0, 159383612, 0, 0, 0, 1677721602, 0, 0, 0, 159383615, 0, 0, 0, 1409286145, 0, 0, 0, 553648193, 0, 0, 0, 603979808, 0, 0, 0, 553648194, 0, 0, 0, 603979808, 0, 0, 0, 553648195, 0, 0, 0, 603979808, 0, 0, 0, 553648196, 0, 0, 0, 603979808, 0, 0, 0, 553648197, 0, 0, 0, 603979808, 0, 0, 0, 553648198, 0, 0, 0, 603979808, 0, 0, 0, 553648199, 0, 0, 0, 603979808, 0, 0, 0, 553648200, 0, 0, 0, 603979808, 0, 0, 0, 553648201, 0, 0, 0, 603979808, 0, 0, 0, 553648202, 0, 0, 0, 603979808, 0, 0, 0, 553648203, 0, 0, 0, 603979808, 0, 0, 0, 553648204, 0, 0, 0, 603979808, 0, 0, 0, 553648205, 0, 0, 0, 603979808, 0, 0, 0, 553648206, 0, 0, 0, 603979808, 0, 0, 0, 553648207, 0, 0, 0, 603979808, 0, 0, 0, 553648208, 0, 0, 0, 603979808, 0, 0, 0, 553648209, 0, 0, 0, 603979808, 0, 0, 0, 553648210, 0, 0, 0, 603979808, 0, 0, 0, 553648211, 0, 0, 0, 603979808, 0, 0, 0, 553648212, 0, 0, 0, 603979808, 0, 0, 0, 553648213, 0, 0, 0, 603979808, 0, 0, 0, 553648214, 0, 0, 0, 603979808, 0, 0, 0, 553648215, 0, 0, 0, 603979808, 0, 0, 0, 553648216, 0, 0, 0, 603979808, 0, 0, 0, 553648217, 0, 0, 0, 603979808, 0, 0, 0, 553648218, 0, 0, 0, 603979808, 0, 0, 0, 150995035, 0, 0, 0, 1476395008, 0, 0, 0, 150995036, 0, 0, 0, 1409286144, 0, 0, 0, 150995037, 0, 0, 0, 1207959552, 0, 0, 0, 150995038, 0, 0, 0, 1610612736, 0, 0, 0, 150995039, 0, 0, 0, 1073741824, 0, 0, 0, 150995040, 0, 0, 0, 1610612736, 0, 0, 0, 553648225, 0, 0, 0, 335609824, 0, 0, 0, 553648226, 0, 0, 0, 335609824, 0, 0, 0, 553648227, 0, 0, 0, 335609824, 0, 0, 0, 553648228, 0, 0, 0, 335609824, 0, 0, 0, 553648229, 0, 0, 0, 335609824, 0, 0, 0, 553648230, 0, 0, 0, 335609824, 0, 0, 0, 553648231, 0, 0, 0, 335609824, 0, 0, 0, 553648232, 0, 0, 0, 335609824, 0, 0, 0, 553648233, 0, 0, 0, 335609824, 0, 0, 0, 553648234, 0, 0, 0, 335609824, 0, 0, 0, 553648235, 0, 0, 0, 335609824, 0, 0, 0, 553648236, 0, 0, 0, 335609824, 0, 0, 0, 553648237, 0, 0, 0, 335609824, 0, 0, 0, 553648238, 0, 0, 0, 335609824, 0, 0, 0, 553648239, 0, 0, 0, 335609824, 0, 0, 0, 553648240, 0, 0, 0, 335609824, 0, 0, 0, 553648241, 0, 0, 0, 335609824, 0, 0, 0, 553648242, 0, 0, 0, 335609824, 0, 0, 0, 553648243, 0, 0, 0, 335609824, 0, 0, 0, 553648244, 0, 0, 0, 335609824, 0, 0, 0, 553648245, 0, 0, 0, 335609824, 0, 0, 0, 553648246, 0, 0, 0, 335609824, 0, 0, 0, 553648247, 0, 0, 0, 335609824, 0, 0, 0, 553648248, 0, 0, 0, 335609824, 0, 0, 0, 553648249, 0, 0, 0, 335609824, 0, 0, 0, 553648250, 0, 0, 0, 335609824, 0, 0, 0, 150995067, 0, 0, 0, 1476395008, 0, 0, 0, 150995068, 0, 0, 0, 1677721600, 0, 0, 0, 150995069, 0, 0, 0, 1207959552, 0, 0, 0, 150995070, 0, 0, 0, 1677721600, 0, 0, 0, 159383679, 0, 0, 0, 32, 0, 0, 0, 150995104, 0, 0, 0, 1946157056, 0, 0, 0, 150995105, 0, 0, 0, 1409286144, 0, 0, 0, 159383714, 0, 0, 0, 1543503875, 0, 0, 0, 159383718, 0, 0, 0, 1744830465, 0, 0, 0, 150995112, 0, 0, 0, 1610612736, 0, 0, 0, 150995113, 0, 0, 0, 1744830464, 0, 0, 0, 553648298, 0, 0, 0, 335544320, 0, 0, 0, 150995115, 0, 0, 0, 1342177280, 0, 0, 0, 150995116, 0, 0, 0, 1677721600, 0, 0, 0, 150995117, 0, 0, 0, 67108864, 0, 0, 0, 150995118, 0, 0, 0, 1744830464, 0, 0, 0, 150995119, 0, 0, 0, 1610612736, 0, 0, 0, 150995120, 0, 0, 0, 1744830464, 0, 0, 0, 150995121, 0, 0, 0, 1677721600, 0, 0, 0, 159383730, 0, 0, 0, 1006632961, 0, 0, 0, 150995124, 0, 0, 0, 1610612736, 0, 0, 0, 150995125, 0, 0, 0, 335545063, 0, 0, 0, 150995126, 0, 0, 0, 1744830464, 0, 0, 0, 150995127, 0, 0, 0, 1409286144, 0, 0, 0, 150995128, 0, 0, 0, 1610612736, 0, 0, 0, 150995129, 0, 0, 0, 1006632960, 0, 0, 0, 553648314, 0, 0, 0, 335544320, 0, 0, 0, 150995131, 0, 0, 0, 1275068416, 0, 0, 0, 159383740, 0, 0, 0, 1006632962, 0, 0, 0, 150995135, 0, 0, 0, 1409286144, 0, 0, 0, 553648320, 0, 0, 0, 603979808, 0, 0, 0, 553648321, 0, 0, 0, 603979808, 0, 0, 0, 553648322, 0, 0, 0, 603979808, 0, 0, 0, 553648323, 0, 0, 0, 603979808, 0, 0, 0, 553648324, 0, 0, 0, 603979808, 0, 0, 0, 553648325, 0, 0, 0, 603979808, 0, 0, 0, 553648326, 0, 0, 0, 603979808, 0, 0, 0, 553648327, 0, 0, 0, 603979808, 0, 0, 0, 553648328, 0, 0, 0, 603979808, 0, 0, 0, 553648329, 0, 0, 0, 603979808, 0, 0, 0, 553648330, 0, 0, 0, 603979808, 0, 0, 0, 553648331, 0, 0, 0, 603979808, 0, 0, 0, 553648332, 0, 0, 0, 603979808, 0, 0, 0, 553648333, 0, 0, 0, 603979808, 0, 0, 0, 553648334, 0, 0, 0, 603979808, 0, 0, 0, 553648335, 0, 0, 0, 603979808, 0, 0, 0, 553648336, 0, 0, 0, 603979808, 0, 0, 0, 553648337, 0, 0, 0, 603979808, 0, 0, 0, 553648338, 0, 0, 0, 603979808, 0, 0, 0, 553648339, 0, 0, 0, 603979808, 0, 0, 0, 553648340, 0, 0, 0, 603979808, 0, 0, 0, 553648341, 0, 0, 0, 603979808, 0, 0, 0, 553648342, 0, 0, 0, 603979808, 0, 0, 0, 150995159, 0, 0, 0, 1677721600, 0, 0, 0, 553648344, 0, 0, 0, 603979808, 0, 0, 0, 553648345, 0, 0, 0, 603979808, 0, 0, 0, 553648346, 0, 0, 0, 603979808, 0, 0, 0, 553648347, 0, 0, 0, 603979808, 0, 0, 0, 553648348, 0, 0, 0, 603979808, 0, 0, 0, 553648349, 0, 0, 0, 603979808, 0, 0, 0, 553648350, 0, 0, 0, 603979808, 0, 0, 0, 553648351, 0, 0, 0, 335544320, 0, 0, 0, 553648352, 0, 0, 0, 335609824, 0, 0, 0, 553648353, 0, 0, 0, 335609824, 0, 0, 0, 553648354, 0, 0, 0, 335609824, 0, 0, 0, 553648355, 0, 0, 0, 335609824, 0, 0, 0, 553648356, 0, 0, 0, 335609824, 0, 0, 0, 553648357, 0, 0, 0, 335609824, 0, 0, 0, 553648358, 0, 0, 0, 335609824, 0, 0, 0, 553648359, 0, 0, 0, 335609824, 0, 0, 0, 553648360, 0, 0, 0, 335609824, 0, 0, 0, 553648361, 0, 0, 0, 335609824, 0, 0, 0, 553648362, 0, 0, 0, 335609824, 0, 0, 0, 553648363, 0, 0, 0, 335609824, 0, 0, 0, 553648364, 0, 0, 0, 335609824, 0, 0, 0, 553648365, 0, 0, 0, 335609824, 0, 0, 0, 553648366, 0, 0, 0, 335609824, 0, 0, 0, 553648367, 0, 0, 0, 335609824, 0, 0, 0, 553648368, 0, 0, 0, 335609824, 0, 0, 0, 553648369, 0, 0, 0, 335609824, 0, 0, 0, 553648370, 0, 0, 0, 335609824, 0, 0, 0, 553648371, 0, 0, 0, 335609824, 0, 0, 0, 553648372, 0, 0, 0, 335609824, 0, 0, 0, 553648373, 0, 0, 0, 335609824, 0, 0, 0, 553648374, 0, 0, 0, 335609824, 0, 0, 0, 150995191, 0, 0, 0, 1677721600, 0, 0, 0, 553648376, 0, 0, 0, 335609824, 0, 0, 0, 553648377, 0, 0, 0, 335609824, 0, 0, 0, 553648378, 0, 0, 0, 335609824, 0, 0, 0, 553648379, 0, 0, 0, 335609824, 0, 0, 0, 553648380, 0, 0, 0, 335609824, 0, 0, 0, 553648381, 0, 0, 0, 335609824, 0, 0, 0, 553648382, 0, 0, 0, 335609824, 0, 0, 0, 553648383, 0, 0, 0, 335544441, 0, 0, 0, 553648384, 0, 0, 0, 603979777, 0, 0, 0, 553648385, 0, 0, 0, 335609855, 0, 0, 0, 553648386, 0, 0, 0, 603979777, 0, 0, 0, 553648387, 0, 0, 0, 335609855, 0, 0, 0, 553648388, 0, 0, 0, 603979777, 0, 0, 0, 553648389, 0, 0, 0, 335609855, 0, 0, 0, 553648390, 0, 0, 0, 603979777, 0, 0, 0, 553648391, 0, 0, 0, 335609855, 0, 0, 0, 553648392, 0, 0, 0, 603979777, 0, 0, 0, 553648393, 0, 0, 0, 335609855, 0, 0, 0, 553648394, 0, 0, 0, 603979777, 0, 0, 0, 553648395, 0, 0, 0, 335609855, 0, 0, 0, 553648396, 0, 0, 0, 603979777, 0, 0, 0, 553648397, 0, 0, 0, 335609855, 0, 0, 0, 553648398, 0, 0, 0, 603979777, 0, 0, 0, 553648399, 0, 0, 0, 335609855, 0, 0, 0, 553648400, 0, 0, 0, 603979777, 0, 0, 0, 553648401, 0, 0, 0, 335609855, 0, 0, 0, 553648402, 0, 0, 0, 603979777, 0, 0, 0, 553648403, 0, 0, 0, 335609855, 0, 0, 0, 553648404, 0, 0, 0, 603979777, 0, 0, 0, 553648405, 0, 0, 0, 335609855, 0, 0, 0, 553648406, 0, 0, 0, 603979777, 0, 0, 0, 553648407, 0, 0, 0, 335609855, 0, 0, 0, 553648408, 0, 0, 0, 603979777, 0, 0, 0, 553648409, 0, 0, 0, 335609855, 0, 0, 0, 553648410, 0, 0, 0, 603979777, 0, 0, 0, 553648411, 0, 0, 0, 335609855, 0, 0, 0, 553648412, 0, 0, 0, 603979777, 0, 0, 0, 553648413, 0, 0, 0, 335609855, 0, 0, 0, 553648414, 0, 0, 0, 603979777, 0, 0, 0, 553648415, 0, 0, 0, 335609855, 0, 0, 0, 553648416, 0, 0, 0, 603979777, 0, 0, 0, 553648417, 0, 0, 0, 335609855, 0, 0, 0, 553648418, 0, 0, 0, 603979777, 0, 0, 0, 553648419, 0, 0, 0, 335609855, 0, 0, 0, 553648420, 0, 0, 0, 603979777, 0, 0, 0, 553648421, 0, 0, 0, 335609855, 0, 0, 0, 553648422, 0, 0, 0, 603979777, 0, 0, 0, 553648423, 0, 0, 0, 335609855, 0, 0, 0, 553648424, 0, 0, 0, 603979777, 0, 0, 0, 553648425, 0, 0, 0, 335609855, 0, 0, 0, 553648426, 0, 0, 0, 603979777, 0, 0, 0, 553648427, 0, 0, 0, 335609855, 0, 0, 0, 553648428, 0, 0, 0, 603979777, 0, 0, 0, 553648429, 0, 0, 0, 335609855, 0, 0, 0, 553648430, 0, 0, 0, 603979777, 0, 0, 0, 553648431, 0, 0, 0, 335609855, 0, 0, 0, 553648432, 0, 0, 0, 604045113, 0, 0, 0, 553648433, 0, 0, 0, 335609624, 0, 0, 0, 553648434, 0, 0, 0, 603979777, 0, 0, 0, 553648435, 0, 0, 0, 335609855, 0, 0, 0, 553648436, 0, 0, 0, 603979777, 0, 0, 0, 553648437, 0, 0, 0, 335609855, 0, 0, 0, 553648438, 0, 0, 0, 603979777, 0, 0, 0, 553648439, 0, 0, 0, 335609855, 0, 0, 0, 553648440, 0, 0, 0, 335544320, 0, 0, 0, 553648441, 0, 0, 0, 603979777, 0, 0, 0, 553648442, 0, 0, 0, 335609855, 0, 0, 0, 553648443, 0, 0, 0, 603979777, 0, 0, 0, 553648444, 0, 0, 0, 335609855, 0, 0, 0, 553648445, 0, 0, 0, 603979777, 0, 0, 0, 553648446, 0, 0, 0, 335609855, 0, 0, 0, 553648447, 0, 0, 0, 603979777, 0, 0, 0, 553648448, 0, 0, 0, 335609855, 0, 0, 0, 553648449, 0, 0, 0, 603979777, 0, 0, 0, 553648450, 0, 0, 0, 335609855, 0, 0, 0, 553648451, 0, 0, 0, 603979777, 0, 0, 0, 553648452, 0, 0, 0, 335609855, 0, 0, 0, 553648453, 0, 0, 0, 603979777, 0, 0, 0, 553648454, 0, 0, 0, 335609855, 0, 0, 0, 553648455, 0, 0, 0, 603979777, 0, 0, 0, 553648456, 0, 0, 0, 335609855, 0, 0, 0, 553648457, 0, 0, 0, 335544320, 0, 0, 0, 553648458, 0, 0, 0, 603979777, 0, 0, 0, 553648459, 0, 0, 0, 335609855, 0, 0, 0, 553648460, 0, 0, 0, 603979777, 0, 0, 0, 553648461, 0, 0, 0, 335609855, 0, 0, 0, 553648462, 0, 0, 0, 603979777, 0, 0, 0, 553648463, 0, 0, 0, 335609855, 0, 0, 0, 553648464, 0, 0, 0, 603979777, 0, 0, 0, 553648465, 0, 0, 0, 335609855, 0, 0, 0, 553648466, 0, 0, 0, 603979777, 0, 0, 0, 553648467, 0, 0, 0, 335609855, 0, 0, 0, 553648468, 0, 0, 0, 603979777, 0, 0, 0, 553648469, 0, 0, 0, 335609855, 0, 0, 0, 553648470, 0, 0, 0, 603979777, 0, 0, 0, 553648471, 0, 0, 0, 335609855, 0, 0, 0, 553648472, 0, 0, 0, 603979777, 0, 0, 0, 553648473, 0, 0, 0, 335609855, 0, 0, 0, 553648474, 0, 0, 0, 603979777, 0, 0, 0, 553648475, 0, 0, 0, 335609855, 0, 0, 0, 553648476, 0, 0, 0, 603979777, 0, 0, 0, 553648477, 0, 0, 0, 335609855, 0, 0, 0, 553648478, 0, 0, 0, 603979777, 0, 0, 0, 553648479, 0, 0, 0, 335609855, 0, 0, 0, 553648480, 0, 0, 0, 603979777, 0, 0, 0, 553648481, 0, 0, 0, 335609855, 0, 0, 0, 553648482, 0, 0, 0, 603979777, 0, 0, 0, 553648483, 0, 0, 0, 335609855, 0, 0, 0, 553648484, 0, 0, 0, 603979777, 0, 0, 0, 553648485, 0, 0, 0, 335609855, 0, 0, 0, 553648486, 0, 0, 0, 603979777, 0, 0, 0, 553648487, 0, 0, 0, 335609855, 0, 0, 0, 553648488, 0, 0, 0, 603979777, 0, 0, 0, 553648489, 0, 0, 0, 335609855, 0, 0, 0, 553648490, 0, 0, 0, 603979777, 0, 0, 0, 553648491, 0, 0, 0, 335609855, 0, 0, 0, 553648492, 0, 0, 0, 603979777, 0, 0, 0, 553648493, 0, 0, 0, 335609855, 0, 0, 0, 553648494, 0, 0, 0, 603979777, 0, 0, 0, 553648495, 0, 0, 0, 335609855, 0, 0, 0, 553648496, 0, 0, 0, 603979777, 0, 0, 0, 553648497, 0, 0, 0, 335609855, 0, 0, 0, 553648498, 0, 0, 0, 603979777, 0, 0, 0, 553648499, 0, 0, 0, 335609855, 0, 0, 0, 553648500, 0, 0, 0, 603979777, 0, 0, 0, 553648501, 0, 0, 0, 335609855, 0, 0, 0, 553648502, 0, 0, 0, 603979777, 0, 0, 0, 553648503, 0, 0, 0, 335609855, 0, 0, 0, 553648504, 0, 0, 0, 604045191, 0, 0, 0, 553648505, 0, 0, 0, 603979777, 0, 0, 0, 553648506, 0, 0, 0, 335609855, 0, 0, 0, 553648507, 0, 0, 0, 603979777, 0, 0, 0, 553648508, 0, 0, 0, 335609855, 0, 0, 0, 553648509, 0, 0, 0, 603979777, 0, 0, 0, 553648510, 0, 0, 0, 335609855, 0, 0, 0, 553648511, 0, 0, 0, 335609556, 0, 0, 0, 553648512, 0, 0, 0, 335544320, 0, 0, 0, 553648513, 0, 0, 0, 603979986, 0, 0, 0, 553648514, 0, 0, 0, 603979777, 0, 0, 0, 553648515, 0, 0, 0, 335609855, 0, 0, 0, 553648516, 0, 0, 0, 603979777, 0, 0, 0, 553648517, 0, 0, 0, 335609855, 0, 0, 0, 553648518, 0, 0, 0, 603979982, 0, 0, 0, 553648519, 0, 0, 0, 603979777, 0, 0, 0, 553648520, 0, 0, 0, 335609855, 0, 0, 0, 553648521, 0, 0, 0, 603979981, 0, 0, 0, 553648522, 0, 0, 0, 603979981, 0, 0, 0, 553648523, 0, 0, 0, 603979777, 0, 0, 0, 553648524, 0, 0, 0, 335609855, 0, 0, 0, 553648525, 0, 0, 0, 335544320, 0, 0, 0, 553648526, 0, 0, 0, 603979855, 0, 0, 0, 553648527, 0, 0, 0, 603979978, 0, 0, 0, 553648528, 0, 0, 0, 603979979, 0, 0, 0, 553648529, 0, 0, 0, 603979777, 0, 0, 0, 553648530, 0, 0, 0, 335609855, 0, 0, 0, 553648531, 0, 0, 0, 603979981, 0, 0, 0, 553648532, 0, 0, 0, 603979983, 0, 0, 0, 553648533, 0, 0, 0, 335544417, 0, 0, 0, 553648534, 0, 0, 0, 603979987, 0, 0, 0, 553648535, 0, 0, 0, 603979985, 0, 0, 0, 553648536, 0, 0, 0, 603979777, 0, 0, 0, 553648537, 0, 0, 0, 335609855, 0, 0, 0, 553648538, 0, 0, 0, 335544483, 0, 0, 0, 553648539, 0, 0, 0, 335544320, 0, 0, 0, 553648540, 0, 0, 0, 603979987, 0, 0, 0, 553648541, 0, 0, 0, 603979989, 0, 0, 0, 553648542, 0, 0, 0, 335544450, 0, 0, 0, 553648543, 0, 0, 0, 603979990, 0, 0, 0, 553648544, 0, 0, 0, 603979777, 0, 0, 0, 553648545, 0, 0, 0, 335609855, 0, 0, 0, 553648546, 0, 0, 0, 603979777, 0, 0, 0, 553648547, 0, 0, 0, 335609855, 0, 0, 0, 553648548, 0, 0, 0, 603979777, 0, 0, 0, 553648549, 0, 0, 0, 335609855, 0, 0, 0, 553648550, 0, 0, 0, 603979994, 0, 0, 0, 553648551, 0, 0, 0, 603979777, 0, 0, 0, 553648552, 0, 0, 0, 335609855, 0, 0, 0, 553648553, 0, 0, 0, 603979994, 0, 0, 0, 562037162, 0, 0, 0, 335544321, 0, 0, 0, 553648556, 0, 0, 0, 603979777, 0, 0, 0, 553648557, 0, 0, 0, 335609855, 0, 0, 0, 553648558, 0, 0, 0, 603979994, 0, 0, 0, 553648559, 0, 0, 0, 603979777, 0, 0, 0, 553648560, 0, 0, 0, 335609855, 0, 0, 0, 553648561, 0, 0, 0, 603979993, 0, 0, 0, 553648562, 0, 0, 0, 603979993, 0, 0, 0, 553648563, 0, 0, 0, 603979777, 0, 0, 0, 553648564, 0, 0, 0, 335609855, 0, 0, 0, 553648565, 0, 0, 0, 603979777, 0, 0, 0, 553648566, 0, 0, 0, 335609855, 0, 0, 0, 553648567, 0, 0, 0, 603979995, 0, 0, 0, 553648568, 0, 0, 0, 603979777, 0, 0, 0, 553648569, 0, 0, 0, 335609855, 0, 0, 0, 553648570, 0, 0, 0, 335544320, 0, 0, 0, 553648571, 0, 0, 0, 469762048, 0, 0, 0, 553648572, 0, 0, 0, 603979777, 0, 0, 0, 553648573, 0, 0, 0, 335609855, 0, 0, 0, 553648574, 0, 0, 0, 335544320, 0, 0, 0, 553648575, 0, 0, 0, 335544376, 0, 0, 0, 562037184, 0, 0, 0, 469762051, 0, 0, 0, 553648580, 0, 0, 0, 603979778, 0, 0, 0, 553648581, 0, 0, 0, 536936447, 0, 0, 0, 553648582, 0, 0, 0, 335609854, 0, 0, 0, 553648583, 0, 0, 0, 603979778, 0, 0, 0, 553648584, 0, 0, 0, 536936447, 0, 0, 0, 553648585, 0, 0, 0, 335609854, 0, 0, 0, 553648586, 0, 0, 0, 603979778, 0, 0, 0, 553648587, 0, 0, 0, 536936447, 0, 0, 0, 553648588, 0, 0, 0, 335609854, 0, 0, 0, 553648589, 0, 0, 0, 603979777, 0, 0, 0, 553648590, 0, 0, 0, 335609855, 0, 0, 0, 553648591, 0, 0, 0, 603979777, 0, 0, 0, 553648592, 0, 0, 0, 335609855, 0, 0, 0, 553648593, 0, 0, 0, 603979777, 0, 0, 0, 553648594, 0, 0, 0, 335609855, 0, 0, 0, 553648595, 0, 0, 0, 603979777, 0, 0, 0, 553648596, 0, 0, 0, 335609855, 0, 0, 0, 553648597, 0, 0, 0, 603979777, 0, 0, 0, 553648598, 0, 0, 0, 335609855, 0, 0, 0, 553648599, 0, 0, 0, 603979777, 0, 0, 0, 553648600, 0, 0, 0, 335609855, 0, 0, 0, 553648601, 0, 0, 0, 603979777, 0, 0, 0, 553648602, 0, 0, 0, 335609855, 0, 0, 0, 553648603, 0, 0, 0, 603979777, 0, 0, 0, 553648604, 0, 0, 0, 335609855, 0, 0, 0, 553648605, 0, 0, 0, 335609777, 0, 0, 0, 553648606, 0, 0, 0, 603979777, 0, 0, 0, 553648607, 0, 0, 0, 335609855, 0, 0, 0, 553648608, 0, 0, 0, 603979777, 0, 0, 0, 553648609, 0, 0, 0, 335609855, 0, 0, 0, 553648610, 0, 0, 0, 603979777, 0, 0, 0, 553648611, 0, 0, 0, 335609855, 0, 0, 0, 553648612, 0, 0, 0, 603979777, 0, 0, 0, 553648613, 0, 0, 0, 335609855, 0, 0, 0, 553648614, 0, 0, 0, 603979777, 0, 0, 0, 553648615, 0, 0, 0, 335609855, 0, 0, 0, 553648616, 0, 0, 0, 603979777, 0, 0, 0, 553648617, 0, 0, 0, 335609855, 0, 0, 0, 553648618, 0, 0, 0, 603979777, 0, 0, 0, 553648619, 0, 0, 0, 335609855, 0, 0, 0, 553648620, 0, 0, 0, 603979777, 0, 0, 0, 553648621, 0, 0, 0, 335609855, 0, 0, 0, 553648622, 0, 0, 0, 603979777, 0, 0, 0, 553648623, 0, 0, 0, 335609855, 0, 0, 0, 553648624, 0, 0, 0, 335544320, 0, 0, 0, 553648625, 0, 0, 0, 603979778, 0, 0, 0, 553648626, 0, 0, 0, 536936447, 0, 0, 0, 553648627, 0, 0, 0, 335609854, 0, 0, 0, 553648628, 0, 0, 0, 603979777, 0, 0, 0, 553648629, 0, 0, 0, 335609855, 0, 0, 0, 553648630, 0, 0, 0, 604045215, 0, 0, 0, 553648631, 0, 0, 0, 604045256, 0, 0, 0, 553648632, 0, 0, 0, 603979777, 0, 0, 0, 553648633, 0, 0, 0, 335609855, 0, 0, 0, 553648634, 0, 0, 0, 603979777, 0, 0, 0, 553648635, 0, 0, 0, 335609855, 0, 0, 0, 553648636, 0, 0, 0, 603979777, 0, 0, 0, 553648637, 0, 0, 0, 335609855, 0, 0, 0, 553648638, 0, 0, 0, 603979777, 0, 0, 0, 553648639, 0, 0, 0, 335609855, 0, 0, 0, 553648640, 0, 0, 0, 603979777, 0, 0, 0, 553648641, 0, 0, 0, 335609855, 0, 0, 0, 553648642, 0, 0, 0, 603979777, 0, 0, 0, 553648643, 0, 0, 0, 335609855, 0, 0, 0, 553648644, 0, 0, 0, 603979777, 0, 0, 0, 553648645, 0, 0, 0, 335609855, 0, 0, 0, 553648646, 0, 0, 0, 603979777, 0, 0, 0, 553648647, 0, 0, 0, 335609855, 0, 0, 0, 553648648, 0, 0, 0, 603979777, 0, 0, 0, 553648649, 0, 0, 0, 335609855, 0, 0, 0, 553648650, 0, 0, 0, 603979777, 0, 0, 0, 553648651, 0, 0, 0, 335609855, 0, 0, 0, 553648652, 0, 0, 0, 603979777, 0, 0, 0, 553648653, 0, 0, 0, 335609855, 0, 0, 0, 553648654, 0, 0, 0, 603979777, 0, 0, 0, 553648655, 0, 0, 0, 335609855, 0, 0, 0, 553648656, 0, 0, 0, 603979777, 0, 0, 0, 553648657, 0, 0, 0, 335609855, 0, 0, 0, 553648658, 0, 0, 0, 603979777, 0, 0, 0, 553648659, 0, 0, 0, 335609855, 0, 0, 0, 553648660, 0, 0, 0, 603979777, 0, 0, 0, 553648661, 0, 0, 0, 335609855, 0, 0, 0, 553648662, 0, 0, 0, 603979777, 0, 0, 0, 553648663, 0, 0, 0, 335609855, 0, 0, 0, 553648664, 0, 0, 0, 603979777, 0, 0, 0, 553648665, 0, 0, 0, 335609855, 0, 0, 0, 553648666, 0, 0, 0, 603979777, 0, 0, 0, 553648667, 0, 0, 0, 335609855, 0, 0, 0, 553648668, 0, 0, 0, 603979777, 0, 0, 0, 553648669, 0, 0, 0, 335609855, 0, 0, 0, 553648670, 0, 0, 0, 603979777, 0, 0, 0, 553648671, 0, 0, 0, 335609855, 0, 0, 0, 553648672, 0, 0, 0, 604045182, 0, 0, 0, 553648673, 0, 0, 0, 335544320, 0, 0, 0, 553648674, 0, 0, 0, 603979777, 0, 0, 0, 553648675, 0, 0, 0, 335609855, 0, 0, 0, 553648676, 0, 0, 0, 603979777, 0, 0, 0, 553648677, 0, 0, 0, 335609855, 0, 0, 0, 553648678, 0, 0, 0, 603979777, 0, 0, 0, 553648679, 0, 0, 0, 335609855, 0, 0, 0, 553648680, 0, 0, 0, 603979777, 0, 0, 0, 553648681, 0, 0, 0, 335609855, 0, 0, 0, 553648682, 0, 0, 0, 603979777, 0, 0, 0, 553648683, 0, 0, 0, 335609855, 0, 0, 0, 553648684, 0, 0, 0, 603979777, 0, 0, 0, 553648685, 0, 0, 0, 335609855, 0, 0, 0, 553648686, 0, 0, 0, 603979777, 0, 0, 0, 553648687, 0, 0, 0, 335609855, 0, 0, 0, 553648688, 0, 0, 0, 603979777, 0, 0, 0, 553648689, 0, 0, 0, 335609855, 0, 0, 0, 553648690, 0, 0, 0, 603979777, 0, 0, 0, 553648691, 0, 0, 0, 335609855, 0, 0, 0, 562037300, 0, 0, 0, 335544325, 0, 0, 0, 553648698, 0, 0, 0, 603979776, 0, 0, 0, 553648699, 0, 0, 0, 603979777, 0, 0, 0, 553648700, 0, 0, 0, 335609855, 0, 0, 0, 553648701, 0, 0, 0, 604045149, 0, 0, 0, 553648702, 0, 0, 0, 603979776, 0, 0, 0, 562037311, 0, 0, 0, 335544321, 0, 0, 0, 553648705, 0, 0, 0, 603979859, 0, 0, 0, 562037328, 0, 0, 0, 335544322, 0, 0, 0, 553648723, 0, 0, 0, 335609646, 0, 0, 0, 553648724, 0, 0, 0, 335609650, 0, 0, 0, 553648725, 0, 0, 0, 335544320, 0, 0, 0, 553648726, 0, 0, 0, 335609651, 0, 0, 0, 553648727, 0, 0, 0, 335609651, 0, 0, 0, 553648728, 0, 0, 0, 335544320, 0, 0, 0, 553648729, 0, 0, 0, 335609654, 0, 0, 0, 553648730, 0, 0, 0, 335544320, 0, 0, 0, 553648731, 0, 0, 0, 335609653, 0, 0, 0, 562037340, 0, 0, 0, 335544323, 0, 0, 0, 553648736, 0, 0, 0, 335609651, 0, 0, 0, 562037345, 0, 0, 0, 335544321, 0, 0, 0, 553648739, 0, 0, 0, 335609649, 0, 0, 0, 562037348, 0, 0, 0, 335544323, 0, 0, 0, 553648744, 0, 0, 0, 335609647, 0, 0, 0, 553648745, 0, 0, 0, 335609645, 0, 0, 0, 562037354, 0, 0, 0, 335544324, 0, 0, 0, 553648751, 0, 0, 0, 335609645, 0, 0, 0, 562037360, 0, 0, 0, 335544321, 0, 0, 0, 553648754, 0, 0, 0, 335609643, 0, 0, 0, 562037363, 0, 0, 0, 335544321, 0, 0, 0, 553648757, 0, 0, 0, 335609642, 0, 0, 0, 562037366, 0, 0, 0, 335544329, 0, 0, 0, 553648768, 0, 0, 0, 335609638, 0, 0, 0, 562037377, 0, 0, 0, 335544321, 0, 0, 0, 553648771, 0, 0, 0, 335609638, 0, 0, 0, 562037380, 0, 0, 0, 335544323, 0, 0, 0, 553648776, 0, 0, 0, 335609638, 0, 0, 0, 553648777, 0, 0, 0, 335544320, 0, 0, 0, 553648778, 0, 0, 0, 335609639, 0, 0, 0, 553648779, 0, 0, 0, 335609639, 0, 0, 0, 562037388, 0, 0, 0, 335544325, 0, 0, 0, 553648786, 0, 0, 0, 335609637, 0, 0, 0, 553648787, 0, 0, 0, 335544320, 0, 0, 0, 553648788, 0, 0, 0, 335609773, 0, 0, 0, 562037397, 0, 0, 0, 335544346, 0, 0, 0, 562037424, 0, 0, 0, 402653201, 0, 0, 0, 159384258, 0, 0, 0, 1610612739, 0, 0, 0, 159384262, 0, 0, 0, 402653195, 0, 0, 0, 159384274, 0, 0, 0, 1610612749, 0, 0, 0, 562037472, 0, 0, 0, 402653188, 0, 0, 0, 159384293, 0, 0, 0, 1610612744, 0, 0, 0, 150995694, 0, 0, 0, 402653184, 0, 0, 0, 159384303, 0, 0, 0, 1610612752, 0, 0, 0, 461374208, 0, 0, 0, 805306436, 0, 0, 0, 452985669, 0, 0, 0, 805306452, 0, 0, 0, 461374278, 0, 0, 0, 805306409, 0, 0, 0, 327156596, 0, 0, 0, 1610612737, 0, 0, 0, 318767994, 0, 0, 0, 402653184, 0, 0, 0, 150995838, 0, 0, 0, 1409286144, 0, 0, 0, 327156612, 0, 0, 0, 1610612737, 0, 0, 0, 318768006, 0, 0, 0, 603979814, 0, 0, 0, 150995847, 0, 0, 0, 1409286144, 0, 0, 0, 318768008, 0, 0, 0, 603979813, 0, 0, 0, 318768009, 0, 0, 0, 603979813, 0, 0, 0, 318768010, 0, 0, 0, 603979813, 0, 0, 0, 318768012, 0, 0, 0, 603979840, 0, 0, 0, 318768014, 0, 0, 0, 603979839, 0, 0, 0, 318768015, 0, 0, 0, 603979839, 0, 0, 0, 318768016, 0, 0, 0, 335544320, 0, 0, 0, 318768017, 0, 0, 0, 603979808, 0, 0, 0, 318768018, 0, 0, 0, 603979808, 0, 0, 0, 318768019, 0, 0, 0, 603979808, 0, 0, 0, 318768020, 0, 0, 0, 603979808, 0, 0, 0, 318768021, 0, 0, 0, 603979808, 0, 0, 0, 318768022, 0, 0, 0, 603979808, 0, 0, 0, 318768023, 0, 0, 0, 603979808, 0, 0, 0, 318768024, 0, 0, 0, 603979808, 0, 0, 0, 318768025, 0, 0, 0, 603979808, 0, 0, 0, 318768026, 0, 0, 0, 603979808, 0, 0, 0, 318768027, 0, 0, 0, 603979808, 0, 0, 0, 318768028, 0, 0, 0, 603979808, 0, 0, 0, 318768029, 0, 0, 0, 603979808, 0, 0, 0, 318768030, 0, 0, 0, 603979808, 0, 0, 0, 318768031, 0, 0, 0, 603979808, 0, 0, 0, 318768032, 0, 0, 0, 603979808, 0, 0, 0, 318768033, 0, 0, 0, 603979808, 0, 0, 0, 318768035, 0, 0, 0, 603979808, 0, 0, 0, 318768036, 0, 0, 0, 603979808, 0, 0, 0, 318768037, 0, 0, 0, 603979808, 0, 0, 0, 318768038, 0, 0, 0, 603979808, 0, 0, 0, 318768039, 0, 0, 0, 603979808, 0, 0, 0, 318768040, 0, 0, 0, 603979808, 0, 0, 0, 318768041, 0, 0, 0, 603979808, 0, 0, 0, 318768042, 0, 0, 0, 603979808, 0, 0, 0, 318768043, 0, 0, 0, 603979808, 0, 0, 0, 318768044, 0, 0, 0, 335609818, 0, 0, 0, 318768045, 0, 0, 0, 335609819, 0, 0, 0, 318768046, 0, 0, 0, 335609819, 0, 0, 0, 318768047, 0, 0, 0, 335609819, 0, 0, 0, 318768048, 0, 0, 0, 335544320, 0, 0, 0, 318768049, 0, 0, 0, 335609824, 0, 0, 0, 318768050, 0, 0, 0, 335609824, 0, 0, 0, 318768051, 0, 0, 0, 335609824, 0, 0, 0, 318768052, 0, 0, 0, 335609824, 0, 0, 0, 318768053, 0, 0, 0, 335609824, 0, 0, 0, 318768054, 0, 0, 0, 335609824, 0, 0, 0, 318768055, 0, 0, 0, 335609824, 0, 0, 0, 318768056, 0, 0, 0, 335609824, 0, 0, 0, 318768057, 0, 0, 0, 335609824, 0, 0, 0, 318768058, 0, 0, 0, 335609824, 0, 0, 0, 318768059, 0, 0, 0, 335609824, 0, 0, 0, 318768060, 0, 0, 0, 335609824, 0, 0, 0, 318768061, 0, 0, 0, 335609824, 0, 0, 0, 318768062, 0, 0, 0, 335609824, 0, 0, 0, 318768063, 0, 0, 0, 335609824, 0, 0, 0, 318768064, 0, 0, 0, 335609824, 0, 0, 0, 318768065, 0, 0, 0, 335609824, 0, 0, 0, 318768066, 0, 0, 0, 335609825, 0, 0, 0, 318768067, 0, 0, 0, 335609824, 0, 0, 0, 318768068, 0, 0, 0, 335609824, 0, 0, 0, 318768069, 0, 0, 0, 335609824, 0, 0, 0, 318768070, 0, 0, 0, 335609824, 0, 0, 0, 318768071, 0, 0, 0, 335609824, 0, 0, 0, 318768072, 0, 0, 0, 335609824, 0, 0, 0, 318768073, 0, 0, 0, 335609824, 0, 0, 0, 318768074, 0, 0, 0, 335609824, 0, 0, 0, 318768075, 0, 0, 0, 335609824, 0, 0, 0, 318768076, 0, 0, 0, 335609792, 0, 0, 0, 318768077, 0, 0, 0, 335609793, 0, 0, 0, 318768078, 0, 0, 0, 335609793, 0, 0, 0, 318768080, 0, 0, 0, 335609794, 0, 0, 0, 318768081, 0, 0, 0, 335609799, 0, 0, 0, 327156690, 0, 0, 0, 603979778, 0, 0, 0, 318768085, 0, 0, 0, 335609809, 0, 0, 0, 318768086, 0, 0, 0, 335609802, 0, 0, 0, 318768087, 0, 0, 0, 335544320, 0, 0, 0, 318768088, 0, 0, 0, 603979777, 0, 0, 0, 318768089, 0, 0, 0, 335609855, 0, 0, 0, 318768090, 0, 0, 0, 603979777, 0, 0, 0, 318768091, 0, 0, 0, 335609855, 0, 0, 0, 318768092, 0, 0, 0, 603979777, 0, 0, 0, 318768093, 0, 0, 0, 335609855, 0, 0, 0, 318768094, 0, 0, 0, 603979777, 0, 0, 0, 318768095, 0, 0, 0, 335609855, 0, 0, 0, 318768096, 0, 0, 0, 603979777, 0, 0, 0, 318768097, 0, 0, 0, 335609855, 0, 0, 0, 167773154, 0, 0, 0, 603979777, 0, 0, 0, 167773155, 0, 0, 0, 335609855, 0, 0, 0, 167773156, 0, 0, 0, 603979777, 0, 0, 0, 167773157, 0, 0, 0, 335609855, 0, 0, 0, 167773158, 0, 0, 0, 603979777, 0, 0, 0, 167773159, 0, 0, 0, 335609855, 0, 0, 0, 167773160, 0, 0, 0, 603979777, 0, 0, 0, 167773161, 0, 0, 0, 335609855, 0, 0, 0, 167773162, 0, 0, 0, 603979777, 0, 0, 0, 167773163, 0, 0, 0, 335609855, 0, 0, 0, 167773164, 0, 0, 0, 603979777, 0, 0, 0, 167773165, 0, 0, 0, 335609855, 0, 0, 0, 167773166, 0, 0, 0, 603979777, 0, 0, 0, 167773167, 0, 0, 0, 335609855, 0, 0, 0, 318768112, 0, 0, 0, 335609770, 0, 0, 0, 318768113, 0, 0, 0, 335609776, 0, 0, 0, 318768114, 0, 0, 0, 335544327, 0, 0, 0, 318768115, 0, 0, 0, 335544320, 0, 0, 0, 318768116, 0, 0, 0, 604045252, 0, 0, 0, 318768117, 0, 0, 0, 335609760, 0, 0, 0, 318768118, 0, 0, 0, 1677721600, 0, 0, 0, 318768119, 0, 0, 0, 603979777, 0, 0, 0, 318768120, 0, 0, 0, 335609855, 0, 0, 0, 318768121, 0, 0, 0, 604045305, 0, 0, 0, 318768122, 0, 0, 0, 603979777, 0, 0, 0, 318768123, 0, 0, 0, 335609855, 0, 0, 0, 318768124, 0, 0, 0, 335544320, 0, 0, 0, 327156733, 0, 0, 0, 603979778, 0, 0, 0, 201327616, 0, 0, 0, 603979856, 0, 0, 0, 201327617, 0, 0, 0, 603979856, 0, 0, 0, 201327618, 0, 0, 0, 603979856, 0, 0, 0, 201327619, 0, 0, 0, 603979856, 0, 0, 0, 201327620, 0, 0, 0, 603979856, 0, 0, 0, 201327621, 0, 0, 0, 603979856, 0, 0, 0, 201327622, 0, 0, 0, 603979856, 0, 0, 0, 201327623, 0, 0, 0, 603979856, 0, 0, 0, 201327624, 0, 0, 0, 603979856, 0, 0, 0, 201327625, 0, 0, 0, 603979856, 0, 0, 0, 201327626, 0, 0, 0, 603979856, 0, 0, 0, 201327627, 0, 0, 0, 603979856, 0, 0, 0, 201327628, 0, 0, 0, 603979856, 0, 0, 0, 201327629, 0, 0, 0, 603979856, 0, 0, 0, 201327630, 0, 0, 0, 603979856, 0, 0, 0, 201327631, 0, 0, 0, 603979856, 0, 0, 0, 201327632, 0, 0, 0, 603979808, 0, 0, 0, 201327633, 0, 0, 0, 603979808, 0, 0, 0, 201327634, 0, 0, 0, 603979808, 0, 0, 0, 201327635, 0, 0, 0, 603979808, 0, 0, 0, 201327636, 0, 0, 0, 603979808, 0, 0, 0, 201327637, 0, 0, 0, 603979808, 0, 0, 0, 201327638, 0, 0, 0, 603979808, 0, 0, 0, 201327639, 0, 0, 0, 603979808, 0, 0, 0, 201327640, 0, 0, 0, 603979808, 0, 0, 0, 201327641, 0, 0, 0, 603979808, 0, 0, 0, 201327642, 0, 0, 0, 603979808, 0, 0, 0, 201327643, 0, 0, 0, 603979808, 0, 0, 0, 201327644, 0, 0, 0, 603979808, 0, 0, 0, 201327645, 0, 0, 0, 603979808, 0, 0, 0, 201327646, 0, 0, 0, 603979808, 0, 0, 0, 201327647, 0, 0, 0, 603979808, 0, 0, 0, 201327648, 0, 0, 0, 603979808, 0, 0, 0, 201327649, 0, 0, 0, 603979808, 0, 0, 0, 201327650, 0, 0, 0, 603979808, 0, 0, 0, 201327651, 0, 0, 0, 603979808, 0, 0, 0, 201327652, 0, 0, 0, 603979808, 0, 0, 0, 201327653, 0, 0, 0, 603979808, 0, 0, 0, 201327654, 0, 0, 0, 603979808, 0, 0, 0, 201327655, 0, 0, 0, 603979808, 0, 0, 0, 201327656, 0, 0, 0, 603979808, 0, 0, 0, 201327657, 0, 0, 0, 603979808, 0, 0, 0, 201327658, 0, 0, 0, 603979808, 0, 0, 0, 201327659, 0, 0, 0, 603979808, 0, 0, 0, 201327660, 0, 0, 0, 603979808, 0, 0, 0, 201327661, 0, 0, 0, 603979808, 0, 0, 0, 201327662, 0, 0, 0, 603979808, 0, 0, 0, 201327663, 0, 0, 0, 603979808, 0, 0, 0, 201327664, 0, 0, 0, 335609824, 0, 0, 0, 201327665, 0, 0, 0, 335609824, 0, 0, 0, 201327666, 0, 0, 0, 335609824, 0, 0, 0, 201327667, 0, 0, 0, 335609824, 0, 0, 0, 201327668, 0, 0, 0, 335609824, 0, 0, 0, 201327669, 0, 0, 0, 335609824, 0, 0, 0, 201327670, 0, 0, 0, 335609824, 0, 0, 0, 201327671, 0, 0, 0, 335609824, 0, 0, 0, 201327672, 0, 0, 0, 335609824, 0, 0, 0, 201327673, 0, 0, 0, 335609824, 0, 0, 0, 201327674, 0, 0, 0, 335609824, 0, 0, 0, 201327675, 0, 0, 0, 335609824, 0, 0, 0, 201327676, 0, 0, 0, 335609824, 0, 0, 0, 201327677, 0, 0, 0, 335609824, 0, 0, 0, 201327678, 0, 0, 0, 335609824, 0, 0, 0, 201327679, 0, 0, 0, 335609824, 0, 0, 0, 201327680, 0, 0, 0, 335609824, 0, 0, 0, 201327681, 0, 0, 0, 335609824, 0, 0, 0, 201327682, 0, 0, 0, 335609824, 0, 0, 0, 201327683, 0, 0, 0, 335609824, 0, 0, 0, 201327684, 0, 0, 0, 335609824, 0, 0, 0, 201327685, 0, 0, 0, 335609824, 0, 0, 0, 201327686, 0, 0, 0, 335609824, 0, 0, 0, 201327687, 0, 0, 0, 335609824, 0, 0, 0, 201327688, 0, 0, 0, 335609824, 0, 0, 0, 201327689, 0, 0, 0, 335609824, 0, 0, 0, 201327690, 0, 0, 0, 335609824, 0, 0, 0, 201327691, 0, 0, 0, 335609824, 0, 0, 0, 201327692, 0, 0, 0, 335609824, 0, 0, 0, 201327693, 0, 0, 0, 335609824, 0, 0, 0, 201327694, 0, 0, 0, 335609824, 0, 0, 0, 201327695, 0, 0, 0, 335609824, 0, 0, 0, 201327696, 0, 0, 0, 335609776, 0, 0, 0, 201327697, 0, 0, 0, 335609776, 0, 0, 0, 201327698, 0, 0, 0, 335609776, 0, 0, 0, 201327699, 0, 0, 0, 335609776, 0, 0, 0, 201327700, 0, 0, 0, 335609776, 0, 0, 0, 201327701, 0, 0, 0, 335609776, 0, 0, 0, 201327702, 0, 0, 0, 335609776, 0, 0, 0, 201327703, 0, 0, 0, 335609776, 0, 0, 0, 201327704, 0, 0, 0, 335609776, 0, 0, 0, 201327705, 0, 0, 0, 335609776, 0, 0, 0, 201327706, 0, 0, 0, 335609776, 0, 0, 0, 201327707, 0, 0, 0, 335609776, 0, 0, 0, 201327708, 0, 0, 0, 335609776, 0, 0, 0, 201327709, 0, 0, 0, 335609776, 0, 0, 0, 201327710, 0, 0, 0, 335609776, 0, 0, 0, 201327711, 0, 0, 0, 335609776, 0, 0, 0, 201327712, 0, 0, 0, 603979777, 0, 0, 0, 201327713, 0, 0, 0, 335609855, 0, 0, 0, 201327714, 0, 0, 0, 603979777, 0, 0, 0, 201327715, 0, 0, 0, 335609855, 0, 0, 0, 201327716, 0, 0, 0, 603979777, 0, 0, 0, 201327717, 0, 0, 0, 335609855, 0, 0, 0, 201327718, 0, 0, 0, 603979777, 0, 0, 0, 201327719, 0, 0, 0, 335609855, 0, 0, 0, 201327720, 0, 0, 0, 603979777, 0, 0, 0, 201327721, 0, 0, 0, 335609855, 0, 0, 0, 201327722, 0, 0, 0, 603979777, 0, 0, 0, 201327723, 0, 0, 0, 335609855, 0, 0, 0, 201327724, 0, 0, 0, 603979777, 0, 0, 0, 201327725, 0, 0, 0, 335609855, 0, 0, 0, 201327726, 0, 0, 0, 603979777, 0, 0, 0, 201327727, 0, 0, 0, 335609855, 0, 0, 0, 201327728, 0, 0, 0, 603979777, 0, 0, 0, 201327729, 0, 0, 0, 335609855, 0, 0, 0, 201327730, 0, 0, 0, 603979777, 0, 0, 0, 201327731, 0, 0, 0, 335609855, 0, 0, 0, 201327732, 0, 0, 0, 603979777, 0, 0, 0, 201327733, 0, 0, 0, 335609855, 0, 0, 0, 201327734, 0, 0, 0, 603979777, 0, 0, 0, 201327735, 0, 0, 0, 335609855, 0, 0, 0, 201327736, 0, 0, 0, 603979777, 0, 0, 0, 201327737, 0, 0, 0, 335609855, 0, 0, 0, 201327738, 0, 0, 0, 603979777, 0, 0, 0, 201327739, 0, 0, 0, 335609855, 0, 0, 0, 201327740, 0, 0, 0, 603979777, 0, 0, 0, 201327741, 0, 0, 0, 335609855, 0, 0, 0, 201327742, 0, 0, 0, 603979777, 0, 0, 0, 201327743, 0, 0, 0, 335609855, 0, 0, 0, 201327744, 0, 0, 0, 603979777, 0, 0, 0, 201327745, 0, 0, 0, 335609855, 0, 0, 0, 201327746, 0, 0, 0, 1744830464, 0, 0, 0, 209716355, 0, 0, 0, 805306371, 0, 0, 0, 209716360, 0, 0, 0, 738197505, 0, 0, 0, 201327754, 0, 0, 0, 603979777, 0, 0, 0, 201327755, 0, 0, 0, 335609855, 0, 0, 0, 201327756, 0, 0, 0, 603979777, 0, 0, 0, 201327757, 0, 0, 0, 335609855, 0, 0, 0, 201327758, 0, 0, 0, 603979777, 0, 0, 0, 201327759, 0, 0, 0, 335609855, 0, 0, 0, 201327760, 0, 0, 0, 603979777, 0, 0, 0, 201327761, 0, 0, 0, 335609855, 0, 0, 0, 201327762, 0, 0, 0, 603979777, 0, 0, 0, 201327763, 0, 0, 0, 335609855, 0, 0, 0, 201327764, 0, 0, 0, 603979777, 0, 0, 0, 201327765, 0, 0, 0, 335609855, 0, 0, 0, 201327766, 0, 0, 0, 603979777, 0, 0, 0, 201327767, 0, 0, 0, 335609855, 0, 0, 0, 201327768, 0, 0, 0, 603979777, 0, 0, 0, 201327769, 0, 0, 0, 335609855, 0, 0, 0, 201327770, 0, 0, 0, 603979777, 0, 0, 0, 201327771, 0, 0, 0, 335609855, 0, 0, 0, 201327772, 0, 0, 0, 603979777, 0, 0, 0, 201327773, 0, 0, 0, 335609855, 0, 0, 0, 201327774, 0, 0, 0, 603979777, 0, 0, 0, 201327775, 0, 0, 0, 335609855, 0, 0, 0, 201327776, 0, 0, 0, 603979777, 0, 0, 0, 201327777, 0, 0, 0, 335609855, 0, 0, 0, 201327778, 0, 0, 0, 603979777, 0, 0, 0, 201327779, 0, 0, 0, 335609855, 0, 0, 0, 201327780, 0, 0, 0, 603979777, 0, 0, 0, 201327781, 0, 0, 0, 335609855, 0, 0, 0, 201327782, 0, 0, 0, 603979777, 0, 0, 0, 201327783, 0, 0, 0, 335609855, 0, 0, 0, 201327784, 0, 0, 0, 603979777, 0, 0, 0, 201327785, 0, 0, 0, 335609855, 0, 0, 0, 201327786, 0, 0, 0, 603979777, 0, 0, 0, 201327787, 0, 0, 0, 335609855, 0, 0, 0, 201327788, 0, 0, 0, 603979777, 0, 0, 0, 201327789, 0, 0, 0, 335609855, 0, 0, 0, 201327790, 0, 0, 0, 603979777, 0, 0, 0, 201327791, 0, 0, 0, 335609855, 0, 0, 0, 201327792, 0, 0, 0, 603979777, 0, 0, 0, 201327793, 0, 0, 0, 335609855, 0, 0, 0, 201327794, 0, 0, 0, 603979777, 0, 0, 0, 201327795, 0, 0, 0, 335609855, 0, 0, 0, 201327796, 0, 0, 0, 603979777, 0, 0, 0, 201327797, 0, 0, 0, 335609855, 0, 0, 0, 201327798, 0, 0, 0, 603979777, 0, 0, 0, 201327799, 0, 0, 0, 335609855, 0, 0, 0, 201327800, 0, 0, 0, 603979777, 0, 0, 0, 201327801, 0, 0, 0, 335609855, 0, 0, 0, 201327802, 0, 0, 0, 603979777, 0, 0, 0, 201327803, 0, 0, 0, 335609855, 0, 0, 0, 201327804, 0, 0, 0, 603979777, 0, 0, 0, 201327805, 0, 0, 0, 335609855, 0, 0, 0, 201327806, 0, 0, 0, 603979777, 0, 0, 0, 201327807, 0, 0, 0, 335609855, 0, 0, 0, 201327808, 0, 0, 0, 603979776, 0, 0, 0, 201327809, 0, 0, 0, 603979777, 0, 0, 0, 201327810, 0, 0, 0, 335609855, 0, 0, 0, 201327811, 0, 0, 0, 603979777, 0, 0, 0, 201327812, 0, 0, 0, 335609855, 0, 0, 0, 201327813, 0, 0, 0, 603979777, 0, 0, 0, 201327814, 0, 0, 0, 335609855, 0, 0, 0, 201327815, 0, 0, 0, 603979777, 0, 0, 0, 201327816, 0, 0, 0, 335609855, 0, 0, 0, 201327817, 0, 0, 0, 603979777, 0, 0, 0, 201327818, 0, 0, 0, 335609855, 0, 0, 0, 201327819, 0, 0, 0, 603979777, 0, 0, 0, 201327820, 0, 0, 0, 335609855, 0, 0, 0, 201327821, 0, 0, 0, 603979777, 0, 0, 0, 201327822, 0, 0, 0, 335609855, 0, 0, 0, 201327824, 0, 0, 0, 603979777, 0, 0, 0, 201327825, 0, 0, 0, 335609855, 0, 0, 0, 201327826, 0, 0, 0, 603979777, 0, 0, 0, 201327827, 0, 0, 0, 335609855, 0, 0, 0, 201327828, 0, 0, 0, 603979777, 0, 0, 0, 201327829, 0, 0, 0, 335609855, 0, 0, 0, 201327830, 0, 0, 0, 603979777, 0, 0, 0, 201327831, 0, 0, 0, 335609855, 0, 0, 0, 201327832, 0, 0, 0, 603979777, 0, 0, 0, 201327833, 0, 0, 0, 335609855, 0, 0, 0, 201327834, 0, 0, 0, 603979777, 0, 0, 0, 201327835, 0, 0, 0, 335609855, 0, 0, 0, 201327836, 0, 0, 0, 603979777, 0, 0, 0, 201327837, 0, 0, 0, 335609855, 0, 0, 0, 201327838, 0, 0, 0, 603979777, 0, 0, 0, 201327839, 0, 0, 0, 335609855, 0, 0, 0, 201327840, 0, 0, 0, 603979777, 0, 0, 0, 201327841, 0, 0, 0, 335609855, 0, 0, 0, 201327842, 0, 0, 0, 603979777, 0, 0, 0, 201327843, 0, 0, 0, 335609855, 0, 0, 0, 201327844, 0, 0, 0, 603979777, 0, 0, 0, 201327845, 0, 0, 0, 335609855, 0, 0, 0, 201327846, 0, 0, 0, 603979777, 0, 0, 0, 201327847, 0, 0, 0, 335609855, 0, 0, 0, 201327848, 0, 0, 0, 603979777, 0, 0, 0, 201327849, 0, 0, 0, 335609855, 0, 0, 0, 201327850, 0, 0, 0, 603979777, 0, 0, 0, 201327851, 0, 0, 0, 335609855, 0, 0, 0, 201327852, 0, 0, 0, 603979777, 0, 0, 0, 201327853, 0, 0, 0, 335609855, 0, 0, 0, 201327854, 0, 0, 0, 603979777, 0, 0, 0, 201327855, 0, 0, 0, 335609855, 0, 0, 0, 201327856, 0, 0, 0, 603979777, 0, 0, 0, 201327857, 0, 0, 0, 335609855, 0, 0, 0, 201327858, 0, 0, 0, 603979777, 0, 0, 0, 201327859, 0, 0, 0, 335609855, 0, 0, 0, 201327860, 0, 0, 0, 603979777, 0, 0, 0, 201327861, 0, 0, 0, 335609855, 0, 0, 0, 201327862, 0, 0, 0, 603979777, 0, 0, 0, 201327863, 0, 0, 0, 335609855, 0, 0, 0, 201327864, 0, 0, 0, 603979777, 0, 0, 0, 201327865, 0, 0, 0, 335609855, 0, 0, 0, 201327872, 0, 0, 0, 603979777, 0, 0, 0, 201327873, 0, 0, 0, 335609855, 0, 0, 0, 201327874, 0, 0, 0, 603979777, 0, 0, 0, 201327875, 0, 0, 0, 335609855, 0, 0, 0, 201327876, 0, 0, 0, 603979777, 0, 0, 0, 201327877, 0, 0, 0, 335609855, 0, 0, 0, 201327878, 0, 0, 0, 603979777, 0, 0, 0, 201327879, 0, 0, 0, 335609855, 0, 0, 0, 201327880, 0, 0, 0, 603979777, 0, 0, 0, 201327881, 0, 0, 0, 335609855, 0, 0, 0, 201327882, 0, 0, 0, 603979777, 0, 0, 0, 201327883, 0, 0, 0, 335609855, 0, 0, 0, 201327884, 0, 0, 0, 603979777, 0, 0, 0, 201327885, 0, 0, 0, 335609855, 0, 0, 0, 201327886, 0, 0, 0, 603979777, 0, 0, 0, 201327887, 0, 0, 0, 335609855, 0, 0, 0, 16778545, 0, 0, 0, 603979824, 0, 0, 0, 16778546, 0, 0, 0, 603979824, 0, 0, 0, 16778547, 0, 0, 0, 603979824, 0, 0, 0, 16778548, 0, 0, 0, 603979824, 0, 0, 0, 16778549, 0, 0, 0, 603979824, 0, 0, 0, 16778550, 0, 0, 0, 603979824, 0, 0, 0, 16778551, 0, 0, 0, 603979824, 0, 0, 0, 16778552, 0, 0, 0, 603979824, 0, 0, 0, 16778553, 0, 0, 0, 603979824, 0, 0, 0, 16778554, 0, 0, 0, 603979824, 0, 0, 0, 16778555, 0, 0, 0, 603979824, 0, 0, 0, 16778556, 0, 0, 0, 603979824, 0, 0, 0, 16778557, 0, 0, 0, 603979824, 0, 0, 0, 16778558, 0, 0, 0, 603979824, 0, 0, 0, 16778559, 0, 0, 0, 603979824, 0, 0, 0, 16778560, 0, 0, 0, 603979824, 0, 0, 0, 16778561, 0, 0, 0, 603979824, 0, 0, 0, 16778562, 0, 0, 0, 603979824, 0, 0, 0, 16778563, 0, 0, 0, 603979824, 0, 0, 0, 16778564, 0, 0, 0, 603979824, 0, 0, 0, 16778565, 0, 0, 0, 603979824, 0, 0, 0, 16778566, 0, 0, 0, 603979824, 0, 0, 0, 16778567, 0, 0, 0, 603979824, 0, 0, 0, 16778568, 0, 0, 0, 603979824, 0, 0, 0, 16778569, 0, 0, 0, 603979824, 0, 0, 0, 16778570, 0, 0, 0, 603979824, 0, 0, 0, 16778571, 0, 0, 0, 603979824, 0, 0, 0, 16778572, 0, 0, 0, 603979824, 0, 0, 0, 16778573, 0, 0, 0, 603979824, 0, 0, 0, 16778574, 0, 0, 0, 603979824, 0, 0, 0, 16778575, 0, 0, 0, 603979824, 0, 0, 0, 16778576, 0, 0, 0, 603979824, 0, 0, 0, 16778577, 0, 0, 0, 603979824, 0, 0, 0, 16778578, 0, 0, 0, 603979824, 0, 0, 0, 16778579, 0, 0, 0, 603979824, 0, 0, 0, 16778580, 0, 0, 0, 603979824, 0, 0, 0, 16778581, 0, 0, 0, 603979824, 0, 0, 0, 16778582, 0, 0, 0, 603979824, 0, 0, 0, 16778585, 0, 0, 0, 402653184, 0, 0, 0, 25167194, 0, 0, 0, 1409286149, 0, 0, 0, 16778593, 0, 0, 0, 335609808, 0, 0, 0, 16778594, 0, 0, 0, 335609808, 0, 0, 0, 16778595, 0, 0, 0, 335609808, 0, 0, 0, 16778596, 0, 0, 0, 335609808, 0, 0, 0, 16778597, 0, 0, 0, 335609808, 0, 0, 0, 16778598, 0, 0, 0, 335609808, 0, 0, 0, 16778599, 0, 0, 0, 335609808, 0, 0, 0, 16778600, 0, 0, 0, 335609808, 0, 0, 0, 16778601, 0, 0, 0, 335609808, 0, 0, 0, 16778602, 0, 0, 0, 335609808, 0, 0, 0, 16778603, 0, 0, 0, 335609808, 0, 0, 0, 16778604, 0, 0, 0, 335609808, 0, 0, 0, 16778605, 0, 0, 0, 335609808, 0, 0, 0, 16778606, 0, 0, 0, 335609808, 0, 0, 0, 16778607, 0, 0, 0, 335609808, 0, 0, 0, 16778608, 0, 0, 0, 335609808, 0, 0, 0, 16778609, 0, 0, 0, 335609808, 0, 0, 0, 16778610, 0, 0, 0, 335609808, 0, 0, 0, 16778611, 0, 0, 0, 335609808, 0, 0, 0, 16778612, 0, 0, 0, 335609808, 0, 0, 0, 16778613, 0, 0, 0, 335609808, 0, 0, 0, 16778614, 0, 0, 0, 335609808, 0, 0, 0, 16778615, 0, 0, 0, 335609808, 0, 0, 0, 16778616, 0, 0, 0, 335609808, 0, 0, 0, 16778617, 0, 0, 0, 335609808, 0, 0, 0, 16778618, 0, 0, 0, 335609808, 0, 0, 0, 16778619, 0, 0, 0, 335609808, 0, 0, 0, 16778620, 0, 0, 0, 335609808, 0, 0, 0, 16778621, 0, 0, 0, 335609808, 0, 0, 0, 16778622, 0, 0, 0, 335609808, 0, 0, 0, 16778623, 0, 0, 0, 335609808, 0, 0, 0, 16778624, 0, 0, 0, 335609808, 0, 0, 0, 16778625, 0, 0, 0, 335609808, 0, 0, 0, 16778626, 0, 0, 0, 335609808, 0, 0, 0, 16778627, 0, 0, 0, 335609808, 0, 0, 0, 16778628, 0, 0, 0, 335609808, 0, 0, 0, 16778629, 0, 0, 0, 335609808, 0, 0, 0, 16778630, 0, 0, 0, 335609808, 0, 0, 0, 16778631, 0, 0, 0, 335544320, 0, 0, 0, 150996361, 0, 0, 0, 1409286144, 0, 0, 0, 16778634, 0, 0, 0, 1140850688, 0, 0, 0, 427820433, 0, 0, 0, 805306408, 0, 0, 0, 427820475, 0, 0, 0, 805306370, 0, 0, 0, 419431870, 0, 0, 0, 1409286144, 0, 0, 0, 419431871, 0, 0, 0, 805306368, 0, 0, 0, 419431872, 0, 0, 0, 1409286144, 0, 0, 0, 427820481, 0, 0, 0, 805306369, 0, 0, 0, 419431875, 0, 0, 0, 1409286144, 0, 0, 0, 427820484, 0, 0, 0, 805306369, 0, 0, 0, 419431878, 0, 0, 0, 1409286144, 0, 0, 0, 419431879, 0, 0, 0, 805306368, 0, 0, 0, 427820496, 0, 0, 0, 469762074, 0, 0, 0, 427820528, 0, 0, 0, 469762050, 0, 0, 0, 427820531, 0, 0, 0, 1409286145, 0, 0, 0, 159385088, 0, 0, 0, 67108867, 0, 0, 0, 1547, 0, 0, 0, 1543503872, 0, 0, 0, 159385100, 0, 0, 0, 1409286145, 0, 0, 0, 8390158, 0, 0, 0, 1744830465, 0, 0, 0, 8390160, 0, 0, 0, 805306373, 0, 0, 0, 150996507, 0, 0, 0, 1409286144, 0, 0, 0, 8390174, 0, 0, 0, 1409286145, 0, 0, 0, 8390177, 0, 0, 0, 469762073, 0, 0, 0, 150996544, 0, 0, 0, 402653184, 0, 0, 0, 8390209, 0, 0, 0, 469762057, 0, 0, 0, 461375051, 0, 0, 0, 805306387, 0, 0, 0, 159385184, 0, 0, 0, 872415241, 0, 0, 0, 8390250, 0, 0, 0, 1409286147, 0, 0, 0, 8390254, 0, 0, 0, 469762049, 0, 0, 0, 452986480, 0, 0, 0, 805306368, 0, 0, 0, 8390257, 0, 0, 0, 469762146, 0, 0, 0, 1748, 0, 0, 0, 1409286144, 0, 0, 0, 1749, 0, 0, 0, 469762048, 0, 0, 0, 8390358, 0, 0, 0, 805306374, 0, 0, 0, 150996701, 0, 0, 0, 67108864, 0, 0, 0, 1758, 0, 0, 0, 738197504, 0, 0, 0, 8390367, 0, 0, 0, 805306373, 0, 0, 0, 8390373, 0, 0, 0, 402653185, 0, 0, 0, 8390375, 0, 0, 0, 805306369, 0, 0, 0, 1769, 0, 0, 0, 1744830464, 0, 0, 0, 8390378, 0, 0, 0, 805306371, 0, 0, 0, 8390382, 0, 0, 0, 469762049, 0, 0, 0, 8390384, 0, 0, 0, 872415241, 0, 0, 0, 8390394, 0, 0, 0, 469762050, 0, 0, 0, 8390397, 0, 0, 0, 1744830465, 0, 0, 0, 1791, 0, 0, 0, 469762048, 0, 0, 0, 830473984, 0, 0, 0, 1409286157, 0, 0, 0, 822085391, 0, 0, 0, 67108864, 0, 0, 0, 822085392, 0, 0, 0, 469762048, 0, 0, 0, 822085393, 0, 0, 0, 805306368, 0, 0, 0, 830474002, 0, 0, 0, 469762077, 0, 0, 0, 830474032, 0, 0, 0, 805306394, 0, 0, 0, 830474061, 0, 0, 0, 469762080, 0, 0, 0, 931137408, 0, 0, 0, 469762085, 0, 0, 0, 931137446, 0, 0, 0, 805306378, 0, 0, 0, 922748849, 0, 0, 0, 469762048, 0, 0, 0, 243271937, 0, 0, 0, 805306369, 0, 0, 0, 234883331, 0, 0, 0, 671088640, 0, 0, 0, 243271940, 0, 0, 0, 469762101, 0, 0, 0, 234883388, 0, 0, 0, 805306368, 0, 0, 0, 234883389, 0, 0, 0, 469762048, 0, 0, 0, 243271998, 0, 0, 0, 671088642, 0, 0, 0, 243272001, 0, 0, 0, 805306375, 0, 0, 0, 243272009, 0, 0, 0, 671088643, 0, 0, 0, 234883405, 0, 0, 0, 805306368, 0, 0, 0, 234883408, 0, 0, 0, 469762048, 0, 0, 0, 243272017, 0, 0, 0, 805306371, 0, 0, 0, 243272024, 0, 0, 0, 469762057, 0, 0, 0, 243272034, 0, 0, 0, 805306369, 0, 0, 0, 159385956, 0, 0, 0, 1409286145, 0, 0, 0, 243272038, 0, 0, 0, 872415241, 0, 0, 0, 150997360, 0, 0, 0, 1409286144, 0, 0, 0, 234883453, 0, 0, 0, 469762048, 0, 0, 0, 33556865, 0, 0, 0, 805306368, 0, 0, 0, 41945474, 0, 0, 0, 671088641, 0, 0, 0, 41945477, 0, 0, 0, 469762055, 0, 0, 0, 41945487, 0, 0, 0, 469762049, 0, 0, 0, 41945491, 0, 0, 0, 469762069, 0, 0, 0, 41945514, 0, 0, 0, 469762054, 0, 0, 0, 33556914, 0, 0, 0, 469762048, 0, 0, 0, 41945526, 0, 0, 0, 469762051, 0, 0, 0, 33556924, 0, 0, 0, 805306368, 0, 0, 0, 33556925, 0, 0, 0, 469762048, 0, 0, 0, 41945534, 0, 0, 0, 671088642, 0, 0, 0, 41945537, 0, 0, 0, 805306371, 0, 0, 0, 41945543, 0, 0, 0, 671088641, 0, 0, 0, 41945547, 0, 0, 0, 671088641, 0, 0, 0, 33556941, 0, 0, 0, 805306368, 0, 0, 0, 33556942, 0, 0, 0, 469762048, 0, 0, 0, 33556951, 0, 0, 0, 671088640, 0, 0, 0, 41945564, 0, 0, 0, 469762049, 0, 0, 0, 41945567, 0, 0, 0, 469762050, 0, 0, 0, 41945570, 0, 0, 0, 805306369, 0, 0, 0, 41945574, 0, 0, 0, 872415241, 0, 0, 0, 41945584, 0, 0, 0, 469762049, 0, 0, 0, 41945586, 0, 0, 0, 1543503873, 0, 0, 0, 41945588, 0, 0, 0, 1006632965, 0, 0, 0, 33556986, 0, 0, 0, 1744830464, 0, 0, 0, 360712705, 0, 0, 0, 805306369, 0, 0, 0, 352324099, 0, 0, 0, 671088640, 0, 0, 0, 360712709, 0, 0, 0, 469762053, 0, 0, 0, 360712719, 0, 0, 0, 469762049, 0, 0, 0, 360712723, 0, 0, 0, 469762069, 0, 0, 0, 360712746, 0, 0, 0, 469762054, 0, 0, 0, 360712754, 0, 0, 0, 469762049, 0, 0, 0, 360712757, 0, 0, 0, 469762049, 0, 0, 0, 360712760, 0, 0, 0, 469762049, 0, 0, 0, 352324156, 0, 0, 0, 805306368, 0, 0, 0, 360712766, 0, 0, 0, 671088642, 0, 0, 0, 360712769, 0, 0, 0, 805306369, 0, 0, 0, 360712775, 0, 0, 0, 805306369, 0, 0, 0, 360712779, 0, 0, 0, 805306370, 0, 0, 0, 360712793, 0, 0, 0, 469762051, 0, 0, 0, 352324190, 0, 0, 0, 469762048, 0, 0, 0, 360712806, 0, 0, 0, 872415241, 0, 0, 0, 360712816, 0, 0, 0, 805306369, 0, 0, 0, 360712818, 0, 0, 0, 469762050, 0, 0, 0, 343935617, 0, 0, 0, 805306369, 0, 0, 0, 335547011, 0, 0, 0, 671088640, 0, 0, 0, 343935621, 0, 0, 0, 469762056, 0, 0, 0, 343935631, 0, 0, 0, 469762050, 0, 0, 0, 343935635, 0, 0, 0, 469762069, 0, 0, 0, 343935658, 0, 0, 0, 469762054, 0, 0, 0, 343935666, 0, 0, 0, 469762049, 0, 0, 0, 343935669, 0, 0, 0, 469762052, 0, 0, 0, 335547068, 0, 0, 0, 805306368, 0, 0, 0, 335547069, 0, 0, 0, 469762048, 0, 0, 0, 343935678, 0, 0, 0, 671088642, 0, 0, 0, 343935681, 0, 0, 0, 805306372, 0, 0, 0, 343935687, 0, 0, 0, 805306369, 0, 0, 0, 335547081, 0, 0, 0, 671088640, 0, 0, 0, 343935691, 0, 0, 0, 671088641, 0, 0, 0, 335547085, 0, 0, 0, 805306368, 0, 0, 0, 335547088, 0, 0, 0, 469762048, 0, 0, 0, 343935712, 0, 0, 0, 469762049, 0, 0, 0, 343935714, 0, 0, 0, 805306369, 0, 0, 0, 343935718, 0, 0, 0, 872415241, 0, 0, 0, 335547121, 0, 0, 0, 1543503872, 0, 0, 0, 721423105, 0, 0, 0, 805306368, 0, 0, 0, 729811714, 0, 0, 0, 671088641, 0, 0, 0, 729811717, 0, 0, 0, 469762055, 0, 0, 0, 729811727, 0, 0, 0, 469762049, 0, 0, 0, 729811731, 0, 0, 0, 469762069, 0, 0, 0, 729811754, 0, 0, 0, 469762054, 0, 0, 0, 729811762, 0, 0, 0, 469762049, 0, 0, 0, 729811765, 0, 0, 0, 469762052, 0, 0, 0, 721423164, 0, 0, 0, 805306368, 0, 0, 0, 721423165, 0, 0, 0, 469762048, 0, 0, 0, 721423166, 0, 0, 0, 671088640, 0, 0, 0, 721423167, 0, 0, 0, 805306368, 0, 0, 0, 721423168, 0, 0, 0, 671088640, 0, 0, 0, 729811777, 0, 0, 0, 805306370, 0, 0, 0, 729811783, 0, 0, 0, 671088641, 0, 0, 0, 729811787, 0, 0, 0, 671088641, 0, 0, 0, 721423181, 0, 0, 0, 805306368, 0, 0, 0, 721423190, 0, 0, 0, 805306368, 0, 0, 0, 721423191, 0, 0, 0, 671088640, 0, 0, 0, 729811804, 0, 0, 0, 469762049, 0, 0, 0, 729811807, 0, 0, 0, 469762050, 0, 0, 0, 729811814, 0, 0, 0, 872415241, 0, 0, 0, 721423216, 0, 0, 0, 1744830464, 0, 0, 0, 721423217, 0, 0, 0, 469762048, 0, 0, 0, 889195394, 0, 0, 0, 805306368, 0, 0, 0, 889195395, 0, 0, 0, 469762048, 0, 0, 0, 897584005, 0, 0, 0, 469762053, 0, 0, 0, 897584014, 0, 0, 0, 469762050, 0, 0, 0, 897584018, 0, 0, 0, 469762051, 0, 0, 0, 897584025, 0, 0, 0, 469762049, 0, 0, 0, 889195420, 0, 0, 0, 469762048, 0, 0, 0, 897584030, 0, 0, 0, 469762049, 0, 0, 0, 897584035, 0, 0, 0, 469762049, 0, 0, 0, 897584040, 0, 0, 0, 469762050, 0, 0, 0, 897584046, 0, 0, 0, 469762059, 0, 0, 0, 897584062, 0, 0, 0, 671088641, 0, 0, 0, 889195456, 0, 0, 0, 805306368, 0, 0, 0, 897584065, 0, 0, 0, 671088641, 0, 0, 0, 897584070, 0, 0, 0, 671088642, 0, 0, 0, 897584074, 0, 0, 0, 671088642, 0, 0, 0, 889195469, 0, 0, 0, 805306368, 0, 0, 0, 889195479, 0, 0, 0, 671088640, 0, 0, 0, 897584102, 0, 0, 0, 872415241, 0, 0, 0, 897584112, 0, 0, 0, 1006632962, 0, 0, 0, 897584115, 0, 0, 0, 1744830469, 0, 0, 0, 889195513, 0, 0, 0, 1543503872, 0, 0, 0, 889195514, 0, 0, 0, 1744830464, 0, 0, 0, 914361345, 0, 0, 0, 671088642, 0, 0, 0, 914361349, 0, 0, 0, 469762055, 0, 0, 0, 914361358, 0, 0, 0, 469762050, 0, 0, 0, 914361362, 0, 0, 0, 469762070, 0, 0, 0, 914361386, 0, 0, 0, 469762057, 0, 0, 0, 914361397, 0, 0, 0, 469762052, 0, 0, 0, 914361406, 0, 0, 0, 805306370, 0, 0, 0, 914361409, 0, 0, 0, 671088643, 0, 0, 0, 914361414, 0, 0, 0, 805306370, 0, 0, 0, 914361418, 0, 0, 0, 805306371, 0, 0, 0, 914361429, 0, 0, 0, 805306369, 0, 0, 0, 914361440, 0, 0, 0, 469762049, 0, 0, 0, 914361446, 0, 0, 0, 872415241, 0, 0, 0, 478153858, 0, 0, 0, 671088641, 0, 0, 0, 478153861, 0, 0, 0, 469762055, 0, 0, 0, 478153870, 0, 0, 0, 469762050, 0, 0, 0, 478153874, 0, 0, 0, 469762070, 0, 0, 0, 478153898, 0, 0, 0, 469762057, 0, 0, 0, 478153909, 0, 0, 0, 469762052, 0, 0, 0, 469765308, 0, 0, 0, 805306368, 0, 0, 0, 469765309, 0, 0, 0, 469762048, 0, 0, 0, 469765310, 0, 0, 0, 671088640, 0, 0, 0, 469765311, 0, 0, 0, 805306368, 0, 0, 0, 478153920, 0, 0, 0, 671088644, 0, 0, 0, 469765318, 0, 0, 0, 805306368, 0, 0, 0, 478153927, 0, 0, 0, 671088641, 0, 0, 0, 478153930, 0, 0, 0, 671088641, 0, 0, 0, 478153932, 0, 0, 0, 805306369, 0, 0, 0, 478153941, 0, 0, 0, 671088641, 0, 0, 0, 469765342, 0, 0, 0, 469762048, 0, 0, 0, 478153952, 0, 0, 0, 469762049, 0, 0, 0, 478153958, 0, 0, 0, 872415241, 0, 0, 0, 612371714, 0, 0, 0, 671088641, 0, 0, 0, 612371717, 0, 0, 0, 469762055, 0, 0, 0, 612371726, 0, 0, 0, 469762050, 0, 0, 0, 612371730, 0, 0, 0, 469762070, 0, 0, 0, 612371754, 0, 0, 0, 469762063, 0, 0, 0, 612371774, 0, 0, 0, 671088642, 0, 0, 0, 612371777, 0, 0, 0, 805306370, 0, 0, 0, 612371782, 0, 0, 0, 671088642, 0, 0, 0, 612371786, 0, 0, 0, 671088642, 0, 0, 0, 603983181, 0, 0, 0, 805306368, 0, 0, 0, 603983191, 0, 0, 0, 671088640, 0, 0, 0, 612371808, 0, 0, 0, 469762049, 0, 0, 0, 612371814, 0, 0, 0, 872415241, 0, 0, 0, 796921218, 0, 0, 0, 671088641, 0, 0, 0, 796921221, 0, 0, 0, 469762065, 0, 0, 0, 796921242, 0, 0, 0, 469762071, 0, 0, 0, 796921267, 0, 0, 0, 469762056, 0, 0, 0, 788532669, 0, 0, 0, 469762048, 0, 0, 0, 796921280, 0, 0, 0, 469762054, 0, 0, 0, 788532682, 0, 0, 0, 805306368, 0, 0, 0, 796921295, 0, 0, 0, 671088642, 0, 0, 0, 796921298, 0, 0, 0, 805306370, 0, 0, 0, 788532694, 0, 0, 0, 805306368, 0, 0, 0, 796921304, 0, 0, 0, 671088647, 0, 0, 0, 796921330, 0, 0, 0, 671088641, 0, 0, 0, 788532724, 0, 0, 0, 1409286144, 0, 0, 0, 947916289, 0, 0, 0, 469762095, 0, 0, 0, 939527729, 0, 0, 0, 805306368, 0, 0, 0, 947916338, 0, 0, 0, 469762049, 0, 0, 0, 947916340, 0, 0, 0, 805306374, 0, 0, 0, 150998591, 0, 0, 0, 1543503872, 0, 0, 0, 947916352, 0, 0, 0, 469762053, 0, 0, 0, 939527750, 0, 0, 0, 402653184, 0, 0, 0, 947916359, 0, 0, 0, 805306375, 0, 0, 0, 939527759, 0, 0, 0, 1409286144, 0, 0, 0, 947916368, 0, 0, 0, 872415241, 0, 0, 0, 947916378, 0, 0, 0, 1409286145, 0, 0, 0, 545263233, 0, 0, 0, 469762049, 0, 0, 0, 536874628, 0, 0, 0, 469762048, 0, 0, 0, 545263239, 0, 0, 0, 469762049, 0, 0, 0, 536874634, 0, 0, 0, 469762048, 0, 0, 0, 536874637, 0, 0, 0, 469762048, 0, 0, 0, 545263252, 0, 0, 0, 469762051, 0, 0, 0, 545263257, 0, 0, 0, 469762054, 0, 0, 0, 545263265, 0, 0, 0, 469762050, 0, 0, 0, 536874661, 0, 0, 0, 469762048, 0, 0, 0, 536874663, 0, 0, 0, 469762048, 0, 0, 0, 545263274, 0, 0, 0, 469762049, 0, 0, 0, 545263277, 0, 0, 0, 469762051, 0, 0, 0, 536874673, 0, 0, 0, 805306368, 0, 0, 0, 545263282, 0, 0, 0, 469762049, 0, 0, 0, 545263284, 0, 0, 0, 805306373, 0, 0, 0, 545263291, 0, 0, 0, 805306369, 0, 0, 0, 536874685, 0, 0, 0, 469762048, 0, 0, 0, 545263296, 0, 0, 0, 469762052, 0, 0, 0, 536874694, 0, 0, 0, 402653184, 0, 0, 0, 545263304, 0, 0, 0, 805306373, 0, 0, 0, 545263312, 0, 0, 0, 872415241, 0, 0, 0, 545263324, 0, 0, 0, 469762049, 0, 0, 0, 956305152, 0, 0, 0, 469762048, 0, 0, 0, 964693761, 0, 0, 0, 1744830466, 0, 0, 0, 964693764, 0, 0, 0, 1409286158, 0, 0, 0, 964693779, 0, 0, 0, 1744830468, 0, 0, 0, 964693784, 0, 0, 0, 805306369, 0, 0, 0, 964693786, 0, 0, 0, 1744830469, 0, 0, 0, 964693792, 0, 0, 0, 872415241, 0, 0, 0, 964693802, 0, 0, 0, 1006632969, 0, 0, 0, 956305204, 0, 0, 0, 1744830464, 0, 0, 0, 956305205, 0, 0, 0, 805306368, 0, 0, 0, 956305206, 0, 0, 0, 1744830464, 0, 0, 0, 956305207, 0, 0, 0, 805306368, 0, 0, 0, 956305208, 0, 0, 0, 1744830464, 0, 0, 0, 956305209, 0, 0, 0, 805306368, 0, 0, 0, 956305210, 0, 0, 0, 1476395008, 0, 0, 0, 956305211, 0, 0, 0, 1207959552, 0, 0, 0, 956305212, 0, 0, 0, 1476395008, 0, 0, 0, 956305213, 0, 0, 0, 1207959552, 0, 0, 0, 964693822, 0, 0, 0, 671088641, 0, 0, 0, 964693824, 0, 0, 0, 469762055, 0, 0, 0, 964693833, 0, 0, 0, 469762081, 0, 0, 0, 964693873, 0, 0, 0, 805306381, 0, 0, 0, 956305279, 0, 0, 0, 671088640, 0, 0, 0, 964693888, 0, 0, 0, 805306372, 0, 0, 0, 956305285, 0, 0, 0, 1409286144, 0, 0, 0, 964693894, 0, 0, 0, 805306369, 0, 0, 0, 964693896, 0, 0, 0, 469762051, 0, 0, 0, 964693904, 0, 0, 0, 805306375, 0, 0, 0, 964693913, 0, 0, 0, 805306403, 0, 0, 0, 964693950, 0, 0, 0, 1744830471, 0, 0, 0, 956305350, 0, 0, 0, 805306368, 0, 0, 0, 964693959, 0, 0, 0, 1744830469, 0, 0, 0, 956305359, 0, 0, 0, 1744830464, 0, 0, 0, 964693968, 0, 0, 0, 1409286145, 0, 0, 0, 645926912, 0, 0, 0, 469762081, 0, 0, 0, 645926947, 0, 0, 0, 469762052, 0, 0, 0, 645926953, 0, 0, 0, 469762049, 0, 0, 0, 637538348, 0, 0, 0, 671088640, 0, 0, 0, 645926957, 0, 0, 0, 805306371, 0, 0, 0, 637538353, 0, 0, 0, 671088640, 0, 0, 0, 637538354, 0, 0, 0, 805306368, 0, 0, 0, 645926966, 0, 0, 0, 805306369, 0, 0, 0, 637538360, 0, 0, 0, 671088640, 0, 0, 0, 637538361, 0, 0, 0, 805306368, 0, 0, 0, 645926976, 0, 0, 0, 872415241, 0, 0, 0, 645926986, 0, 0, 0, 1409286149, 0, 0, 0, 645926992, 0, 0, 0, 469762053, 0, 0, 0, 645926998, 0, 0, 0, 671088641, 0, 0, 0, 645927e3, 0, 0, 0, 805306369, 0, 0, 0, 268439712, 0, 0, 0, 603987040, 0, 0, 0, 268439713, 0, 0, 0, 603987040, 0, 0, 0, 268439714, 0, 0, 0, 603987040, 0, 0, 0, 268439715, 0, 0, 0, 603987040, 0, 0, 0, 268439716, 0, 0, 0, 603987040, 0, 0, 0, 268439717, 0, 0, 0, 603987040, 0, 0, 0, 268439718, 0, 0, 0, 603987040, 0, 0, 0, 268439719, 0, 0, 0, 603987040, 0, 0, 0, 268439720, 0, 0, 0, 603987040, 0, 0, 0, 268439721, 0, 0, 0, 603987040, 0, 0, 0, 268439722, 0, 0, 0, 603987040, 0, 0, 0, 268439723, 0, 0, 0, 603987040, 0, 0, 0, 268439724, 0, 0, 0, 603987040, 0, 0, 0, 268439725, 0, 0, 0, 603987040, 0, 0, 0, 268439726, 0, 0, 0, 603987040, 0, 0, 0, 268439727, 0, 0, 0, 603987040, 0, 0, 0, 268439728, 0, 0, 0, 603987040, 0, 0, 0, 268439729, 0, 0, 0, 603987040, 0, 0, 0, 268439730, 0, 0, 0, 603987040, 0, 0, 0, 268439731, 0, 0, 0, 603987040, 0, 0, 0, 268439732, 0, 0, 0, 603987040, 0, 0, 0, 268439733, 0, 0, 0, 603987040, 0, 0, 0, 268439734, 0, 0, 0, 603987040, 0, 0, 0, 268439735, 0, 0, 0, 603987040, 0, 0, 0, 268439736, 0, 0, 0, 603987040, 0, 0, 0, 268439737, 0, 0, 0, 603987040, 0, 0, 0, 268439738, 0, 0, 0, 603987040, 0, 0, 0, 268439739, 0, 0, 0, 603987040, 0, 0, 0, 268439740, 0, 0, 0, 603987040, 0, 0, 0, 268439741, 0, 0, 0, 603987040, 0, 0, 0, 268439742, 0, 0, 0, 603987040, 0, 0, 0, 268439743, 0, 0, 0, 603987040, 0, 0, 0, 268439744, 0, 0, 0, 603987040, 0, 0, 0, 268439745, 0, 0, 0, 603987040, 0, 0, 0, 268439746, 0, 0, 0, 603987040, 0, 0, 0, 268439747, 0, 0, 0, 603987040, 0, 0, 0, 268439748, 0, 0, 0, 603987040, 0, 0, 0, 268439749, 0, 0, 0, 603987040, 0, 0, 0, 276828368, 0, 0, 0, 469762090, 0, 0, 0, 150999291, 0, 0, 0, 1409286144, 0, 0, 0, 268439804, 0, 0, 0, 402653184, 0, 0, 0, 394268928, 0, 0, 0, 469762137, 0, 0, 0, 394269023, 0, 0, 0, 469762115, 0, 0, 0, 394269096, 0, 0, 0, 469762129, 0, 0, 0, 260051456, 0, 0, 0, 469762120, 0, 0, 0, 260051530, 0, 0, 0, 469762051, 0, 0, 0, 260051536, 0, 0, 0, 469762054, 0, 0, 0, 251662936, 0, 0, 0, 469762048, 0, 0, 0, 260051546, 0, 0, 0, 469762051, 0, 0, 0, 260051552, 0, 0, 0, 469762088, 0, 0, 0, 260051594, 0, 0, 0, 469762051, 0, 0, 0, 260051600, 0, 0, 0, 469762080, 0, 0, 0, 260051634, 0, 0, 0, 469762051, 0, 0, 0, 260051640, 0, 0, 0, 469762054, 0, 0, 0, 251663040, 0, 0, 0, 469762048, 0, 0, 0, 260051650, 0, 0, 0, 469762051, 0, 0, 0, 260051656, 0, 0, 0, 469762062, 0, 0, 0, 260051672, 0, 0, 0, 469762104, 0, 0, 0, 260051730, 0, 0, 0, 469762051, 0, 0, 0, 260051736, 0, 0, 0, 469762114, 0, 0, 0, 251663199, 0, 0, 0, 805306368, 0, 0, 0, 251663200, 0, 0, 0, 1744830464, 0, 0, 0, 260051809, 0, 0, 0, 1409286151, 0, 0, 0, 260051817, 0, 0, 0, 1006632979, 0, 0, 0, 260051840, 0, 0, 0, 469762063, 0, 0, 0, 260051856, 0, 0, 0, 1744830473, 0, 0, 0, 142611360, 0, 0, 0, 469762132, 0, 0, 0, 125834241, 0, 0, 0, 469762667, 0, 0, 0, 125834861, 0, 0, 0, 1409286145, 0, 0, 0, 125834863, 0, 0, 0, 469762055, 0, 0, 0, 671094400, 0, 0, 0, 1946157056, 0, 0, 0, 679483009, 0, 0, 0, 469762073, 0, 0, 0, 671094427, 0, 0, 0, 1476395008, 0, 0, 0, 671094428, 0, 0, 0, 1207959552, 0, 0, 0, 763369120, 0, 0, 0, 469762122, 0, 0, 0, 159389419, 0, 0, 0, 1409286146, 0, 0, 0, 763369198, 0, 0, 0, 939524098, 0, 0, 0, 847255296, 0, 0, 0, 469762060, 0, 0, 0, 847255310, 0, 0, 0, 469762051, 0, 0, 0, 847255314, 0, 0, 0, 805306370, 0, 0, 0, 411047712, 0, 0, 0, 469762065, 0, 0, 0, 411047730, 0, 0, 0, 805306370, 0, 0, 0, 159389493, 0, 0, 0, 1409286145, 0, 0, 0, 109057856, 0, 0, 0, 469762065, 0, 0, 0, 109057874, 0, 0, 0, 805306369, 0, 0, 0, 864032608, 0, 0, 0, 469762060, 0, 0, 0, 864032622, 0, 0, 0, 469762050, 0, 0, 0, 864032626, 0, 0, 0, 805306369, 0, 0, 0, 528488320, 0, 0, 0, 469762099, 0, 0, 0, 528488372, 0, 0, 0, 67108865, 0, 0, 0, 520099766, 0, 0, 0, 671088640, 0, 0, 0, 528488375, 0, 0, 0, 805306374, 0, 0, 0, 528488382, 0, 0, 0, 671088647, 0, 0, 0, 520099782, 0, 0, 0, 805306368, 0, 0, 0, 528488391, 0, 0, 0, 671088641, 0, 0, 0, 528488393, 0, 0, 0, 805306378, 0, 0, 0, 528488404, 0, 0, 0, 1409286146, 0, 0, 0, 520099799, 0, 0, 0, 402653184, 0, 0, 0, 528488408, 0, 0, 0, 1409286146, 0, 0, 0, 520099803, 0, 0, 0, 1543503872, 0, 0, 0, 520099804, 0, 0, 0, 469762048, 0, 0, 0, 520099805, 0, 0, 0, 805306368, 0, 0, 0, 528488416, 0, 0, 0, 872415241, 0, 0, 0, 528488432, 0, 0, 0, 1006632969, 0, 0, 0, 629151744, 0, 0, 0, 1409286149, 0, 0, 0, 620763142, 0, 0, 0, 1140850688, 0, 0, 0, 629151751, 0, 0, 0, 1409286147, 0, 0, 0, 629151755, 0, 0, 0, 805306370, 0, 0, 0, 620763150, 0, 0, 0, 1946157056, 0, 0, 0, 629151760, 0, 0, 0, 872415241, 0, 0, 0, 629151776, 0, 0, 0, 469762082, 0, 0, 0, 620763203, 0, 0, 0, 402653184, 0, 0, 0, 629151812, 0, 0, 0, 469762099, 0, 0, 0, 629151872, 0, 0, 0, 469762088, 0, 0, 0, 620763305, 0, 0, 0, 805306368, 0, 0, 0, 578820352, 0, 0, 0, 469762076, 0, 0, 0, 578820384, 0, 0, 0, 805306370, 0, 0, 0, 578820387, 0, 0, 0, 671088643, 0, 0, 0, 578820391, 0, 0, 0, 805306369, 0, 0, 0, 578820393, 0, 0, 0, 671088642, 0, 0, 0, 578820400, 0, 0, 0, 671088641, 0, 0, 0, 570431794, 0, 0, 0, 805306368, 0, 0, 0, 578820403, 0, 0, 0, 671088645, 0, 0, 0, 578820409, 0, 0, 0, 805306370, 0, 0, 0, 570431808, 0, 0, 0, 1744830464, 0, 0, 0, 578820420, 0, 0, 0, 1409286145, 0, 0, 0, 578820422, 0, 0, 0, 872415241, 0, 0, 0, 880810320, 0, 0, 0, 469762077, 0, 0, 0, 880810352, 0, 0, 0, 469762052, 0, 0, 0, 662706560, 0, 0, 0, 469762089, 0, 0, 0, 662706608, 0, 0, 0, 671088656, 0, 0, 0, 662706625, 0, 0, 0, 469762054, 0, 0, 0, 662706632, 0, 0, 0, 671088641, 0, 0, 0, 662706640, 0, 0, 0, 872415241, 0, 0, 0, 662706654, 0, 0, 0, 1409286145, 0, 0, 0, 528488928, 0, 0, 0, 1744830495, 0, 0, 0, 92281344, 0, 0, 0, 469762070, 0, 0, 0, 92281367, 0, 0, 0, 805306369, 0, 0, 0, 92281369, 0, 0, 0, 671088642, 0, 0, 0, 92281374, 0, 0, 0, 1409286145, 0, 0, 0, 562044160, 0, 0, 0, 335544363, 0, 0, 0, 562044204, 0, 0, 0, 402653237, 0, 0, 0, 562044258, 0, 0, 0, 335544341, 0, 0, 0, 201334136, 0, 0, 0, 402653184, 0, 0, 0, 562044281, 0, 0, 0, 335544353, 0, 0, 0, 562044315, 0, 0, 0, 402653220, 0, 0, 0, 461381056, 0, 0, 0, 805306371, 0, 0, 0, 553655808, 0, 0, 0, 603979777, 0, 0, 0, 553655809, 0, 0, 0, 335609855, 0, 0, 0, 553655810, 0, 0, 0, 603979777, 0, 0, 0, 553655811, 0, 0, 0, 335609855, 0, 0, 0, 553655812, 0, 0, 0, 603979777, 0, 0, 0, 553655813, 0, 0, 0, 335609855, 0, 0, 0, 553655814, 0, 0, 0, 603979777, 0, 0, 0, 553655815, 0, 0, 0, 335609855, 0, 0, 0, 553655816, 0, 0, 0, 603979777, 0, 0, 0, 553655817, 0, 0, 0, 335609855, 0, 0, 0, 553655818, 0, 0, 0, 603979777, 0, 0, 0, 553655819, 0, 0, 0, 335609855, 0, 0, 0, 553655820, 0, 0, 0, 603979777, 0, 0, 0, 553655821, 0, 0, 0, 335609855, 0, 0, 0, 553655822, 0, 0, 0, 603979777, 0, 0, 0, 553655823, 0, 0, 0, 335609855, 0, 0, 0, 553655824, 0, 0, 0, 603979777, 0, 0, 0, 553655825, 0, 0, 0, 335609855, 0, 0, 0, 553655826, 0, 0, 0, 603979777, 0, 0, 0, 553655827, 0, 0, 0, 335609855, 0, 0, 0, 553655828, 0, 0, 0, 603979777, 0, 0, 0, 553655829, 0, 0, 0, 335609855, 0, 0, 0, 553655830, 0, 0, 0, 603979777, 0, 0, 0, 553655831, 0, 0, 0, 335609855, 0, 0, 0, 553655832, 0, 0, 0, 603979777, 0, 0, 0, 553655833, 0, 0, 0, 335609855, 0, 0, 0, 553655834, 0, 0, 0, 603979777, 0, 0, 0, 553655835, 0, 0, 0, 335609855, 0, 0, 0, 553655836, 0, 0, 0, 603979777, 0, 0, 0, 553655837, 0, 0, 0, 335609855, 0, 0, 0, 553655838, 0, 0, 0, 603979777, 0, 0, 0, 553655839, 0, 0, 0, 335609855, 0, 0, 0, 553655840, 0, 0, 0, 603979777, 0, 0, 0, 553655841, 0, 0, 0, 335609855, 0, 0, 0, 553655842, 0, 0, 0, 603979777, 0, 0, 0, 553655843, 0, 0, 0, 335609855, 0, 0, 0, 553655844, 0, 0, 0, 603979777, 0, 0, 0, 553655845, 0, 0, 0, 335609855, 0, 0, 0, 553655846, 0, 0, 0, 603979777, 0, 0, 0, 553655847, 0, 0, 0, 335609855, 0, 0, 0, 553655848, 0, 0, 0, 603979777, 0, 0, 0, 553655849, 0, 0, 0, 335609855, 0, 0, 0, 553655850, 0, 0, 0, 603979777, 0, 0, 0, 553655851, 0, 0, 0, 335609855, 0, 0, 0, 553655852, 0, 0, 0, 603979777, 0, 0, 0, 553655853, 0, 0, 0, 335609855, 0, 0, 0, 553655854, 0, 0, 0, 603979777, 0, 0, 0, 553655855, 0, 0, 0, 335609855, 0, 0, 0, 553655856, 0, 0, 0, 603979777, 0, 0, 0, 553655857, 0, 0, 0, 335609855, 0, 0, 0, 553655858, 0, 0, 0, 603979777, 0, 0, 0, 553655859, 0, 0, 0, 335609855, 0, 0, 0, 553655860, 0, 0, 0, 603979777, 0, 0, 0, 553655861, 0, 0, 0, 335609855, 0, 0, 0, 553655862, 0, 0, 0, 603979777, 0, 0, 0, 553655863, 0, 0, 0, 335609855, 0, 0, 0, 553655864, 0, 0, 0, 603979777, 0, 0, 0, 553655865, 0, 0, 0, 335609855, 0, 0, 0, 553655866, 0, 0, 0, 603979777, 0, 0, 0, 553655867, 0, 0, 0, 335609855, 0, 0, 0, 553655868, 0, 0, 0, 603979777, 0, 0, 0, 553655869, 0, 0, 0, 335609855, 0, 0, 0, 553655870, 0, 0, 0, 603979777, 0, 0, 0, 553655871, 0, 0, 0, 335609855, 0, 0, 0, 553655872, 0, 0, 0, 603979777, 0, 0, 0, 553655873, 0, 0, 0, 335609855, 0, 0, 0, 553655874, 0, 0, 0, 603979777, 0, 0, 0, 553655875, 0, 0, 0, 335609855, 0, 0, 0, 553655876, 0, 0, 0, 603979777, 0, 0, 0, 553655877, 0, 0, 0, 335609855, 0, 0, 0, 553655878, 0, 0, 0, 603979777, 0, 0, 0, 553655879, 0, 0, 0, 335609855, 0, 0, 0, 553655880, 0, 0, 0, 603979777, 0, 0, 0, 553655881, 0, 0, 0, 335609855, 0, 0, 0, 553655882, 0, 0, 0, 603979777, 0, 0, 0, 553655883, 0, 0, 0, 335609855, 0, 0, 0, 553655884, 0, 0, 0, 603979777, 0, 0, 0, 553655885, 0, 0, 0, 335609855, 0, 0, 0, 553655886, 0, 0, 0, 603979777, 0, 0, 0, 553655887, 0, 0, 0, 335609855, 0, 0, 0, 553655888, 0, 0, 0, 603979777, 0, 0, 0, 553655889, 0, 0, 0, 335609855, 0, 0, 0, 553655890, 0, 0, 0, 603979777, 0, 0, 0, 553655891, 0, 0, 0, 335609855, 0, 0, 0, 553655892, 0, 0, 0, 603979777, 0, 0, 0, 553655893, 0, 0, 0, 335609855, 0, 0, 0, 553655894, 0, 0, 0, 603979777, 0, 0, 0, 553655895, 0, 0, 0, 335609855, 0, 0, 0, 553655896, 0, 0, 0, 603979777, 0, 0, 0, 553655897, 0, 0, 0, 335609855, 0, 0, 0, 553655898, 0, 0, 0, 603979777, 0, 0, 0, 553655899, 0, 0, 0, 335609855, 0, 0, 0, 553655900, 0, 0, 0, 603979777, 0, 0, 0, 553655901, 0, 0, 0, 335609855, 0, 0, 0, 553655902, 0, 0, 0, 603979777, 0, 0, 0, 553655903, 0, 0, 0, 335609855, 0, 0, 0, 553655904, 0, 0, 0, 603979777, 0, 0, 0, 553655905, 0, 0, 0, 335609855, 0, 0, 0, 553655906, 0, 0, 0, 603979777, 0, 0, 0, 553655907, 0, 0, 0, 335609855, 0, 0, 0, 553655908, 0, 0, 0, 603979777, 0, 0, 0, 553655909, 0, 0, 0, 335609855, 0, 0, 0, 553655910, 0, 0, 0, 603979777, 0, 0, 0, 553655911, 0, 0, 0, 335609855, 0, 0, 0, 553655912, 0, 0, 0, 603979777, 0, 0, 0, 553655913, 0, 0, 0, 335609855, 0, 0, 0, 553655914, 0, 0, 0, 603979777, 0, 0, 0, 553655915, 0, 0, 0, 335609855, 0, 0, 0, 553655916, 0, 0, 0, 603979777, 0, 0, 0, 553655917, 0, 0, 0, 335609855, 0, 0, 0, 553655918, 0, 0, 0, 603979777, 0, 0, 0, 553655919, 0, 0, 0, 335609855, 0, 0, 0, 553655920, 0, 0, 0, 603979777, 0, 0, 0, 553655921, 0, 0, 0, 335609855, 0, 0, 0, 553655922, 0, 0, 0, 603979777, 0, 0, 0, 553655923, 0, 0, 0, 335609855, 0, 0, 0, 553655924, 0, 0, 0, 603979777, 0, 0, 0, 553655925, 0, 0, 0, 335609855, 0, 0, 0, 553655926, 0, 0, 0, 603979777, 0, 0, 0, 553655927, 0, 0, 0, 335609855, 0, 0, 0, 553655928, 0, 0, 0, 603979777, 0, 0, 0, 553655929, 0, 0, 0, 335609855, 0, 0, 0, 553655930, 0, 0, 0, 603979777, 0, 0, 0, 553655931, 0, 0, 0, 335609855, 0, 0, 0, 553655932, 0, 0, 0, 603979777, 0, 0, 0, 553655933, 0, 0, 0, 335609855, 0, 0, 0, 553655934, 0, 0, 0, 603979777, 0, 0, 0, 553655935, 0, 0, 0, 335609855, 0, 0, 0, 553655936, 0, 0, 0, 603979777, 0, 0, 0, 553655937, 0, 0, 0, 335609855, 0, 0, 0, 553655938, 0, 0, 0, 603979777, 0, 0, 0, 553655939, 0, 0, 0, 335609855, 0, 0, 0, 553655940, 0, 0, 0, 603979777, 0, 0, 0, 553655941, 0, 0, 0, 335609855, 0, 0, 0, 553655942, 0, 0, 0, 603979777, 0, 0, 0, 553655943, 0, 0, 0, 335609855, 0, 0, 0, 553655944, 0, 0, 0, 603979777, 0, 0, 0, 553655945, 0, 0, 0, 335609855, 0, 0, 0, 553655946, 0, 0, 0, 603979777, 0, 0, 0, 553655947, 0, 0, 0, 335609855, 0, 0, 0, 553655948, 0, 0, 0, 603979777, 0, 0, 0, 553655949, 0, 0, 0, 335609855, 0, 0, 0, 553655950, 0, 0, 0, 603979777, 0, 0, 0, 553655951, 0, 0, 0, 335609855, 0, 0, 0, 553655952, 0, 0, 0, 603979777, 0, 0, 0, 553655953, 0, 0, 0, 335609855, 0, 0, 0, 553655954, 0, 0, 0, 603979777, 0, 0, 0, 553655955, 0, 0, 0, 335609855, 0, 0, 0, 553655956, 0, 0, 0, 603979777, 0, 0, 0, 553655957, 0, 0, 0, 335609855, 0, 0, 0, 562044566, 0, 0, 0, 335544324, 0, 0, 0, 553655963, 0, 0, 0, 335609797, 0, 0, 0, 553655968, 0, 0, 0, 603979777, 0, 0, 0, 553655969, 0, 0, 0, 335609855, 0, 0, 0, 553655970, 0, 0, 0, 603979777, 0, 0, 0, 553655971, 0, 0, 0, 335609855, 0, 0, 0, 553655972, 0, 0, 0, 603979777, 0, 0, 0, 553655973, 0, 0, 0, 335609855, 0, 0, 0, 553655974, 0, 0, 0, 603979777, 0, 0, 0, 553655975, 0, 0, 0, 335609855, 0, 0, 0, 553655976, 0, 0, 0, 603979777, 0, 0, 0, 553655977, 0, 0, 0, 335609855, 0, 0, 0, 553655978, 0, 0, 0, 603979777, 0, 0, 0, 553655979, 0, 0, 0, 335609855, 0, 0, 0, 553655980, 0, 0, 0, 603979777, 0, 0, 0, 553655981, 0, 0, 0, 335609855, 0, 0, 0, 553655982, 0, 0, 0, 603979777, 0, 0, 0, 553655983, 0, 0, 0, 335609855, 0, 0, 0, 553655984, 0, 0, 0, 603979777, 0, 0, 0, 553655985, 0, 0, 0, 335609855, 0, 0, 0, 553655986, 0, 0, 0, 603979777, 0, 0, 0, 553655987, 0, 0, 0, 335609855, 0, 0, 0, 553655988, 0, 0, 0, 603979777, 0, 0, 0, 553655989, 0, 0, 0, 335609855, 0, 0, 0, 553655990, 0, 0, 0, 603979777, 0, 0, 0, 553655991, 0, 0, 0, 335609855, 0, 0, 0, 553655992, 0, 0, 0, 603979777, 0, 0, 0, 553655993, 0, 0, 0, 335609855, 0, 0, 0, 553655994, 0, 0, 0, 603979777, 0, 0, 0, 553655995, 0, 0, 0, 335609855, 0, 0, 0, 553655996, 0, 0, 0, 603979777, 0, 0, 0, 553655997, 0, 0, 0, 335609855, 0, 0, 0, 553655998, 0, 0, 0, 603979777, 0, 0, 0, 553655999, 0, 0, 0, 335609855, 0, 0, 0, 553656e3, 0, 0, 0, 603979777, 0, 0, 0, 553656001, 0, 0, 0, 335609855, 0, 0, 0, 553656002, 0, 0, 0, 603979777, 0, 0, 0, 553656003, 0, 0, 0, 335609855, 0, 0, 0, 553656004, 0, 0, 0, 603979777, 0, 0, 0, 553656005, 0, 0, 0, 335609855, 0, 0, 0, 553656006, 0, 0, 0, 603979777, 0, 0, 0, 553656007, 0, 0, 0, 335609855, 0, 0, 0, 553656008, 0, 0, 0, 603979777, 0, 0, 0, 553656009, 0, 0, 0, 335609855, 0, 0, 0, 553656010, 0, 0, 0, 603979777, 0, 0, 0, 553656011, 0, 0, 0, 335609855, 0, 0, 0, 553656012, 0, 0, 0, 603979777, 0, 0, 0, 553656013, 0, 0, 0, 335609855, 0, 0, 0, 553656014, 0, 0, 0, 603979777, 0, 0, 0, 553656015, 0, 0, 0, 335609855, 0, 0, 0, 553656016, 0, 0, 0, 603979777, 0, 0, 0, 553656017, 0, 0, 0, 335609855, 0, 0, 0, 553656018, 0, 0, 0, 603979777, 0, 0, 0, 553656019, 0, 0, 0, 335609855, 0, 0, 0, 553656020, 0, 0, 0, 603979777, 0, 0, 0, 553656021, 0, 0, 0, 335609855, 0, 0, 0, 553656022, 0, 0, 0, 603979777, 0, 0, 0, 553656023, 0, 0, 0, 335609855, 0, 0, 0, 553656024, 0, 0, 0, 603979777, 0, 0, 0, 553656025, 0, 0, 0, 335609855, 0, 0, 0, 553656026, 0, 0, 0, 603979777, 0, 0, 0, 553656027, 0, 0, 0, 335609855, 0, 0, 0, 553656028, 0, 0, 0, 603979777, 0, 0, 0, 553656029, 0, 0, 0, 335609855, 0, 0, 0, 553656030, 0, 0, 0, 603979777, 0, 0, 0, 553656031, 0, 0, 0, 335609855, 0, 0, 0, 553656032, 0, 0, 0, 603979777, 0, 0, 0, 553656033, 0, 0, 0, 335609855, 0, 0, 0, 553656034, 0, 0, 0, 603979777, 0, 0, 0, 553656035, 0, 0, 0, 335609855, 0, 0, 0, 553656036, 0, 0, 0, 603979777, 0, 0, 0, 553656037, 0, 0, 0, 335609855, 0, 0, 0, 553656038, 0, 0, 0, 603979777, 0, 0, 0, 553656039, 0, 0, 0, 335609855, 0, 0, 0, 553656040, 0, 0, 0, 603979777, 0, 0, 0, 553656041, 0, 0, 0, 335609855, 0, 0, 0, 553656042, 0, 0, 0, 603979777, 0, 0, 0, 553656043, 0, 0, 0, 335609855, 0, 0, 0, 553656044, 0, 0, 0, 603979777, 0, 0, 0, 553656045, 0, 0, 0, 335609855, 0, 0, 0, 553656046, 0, 0, 0, 603979777, 0, 0, 0, 553656047, 0, 0, 0, 335609855, 0, 0, 0, 553656048, 0, 0, 0, 603979777, 0, 0, 0, 553656049, 0, 0, 0, 335609855, 0, 0, 0, 553656050, 0, 0, 0, 603979777, 0, 0, 0, 553656051, 0, 0, 0, 335609855, 0, 0, 0, 553656052, 0, 0, 0, 603979777, 0, 0, 0, 553656053, 0, 0, 0, 335609855, 0, 0, 0, 553656054, 0, 0, 0, 603979777, 0, 0, 0, 553656055, 0, 0, 0, 335609855, 0, 0, 0, 553656056, 0, 0, 0, 603979777, 0, 0, 0, 553656057, 0, 0, 0, 335609855, 0, 0, 0, 318775040, 0, 0, 0, 335544328, 0, 0, 0, 318775041, 0, 0, 0, 335544328, 0, 0, 0, 318775042, 0, 0, 0, 335544328, 0, 0, 0, 318775043, 0, 0, 0, 335544328, 0, 0, 0, 318775044, 0, 0, 0, 335544328, 0, 0, 0, 318775045, 0, 0, 0, 335544328, 0, 0, 0, 318775046, 0, 0, 0, 335544328, 0, 0, 0, 318775047, 0, 0, 0, 335544328, 0, 0, 0, 318775048, 0, 0, 0, 604045304, 0, 0, 0, 318775049, 0, 0, 0, 604045304, 0, 0, 0, 318775050, 0, 0, 0, 604045304, 0, 0, 0, 318775051, 0, 0, 0, 604045304, 0, 0, 0, 318775052, 0, 0, 0, 604045304, 0, 0, 0, 318775053, 0, 0, 0, 604045304, 0, 0, 0, 318775054, 0, 0, 0, 604045304, 0, 0, 0, 318775055, 0, 0, 0, 604045304, 0, 0, 0, 318775056, 0, 0, 0, 335544328, 0, 0, 0, 318775057, 0, 0, 0, 335544328, 0, 0, 0, 318775058, 0, 0, 0, 335544328, 0, 0, 0, 318775059, 0, 0, 0, 335544328, 0, 0, 0, 318775060, 0, 0, 0, 335544328, 0, 0, 0, 318775061, 0, 0, 0, 335544328, 0, 0, 0, 318775064, 0, 0, 0, 604045304, 0, 0, 0, 318775065, 0, 0, 0, 604045304, 0, 0, 0, 318775066, 0, 0, 0, 604045304, 0, 0, 0, 318775067, 0, 0, 0, 604045304, 0, 0, 0, 318775068, 0, 0, 0, 604045304, 0, 0, 0, 318775069, 0, 0, 0, 604045304, 0, 0, 0, 318775072, 0, 0, 0, 335544328, 0, 0, 0, 318775073, 0, 0, 0, 335544328, 0, 0, 0, 318775074, 0, 0, 0, 335544328, 0, 0, 0, 318775075, 0, 0, 0, 335544328, 0, 0, 0, 318775076, 0, 0, 0, 335544328, 0, 0, 0, 318775077, 0, 0, 0, 335544328, 0, 0, 0, 318775078, 0, 0, 0, 335544328, 0, 0, 0, 318775079, 0, 0, 0, 335544328, 0, 0, 0, 318775080, 0, 0, 0, 604045304, 0, 0, 0, 318775081, 0, 0, 0, 604045304, 0, 0, 0, 318775082, 0, 0, 0, 604045304, 0, 0, 0, 318775083, 0, 0, 0, 604045304, 0, 0, 0, 318775084, 0, 0, 0, 604045304, 0, 0, 0, 318775085, 0, 0, 0, 604045304, 0, 0, 0, 318775086, 0, 0, 0, 604045304, 0, 0, 0, 318775087, 0, 0, 0, 604045304, 0, 0, 0, 318775088, 0, 0, 0, 335544328, 0, 0, 0, 318775089, 0, 0, 0, 335544328, 0, 0, 0, 318775090, 0, 0, 0, 335544328, 0, 0, 0, 318775091, 0, 0, 0, 335544328, 0, 0, 0, 318775092, 0, 0, 0, 335544328, 0, 0, 0, 318775093, 0, 0, 0, 335544328, 0, 0, 0, 318775094, 0, 0, 0, 335544328, 0, 0, 0, 318775095, 0, 0, 0, 335544328, 0, 0, 0, 318775096, 0, 0, 0, 604045304, 0, 0, 0, 318775097, 0, 0, 0, 604045304, 0, 0, 0, 318775098, 0, 0, 0, 604045304, 0, 0, 0, 318775099, 0, 0, 0, 604045304, 0, 0, 0, 318775100, 0, 0, 0, 604045304, 0, 0, 0, 318775101, 0, 0, 0, 604045304, 0, 0, 0, 318775102, 0, 0, 0, 604045304, 0, 0, 0, 318775103, 0, 0, 0, 604045304, 0, 0, 0, 318775104, 0, 0, 0, 335544328, 0, 0, 0, 318775105, 0, 0, 0, 335544328, 0, 0, 0, 318775106, 0, 0, 0, 335544328, 0, 0, 0, 318775107, 0, 0, 0, 335544328, 0, 0, 0, 318775108, 0, 0, 0, 335544328, 0, 0, 0, 318775109, 0, 0, 0, 335544328, 0, 0, 0, 318775112, 0, 0, 0, 604045304, 0, 0, 0, 318775113, 0, 0, 0, 604045304, 0, 0, 0, 318775114, 0, 0, 0, 604045304, 0, 0, 0, 318775115, 0, 0, 0, 604045304, 0, 0, 0, 318775116, 0, 0, 0, 604045304, 0, 0, 0, 318775117, 0, 0, 0, 604045304, 0, 0, 0, 318775120, 0, 0, 0, 335544320, 0, 0, 0, 318775121, 0, 0, 0, 335544328, 0, 0, 0, 318775122, 0, 0, 0, 335544320, 0, 0, 0, 318775123, 0, 0, 0, 335544328, 0, 0, 0, 318775124, 0, 0, 0, 335544320, 0, 0, 0, 318775125, 0, 0, 0, 335544328, 0, 0, 0, 318775126, 0, 0, 0, 335544320, 0, 0, 0, 318775127, 0, 0, 0, 335544328, 0, 0, 0, 318775129, 0, 0, 0, 604045304, 0, 0, 0, 318775131, 0, 0, 0, 604045304, 0, 0, 0, 318775133, 0, 0, 0, 604045304, 0, 0, 0, 318775135, 0, 0, 0, 604045304, 0, 0, 0, 318775136, 0, 0, 0, 335544328, 0, 0, 0, 318775137, 0, 0, 0, 335544328, 0, 0, 0, 318775138, 0, 0, 0, 335544328, 0, 0, 0, 318775139, 0, 0, 0, 335544328, 0, 0, 0, 318775140, 0, 0, 0, 335544328, 0, 0, 0, 318775141, 0, 0, 0, 335544328, 0, 0, 0, 318775142, 0, 0, 0, 335544328, 0, 0, 0, 318775143, 0, 0, 0, 335544328, 0, 0, 0, 318775144, 0, 0, 0, 604045304, 0, 0, 0, 318775145, 0, 0, 0, 604045304, 0, 0, 0, 318775146, 0, 0, 0, 604045304, 0, 0, 0, 318775147, 0, 0, 0, 604045304, 0, 0, 0, 318775148, 0, 0, 0, 604045304, 0, 0, 0, 318775149, 0, 0, 0, 604045304, 0, 0, 0, 318775150, 0, 0, 0, 604045304, 0, 0, 0, 318775151, 0, 0, 0, 604045304, 0, 0, 0, 318775152, 0, 0, 0, 335544394, 0, 0, 0, 318775153, 0, 0, 0, 335544394, 0, 0, 0, 318775154, 0, 0, 0, 335544406, 0, 0, 0, 318775155, 0, 0, 0, 335544406, 0, 0, 0, 318775156, 0, 0, 0, 335544406, 0, 0, 0, 318775157, 0, 0, 0, 335544406, 0, 0, 0, 318775158, 0, 0, 0, 335544420, 0, 0, 0, 318775159, 0, 0, 0, 335544420, 0, 0, 0, 318775160, 0, 0, 0, 335544448, 0, 0, 0, 318775161, 0, 0, 0, 335544448, 0, 0, 0, 318775162, 0, 0, 0, 335544432, 0, 0, 0, 318775163, 0, 0, 0, 335544432, 0, 0, 0, 318775164, 0, 0, 0, 335544446, 0, 0, 0, 318775165, 0, 0, 0, 335544446, 0, 0, 0, 318775168, 0, 0, 0, 335544328, 0, 0, 0, 318775169, 0, 0, 0, 335544328, 0, 0, 0, 318775170, 0, 0, 0, 335544328, 0, 0, 0, 318775171, 0, 0, 0, 335544328, 0, 0, 0, 318775172, 0, 0, 0, 335544328, 0, 0, 0, 318775173, 0, 0, 0, 335544328, 0, 0, 0, 318775174, 0, 0, 0, 335544328, 0, 0, 0, 318775175, 0, 0, 0, 335544328, 0, 0, 0, 318775176, 0, 0, 0, 536936440, 0, 0, 0, 318775177, 0, 0, 0, 536936440, 0, 0, 0, 318775178, 0, 0, 0, 536936440, 0, 0, 0, 318775179, 0, 0, 0, 536936440, 0, 0, 0, 318775180, 0, 0, 0, 536936440, 0, 0, 0, 318775181, 0, 0, 0, 536936440, 0, 0, 0, 318775182, 0, 0, 0, 536936440, 0, 0, 0, 318775183, 0, 0, 0, 536936440, 0, 0, 0, 318775184, 0, 0, 0, 335544328, 0, 0, 0, 318775185, 0, 0, 0, 335544328, 0, 0, 0, 318775186, 0, 0, 0, 335544328, 0, 0, 0, 318775187, 0, 0, 0, 335544328, 0, 0, 0, 318775188, 0, 0, 0, 335544328, 0, 0, 0, 318775189, 0, 0, 0, 335544328, 0, 0, 0, 318775190, 0, 0, 0, 335544328, 0, 0, 0, 318775191, 0, 0, 0, 335544328, 0, 0, 0, 318775192, 0, 0, 0, 536936440, 0, 0, 0, 318775193, 0, 0, 0, 536936440, 0, 0, 0, 318775194, 0, 0, 0, 536936440, 0, 0, 0, 318775195, 0, 0, 0, 536936440, 0, 0, 0, 318775196, 0, 0, 0, 536936440, 0, 0, 0, 318775197, 0, 0, 0, 536936440, 0, 0, 0, 318775198, 0, 0, 0, 536936440, 0, 0, 0, 318775199, 0, 0, 0, 536936440, 0, 0, 0, 318775200, 0, 0, 0, 335544328, 0, 0, 0, 318775201, 0, 0, 0, 335544328, 0, 0, 0, 318775202, 0, 0, 0, 335544328, 0, 0, 0, 318775203, 0, 0, 0, 335544328, 0, 0, 0, 318775204, 0, 0, 0, 335544328, 0, 0, 0, 318775205, 0, 0, 0, 335544328, 0, 0, 0, 318775206, 0, 0, 0, 335544328, 0, 0, 0, 318775207, 0, 0, 0, 335544328, 0, 0, 0, 318775208, 0, 0, 0, 536936440, 0, 0, 0, 318775209, 0, 0, 0, 536936440, 0, 0, 0, 318775210, 0, 0, 0, 536936440, 0, 0, 0, 318775211, 0, 0, 0, 536936440, 0, 0, 0, 318775212, 0, 0, 0, 536936440, 0, 0, 0, 318775213, 0, 0, 0, 536936440, 0, 0, 0, 318775214, 0, 0, 0, 536936440, 0, 0, 0, 318775215, 0, 0, 0, 536936440, 0, 0, 0, 318775216, 0, 0, 0, 335544328, 0, 0, 0, 318775217, 0, 0, 0, 335544328, 0, 0, 0, 318775218, 0, 0, 0, 335544320, 0, 0, 0, 318775219, 0, 0, 0, 335544329, 0, 0, 0, 318775220, 0, 0, 0, 335544320, 0, 0, 0, 327163830, 0, 0, 0, 335544321, 0, 0, 0, 318775224, 0, 0, 0, 604045304, 0, 0, 0, 318775225, 0, 0, 0, 604045304, 0, 0, 0, 318775226, 0, 0, 0, 604045238, 0, 0, 0, 318775227, 0, 0, 0, 604045238, 0, 0, 0, 318775228, 0, 0, 0, 536936439, 0, 0, 0, 318775229, 0, 0, 0, 1610612736, 0, 0, 0, 318775230, 0, 0, 0, 335602651, 0, 0, 0, 327163839, 0, 0, 0, 1610612738, 0, 0, 0, 318775234, 0, 0, 0, 335544320, 0, 0, 0, 318775235, 0, 0, 0, 335544329, 0, 0, 0, 318775236, 0, 0, 0, 335544320, 0, 0, 0, 327163846, 0, 0, 0, 335544321, 0, 0, 0, 318775240, 0, 0, 0, 604045226, 0, 0, 0, 318775241, 0, 0, 0, 604045226, 0, 0, 0, 318775242, 0, 0, 0, 604045226, 0, 0, 0, 318775243, 0, 0, 0, 604045226, 0, 0, 0, 318775244, 0, 0, 0, 536936439, 0, 0, 0, 327163853, 0, 0, 0, 1610612738, 0, 0, 0, 318775248, 0, 0, 0, 335544328, 0, 0, 0, 318775249, 0, 0, 0, 335544328, 0, 0, 0, 327163858, 0, 0, 0, 335544321, 0, 0, 0, 327163862, 0, 0, 0, 335544321, 0, 0, 0, 318775256, 0, 0, 0, 604045304, 0, 0, 0, 318775257, 0, 0, 0, 604045304, 0, 0, 0, 318775258, 0, 0, 0, 604045212, 0, 0, 0, 318775259, 0, 0, 0, 604045212, 0, 0, 0, 327163869, 0, 0, 0, 1610612738, 0, 0, 0, 318775264, 0, 0, 0, 335544328, 0, 0, 0, 318775265, 0, 0, 0, 335544328, 0, 0, 0, 327163874, 0, 0, 0, 335544322, 0, 0, 0, 318775269, 0, 0, 0, 335544327, 0, 0, 0, 327163878, 0, 0, 0, 335544321, 0, 0, 0, 318775272, 0, 0, 0, 604045304, 0, 0, 0, 318775273, 0, 0, 0, 604045304, 0, 0, 0, 318775274, 0, 0, 0, 604045200, 0, 0, 0, 318775275, 0, 0, 0, 604045200, 0, 0, 0, 318775276, 0, 0, 0, 604045305, 0, 0, 0, 327163885, 0, 0, 0, 1610612738, 0, 0, 0, 318775282, 0, 0, 0, 335544320, 0, 0, 0, 318775283, 0, 0, 0, 335544329, 0, 0, 0, 318775284, 0, 0, 0, 335544320, 0, 0, 0, 327163894, 0, 0, 0, 335544321, 0, 0, 0, 318775288, 0, 0, 0, 604045184, 0, 0, 0, 318775289, 0, 0, 0, 604045184, 0, 0, 0, 318775290, 0, 0, 0, 604045186, 0, 0, 0, 318775291, 0, 0, 0, 604045186, 0, 0, 0, 318775292, 0, 0, 0, 536936439, 0, 0, 0, 327163901, 0, 0, 0, 1610612737, 0, 0, 0, 159391744, 0, 0, 0, 1946157066, 0, 0, 0, 159391755, 0, 0, 0, 67108868, 0, 0, 0, 159391760, 0, 0, 0, 1140850693, 0, 0, 0, 159391766, 0, 0, 0, 1409286145, 0, 0, 0, 151003160, 0, 0, 0, 1342177280, 0, 0, 0, 151003161, 0, 0, 0, 1275068416, 0, 0, 0, 151003162, 0, 0, 0, 1476395008, 0, 0, 0, 159391771, 0, 0, 0, 1342177281, 0, 0, 0, 151003165, 0, 0, 0, 1275068416, 0, 0, 0, 151003166, 0, 0, 0, 1476395008, 0, 0, 0, 151003167, 0, 0, 0, 1342177280, 0, 0, 0, 159391776, 0, 0, 0, 1409286151, 0, 0, 0, 151003176, 0, 0, 0, 1811939328, 0, 0, 0, 151003177, 0, 0, 0, 1879048192, 0, 0, 0, 159391786, 0, 0, 0, 67108868, 0, 0, 0, 151003183, 0, 0, 0, 1946157056, 0, 0, 0, 159391792, 0, 0, 0, 1409286152, 0, 0, 0, 151003193, 0, 0, 0, 1342177280, 0, 0, 0, 151003194, 0, 0, 0, 1275068416, 0, 0, 0, 159391803, 0, 0, 0, 1409286147, 0, 0, 0, 159391807, 0, 0, 0, 1073741825, 0, 0, 0, 159391809, 0, 0, 0, 1409286146, 0, 0, 0, 151003204, 0, 0, 0, 1677721600, 0, 0, 0, 151003205, 0, 0, 0, 1476395008, 0, 0, 0, 151003206, 0, 0, 0, 1207959552, 0, 0, 0, 159391815, 0, 0, 0, 1409286154, 0, 0, 0, 151003218, 0, 0, 0, 1677721600, 0, 0, 0, 151003219, 0, 0, 0, 1409286144, 0, 0, 0, 151003220, 0, 0, 0, 1073741824, 0, 0, 0, 159391829, 0, 0, 0, 1409286153, 0, 0, 0, 151003231, 0, 0, 0, 1946157056, 0, 0, 0, 159391840, 0, 0, 0, 67108867, 0, 0, 0, 159391850, 0, 0, 0, 67108869, 0, 0, 0, 151003248, 0, 0, 0, 1006632960, 0, 0, 0, 553656433, 0, 0, 0, 335544320, 0, 0, 0, 159391860, 0, 0, 0, 1006632965, 0, 0, 0, 159391866, 0, 0, 0, 1677721602, 0, 0, 0, 151003261, 0, 0, 0, 1476395008, 0, 0, 0, 151003262, 0, 0, 0, 1207959552, 0, 0, 0, 553656447, 0, 0, 0, 335544320, 0, 0, 0, 159391872, 0, 0, 0, 1006632969, 0, 0, 0, 159391882, 0, 0, 0, 1677721602, 0, 0, 0, 151003277, 0, 0, 0, 1476395008, 0, 0, 0, 151003278, 0, 0, 0, 1207959552, 0, 0, 0, 562045072, 0, 0, 0, 402653188, 0, 0, 0, 159391904, 0, 0, 0, 1543503893, 0, 0, 0, 461381840, 0, 0, 0, 805306380, 0, 0, 0, 461381853, 0, 0, 0, 738197507, 0, 0, 0, 452993249, 0, 0, 0, 805306368, 0, 0, 0, 461381858, 0, 0, 0, 738197506, 0, 0, 0, 461381861, 0, 0, 0, 805306374, 0, 0, 0, 159392e3, 0, 0, 0, 1744830465, 0, 0, 0, 151003394, 0, 0, 0, 603979776, 0, 0, 0, 159392003, 0, 0, 0, 1744830467, 0, 0, 0, 151003399, 0, 0, 0, 603979776, 0, 0, 0, 159392008, 0, 0, 0, 1744830465, 0, 0, 0, 151003402, 0, 0, 0, 335544320, 0, 0, 0, 159392011, 0, 0, 0, 603979778, 0, 0, 0, 159392014, 0, 0, 0, 335544321, 0, 0, 0, 159392016, 0, 0, 0, 603979778, 0, 0, 0, 151003411, 0, 0, 0, 335544320, 0, 0, 0, 151003412, 0, 0, 0, 1744830464, 0, 0, 0, 151003413, 0, 0, 0, 603979776, 0, 0, 0, 159392022, 0, 0, 0, 1744830466, 0, 0, 0, 159392025, 0, 0, 0, 603979780, 0, 0, 0, 159392030, 0, 0, 0, 1744830469, 0, 0, 0, 151003428, 0, 0, 0, 603979776, 0, 0, 0, 151003429, 0, 0, 0, 1744830464, 0, 0, 0, 318775590, 0, 0, 0, 604037795, 0, 0, 0, 151003431, 0, 0, 0, 1744830464, 0, 0, 0, 151003432, 0, 0, 0, 603979776, 0, 0, 0, 151003433, 0, 0, 0, 1744830464, 0, 0, 0, 553656618, 0, 0, 0, 604036929, 0, 0, 0, 553656619, 0, 0, 0, 604037050, 0, 0, 0, 159392044, 0, 0, 0, 603979777, 0, 0, 0, 151003438, 0, 0, 0, 1744830464, 0, 0, 0, 151003439, 0, 0, 0, 335544320, 0, 0, 0, 159392048, 0, 0, 0, 603979777, 0, 0, 0, 151003442, 0, 0, 0, 1744830464, 0, 0, 0, 151003443, 0, 0, 0, 603979776, 0, 0, 0, 151003444, 0, 0, 0, 335544320, 0, 0, 0, 159392053, 0, 0, 0, 469762051, 0, 0, 0, 151003449, 0, 0, 0, 335544320, 0, 0, 0, 159392058, 0, 0, 0, 1744830465, 0, 0, 0, 159392060, 0, 0, 0, 335544321, 0, 0, 0, 159392062, 0, 0, 0, 603979777, 0, 0, 0, 159392064, 0, 0, 0, 1677721604, 0, 0, 0, 151003461, 0, 0, 0, 603979776, 0, 0, 0, 159392070, 0, 0, 0, 335544323, 0, 0, 0, 151003466, 0, 0, 0, 1744830464, 0, 0, 0, 151003467, 0, 0, 0, 1677721600, 0, 0, 0, 151003468, 0, 0, 0, 1744830464, 0, 0, 0, 159392083, 0, 0, 0, 1006632972, 0, 0, 0, 151003488, 0, 0, 0, 939524112, 0, 0, 0, 151003489, 0, 0, 0, 939524112, 0, 0, 0, 151003490, 0, 0, 0, 939524112, 0, 0, 0, 151003491, 0, 0, 0, 939524112, 0, 0, 0, 151003492, 0, 0, 0, 939524112, 0, 0, 0, 151003493, 0, 0, 0, 939524112, 0, 0, 0, 151003494, 0, 0, 0, 939524112, 0, 0, 0, 151003495, 0, 0, 0, 939524112, 0, 0, 0, 151003496, 0, 0, 0, 939524112, 0, 0, 0, 151003497, 0, 0, 0, 939524112, 0, 0, 0, 151003498, 0, 0, 0, 939524112, 0, 0, 0, 151003499, 0, 0, 0, 939524112, 0, 0, 0, 151003500, 0, 0, 0, 939524112, 0, 0, 0, 151003501, 0, 0, 0, 939524112, 0, 0, 0, 151003502, 0, 0, 0, 939524112, 0, 0, 0, 151003503, 0, 0, 0, 939524112, 0, 0, 0, 151003504, 0, 0, 0, 939589616, 0, 0, 0, 151003505, 0, 0, 0, 939589616, 0, 0, 0, 151003506, 0, 0, 0, 939589616, 0, 0, 0, 151003507, 0, 0, 0, 939589616, 0, 0, 0, 151003508, 0, 0, 0, 939589616, 0, 0, 0, 151003509, 0, 0, 0, 939589616, 0, 0, 0, 151003510, 0, 0, 0, 939589616, 0, 0, 0, 151003511, 0, 0, 0, 939589616, 0, 0, 0, 151003512, 0, 0, 0, 939589616, 0, 0, 0, 151003513, 0, 0, 0, 939589616, 0, 0, 0, 151003514, 0, 0, 0, 939589616, 0, 0, 0, 151003515, 0, 0, 0, 939589616, 0, 0, 0, 151003516, 0, 0, 0, 939589616, 0, 0, 0, 151003517, 0, 0, 0, 939589616, 0, 0, 0, 151003518, 0, 0, 0, 939589616, 0, 0, 0, 151003519, 0, 0, 0, 939589616, 0, 0, 0, 159392128, 0, 0, 0, 939524099, 0, 0, 0, 159392144, 0, 0, 0, 1677721604, 0, 0, 0, 159392149, 0, 0, 0, 1744830468, 0, 0, 0, 159392154, 0, 0, 0, 1677721601, 0, 0, 0, 159392156, 0, 0, 0, 1744830467, 0, 0, 0, 151003552, 0, 0, 0, 1677721600, 0, 0, 0, 159392161, 0, 0, 0, 1744830465, 0, 0, 0, 151003555, 0, 0, 0, 1677721600, 0, 0, 0, 159392164, 0, 0, 0, 1744830465, 0, 0, 0, 151003558, 0, 0, 0, 1677721600, 0, 0, 0, 159392167, 0, 0, 0, 1744830470, 0, 0, 0, 151003566, 0, 0, 0, 1677721600, 0, 0, 0, 159392175, 0, 0, 0, 1744830494, 0, 0, 0, 159392206, 0, 0, 0, 1677721601, 0, 0, 0, 159392208, 0, 0, 0, 1744830465, 0, 0, 0, 151003602, 0, 0, 0, 1677721600, 0, 0, 0, 151003603, 0, 0, 0, 1744830464, 0, 0, 0, 151003604, 0, 0, 0, 1677721600, 0, 0, 0, 159392213, 0, 0, 0, 1744830494, 0, 0, 0, 159392244, 0, 0, 0, 1677721867, 0, 0, 0, 159392512, 0, 0, 0, 1744830471, 0, 0, 0, 159392520, 0, 0, 0, 1677721603, 0, 0, 0, 159392524, 0, 0, 0, 1744830483, 0, 0, 0, 159392544, 0, 0, 0, 1677721601, 0, 0, 0, 159392546, 0, 0, 0, 1744830470, 0, 0, 0, 151003945, 0, 0, 0, 1476395008, 0, 0, 0, 151003946, 0, 0, 0, 1207959552, 0, 0, 0, 159392555, 0, 0, 0, 1744830544, 0, 0, 0, 151004028, 0, 0, 0, 1677721600, 0, 0, 0, 159392637, 0, 0, 0, 1744830493, 0, 0, 0, 159392667, 0, 0, 0, 1677721624, 0, 0, 0, 151004084, 0, 0, 0, 1476395008, 0, 0, 0, 151004085, 0, 0, 0, 1207959552, 0, 0, 0, 151004086, 0, 0, 0, 1409286144, 0, 0, 0, 159392695, 0, 0, 0, 1744830500, 0, 0, 0, 159392768, 0, 0, 0, 1744830502, 0, 0, 0, 159392832, 0, 0, 0, 1744830474, 0, 0, 0, 159392864, 0, 0, 0, 1006633019, 0, 0, 0, 159392924, 0, 0, 0, 1744830489, 0, 0, 0, 151004342, 0, 0, 0, 1744830490, 0, 0, 0, 151004343, 0, 0, 0, 1744830490, 0, 0, 0, 151004344, 0, 0, 0, 1744830490, 0, 0, 0, 151004345, 0, 0, 0, 1744830490, 0, 0, 0, 151004346, 0, 0, 0, 1744830490, 0, 0, 0, 151004347, 0, 0, 0, 1744830490, 0, 0, 0, 151004348, 0, 0, 0, 1744830490, 0, 0, 0, 151004349, 0, 0, 0, 1744830490, 0, 0, 0, 151004350, 0, 0, 0, 1744830490, 0, 0, 0, 151004351, 0, 0, 0, 1744830490, 0, 0, 0, 151004352, 0, 0, 0, 1744830490, 0, 0, 0, 151004353, 0, 0, 0, 1744830490, 0, 0, 0, 151004354, 0, 0, 0, 1744830490, 0, 0, 0, 151004355, 0, 0, 0, 1744830490, 0, 0, 0, 151004356, 0, 0, 0, 1744830490, 0, 0, 0, 151004357, 0, 0, 0, 1744830490, 0, 0, 0, 151004358, 0, 0, 0, 1744830490, 0, 0, 0, 151004359, 0, 0, 0, 1744830490, 0, 0, 0, 151004360, 0, 0, 0, 1744830490, 0, 0, 0, 151004361, 0, 0, 0, 1744830490, 0, 0, 0, 151004362, 0, 0, 0, 1744830490, 0, 0, 0, 151004363, 0, 0, 0, 1744830490, 0, 0, 0, 151004364, 0, 0, 0, 1744830490, 0, 0, 0, 151004365, 0, 0, 0, 1744830490, 0, 0, 0, 151004366, 0, 0, 0, 1744830490, 0, 0, 0, 151004367, 0, 0, 0, 1744830490, 0, 0, 0, 151004368, 0, 0, 0, 1744895974, 0, 0, 0, 151004369, 0, 0, 0, 1744895974, 0, 0, 0, 151004370, 0, 0, 0, 1744895974, 0, 0, 0, 151004371, 0, 0, 0, 1744895974, 0, 0, 0, 151004372, 0, 0, 0, 1744895974, 0, 0, 0, 151004373, 0, 0, 0, 1744895974, 0, 0, 0, 151004374, 0, 0, 0, 1744895974, 0, 0, 0, 151004375, 0, 0, 0, 1744895974, 0, 0, 0, 151004376, 0, 0, 0, 1744895974, 0, 0, 0, 151004377, 0, 0, 0, 1744895974, 0, 0, 0, 151004378, 0, 0, 0, 1744895974, 0, 0, 0, 151004379, 0, 0, 0, 1744895974, 0, 0, 0, 151004380, 0, 0, 0, 1744895974, 0, 0, 0, 151004381, 0, 0, 0, 1744895974, 0, 0, 0, 151004382, 0, 0, 0, 1744895974, 0, 0, 0, 151004383, 0, 0, 0, 1744895974, 0, 0, 0, 151004384, 0, 0, 0, 1744895974, 0, 0, 0, 151004385, 0, 0, 0, 1744895974, 0, 0, 0, 151004386, 0, 0, 0, 1744895974, 0, 0, 0, 151004387, 0, 0, 0, 1744895974, 0, 0, 0, 151004388, 0, 0, 0, 1744895974, 0, 0, 0, 151004389, 0, 0, 0, 1744895974, 0, 0, 0, 151004390, 0, 0, 0, 1744895974, 0, 0, 0, 151004391, 0, 0, 0, 1744895974, 0, 0, 0, 151004392, 0, 0, 0, 1744895974, 0, 0, 0, 151004393, 0, 0, 0, 1744895974, 0, 0, 0, 159393002, 0, 0, 0, 1006632981, 0, 0, 0, 159393024, 0, 0, 0, 1744830646, 0, 0, 0, 151004599, 0, 0, 0, 1677721600, 0, 0, 0, 159393208, 0, 0, 0, 1744830472, 0, 0, 0, 151004609, 0, 0, 0, 1677721600, 0, 0, 0, 159393218, 0, 0, 0, 1744830517, 0, 0, 0, 159393272, 0, 0, 0, 1677721607, 0, 0, 0, 159393280, 0, 0, 0, 1744830574, 0, 0, 0, 151004783, 0, 0, 0, 1677721600, 0, 0, 0, 159393392, 0, 0, 0, 1744830508, 0, 0, 0, 159393440, 0, 0, 0, 1744830481, 0, 0, 0, 159393537, 0, 0, 0, 1744830467, 0, 0, 0, 159393542, 0, 0, 0, 1744830467, 0, 0, 0, 159393548, 0, 0, 0, 1744830491, 0, 0, 0, 159393577, 0, 0, 0, 1744830498, 0, 0, 0, 151005005, 0, 0, 0, 1744830464, 0, 0, 0, 159393615, 0, 0, 0, 1744830467, 0, 0, 0, 151005014, 0, 0, 0, 1744830464, 0, 0, 0, 159393624, 0, 0, 0, 1744830470, 0, 0, 0, 159393633, 0, 0, 0, 1744830470, 0, 0, 0, 151005032, 0, 0, 0, 1476395008, 0, 0, 0, 151005033, 0, 0, 0, 1207959552, 0, 0, 0, 151005034, 0, 0, 0, 1476395008, 0, 0, 0, 151005035, 0, 0, 0, 1207959552, 0, 0, 0, 151005036, 0, 0, 0, 1476395008, 0, 0, 0, 151005037, 0, 0, 0, 1207959552, 0, 0, 0, 151005038, 0, 0, 0, 1476395008, 0, 0, 0, 151005039, 0, 0, 0, 1207959552, 0, 0, 0, 151005040, 0, 0, 0, 1476395008, 0, 0, 0, 151005041, 0, 0, 0, 1207959552, 0, 0, 0, 151005042, 0, 0, 0, 1476395008, 0, 0, 0, 151005043, 0, 0, 0, 1207959552, 0, 0, 0, 151005044, 0, 0, 0, 1476395008, 0, 0, 0, 151005045, 0, 0, 0, 1207959552, 0, 0, 0, 159393654, 0, 0, 0, 1006632989, 0, 0, 0, 151005076, 0, 0, 0, 1744830464, 0, 0, 0, 159393688, 0, 0, 0, 1744830487, 0, 0, 0, 159393713, 0, 0, 0, 1744830477, 0, 0, 0, 159393728, 0, 0, 0, 1677721604, 0, 0, 0, 151005125, 0, 0, 0, 1476395008, 0, 0, 0, 151005126, 0, 0, 0, 1207959552, 0, 0, 0, 159393744, 0, 0, 0, 1677721621, 0, 0, 0, 151005158, 0, 0, 0, 1476395008, 0, 0, 0, 151005159, 0, 0, 0, 1207959552, 0, 0, 0, 151005160, 0, 0, 0, 1476395008, 0, 0, 0, 151005161, 0, 0, 0, 1207959552, 0, 0, 0, 151005162, 0, 0, 0, 1476395008, 0, 0, 0, 151005163, 0, 0, 0, 1207959552, 0, 0, 0, 159393776, 0, 0, 0, 1677721615, 0, 0, 0, 75507712, 0, 0, 0, 1744830719, 0, 0, 0, 159394048, 0, 0, 0, 1677721730, 0, 0, 0, 151005571, 0, 0, 0, 1476395008, 0, 0, 0, 151005572, 0, 0, 0, 1207959552, 0, 0, 0, 151005573, 0, 0, 0, 1476395008, 0, 0, 0, 151005574, 0, 0, 0, 1207959552, 0, 0, 0, 151005575, 0, 0, 0, 1476395008, 0, 0, 0, 151005576, 0, 0, 0, 1207959552, 0, 0, 0, 151005577, 0, 0, 0, 1476395008, 0, 0, 0, 151005578, 0, 0, 0, 1207959552, 0, 0, 0, 151005579, 0, 0, 0, 1476395008, 0, 0, 0, 151005580, 0, 0, 0, 1207959552, 0, 0, 0, 151005581, 0, 0, 0, 1476395008, 0, 0, 0, 151005582, 0, 0, 0, 1207959552, 0, 0, 0, 151005583, 0, 0, 0, 1476395008, 0, 0, 0, 151005584, 0, 0, 0, 1207959552, 0, 0, 0, 151005585, 0, 0, 0, 1476395008, 0, 0, 0, 151005586, 0, 0, 0, 1207959552, 0, 0, 0, 151005587, 0, 0, 0, 1476395008, 0, 0, 0, 151005588, 0, 0, 0, 1207959552, 0, 0, 0, 151005589, 0, 0, 0, 1476395008, 0, 0, 0, 151005590, 0, 0, 0, 1207959552, 0, 0, 0, 151005591, 0, 0, 0, 1476395008, 0, 0, 0, 151005592, 0, 0, 0, 1207959552, 0, 0, 0, 159394201, 0, 0, 0, 1677721662, 0, 0, 0, 151005656, 0, 0, 0, 1476395008, 0, 0, 0, 151005657, 0, 0, 0, 1207959552, 0, 0, 0, 151005658, 0, 0, 0, 1476395008, 0, 0, 0, 151005659, 0, 0, 0, 1207959552, 0, 0, 0, 159394268, 0, 0, 0, 1677721631, 0, 0, 0, 151005692, 0, 0, 0, 1476395008, 0, 0, 0, 151005693, 0, 0, 0, 1207959552, 0, 0, 0, 159394302, 0, 0, 0, 1677721857, 0, 0, 0, 159394560, 0, 0, 0, 1744830483, 0, 0, 0, 285223936, 0, 0, 0, 603979824, 0, 0, 0, 285223937, 0, 0, 0, 603979824, 0, 0, 0, 285223938, 0, 0, 0, 603979824, 0, 0, 0, 285223939, 0, 0, 0, 603979824, 0, 0, 0, 285223940, 0, 0, 0, 603979824, 0, 0, 0, 285223941, 0, 0, 0, 603979824, 0, 0, 0, 285223942, 0, 0, 0, 603979824, 0, 0, 0, 285223943, 0, 0, 0, 603979824, 0, 0, 0, 285223944, 0, 0, 0, 603979824, 0, 0, 0, 285223945, 0, 0, 0, 603979824, 0, 0, 0, 285223946, 0, 0, 0, 603979824, 0, 0, 0, 285223947, 0, 0, 0, 603979824, 0, 0, 0, 285223948, 0, 0, 0, 603979824, 0, 0, 0, 285223949, 0, 0, 0, 603979824, 0, 0, 0, 285223950, 0, 0, 0, 603979824, 0, 0, 0, 285223951, 0, 0, 0, 603979824, 0, 0, 0, 285223952, 0, 0, 0, 603979824, 0, 0, 0, 285223953, 0, 0, 0, 603979824, 0, 0, 0, 285223954, 0, 0, 0, 603979824, 0, 0, 0, 285223955, 0, 0, 0, 603979824, 0, 0, 0, 285223956, 0, 0, 0, 603979824, 0, 0, 0, 285223957, 0, 0, 0, 603979824, 0, 0, 0, 285223958, 0, 0, 0, 603979824, 0, 0, 0, 285223959, 0, 0, 0, 603979824, 0, 0, 0, 285223960, 0, 0, 0, 603979824, 0, 0, 0, 285223961, 0, 0, 0, 603979824, 0, 0, 0, 285223962, 0, 0, 0, 603979824, 0, 0, 0, 285223963, 0, 0, 0, 603979824, 0, 0, 0, 285223964, 0, 0, 0, 603979824, 0, 0, 0, 285223965, 0, 0, 0, 603979824, 0, 0, 0, 285223966, 0, 0, 0, 603979824, 0, 0, 0, 285223967, 0, 0, 0, 603979824, 0, 0, 0, 285223968, 0, 0, 0, 603979824, 0, 0, 0, 285223969, 0, 0, 0, 603979824, 0, 0, 0, 285223970, 0, 0, 0, 603979824, 0, 0, 0, 285223971, 0, 0, 0, 603979824, 0, 0, 0, 285223972, 0, 0, 0, 603979824, 0, 0, 0, 285223973, 0, 0, 0, 603979824, 0, 0, 0, 285223974, 0, 0, 0, 603979824, 0, 0, 0, 285223975, 0, 0, 0, 603979824, 0, 0, 0, 285223976, 0, 0, 0, 603979824, 0, 0, 0, 285223977, 0, 0, 0, 603979824, 0, 0, 0, 285223978, 0, 0, 0, 603979824, 0, 0, 0, 285223979, 0, 0, 0, 603979824, 0, 0, 0, 285223980, 0, 0, 0, 603979824, 0, 0, 0, 285223981, 0, 0, 0, 603979824, 0, 0, 0, 285223982, 0, 0, 0, 603979824, 0, 0, 0, 285223984, 0, 0, 0, 335609808, 0, 0, 0, 285223985, 0, 0, 0, 335609808, 0, 0, 0, 285223986, 0, 0, 0, 335609808, 0, 0, 0, 285223987, 0, 0, 0, 335609808, 0, 0, 0, 285223988, 0, 0, 0, 335609808, 0, 0, 0, 285223989, 0, 0, 0, 335609808, 0, 0, 0, 285223990, 0, 0, 0, 335609808, 0, 0, 0, 285223991, 0, 0, 0, 335609808, 0, 0, 0, 285223992, 0, 0, 0, 335609808, 0, 0, 0, 285223993, 0, 0, 0, 335609808, 0, 0, 0, 285223994, 0, 0, 0, 335609808, 0, 0, 0, 285223995, 0, 0, 0, 335609808, 0, 0, 0, 285223996, 0, 0, 0, 335609808, 0, 0, 0, 285223997, 0, 0, 0, 335609808, 0, 0, 0, 285223998, 0, 0, 0, 335609808, 0, 0, 0, 285223999, 0, 0, 0, 335609808, 0, 0, 0, 285224e3, 0, 0, 0, 335609808, 0, 0, 0, 285224001, 0, 0, 0, 335609808, 0, 0, 0, 285224002, 0, 0, 0, 335609808, 0, 0, 0, 285224003, 0, 0, 0, 335609808, 0, 0, 0, 285224004, 0, 0, 0, 335609808, 0, 0, 0, 285224005, 0, 0, 0, 335609808, 0, 0, 0, 285224006, 0, 0, 0, 335609808, 0, 0, 0, 285224007, 0, 0, 0, 335609808, 0, 0, 0, 285224008, 0, 0, 0, 335609808, 0, 0, 0, 285224009, 0, 0, 0, 335609808, 0, 0, 0, 285224010, 0, 0, 0, 335609808, 0, 0, 0, 285224011, 0, 0, 0, 335609808, 0, 0, 0, 285224012, 0, 0, 0, 335609808, 0, 0, 0, 285224013, 0, 0, 0, 335609808, 0, 0, 0, 285224014, 0, 0, 0, 335609808, 0, 0, 0, 285224015, 0, 0, 0, 335609808, 0, 0, 0, 285224016, 0, 0, 0, 335609808, 0, 0, 0, 285224017, 0, 0, 0, 335609808, 0, 0, 0, 285224018, 0, 0, 0, 335609808, 0, 0, 0, 285224019, 0, 0, 0, 335609808, 0, 0, 0, 285224020, 0, 0, 0, 335609808, 0, 0, 0, 285224021, 0, 0, 0, 335609808, 0, 0, 0, 285224022, 0, 0, 0, 335609808, 0, 0, 0, 285224023, 0, 0, 0, 335609808, 0, 0, 0, 285224024, 0, 0, 0, 335609808, 0, 0, 0, 285224025, 0, 0, 0, 335609808, 0, 0, 0, 285224026, 0, 0, 0, 335609808, 0, 0, 0, 285224027, 0, 0, 0, 335609808, 0, 0, 0, 285224028, 0, 0, 0, 335609808, 0, 0, 0, 285224029, 0, 0, 0, 335609808, 0, 0, 0, 285224030, 0, 0, 0, 335609808, 0, 0, 0, 167783552, 0, 0, 0, 603979777, 0, 0, 0, 167783553, 0, 0, 0, 335609855, 0, 0, 0, 167783554, 0, 0, 0, 603979777, 0, 0, 0, 167783555, 0, 0, 0, 335609855, 0, 0, 0, 167783556, 0, 0, 0, 603979777, 0, 0, 0, 167783557, 0, 0, 0, 335609855, 0, 0, 0, 167783558, 0, 0, 0, 603979777, 0, 0, 0, 167783559, 0, 0, 0, 335609855, 0, 0, 0, 167783560, 0, 0, 0, 603979777, 0, 0, 0, 167783561, 0, 0, 0, 335609855, 0, 0, 0, 167783562, 0, 0, 0, 603979777, 0, 0, 0, 167783563, 0, 0, 0, 335609855, 0, 0, 0, 167783564, 0, 0, 0, 603979777, 0, 0, 0, 167783565, 0, 0, 0, 335609855, 0, 0, 0, 167783566, 0, 0, 0, 603979777, 0, 0, 0, 167783567, 0, 0, 0, 335609855, 0, 0, 0, 167783568, 0, 0, 0, 603979777, 0, 0, 0, 167783569, 0, 0, 0, 335609855, 0, 0, 0, 167783570, 0, 0, 0, 603979777, 0, 0, 0, 167783571, 0, 0, 0, 335609855, 0, 0, 0, 167783572, 0, 0, 0, 603979777, 0, 0, 0, 167783573, 0, 0, 0, 335609855, 0, 0, 0, 167783574, 0, 0, 0, 603979777, 0, 0, 0, 167783575, 0, 0, 0, 335609855, 0, 0, 0, 167783576, 0, 0, 0, 603979777, 0, 0, 0, 167783577, 0, 0, 0, 335609855, 0, 0, 0, 167783578, 0, 0, 0, 603979777, 0, 0, 0, 167783579, 0, 0, 0, 335609855, 0, 0, 0, 167783580, 0, 0, 0, 603979777, 0, 0, 0, 167783581, 0, 0, 0, 335609855, 0, 0, 0, 167783582, 0, 0, 0, 603979777, 0, 0, 0, 167783583, 0, 0, 0, 335609855, 0, 0, 0, 167783584, 0, 0, 0, 603979777, 0, 0, 0, 167783585, 0, 0, 0, 335609855, 0, 0, 0, 167783586, 0, 0, 0, 603979777, 0, 0, 0, 167783587, 0, 0, 0, 335609855, 0, 0, 0, 167783588, 0, 0, 0, 603979777, 0, 0, 0, 167783589, 0, 0, 0, 335609855, 0, 0, 0, 167783590, 0, 0, 0, 603979777, 0, 0, 0, 167783591, 0, 0, 0, 335609855, 0, 0, 0, 167783592, 0, 0, 0, 603979777, 0, 0, 0, 167783593, 0, 0, 0, 335609855, 0, 0, 0, 167783594, 0, 0, 0, 603979777, 0, 0, 0, 167783595, 0, 0, 0, 335609855, 0, 0, 0, 167783596, 0, 0, 0, 603979777, 0, 0, 0, 167783597, 0, 0, 0, 335609855, 0, 0, 0, 167783598, 0, 0, 0, 603979777, 0, 0, 0, 167783599, 0, 0, 0, 335609855, 0, 0, 0, 167783600, 0, 0, 0, 603979777, 0, 0, 0, 167783601, 0, 0, 0, 335609855, 0, 0, 0, 167783602, 0, 0, 0, 603979777, 0, 0, 0, 167783603, 0, 0, 0, 335609855, 0, 0, 0, 167783604, 0, 0, 0, 603979777, 0, 0, 0, 167783605, 0, 0, 0, 335609855, 0, 0, 0, 167783606, 0, 0, 0, 603979777, 0, 0, 0, 167783607, 0, 0, 0, 335609855, 0, 0, 0, 167783608, 0, 0, 0, 603979777, 0, 0, 0, 167783609, 0, 0, 0, 335609855, 0, 0, 0, 167783610, 0, 0, 0, 603979777, 0, 0, 0, 167783611, 0, 0, 0, 335609855, 0, 0, 0, 167783612, 0, 0, 0, 603979777, 0, 0, 0, 167783613, 0, 0, 0, 335609855, 0, 0, 0, 167783614, 0, 0, 0, 603979777, 0, 0, 0, 167783615, 0, 0, 0, 335609855, 0, 0, 0, 167783616, 0, 0, 0, 603979777, 0, 0, 0, 167783617, 0, 0, 0, 335609855, 0, 0, 0, 167783618, 0, 0, 0, 603979777, 0, 0, 0, 167783619, 0, 0, 0, 335609855, 0, 0, 0, 167783620, 0, 0, 0, 603979777, 0, 0, 0, 167783621, 0, 0, 0, 335609855, 0, 0, 0, 167783622, 0, 0, 0, 603979777, 0, 0, 0, 167783623, 0, 0, 0, 335609855, 0, 0, 0, 167783624, 0, 0, 0, 603979777, 0, 0, 0, 167783625, 0, 0, 0, 335609855, 0, 0, 0, 167783626, 0, 0, 0, 603979777, 0, 0, 0, 167783627, 0, 0, 0, 335609855, 0, 0, 0, 167783628, 0, 0, 0, 603979777, 0, 0, 0, 167783629, 0, 0, 0, 335609855, 0, 0, 0, 167783630, 0, 0, 0, 603979777, 0, 0, 0, 167783631, 0, 0, 0, 335609855, 0, 0, 0, 167783632, 0, 0, 0, 603979777, 0, 0, 0, 167783633, 0, 0, 0, 335609855, 0, 0, 0, 167783634, 0, 0, 0, 603979777, 0, 0, 0, 167783635, 0, 0, 0, 335609855, 0, 0, 0, 167783636, 0, 0, 0, 603979777, 0, 0, 0, 167783637, 0, 0, 0, 335609855, 0, 0, 0, 167783638, 0, 0, 0, 603979777, 0, 0, 0, 167783639, 0, 0, 0, 335609855, 0, 0, 0, 167783640, 0, 0, 0, 603979777, 0, 0, 0, 167783641, 0, 0, 0, 335609855, 0, 0, 0, 167783642, 0, 0, 0, 603979777, 0, 0, 0, 167783643, 0, 0, 0, 335609855, 0, 0, 0, 167783644, 0, 0, 0, 603979777, 0, 0, 0, 167783645, 0, 0, 0, 335609855, 0, 0, 0, 167783646, 0, 0, 0, 603979777, 0, 0, 0, 167783647, 0, 0, 0, 335609855, 0, 0, 0, 167783648, 0, 0, 0, 603979777, 0, 0, 0, 167783649, 0, 0, 0, 335609855, 0, 0, 0, 167783650, 0, 0, 0, 603979777, 0, 0, 0, 167783651, 0, 0, 0, 335609855, 0, 0, 0, 167783652, 0, 0, 0, 335544320, 0, 0, 0, 176172261, 0, 0, 0, 1744830469, 0, 0, 0, 176172281, 0, 0, 0, 1409286147, 0, 0, 0, 167783677, 0, 0, 0, 1006632960, 0, 0, 0, 176172286, 0, 0, 0, 1409286145, 0, 0, 0, 268446976, 0, 0, 0, 335602592, 0, 0, 0, 268446977, 0, 0, 0, 335602592, 0, 0, 0, 268446978, 0, 0, 0, 335602592, 0, 0, 0, 268446979, 0, 0, 0, 335602592, 0, 0, 0, 268446980, 0, 0, 0, 335602592, 0, 0, 0, 268446981, 0, 0, 0, 335602592, 0, 0, 0, 268446982, 0, 0, 0, 335602592, 0, 0, 0, 268446983, 0, 0, 0, 335602592, 0, 0, 0, 268446984, 0, 0, 0, 335602592, 0, 0, 0, 268446985, 0, 0, 0, 335602592, 0, 0, 0, 268446986, 0, 0, 0, 335602592, 0, 0, 0, 268446987, 0, 0, 0, 335602592, 0, 0, 0, 268446988, 0, 0, 0, 335602592, 0, 0, 0, 268446989, 0, 0, 0, 335602592, 0, 0, 0, 268446990, 0, 0, 0, 335602592, 0, 0, 0, 268446991, 0, 0, 0, 335602592, 0, 0, 0, 268446992, 0, 0, 0, 335602592, 0, 0, 0, 268446993, 0, 0, 0, 335602592, 0, 0, 0, 268446994, 0, 0, 0, 335602592, 0, 0, 0, 268446995, 0, 0, 0, 335602592, 0, 0, 0, 268446996, 0, 0, 0, 335602592, 0, 0, 0, 268446997, 0, 0, 0, 335602592, 0, 0, 0, 268446998, 0, 0, 0, 335602592, 0, 0, 0, 268446999, 0, 0, 0, 335602592, 0, 0, 0, 268447e3, 0, 0, 0, 335602592, 0, 0, 0, 268447001, 0, 0, 0, 335602592, 0, 0, 0, 268447002, 0, 0, 0, 335602592, 0, 0, 0, 268447003, 0, 0, 0, 335602592, 0, 0, 0, 268447004, 0, 0, 0, 335602592, 0, 0, 0, 268447005, 0, 0, 0, 335602592, 0, 0, 0, 268447006, 0, 0, 0, 335602592, 0, 0, 0, 268447007, 0, 0, 0, 335602592, 0, 0, 0, 268447008, 0, 0, 0, 335602592, 0, 0, 0, 268447009, 0, 0, 0, 335602592, 0, 0, 0, 268447010, 0, 0, 0, 335602592, 0, 0, 0, 268447011, 0, 0, 0, 335602592, 0, 0, 0, 268447012, 0, 0, 0, 335602592, 0, 0, 0, 268447013, 0, 0, 0, 335602592, 0, 0, 0, 981478704, 0, 0, 0, 469762101, 0, 0, 0, 973090159, 0, 0, 0, 402653184, 0, 0, 0, 260058496, 0, 0, 0, 469762070, 0, 0, 0, 260058528, 0, 0, 0, 469762054, 0, 0, 0, 260058536, 0, 0, 0, 469762054, 0, 0, 0, 260058544, 0, 0, 0, 469762054, 0, 0, 0, 260058552, 0, 0, 0, 469762054, 0, 0, 0, 260058560, 0, 0, 0, 469762054, 0, 0, 0, 260058568, 0, 0, 0, 469762054, 0, 0, 0, 260058576, 0, 0, 0, 469762054, 0, 0, 0, 260058584, 0, 0, 0, 469762054, 0, 0, 0, 159395328, 0, 0, 0, 1409286145, 0, 0, 0, 151006722, 0, 0, 0, 1342177280, 0, 0, 0, 151006723, 0, 0, 0, 1275068416, 0, 0, 0, 151006724, 0, 0, 0, 1342177280, 0, 0, 0, 151006725, 0, 0, 0, 1275068416, 0, 0, 0, 159395334, 0, 0, 0, 1409286146, 0, 0, 0, 151006729, 0, 0, 0, 1342177280, 0, 0, 0, 151006730, 0, 0, 0, 1275068416, 0, 0, 0, 151006731, 0, 0, 0, 1409286144, 0, 0, 0, 151006732, 0, 0, 0, 1342177280, 0, 0, 0, 151006733, 0, 0, 0, 1275068416, 0, 0, 0, 159395342, 0, 0, 0, 1409286152, 0, 0, 0, 151006743, 0, 0, 0, 1140850688, 0, 0, 0, 151006748, 0, 0, 0, 1342177280, 0, 0, 0, 151006749, 0, 0, 0, 1275068416, 0, 0, 0, 377499264, 0, 0, 0, 1744830489, 0, 0, 0, 377499291, 0, 0, 0, 1744830552, 0, 0, 0, 377499392, 0, 0, 0, 1744830677, 0, 0, 0, 159395824, 0, 0, 0, 1744830475, 0, 0, 0, 151007232, 0, 0, 0, 1946157056, 0, 0, 0, 159395841, 0, 0, 0, 1409286146, 0, 0, 0, 151007236, 0, 0, 0, 1744830464, 0, 0, 0, 369111045, 0, 0, 0, 402653184, 0, 0, 0, 151007238, 0, 0, 0, 469762048, 0, 0, 0, 369111047, 0, 0, 0, 939524096, 0, 0, 0, 151007240, 0, 0, 0, 1476395008, 0, 0, 0, 151007241, 0, 0, 0, 1207959552, 0, 0, 0, 151007242, 0, 0, 0, 1476395008, 0, 0, 0, 151007243, 0, 0, 0, 1207959552, 0, 0, 0, 151007244, 0, 0, 0, 1476395008, 0, 0, 0, 151007245, 0, 0, 0, 1207959552, 0, 0, 0, 151007246, 0, 0, 0, 1476395008, 0, 0, 0, 151007247, 0, 0, 0, 1207959552, 0, 0, 0, 151007248, 0, 0, 0, 1476395008, 0, 0, 0, 151007249, 0, 0, 0, 1207959552, 0, 0, 0, 159395858, 0, 0, 0, 1744830465, 0, 0, 0, 151007252, 0, 0, 0, 1476395008, 0, 0, 0, 151007253, 0, 0, 0, 1207959552, 0, 0, 0, 151007254, 0, 0, 0, 1476395008, 0, 0, 0, 151007255, 0, 0, 0, 1207959552, 0, 0, 0, 151007256, 0, 0, 0, 1476395008, 0, 0, 0, 151007257, 0, 0, 0, 1207959552, 0, 0, 0, 151007258, 0, 0, 0, 1476395008, 0, 0, 0, 151007259, 0, 0, 0, 1207959552, 0, 0, 0, 151007260, 0, 0, 0, 1140850688, 0, 0, 0, 151007261, 0, 0, 0, 1476395008, 0, 0, 0, 159395870, 0, 0, 0, 1207959553, 0, 0, 0, 151007264, 0, 0, 0, 1744830464, 0, 0, 0, 377499681, 0, 0, 0, 939524104, 0, 0, 0, 461385770, 0, 0, 0, 805306373, 0, 0, 0, 151007280, 0, 0, 0, 1140850688, 0, 0, 0, 159395889, 0, 0, 0, 402653188, 0, 0, 0, 159395894, 0, 0, 0, 1744830465, 0, 0, 0, 377499704, 0, 0, 0, 939524098, 0, 0, 0, 369111099, 0, 0, 0, 402653184, 0, 0, 0, 151007292, 0, 0, 0, 469762048, 0, 0, 0, 151007293, 0, 0, 0, 1409286144, 0, 0, 0, 159395902, 0, 0, 0, 1744830465, 0, 0, 0, 444608577, 0, 0, 0, 469762133, 0, 0, 0, 461385881, 0, 0, 0, 805306369, 0, 0, 0, 159395995, 0, 0, 0, 1610612737, 0, 0, 0, 444608669, 0, 0, 0, 402653185, 0, 0, 0, 436220063, 0, 0, 0, 469762048, 0, 0, 0, 151007392, 0, 0, 0, 1140850688, 0, 0, 0, 494940321, 0, 0, 0, 469762137, 0, 0, 0, 151007483, 0, 0, 0, 1409286144, 0, 0, 0, 159396092, 0, 0, 0, 402653186, 0, 0, 0, 486551807, 0, 0, 0, 469762048, 0, 0, 0, 58732805, 0, 0, 0, 469762087, 0, 0, 0, 394277169, 0, 0, 0, 469762141, 0, 0, 0, 159396240, 0, 0, 0, 1744830465, 0, 0, 0, 159396242, 0, 0, 0, 1006632963, 0, 0, 0, 159396246, 0, 0, 0, 1744830473, 0, 0, 0, 58732960, 0, 0, 0, 469762071, 0, 0, 0, 159396288, 0, 0, 0, 1744830479, 0, 0, 0, 494940656, 0, 0, 0, 469762063, 0, 0, 0, 394277376, 0, 0, 0, 1744830494, 0, 0, 0, 159396384, 0, 0, 0, 1006632969, 0, 0, 0, 159396394, 0, 0, 0, 1744830489, 0, 0, 0, 151007824, 0, 0, 0, 1744830464, 0, 0, 0, 159396433, 0, 0, 0, 1006632974, 0, 0, 0, 394277472, 0, 0, 0, 1744830495, 0, 0, 0, 159396480, 0, 0, 0, 1006632969, 0, 0, 0, 159396490, 0, 0, 0, 1744830502, 0, 0, 0, 159396529, 0, 0, 0, 1006632974, 0, 0, 0, 159396544, 0, 0, 0, 1744830526, 0, 0, 0, 159396608, 0, 0, 0, 1744830719, 0, 0, 0, 377500672, 0, 0, 0, 469768629, 0, 0, 0, 159403456, 0, 0, 0, 1744830527, 0, 0, 0, 377507328, 0, 0, 0, 469782971, 0, 0, 0, 1015062528, 0, 0, 0, 469762068, 0, 0, 0, 1006673941, 0, 0, 0, 402653184, 0, 0, 0, 1015062550, 0, 0, 0, 469763190, 0, 0, 0, 1015063696, 0, 0, 0, 1744830518, 0, 0, 0, 159426304, 0, 0, 0, 1610612758, 0, 0, 0, 813737984, 0, 0, 0, 469762049, 0, 0, 0, 805349378, 0, 0, 0, 671088640, 0, 0, 0, 813737987, 0, 0, 0, 469762050, 0, 0, 0, 805349382, 0, 0, 0, 805306368, 0, 0, 0, 813737991, 0, 0, 0, 469762051, 0, 0, 0, 805349387, 0, 0, 0, 805306368, 0, 0, 0, 813737996, 0, 0, 0, 469762070, 0, 0, 0, 813738019, 0, 0, 0, 671088641, 0, 0, 0, 813738021, 0, 0, 0, 805306369, 0, 0, 0, 805349415, 0, 0, 0, 671088640, 0, 0, 0, 813738024, 0, 0, 0, 1744830467, 0, 0, 0, 394308608, 0, 0, 0, 469773219, 0, 0, 0, 159438848, 0, 0, 0, 268436351, 0, 0, 0, 159439744, 0, 0, 0, 268435583, 0, 0, 0, 159439872, 0, 0, 0, 268436479, 0, 0, 0, 159440896, 0, 0, 0, 201332991, 0, 0, 0, 377551104, 0, 0, 0, 469762349, 0, 0, 0, 377551408, 0, 0, 0, 469762106, 0, 0, 0, 377551472, 0, 0, 0, 469762153, 0, 0, 0, 562100992, 0, 0, 0, 335544326, 0, 0, 0, 25230099, 0, 0, 0, 335544324, 0, 0, 0, 419494685, 0, 0, 0, 469762048, 0, 0, 0, 419494686, 0, 0, 0, 805306368, 0, 0, 0, 427883295, 0, 0, 0, 469762057, 0, 0, 0, 419494697, 0, 0, 0, 1677721600, 0, 0, 0, 427883306, 0, 0, 0, 469762060, 0, 0, 0, 427883320, 0, 0, 0, 469762052, 0, 0, 0, 419494718, 0, 0, 0, 469762048, 0, 0, 0, 427883328, 0, 0, 0, 469762049, 0, 0, 0, 427883331, 0, 0, 0, 469762049, 0, 0, 0, 427883334, 0, 0, 0, 469762155, 0, 0, 0, 8453075, 0, 0, 0, 469762410, 0, 0, 0, 151059774, 0, 0, 0, 1476395008, 0, 0, 0, 151059775, 0, 0, 0, 1207959552, 0, 0, 0, 8453456, 0, 0, 0, 469762111, 0, 0, 0, 8453522, 0, 0, 0, 469762101, 0, 0, 0, 8453616, 0, 0, 0, 469762059, 0, 0, 0, 65020, 0, 0, 0, 1543503872, 0, 0, 0, 151059965, 0, 0, 0, 1744830464, 0, 0, 0, 461438464, 0, 0, 0, 805306383, 0, 0, 0, 159448592, 0, 0, 0, 1409286150, 0, 0, 0, 151059991, 0, 0, 0, 1476395008, 0, 0, 0, 151059992, 0, 0, 0, 1207959552, 0, 0, 0, 151059993, 0, 0, 0, 1409286144, 0, 0, 0, 461438496, 0, 0, 0, 805306371, 0, 0, 0, 151060016, 0, 0, 0, 1409286144, 0, 0, 0, 159448625, 0, 0, 0, 1140850689, 0, 0, 0, 159448627, 0, 0, 0, 1073741825, 0, 0, 0, 151060021, 0, 0, 0, 1476395008, 0, 0, 0, 151060022, 0, 0, 0, 1207959552, 0, 0, 0, 151060023, 0, 0, 0, 1476395008, 0, 0, 0, 151060024, 0, 0, 0, 1207959552, 0, 0, 0, 151060025, 0, 0, 0, 1476395008, 0, 0, 0, 151060026, 0, 0, 0, 1207959552, 0, 0, 0, 151060027, 0, 0, 0, 1476395008, 0, 0, 0, 151060028, 0, 0, 0, 1207959552, 0, 0, 0, 151060029, 0, 0, 0, 1476395008, 0, 0, 0, 151060030, 0, 0, 0, 1207959552, 0, 0, 0, 151060031, 0, 0, 0, 1476395008, 0, 0, 0, 151060032, 0, 0, 0, 1207959552, 0, 0, 0, 151060033, 0, 0, 0, 1476395008, 0, 0, 0, 151060034, 0, 0, 0, 1207959552, 0, 0, 0, 151060035, 0, 0, 0, 1476395008, 0, 0, 0, 151060036, 0, 0, 0, 1207959552, 0, 0, 0, 159448645, 0, 0, 0, 1409286145, 0, 0, 0, 151060039, 0, 0, 0, 1476395008, 0, 0, 0, 151060040, 0, 0, 0, 1207959552, 0, 0, 0, 159448649, 0, 0, 0, 1409286147, 0, 0, 0, 159448653, 0, 0, 0, 1073741826, 0, 0, 0, 159448656, 0, 0, 0, 1409286146, 0, 0, 0, 159448660, 0, 0, 0, 1409286147, 0, 0, 0, 151060056, 0, 0, 0, 1140850688, 0, 0, 0, 151060057, 0, 0, 0, 1476395008, 0, 0, 0, 151060058, 0, 0, 0, 1207959552, 0, 0, 0, 151060059, 0, 0, 0, 1476395008, 0, 0, 0, 151060060, 0, 0, 0, 1207959552, 0, 0, 0, 151060061, 0, 0, 0, 1476395008, 0, 0, 0, 151060062, 0, 0, 0, 1207959552, 0, 0, 0, 159448671, 0, 0, 0, 1409286146, 0, 0, 0, 151060066, 0, 0, 0, 1677721600, 0, 0, 0, 151060067, 0, 0, 0, 1140850688, 0, 0, 0, 159448676, 0, 0, 0, 1677721602, 0, 0, 0, 151060072, 0, 0, 0, 1409286144, 0, 0, 0, 151060073, 0, 0, 0, 1543503872, 0, 0, 0, 159448682, 0, 0, 0, 1409286145, 0, 0, 0, 8453744, 0, 0, 0, 469762052, 0, 0, 0, 8453750, 0, 0, 0, 469762182, 0, 0, 0, 151060223, 0, 0, 0, 67108864, 0, 0, 0, 159448833, 0, 0, 0, 1409286146, 0, 0, 0, 151060228, 0, 0, 0, 1543503872, 0, 0, 0, 159448837, 0, 0, 0, 1409286146, 0, 0, 0, 151060232, 0, 0, 0, 1476395008, 0, 0, 0, 151060233, 0, 0, 0, 1207959552, 0, 0, 0, 151060234, 0, 0, 0, 1409286144, 0, 0, 0, 151060235, 0, 0, 0, 1677721600, 0, 0, 0, 151060236, 0, 0, 0, 1409286144, 0, 0, 0, 151060237, 0, 0, 0, 1140850688, 0, 0, 0, 159448846, 0, 0, 0, 1409286145, 0, 0, 0, 159448848, 0, 0, 0, 872415241, 0, 0, 0, 159448858, 0, 0, 0, 1409286145, 0, 0, 0, 159448860, 0, 0, 0, 1677721602, 0, 0, 0, 159448863, 0, 0, 0, 1409286145, 0, 0, 0, 553713441, 0, 0, 0, 603979808, 0, 0, 0, 553713442, 0, 0, 0, 603979808, 0, 0, 0, 553713443, 0, 0, 0, 603979808, 0, 0, 0, 553713444, 0, 0, 0, 603979808, 0, 0, 0, 553713445, 0, 0, 0, 603979808, 0, 0, 0, 553713446, 0, 0, 0, 603979808, 0, 0, 0, 553713447, 0, 0, 0, 603979808, 0, 0, 0, 553713448, 0, 0, 0, 603979808, 0, 0, 0, 553713449, 0, 0, 0, 603979808, 0, 0, 0, 553713450, 0, 0, 0, 603979808, 0, 0, 0, 553713451, 0, 0, 0, 603979808, 0, 0, 0, 553713452, 0, 0, 0, 603979808, 0, 0, 0, 553713453, 0, 0, 0, 603979808, 0, 0, 0, 553713454, 0, 0, 0, 603979808, 0, 0, 0, 553713455, 0, 0, 0, 603979808, 0, 0, 0, 553713456, 0, 0, 0, 603979808, 0, 0, 0, 553713457, 0, 0, 0, 603979808, 0, 0, 0, 553713458, 0, 0, 0, 603979808, 0, 0, 0, 553713459, 0, 0, 0, 603979808, 0, 0, 0, 553713460, 0, 0, 0, 603979808, 0, 0, 0, 553713461, 0, 0, 0, 603979808, 0, 0, 0, 553713462, 0, 0, 0, 603979808, 0, 0, 0, 553713463, 0, 0, 0, 603979808, 0, 0, 0, 553713464, 0, 0, 0, 603979808, 0, 0, 0, 553713465, 0, 0, 0, 603979808, 0, 0, 0, 553713466, 0, 0, 0, 603979808, 0, 0, 0, 151060283, 0, 0, 0, 1476395008, 0, 0, 0, 151060284, 0, 0, 0, 1409286144, 0, 0, 0, 151060285, 0, 0, 0, 1207959552, 0, 0, 0, 151060286, 0, 0, 0, 1610612736, 0, 0, 0, 151060287, 0, 0, 0, 1073741824, 0, 0, 0, 151060288, 0, 0, 0, 1610612736, 0, 0, 0, 553713473, 0, 0, 0, 335609824, 0, 0, 0, 553713474, 0, 0, 0, 335609824, 0, 0, 0, 553713475, 0, 0, 0, 335609824, 0, 0, 0, 553713476, 0, 0, 0, 335609824, 0, 0, 0, 553713477, 0, 0, 0, 335609824, 0, 0, 0, 553713478, 0, 0, 0, 335609824, 0, 0, 0, 553713479, 0, 0, 0, 335609824, 0, 0, 0, 553713480, 0, 0, 0, 335609824, 0, 0, 0, 553713481, 0, 0, 0, 335609824, 0, 0, 0, 553713482, 0, 0, 0, 335609824, 0, 0, 0, 553713483, 0, 0, 0, 335609824, 0, 0, 0, 553713484, 0, 0, 0, 335609824, 0, 0, 0, 553713485, 0, 0, 0, 335609824, 0, 0, 0, 553713486, 0, 0, 0, 335609824, 0, 0, 0, 553713487, 0, 0, 0, 335609824, 0, 0, 0, 553713488, 0, 0, 0, 335609824, 0, 0, 0, 553713489, 0, 0, 0, 335609824, 0, 0, 0, 553713490, 0, 0, 0, 335609824, 0, 0, 0, 553713491, 0, 0, 0, 335609824, 0, 0, 0, 553713492, 0, 0, 0, 335609824, 0, 0, 0, 553713493, 0, 0, 0, 335609824, 0, 0, 0, 553713494, 0, 0, 0, 335609824, 0, 0, 0, 553713495, 0, 0, 0, 335609824, 0, 0, 0, 553713496, 0, 0, 0, 335609824, 0, 0, 0, 553713497, 0, 0, 0, 335609824, 0, 0, 0, 553713498, 0, 0, 0, 335609824, 0, 0, 0, 151060315, 0, 0, 0, 1476395008, 0, 0, 0, 151060316, 0, 0, 0, 1677721600, 0, 0, 0, 151060317, 0, 0, 0, 1207959552, 0, 0, 0, 151060318, 0, 0, 0, 1677721600, 0, 0, 0, 151060319, 0, 0, 0, 1476395008, 0, 0, 0, 151060320, 0, 0, 0, 1207959552, 0, 0, 0, 151060321, 0, 0, 0, 1409286144, 0, 0, 0, 151060322, 0, 0, 0, 1476395008, 0, 0, 0, 151060323, 0, 0, 0, 1207959552, 0, 0, 0, 159448932, 0, 0, 0, 1409286145, 0, 0, 0, 494993254, 0, 0, 0, 469762057, 0, 0, 0, 151060336, 0, 0, 0, 402653184, 0, 0, 0, 494993265, 0, 0, 0, 469762092, 0, 0, 0, 159448990, 0, 0, 0, 402653185, 0, 0, 0, 394330016, 0, 0, 0, 469762078, 0, 0, 0, 394330050, 0, 0, 0, 469762053, 0, 0, 0, 394330058, 0, 0, 0, 469762053, 0, 0, 0, 394330066, 0, 0, 0, 469762053, 0, 0, 0, 394330074, 0, 0, 0, 469762050, 0, 0, 0, 159449056, 0, 0, 0, 1543503873, 0, 0, 0, 151060450, 0, 0, 0, 1677721600, 0, 0, 0, 151060451, 0, 0, 0, 1610612736, 0, 0, 0, 151060452, 0, 0, 0, 1744830464, 0, 0, 0, 159449061, 0, 0, 0, 1543503873, 0, 0, 0, 151060456, 0, 0, 0, 1744830464, 0, 0, 0, 159449065, 0, 0, 0, 1677721603, 0, 0, 0, 159449069, 0, 0, 0, 1744830465, 0, 0, 0, 159449081, 0, 0, 0, 67108866, 0, 0, 0, 159449084, 0, 0, 0, 1744830465, 0, 0, 0, 595656704, 0, 0, 0, 469762059, 0, 0, 0, 595656717, 0, 0, 0, 469762073, 0, 0, 0, 595656744, 0, 0, 0, 469762066, 0, 0, 0, 595656764, 0, 0, 0, 469762049, 0, 0, 0, 595656767, 0, 0, 0, 469762062, 0, 0, 0, 595656784, 0, 0, 0, 469762061, 0, 0, 0, 595656832, 0, 0, 0, 469762170, 0, 0, 0, 159449344, 0, 0, 0, 1409286145, 0, 0, 0, 151060738, 0, 0, 0, 1744830464, 0, 0, 0, 159449351, 0, 0, 0, 1006633004, 0, 0, 0, 159449399, 0, 0, 0, 1744830472, 0, 0, 0, 327221568, 0, 0, 0, 939524148, 0, 0, 0, 327221621, 0, 0, 0, 1006632963, 0, 0, 0, 327221625, 0, 0, 0, 1744830480, 0, 0, 0, 318833034, 0, 0, 0, 1006632960, 0, 0, 0, 696320768, 0, 0, 0, 469762078, 0, 0, 0, 696320800, 0, 0, 0, 1006632963, 0, 0, 0, 310444848, 0, 0, 0, 469762073, 0, 0, 0, 302056266, 0, 0, 0, 939524096, 0, 0, 0, 998310784, 0, 0, 0, 469762077, 0, 0, 0, 989922207, 0, 0, 0, 1409286144, 0, 0, 0, 713098144, 0, 0, 0, 469762083, 0, 0, 0, 713098184, 0, 0, 0, 469762055, 0, 0, 0, 704709584, 0, 0, 0, 1744830464, 0, 0, 0, 713098193, 0, 0, 0, 939524100, 0, 0, 0, 218170368, 0, 0, 0, 603979816, 0, 0, 0, 218170369, 0, 0, 0, 603979816, 0, 0, 0, 218170370, 0, 0, 0, 603979816, 0, 0, 0, 218170371, 0, 0, 0, 603979816, 0, 0, 0, 218170372, 0, 0, 0, 603979816, 0, 0, 0, 218170373, 0, 0, 0, 603979816, 0, 0, 0, 218170374, 0, 0, 0, 603979816, 0, 0, 0, 218170375, 0, 0, 0, 603979816, 0, 0, 0, 218170376, 0, 0, 0, 603979816, 0, 0, 0, 218170377, 0, 0, 0, 603979816, 0, 0, 0, 218170378, 0, 0, 0, 603979816, 0, 0, 0, 218170379, 0, 0, 0, 603979816, 0, 0, 0, 218170380, 0, 0, 0, 603979816, 0, 0, 0, 218170381, 0, 0, 0, 603979816, 0, 0, 0, 218170382, 0, 0, 0, 603979816, 0, 0, 0, 218170383, 0, 0, 0, 603979816, 0, 0, 0, 218170384, 0, 0, 0, 603979816, 0, 0, 0, 218170385, 0, 0, 0, 603979816, 0, 0, 0, 218170386, 0, 0, 0, 603979816, 0, 0, 0, 218170387, 0, 0, 0, 603979816, 0, 0, 0, 218170388, 0, 0, 0, 603979816, 0, 0, 0, 218170389, 0, 0, 0, 603979816, 0, 0, 0, 218170390, 0, 0, 0, 603979816, 0, 0, 0, 218170391, 0, 0, 0, 603979816, 0, 0, 0, 218170392, 0, 0, 0, 603979816, 0, 0, 0, 218170393, 0, 0, 0, 603979816, 0, 0, 0, 218170394, 0, 0, 0, 603979816, 0, 0, 0, 218170395, 0, 0, 0, 603979816, 0, 0, 0, 218170396, 0, 0, 0, 603979816, 0, 0, 0, 218170397, 0, 0, 0, 603979816, 0, 0, 0, 218170398, 0, 0, 0, 603979816, 0, 0, 0, 218170399, 0, 0, 0, 603979816, 0, 0, 0, 218170400, 0, 0, 0, 603979816, 0, 0, 0, 218170401, 0, 0, 0, 603979816, 0, 0, 0, 218170402, 0, 0, 0, 603979816, 0, 0, 0, 218170403, 0, 0, 0, 603979816, 0, 0, 0, 218170404, 0, 0, 0, 603979816, 0, 0, 0, 218170405, 0, 0, 0, 603979816, 0, 0, 0, 218170406, 0, 0, 0, 603979816, 0, 0, 0, 218170407, 0, 0, 0, 603979816, 0, 0, 0, 218170408, 0, 0, 0, 335609816, 0, 0, 0, 218170409, 0, 0, 0, 335609816, 0, 0, 0, 218170410, 0, 0, 0, 335609816, 0, 0, 0, 218170411, 0, 0, 0, 335609816, 0, 0, 0, 218170412, 0, 0, 0, 335609816, 0, 0, 0, 218170413, 0, 0, 0, 335609816, 0, 0, 0, 218170414, 0, 0, 0, 335609816, 0, 0, 0, 218170415, 0, 0, 0, 335609816, 0, 0, 0, 218170416, 0, 0, 0, 335609816, 0, 0, 0, 218170417, 0, 0, 0, 335609816, 0, 0, 0, 218170418, 0, 0, 0, 335609816, 0, 0, 0, 218170419, 0, 0, 0, 335609816, 0, 0, 0, 218170420, 0, 0, 0, 335609816, 0, 0, 0, 218170421, 0, 0, 0, 335609816, 0, 0, 0, 218170422, 0, 0, 0, 335609816, 0, 0, 0, 218170423, 0, 0, 0, 335609816, 0, 0, 0, 218170424, 0, 0, 0, 335609816, 0, 0, 0, 218170425, 0, 0, 0, 335609816, 0, 0, 0, 218170426, 0, 0, 0, 335609816, 0, 0, 0, 218170427, 0, 0, 0, 335609816, 0, 0, 0, 218170428, 0, 0, 0, 335609816, 0, 0, 0, 218170429, 0, 0, 0, 335609816, 0, 0, 0, 218170430, 0, 0, 0, 335609816, 0, 0, 0, 218170431, 0, 0, 0, 335609816, 0, 0, 0, 218170432, 0, 0, 0, 335609816, 0, 0, 0, 218170433, 0, 0, 0, 335609816, 0, 0, 0, 218170434, 0, 0, 0, 335609816, 0, 0, 0, 218170435, 0, 0, 0, 335609816, 0, 0, 0, 218170436, 0, 0, 0, 335609816, 0, 0, 0, 218170437, 0, 0, 0, 335609816, 0, 0, 0, 218170438, 0, 0, 0, 335609816, 0, 0, 0, 218170439, 0, 0, 0, 335609816, 0, 0, 0, 218170440, 0, 0, 0, 335609816, 0, 0, 0, 218170441, 0, 0, 0, 335609816, 0, 0, 0, 218170442, 0, 0, 0, 335609816, 0, 0, 0, 218170443, 0, 0, 0, 335609816, 0, 0, 0, 218170444, 0, 0, 0, 335609816, 0, 0, 0, 218170445, 0, 0, 0, 335609816, 0, 0, 0, 218170446, 0, 0, 0, 335609816, 0, 0, 0, 218170447, 0, 0, 0, 335609816, 0, 0, 0, 780207184, 0, 0, 0, 469762125, 0, 0, 0, 746652832, 0, 0, 0, 872415241, 0, 0, 0, 193005568, 0, 0, 0, 469762053, 0, 0, 0, 184616968, 0, 0, 0, 469762048, 0, 0, 0, 193005578, 0, 0, 0, 469762091, 0, 0, 0, 193005623, 0, 0, 0, 469762049, 0, 0, 0, 184617020, 0, 0, 0, 469762048, 0, 0, 0, 184617023, 0, 0, 0, 469762048, 0, 0, 0, 503384576, 0, 0, 0, 469762048, 0, 0, 0, 511773185, 0, 0, 0, 805306370, 0, 0, 0, 511773189, 0, 0, 0, 805306369, 0, 0, 0, 511773196, 0, 0, 0, 805306371, 0, 0, 0, 511773200, 0, 0, 0, 469762051, 0, 0, 0, 511773205, 0, 0, 0, 469762050, 0, 0, 0, 511773209, 0, 0, 0, 469762074, 0, 0, 0, 511773240, 0, 0, 0, 805306370, 0, 0, 0, 503384639, 0, 0, 0, 805306368, 0, 0, 0, 511773248, 0, 0, 0, 1006632967, 0, 0, 0, 511773264, 0, 0, 0, 1409286152, 0, 0, 0, 159502336, 0, 0, 0, 1744830709, 0, 0, 0, 159502592, 0, 0, 0, 1744830502, 0, 0, 0, 159502634, 0, 0, 0, 1744830522, 0, 0, 0, 159502693, 0, 0, 0, 671088641, 0, 0, 0, 461492583, 0, 0, 0, 805306370, 0, 0, 0, 159502698, 0, 0, 0, 1744830466, 0, 0, 0, 159502701, 0, 0, 0, 671088645, 0, 0, 0, 159502707, 0, 0, 0, 67108871, 0, 0, 0, 461492603, 0, 0, 0, 805306375, 0, 0, 0, 159502723, 0, 0, 0, 1744830465, 0, 0, 0, 461492613, 0, 0, 0, 805306374, 0, 0, 0, 159502732, 0, 0, 0, 1744830493, 0, 0, 0, 461492650, 0, 0, 0, 805306371, 0, 0, 0, 159502766, 0, 0, 0, 1744830511, 0, 0, 0, 327275008, 0, 0, 0, 1744830529, 0, 0, 0, 327275074, 0, 0, 0, 805306370, 0, 0, 0, 318886469, 0, 0, 0, 1744830464, 0, 0, 0, 159503104, 0, 0, 0, 1744830550, 0, 0, 0, 159503360, 0, 0, 0, 603979801, 0, 0, 0, 159503386, 0, 0, 0, 335544345, 0, 0, 0, 159503412, 0, 0, 0, 603979801, 0, 0, 0, 159503438, 0, 0, 0, 335544326, 0, 0, 0, 159503446, 0, 0, 0, 335544337, 0, 0, 0, 159503464, 0, 0, 0, 603979801, 0, 0, 0, 159503490, 0, 0, 0, 335544345, 0, 0, 0, 151114908, 0, 0, 0, 603979776, 0, 0, 0, 159503518, 0, 0, 0, 603979777, 0, 0, 0, 151114914, 0, 0, 0, 603979776, 0, 0, 0, 159503525, 0, 0, 0, 603979777, 0, 0, 0, 159503529, 0, 0, 0, 603979779, 0, 0, 0, 159503534, 0, 0, 0, 603979783, 0, 0, 0, 159503542, 0, 0, 0, 335544323, 0, 0, 0, 151114939, 0, 0, 0, 335544320, 0, 0, 0, 159503549, 0, 0, 0, 335544326, 0, 0, 0, 159503557, 0, 0, 0, 335544330, 0, 0, 0, 159503568, 0, 0, 0, 603979801, 0, 0, 0, 159503594, 0, 0, 0, 335544345, 0, 0, 0, 159503620, 0, 0, 0, 603979777, 0, 0, 0, 159503623, 0, 0, 0, 603979779, 0, 0, 0, 159503629, 0, 0, 0, 603979783, 0, 0, 0, 159503638, 0, 0, 0, 603979782, 0, 0, 0, 159503646, 0, 0, 0, 335544345, 0, 0, 0, 159503672, 0, 0, 0, 603979777, 0, 0, 0, 159503675, 0, 0, 0, 603979779, 0, 0, 0, 159503680, 0, 0, 0, 603979780, 0, 0, 0, 151115078, 0, 0, 0, 603979776, 0, 0, 0, 159503690, 0, 0, 0, 603979782, 0, 0, 0, 159503698, 0, 0, 0, 335544345, 0, 0, 0, 159503724, 0, 0, 0, 603979801, 0, 0, 0, 159503750, 0, 0, 0, 335544345, 0, 0, 0, 159503776, 0, 0, 0, 603979801, 0, 0, 0, 159503802, 0, 0, 0, 335544345, 0, 0, 0, 159503828, 0, 0, 0, 603979801, 0, 0, 0, 159503854, 0, 0, 0, 335544345, 0, 0, 0, 159503880, 0, 0, 0, 603979801, 0, 0, 0, 159503906, 0, 0, 0, 335544345, 0, 0, 0, 159503932, 0, 0, 0, 603979801, 0, 0, 0, 159503958, 0, 0, 0, 335544345, 0, 0, 0, 159503984, 0, 0, 0, 603979801, 0, 0, 0, 159504010, 0, 0, 0, 335544347, 0, 0, 0, 159504040, 0, 0, 0, 603979800, 0, 0, 0, 151115457, 0, 0, 0, 1677721600, 0, 0, 0, 159504066, 0, 0, 0, 335544344, 0, 0, 0, 151115483, 0, 0, 0, 1677721600, 0, 0, 0, 159504092, 0, 0, 0, 335544325, 0, 0, 0, 159504098, 0, 0, 0, 603979800, 0, 0, 0, 151115515, 0, 0, 0, 1677721600, 0, 0, 0, 159504124, 0, 0, 0, 335544344, 0, 0, 0, 151115541, 0, 0, 0, 1677721600, 0, 0, 0, 159504150, 0, 0, 0, 335544325, 0, 0, 0, 159504156, 0, 0, 0, 603979800, 0, 0, 0, 151115573, 0, 0, 0, 1677721600, 0, 0, 0, 159504182, 0, 0, 0, 335544344, 0, 0, 0, 151115599, 0, 0, 0, 1677721600, 0, 0, 0, 159504208, 0, 0, 0, 335544325, 0, 0, 0, 159504214, 0, 0, 0, 603979800, 0, 0, 0, 151115631, 0, 0, 0, 1677721600, 0, 0, 0, 159504240, 0, 0, 0, 335544344, 0, 0, 0, 151115657, 0, 0, 0, 1677721600, 0, 0, 0, 159504266, 0, 0, 0, 335544325, 0, 0, 0, 159504272, 0, 0, 0, 603979800, 0, 0, 0, 151115689, 0, 0, 0, 1677721600, 0, 0, 0, 159504298, 0, 0, 0, 335544344, 0, 0, 0, 151115715, 0, 0, 0, 1677721600, 0, 0, 0, 159504324, 0, 0, 0, 335544325, 0, 0, 0, 159504334, 0, 0, 0, 872415281, 0, 0, 0, 377618432, 0, 0, 0, 469804758, 0, 0, 0, 377681920, 0, 0, 0, 469762589, 0, 0, 0, 151912449, 0, 0, 0, 67108864, 0, 0, 0, 160301088, 0, 0, 0, 67108959, 0, 0, 0, 462291200, 0, 0, 0, 805306607, 0, 0, 0, 160366592, 0, 0, 0, 201392125, 0, 0, 0, 160432128, 0, 0, 0, 201392125, 0, 0, 0 ], [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

STRING_TABLE.__str4498 = allocate([ 37, 100, 0 ], "i8", ALLOC_STATIC);

__gm_ = allocate(468, [ "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0, "*", 0, 0, 0, "i32", 0, 0, 0 ], ALLOC_STATIC);

_mparams = allocate(24, "i32", ALLOC_STATIC);

STRING_TABLE.__str293 = allocate([ 109, 97, 120, 32, 115, 121, 115, 116, 101, 109, 32, 98, 121, 116, 101, 115, 32, 61, 32, 37, 49, 48, 108, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str1294 = allocate([ 115, 121, 115, 116, 101, 109, 32, 98, 121, 116, 101, 115, 32, 32, 32, 32, 32, 61, 32, 37, 49, 48, 108, 117, 10, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__str2295 = allocate([ 105, 110, 32, 117, 115, 101, 32, 98, 121, 116, 101, 115, 32, 32, 32, 32, 32, 61, 32, 37, 49, 48, 108, 117, 10, 0 ], "i8", ALLOC_STATIC);

__ZSt7nothrow = allocate([ undef ], "i8", ALLOC_STATIC);

__ZL13__new_handler = allocate(1, "void ()*", ALLOC_STATIC);

__ZTVSt9bad_alloc = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 302, 0, 0, 0, 2e3, 0, 0, 0, 2002, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str3296 = allocate([ 115, 116, 100, 58, 58, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

__ZTVSt20bad_array_new_length = allocate([ 0, 0, 0, 0, 0, 0, 0, 0, 302, 0, 0, 0, 2004, 0, 0, 0, 2006, 0, 0, 0 ], [ "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0, "*", 0, 0, 0 ], ALLOC_STATIC);

allocate(1, "void*", ALLOC_STATIC);

STRING_TABLE.__str14297 = allocate([ 98, 97, 100, 95, 97, 114, 114, 97, 121, 95, 110, 101, 119, 95, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE.__ZTSSt9bad_alloc = allocate([ 83, 116, 57, 98, 97, 100, 95, 97, 108, 108, 111, 99, 0 ], "i8", ALLOC_STATIC);

__ZTISt9bad_alloc = allocate(12, "*", ALLOC_STATIC);

STRING_TABLE.__ZTSSt20bad_array_new_length = allocate([ 83, 116, 50, 48, 98, 97, 100, 95, 97, 114, 114, 97, 121, 95, 110, 101, 119, 95, 108, 101, 110, 103, 116, 104, 0 ], "i8", ALLOC_STATIC);

__ZTISt20bad_array_new_length = allocate(12, "*", ALLOC_STATIC);

STRING_TABLE._str = allocate([ 32, 123, 125, 0 ], "i8", ALLOC_STATIC);

STRING_TABLE._str1 = allocate([ 10, 125, 0 ], "i8", ALLOC_STATIC);

HEAP32[_DebuggerFrame_class >> 2] = STRING_TABLE.__str48 | 0;

HEAP32[_DebuggerObject_class >> 2] = STRING_TABLE._js_Object_str | 0;

HEAP32[__ZN2js8Debugger7jsclassE >> 2] = STRING_TABLE.__str2 | 0;

HEAP32[__ZN2js8Debugger10propertiesE >> 2] = STRING_TABLE.__str31 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 16 >> 2] = STRING_TABLE.__str32 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 32 >> 2] = STRING_TABLE.__str33 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 48 >> 2] = STRING_TABLE.__str34 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 64 >> 2] = STRING_TABLE.__str35 | 0;

HEAP32[__ZN2js8Debugger10propertiesE + 80 >> 2] = STRING_TABLE.__str21 | 0;

HEAP32[__ZN2js8Debugger7methodsE >> 2] = STRING_TABLE.__str23 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 12 >> 2] = STRING_TABLE.__str25 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 24 >> 2] = STRING_TABLE.__str27 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 36 >> 2] = STRING_TABLE.__str28 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 48 >> 2] = STRING_TABLE.__str29 | 0;

HEAP32[__ZN2js8Debugger7methodsE + 60 >> 2] = STRING_TABLE.__str30 | 0;

HEAP32[_DebuggerScript_class >> 2] = STRING_TABLE.__str23669 | 0;

HEAP32[__ZL25DebuggerScript_properties >> 2] = STRING_TABLE.__str37 | 0;

HEAP32[__ZL25DebuggerScript_properties + 16 >> 2] = STRING_TABLE.__str38 | 0;

HEAP32[__ZL25DebuggerScript_properties + 32 >> 2] = STRING_TABLE.__str39 | 0;

HEAP32[__ZL25DebuggerScript_properties + 48 >> 2] = STRING_TABLE.__str40 | 0;

HEAP32[__ZL22DebuggerScript_methods >> 2] = STRING_TABLE.__str41 | 0;

HEAP32[__ZL22DebuggerScript_methods + 12 >> 2] = STRING_TABLE.__str42 | 0;

HEAP32[__ZL22DebuggerScript_methods + 24 >> 2] = STRING_TABLE.__str43 | 0;

HEAP32[__ZL22DebuggerScript_methods + 36 >> 2] = STRING_TABLE.__str44 | 0;

HEAP32[__ZL22DebuggerScript_methods + 48 >> 2] = STRING_TABLE.__str45 | 0;

HEAP32[__ZL22DebuggerScript_methods + 60 >> 2] = STRING_TABLE.__str46 | 0;

HEAP32[__ZL22DebuggerScript_methods + 72 >> 2] = STRING_TABLE.__str47 | 0;

HEAP32[__ZL22DebuggerScript_methods + 84 >> 2] = STRING_TABLE.__str30 | 0;

HEAP32[_DebuggerArguments_class >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZL24DebuggerFrame_properties >> 2] = STRING_TABLE._js_arguments_str | 0;

HEAP32[__ZL24DebuggerFrame_properties + 16 >> 2] = STRING_TABLE._js_callee_str | 0;

HEAP32[__ZL24DebuggerFrame_properties + 32 >> 2] = STRING_TABLE.__str52 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 48 >> 2] = STRING_TABLE.__str2323384 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 64 >> 2] = STRING_TABLE.__str40 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 80 >> 2] = STRING_TABLE.__str54 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 96 >> 2] = STRING_TABLE.__str55 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 112 >> 2] = STRING_TABLE.__str33670 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 128 >> 2] = STRING_TABLE._js_this_str | 0;

HEAP32[__ZL24DebuggerFrame_properties + 144 >> 2] = STRING_TABLE.__str1763328 | 0;

HEAP32[__ZL24DebuggerFrame_properties + 160 >> 2] = STRING_TABLE.__str59 | 0;

HEAP32[__ZL21DebuggerFrame_methods >> 2] = STRING_TABLE._js_eval_str | 0;

HEAP32[__ZL21DebuggerFrame_methods + 12 >> 2] = STRING_TABLE.__str61 | 0;

HEAP32[__ZL25DebuggerObject_properties >> 2] = STRING_TABLE.__str63 | 0;

HEAP32[__ZL25DebuggerObject_properties + 16 >> 2] = STRING_TABLE._js_class_str | 0;

HEAP32[__ZL25DebuggerObject_properties + 32 >> 2] = STRING_TABLE.__str65 | 0;

HEAP32[__ZL25DebuggerObject_properties + 48 >> 2] = STRING_TABLE._js_name_str | 0;

HEAP32[__ZL25DebuggerObject_properties + 64 >> 2] = STRING_TABLE.__str67 | 0;

HEAP32[__ZL25DebuggerObject_properties + 80 >> 2] = STRING_TABLE.__str33670 | 0;

HEAP32[__ZL22DebuggerObject_methods >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[__ZL22DebuggerObject_methods + 12 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[__ZL22DebuggerObject_methods + 24 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[__ZL22DebuggerObject_methods + 36 >> 2] = STRING_TABLE.__str132210 | 0;

HEAP32[__ZL22DebuggerObject_methods + 48 >> 2] = STRING_TABLE.__str72 | 0;

HEAP32[__ZL22DebuggerObject_methods + 60 >> 2] = STRING_TABLE.__str202217 | 0;

HEAP32[__ZL22DebuggerObject_methods + 72 >> 2] = STRING_TABLE.__str182215 | 0;

HEAP32[__ZL22DebuggerObject_methods + 84 >> 2] = STRING_TABLE.__str172214 | 0;

HEAP32[__ZL22DebuggerObject_methods + 96 >> 2] = STRING_TABLE.__str212218 | 0;

HEAP32[__ZL22DebuggerObject_methods + 108 >> 2] = STRING_TABLE.__str192216 | 0;

HEAP32[__ZL22DebuggerObject_methods + 120 >> 2] = STRING_TABLE.__str162213 | 0;

HEAP32[__ZL22DebuggerObject_methods + 132 >> 2] = STRING_TABLE._js_apply_str | 0;

HEAP32[__ZL22DebuggerObject_methods + 144 >> 2] = STRING_TABLE._js_call_str | 0;

HEAP32[__ZN2jsL21GlobalDebuggees_classE >> 2] = STRING_TABLE.__str122 | 0;

HEAP32[__ZL6v2smap + 4 >> 2] = STRING_TABLE.__str9202 | 0;

HEAP32[__ZL6v2smap + 12 >> 2] = STRING_TABLE.__str10203 | 0;

HEAP32[__ZL6v2smap + 20 >> 2] = STRING_TABLE.__str11204 | 0;

HEAP32[__ZL6v2smap + 28 >> 2] = STRING_TABLE.__str12205 | 0;

HEAP32[__ZL6v2smap + 36 >> 2] = STRING_TABLE.__str13206 | 0;

HEAP32[__ZL6v2smap + 44 >> 2] = STRING_TABLE.__str14207 | 0;

HEAP32[__ZL6v2smap + 52 >> 2] = STRING_TABLE.__str15208 | 0;

HEAP32[__ZL6v2smap + 60 >> 2] = STRING_TABLE.__str16209 | 0;

HEAP32[__ZL6v2smap + 68 >> 2] = STRING_TABLE.__str17210 | 0;

HEAP32[__ZL6v2smap + 76 >> 2] = STRING_TABLE.__str18211 | 0;

HEAP32[__ZL6v2smap + 84 >> 2] = STRING_TABLE.__str19212 | 0;

HEAP32[__ZL6v2smap + 92 >> 2] = STRING_TABLE._js_default_str | 0;

HEAP32[_js_dummy_class >> 2] = STRING_TABLE.__str22215 | 0;

HEAP32[__ZL20standard_class_atoms + 12 >> 2] = __ZN2js13FunctionClassE;

HEAP32[__ZL20standard_class_atoms + 28 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL20standard_class_atoms + 44 >> 2] = __ZN2js10ArrayClassE;

HEAP32[__ZL20standard_class_atoms + 60 >> 2] = __ZN2js12BooleanClassE;

HEAP32[__ZL20standard_class_atoms + 76 >> 2] = __ZN2js9DateClassE;

HEAP32[__ZL20standard_class_atoms + 92 >> 2] = __ZN2js9MathClassE;

HEAP32[__ZL20standard_class_atoms + 108 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_atoms + 124 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_atoms + 140 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_atoms + 156 >> 2] = __ZN2js11RegExpClassE;

HEAP32[__ZL20standard_class_atoms + 172 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_atoms + 188 >> 2] = __ZN2js14NamespaceClassE;

HEAP32[__ZL20standard_class_atoms + 204 >> 2] = __ZN2js10QNameClassE;

HEAP32[__ZL20standard_class_atoms + 220 >> 2] = __ZN2js18StopIterationClassE;

HEAP32[__ZL20standard_class_atoms + 236 >> 2] = __ZN2js9JSONClassE;

HEAP32[__ZL20standard_class_atoms + 252 >> 2] = __ZN2js11ArrayBuffer9slowClassE;

HEAP32[__ZL20standard_class_atoms + 268 >> 2] = __ZN2js12WeakMapClassE;

HEAP32[__ZL20standard_class_names + 12 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL20standard_class_names + 28 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 44 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 56 >> 2] = STRING_TABLE._js_isNaN_str | 0;

HEAP32[__ZL20standard_class_names + 60 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 72 >> 2] = STRING_TABLE._js_isFinite_str | 0;

HEAP32[__ZL20standard_class_names + 76 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 88 >> 2] = STRING_TABLE._js_parseFloat_str | 0;

HEAP32[__ZL20standard_class_names + 92 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 104 >> 2] = STRING_TABLE._js_parseInt_str | 0;

HEAP32[__ZL20standard_class_names + 108 >> 2] = __ZN2js11NumberClassE;

HEAP32[__ZL20standard_class_names + 120 >> 2] = STRING_TABLE._js_escape_str | 0;

HEAP32[__ZL20standard_class_names + 124 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 136 >> 2] = STRING_TABLE._js_unescape_str | 0;

HEAP32[__ZL20standard_class_names + 140 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 152 >> 2] = STRING_TABLE._js_decodeURI_str | 0;

HEAP32[__ZL20standard_class_names + 156 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 168 >> 2] = STRING_TABLE._js_encodeURI_str | 0;

HEAP32[__ZL20standard_class_names + 172 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 184 >> 2] = STRING_TABLE._js_decodeURIComponent_str | 0;

HEAP32[__ZL20standard_class_names + 188 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 200 >> 2] = STRING_TABLE._js_encodeURIComponent_str | 0;

HEAP32[__ZL20standard_class_names + 204 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 216 >> 2] = STRING_TABLE._js_uneval_str | 0;

HEAP32[__ZL20standard_class_names + 220 >> 2] = __ZN2js11StringClassE;

HEAP32[__ZL20standard_class_names + 236 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 252 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 268 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 284 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 300 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 316 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 332 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 348 >> 2] = __ZN2js10ErrorClassE;

HEAP32[__ZL20standard_class_names + 360 >> 2] = STRING_TABLE._js_XMLList_str | 0;

HEAP32[__ZL20standard_class_names + 364 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_names + 376 >> 2] = STRING_TABLE._js_isXMLName_str | 0;

HEAP32[__ZL20standard_class_names + 380 >> 2] = __ZN2js8XMLClassE;

HEAP32[__ZL20standard_class_names + 396 >> 2] = __ZN2js13IteratorClassE;

HEAP32[__ZL20standard_class_names + 412 >> 2] = __ZN2js16ArrayBufferClassE;

HEAP32[__ZL20standard_class_names + 428 >> 2] = __ZN2js10TypedArray11fastClassesE | 0;

HEAP32[__ZL20standard_class_names + 444 >> 2] = __ZN2js10TypedArray11fastClassesE + 232 | 0;

HEAP32[__ZL20standard_class_names + 460 >> 2] = __ZN2js10TypedArray11fastClassesE + 464 | 0;

HEAP32[__ZL20standard_class_names + 476 >> 2] = __ZN2js10TypedArray11fastClassesE + 696 | 0;

HEAP32[__ZL20standard_class_names + 492 >> 2] = __ZN2js10TypedArray11fastClassesE + 928 | 0;

HEAP32[__ZL20standard_class_names + 508 >> 2] = __ZN2js10TypedArray11fastClassesE + 1160 | 0;

HEAP32[__ZL20standard_class_names + 524 >> 2] = __ZN2js10TypedArray11fastClassesE + 1392 | 0;

HEAP32[__ZL20standard_class_names + 540 >> 2] = __ZN2js10TypedArray11fastClassesE + 1624 | 0;

HEAP32[__ZL20standard_class_names + 556 >> 2] = __ZN2js10TypedArray11fastClassesE + 1856 | 0;

HEAP32[__ZL20standard_class_names + 572 >> 2] = __ZN2js10ProxyClassE;

HEAP32[__ZL22object_prototype_names + 12 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 28 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 44 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 60 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 76 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 88 >> 2] = STRING_TABLE._js_watch_str | 0;

HEAP32[__ZL22object_prototype_names + 92 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 104 >> 2] = STRING_TABLE._js_unwatch_str | 0;

HEAP32[__ZL22object_prototype_names + 108 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 120 >> 2] = STRING_TABLE._js_hasOwnProperty_str | 0;

HEAP32[__ZL22object_prototype_names + 124 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 136 >> 2] = STRING_TABLE._js_isPrototypeOf_str | 0;

HEAP32[__ZL22object_prototype_names + 140 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 152 >> 2] = STRING_TABLE._js_propertyIsEnumerable_str | 0;

HEAP32[__ZL22object_prototype_names + 156 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 168 >> 2] = STRING_TABLE._js_defineGetter_str | 0;

HEAP32[__ZL22object_prototype_names + 172 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 184 >> 2] = STRING_TABLE._js_defineSetter_str | 0;

HEAP32[__ZL22object_prototype_names + 188 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 200 >> 2] = STRING_TABLE._js_lookupGetter_str | 0;

HEAP32[__ZL22object_prototype_names + 204 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL22object_prototype_names + 216 >> 2] = STRING_TABLE._js_lookupSetter_str | 0;

HEAP32[__ZL22object_prototype_names + 220 >> 2] = __ZN2js11ObjectClassE;

HEAP32[__ZL15prop_iter_class >> 2] = STRING_TABLE.__str23216 | 0;

HEAP32[__ZN2js10ArrayClassE >> 2] = STRING_TABLE._js_Array_str | 0;

HEAP32[__ZN2js14SlowArrayClassE >> 2] = STRING_TABLE._js_Array_str | 0;

HEAP32[__ZL13array_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL13array_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL13array_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL13array_methods + 36 >> 2] = STRING_TABLE._js_join_str | 0;

HEAP32[__ZL13array_methods + 48 >> 2] = STRING_TABLE.__str2319 | 0;

HEAP32[__ZL13array_methods + 60 >> 2] = STRING_TABLE.__str3320 | 0;

HEAP32[__ZL13array_methods + 72 >> 2] = STRING_TABLE.__str4321 | 0;

HEAP32[__ZL13array_methods + 84 >> 2] = STRING_TABLE.__str5322 | 0;

HEAP32[__ZL13array_methods + 96 >> 2] = STRING_TABLE.__str6323 | 0;

HEAP32[__ZL13array_methods + 108 >> 2] = STRING_TABLE.__str7324 | 0;

HEAP32[__ZL13array_methods + 120 >> 2] = STRING_TABLE.__str8325 | 0;

HEAP32[__ZL13array_methods + 132 >> 2] = STRING_TABLE.__str193782 | 0;

HEAP32[__ZL13array_methods + 144 >> 2] = STRING_TABLE.__str203783 | 0;

HEAP32[__ZL13array_methods + 156 >> 2] = STRING_TABLE.__str63769 | 0;

HEAP32[__ZL13array_methods + 168 >> 2] = STRING_TABLE.__str73770 | 0;

HEAP32[__ZL13array_methods + 180 >> 2] = STRING_TABLE.__str13330 | 0;

HEAP32[__ZL13array_methods + 192 >> 2] = STRING_TABLE.__str14331 | 0;

HEAP32[__ZL13array_methods + 204 >> 2] = STRING_TABLE.__str15332 | 0;

HEAP32[__ZL13array_methods + 216 >> 2] = STRING_TABLE.__str16333 | 0;

HEAP32[__ZL13array_methods + 228 >> 2] = STRING_TABLE.__str2203372 | 0;

HEAP32[__ZL13array_methods + 240 >> 2] = STRING_TABLE.__str18335 | 0;

HEAP32[__ZL13array_methods + 252 >> 2] = STRING_TABLE.__str19336 | 0;

HEAP32[__ZL20array_static_methods >> 2] = STRING_TABLE.__str20337 | 0;

HEAP32[_js_common_atom_names >> 2] = __str93064 | 0;

HEAP32[_js_common_atom_names + 4 >> 2] = STRING_TABLE._js_false_str | 0;

HEAP32[_js_common_atom_names + 8 >> 2] = STRING_TABLE._js_true_str | 0;

HEAP32[_js_common_atom_names + 12 >> 2] = STRING_TABLE._js_undefined_str | 0;

HEAP32[_js_common_atom_names + 16 >> 2] = STRING_TABLE._js_object_str | 0;

HEAP32[_js_common_atom_names + 20 >> 2] = STRING_TABLE._js_function_str | 0;

HEAP32[_js_common_atom_names + 24 >> 2] = STRING_TABLE.__str22179 | 0;

HEAP32[_js_common_atom_names + 28 >> 2] = STRING_TABLE.__str32180 | 0;

HEAP32[_js_common_atom_names + 32 >> 2] = STRING_TABLE.__str42181 | 0;

HEAP32[_js_common_atom_names + 36 >> 2] = STRING_TABLE._js_null_str | 0;

HEAP32[_js_common_atom_names + 40 >> 2] = STRING_TABLE._js_xml_str | 0;

HEAP32[_js_common_atom_names + 44 >> 2] = STRING_TABLE._js_null_str | 0;

HEAP32[_js_common_atom_names + 48 >> 2] = STRING_TABLE._js_Null_str | 0;

HEAP32[_js_common_atom_names + 52 >> 2] = STRING_TABLE._js_Object_str | 0;

HEAP32[_js_common_atom_names + 56 >> 2] = STRING_TABLE._js_Function_str | 0;

HEAP32[_js_common_atom_names + 60 >> 2] = STRING_TABLE._js_Array_str | 0;

HEAP32[_js_common_atom_names + 64 >> 2] = STRING_TABLE._js_Boolean_str | 0;

HEAP32[_js_common_atom_names + 68 >> 2] = STRING_TABLE._js_JSON_str | 0;

HEAP32[_js_common_atom_names + 72 >> 2] = STRING_TABLE._js_Date_str | 0;

HEAP32[_js_common_atom_names + 76 >> 2] = STRING_TABLE._js_Math_str | 0;

HEAP32[_js_common_atom_names + 80 >> 2] = STRING_TABLE._js_Number_str | 0;

HEAP32[_js_common_atom_names + 84 >> 2] = STRING_TABLE._js_String_str | 0;

HEAP32[_js_common_atom_names + 88 >> 2] = STRING_TABLE._js_RegExp_str | 0;

HEAP32[_js_common_atom_names + 92 >> 2] = STRING_TABLE._js_XML_str | 0;

HEAP32[_js_common_atom_names + 96 >> 2] = STRING_TABLE._js_Namespace_str | 0;

HEAP32[_js_common_atom_names + 100 >> 2] = STRING_TABLE._js_QName_str | 0;

HEAP32[_js_common_atom_names + 104 >> 2] = STRING_TABLE._js_Error_str | 0;

HEAP32[_js_common_atom_names + 108 >> 2] = STRING_TABLE._js_InternalError_str | 0;

HEAP32[_js_common_atom_names + 112 >> 2] = STRING_TABLE._js_EvalError_str | 0;

HEAP32[_js_common_atom_names + 116 >> 2] = STRING_TABLE._js_RangeError_str | 0;

HEAP32[_js_common_atom_names + 120 >> 2] = STRING_TABLE._js_ReferenceError_str | 0;

HEAP32[_js_common_atom_names + 124 >> 2] = STRING_TABLE._js_SyntaxError_str | 0;

HEAP32[_js_common_atom_names + 128 >> 2] = STRING_TABLE._js_TypeError_str | 0;

HEAP32[_js_common_atom_names + 132 >> 2] = STRING_TABLE._js_URIError_str | 0;

HEAP32[_js_common_atom_names + 136 >> 2] = STRING_TABLE._js_Iterator_str | 0;

HEAP32[_js_common_atom_names + 140 >> 2] = STRING_TABLE._js_StopIteration_str | 0;

HEAP32[_js_common_atom_names + 144 >> 2] = STRING_TABLE._js_ArrayBuffer_str | 0;

HEAP32[_js_common_atom_names + 148 >> 2] = STRING_TABLE._js_Int8Array_str | 0;

HEAP32[_js_common_atom_names + 152 >> 2] = STRING_TABLE._js_Uint8Array_str | 0;

HEAP32[_js_common_atom_names + 156 >> 2] = STRING_TABLE._js_Int16Array_str | 0;

HEAP32[_js_common_atom_names + 160 >> 2] = STRING_TABLE._js_Uint16Array_str | 0;

HEAP32[_js_common_atom_names + 164 >> 2] = STRING_TABLE._js_Int32Array_str | 0;

HEAP32[_js_common_atom_names + 168 >> 2] = STRING_TABLE._js_Uint32Array_str | 0;

HEAP32[_js_common_atom_names + 172 >> 2] = STRING_TABLE._js_Float32Array_str | 0;

HEAP32[_js_common_atom_names + 176 >> 2] = STRING_TABLE._js_Float64Array_str | 0;

HEAP32[_js_common_atom_names + 180 >> 2] = STRING_TABLE._js_Uint8ClampedArray_str | 0;

HEAP32[_js_common_atom_names + 184 >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[_js_common_atom_names + 188 >> 2] = STRING_TABLE._js_AnyName_str | 0;

HEAP32[_js_common_atom_names + 192 >> 2] = STRING_TABLE._js_WeakMap_str | 0;

HEAP32[_js_common_atom_names + 196 >> 2] = STRING_TABLE._js_anonymous_str | 0;

HEAP32[_js_common_atom_names + 200 >> 2] = STRING_TABLE._js_apply_str | 0;

HEAP32[_js_common_atom_names + 204 >> 2] = STRING_TABLE._js_arguments_str | 0;

HEAP32[_js_common_atom_names + 208 >> 2] = STRING_TABLE._js_arity_str | 0;

HEAP32[_js_common_atom_names + 212 >> 2] = STRING_TABLE._js_BYTES_PER_ELEMENT_str | 0;

HEAP32[_js_common_atom_names + 216 >> 2] = STRING_TABLE._js_call_str | 0;

HEAP32[_js_common_atom_names + 220 >> 2] = STRING_TABLE._js_callee_str | 0;

HEAP32[_js_common_atom_names + 224 >> 2] = STRING_TABLE._js_caller_str | 0;

HEAP32[_js_common_atom_names + 228 >> 2] = STRING_TABLE._js_class_prototype_str | 0;

HEAP32[_js_common_atom_names + 232 >> 2] = STRING_TABLE._js_constructor_str | 0;

HEAP32[_js_common_atom_names + 236 >> 2] = STRING_TABLE._js_each_str | 0;

HEAP32[_js_common_atom_names + 240 >> 2] = STRING_TABLE._js_eval_str | 0;

HEAP32[_js_common_atom_names + 244 >> 2] = STRING_TABLE._js_fileName_str | 0;

HEAP32[_js_common_atom_names + 248 >> 2] = STRING_TABLE._js_get_str | 0;

HEAP32[_js_common_atom_names + 252 >> 2] = STRING_TABLE._js_global_str | 0;

HEAP32[_js_common_atom_names + 256 >> 2] = STRING_TABLE._js_ignoreCase_str | 0;

HEAP32[_js_common_atom_names + 260 >> 2] = STRING_TABLE._js_index_str | 0;

HEAP32[_js_common_atom_names + 264 >> 2] = STRING_TABLE._js_input_str | 0;

HEAP32[_js_common_atom_names + 268 >> 2] = STRING_TABLE.__str44938 | 0;

HEAP32[_js_common_atom_names + 272 >> 2] = STRING_TABLE._js_iterator_str | 0;

HEAP32[_js_common_atom_names + 276 >> 2] = STRING_TABLE._js_join_str | 0;

HEAP32[_js_common_atom_names + 280 >> 2] = STRING_TABLE._js_lastIndex_str | 0;

HEAP32[_js_common_atom_names + 284 >> 2] = STRING_TABLE._js_length_str | 0;

HEAP32[_js_common_atom_names + 288 >> 2] = STRING_TABLE._js_lineNumber_str | 0;

HEAP32[_js_common_atom_names + 292 >> 2] = STRING_TABLE._js_message_str | 0;

HEAP32[_js_common_atom_names + 296 >> 2] = STRING_TABLE._js_multiline_str | 0;

HEAP32[_js_common_atom_names + 300 >> 2] = STRING_TABLE._js_name_str | 0;

HEAP32[_js_common_atom_names + 304 >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[_js_common_atom_names + 308 >> 2] = STRING_TABLE._js_noSuchMethod_str | 0;

HEAP32[_js_common_atom_names + 312 >> 2] = STRING_TABLE.__str6436 | 0;

HEAP32[_js_common_atom_names + 316 >> 2] = STRING_TABLE.__str7437 | 0;

HEAP32[_js_common_atom_names + 320 >> 2] = STRING_TABLE._js_proto_str | 0;

HEAP32[_js_common_atom_names + 324 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[_js_common_atom_names + 328 >> 2] = STRING_TABLE._js_source_str | 0;

HEAP32[_js_common_atom_names + 332 >> 2] = STRING_TABLE._js_stack_str | 0;

HEAP32[_js_common_atom_names + 336 >> 2] = STRING_TABLE._js_sticky_str | 0;

HEAP32[_js_common_atom_names + 340 >> 2] = STRING_TABLE._js_toGMTString_str | 0;

HEAP32[_js_common_atom_names + 344 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[_js_common_atom_names + 348 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[_js_common_atom_names + 352 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[_js_common_atom_names + 356 >> 2] = STRING_TABLE._js_toUTCString_str | 0;

HEAP32[_js_common_atom_names + 360 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_js_common_atom_names + 364 >> 2] = STRING_TABLE._js_toJSON_str | 0;

HEAP32[_js_common_atom_names + 368 >> 2] = STRING_TABLE.__str8438 | 0;

HEAP32[_js_common_atom_names + 372 >> 2] = STRING_TABLE._js_enumerable_str | 0;

HEAP32[_js_common_atom_names + 376 >> 2] = STRING_TABLE._js_configurable_str | 0;

HEAP32[_js_common_atom_names + 380 >> 2] = STRING_TABLE._js_writable_str | 0;

HEAP32[_js_common_atom_names + 384 >> 2] = STRING_TABLE._js_value_str | 0;

HEAP32[_js_common_atom_names + 388 >> 2] = STRING_TABLE._js_test_str | 0;

HEAP32[_js_common_atom_names + 392 >> 2] = STRING_TABLE.__str9439 | 0;

HEAP32[_js_common_atom_names + 396 >> 2] = STRING_TABLE.__str1823334 | 0;

HEAP32[_js_common_atom_names + 400 >> 2] = STRING_TABLE.__str1783330 | 0;

HEAP32[_js_common_atom_names + 404 >> 2] = STRING_TABLE._js_Infinity_str | 0;

HEAP32[_js_common_atom_names + 408 >> 2] = STRING_TABLE._js_NaN_str | 0;

HEAP32[_js_common_atom_names + 412 >> 2] = STRING_TABLE.__str14444 | 0;

HEAP32[_js_common_atom_names + 416 >> 2] = STRING_TABLE._js_etago_str | 0;

HEAP32[_js_common_atom_names + 420 >> 2] = STRING_TABLE._js_namespace_str | 0;

HEAP32[_js_common_atom_names + 424 >> 2] = STRING_TABLE._js_ptagc_str | 0;

HEAP32[_js_common_atom_names + 428 >> 2] = STRING_TABLE._js_qualifier_str | 0;

HEAP32[_js_common_atom_names + 432 >> 2] = STRING_TABLE._js_space_str | 0;

HEAP32[_js_common_atom_names + 436 >> 2] = STRING_TABLE._js_stago_str | 0;

HEAP32[_js_common_atom_names + 440 >> 2] = STRING_TABLE._js_star_str | 0;

HEAP32[_js_common_atom_names + 444 >> 2] = STRING_TABLE._js_starQualifier_str | 0;

HEAP32[_js_common_atom_names + 448 >> 2] = STRING_TABLE._js_tagc_str | 0;

HEAP32[_js_common_atom_names + 452 >> 2] = STRING_TABLE._js_xml_str | 0;

HEAP32[_js_common_atom_names + 456 >> 2] = STRING_TABLE.__str15445 | 0;

HEAP32[_js_common_atom_names + 460 >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[_js_common_atom_names + 464 >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[_js_common_atom_names + 468 >> 2] = STRING_TABLE.__str18448 | 0;

HEAP32[_js_common_atom_names + 472 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[_js_common_atom_names + 476 >> 2] = STRING_TABLE._js_delete_str | 0;

HEAP32[_js_common_atom_names + 480 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[_js_common_atom_names + 484 >> 2] = STRING_TABLE.__str22452 | 0;

HEAP32[_js_common_atom_names + 488 >> 2] = STRING_TABLE.__str23453 | 0;

HEAP32[_js_common_atom_names + 492 >> 2] = STRING_TABLE.__str14078 | 0;

HEAP32[_js_common_atom_names + 496 >> 2] = STRING_TABLE.__str25455 | 0;

HEAP32[_js_common_atom_names + 500 >> 2] = STRING_TABLE.__str112208 | 0;

HEAP32[_js_common_atom_names + 504 >> 2] = STRING_TABLE.__str27457 | 0;

HEAP32[_js_common_atom_names + 508 >> 2] = STRING_TABLE._js_WeakMap_str | 0;

HEAP32[_js_common_atom_names + 512 >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[_js_common_atom_names + 516 >> 2] = STRING_TABLE._js_return_str | 0;

HEAP32[_js_common_atom_names + 520 >> 2] = STRING_TABLE._js_throw_str | 0;

HEAP32[__ZN2js12BooleanClassE >> 2] = STRING_TABLE._js_Boolean_str | 0;

HEAP32[__ZL15boolean_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL15boolean_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL15boolean_methods + 24 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_js_ErrorFormatString >> 2] = STRING_TABLE.__str6651 | 0;

HEAP32[_js_ErrorFormatString + 8 >> 2] = STRING_TABLE.__str7652 | 0;

HEAP32[_js_ErrorFormatString + 16 >> 2] = STRING_TABLE.__str8653 | 0;

HEAP32[_js_ErrorFormatString + 24 >> 2] = STRING_TABLE.__str9654 | 0;

HEAP32[_js_ErrorFormatString + 32 >> 2] = STRING_TABLE.__str10655 | 0;

HEAP32[_js_ErrorFormatString + 40 >> 2] = STRING_TABLE.__str11656 | 0;

HEAP32[_js_ErrorFormatString + 48 >> 2] = STRING_TABLE.__str12657 | 0;

HEAP32[_js_ErrorFormatString + 56 >> 2] = STRING_TABLE.__str13658 | 0;

HEAP32[_js_ErrorFormatString + 64 >> 2] = STRING_TABLE.__str14659 | 0;

HEAP32[_js_ErrorFormatString + 72 >> 2] = STRING_TABLE.__str15660 | 0;

HEAP32[_js_ErrorFormatString + 80 >> 2] = STRING_TABLE.__str16661 | 0;

HEAP32[_js_ErrorFormatString + 88 >> 2] = STRING_TABLE.__str17662 | 0;

HEAP32[_js_ErrorFormatString + 96 >> 2] = STRING_TABLE.__str18663 | 0;

HEAP32[_js_ErrorFormatString + 104 >> 2] = STRING_TABLE.__str19664 | 0;

HEAP32[_js_ErrorFormatString + 112 >> 2] = STRING_TABLE.__str20665 | 0;

HEAP32[_js_ErrorFormatString + 120 >> 2] = STRING_TABLE.__str21666 | 0;

HEAP32[_js_ErrorFormatString + 128 >> 2] = STRING_TABLE.__str22667 | 0;

HEAP32[_js_ErrorFormatString + 136 >> 2] = STRING_TABLE.__str23668 | 0;

HEAP32[_js_ErrorFormatString + 144 >> 2] = STRING_TABLE.__str24669 | 0;

HEAP32[_js_ErrorFormatString + 152 >> 2] = STRING_TABLE.__str25670 | 0;

HEAP32[_js_ErrorFormatString + 160 >> 2] = STRING_TABLE.__str26671 | 0;

HEAP32[_js_ErrorFormatString + 168 >> 2] = STRING_TABLE.__str27672 | 0;

HEAP32[_js_ErrorFormatString + 176 >> 2] = STRING_TABLE.__str28673 | 0;

HEAP32[_js_ErrorFormatString + 184 >> 2] = STRING_TABLE.__str29674 | 0;

HEAP32[_js_ErrorFormatString + 192 >> 2] = STRING_TABLE.__str30675 | 0;

HEAP32[_js_ErrorFormatString + 200 >> 2] = STRING_TABLE.__str31676 | 0;

HEAP32[_js_ErrorFormatString + 208 >> 2] = STRING_TABLE.__str32677 | 0;

HEAP32[_js_ErrorFormatString + 216 >> 2] = STRING_TABLE.__str33678 | 0;

HEAP32[_js_ErrorFormatString + 224 >> 2] = STRING_TABLE.__str34679 | 0;

HEAP32[_js_ErrorFormatString + 232 >> 2] = STRING_TABLE.__str35680 | 0;

HEAP32[_js_ErrorFormatString + 240 >> 2] = STRING_TABLE.__str36681 | 0;

HEAP32[_js_ErrorFormatString + 248 >> 2] = STRING_TABLE.__str37682 | 0;

HEAP32[_js_ErrorFormatString + 256 >> 2] = STRING_TABLE.__str38683 | 0;

HEAP32[_js_ErrorFormatString + 264 >> 2] = STRING_TABLE.__str39684 | 0;

HEAP32[_js_ErrorFormatString + 272 >> 2] = STRING_TABLE.__str40685 | 0;

HEAP32[_js_ErrorFormatString + 280 >> 2] = STRING_TABLE.__str41686 | 0;

HEAP32[_js_ErrorFormatString + 288 >> 2] = STRING_TABLE.__str42687 | 0;

HEAP32[_js_ErrorFormatString + 296 >> 2] = STRING_TABLE.__str43688 | 0;

HEAP32[_js_ErrorFormatString + 304 >> 2] = STRING_TABLE.__str44689 | 0;

HEAP32[_js_ErrorFormatString + 312 >> 2] = STRING_TABLE.__str45690 | 0;

HEAP32[_js_ErrorFormatString + 320 >> 2] = STRING_TABLE.__str46691 | 0;

HEAP32[_js_ErrorFormatString + 328 >> 2] = STRING_TABLE.__str47692 | 0;

HEAP32[_js_ErrorFormatString + 336 >> 2] = STRING_TABLE.__str48693 | 0;

HEAP32[_js_ErrorFormatString + 344 >> 2] = STRING_TABLE.__str49694 | 0;

HEAP32[_js_ErrorFormatString + 352 >> 2] = STRING_TABLE.__str50695 | 0;

HEAP32[_js_ErrorFormatString + 360 >> 2] = STRING_TABLE.__str51696 | 0;

HEAP32[_js_ErrorFormatString + 368 >> 2] = STRING_TABLE.__str52697 | 0;

HEAP32[_js_ErrorFormatString + 376 >> 2] = STRING_TABLE.__str53698 | 0;

HEAP32[_js_ErrorFormatString + 384 >> 2] = STRING_TABLE.__str54699 | 0;

HEAP32[_js_ErrorFormatString + 392 >> 2] = STRING_TABLE.__str55700 | 0;

HEAP32[_js_ErrorFormatString + 400 >> 2] = STRING_TABLE.__str56701 | 0;

HEAP32[_js_ErrorFormatString + 408 >> 2] = STRING_TABLE.__str57702 | 0;

HEAP32[_js_ErrorFormatString + 416 >> 2] = STRING_TABLE.__str58703 | 0;

HEAP32[_js_ErrorFormatString + 424 >> 2] = STRING_TABLE.__str59704 | 0;

HEAP32[_js_ErrorFormatString + 432 >> 2] = STRING_TABLE.__str60705 | 0;

HEAP32[_js_ErrorFormatString + 440 >> 2] = STRING_TABLE.__str61706 | 0;

HEAP32[_js_ErrorFormatString + 448 >> 2] = STRING_TABLE.__str62707 | 0;

HEAP32[_js_ErrorFormatString + 456 >> 2] = STRING_TABLE.__str63708 | 0;

HEAP32[_js_ErrorFormatString + 464 >> 2] = STRING_TABLE.__str64709 | 0;

HEAP32[_js_ErrorFormatString + 472 >> 2] = STRING_TABLE.__str65710 | 0;

HEAP32[_js_ErrorFormatString + 480 >> 2] = STRING_TABLE.__str66711 | 0;

HEAP32[_js_ErrorFormatString + 488 >> 2] = STRING_TABLE.__str67712 | 0;

HEAP32[_js_ErrorFormatString + 496 >> 2] = STRING_TABLE.__str68713 | 0;

HEAP32[_js_ErrorFormatString + 504 >> 2] = STRING_TABLE.__str72613 | 0;

HEAP32[_js_ErrorFormatString + 512 >> 2] = STRING_TABLE.__str70715 | 0;

HEAP32[_js_ErrorFormatString + 520 >> 2] = STRING_TABLE.__str71716 | 0;

HEAP32[_js_ErrorFormatString + 528 >> 2] = STRING_TABLE.__str72717 | 0;

HEAP32[_js_ErrorFormatString + 536 >> 2] = STRING_TABLE.__str73718 | 0;

HEAP32[_js_ErrorFormatString + 544 >> 2] = STRING_TABLE.__str74719 | 0;

HEAP32[_js_ErrorFormatString + 552 >> 2] = STRING_TABLE.__str75720 | 0;

HEAP32[_js_ErrorFormatString + 560 >> 2] = STRING_TABLE.__str76721 | 0;

HEAP32[_js_ErrorFormatString + 568 >> 2] = STRING_TABLE.__str77722 | 0;

HEAP32[_js_ErrorFormatString + 576 >> 2] = STRING_TABLE.__str78723 | 0;

HEAP32[_js_ErrorFormatString + 584 >> 2] = STRING_TABLE.__str79724 | 0;

HEAP32[_js_ErrorFormatString + 592 >> 2] = STRING_TABLE.__str80725 | 0;

HEAP32[_js_ErrorFormatString + 600 >> 2] = STRING_TABLE.__str81726 | 0;

HEAP32[_js_ErrorFormatString + 608 >> 2] = STRING_TABLE.__str82727 | 0;

HEAP32[_js_ErrorFormatString + 616 >> 2] = STRING_TABLE.__str83728 | 0;

HEAP32[_js_ErrorFormatString + 624 >> 2] = STRING_TABLE.__str84729 | 0;

HEAP32[_js_ErrorFormatString + 632 >> 2] = STRING_TABLE.__str85730 | 0;

HEAP32[_js_ErrorFormatString + 640 >> 2] = STRING_TABLE.__str86731 | 0;

HEAP32[_js_ErrorFormatString + 648 >> 2] = STRING_TABLE.__str87732 | 0;

HEAP32[_js_ErrorFormatString + 656 >> 2] = STRING_TABLE.__str88733 | 0;

HEAP32[_js_ErrorFormatString + 664 >> 2] = STRING_TABLE.__str89734 | 0;

HEAP32[_js_ErrorFormatString + 672 >> 2] = STRING_TABLE.__str90735 | 0;

HEAP32[_js_ErrorFormatString + 680 >> 2] = STRING_TABLE.__str91736 | 0;

HEAP32[_js_ErrorFormatString + 688 >> 2] = STRING_TABLE.__str92737 | 0;

HEAP32[_js_ErrorFormatString + 696 >> 2] = STRING_TABLE.__str93738 | 0;

HEAP32[_js_ErrorFormatString + 704 >> 2] = STRING_TABLE.__str94739 | 0;

HEAP32[_js_ErrorFormatString + 712 >> 2] = STRING_TABLE.__str95740 | 0;

HEAP32[_js_ErrorFormatString + 720 >> 2] = STRING_TABLE.__str96741 | 0;

HEAP32[_js_ErrorFormatString + 728 >> 2] = STRING_TABLE.__str97742 | 0;

HEAP32[_js_ErrorFormatString + 736 >> 2] = STRING_TABLE.__str98743 | 0;

HEAP32[_js_ErrorFormatString + 744 >> 2] = STRING_TABLE.__str99744 | 0;

HEAP32[_js_ErrorFormatString + 752 >> 2] = STRING_TABLE.__str100745 | 0;

HEAP32[_js_ErrorFormatString + 760 >> 2] = STRING_TABLE.__str101746 | 0;

HEAP32[_js_ErrorFormatString + 768 >> 2] = STRING_TABLE.__str102747 | 0;

HEAP32[_js_ErrorFormatString + 776 >> 2] = STRING_TABLE.__str103748 | 0;

HEAP32[_js_ErrorFormatString + 784 >> 2] = STRING_TABLE.__str104749 | 0;

HEAP32[_js_ErrorFormatString + 792 >> 2] = STRING_TABLE.__str105750 | 0;

HEAP32[_js_ErrorFormatString + 800 >> 2] = STRING_TABLE.__str106751 | 0;

HEAP32[_js_ErrorFormatString + 808 >> 2] = STRING_TABLE.__str107752 | 0;

HEAP32[_js_ErrorFormatString + 816 >> 2] = STRING_TABLE.__str108753 | 0;

HEAP32[_js_ErrorFormatString + 824 >> 2] = STRING_TABLE.__str109754 | 0;

HEAP32[_js_ErrorFormatString + 832 >> 2] = STRING_TABLE.__str110755 | 0;

HEAP32[_js_ErrorFormatString + 840 >> 2] = STRING_TABLE.__str111756 | 0;

HEAP32[_js_ErrorFormatString + 848 >> 2] = STRING_TABLE.__str112757 | 0;

HEAP32[_js_ErrorFormatString + 856 >> 2] = STRING_TABLE.__str113758 | 0;

HEAP32[_js_ErrorFormatString + 864 >> 2] = STRING_TABLE.__str114759 | 0;

HEAP32[_js_ErrorFormatString + 872 >> 2] = STRING_TABLE.__str115760 | 0;

HEAP32[_js_ErrorFormatString + 880 >> 2] = STRING_TABLE.__str116761 | 0;

HEAP32[_js_ErrorFormatString + 888 >> 2] = STRING_TABLE.__str117762 | 0;

HEAP32[_js_ErrorFormatString + 896 >> 2] = STRING_TABLE.__str118763 | 0;

HEAP32[_js_ErrorFormatString + 904 >> 2] = STRING_TABLE.__str119764 | 0;

HEAP32[_js_ErrorFormatString + 912 >> 2] = STRING_TABLE.__str120765 | 0;

HEAP32[_js_ErrorFormatString + 920 >> 2] = STRING_TABLE.__str121766 | 0;

HEAP32[_js_ErrorFormatString + 928 >> 2] = STRING_TABLE.__str122767 | 0;

HEAP32[_js_ErrorFormatString + 936 >> 2] = STRING_TABLE.__str123 | 0;

HEAP32[_js_ErrorFormatString + 944 >> 2] = STRING_TABLE.__str124 | 0;

HEAP32[_js_ErrorFormatString + 952 >> 2] = STRING_TABLE.__str125 | 0;

HEAP32[_js_ErrorFormatString + 960 >> 2] = STRING_TABLE.__str126 | 0;

HEAP32[_js_ErrorFormatString + 968 >> 2] = STRING_TABLE.__str127 | 0;

HEAP32[_js_ErrorFormatString + 976 >> 2] = STRING_TABLE.__str128 | 0;

HEAP32[_js_ErrorFormatString + 984 >> 2] = STRING_TABLE.__str129 | 0;

HEAP32[_js_ErrorFormatString + 992 >> 2] = STRING_TABLE.__str130 | 0;

HEAP32[_js_ErrorFormatString + 1e3 >> 2] = STRING_TABLE.__str131 | 0;

HEAP32[_js_ErrorFormatString + 1008 >> 2] = STRING_TABLE.__str132 | 0;

HEAP32[_js_ErrorFormatString + 1016 >> 2] = STRING_TABLE.__str133 | 0;

HEAP32[_js_ErrorFormatString + 1024 >> 2] = STRING_TABLE.__str134 | 0;

HEAP32[_js_ErrorFormatString + 1032 >> 2] = STRING_TABLE.__str135 | 0;

HEAP32[_js_ErrorFormatString + 1040 >> 2] = STRING_TABLE.__str136 | 0;

HEAP32[_js_ErrorFormatString + 1048 >> 2] = STRING_TABLE.__str137 | 0;

HEAP32[_js_ErrorFormatString + 1056 >> 2] = STRING_TABLE.__str138 | 0;

HEAP32[_js_ErrorFormatString + 1064 >> 2] = STRING_TABLE.__str139 | 0;

HEAP32[_js_ErrorFormatString + 1072 >> 2] = STRING_TABLE.__str140 | 0;

HEAP32[_js_ErrorFormatString + 1080 >> 2] = STRING_TABLE.__str141 | 0;

HEAP32[_js_ErrorFormatString + 1088 >> 2] = STRING_TABLE.__str142 | 0;

HEAP32[_js_ErrorFormatString + 1096 >> 2] = STRING_TABLE.__str143 | 0;

HEAP32[_js_ErrorFormatString + 1104 >> 2] = STRING_TABLE.__str232629 | 0;

HEAP32[_js_ErrorFormatString + 1112 >> 2] = STRING_TABLE.__str145 | 0;

HEAP32[_js_ErrorFormatString + 1120 >> 2] = STRING_TABLE.__str146 | 0;

HEAP32[_js_ErrorFormatString + 1128 >> 2] = STRING_TABLE.__str147 | 0;

HEAP32[_js_ErrorFormatString + 1136 >> 2] = STRING_TABLE.__str148 | 0;

HEAP32[_js_ErrorFormatString + 1144 >> 2] = STRING_TABLE.__str149 | 0;

HEAP32[_js_ErrorFormatString + 1152 >> 2] = STRING_TABLE.__str150 | 0;

HEAP32[_js_ErrorFormatString + 1160 >> 2] = STRING_TABLE.__str151 | 0;

HEAP32[_js_ErrorFormatString + 1168 >> 2] = STRING_TABLE.__str152 | 0;

HEAP32[_js_ErrorFormatString + 1176 >> 2] = STRING_TABLE.__str153 | 0;

HEAP32[_js_ErrorFormatString + 1184 >> 2] = STRING_TABLE.__str154 | 0;

HEAP32[_js_ErrorFormatString + 1192 >> 2] = STRING_TABLE.__str155 | 0;

HEAP32[_js_ErrorFormatString + 1200 >> 2] = STRING_TABLE.__str156768 | 0;

HEAP32[_js_ErrorFormatString + 1208 >> 2] = STRING_TABLE.__str157 | 0;

HEAP32[_js_ErrorFormatString + 1216 >> 2] = STRING_TABLE.__str158 | 0;

HEAP32[_js_ErrorFormatString + 1224 >> 2] = STRING_TABLE.__str159 | 0;

HEAP32[_js_ErrorFormatString + 1232 >> 2] = STRING_TABLE.__str160 | 0;

HEAP32[_js_ErrorFormatString + 1240 >> 2] = STRING_TABLE.__str161 | 0;

HEAP32[_js_ErrorFormatString + 1248 >> 2] = STRING_TABLE.__str162 | 0;

HEAP32[_js_ErrorFormatString + 1256 >> 2] = STRING_TABLE.__str163 | 0;

HEAP32[_js_ErrorFormatString + 1264 >> 2] = STRING_TABLE.__str164 | 0;

HEAP32[_js_ErrorFormatString + 1272 >> 2] = STRING_TABLE.__str165 | 0;

HEAP32[_js_ErrorFormatString + 1280 >> 2] = STRING_TABLE.__str166 | 0;

HEAP32[_js_ErrorFormatString + 1288 >> 2] = STRING_TABLE.__str167 | 0;

HEAP32[_js_ErrorFormatString + 1296 >> 2] = STRING_TABLE.__str168 | 0;

HEAP32[_js_ErrorFormatString + 1304 >> 2] = STRING_TABLE.__str169 | 0;

HEAP32[_js_ErrorFormatString + 1312 >> 2] = STRING_TABLE.__str170 | 0;

HEAP32[_js_ErrorFormatString + 1320 >> 2] = STRING_TABLE.__str171 | 0;

HEAP32[_js_ErrorFormatString + 1328 >> 2] = STRING_TABLE.__str172 | 0;

HEAP32[_js_ErrorFormatString + 1336 >> 2] = STRING_TABLE.__str173 | 0;

HEAP32[_js_ErrorFormatString + 1344 >> 2] = STRING_TABLE.__str174769 | 0;

HEAP32[_js_ErrorFormatString + 1352 >> 2] = STRING_TABLE.__str175 | 0;

HEAP32[_js_ErrorFormatString + 1360 >> 2] = STRING_TABLE.__str176 | 0;

HEAP32[_js_ErrorFormatString + 1368 >> 2] = STRING_TABLE.__str177 | 0;

HEAP32[_js_ErrorFormatString + 1376 >> 2] = STRING_TABLE.__str178 | 0;

HEAP32[_js_ErrorFormatString + 1384 >> 2] = STRING_TABLE.__str179 | 0;

HEAP32[_js_ErrorFormatString + 1392 >> 2] = STRING_TABLE.__str180 | 0;

HEAP32[_js_ErrorFormatString + 1400 >> 2] = STRING_TABLE.__str181 | 0;

HEAP32[_js_ErrorFormatString + 1408 >> 2] = STRING_TABLE.__str182770 | 0;

HEAP32[_js_ErrorFormatString + 1416 >> 2] = STRING_TABLE.__str183 | 0;

HEAP32[_js_ErrorFormatString + 1424 >> 2] = STRING_TABLE.__str184771 | 0;

HEAP32[_js_ErrorFormatString + 1432 >> 2] = STRING_TABLE.__str185 | 0;

HEAP32[_js_ErrorFormatString + 1440 >> 2] = STRING_TABLE.__str186 | 0;

HEAP32[_js_ErrorFormatString + 1448 >> 2] = STRING_TABLE.__str187 | 0;

HEAP32[_js_ErrorFormatString + 1456 >> 2] = STRING_TABLE.__str188772 | 0;

HEAP32[_js_ErrorFormatString + 1464 >> 2] = STRING_TABLE.__str189 | 0;

HEAP32[_js_ErrorFormatString + 1472 >> 2] = STRING_TABLE.__str190 | 0;

HEAP32[_js_ErrorFormatString + 1480 >> 2] = STRING_TABLE.__str191 | 0;

HEAP32[_js_ErrorFormatString + 1488 >> 2] = STRING_TABLE.__str192 | 0;

HEAP32[_js_ErrorFormatString + 1496 >> 2] = STRING_TABLE.__str193 | 0;

HEAP32[_js_ErrorFormatString + 1504 >> 2] = STRING_TABLE.__str194 | 0;

HEAP32[_js_ErrorFormatString + 1512 >> 2] = STRING_TABLE.__str195 | 0;

HEAP32[_js_ErrorFormatString + 1520 >> 2] = STRING_TABLE.__str196 | 0;

HEAP32[_js_ErrorFormatString + 1528 >> 2] = STRING_TABLE.__str197 | 0;

HEAP32[_js_ErrorFormatString + 1536 >> 2] = STRING_TABLE.__str198773 | 0;

HEAP32[_js_ErrorFormatString + 1544 >> 2] = STRING_TABLE.__str199 | 0;

HEAP32[_js_ErrorFormatString + 1552 >> 2] = STRING_TABLE.__str200 | 0;

HEAP32[_js_ErrorFormatString + 1560 >> 2] = STRING_TABLE.__str201 | 0;

HEAP32[_js_ErrorFormatString + 1568 >> 2] = STRING_TABLE.__str202 | 0;

HEAP32[_js_ErrorFormatString + 1576 >> 2] = STRING_TABLE.__str203 | 0;

HEAP32[_js_ErrorFormatString + 1584 >> 2] = STRING_TABLE.__str204 | 0;

HEAP32[_js_ErrorFormatString + 1592 >> 2] = STRING_TABLE.__str205 | 0;

HEAP32[_js_ErrorFormatString + 1600 >> 2] = STRING_TABLE.__str206 | 0;

HEAP32[_js_ErrorFormatString + 1608 >> 2] = STRING_TABLE.__str207 | 0;

HEAP32[_js_ErrorFormatString + 1616 >> 2] = STRING_TABLE.__str208 | 0;

HEAP32[_js_ErrorFormatString + 1624 >> 2] = STRING_TABLE.__str209 | 0;

HEAP32[_js_ErrorFormatString + 1632 >> 2] = STRING_TABLE.__str210 | 0;

HEAP32[_js_ErrorFormatString + 1640 >> 2] = STRING_TABLE.__str211 | 0;

HEAP32[_js_ErrorFormatString + 1648 >> 2] = STRING_TABLE.__str212 | 0;

HEAP32[_js_ErrorFormatString + 1656 >> 2] = STRING_TABLE.__str213 | 0;

HEAP32[_js_ErrorFormatString + 1664 >> 2] = STRING_TABLE.__str214 | 0;

HEAP32[_js_ErrorFormatString + 1672 >> 2] = STRING_TABLE.__str215 | 0;

HEAP32[_js_ErrorFormatString + 1680 >> 2] = STRING_TABLE.__str216 | 0;

HEAP32[_js_ErrorFormatString + 1688 >> 2] = STRING_TABLE.__str217 | 0;

HEAP32[_js_ErrorFormatString + 1696 >> 2] = STRING_TABLE.__str218 | 0;

HEAP32[_js_ErrorFormatString + 1704 >> 2] = STRING_TABLE.__str219 | 0;

HEAP32[_js_ErrorFormatString + 1712 >> 2] = STRING_TABLE.__str220 | 0;

HEAP32[_js_ErrorFormatString + 1720 >> 2] = STRING_TABLE.__str221 | 0;

HEAP32[_js_ErrorFormatString + 1728 >> 2] = STRING_TABLE.__str222 | 0;

HEAP32[_js_ErrorFormatString + 1736 >> 2] = STRING_TABLE.__str223 | 0;

HEAP32[_js_ErrorFormatString + 1744 >> 2] = STRING_TABLE.__str224 | 0;

HEAP32[_js_ErrorFormatString + 1752 >> 2] = STRING_TABLE.__str225 | 0;

HEAP32[_js_ErrorFormatString + 1760 >> 2] = STRING_TABLE.__str226 | 0;

HEAP32[_js_ErrorFormatString + 1768 >> 2] = STRING_TABLE.__str227 | 0;

HEAP32[_js_ErrorFormatString + 1776 >> 2] = STRING_TABLE.__str228 | 0;

HEAP32[_js_ErrorFormatString + 1784 >> 2] = STRING_TABLE.__str229 | 0;

HEAP32[_js_ErrorFormatString + 1792 >> 2] = STRING_TABLE.__str230 | 0;

HEAP32[_js_ErrorFormatString + 1800 >> 2] = STRING_TABLE.__str231 | 0;

HEAP32[_js_ErrorFormatString + 1808 >> 2] = STRING_TABLE.__str232 | 0;

HEAP32[_js_ErrorFormatString + 1816 >> 2] = STRING_TABLE.__str233 | 0;

HEAP32[_js_ErrorFormatString + 1824 >> 2] = STRING_TABLE.__str234 | 0;

HEAP32[_js_ErrorFormatString + 1832 >> 2] = STRING_TABLE.__str235 | 0;

HEAP32[_js_ErrorFormatString + 1840 >> 2] = STRING_TABLE.__str236 | 0;

HEAP32[_js_ErrorFormatString + 1848 >> 2] = STRING_TABLE.__str237 | 0;

HEAP32[_js_ErrorFormatString + 1856 >> 2] = STRING_TABLE.__str238 | 0;

HEAP32[_js_ErrorFormatString + 1864 >> 2] = STRING_TABLE.__str239 | 0;

HEAP32[_js_ErrorFormatString + 1872 >> 2] = STRING_TABLE.__str240 | 0;

HEAP32[_js_ErrorFormatString + 1880 >> 2] = STRING_TABLE.__str241 | 0;

HEAP32[_js_ErrorFormatString + 1888 >> 2] = STRING_TABLE.__str242 | 0;

HEAP32[_js_ErrorFormatString + 1896 >> 2] = STRING_TABLE.__str243 | 0;

HEAP32[_js_ErrorFormatString + 1904 >> 2] = STRING_TABLE.__str244 | 0;

HEAP32[_js_ErrorFormatString + 1912 >> 2] = STRING_TABLE.__str245 | 0;

HEAP32[_js_ErrorFormatString + 1920 >> 2] = STRING_TABLE.__str246 | 0;

HEAP32[_js_ErrorFormatString + 1928 >> 2] = STRING_TABLE.__str247 | 0;

HEAP32[_js_ErrorFormatString + 1936 >> 2] = STRING_TABLE.__str248 | 0;

HEAP32[_js_ErrorFormatString + 1944 >> 2] = STRING_TABLE.__str249 | 0;

HEAP32[_js_ErrorFormatString + 1952 >> 2] = STRING_TABLE.__str250 | 0;

HEAP32[_js_ErrorFormatString + 1960 >> 2] = STRING_TABLE.__str251 | 0;

HEAP32[_js_ErrorFormatString + 1968 >> 2] = STRING_TABLE.__str252 | 0;

HEAP32[_js_ErrorFormatString + 1976 >> 2] = STRING_TABLE.__str253 | 0;

HEAP32[_js_ErrorFormatString + 1984 >> 2] = STRING_TABLE.__str254 | 0;

HEAP32[_js_ErrorFormatString + 1992 >> 2] = STRING_TABLE.__str255 | 0;

HEAP32[_js_ErrorFormatString + 2e3 >> 2] = STRING_TABLE.__str256 | 0;

HEAP32[_js_ErrorFormatString + 2008 >> 2] = STRING_TABLE.__str257 | 0;

HEAP32[_js_ErrorFormatString + 2016 >> 2] = STRING_TABLE.__str258 | 0;

HEAP32[_js_ErrorFormatString + 2024 >> 2] = STRING_TABLE.__str259 | 0;

HEAP32[_js_ErrorFormatString + 2032 >> 2] = STRING_TABLE.__str260 | 0;

HEAP32[_js_ErrorFormatString + 2040 >> 2] = STRING_TABLE.__str261 | 0;

HEAP32[_js_ErrorFormatString + 2048 >> 2] = STRING_TABLE.__str262 | 0;

HEAP32[_js_ErrorFormatString + 2056 >> 2] = STRING_TABLE.__str263 | 0;

HEAP32[_js_ErrorFormatString + 2064 >> 2] = STRING_TABLE.__str264 | 0;

HEAP32[_js_ErrorFormatString + 2072 >> 2] = STRING_TABLE.__str265 | 0;

HEAP32[_js_ErrorFormatString + 2080 >> 2] = STRING_TABLE.__str266 | 0;

HEAP32[_js_ErrorFormatString + 2088 >> 2] = STRING_TABLE.__str267 | 0;

HEAP32[_js_ErrorFormatString + 2096 >> 2] = STRING_TABLE.__str268 | 0;

HEAP32[_js_ErrorFormatString + 2104 >> 2] = STRING_TABLE.__str269 | 0;

HEAP32[_js_ErrorFormatString + 2112 >> 2] = STRING_TABLE.__str270 | 0;

HEAP32[_js_ErrorFormatString + 2120 >> 2] = STRING_TABLE.__str271 | 0;

HEAP32[_js_ErrorFormatString + 2128 >> 2] = STRING_TABLE.__str272 | 0;

HEAP32[_js_ErrorFormatString + 2136 >> 2] = STRING_TABLE.__str273 | 0;

HEAP32[_js_ErrorFormatString + 2144 >> 2] = STRING_TABLE.__str274 | 0;

HEAP32[_js_ErrorFormatString + 2152 >> 2] = STRING_TABLE.__str275 | 0;

HEAP32[_js_ErrorFormatString + 2160 >> 2] = STRING_TABLE.__str276 | 0;

HEAP32[_js_ErrorFormatString + 2168 >> 2] = STRING_TABLE.__str277 | 0;

HEAP32[_js_ErrorFormatString + 2176 >> 2] = STRING_TABLE.__str278 | 0;

HEAP32[_js_ErrorFormatString + 2184 >> 2] = STRING_TABLE.__str279 | 0;

HEAP32[_js_ErrorFormatString + 2192 >> 2] = STRING_TABLE.__str280 | 0;

HEAP32[_js_ErrorFormatString + 2200 >> 2] = STRING_TABLE.__str281 | 0;

HEAP32[_js_ErrorFormatString + 2208 >> 2] = STRING_TABLE.__str282 | 0;

HEAP32[_js_ErrorFormatString + 2216 >> 2] = STRING_TABLE.__str283 | 0;

HEAP32[_js_ErrorFormatString + 2224 >> 2] = STRING_TABLE.__str284 | 0;

HEAP32[_js_ErrorFormatString + 2232 >> 2] = STRING_TABLE.__str285 | 0;

HEAP32[_js_ErrorFormatString + 2240 >> 2] = STRING_TABLE.__str286 | 0;

HEAP32[_js_ErrorFormatString + 2248 >> 2] = STRING_TABLE.__str287 | 0;

HEAP32[_js_ErrorFormatString + 2256 >> 2] = STRING_TABLE.__str288 | 0;

HEAP32[_js_ErrorFormatString + 2264 >> 2] = STRING_TABLE.__str289 | 0;

HEAP32[_js_ErrorFormatString + 2272 >> 2] = STRING_TABLE.__str290 | 0;

HEAP32[_js_ErrorFormatString + 2280 >> 2] = STRING_TABLE.__str291 | 0;

HEAP32[_js_ErrorFormatString + 2288 >> 2] = STRING_TABLE.__str292 | 0;

HEAP32[__ZN2js9DateClassE >> 2] = STRING_TABLE._js_Date_str | 0;

HEAP32[__ZL19date_static_methods >> 2] = STRING_TABLE.__str894 | 0;

HEAP32[__ZL19date_static_methods + 12 >> 2] = STRING_TABLE.__str2383390 | 0;

HEAP32[__ZL19date_static_methods + 24 >> 2] = STRING_TABLE.__str2896 | 0;

HEAP32[__ZL12date_methods >> 2] = STRING_TABLE.__str3897 | 0;

HEAP32[__ZL12date_methods + 12 >> 2] = STRING_TABLE.__str4898 | 0;

HEAP32[__ZL12date_methods + 24 >> 2] = STRING_TABLE.__str5899 | 0;

HEAP32[__ZL12date_methods + 36 >> 2] = STRING_TABLE.__str6900 | 0;

HEAP32[__ZL12date_methods + 48 >> 2] = STRING_TABLE.__str7901 | 0;

HEAP32[__ZL12date_methods + 60 >> 2] = STRING_TABLE.__str8902 | 0;

HEAP32[__ZL12date_methods + 72 >> 2] = STRING_TABLE.__str9903 | 0;

HEAP32[__ZL12date_methods + 84 >> 2] = STRING_TABLE.__str10904 | 0;

HEAP32[__ZL12date_methods + 96 >> 2] = STRING_TABLE.__str11905 | 0;

HEAP32[__ZL12date_methods + 108 >> 2] = STRING_TABLE.__str12906 | 0;

HEAP32[__ZL12date_methods + 120 >> 2] = STRING_TABLE.__str13907 | 0;

HEAP32[__ZL12date_methods + 132 >> 2] = STRING_TABLE.__str14908 | 0;

HEAP32[__ZL12date_methods + 144 >> 2] = STRING_TABLE.__str15909 | 0;

HEAP32[__ZL12date_methods + 156 >> 2] = STRING_TABLE.__str16910 | 0;

HEAP32[__ZL12date_methods + 168 >> 2] = STRING_TABLE.__str17911 | 0;

HEAP32[__ZL12date_methods + 180 >> 2] = STRING_TABLE.__str18912 | 0;

HEAP32[__ZL12date_methods + 192 >> 2] = STRING_TABLE.__str19913 | 0;

HEAP32[__ZL12date_methods + 204 >> 2] = STRING_TABLE.__str20914 | 0;

HEAP32[__ZL12date_methods + 216 >> 2] = STRING_TABLE.__str21915 | 0;

HEAP32[__ZL12date_methods + 228 >> 2] = STRING_TABLE.__str22916 | 0;

HEAP32[__ZL12date_methods + 240 >> 2] = STRING_TABLE.__str23917 | 0;

HEAP32[__ZL12date_methods + 252 >> 2] = STRING_TABLE.__str24918 | 0;

HEAP32[__ZL12date_methods + 264 >> 2] = STRING_TABLE.__str25919 | 0;

HEAP32[__ZL12date_methods + 276 >> 2] = STRING_TABLE.__str26920 | 0;

HEAP32[__ZL12date_methods + 288 >> 2] = STRING_TABLE.__str27921 | 0;

HEAP32[__ZL12date_methods + 300 >> 2] = STRING_TABLE.__str28922 | 0;

HEAP32[__ZL12date_methods + 312 >> 2] = STRING_TABLE.__str29923 | 0;

HEAP32[__ZL12date_methods + 324 >> 2] = STRING_TABLE.__str30924 | 0;

HEAP32[__ZL12date_methods + 336 >> 2] = STRING_TABLE.__str31925 | 0;

HEAP32[__ZL12date_methods + 348 >> 2] = STRING_TABLE.__str32926 | 0;

HEAP32[__ZL12date_methods + 360 >> 2] = STRING_TABLE.__str33927 | 0;

HEAP32[__ZL12date_methods + 372 >> 2] = STRING_TABLE.__str34928 | 0;

HEAP32[__ZL12date_methods + 384 >> 2] = STRING_TABLE.__str35929 | 0;

HEAP32[__ZL12date_methods + 396 >> 2] = STRING_TABLE.__str36930 | 0;

HEAP32[__ZL12date_methods + 408 >> 2] = STRING_TABLE.__str37931 | 0;

HEAP32[__ZL12date_methods + 420 >> 2] = STRING_TABLE._js_toUTCString_str | 0;

HEAP32[__ZL12date_methods + 432 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL12date_methods + 444 >> 2] = STRING_TABLE.__str39933 | 0;

HEAP32[__ZL12date_methods + 456 >> 2] = STRING_TABLE.__str40934 | 0;

HEAP32[__ZL12date_methods + 468 >> 2] = STRING_TABLE.__str41935 | 0;

HEAP32[__ZL12date_methods + 480 >> 2] = STRING_TABLE.__str42936 | 0;

HEAP32[__ZL12date_methods + 492 >> 2] = STRING_TABLE.__str43937 | 0;

HEAP32[__ZL12date_methods + 504 >> 2] = STRING_TABLE.__str44938 | 0;

HEAP32[__ZL12date_methods + 516 >> 2] = STRING_TABLE._js_toJSON_str | 0;

HEAP32[__ZL12date_methods + 528 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL12date_methods + 540 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL12date_methods + 552 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL3wtb >> 2] = STRING_TABLE.__str45939 | 0;

HEAP32[__ZL3wtb + 4 >> 2] = STRING_TABLE.__str46940 | 0;

HEAP32[__ZL3wtb + 8 >> 2] = STRING_TABLE.__str47941 | 0;

HEAP32[__ZL3wtb + 12 >> 2] = STRING_TABLE.__str48942 | 0;

HEAP32[__ZL3wtb + 16 >> 2] = STRING_TABLE.__str49943 | 0;

HEAP32[__ZL3wtb + 20 >> 2] = STRING_TABLE.__str50944 | 0;

HEAP32[__ZL3wtb + 24 >> 2] = STRING_TABLE.__str51945 | 0;

HEAP32[__ZL3wtb + 28 >> 2] = STRING_TABLE.__str52946 | 0;

HEAP32[__ZL3wtb + 32 >> 2] = STRING_TABLE.__str53947 | 0;

HEAP32[__ZL3wtb + 36 >> 2] = STRING_TABLE.__str54948 | 0;

HEAP32[__ZL3wtb + 40 >> 2] = STRING_TABLE.__str55949 | 0;

HEAP32[__ZL3wtb + 44 >> 2] = STRING_TABLE.__str56950 | 0;

HEAP32[__ZL3wtb + 48 >> 2] = STRING_TABLE.__str57951 | 0;

HEAP32[__ZL3wtb + 52 >> 2] = STRING_TABLE.__str58952 | 0;

HEAP32[__ZL3wtb + 56 >> 2] = STRING_TABLE.__str59953 | 0;

HEAP32[__ZL3wtb + 60 >> 2] = STRING_TABLE.__str60954 | 0;

HEAP32[__ZL3wtb + 64 >> 2] = STRING_TABLE.__str61955 | 0;

HEAP32[__ZL3wtb + 68 >> 2] = STRING_TABLE.__str62956 | 0;

HEAP32[__ZL3wtb + 72 >> 2] = STRING_TABLE.__str63957 | 0;

HEAP32[__ZL3wtb + 76 >> 2] = STRING_TABLE.__str64958 | 0;

HEAP32[__ZL3wtb + 80 >> 2] = STRING_TABLE.__str65959 | 0;

HEAP32[__ZL3wtb + 84 >> 2] = STRING_TABLE.__str66960 | 0;

HEAP32[__ZL3wtb + 88 >> 2] = STRING_TABLE.__str67961 | 0;

HEAP32[__ZL3wtb + 92 >> 2] = STRING_TABLE.__str68962 | 0;

HEAP32[__ZL3wtb + 96 >> 2] = STRING_TABLE.__str69963 | 0;

HEAP32[__ZL3wtb + 100 >> 2] = STRING_TABLE.__str70964 | 0;

HEAP32[__ZL3wtb + 104 >> 2] = STRING_TABLE.__str71965 | 0;

HEAP32[__ZL3wtb + 108 >> 2] = STRING_TABLE.__str72966 | 0;

HEAP32[__ZL3wtb + 112 >> 2] = STRING_TABLE.__str73967 | 0;

HEAP32[__ZL3wtb + 116 >> 2] = STRING_TABLE.__str74968 | 0;

HEAP32[__ZL3wtb + 120 >> 2] = STRING_TABLE.__str75969 | 0;

HEAP32[__ZL3wtb + 124 >> 2] = STRING_TABLE.__str76970 | 0;

HEAP32[__ZL4days >> 2] = STRING_TABLE.__str95989 | 0;

HEAP32[__ZL4days + 4 >> 2] = STRING_TABLE.__str96990 | 0;

HEAP32[__ZL4days + 8 >> 2] = STRING_TABLE.__str97991 | 0;

HEAP32[__ZL4days + 12 >> 2] = STRING_TABLE.__str98992 | 0;

HEAP32[__ZL4days + 16 >> 2] = STRING_TABLE.__str99993 | 0;

HEAP32[__ZL4days + 20 >> 2] = STRING_TABLE.__str100994 | 0;

HEAP32[__ZL4days + 24 >> 2] = STRING_TABLE.__str101995 | 0;

HEAP32[__ZL6months >> 2] = STRING_TABLE.__str83977 | 0;

HEAP32[__ZL6months + 4 >> 2] = STRING_TABLE.__str84978 | 0;

HEAP32[__ZL6months + 8 >> 2] = STRING_TABLE.__str85979 | 0;

HEAP32[__ZL6months + 12 >> 2] = STRING_TABLE.__str86980 | 0;

HEAP32[__ZL6months + 16 >> 2] = STRING_TABLE.__str87981 | 0;

HEAP32[__ZL6months + 20 >> 2] = STRING_TABLE.__str88982 | 0;

HEAP32[__ZL6months + 24 >> 2] = STRING_TABLE.__str89983 | 0;

HEAP32[__ZL6months + 28 >> 2] = STRING_TABLE.__str90984 | 0;

HEAP32[__ZL6months + 32 >> 2] = STRING_TABLE.__str91985 | 0;

HEAP32[__ZL6months + 36 >> 2] = STRING_TABLE.__str92986 | 0;

HEAP32[__ZL6months + 40 >> 2] = STRING_TABLE.__str93987 | 0;

HEAP32[__ZL6months + 44 >> 2] = STRING_TABLE.__str94988 | 0;

HEAP32[_js_SrcNoteSpec >> 2] = STRING_TABLE._js_null_str | 0;

HEAP32[_js_SrcNoteSpec + 8 >> 2] = STRING_TABLE._js_if_str | 0;

HEAP32[_js_SrcNoteSpec + 16 >> 2] = STRING_TABLE.__str41110 | 0;

HEAP32[_js_SrcNoteSpec + 24 >> 2] = STRING_TABLE._js_for_str | 0;

HEAP32[_js_SrcNoteSpec + 32 >> 2] = STRING_TABLE._js_while_str | 0;

HEAP32[_js_SrcNoteSpec + 40 >> 2] = STRING_TABLE._js_continue_str | 0;

HEAP32[_js_SrcNoteSpec + 48 >> 2] = STRING_TABLE.__str81114 | 0;

HEAP32[_js_SrcNoteSpec + 56 >> 2] = STRING_TABLE.__str91115 | 0;

HEAP32[_js_SrcNoteSpec + 64 >> 2] = STRING_TABLE.__str101116 | 0;

HEAP32[_js_SrcNoteSpec + 72 >> 2] = STRING_TABLE.__str111117 | 0;

HEAP32[_js_SrcNoteSpec + 80 >> 2] = STRING_TABLE.__str121118 | 0;

HEAP32[_js_SrcNoteSpec + 88 >> 2] = STRING_TABLE.__str131119 | 0;

HEAP32[_js_SrcNoteSpec + 96 >> 2] = STRING_TABLE.__str141120 | 0;

HEAP32[_js_SrcNoteSpec + 104 >> 2] = STRING_TABLE.__str1883340 | 0;

HEAP32[_js_SrcNoteSpec + 112 >> 2] = STRING_TABLE.__str161122 | 0;

HEAP32[_js_SrcNoteSpec + 120 >> 2] = STRING_TABLE.__str171123 | 0;

HEAP32[_js_SrcNoteSpec + 128 >> 2] = STRING_TABLE.__str181124 | 0;

HEAP32[_js_SrcNoteSpec + 136 >> 2] = STRING_TABLE.__str191125 | 0;

HEAP32[_js_SrcNoteSpec + 144 >> 2] = STRING_TABLE._js_switch_str | 0;

HEAP32[_js_SrcNoteSpec + 152 >> 2] = STRING_TABLE.__str211127 | 0;

HEAP32[_js_SrcNoteSpec + 160 >> 2] = STRING_TABLE._js_catch_str | 0;

HEAP32[_js_SrcNoteSpec + 168 >> 2] = STRING_TABLE.__str231129 | 0;

HEAP32[_js_SrcNoteSpec + 176 >> 2] = STRING_TABLE.__str241130 | 0;

HEAP32[_js_SrcNoteSpec + 184 >> 2] = STRING_TABLE.__str251131 | 0;

HEAP32[_js_SrcNoteSpec + 192 >> 2] = STRING_TABLE.__str261132 | 0;

HEAP32[__ZL13statementName >> 2] = STRING_TABLE.__str271135 | 0;

HEAP32[__ZL13statementName + 4 >> 2] = STRING_TABLE.__str281136 | 0;

HEAP32[__ZL13statementName + 8 >> 2] = STRING_TABLE.__str291137 | 0;

HEAP32[__ZL13statementName + 12 >> 2] = STRING_TABLE.__str301138 | 0;

HEAP32[__ZL13statementName + 16 >> 2] = STRING_TABLE.__str311139 | 0;

HEAP32[__ZL13statementName + 20 >> 2] = STRING_TABLE.__str1993351 | 0;

HEAP32[__ZL13statementName + 24 >> 2] = STRING_TABLE.__ZL21js_with_statement_str | 0;

HEAP32[__ZL13statementName + 28 >> 2] = STRING_TABLE.__str331141 | 0;

HEAP32[__ZL13statementName + 32 >> 2] = STRING_TABLE.__str341142 | 0;

HEAP32[__ZL13statementName + 36 >> 2] = STRING_TABLE.__ZL20js_finally_block_str | 0;

HEAP32[__ZL13statementName + 40 >> 2] = STRING_TABLE.__ZL20js_finally_block_str | 0;

HEAP32[__ZL13statementName + 44 >> 2] = STRING_TABLE.__str351143 | 0;

HEAP32[__ZL13statementName + 48 >> 2] = STRING_TABLE.__str361144 | 0;

HEAP32[__ZL13statementName + 52 >> 2] = STRING_TABLE.__str371145 | 0;

HEAP32[__ZL13statementName + 56 >> 2] = STRING_TABLE.__str381146 | 0;

HEAP32[__ZN2js10ErrorClassE >> 2] = STRING_TABLE._js_Error_str | 0;

HEAP32[__ZL17exception_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL17exception_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js26StrictArgumentsObjectClassE >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZN2js26NormalArgumentsObjectClassE >> 2] = STRING_TABLE.__str1263 | 0;

HEAP32[__ZN2js12DeclEnvClassE >> 2] = STRING_TABLE._js_Object_str | 0;

HEAP32[__ZN2js9CallClassE >> 2] = STRING_TABLE.__str11264 | 0;

HEAP32[__ZN2js13FunctionClassE >> 2] = STRING_TABLE._js_Function_str | 0;

HEAP32[__ZN2js16function_methodsE >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZN2js16function_methodsE + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js16function_methodsE + 24 >> 2] = STRING_TABLE._js_apply_str | 0;

HEAP32[__ZN2js16function_methodsE + 36 >> 2] = STRING_TABLE._js_call_str | 0;

HEAP32[__ZN2js16function_methodsE + 48 >> 2] = STRING_TABLE.__str31270 | 0;

HEAP32[__ZN2js16function_methodsE + 60 >> 2] = STRING_TABLE.__str41271 | 0;

HEAP32[__ZN2js9gcReasonsE >> 2] = STRING_TABLE.__str1551 | 0;

HEAP32[__ZN2js9gcReasonsE + 4 >> 2] = STRING_TABLE.__str11552 | 0;

HEAP32[__ZN2js9gcReasonsE + 8 >> 2] = STRING_TABLE.__str21553 | 0;

HEAP32[__ZN2js9gcReasonsE + 12 >> 2] = STRING_TABLE.__str31554 | 0;

HEAP32[__ZN2js9gcReasonsE + 16 >> 2] = STRING_TABLE.__str41555 | 0;

HEAP32[__ZN2js9gcReasonsE + 20 >> 2] = STRING_TABLE.__str51556 | 0;

HEAP32[__ZN2js9gcReasonsE + 24 >> 2] = STRING_TABLE.__str61557 | 0;

HEAP32[__ZN2js9gcReasonsE + 28 >> 2] = STRING_TABLE.__str71558 | 0;

HEAP32[__ZN2js9gcReasonsE + 32 >> 2] = STRING_TABLE.__str81559 | 0;

HEAP32[__ZN2js9gcReasonsE + 36 >> 2] = STRING_TABLE.__str91560 | 0;

HEAP32[__ZN2js9gcReasonsE + 40 >> 2] = STRING_TABLE.__str101561 | 0;

HEAP32[_js_NoSuchMethodClass >> 2] = STRING_TABLE.__str1777 | 0;

HEAP32[__ZN2js13IteratorClassE >> 2] = STRING_TABLE._js_Iterator_str | 0;

HEAP32[__ZL16iterator_methods >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[__ZN2js18StopIterationClassE >> 2] = STRING_TABLE._js_StopIteration_str | 0;

HEAP32[__ZN2js14GeneratorClassE >> 2] = STRING_TABLE.__str31916 | 0;

HEAP32[__ZL17generator_methods >> 2] = STRING_TABLE._js_next_str | 0;

HEAP32[__ZL17generator_methods + 12 >> 2] = STRING_TABLE._js_send_str | 0;

HEAP32[__ZL17generator_methods + 24 >> 2] = STRING_TABLE._js_throw_str | 0;

HEAP32[__ZL17generator_methods + 36 >> 2] = STRING_TABLE._js_close_str | 0;

HEAP32[__ZN2js9MathClassE >> 2] = STRING_TABLE._js_Math_str | 0;

HEAP32[__ZL19math_static_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL19math_static_methods + 12 >> 2] = STRING_TABLE.__str2000 | 0;

HEAP32[__ZL19math_static_methods + 24 >> 2] = STRING_TABLE.__str12001 | 0;

HEAP32[__ZL19math_static_methods + 36 >> 2] = STRING_TABLE.__str22002 | 0;

HEAP32[__ZL19math_static_methods + 48 >> 2] = STRING_TABLE.__str32003 | 0;

HEAP32[__ZL19math_static_methods + 60 >> 2] = STRING_TABLE.__str42004 | 0;

HEAP32[__ZL19math_static_methods + 72 >> 2] = STRING_TABLE.__str52005 | 0;

HEAP32[__ZL19math_static_methods + 84 >> 2] = STRING_TABLE.__str62006 | 0;

HEAP32[__ZL19math_static_methods + 96 >> 2] = STRING_TABLE.__str72007 | 0;

HEAP32[__ZL19math_static_methods + 108 >> 2] = STRING_TABLE.__str82008 | 0;

HEAP32[__ZL19math_static_methods + 120 >> 2] = STRING_TABLE.__str92009 | 0;

HEAP32[__ZL19math_static_methods + 132 >> 2] = STRING_TABLE.__str102010 | 0;

HEAP32[__ZL19math_static_methods + 144 >> 2] = STRING_TABLE.__str112011 | 0;

HEAP32[__ZL19math_static_methods + 156 >> 2] = STRING_TABLE.__str122012 | 0;

HEAP32[__ZL19math_static_methods + 168 >> 2] = STRING_TABLE.__str132013 | 0;

HEAP32[__ZL19math_static_methods + 180 >> 2] = STRING_TABLE.__str142014 | 0;

HEAP32[__ZL19math_static_methods + 192 >> 2] = STRING_TABLE.__str152015 | 0;

HEAP32[__ZL19math_static_methods + 204 >> 2] = STRING_TABLE.__str162016 | 0;

HEAP32[__ZL19math_static_methods + 216 >> 2] = STRING_TABLE.__str172017 | 0;

HEAP32[__ZL14math_constants + 8 >> 2] = STRING_TABLE.__str182018 | 0;

HEAP32[__ZL14math_constants + 24 >> 2] = STRING_TABLE.__str192019 | 0;

HEAP32[__ZL14math_constants + 40 >> 2] = STRING_TABLE.__str202020 | 0;

HEAP32[__ZL14math_constants + 56 >> 2] = STRING_TABLE.__str212021 | 0;

HEAP32[__ZL14math_constants + 72 >> 2] = STRING_TABLE.__str222022 | 0;

HEAP32[__ZL14math_constants + 88 >> 2] = STRING_TABLE.__str232023 | 0;

HEAP32[__ZL14math_constants + 104 >> 2] = STRING_TABLE.__str242024 | 0;

HEAP32[__ZL14math_constants + 120 >> 2] = STRING_TABLE.__str252025 | 0;

HEAP32[__ZL16number_functions >> 2] = STRING_TABLE._js_isNaN_str | 0;

HEAP32[__ZL16number_functions + 12 >> 2] = STRING_TABLE._js_isFinite_str | 0;

HEAP32[__ZL16number_functions + 24 >> 2] = STRING_TABLE._js_parseFloat_str | 0;

HEAP32[__ZL16number_functions + 36 >> 2] = STRING_TABLE._js_parseInt_str | 0;

HEAP32[__ZN2js11NumberClassE >> 2] = STRING_TABLE._js_Number_str | 0;

HEAP32[__ZL14number_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14number_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14number_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[__ZL14number_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL14number_methods + 48 >> 2] = STRING_TABLE.__str2072 | 0;

HEAP32[__ZL14number_methods + 60 >> 2] = STRING_TABLE.__str12073 | 0;

HEAP32[__ZL14number_methods + 72 >> 2] = STRING_TABLE.__str22074 | 0;

HEAP32[__ZL16number_constants + 8 >> 2] = STRING_TABLE._js_NaN_str | 0;

HEAP32[__ZL16number_constants + 24 >> 2] = STRING_TABLE.__str82086 | 0;

HEAP32[__ZL16number_constants + 40 >> 2] = STRING_TABLE.__str92087 | 0;

HEAP32[__ZL16number_constants + 56 >> 2] = STRING_TABLE.__str102088 | 0;

HEAP32[__ZL16number_constants + 72 >> 2] = STRING_TABLE.__str112089 | 0;

HEAP32[__ZN2js11ObjectClassE >> 2] = STRING_TABLE._js_Object_str | 0;

HEAP32[_object_props >> 2] = STRING_TABLE._js_proto_str | 0;

HEAP32[_object_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[_object_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[_object_methods + 24 >> 2] = STRING_TABLE._js_toLocaleString_str | 0;

HEAP32[_object_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[_object_methods + 48 >> 2] = STRING_TABLE._js_watch_str | 0;

HEAP32[_object_methods + 60 >> 2] = STRING_TABLE._js_unwatch_str | 0;

HEAP32[_object_methods + 72 >> 2] = STRING_TABLE._js_hasOwnProperty_str | 0;

HEAP32[_object_methods + 84 >> 2] = STRING_TABLE._js_isPrototypeOf_str | 0;

HEAP32[_object_methods + 96 >> 2] = STRING_TABLE._js_propertyIsEnumerable_str | 0;

HEAP32[_object_methods + 108 >> 2] = STRING_TABLE._js_defineGetter_str | 0;

HEAP32[_object_methods + 120 >> 2] = STRING_TABLE._js_defineSetter_str | 0;

HEAP32[_object_methods + 132 >> 2] = STRING_TABLE._js_lookupGetter_str | 0;

HEAP32[_object_methods + 144 >> 2] = STRING_TABLE._js_lookupSetter_str | 0;

HEAP32[_object_static_methods >> 2] = STRING_TABLE.__str92206 | 0;

HEAP32[_object_static_methods + 12 >> 2] = STRING_TABLE.__str102207 | 0;

HEAP32[_object_static_methods + 24 >> 2] = STRING_TABLE.__str112208 | 0;

HEAP32[_object_static_methods + 36 >> 2] = STRING_TABLE.__str122209 | 0;

HEAP32[_object_static_methods + 48 >> 2] = STRING_TABLE.__str132210 | 0;

HEAP32[_object_static_methods + 60 >> 2] = STRING_TABLE.__str53058 | 0;

HEAP32[_object_static_methods + 72 >> 2] = STRING_TABLE.__str152212 | 0;

HEAP32[_object_static_methods + 84 >> 2] = STRING_TABLE.__str162213 | 0;

HEAP32[_object_static_methods + 96 >> 2] = STRING_TABLE.__str172214 | 0;

HEAP32[_object_static_methods + 108 >> 2] = STRING_TABLE.__str182215 | 0;

HEAP32[_object_static_methods + 120 >> 2] = STRING_TABLE.__str192216 | 0;

HEAP32[_object_static_methods + 132 >> 2] = STRING_TABLE.__str202217 | 0;

HEAP32[_object_static_methods + 144 >> 2] = STRING_TABLE.__str212218 | 0;

HEAP32[__ZN2js9WithClassE >> 2] = STRING_TABLE.__str222221 | 0;

HEAP32[__ZN2js10BlockClassE >> 2] = STRING_TABLE.__str232224 | 0;

HEAP32[__ZN2js9JSONClassE >> 2] = STRING_TABLE._js_JSON_str | 0;

HEAP32[__ZL19json_static_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL19json_static_methods + 12 >> 2] = STRING_TABLE.__str2383390 | 0;

HEAP32[__ZL19json_static_methods + 24 >> 2] = STRING_TABLE.__str12532 | 0;

HEAP32[__ZL9CodeToken + 36 >> 2] = STRING_TABLE._js_arguments_str | 0;

HEAP32[__ZL9CodeToken + 60 >> 2] = STRING_TABLE.__str283180 | 0;

HEAP32[__ZL9CodeToken + 64 >> 2] = STRING_TABLE.__str293181 | 0;

HEAP32[__ZL9CodeToken + 68 >> 2] = STRING_TABLE.__str303182 | 0;

HEAP32[__ZL9CodeToken + 72 >> 2] = STRING_TABLE.__str123164 | 0;

HEAP32[__ZL9CodeToken + 76 >> 2] = STRING_TABLE.__str133165 | 0;

HEAP32[__ZL9CodeToken + 80 >> 2] = STRING_TABLE._js_stago_str | 0;

HEAP32[__ZL9CodeToken + 84 >> 2] = STRING_TABLE.__str173169 | 0;

HEAP32[__ZL9CodeToken + 88 >> 2] = STRING_TABLE._js_tagc_str | 0;

HEAP32[__ZL9CodeToken + 92 >> 2] = STRING_TABLE.__str193171 | 0;

HEAP32[__ZL9CodeToken + 96 >> 2] = STRING_TABLE.__str203172 | 0;

HEAP32[__ZL9CodeToken + 100 >> 2] = STRING_TABLE.__str213173 | 0;

HEAP32[__ZL9CodeToken + 104 >> 2] = STRING_TABLE.__str223174 | 0;

HEAP32[__ZL9CodeToken + 108 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZL9CodeToken + 112 >> 2] = STRING_TABLE.__str243176 | 0;

HEAP32[__ZL9CodeToken + 116 >> 2] = STRING_TABLE._js_star_str | 0;

HEAP32[__ZL9CodeToken + 120 >> 2] = STRING_TABLE.__str263178 | 0;

HEAP32[__ZL9CodeToken + 124 >> 2] = STRING_TABLE.__str273179 | 0;

HEAP32[__ZL9CodeToken + 128 >> 2] = STRING_TABLE.__str353187 | 0;

HEAP32[__ZL9CodeToken + 132 >> 2] = STRING_TABLE.__str363188 | 0;

HEAP32[__ZL9CodeToken + 136 >> 2] = STRING_TABLE.__str192692 | 0;

HEAP32[__ZL9CodeToken + 140 >> 2] = STRING_TABLE.__str202693 | 0;

HEAP32[__ZL9CodeToken + 248 >> 2] = STRING_TABLE.__str64083 | 0;

HEAP32[__ZL9CodeToken + 252 >> 2] = STRING_TABLE.__str163973 | 0;

HEAP32[__ZL9CodeToken + 256 >> 2] = STRING_TABLE._js_null_str | 0;

HEAP32[__ZL9CodeToken + 260 >> 2] = STRING_TABLE._js_this_str | 0;

HEAP32[__ZL9CodeToken + 264 >> 2] = STRING_TABLE._js_false_str | 0;

HEAP32[__ZL9CodeToken + 268 >> 2] = STRING_TABLE._js_true_str | 0;

HEAP32[__ZL9CodeToken + 288 >> 2] = STRING_TABLE.__str143166 | 0;

HEAP32[__ZL9CodeToken + 292 >> 2] = STRING_TABLE.__str153167 | 0;

HEAP32[__ZL9CodeToken + 308 >> 2] = STRING_TABLE.__str252698 | 0;

HEAP32[__ZL9CodeToken + 452 >> 2] = STRING_TABLE._js_in_str | 0;

HEAP32[__ZL9CodeToken + 456 >> 2] = STRING_TABLE._js_instanceof_str | 0;

HEAP32[__ZL10var_prefix >> 2] = STRING_TABLE.__str1332806 | 0;

HEAP32[__ZL10var_prefix + 4 >> 2] = STRING_TABLE.__str1342807 | 0;

HEAP32[__ZL10var_prefix + 8 >> 2] = STRING_TABLE.__str1352808 | 0;

HEAP32[_table >> 2] = STRING_TABLE._js_var_str | 0;

HEAP32[_table + 4 >> 2] = STRING_TABLE._js_const_str | 0;

HEAP32[_table + 8 >> 2] = STRING_TABLE._js_let_str | 0;

HEAP32[_table + 12 >> 2] = STRING_TABLE._js_function_str | 0;

HEAP32[_table + 16 >> 2] = STRING_TABLE.__str1893341 | 0;

HEAP32[_table + 20 >> 2] = STRING_TABLE.__str20213 | 0;

HEAP32[__ZL6pm_fns >> 2] = STRING_TABLE.__str1773329 | 0;

HEAP32[__ZL6pm_fns + 12 >> 2] = STRING_TABLE.__str12967 | 0;

HEAP32[__ZL6pm_fns + 24 >> 2] = STRING_TABLE.__str22968 | 0;

HEAP32[__ZL6pm_fns + 36 >> 2] = STRING_TABLE.__str32969 | 0;

HEAP32[__ZL8pm_class >> 2] = STRING_TABLE.__str42970 | 0;

HEAP32[__ZL8pm_props >> 2] = STRING_TABLE.__str182984 | 0;

HEAP32[__ZL8pm_props + 16 >> 2] = STRING_TABLE.__str192985 | 0;

HEAP32[__ZL8pm_props + 32 >> 2] = STRING_TABLE.__str202986 | 0;

HEAP32[__ZL8pm_props + 48 >> 2] = STRING_TABLE.__str212987 | 0;

HEAP32[__ZL8pm_props + 64 >> 2] = STRING_TABLE.__str222988 | 0;

HEAP32[__ZL8pm_props + 80 >> 2] = STRING_TABLE.__str232989 | 0;

HEAP32[__ZL8pm_props + 96 >> 2] = STRING_TABLE.__str242990 | 0;

HEAP32[__ZL8pm_props + 112 >> 2] = STRING_TABLE.__str252991 | 0;

HEAP32[__ZL8pm_props + 128 >> 2] = STRING_TABLE.__str262992 | 0;

HEAP32[__ZL8pm_props + 144 >> 2] = STRING_TABLE.__str272993 | 0;

HEAP32[__ZL8pm_props + 160 >> 2] = STRING_TABLE.__str282994 | 0;

HEAP32[__ZL8pm_props + 176 >> 2] = STRING_TABLE.__str292995 | 0;

HEAP32[__ZL9pm_consts >> 2] = STRING_TABLE.__str52971 | 0;

HEAP32[__ZL9pm_consts + 8 >> 2] = STRING_TABLE.__str62972 | 0;

HEAP32[__ZL9pm_consts + 16 >> 2] = STRING_TABLE.__str72973 | 0;

HEAP32[__ZL9pm_consts + 24 >> 2] = STRING_TABLE.__str82974 | 0;

HEAP32[__ZL9pm_consts + 32 >> 2] = STRING_TABLE.__str92975 | 0;

HEAP32[__ZL9pm_consts + 40 >> 2] = STRING_TABLE.__str102976 | 0;

HEAP32[__ZL9pm_consts + 48 >> 2] = STRING_TABLE.__str112977 | 0;

HEAP32[__ZL9pm_consts + 56 >> 2] = STRING_TABLE.__str122978 | 0;

HEAP32[__ZL9pm_consts + 64 >> 2] = STRING_TABLE.__str132979 | 0;

HEAP32[__ZL9pm_consts + 72 >> 2] = STRING_TABLE.__str142980 | 0;

HEAP32[__ZL9pm_consts + 80 >> 2] = STRING_TABLE.__str152981 | 0;

HEAP32[__ZL9pm_consts + 88 >> 2] = STRING_TABLE.__str162982 | 0;

HEAP32[__ZL9pm_consts + 96 >> 2] = STRING_TABLE.__str172983 | 0;

HEAP32[__ZN22JSScriptedProxyHandler9singletonE >> 2] = __ZTV22JSScriptedProxyHandler + 8 | 0;

HEAP32[__ZN22JSScriptedProxyHandler9singletonE + 4 >> 2] = __ZL27sScriptedProxyHandlerFamily;

HEAP32[__ZN2js16ObjectProxyClassE >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[__ZN2js21OuterWindowProxyClassE >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[__ZN2js18FunctionProxyClassE >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[__ZL14static_methods >> 2] = STRING_TABLE.__str53058 | 0;

HEAP32[__ZL14static_methods + 12 >> 2] = STRING_TABLE.__str63059 | 0;

HEAP32[__ZN2js19CallableObjectClassE >> 2] = STRING_TABLE._js_Function_str | 0;

HEAP32[__ZN2js10ProxyClassE >> 2] = STRING_TABLE._js_Proxy_str | 0;

HEAP32[__ZN2js8aopNamesE >> 2] = STRING_TABLE.__str3152 | 0;

HEAP32[__ZN2js8aopNamesE + 4 >> 2] = STRING_TABLE.__str13153 | 0;

HEAP32[__ZN2js8aopNamesE + 8 >> 2] = STRING_TABLE.__str23154 | 0;

HEAP32[__ZN2js8aopNamesE + 12 >> 2] = STRING_TABLE.__str33155 | 0;

HEAP32[__ZN2js8aopNamesE + 16 >> 2] = STRING_TABLE.__str43156 | 0;

HEAP32[__ZN2js8aopNamesE + 20 >> 2] = STRING_TABLE.__str53157 | 0;

HEAP32[__ZN2js8aopNamesE + 24 >> 2] = STRING_TABLE.__str63158 | 0;

HEAP32[__ZN2js8aopNamesE + 28 >> 2] = STRING_TABLE.__str73159 | 0;

HEAP32[__ZN2js8aopNamesE + 32 >> 2] = STRING_TABLE.__str83160 | 0;

HEAP32[__ZN2js8aopNamesE + 36 >> 2] = STRING_TABLE.__str93161 | 0;

HEAP32[__ZN2js8aopNamesE + 40 >> 2] = STRING_TABLE.__str103162 | 0;

HEAP32[__ZN2js8aopNamesE + 44 >> 2] = STRING_TABLE.__str113163 | 0;

HEAP32[__ZN2js10binopNamesE >> 2] = STRING_TABLE.__str123164 | 0;

HEAP32[__ZN2js10binopNamesE + 4 >> 2] = STRING_TABLE.__str133165 | 0;

HEAP32[__ZN2js10binopNamesE + 8 >> 2] = STRING_TABLE.__str143166 | 0;

HEAP32[__ZN2js10binopNamesE + 12 >> 2] = STRING_TABLE.__str153167 | 0;

HEAP32[__ZN2js10binopNamesE + 16 >> 2] = STRING_TABLE._js_stago_str | 0;

HEAP32[__ZN2js10binopNamesE + 20 >> 2] = STRING_TABLE.__str173169 | 0;

HEAP32[__ZN2js10binopNamesE + 24 >> 2] = STRING_TABLE._js_tagc_str | 0;

HEAP32[__ZN2js10binopNamesE + 28 >> 2] = STRING_TABLE.__str193171 | 0;

HEAP32[__ZN2js10binopNamesE + 32 >> 2] = STRING_TABLE.__str203172 | 0;

HEAP32[__ZN2js10binopNamesE + 36 >> 2] = STRING_TABLE.__str213173 | 0;

HEAP32[__ZN2js10binopNamesE + 40 >> 2] = STRING_TABLE.__str223174 | 0;

HEAP32[__ZN2js10binopNamesE + 44 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZN2js10binopNamesE + 48 >> 2] = STRING_TABLE.__str243176 | 0;

HEAP32[__ZN2js10binopNamesE + 52 >> 2] = STRING_TABLE._js_star_str | 0;

HEAP32[__ZN2js10binopNamesE + 56 >> 2] = STRING_TABLE.__str263178 | 0;

HEAP32[__ZN2js10binopNamesE + 60 >> 2] = STRING_TABLE.__str273179 | 0;

HEAP32[__ZN2js10binopNamesE + 64 >> 2] = STRING_TABLE.__str283180 | 0;

HEAP32[__ZN2js10binopNamesE + 68 >> 2] = STRING_TABLE.__str293181 | 0;

HEAP32[__ZN2js10binopNamesE + 72 >> 2] = STRING_TABLE.__str303182 | 0;

HEAP32[__ZN2js10binopNamesE + 76 >> 2] = STRING_TABLE._js_in_str | 0;

HEAP32[__ZN2js10binopNamesE + 80 >> 2] = STRING_TABLE._js_instanceof_str | 0;

HEAP32[__ZN2js10binopNamesE + 84 >> 2] = STRING_TABLE.__str333185 | 0;

HEAP32[__ZN2js9unopNamesE >> 2] = STRING_TABLE._js_delete_str | 0;

HEAP32[__ZN2js9unopNamesE + 4 >> 2] = STRING_TABLE.__str243176 | 0;

HEAP32[__ZN2js9unopNamesE + 8 >> 2] = STRING_TABLE.__str233175 | 0;

HEAP32[__ZN2js9unopNamesE + 12 >> 2] = STRING_TABLE.__str353187 | 0;

HEAP32[__ZN2js9unopNamesE + 16 >> 2] = STRING_TABLE.__str363188 | 0;

HEAP32[__ZN2js9unopNamesE + 20 >> 2] = STRING_TABLE._js_typeof_str | 0;

HEAP32[__ZN2js9unopNamesE + 24 >> 2] = STRING_TABLE._js_void_str | 0;

HEAP32[__ZN2js13nodeTypeNamesE >> 2] = STRING_TABLE.__str393191 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 4 >> 2] = STRING_TABLE.__str403192 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 8 >> 2] = STRING_TABLE.__str413193 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 12 >> 2] = STRING_TABLE.__str423194 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 16 >> 2] = STRING_TABLE.__str433195 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 20 >> 2] = STRING_TABLE.__str443196 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 24 >> 2] = STRING_TABLE.__str453197 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 28 >> 2] = STRING_TABLE.__str463198 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 32 >> 2] = STRING_TABLE.__str473199 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 36 >> 2] = STRING_TABLE.__str483200 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 40 >> 2] = STRING_TABLE.__str493201 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 44 >> 2] = STRING_TABLE.__str503202 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 48 >> 2] = STRING_TABLE.__str513203 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 52 >> 2] = STRING_TABLE.__str523204 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 56 >> 2] = STRING_TABLE.__str533205 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 60 >> 2] = STRING_TABLE.__str543206 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 64 >> 2] = STRING_TABLE.__str553207 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 68 >> 2] = STRING_TABLE.__str563208 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 72 >> 2] = STRING_TABLE.__str573209 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 76 >> 2] = STRING_TABLE.__str583210 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 80 >> 2] = STRING_TABLE.__str593211 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 84 >> 2] = STRING_TABLE.__str603212 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 88 >> 2] = STRING_TABLE.__str613213 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 92 >> 2] = STRING_TABLE.__str623214 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 96 >> 2] = STRING_TABLE.__str633215 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 100 >> 2] = STRING_TABLE.__str643216 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 104 >> 2] = STRING_TABLE.__str653217 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 108 >> 2] = STRING_TABLE.__str663218 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 112 >> 2] = STRING_TABLE.__str673219 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 116 >> 2] = STRING_TABLE.__str683220 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 120 >> 2] = STRING_TABLE.__str693221 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 124 >> 2] = STRING_TABLE.__str703222 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 128 >> 2] = STRING_TABLE.__str713223 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 132 >> 2] = STRING_TABLE.__str723224 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 136 >> 2] = STRING_TABLE.__str733225 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 140 >> 2] = STRING_TABLE.__str743226 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 144 >> 2] = STRING_TABLE.__str753227 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 148 >> 2] = STRING_TABLE.__str763228 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 152 >> 2] = STRING_TABLE.__str773229 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 156 >> 2] = STRING_TABLE.__str783230 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 160 >> 2] = STRING_TABLE.__str793231 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 164 >> 2] = STRING_TABLE.__str803232 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 168 >> 2] = STRING_TABLE.__str813233 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 172 >> 2] = STRING_TABLE.__str823234 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 176 >> 2] = STRING_TABLE.__str833235 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 180 >> 2] = STRING_TABLE.__str843236 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 184 >> 2] = STRING_TABLE.__str853237 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 188 >> 2] = STRING_TABLE.__str863238 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 192 >> 2] = STRING_TABLE.__str873239 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 196 >> 2] = STRING_TABLE.__str883240 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 200 >> 2] = STRING_TABLE.__str423194 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 204 >> 2] = STRING_TABLE.__str893241 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 208 >> 2] = STRING_TABLE.__str903242 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 212 >> 2] = STRING_TABLE.__str913243 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 216 >> 2] = STRING_TABLE.__str923244 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 220 >> 2] = STRING_TABLE.__str933245 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 224 >> 2] = STRING_TABLE.__str943246 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 228 >> 2] = STRING_TABLE.__str953247 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 232 >> 2] = STRING_TABLE.__str963248 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 236 >> 2] = STRING_TABLE.__str973249 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 240 >> 2] = STRING_TABLE._js_XMLList_str | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 244 >> 2] = STRING_TABLE.__str993251 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 248 >> 2] = STRING_TABLE.__str1003252 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 252 >> 2] = STRING_TABLE.__str1013253 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 256 >> 2] = STRING_TABLE.__str1023254 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 260 >> 2] = STRING_TABLE.__str1033255 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 264 >> 2] = STRING_TABLE.__str1043256 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 268 >> 2] = STRING_TABLE.__str1053257 | 0;

HEAP32[__ZN2js13nodeTypeNamesE + 272 >> 2] = STRING_TABLE.__str1063258 | 0;

HEAP32[__ZN2js13callbackNamesE >> 2] = STRING_TABLE.__str1073259 | 0;

HEAP32[__ZN2js13callbackNamesE + 4 >> 2] = STRING_TABLE.__str1083260 | 0;

HEAP32[__ZN2js13callbackNamesE + 8 >> 2] = STRING_TABLE.__str1093261 | 0;

HEAP32[__ZN2js13callbackNamesE + 12 >> 2] = STRING_TABLE.__str1103262 | 0;

HEAP32[__ZN2js13callbackNamesE + 16 >> 2] = STRING_TABLE.__str1113263 | 0;

HEAP32[__ZN2js13callbackNamesE + 20 >> 2] = STRING_TABLE.__str1123264 | 0;

HEAP32[__ZN2js13callbackNamesE + 24 >> 2] = STRING_TABLE.__str1133265 | 0;

HEAP32[__ZN2js13callbackNamesE + 28 >> 2] = STRING_TABLE.__str1143266 | 0;

HEAP32[__ZN2js13callbackNamesE + 32 >> 2] = STRING_TABLE.__str1153267 | 0;

HEAP32[__ZN2js13callbackNamesE + 36 >> 2] = STRING_TABLE.__str1163268 | 0;

HEAP32[__ZN2js13callbackNamesE + 40 >> 2] = STRING_TABLE.__str1173269 | 0;

HEAP32[__ZN2js13callbackNamesE + 44 >> 2] = STRING_TABLE.__str1183270 | 0;

HEAP32[__ZN2js13callbackNamesE + 48 >> 2] = STRING_TABLE.__str1193271 | 0;

HEAP32[__ZN2js13callbackNamesE + 52 >> 2] = STRING_TABLE.__str1203272 | 0;

HEAP32[__ZN2js13callbackNamesE + 56 >> 2] = STRING_TABLE.__str1213273 | 0;

HEAP32[__ZN2js13callbackNamesE + 60 >> 2] = STRING_TABLE.__str1223274 | 0;

HEAP32[__ZN2js13callbackNamesE + 64 >> 2] = STRING_TABLE.__str1233275 | 0;

HEAP32[__ZN2js13callbackNamesE + 68 >> 2] = STRING_TABLE.__str1243276 | 0;

HEAP32[__ZN2js13callbackNamesE + 72 >> 2] = STRING_TABLE.__str1253277 | 0;

HEAP32[__ZN2js13callbackNamesE + 76 >> 2] = STRING_TABLE.__str1263278 | 0;

HEAP32[__ZN2js13callbackNamesE + 80 >> 2] = STRING_TABLE.__str1273279 | 0;

HEAP32[__ZN2js13callbackNamesE + 84 >> 2] = STRING_TABLE.__str1283280 | 0;

HEAP32[__ZN2js13callbackNamesE + 88 >> 2] = STRING_TABLE.__str1293281 | 0;

HEAP32[__ZN2js13callbackNamesE + 92 >> 2] = STRING_TABLE.__str1303282 | 0;

HEAP32[__ZN2js13callbackNamesE + 96 >> 2] = STRING_TABLE.__str1313283 | 0;

HEAP32[__ZN2js13callbackNamesE + 100 >> 2] = STRING_TABLE.__str1323284 | 0;

HEAP32[__ZN2js13callbackNamesE + 104 >> 2] = STRING_TABLE.__str1333285 | 0;

HEAP32[__ZN2js13callbackNamesE + 108 >> 2] = STRING_TABLE.__str1343286 | 0;

HEAP32[__ZN2js13callbackNamesE + 112 >> 2] = STRING_TABLE.__str1353287 | 0;

HEAP32[__ZN2js13callbackNamesE + 116 >> 2] = STRING_TABLE.__str1363288 | 0;

HEAP32[__ZN2js13callbackNamesE + 120 >> 2] = STRING_TABLE.__str1373289 | 0;

HEAP32[__ZN2js13callbackNamesE + 124 >> 2] = STRING_TABLE.__str1383290 | 0;

HEAP32[__ZN2js13callbackNamesE + 128 >> 2] = STRING_TABLE.__str1393291 | 0;

HEAP32[__ZN2js13callbackNamesE + 132 >> 2] = STRING_TABLE.__str1403292 | 0;

HEAP32[__ZN2js13callbackNamesE + 136 >> 2] = STRING_TABLE.__str1413293 | 0;

HEAP32[__ZN2js13callbackNamesE + 140 >> 2] = STRING_TABLE.__str1423294 | 0;

HEAP32[__ZN2js13callbackNamesE + 144 >> 2] = STRING_TABLE.__str1433295 | 0;

HEAP32[__ZN2js13callbackNamesE + 148 >> 2] = STRING_TABLE.__str1443296 | 0;

HEAP32[__ZN2js13callbackNamesE + 152 >> 2] = STRING_TABLE.__str1453297 | 0;

HEAP32[__ZN2js13callbackNamesE + 156 >> 2] = STRING_TABLE.__str1463298 | 0;

HEAP32[__ZN2js13callbackNamesE + 160 >> 2] = STRING_TABLE.__str1473299 | 0;

HEAP32[__ZN2js13callbackNamesE + 164 >> 2] = STRING_TABLE.__str1483300 | 0;

HEAP32[__ZN2js13callbackNamesE + 168 >> 2] = STRING_TABLE.__str1493301 | 0;

HEAP32[__ZN2js13callbackNamesE + 172 >> 2] = STRING_TABLE.__str1503302 | 0;

HEAP32[__ZN2js13callbackNamesE + 176 >> 2] = STRING_TABLE.__str1513303 | 0;

HEAP32[__ZN2js13callbackNamesE + 180 >> 2] = STRING_TABLE.__str1523304 | 0;

HEAP32[__ZN2js13callbackNamesE + 184 >> 2] = STRING_TABLE.__str1533305 | 0;

HEAP32[__ZN2js13callbackNamesE + 188 >> 2] = STRING_TABLE.__str1543306 | 0;

HEAP32[__ZN2js13callbackNamesE + 192 >> 2] = STRING_TABLE.__str1553307 | 0;

HEAP32[__ZN2js13callbackNamesE + 196 >> 2] = STRING_TABLE.__str1563308 | 0;

HEAP32[__ZN2js13callbackNamesE + 200 >> 2] = STRING_TABLE.__str1573309 | 0;

HEAP32[__ZN2js13callbackNamesE + 204 >> 2] = STRING_TABLE.__str1583310 | 0;

HEAP32[__ZN2js13callbackNamesE + 208 >> 2] = STRING_TABLE.__str1593311 | 0;

HEAP32[__ZN2js13callbackNamesE + 212 >> 2] = STRING_TABLE.__str1603312 | 0;

HEAP32[__ZN2js13callbackNamesE + 216 >> 2] = STRING_TABLE.__str1613313 | 0;

HEAP32[__ZN2js13callbackNamesE + 220 >> 2] = STRING_TABLE.__str1623314 | 0;

HEAP32[__ZN2js13callbackNamesE + 224 >> 2] = STRING_TABLE.__str1633315 | 0;

HEAP32[__ZN2js13callbackNamesE + 228 >> 2] = STRING_TABLE.__str1643316 | 0;

HEAP32[__ZN2js13callbackNamesE + 232 >> 2] = STRING_TABLE.__str1653317 | 0;

HEAP32[__ZN2js13callbackNamesE + 236 >> 2] = STRING_TABLE.__str1663318 | 0;

HEAP32[__ZN2js13callbackNamesE + 240 >> 2] = STRING_TABLE.__str1673319 | 0;

HEAP32[__ZN2js13callbackNamesE + 244 >> 2] = STRING_TABLE.__str1683320 | 0;

HEAP32[__ZN2js13callbackNamesE + 248 >> 2] = STRING_TABLE.__str1693321 | 0;

HEAP32[__ZN2js13callbackNamesE + 252 >> 2] = STRING_TABLE.__str1703322 | 0;

HEAP32[__ZN2js13callbackNamesE + 256 >> 2] = STRING_TABLE.__str1713323 | 0;

HEAP32[__ZN2js13callbackNamesE + 260 >> 2] = STRING_TABLE.__str1723324 | 0;

HEAP32[__ZN2js13callbackNamesE + 264 >> 2] = STRING_TABLE.__str1733325 | 0;

HEAP32[__ZN2js13callbackNamesE + 268 >> 2] = STRING_TABLE.__str1743326 | 0;

HEAP32[__ZN2js13callbackNamesE + 272 >> 2] = STRING_TABLE.__str1753327 | 0;

HEAP32[__ZL14static_methods3391 >> 2] = STRING_TABLE.__str2383390 | 0;

HEAP32[__ZN2js20regexp_statics_classE >> 2] = STRING_TABLE.__str3439 | 0;

HEAP32[__ZL19regexp_static_props >> 2] = STRING_TABLE._js_input_str | 0;

HEAP32[__ZL19regexp_static_props + 16 >> 2] = STRING_TABLE._js_multiline_str | 0;

HEAP32[__ZL19regexp_static_props + 32 >> 2] = STRING_TABLE.__str33444 | 0;

HEAP32[__ZL19regexp_static_props + 48 >> 2] = STRING_TABLE.__str43445 | 0;

HEAP32[__ZL19regexp_static_props + 64 >> 2] = STRING_TABLE.__str53446 | 0;

HEAP32[__ZL19regexp_static_props + 80 >> 2] = STRING_TABLE.__str63447 | 0;

HEAP32[__ZL19regexp_static_props + 96 >> 2] = STRING_TABLE.__str73448 | 0;

HEAP32[__ZL19regexp_static_props + 112 >> 2] = STRING_TABLE.__str83449 | 0;

HEAP32[__ZL19regexp_static_props + 128 >> 2] = STRING_TABLE.__str93450 | 0;

HEAP32[__ZL19regexp_static_props + 144 >> 2] = STRING_TABLE.__str103451 | 0;

HEAP32[__ZL19regexp_static_props + 160 >> 2] = STRING_TABLE.__str113452 | 0;

HEAP32[__ZL19regexp_static_props + 176 >> 2] = STRING_TABLE.__str123453 | 0;

HEAP32[__ZL19regexp_static_props + 192 >> 2] = STRING_TABLE.__str133454 | 0;

HEAP32[__ZL19regexp_static_props + 208 >> 2] = STRING_TABLE.__str143455 | 0;

HEAP32[__ZL19regexp_static_props + 224 >> 2] = STRING_TABLE.__str153456 | 0;

HEAP32[__ZL19regexp_static_props + 240 >> 2] = STRING_TABLE.__str163457 | 0;

HEAP32[__ZL19regexp_static_props + 256 >> 2] = STRING_TABLE.__str173458 | 0;

HEAP32[__ZL19regexp_static_props + 272 >> 2] = STRING_TABLE.__str183459 | 0;

HEAP32[__ZL19regexp_static_props + 288 >> 2] = STRING_TABLE.__str193460 | 0;

HEAP32[__ZL19regexp_static_props + 304 >> 2] = STRING_TABLE.__str203461 | 0;

HEAP32[__ZL19regexp_static_props + 320 >> 2] = STRING_TABLE.__str213462 | 0;

HEAP32[__ZN2js11RegExpClassE >> 2] = STRING_TABLE._js_RegExp_str | 0;

HEAP32[__ZL14regexp_methods >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14regexp_methods + 12 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14regexp_methods + 24 >> 2] = STRING_TABLE.__str233466 | 0;

HEAP32[__ZL14regexp_methods + 36 >> 2] = STRING_TABLE.__str243467 | 0;

HEAP32[__ZL14regexp_methods + 48 >> 2] = STRING_TABLE._js_test_str | 0;

HEAP32[__ZL8keywords >> 2] = STRING_TABLE._js_false_str | 0;

HEAP32[__ZL8keywords + 16 >> 2] = STRING_TABLE._js_true_str | 0;

HEAP32[__ZL8keywords + 32 >> 2] = STRING_TABLE._js_null_str | 0;

HEAP32[__ZL8keywords + 48 >> 2] = STRING_TABLE._js_break_str | 0;

HEAP32[__ZL8keywords + 64 >> 2] = STRING_TABLE._js_case_str | 0;

HEAP32[__ZL8keywords + 80 >> 2] = STRING_TABLE._js_catch_str | 0;

HEAP32[__ZL8keywords + 96 >> 2] = STRING_TABLE._js_continue_str | 0;

HEAP32[__ZL8keywords + 112 >> 2] = STRING_TABLE._js_debugger_str | 0;

HEAP32[__ZL8keywords + 128 >> 2] = STRING_TABLE._js_default_str | 0;

HEAP32[__ZL8keywords + 144 >> 2] = STRING_TABLE._js_delete_str | 0;

HEAP32[__ZL8keywords + 160 >> 2] = STRING_TABLE._js_do_str | 0;

HEAP32[__ZL8keywords + 176 >> 2] = STRING_TABLE._js_else_str | 0;

HEAP32[__ZL8keywords + 192 >> 2] = STRING_TABLE._js_finally_str | 0;

HEAP32[__ZL8keywords + 208 >> 2] = STRING_TABLE._js_for_str | 0;

HEAP32[__ZL8keywords + 224 >> 2] = STRING_TABLE._js_function_str | 0;

HEAP32[__ZL8keywords + 240 >> 2] = STRING_TABLE._js_if_str | 0;

HEAP32[__ZL8keywords + 256 >> 2] = STRING_TABLE._js_in_str | 0;

HEAP32[__ZL8keywords + 272 >> 2] = STRING_TABLE._js_instanceof_str | 0;

HEAP32[__ZL8keywords + 288 >> 2] = STRING_TABLE._js_new_str | 0;

HEAP32[__ZL8keywords + 304 >> 2] = STRING_TABLE._js_return_str | 0;

HEAP32[__ZL8keywords + 320 >> 2] = STRING_TABLE._js_switch_str | 0;

HEAP32[__ZL8keywords + 336 >> 2] = STRING_TABLE._js_this_str | 0;

HEAP32[__ZL8keywords + 352 >> 2] = STRING_TABLE._js_throw_str | 0;

HEAP32[__ZL8keywords + 368 >> 2] = STRING_TABLE._js_try_str | 0;

HEAP32[__ZL8keywords + 384 >> 2] = STRING_TABLE._js_typeof_str | 0;

HEAP32[__ZL8keywords + 400 >> 2] = STRING_TABLE._js_var_str | 0;

HEAP32[__ZL8keywords + 416 >> 2] = STRING_TABLE._js_void_str | 0;

HEAP32[__ZL8keywords + 432 >> 2] = STRING_TABLE._js_while_str | 0;

HEAP32[__ZL8keywords + 448 >> 2] = STRING_TABLE._js_with_str | 0;

HEAP32[__ZL8keywords + 464 >> 2] = STRING_TABLE._js_class_str | 0;

HEAP32[__ZL8keywords + 480 >> 2] = STRING_TABLE._js_enum_str | 0;

HEAP32[__ZL8keywords + 496 >> 2] = STRING_TABLE._js_export_str | 0;

HEAP32[__ZL8keywords + 512 >> 2] = STRING_TABLE._js_extends_str | 0;

HEAP32[__ZL8keywords + 528 >> 2] = STRING_TABLE._js_import_str | 0;

HEAP32[__ZL8keywords + 544 >> 2] = STRING_TABLE._js_super_str | 0;

HEAP32[__ZL8keywords + 560 >> 2] = STRING_TABLE._js_const_str | 0;

HEAP32[__ZL8keywords + 576 >> 2] = STRING_TABLE._js_let_str | 0;

HEAP32[__ZL8keywords + 592 >> 2] = STRING_TABLE._js_yield_str | 0;

HEAP32[__ZL8keywords + 608 >> 2] = STRING_TABLE._js_implements_str | 0;

HEAP32[__ZL8keywords + 624 >> 2] = STRING_TABLE._js_interface_str | 0;

HEAP32[__ZL8keywords + 640 >> 2] = STRING_TABLE._js_package_str | 0;

HEAP32[__ZL8keywords + 656 >> 2] = STRING_TABLE._js_private_str | 0;

HEAP32[__ZL8keywords + 672 >> 2] = STRING_TABLE._js_protected_str | 0;

HEAP32[__ZL8keywords + 688 >> 2] = STRING_TABLE._js_public_str | 0;

HEAP32[__ZL8keywords + 704 >> 2] = STRING_TABLE._js_static_str | 0;

HEAP32[__ZN2js11ScriptClassE >> 2] = STRING_TABLE.__str23669 | 0;

HEAP32[__ZL16string_functions >> 2] = STRING_TABLE._js_escape_str | 0;

HEAP32[__ZL16string_functions + 12 >> 2] = STRING_TABLE._js_unescape_str | 0;

HEAP32[__ZL16string_functions + 24 >> 2] = STRING_TABLE._js_uneval_str | 0;

HEAP32[__ZL16string_functions + 36 >> 2] = STRING_TABLE._js_decodeURI_str | 0;

HEAP32[__ZL16string_functions + 48 >> 2] = STRING_TABLE._js_encodeURI_str | 0;

HEAP32[__ZL16string_functions + 60 >> 2] = STRING_TABLE._js_decodeURIComponent_str | 0;

HEAP32[__ZL16string_functions + 72 >> 2] = STRING_TABLE._js_encodeURIComponent_str | 0;

HEAP32[_js_EmptySubString + 4 >> 2] = _js_empty_ucstr | 0;

HEAP32[__ZN2js11StringClassE >> 2] = STRING_TABLE._js_String_str | 0;

HEAP32[__ZL14string_methods >> 2] = STRING_TABLE.__str3763 | 0;

HEAP32[__ZL14string_methods + 12 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL14string_methods + 24 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL14string_methods + 36 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL14string_methods + 48 >> 2] = STRING_TABLE.__str13764 | 0;

HEAP32[__ZL14string_methods + 60 >> 2] = STRING_TABLE.__str23765 | 0;

HEAP32[__ZL14string_methods + 72 >> 2] = STRING_TABLE.__str33766 | 0;

HEAP32[__ZL14string_methods + 84 >> 2] = STRING_TABLE.__str43767 | 0;

HEAP32[__ZL14string_methods + 96 >> 2] = STRING_TABLE.__str53768 | 0;

HEAP32[__ZL14string_methods + 108 >> 2] = STRING_TABLE.__str63769 | 0;

HEAP32[__ZL14string_methods + 120 >> 2] = STRING_TABLE.__str73770 | 0;

HEAP32[__ZL14string_methods + 132 >> 2] = STRING_TABLE.__str83771 | 0;

HEAP32[__ZL14string_methods + 144 >> 2] = STRING_TABLE.__str93772 | 0;

HEAP32[__ZL14string_methods + 156 >> 2] = STRING_TABLE.__str103773 | 0;

HEAP32[__ZL14string_methods + 168 >> 2] = STRING_TABLE.__str113774 | 0;

HEAP32[__ZL14string_methods + 180 >> 2] = STRING_TABLE.__str123775 | 0;

HEAP32[__ZL14string_methods + 192 >> 2] = STRING_TABLE.__str133776 | 0;

HEAP32[__ZL14string_methods + 204 >> 2] = STRING_TABLE.__str143777 | 0;

HEAP32[__ZL14string_methods + 216 >> 2] = STRING_TABLE.__str153778 | 0;

HEAP32[__ZL14string_methods + 228 >> 2] = STRING_TABLE.__str314277 | 0;

HEAP32[__ZL14string_methods + 240 >> 2] = STRING_TABLE.__str173780 | 0;

HEAP32[__ZL14string_methods + 252 >> 2] = STRING_TABLE.__str183781 | 0;

HEAP32[__ZL14string_methods + 264 >> 2] = STRING_TABLE.__str193782 | 0;

HEAP32[__ZL14string_methods + 276 >> 2] = STRING_TABLE.__str203783 | 0;

HEAP32[__ZL14string_methods + 288 >> 2] = STRING_TABLE.__str213784 | 0;

HEAP32[__ZL14string_methods + 300 >> 2] = STRING_TABLE.__str223785 | 0;

HEAP32[__ZL14string_methods + 312 >> 2] = STRING_TABLE.__str233786 | 0;

HEAP32[__ZL14string_methods + 324 >> 2] = STRING_TABLE.__str243787 | 0;

HEAP32[__ZL14string_methods + 336 >> 2] = STRING_TABLE.__str253788 | 0;

HEAP32[__ZL14string_methods + 348 >> 2] = STRING_TABLE.__str263789 | 0;

HEAP32[__ZL14string_methods + 360 >> 2] = STRING_TABLE.__str273790 | 0;

HEAP32[__ZL14string_methods + 372 >> 2] = STRING_TABLE.__str283791 | 0;

HEAP32[__ZL14string_methods + 384 >> 2] = STRING_TABLE.__str293792 | 0;

HEAP32[__ZL14string_methods + 396 >> 2] = STRING_TABLE.__str303793 | 0;

HEAP32[__ZL14string_methods + 408 >> 2] = STRING_TABLE.__str313794 | 0;

HEAP32[__ZL14string_methods + 420 >> 2] = STRING_TABLE.__str323795 | 0;

HEAP32[__ZL14string_methods + 432 >> 2] = STRING_TABLE.__str333796 | 0;

HEAP32[__ZL21string_static_methods >> 2] = STRING_TABLE.__str343797 | 0;

HEAP32[__ZN2js11ArrayBuffer9slowClassE >> 2] = STRING_TABLE._js_ArrayBuffer_str | 0;

HEAP32[__ZN2js16ArrayBufferClassE >> 2] = STRING_TABLE._js_ArrayBuffer_str | 0;

HEAP32[__ZN2js11ArrayBuffer7jspropsE >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE >> 2] = STRING_TABLE._js_length_str | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 16 >> 2] = STRING_TABLE.__str23955 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 32 >> 2] = STRING_TABLE.__str33956 | 0;

HEAP32[__ZN2js10TypedArray7jspropsE + 48 >> 2] = STRING_TABLE.__str43957 | 0;

HEAP32[__ZN9Int8Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN9Int8Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN10Uint8Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Uint8Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN10Int16Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Int16Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN11Uint16Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN11Uint16Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN10Int32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN10Int32Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN11Uint32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN11Uint32Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN12Float32Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN12Float32Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN12Float64Array7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN12Float64Array7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN17Uint8ClampedArray7jsfuncsE >> 2] = STRING_TABLE.__str53958 | 0;

HEAP32[__ZN17Uint8ClampedArray7jsfuncsE + 12 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE >> 2] = STRING_TABLE._js_Int8Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 232 >> 2] = STRING_TABLE._js_Uint8Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 464 >> 2] = STRING_TABLE._js_Int16Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 696 >> 2] = STRING_TABLE._js_Uint16Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 928 >> 2] = STRING_TABLE._js_Int32Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1160 >> 2] = STRING_TABLE._js_Uint32Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1392 >> 2] = STRING_TABLE._js_Float32Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1624 >> 2] = STRING_TABLE._js_Float64Array_str | 0;

HEAP32[__ZN2js10TypedArray11fastClassesE + 1856 >> 2] = STRING_TABLE._js_Uint8ClampedArray_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE >> 2] = STRING_TABLE._js_Int8Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 232 >> 2] = STRING_TABLE._js_Uint8Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 464 >> 2] = STRING_TABLE._js_Int16Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 696 >> 2] = STRING_TABLE._js_Uint16Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 928 >> 2] = STRING_TABLE._js_Int32Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1160 >> 2] = STRING_TABLE._js_Uint32Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1392 >> 2] = STRING_TABLE._js_Float32Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1624 >> 2] = STRING_TABLE._js_Float64Array_str | 0;

HEAP32[__ZN2js10TypedArray11slowClassesE + 1856 >> 2] = STRING_TABLE._js_Uint8ClampedArray_str | 0;

HEAP32[__ZN2js12WeakMapClassE >> 2] = STRING_TABLE._js_WeakMap_str | 0;

HEAP32[__ZL16weak_map_methods >> 2] = STRING_TABLE.__str14078 | 0;

HEAP32[__ZL16weak_map_methods + 12 >> 2] = STRING_TABLE._js_get_str | 0;

HEAP32[__ZL16weak_map_methods + 24 >> 2] = STRING_TABLE._js_delete_str | 0;

HEAP32[__ZL16weak_map_methods + 36 >> 2] = STRING_TABLE._js_set_str | 0;

HEAP32[__ZN9JSWrapper9singletonE >> 2] = __ZTV9JSWrapper + 8 | 0;

HEAP32[__ZN9JSWrapper9singletonE + 4 >> 2] = __ZL14sWrapperFamily;

HEAP32[__ZN25JSCrossCompartmentWrapper9singletonE >> 2] = __ZTV25JSCrossCompartmentWrapper + 8 | 0;

HEAP32[__ZN25JSCrossCompartmentWrapper9singletonE + 4 >> 2] = __ZL14sWrapperFamily;

HEAP32[__ZN2js14NamespaceClassE >> 2] = STRING_TABLE._js_Namespace_str | 0;

HEAP32[__ZL17namespace_methods >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZN2js10QNameClassE >> 2] = STRING_TABLE._js_QName_str | 0;

HEAP32[__ZN2js18AttributeNameClassE >> 2] = STRING_TABLE._js_AttributeName_str | 0;

HEAP32[__ZN2js12AnyNameClassE >> 2] = STRING_TABLE._js_AnyName_str | 0;

HEAP32[__ZL13qname_methods >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL16xml_static_props >> 2] = STRING_TABLE.__ZL21js_ignoreComments_str | 0;

HEAP32[__ZL16xml_static_props + 16 >> 2] = STRING_TABLE.__ZL35js_ignoreProcessingInstructions_str | 0;

HEAP32[__ZL16xml_static_props + 32 >> 2] = STRING_TABLE.__ZL23js_ignoreWhitespace_str | 0;

HEAP32[__ZL16xml_static_props + 48 >> 2] = STRING_TABLE.__ZL21js_prettyPrinting_str | 0;

HEAP32[__ZL16xml_static_props + 64 >> 2] = STRING_TABLE.__ZL19js_prettyIndent_str | 0;

HEAP32[__ZN2js8XMLClassE >> 2] = STRING_TABLE._js_XML_str | 0;

HEAP32[_js_xml_class_str >> 2] = STRING_TABLE.__str34249 | 0;

HEAP32[_js_xml_class_str + 4 >> 2] = STRING_TABLE.__str44250 | 0;

HEAP32[_js_xml_class_str + 8 >> 2] = STRING_TABLE.__str2343386 | 0;

HEAP32[_js_xml_class_str + 12 >> 2] = STRING_TABLE.__str54251 | 0;

HEAP32[_js_xml_class_str + 16 >> 2] = STRING_TABLE.__str2363388 | 0;

HEAP32[_js_xml_class_str + 20 >> 2] = STRING_TABLE.__str64252 | 0;

HEAP32[__ZL11xml_methods >> 2] = STRING_TABLE.__str74253 | 0;

HEAP32[__ZL11xml_methods + 12 >> 2] = STRING_TABLE.__str84254 | 0;

HEAP32[__ZL11xml_methods + 24 >> 2] = STRING_TABLE.__str2343386 | 0;

HEAP32[__ZL11xml_methods + 36 >> 2] = STRING_TABLE.__str94255 | 0;

HEAP32[__ZL11xml_methods + 48 >> 2] = STRING_TABLE.__str104256 | 0;

HEAP32[__ZL11xml_methods + 60 >> 2] = STRING_TABLE.__str114257 | 0;

HEAP32[__ZL11xml_methods + 72 >> 2] = STRING_TABLE.__str124258 | 0;

HEAP32[__ZL11xml_methods + 84 >> 2] = STRING_TABLE.__str134259 | 0;

HEAP32[__ZL11xml_methods + 96 >> 2] = STRING_TABLE.__str144260 | 0;

HEAP32[__ZL11xml_methods + 108 >> 2] = STRING_TABLE.__str154261 | 0;

HEAP32[__ZL11xml_methods + 120 >> 2] = STRING_TABLE.__str164262 | 0;

HEAP32[__ZL11xml_methods + 132 >> 2] = STRING_TABLE.__str174263 | 0;

HEAP32[__ZL11xml_methods + 144 >> 2] = STRING_TABLE._js_hasOwnProperty_str | 0;

HEAP32[__ZL11xml_methods + 156 >> 2] = STRING_TABLE.__str194265 | 0;

HEAP32[__ZL11xml_methods + 168 >> 2] = STRING_TABLE.__str204266 | 0;

HEAP32[__ZL11xml_methods + 180 >> 2] = STRING_TABLE.__str214267 | 0;

HEAP32[__ZL11xml_methods + 192 >> 2] = STRING_TABLE.__str224268 | 0;

HEAP32[__ZL11xml_methods + 204 >> 2] = STRING_TABLE.__str234269 | 0;

HEAP32[__ZL11xml_methods + 216 >> 2] = STRING_TABLE._js_length_str | 0;

HEAP32[__ZL11xml_methods + 228 >> 2] = STRING_TABLE.__ZL16js_localName_str | 0;

HEAP32[__ZL11xml_methods + 240 >> 2] = STRING_TABLE._js_name_str | 0;

HEAP32[__ZL11xml_methods + 252 >> 2] = STRING_TABLE._js_namespace_str | 0;

HEAP32[__ZL11xml_methods + 264 >> 2] = STRING_TABLE.__str244270 | 0;

HEAP32[__ZL11xml_methods + 276 >> 2] = STRING_TABLE.__str254271 | 0;

HEAP32[__ZL11xml_methods + 288 >> 2] = STRING_TABLE.__str264272 | 0;

HEAP32[__ZL11xml_methods + 300 >> 2] = STRING_TABLE.__ZL17js_xml_parent_str | 0;

HEAP32[__ZL11xml_methods + 312 >> 2] = STRING_TABLE.__str274273 | 0;

HEAP32[__ZL11xml_methods + 324 >> 2] = STRING_TABLE.__str284274 | 0;

HEAP32[__ZL11xml_methods + 336 >> 2] = STRING_TABLE._js_propertyIsEnumerable_str | 0;

HEAP32[__ZL11xml_methods + 348 >> 2] = STRING_TABLE.__str304276 | 0;

HEAP32[__ZL11xml_methods + 360 >> 2] = STRING_TABLE.__str314277 | 0;

HEAP32[__ZL11xml_methods + 372 >> 2] = STRING_TABLE.__str324278 | 0;

HEAP32[__ZL11xml_methods + 384 >> 2] = STRING_TABLE.__str334279 | 0;

HEAP32[__ZL11xml_methods + 396 >> 2] = STRING_TABLE.__str344280 | 0;

HEAP32[__ZL11xml_methods + 408 >> 2] = STRING_TABLE.__str354281 | 0;

HEAP32[__ZL11xml_methods + 420 >> 2] = STRING_TABLE.__str2363388 | 0;

HEAP32[__ZL11xml_methods + 432 >> 2] = STRING_TABLE._js_toSource_str | 0;

HEAP32[__ZL11xml_methods + 444 >> 2] = STRING_TABLE._js_toString_str | 0;

HEAP32[__ZL11xml_methods + 456 >> 2] = STRING_TABLE.__ZL18js_toXMLString_str | 0;

HEAP32[__ZL11xml_methods + 468 >> 2] = STRING_TABLE._js_valueOf_str | 0;

HEAP32[__ZL18xml_static_methods >> 2] = STRING_TABLE.__str364282 | 0;

HEAP32[__ZL18xml_static_methods + 12 >> 2] = STRING_TABLE.__str374283 | 0;

HEAP32[__ZL18xml_static_methods + 24 >> 2] = STRING_TABLE.__str384284 | 0;

HEAP32[__ZL15namespace_props >> 2] = STRING_TABLE.__str2033355 | 0;

HEAP32[__ZL15namespace_props + 16 >> 2] = STRING_TABLE.__ZL10js_uri_str | 0;

HEAP32[_js_XMLFilterClass >> 2] = STRING_TABLE.__str454291 | 0;

HEAP32[__ZL11qname_props >> 2] = STRING_TABLE.__ZL10js_uri_str | 0;

HEAP32[__ZL11qname_props + 16 >> 2] = STRING_TABLE.__ZL16js_localName_str | 0;

HEAP32[__ZTVSt9bad_alloc + 4 >> 2] = __ZTISt9bad_alloc;

HEAP32[__ZTVSt20bad_array_new_length + 4 >> 2] = __ZTISt20bad_array_new_length;

__ZTVN10__cxxabiv120__si_class_type_infoE = allocate([ 2, 0, 0, 0, 0 ], [ "i8*", 0, 0, 0, 0 ], ALLOC_STATIC);

HEAP32[__ZTISt9bad_alloc >> 2] = __ZTVN10__cxxabiv120__si_class_type_infoE + 8 | 0;

HEAP32[__ZTISt9bad_alloc + 4 >> 2] = STRING_TABLE.__ZTSSt9bad_alloc | 0;

HEAP32[__ZTISt9bad_alloc + 8 >> 2] = __ZTISt9exception;

HEAP32[__ZTISt20bad_array_new_length >> 2] = __ZTVN10__cxxabiv120__si_class_type_infoE + 8 | 0;

HEAP32[__ZTISt20bad_array_new_length + 4 >> 2] = STRING_TABLE.__ZTSSt20bad_array_new_length | 0;

HEAP32[__ZTISt20bad_array_new_length + 8 >> 2] = __ZTISt9bad_alloc;

__ZN2js14BreakpointSiteC1EP8JSScriptPh = 2008;

__ZN2js10BreakpointC1EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject = 2010;

__ZN2js8DebuggerC1EP9JSContextP8JSObject = 2012;

__ZN2js8DebuggerD1Ev = 2014;

__ZN2js10StackSpaceC1Ev = 2016;

__ZN2js10StackSpaceD1Ev = 2018;

__ZN2js12ContextStackC1EP9JSContext = 2020;

__ZN2js12ContextStackD1Ev = 2022;

__ZN2js9StackIterC1EP9JSContextNS0_11SavedOptionE = 2024;

__ZN2js13AllFramesIterC1ERNS_10StackSpaceE = 2026;

__ZN9JSRuntimeC1Ev = 2028;

__ZN9JSRuntimeD1Ev = 2030;

__ZN2js7SCInputC1EP9JSContextPKyj = 2032;

__ZN2js8SCOutputC1EP9JSContext = 2034;

__ZN2js10ThreadDataC1Ev = 2036;

__ZN2js10ThreadDataD1Ev = 2038;

__ZN9JSContextC1EP9JSRuntime = 2040;

__ZN9JSContextD1Ev = 2042;

__ZN13JSCompartmentC1EP9JSRuntime = 2044;

__ZN13JSCompartmentD1Ev = 2046;

__ZN2js5crash5StackC1Ey = 2048;

__ZN2js5crash4RingC1Ey = 2050;

__ZN15JSCodeGeneratorC1EPN2js6ParserEj = 2052;

__ZN15JSCodeGeneratorD1Ev = 2054;

__ZN2JS23AutoPreserveCompartmentC1EP9JSContext = 2056;

__ZN2JS23AutoPreserveCompartmentD1Ev = 2058;

__ZN2JS21AutoSwitchCompartmentC1EP9JSContextP13JSCompartment = 2060;

__ZN2JS21AutoSwitchCompartmentC1EP9JSContextP8JSObject = 2062;

__ZN2JS21AutoSwitchCompartmentD1Ev = 2064;

__ZN2js8GCMarkerC1EP9JSContext = 2066;

__ZN2js8GCMarkerD1Ev = 2068;

__ZN13AutoGCSessionC1EP9JSContext = 2070;

__ZN13AutoGCSessionD1Ev = 2072;

__ZN2js7GCTimerC1EP9JSRuntimeP13JSCompartment = 2074;

__ZN2js5types17TypeScriptNestingD1Ev = 2076;

__ZN2js5types15TypeCompartmentD1Ev = 2078;

__ZN2js9MathCacheC1Ev = 2080;

__ZN2js12ToCStringBufC1Ev = 2082;

__ZN2js12ToCStringBufD1Ev = 2084;

__ZN2js8PropDescC1Ev = 2086;

__ZN2js6ParserC1EP9JSContextP12JSPrincipalsPNS_10StackFrameEb = 2088;

__ZN2js6ParserD1Ev = 2090;

__ZN2js8CompilerC1EP9JSContextP12JSPrincipalsPNS_10StackFrameE = 2092;

__ZN2js14JSProxyHandlerD1Ev = 1028;

__ZN22JSScriptedProxyHandlerC1Ev = 2094;

__ZN22JSScriptedProxyHandlerD1Ev = 1028;

__ZN22JSScriptedProxyHandlerD2Ev = 1028;

__ZN2js11TokenStreamC1EP9JSContext = 2096;

__ZN2js11TokenStreamD1Ev = 2098;

__ZN2js11ArrayBufferD1Ev = 2100;

__ZN9JSWrapperC1Ej = 2102;

__ZN9JSWrapperD1Ev = 1728;

__ZN2js10ForceFrameC1EP9JSContextP8JSObject = 2104;

__ZN2js10ForceFrameD1Ev = 2106;

__ZN2js15AutoCompartmentC1EP9JSContextP8JSObject = 2108;

__ZN2js15AutoCompartmentD1Ev = 2110;

__ZN2js11ErrorCopierD1Ev = 2112;

__ZN25JSCrossCompartmentWrapperC1Ej = 2114;

__ZN25JSCrossCompartmentWrapperD1Ev = 1728;

__ZN25JSCrossCompartmentWrapperD2Ev = 1728;

__ZN2js14XDRScriptStateC1EP10JSXDRState = 2116;

__ZN2js14XDRScriptStateD1Ev = 2118;

__ZN2JS15PerfMeasurementC1ENS0_9EventMaskE = 2120;

__ZN2JS15PerfMeasurementD1Ev = 2122;

__ZNSt9bad_allocC1Ev = 2124;

__ZNSt9bad_allocD1Ev = 302;

__ZNSt20bad_array_new_lengthC1Ev = 2126;

__ZNSt20bad_array_new_lengthD1Ev = 302;

__ZNSt20bad_array_new_lengthD2Ev = 302;

FUNCTION_TABLE = [ 0, 0, __Z18js_GetErrorMessagePvPKcj, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, _JS_PropertyStub, 0, _JS_StrictPropertyStub, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv, 0, __Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __Z9js_ObjectP9JSContextjPN2JS5ValueE, 0, __ZN2js8FunctionEP9JSContextjPN2JS5ValueE, 0, __ZN2js4evalEP9JSContextjPN2JS5ValueE, 0, __ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE, 0, _TransparentObjectWrapper, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __Z18js_InitObjectClassP9JSContextP8JSObject, 0, __Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE, 0, _js_DecompileFunction, 0, _js_DecompileFunctionBody, 0, __Z16js_SetAttributesP9JSContextP8JSObjectiPj, 0, __Z16js_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL20sort_compare_stringsPvPKvS1_Pi, 0, __ZL12sort_comparePvPKvS1_Pi, 0, __Z8js_ArrayP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZL7BooleanP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZL16print_gmt_stringPcjd, 0, __ZL16print_iso_stringPcjd, 0, __Z7js_DateP9JSContextjPN2JS5ValueE, 0, _JS_ConvertStub, 0, __ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL26DumpBytecodeScriptCallbackP9JSContextPvS1_13JSGCTraceKindj, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode, 0, __ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode, 0, __ZL9ExceptionP9JSContextjPN2JS5ValueE, 0, __ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZN2js10array_pushEP9JSContextjPN2JS5ValueE, 0, __ZN2js9array_popEP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZN2js2gc12EmptyArenaOpEPNS0_5ArenaE, 0, __ZN2js10array_sortEP9JSContextjPN2JS5ValueE, 0, __ZN2js11str_replaceEP9JSContextjPN2JS5ValueE, 0, __Z9js_TypeOfP9JSContextP8JSObject, 0, _JS_EnumerateStub, 0, __ZL8IteratorP9JSContextjPN2JS5ValueE, 0, __Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv, 0, _sqrt, 0, _acos, 0, _asin, 0, _atan, 0, _cos, 0, __ZL13math_exp_bodyd, 0, _log, 0, _sin, 0, _tan, 0, __ZL6NumberP9JSContextjPN2JS5ValueE, 0, __ZL14js_hash_objectPKv, 0, _JS_CompareValues, 0, __ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv, 0, __ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv, 0, __ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, _JS_ResolveStub, 0, __Z23js_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __Z23js_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __Z15js_str_toStringP9JSContextjPN2JS5ValueE, 0, __Z14js_num_valueOfP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv, 0, __ZL2JAP9JSContextP8JSObjectP16StringifyContext, 0, __ZL2JOP9JSContextP8JSObjectP16StringifyContext, 0, __ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv, 0, __ZL14CompareOffsetsPvPKvS1_Pi, 0, __ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZL12pm_constructP9JSContextjPN2JS5ValueE, 0, __ZL9FuncStuffP15SprintfStateStrPKcj, 0, __ZL9GrowStuffP15SprintfStateStrPKcj, 0, __ZL10LimitStuffP15SprintfStateStrPKcj, 0, __ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv, 0, __ZL16regexp_constructP9JSContextjPN2JS5ValueE, 0, __ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv, 0, __ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv, 0, __ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv, 0, __Z9js_StringP9JSContextjPN2JS5ValueE, 0, __Z16js_ValueToSourceP9JSContextRKN2JS5ValueE, 0, __Z16js_ValueToStringP9JSContextRKN2JS5ValueE, 0, __Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE, 0, __ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv, 0, __ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv, 0, __ZL17WeakMap_constructP9JSContextjPN2JS5ValueE, 0, __ZL13attr_identityPKvS0_, 0, __ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL15namespace_matchPKvS0_, 0, __ZL9NamespaceP9JSContextjPN2JS5ValueE, 0, __ZL5QNameP9JSContextjPN2JS5ValueE, 0, __ZL3XMLP9JSContextjPN2JS5ValueE, 0, __ZL7XMLListP9JSContextjPN2JS5ValueE, 0, __ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE, 0, __ZL13MatchAttrNameP8JSObjectP5JSXML, 0, __ZL13MatchElemNameP8JSObjectP5JSXML, 0, __ZL18namespace_identityPKvS0_, 0, __ZL20namespace_full_matchPKvS0_, 0, __ZNSt9bad_allocD2Ev, 0, __ZL20DebuggerObject_traceP8JSTracerP8JSObject, 0, __ZN2js8Debugger8finalizeEP9JSContextP8JSObject, 0, __ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject, 0, __ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE, 0, __ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE, 0, __ZL20DebuggerScript_traceP8JSTracerP8JSObject, 0, __ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE, 0, __ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE, 0, __ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE, 0, __ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE, 0, __ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE, 0, __ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE, 0, __ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE, 0, __ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE, 0, __ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE, 0, __ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE, 0, __ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE, 0, __ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE, 0, __ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE, 0, __ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE, 0, __ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE, 0, __ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE, 0, __ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE, 0, __ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE, 0, __ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE, 0, __ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer, 0, ___cxa_pure_virtual, 0, __ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject, 0, __Z20js_InitFunctionClassP9JSContextP8JSObject, 0, __Z17js_InitArrayClassP9JSContextP8JSObject, 0, __Z19js_InitBooleanClassP9JSContextP8JSObject, 0, __Z16js_InitDateClassP9JSContextP8JSObject, 0, __Z16js_InitMathClassP9JSContextP8JSObject, 0, __Z18js_InitNumberClassP9JSContextP8JSObject, 0, __Z18js_InitStringClassP9JSContextP8JSObject, 0, __Z23js_InitExceptionClassesP9JSContextP8JSObject, 0, __Z18js_InitRegExpClassP9JSContextP8JSObject, 0, __Z15js_InitXMLClassP9JSContextP8JSObject, 0, __Z21js_InitNamespaceClassP9JSContextP8JSObject, 0, __Z17js_InitQNameClassP9JSContextP8JSObject, 0, __Z22js_InitIteratorClassesP9JSContextP8JSObject, 0, __Z16js_InitJSONClassP9JSContextP8JSObject, 0, __Z24js_InitTypedArrayClassesP9JSContextP8JSObject, 0, __Z19js_InitWeakMapClassP9JSContextP8JSObject, 0, _js_InitProxyClass, 0, __ZL18prop_iter_finalizeP9JSContextP8JSObject, 0, __ZL15prop_iter_traceP8JSTracerP8JSObject, 0, __ZL11array_traceP8JSTracerP8JSObject, 0, __ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej, 0, __ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej, 0, __ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL19array_getAttributesP9JSContextP8JSObjectiPj, 0, __ZL26array_getElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19array_setAttributesP9JSContextP8JSObjectiPj, 0, __ZL26array_setElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL12array_typeOfP9JSContextP8JSObject, 0, __ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL14array_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL14array_toStringP9JSContextjPN2JS5ValueE, 0, __ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL10array_joinP9JSContextjPN2JS5ValueE, 0, __ZL13array_reverseP9JSContextjPN2JS5ValueE, 0, __ZL11array_shiftP9JSContextjPN2JS5ValueE, 0, __ZL13array_unshiftP9JSContextjPN2JS5ValueE, 0, __ZL12array_spliceP9JSContextjPN2JS5ValueE, 0, __ZL12array_concatP9JSContextjPN2JS5ValueE, 0, __ZL11array_sliceP9JSContextjPN2JS5ValueE, 0, __ZL13array_indexOfP9JSContextjPN2JS5ValueE, 0, __ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE, 0, __ZL13array_forEachP9JSContextjPN2JS5ValueE, 0, __ZL9array_mapP9JSContextjPN2JS5ValueE, 0, __ZL12array_reduceP9JSContextjPN2JS5ValueE, 0, __ZL17array_reduceRightP9JSContextjPN2JS5ValueE, 0, __ZL12array_filterP9JSContextjPN2JS5ValueE, 0, __ZL10array_someP9JSContextjPN2JS5ValueE, 0, __ZL11array_everyP9JSContextjPN2JS5ValueE, 0, __ZL13array_isArrayP9JSContextjPN2JS5ValueE, 0, __ZL13bool_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13bool_toStringP9JSContextjPN2JS5ValueE, 0, __ZL12bool_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL8date_UTCP9JSContextjPN2JS5ValueE, 0, __ZL10date_parseP9JSContextjPN2JS5ValueE, 0, __ZL8date_nowP9JSContextjPN2JS5ValueE, 0, __ZL12date_getTimeP9JSContextjPN2JS5ValueE, 0, __ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE, 0, __ZL12date_getYearP9JSContextjPN2JS5ValueE, 0, __ZL16date_getFullYearP9JSContextjPN2JS5ValueE, 0, __ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE, 0, __ZL13date_getMonthP9JSContextjPN2JS5ValueE, 0, __ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE, 0, __ZL12date_getDateP9JSContextjPN2JS5ValueE, 0, __ZL15date_getUTCDateP9JSContextjPN2JS5ValueE, 0, __ZL11date_getDayP9JSContextjPN2JS5ValueE, 0, __ZL14date_getUTCDayP9JSContextjPN2JS5ValueE, 0, __ZL13date_getHoursP9JSContextjPN2JS5ValueE, 0, __ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE, 0, __ZL15date_getMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE, 0, __ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL12date_setTimeP9JSContextjPN2JS5ValueE, 0, __ZL12date_setYearP9JSContextjPN2JS5ValueE, 0, __ZL16date_setFullYearP9JSContextjPN2JS5ValueE, 0, __ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE, 0, __ZL13date_setMonthP9JSContextjPN2JS5ValueE, 0, __ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE, 0, __ZL12date_setDateP9JSContextjPN2JS5ValueE, 0, __ZL15date_setUTCDateP9JSContextjPN2JS5ValueE, 0, __ZL13date_setHoursP9JSContextjPN2JS5ValueE, 0, __ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE, 0, __ZL15date_setMinutesP9JSContextjPN2JS5ValueE, 0, __ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE, 0, __ZL15date_setSecondsP9JSContextjPN2JS5ValueE, 0, __ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE, 0, __ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE, 0, __ZL16date_toGMTStringP9JSContextjPN2JS5ValueE, 0, __ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE, 0, __ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE, 0, __ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE, 0, __ZL17date_toDateStringP9JSContextjPN2JS5ValueE, 0, __ZL17date_toTimeStringP9JSContextjPN2JS5ValueE, 0, __ZL16date_toISOStringP9JSContextjPN2JS5ValueE, 0, __ZL11date_toJSONP9JSContextjPN2JS5ValueE, 0, __ZL13date_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13date_toStringP9JSContextjPN2JS5ValueE, 0, __ZL12date_valueOfP9JSContextjPN2JS5ValueE, 0, _JS_DHashAllocTable, 0, _JS_DHashFreeTable, 0, _JS_DHashVoidPtrKeyStub, 0, _JS_DHashMatchEntryStub, 0, _JS_DHashMoveEntryStub, 0, _JS_DHashClearEntryStub, 0, _JS_DHashFinalizeStub, 0, __ZL11exn_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12exn_finalizeP9JSContextP8JSObject, 0, __ZL9exn_traceP8JSTracerP8JSObject, 0, __ZL12exn_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12exn_toStringP9JSContextjPN2JS5ValueE, 0, __ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20strictargs_enumerateP9JSContextP8JSObject, 0, __ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL13args_finalizeP9JSContextP8JSObject, 0, __ZL10args_traceP8JSTracerP8JSObject, 0, __ZL14args_enumerateP9JSContextP8JSObject, 0, __ZL12args_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12call_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL10call_traceP8JSTracerP8JSObject, 0, __ZL13fun_enumerateP9JSContextP8JSObject, 0, __ZL11fun_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL12fun_finalizeP9JSContextP8JSObject, 0, __ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL9fun_traceP8JSTracerP8JSObject, 0, __ZL12fun_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12fun_toStringP9JSContextjPN2JS5ValueE, 0, __Z12js_fun_applyP9JSContextjPN2JS5ValueE, 0, __Z11js_fun_callP9JSContextjPN2JS5ValueE, 0, __ZL8fun_bindP9JSContextjPN2JS5ValueE, 0, __ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE, 0, __ZL17DefaultAllocTablePvj, 0, __ZL16DefaultFreeTablePvS_j, 0, __ZL17DefaultAllocEntryPvPKv, 0, __ZL16DefaultFreeEntryPvP11JSHashEntryj, 0, __ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE, 0, __ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb, 0, __ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN26TypeConstraintFreezeGlobal7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN31TypeConstraintFreezeOwnProperty7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN31TypeConstraintFreezeOwnProperty16newPropertyStateEP9JSContextPN2js5types7TypeSetE, 0, __ZN31TypeConstraintFreezeObjectFlags7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN31TypeConstraintFreezeObjectFlags14newObjectStateEP9JSContextPN2js5types10TypeObjectEb, 0, __ZN34TypeConstraintFreezeObjectFlagsSet7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintFreezeTypeTag7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN20TypeConstraintFreeze7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb, 0, __ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE, 0, __ZL20no_such_method_traceP8JSTracerP8JSObject, 0, __ZNK23GenericInterruptEnablerIiE16enableInterruptsEv, 0, __ZL17iterator_finalizeP9JSContextP8JSObject, 0, __ZL14iterator_traceP8JSTracerP8JSObject, 0, __ZL17iterator_iteratorP9JSContextP8JSObjecti, 0, __ZL13iterator_nextP9JSContextjPN2JS5ValueE, 0, __ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL18generator_finalizeP9JSContextP8JSObject, 0, __ZL15generator_traceP8JSTracerP8JSObject, 0, __ZL14generator_nextP9JSContextjPN2JS5ValueE, 0, __ZL14generator_sendP9JSContextjPN2JS5ValueE, 0, __ZL15generator_throwP9JSContextjPN2JS5ValueE, 0, __ZL15generator_closeP9JSContextjPN2JS5ValueE, 0, __ZL13math_toSourceP9JSContextjPN2JS5ValueE, 0, __Z11js_math_absP9JSContextjPN2JS5ValueE, 0, __ZL9math_acosP9JSContextjPN2JS5ValueE, 0, __ZL9math_asinP9JSContextjPN2JS5ValueE, 0, __ZL9math_atanP9JSContextjPN2JS5ValueE, 0, __ZL10math_atan2P9JSContextjPN2JS5ValueE, 0, __Z12js_math_ceilP9JSContextjPN2JS5ValueE, 0, __ZL8math_cosP9JSContextjPN2JS5ValueE, 0, __ZL8math_expP9JSContextjPN2JS5ValueE, 0, __Z13js_math_floorP9JSContextjPN2JS5ValueE, 0, __ZL8math_logP9JSContextjPN2JS5ValueE, 0, __Z11js_math_maxP9JSContextjPN2JS5ValueE, 0, __Z11js_math_minP9JSContextjPN2JS5ValueE, 0, __Z11js_math_powP9JSContextjPN2JS5ValueE, 0, __ZL11math_randomP9JSContextjPN2JS5ValueE, 0, __Z13js_math_roundP9JSContextjPN2JS5ValueE, 0, __ZL8math_sinP9JSContextjPN2JS5ValueE, 0, __Z12js_math_sqrtP9JSContextjPN2JS5ValueE, 0, __ZL8math_tanP9JSContextjPN2JS5ValueE, 0, __ZL9num_isNaNP9JSContextjPN2JS5ValueE, 0, __ZL12num_isFiniteP9JSContextjPN2JS5ValueE, 0, __ZL14num_parseFloatP9JSContextjPN2JS5ValueE, 0, __ZL12num_parseIntP9JSContextjPN2JS5ValueE, 0, __ZL12num_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12num_toStringP9JSContextjPN2JS5ValueE, 0, __ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL11num_toFixedP9JSContextjPN2JS5ValueE, 0, __ZL17num_toExponentialP9JSContextjPN2JS5ValueE, 0, __ZL15num_toPrecisionP9JSContextjPN2JS5ValueE, 0, __ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL12obj_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12obj_toStringP9JSContextjPN2JS5ValueE, 0, __ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE, 0, __ZL11obj_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL9obj_watchP9JSContextjPN2JS5ValueE, 0, __ZL11obj_unwatchP9JSContextjPN2JS5ValueE, 0, __ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE, 0, __ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE, 0, __ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE, 0, __Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE, 0, __Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE, 0, __ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE, 0, __ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE, 0, __Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE, 0, __ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE, 0, __ZL8obj_keysP9JSContextjPN2JS5ValueE, 0, __ZL18obj_definePropertyP9JSContextjPN2JS5ValueE, 0, __ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE, 0, __ZL10obj_createP9JSContextjPN2JS5ValueE, 0, __ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE, 0, __ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE, 0, __ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE, 0, __ZL10obj_freezeP9JSContextjPN2JS5ValueE, 0, __ZL12obj_isFrozenP9JSContextjPN2JS5ValueE, 0, __ZL8obj_sealP9JSContextjPN2JS5ValueE, 0, __ZL12obj_isSealedP9JSContextjPN2JS5ValueE, 0, __ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL18with_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL18with_SetAttributesP9JSContextP8JSObjectiPj, 0, __ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZL11with_TypeOfP9JSContextP8JSObject, 0, __ZL15with_ThisObjectP9JSContextP8JSObject, 0, __ZL16js_InitNullClassP9JSContextP8JSObject, 0, __ZL13json_toSourceP9JSContextjPN2JS5ValueE, 0, __Z13js_json_parseP9JSContextjPN2JS5ValueE, 0, __Z17js_json_stringifyP9JSContextjPN2JS5ValueE, 0, __ZL8pm_startP9JSContextjPN2JS5ValueE, 0, __ZL7pm_stopP9JSContextjPN2JS5ValueE, 0, __ZL8pm_resetP9JSContextjPN2JS5ValueE, 0, __ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE, 0, __ZL11pm_finalizeP9JSContextP8JSObject, 0, __ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js14JSProxyHandlerD2Ev, 0, __ZN2js14JSProxyHandlerD0Ev, 0, __ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb, 0, __ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE, 0, __ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE, 0, __ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_, 0, __ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject, 0, __ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject, 0, __ZN2js14JSProxyHandler13isOuterWindowEv, 0, __ZN22JSScriptedProxyHandlerD0Ev, 0, __ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL14proxy_FinalizeP9JSContextP8JSObject, 0, __ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL17proxy_TraceObjectP8JSTracerP8JSObject, 0, __ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj, 0, __ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj, 0, __ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL12proxy_TypeOfP9JSContextP8JSObject, 0, __ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL17proxy_innerObjectP9JSContextP8JSObject, 0, __ZL10proxy_CallP9JSContextjPN2JS5ValueE, 0, __ZL15proxy_ConstructP9JSContextjPN2JS5ValueE, 0, __ZL19proxy_TraceFunctionP8JSTracerP8JSObject, 0, __ZL12proxy_createP9JSContextjPN2JS5ValueE, 0, __ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE, 0, __ZL13callable_CallP9JSContextjPN2JS5ValueE, 0, __Z18callable_ConstructP9JSContextjPN2JS5ValueE, 0, __ZL13reflect_parseP9JSContextjPN2JS5ValueE, 0, __ZL13resc_finalizeP9JSContextP8JSObject, 0, __ZL10resc_traceP8JSTracerP8JSObject, 0, __ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE, 0, __ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL15regexp_finalizeP9JSContextP8JSObject, 0, __Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject, 0, __ZL15regexp_toStringP9JSContextjPN2JS5ValueE, 0, __ZL14regexp_compileP9JSContextjPN2JS5ValueE, 0, __Z14js_regexp_execP9JSContextjPN2JS5ValueE, 0, __Z14js_regexp_testP9JSContextjPN2JS5ValueE, 0, __ZL12script_traceP8JSTracerP8JSObject, 0, __ZL10str_escapeP9JSContextjPN2JS5ValueE, 0, __ZL12str_unescapeP9JSContextjPN2JS5ValueE, 0, __ZL10str_unevalP9JSContextjPN2JS5ValueE, 0, __ZL13str_decodeURIP9JSContextjPN2JS5ValueE, 0, __ZL13str_encodeURIP9JSContextjPN2JS5ValueE, 0, __ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE, 0, __ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE, 0, __ZL13str_enumerateP9JSContextP8JSObject, 0, __ZL11str_resolveP9JSContextP8JSObjectijPS2_, 0, __ZL9str_quoteP9JSContextjPN2JS5ValueE, 0, __ZL12str_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL13str_substringP9JSContextjPN2JS5ValueE, 0, __ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE, 0, __ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE, 0, __Z13js_str_charAtP9JSContextjPN2JS5ValueE, 0, __Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE, 0, __ZL11str_indexOfP9JSContextjPN2JS5ValueE, 0, __ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE, 0, __ZL8str_trimP9JSContextjPN2JS5ValueE, 0, __ZL12str_trimLeftP9JSContextjPN2JS5ValueE, 0, __ZL13str_trimRightP9JSContextjPN2JS5ValueE, 0, __ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE, 0, __ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE, 0, __ZL17str_localeCompareP9JSContextjPN2JS5ValueE, 0, __ZL9str_matchP9JSContextjPN2JS5ValueE, 0, __ZL10str_searchP9JSContextjPN2JS5ValueE, 0, __ZL9str_splitP9JSContextjPN2JS5ValueE, 0, __ZL10str_substrP9JSContextjPN2JS5ValueE, 0, __ZL10str_concatP9JSContextjPN2JS5ValueE, 0, __ZL9str_sliceP9JSContextjPN2JS5ValueE, 0, __ZL8str_boldP9JSContextjPN2JS5ValueE, 0, __ZL11str_italicsP9JSContextjPN2JS5ValueE, 0, __ZL9str_fixedP9JSContextjPN2JS5ValueE, 0, __ZL12str_fontsizeP9JSContextjPN2JS5ValueE, 0, __ZL13str_fontcolorP9JSContextjPN2JS5ValueE, 0, __ZL8str_linkP9JSContextjPN2JS5ValueE, 0, __ZL10str_anchorP9JSContextjPN2JS5ValueE, 0, __ZL10str_strikeP9JSContextjPN2JS5ValueE, 0, __ZL9str_smallP9JSContextjPN2JS5ValueE, 0, __ZL7str_bigP9JSContextjPN2JS5ValueE, 0, __ZL9str_blinkP9JSContextjPN2JS5ValueE, 0, __ZL7str_supP9JSContextjPN2JS5ValueE, 0, __ZL7str_subP9JSContextjPN2JS5ValueE, 0, __ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE, 0, _JS_FinalizeStub, 0, __ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject, 0, __ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty, 0, __ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej, 0, __ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE, 0, __ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE, 0, __ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi, 0, __ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject, 0, __ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject, 0, __ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty, 0, __ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty, 0, __ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty, 0, __ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj, 0, __ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj, 0, __ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj, 0, __ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej, 0, __ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej, 0, __ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject, 0, __ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject, 0, __ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE, 0, __ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject, 0, __ZL16WeakMap_finalizeP9JSContextP8JSObject, 0, __ZL12WeakMap_markP8JSTracerP8JSObject, 0, __ZL11WeakMap_hasP9JSContextjPN2JS5ValueE, 0, __ZL11WeakMap_getP9JSContextjPN2JS5ValueE, 0, __ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE, 0, __ZL11WeakMap_setP9JSContextjPN2JS5ValueE, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer, 0, __ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer, 0, __ZN9JSWrapperD2Ev, 0, __ZN9JSWrapperD0Ev, 0, __ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE, 0, __ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_, 0, __ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN9JSWrapper6typeOfEP9JSContextP8JSObject, 0, __ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject, 0, __ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN9JSWrapper5traceEP8JSTracerP8JSObject, 0, __ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb, 0, __ZN9JSWrapper5leaveEP9JSContextP8JSObject, 0, __ZN25JSCrossCompartmentWrapperD0Ev, 0, __ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor, 0, __ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb, 0, __ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE, 0, __ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_, 0, __ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb, 0, __ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject, 0, __ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj, 0, __ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject, 0, __ZL9mem_get32P10JSXDRStatePj, 0, __ZL9mem_set32P10JSXDRStatePj, 0, __ZL12mem_getbytesP10JSXDRStatePcj, 0, __ZL12mem_setbytesP10JSXDRStatePcj, 0, __ZL7mem_rawP10JSXDRStatej, 0, __ZL8mem_seekP10JSXDRStatei11JSXDRWhence, 0, __ZL8mem_tellP10JSXDRState, 0, __ZL12mem_finalizeP10JSXDRState, 0, __ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL18namespace_toStringP9JSContextjPN2JS5ValueE, 0, __ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL14qname_toStringP9JSContextjPN2JS5ValueE, 0, __Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE, 0, __ZL12xml_finalizeP9JSContextP8JSObject, 0, __ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi, 0, __ZL9xml_traceP8JSTracerP8JSObject, 0, __ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty, 0, __ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty, 0, __ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty, 0, __ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej, 0, __ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej, 0, __ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE, 0, __ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE, 0, __ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE, 0, __ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE, 0, __ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL17xml_getAttributesP9JSContextP8JSObjectiPj, 0, __ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL17xml_setAttributesP9JSContextP8JSObjectiPj, 0, __ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj, 0, __ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj, 0, __ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi, 0, __ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi, 0, __ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi, 0, __ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi, 0, __ZL10xml_typeOfP9JSContextP8JSObject, 0, __ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE, 0, __ZL9xml_clearP9JSContextP8JSObject, 0, __ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL15xml_appendChildP9JSContextjPN2JS5ValueE, 0, __ZL13xml_attributeP9JSContextjPN2JS5ValueE, 0, __ZL14xml_attributesP9JSContextjPN2JS5ValueE, 0, __ZL9xml_childP9JSContextjPN2JS5ValueE, 0, __ZL14xml_childIndexP9JSContextjPN2JS5ValueE, 0, __ZL12xml_childrenP9JSContextjPN2JS5ValueE, 0, __ZL12xml_commentsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_containsP9JSContextjPN2JS5ValueE, 0, __ZL8xml_copyP9JSContextjPN2JS5ValueE, 0, __ZL15xml_descendantsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_elementsP9JSContextjPN2JS5ValueE, 0, __ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE, 0, __ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE, 0, __ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE, 0, __ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE, 0, __ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE, 0, __ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE, 0, __ZL10xml_lengthP9JSContextjPN2JS5ValueE, 0, __ZL13xml_localNameP9JSContextjPN2JS5ValueE, 0, __ZL8xml_nameP9JSContextjPN2JS5ValueE, 0, __ZL13xml_namespaceP9JSContextjPN2JS5ValueE, 0, __ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE, 0, __ZL12xml_nodeKindP9JSContextjPN2JS5ValueE, 0, __ZL13xml_normalizeP9JSContextjPN2JS5ValueE, 0, __ZL10xml_parentP9JSContextjPN2JS5ValueE, 0, __ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE, 0, __ZL16xml_prependChildP9JSContextjPN2JS5ValueE, 0, __ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE, 0, __ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL11xml_replaceP9JSContextjPN2JS5ValueE, 0, __ZL15xml_setChildrenP9JSContextjPN2JS5ValueE, 0, __ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE, 0, __ZL11xml_setNameP9JSContextjPN2JS5ValueE, 0, __ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE, 0, __ZL8xml_textP9JSContextjPN2JS5ValueE, 0, __ZL12xml_toSourceP9JSContextjPN2JS5ValueE, 0, __ZL12xml_toStringP9JSContextjPN2JS5ValueE, 0, __ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE, 0, __ZL11xml_valueOfP9JSContextjPN2JS5ValueE, 0, __ZL12xml_settingsP9JSContextjPN2JS5ValueE, 0, __ZL15xml_setSettingsP9JSContextjPN2JS5ValueE, 0, __ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE, 0, __ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL18xmlfilter_finalizeP9JSContextP8JSObject, 0, __ZL15xmlfilter_traceP8JSTracerP8JSObject, 0, __ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE, 0, __ZNSt9bad_allocD0Ev, 0, __ZNKSt9bad_alloc4whatEv, 0, __ZNSt20bad_array_new_lengthD0Ev, 0, __ZNKSt20bad_array_new_length4whatEv, 0, __ZN2js14BreakpointSiteC2EP8JSScriptPh, 0, __ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject, 0, __ZN2js8DebuggerC2EP9JSContextP8JSObject, 0, __ZN2js8DebuggerD2Ev, 0, __ZN2js10StackSpaceC2Ev, 0, __ZN2js10StackSpaceD2Ev, 0, __ZN2js12ContextStackC2EP9JSContext, 0, __ZN2js12ContextStackD2Ev, 0, __ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE, 0, __ZN2js13AllFramesIterC2ERNS_10StackSpaceE, 0, __ZN9JSRuntimeC2Ev, 0, __ZN9JSRuntimeD2Ev, 0, __ZN2js7SCInputC2EP9JSContextPKyj, 0, __ZN2js8SCOutputC2EP9JSContext, 0, __ZN2js10ThreadDataC2Ev, 0, __ZN2js10ThreadDataD2Ev, 0, __ZN9JSContextC2EP9JSRuntime, 0, __ZN9JSContextD2Ev, 0, __ZN13JSCompartmentC2EP9JSRuntime, 0, __ZN13JSCompartmentD2Ev, 0, __ZN2js5crash5StackC2Ey, 0, __ZN2js5crash4RingC2Ey, 0, __ZN15JSCodeGeneratorC2EPN2js6ParserEj, 0, __ZN15JSCodeGeneratorD2Ev, 0, __ZN2JS23AutoPreserveCompartmentC2EP9JSContext, 0, __ZN2JS23AutoPreserveCompartmentD2Ev, 0, __ZN2JS21AutoSwitchCompartmentC2EP9JSContextP13JSCompartment, 0, __ZN2JS21AutoSwitchCompartmentC2EP9JSContextP8JSObject, 0, __ZN2JS21AutoSwitchCompartmentD2Ev, 0, __ZN2js8GCMarkerC2EP9JSContext, 0, __ZN2js8GCMarkerD2Ev, 0, __ZN13AutoGCSessionC2EP9JSContext, 0, __ZN13AutoGCSessionD2Ev, 0, __ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment, 0, __ZN2js5types17TypeScriptNestingD2Ev, 0, __ZN2js5types15TypeCompartmentD2Ev, 0, __ZN2js9MathCacheC2Ev, 0, __ZN2js12ToCStringBufC2Ev, 0, __ZN2js12ToCStringBufD2Ev, 0, __ZN2js8PropDescC2Ev, 0, __ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb, 0, __ZN2js6ParserD2Ev, 0, __ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE, 0, __ZN22JSScriptedProxyHandlerC2Ev, 0, __ZN2js11TokenStreamC2EP9JSContext, 0, __ZN2js11TokenStreamD2Ev, 0, __ZN2js11ArrayBufferD2Ev, 0, __ZN9JSWrapperC2Ej, 0, __ZN2js10ForceFrameC2EP9JSContextP8JSObject, 0, __ZN2js10ForceFrameD2Ev, 0, __ZN2js15AutoCompartmentC2EP9JSContextP8JSObject, 0, __ZN2js15AutoCompartmentD2Ev, 0, __ZN2js11ErrorCopierD2Ev, 0, __ZN25JSCrossCompartmentWrapperC2Ej, 0, __ZN2js14XDRScriptStateC2EP10JSXDRState, 0, __ZN2js14XDRScriptStateD2Ev, 0, __ZN2JS15PerfMeasurementC2ENS0_9EventMaskE, 0, __ZN2JS15PerfMeasurementD2Ev, 0, __ZNSt9bad_allocC2Ev, 0, __ZNSt20bad_array_new_lengthC2Ev, 0 ];

Module["FUNCTION_TABLE"] = FUNCTION_TABLE;

function run(args) {
  args = args || Module["arguments"];
  if (Module["setStatus"]) {
    Module["setStatus"]("");
  }
  if (Module["preRun"]) {
    Module["preRun"]();
  }
  var ret = null;
  if (Module["_main"]) {
    preMain();
    ret = Module.callMain(args);
    if (!Module["noExitRuntime"]) {
      exitRuntime();
    }
  }
  if (Module["postRun"]) {
    Module["postRun"]();
  }
  return ret;
}

Module["run"] = run;

initRuntime();

if (Module["noInitialRun"]) {
  addRunDependency();
}

if (runDependencies == 0) {
  var ret = run();
}
// EMSCRIPTEN_GENERATED_FUNCTIONS: ["__ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE","__ZN2js14BreakpointSite9recompileEP9JSContextb","__ZNK8JSObject10fixedSlotsEv","__ZN8JSObject6asCallEv","__ZNK2js8Bindings16countArgsAndVarsEv","__ZN2js2gcL15GetGCObjectKindEjb","__ZN9JSContext20typeInferenceEnabledEv","__ZN8JSObject10makeVarObjEv","_BUILD_JSVAL","_OBJECT_TO_JSVAL_IMPL","__ZNK2js8Bindings9lastShapeEv","__ZNK2js8Bindings17extensibleParentsEv","__ZN8JSObject11setOwnShapeEj","__ZN8JSObject7setTypeEPN2js5types10TypeObjectE","__ZN8JSObject11setDelegateEv","_MAGIC_TO_JSVAL_IMPL","__ZN2js2gc5Arena9thingSizeENS0_9AllocKindE","__ZN8JSObject9earlyInitEj","__ZN2js2gc8FreeSpan8allocateEj","__ZN2js14BreakpointSite3incEP9JSContext","__ZN2js14BreakpointSite3decEP9JSContext","__ZN2js14BreakpointSite7setTrapEP9JSContextPF12JSTrapStatusS2_P8JSScriptPhPN2JS5ValueES8_ERKS8_","__ZN2js10Breakpoint13fromSiteLinksEP10JSCListStr","__ZN2js10BreakpointC2EPNS_8DebuggerEPNS_14BreakpointSiteEP8JSObject","__ZN2js10Breakpoint17fromDebuggerLinksEP10JSCListStr","__ZN2js10CallObject6createEP9JSContextP8JSScriptR8JSObjectPS5_","__Z14js_NewGCObjectP9JSContextN2js2gc9AllocKindE","__ZN8JSObject8initCallEP9JSContextRKN2js8BindingsEPS_","__ZN2js10CallObject9setCalleeEP8JSObject","__ZN8JSObject12setFixedSlotEjRKN2JS5ValueE","__ZN2JSL17ObjectOrNullValueEP8JSObject","__ZN2JS5Value15setObjectOrNullEP8JSObject","__ZN2JS5Value9setObjectER8JSObject","__ZN2JS5Value7setNullEv","__ZN8JSObject4initEP9JSContextPN2js5ClassEPNS2_5types10TypeObjectEPS_Pvb","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb","__ZN8JSObject9setParentEPS_","__ZN8JSObject19setDelegateNullSafeEPS_","__ZN2JS5Value8setMagicE10JSWhyMagic","__ZN2JS5Value12setUndefinedEv","__Z10NewGCThingI8JSObjectEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js2gc10ArenaLists20allocateFromFreeListENS0_9AllocKindEj","__Z20ReportMoreArgsNeededP9JSContextPKcj","__Z20ReportObjectRequiredP9JSContext","__ZN2js14BreakpointSiteC2EP8JSScriptPh","__ZN2JSL14UndefinedValueEv","__ZN2js14BreakpointSite9clearTrapEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumEPPF12JSTrapStatusS2_P8JSScriptS6_PN2JS5ValueESM_ESN_","__ZN2js14BreakpointSite14destroyIfEmptyEP9JSRuntimePNS_6detail9HashTableINS_12HashMapEntryIPhPS0_EENS_7HashMapIS6_S7_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESC_E4EnumE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4Enum11removeFrontEv","__ZNK2js2gc4Cell11compartmentEv","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeERKS1_","__ZN9JSRuntime7delete_IN2js14BreakpointSiteEEEvPT_","__ZNK2js14BreakpointSite15firstBreakpointEv","__ZN2js14BreakpointSite13hasBreakpointEPNS_10BreakpointE","__ZN2js10Breakpoint10nextInSiteEv","__ZN2js10Breakpoint7destroyEP9JSContextPNS_6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS6_S8_NS_13DefaultHasherIS6_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESD_E4EnumE","__ZN9JSRuntime7delete_IN2js10BreakpointEEEvPT_","__ZN2js10Breakpoint14nextInDebuggerEv","__ZN2js8DebuggerC2EP9JSContextP8JSObject","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_","__ZN2js18RuntimeAllocPolicyC1EP9JSContext","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC1EP9JSContext","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC1ES7_","__ZN2js10AutoLockGCC1EP9JSRuntime","__ZN2js8DebuggerD2Ev","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED1Ev","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js8Debugger4initEP9JSContext","__ZN8JSObject10setPrivateEPv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js14BreakpointSite15getScriptObjectEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5beginEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js8Debugger10toJSObjectEv","__ZNK2js10StackFrame13isScriptFrameEv","__ZNK2js10StackFrame11isEvalFrameEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK8JSObject8getClassEv","__ZNK8JSObject10getPrivateEv","__ZN9JSContext18isExceptionPendingEv","__ZN9JSContext19getPendingExceptionEv","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN2js8Debugger17fromChildJSObjectEP8JSObject","__ZNK8JSObject15getReservedSlotEj","__ZNK2JS5Value8toObjectEv","__ZN2js8Debugger12fromJSObjectEP8JSObject","__ZN2js8Debugger14getScriptFrameEP9JSContextPNS_10StackFrameEPN2JS5ValueE","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN8JSObject24ensureClassReservedSlotsEP9JSContext","__ZN8JSObject15setReservedSlotEjRKN2JS5ValueE","__ZN2JSL11ObjectValueER8JSObject","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZNK2js8Debugger7getHookENS0_4HookE","__ZNK2JS5Value11isUndefinedEv","__ZNK2js8Debugger15hasAnyLiveHooksEP9JSContext","__ZNK2js8Debugger15firstBreakpointEv","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js8Debugger20slowPathOnEnterFrameEP9JSContext","__ZN2js15AutoValueVectorC1EP9JSContext","__ZNK9JSContext2fpEv","__ZNK2js10StackFrame10scopeChainEv","__ZNK2js8Debugger18observesEnterFrameEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE6appendERKS2_","__ZN2js16AutoVectorRooterIN2JS5ValueEE5beginEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE3endEv","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3hasERKS2_","__ZN2js8Debugger14fireEnterFrameEP9JSContext","__ZN2js15AutoValueVectorD1Ev","__ZN2js8Debugger20slowPathOnLeaveFrameEP9JSContext","__ZNK2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZNK2js10StackFrame6scriptEv","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2js8Debugger17wrapDebuggeeValueEP9JSContextPN2JS5ValueE","__ZNK2JS5Value8isObjectEv","__ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_SG_","__ZN2js8Debugger19unwrapDebuggeeValueEP9JSContextPN2JS5ValueE","__ZNK2JS5Value14toObjectOrNullEv","__ZNK2JS5Value6isNullEv","__ZN2js8Debugger23handleUncaughtExceptionERNS_15AutoCompartmentEPN2JS5ValueEb","__ZN9JSContext21clearPendingExceptionEv","__ZNK8JSObject8isObjectEv","__ZNK8JSObject12lastPropertyEv","__ZNK2js5Shape8previousEv","__ZNK2js5Shape16isDataDescriptorEv","__ZN9JSContext19setPendingExceptionEN2JS5ValueE","__ZN13JSCompartment12getDebuggeesEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE3endEv","__ZN2js8Debugger20parseResumptionValueERNS_15AutoCompartmentEbRKN2JS5ValueEPS4_b","__ZN2js8Debugger18newCompletionValueERNS_15AutoCompartmentEbN2JS5ValueEPS4_","__ZL12ATOM_TO_JSIDP6JSAtom","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE","__Z19CallMethodIfPresentP9JSContextP8JSObjectPKciPN2JS5ValueES7_","__ZL13js_IsCallableRKN2JS5ValueE","__ZN2js8Debugger21fireDebuggerStatementEP9JSContextPN2JS5ValueE","__ZN2js8Debugger19fireExceptionUnwindEP9JSContextPN2JS5ValueE","__ZN2js8Debugger13fireNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__ZN2js8Debugger14wrapHeldScriptEP9JSContextP8JSScriptP8JSObject","__ZN2js8Debugger17wrapNonHeldScriptEP9JSContextP8JSScript","__ZN2js8Debugger12dispatchHookEP9JSContextPN2JS5ValueENS0_4HookE","__ZN2js8Debugger19slowPathOnNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__ZL22AddNewScriptRecipientsPN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEEPNS_15AutoValueVectorE","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3allEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__ZN2js8Debugger6onTrapEP9JSContextPN2JS5ValueE","__ZNK9JSContext4regsEv","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js15TempAllocPolicyC1EP9JSContext","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2js8Debugger9fromLinksEP10JSCListStr","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5beginEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE3endEv","__ZNK2js10Breakpoint10getHandlerEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5emptyEv","__ZNK2js12CallReceiver5thisvEv","__ZNK2js12CallReceiver4rvalEv","__ZN2JS5Value8setInt32Ei","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js8Debugger12onSingleStepEP9JSContextPN2JS5ValueE","__ZN2js16AutoObjectVectorC1EP9JSContext","__ZN2js16AutoVectorRooterIP8JSObjectE6appendERKS2_","__ZN2js16AutoVectorRooterIP8JSObjectE5beginEv","__ZN2js16AutoVectorRooterIP8JSObjectE3endEv","__ZN2js16AutoObjectVectorD1Ev","__ZN2js8Debugger21markKeysInCompartmentEP8JSTracerRKNS_7WeakMapIP8JSObjectS5_NS_13DefaultHasherIS5_EENS_17DefaultMarkPolicyIS5_S5_EEEE","__ZNK2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js8Debugger43markCrossCompartmentDebuggerObjectReferentsEP8JSTracer","__ZN2js8Debugger18markAllIterativelyEPNS_8GCMarkerE","__ZN2js8Debugger11traceObjectEP8JSTracerP8JSObject","__ZN2js8Debugger5traceEP8JSTracer","__ZN2js11WeakMapBase5traceEP8JSTracer","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js8Debugger8sweepAllEP9JSContext","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_","__ZN2js8Debugger20removeDebuggeeGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumESG_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev","__ZN2js8Debugger28detachAllDebuggersFromGlobalEP9JSContextPNS_12GlobalObjectEPNS_6detail9HashTableIKS4_NS_7HashSetIS4_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE6SetOpsESB_E4EnumE","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE4backEv","__ZN2js8Debugger8finalizeEP9JSContextP8JSObject","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5emptyEv","__ZN9JSContext7delete_IN2js8DebuggerEEEvPT_","__ZN2js8Debugger13fromThisValueEP9JSContextRKNS_8CallArgsEPKc","__ZN2js8Debugger10getEnabledEP9JSContextjPN2JS5ValueE","__ZN2js14CallArgsFromVpEjPN2JS5ValueE","__ZN2JS5Value10setBooleanEb","__ZNK2js8CallArgsixEj","__ZN8JSObject20setDenseArrayElementEjRKN2JS5ValueE","__ZNK2js12ContextStack5spaceEv","__ZNK2js13AllFramesIter4doneEv","__ZNK2js13AllFramesIter2fpEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE3endEv","__ZNK13JSCompartment9debugModeEv","__ZN2js8Debugger10setEnabledEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger11getHookImplEP9JSContextjPN2JS5ValueENS0_4HookE","__ZN2js8Debugger11setHookImplEP9JSContextjPN2JS5ValueENS0_4HookE","__ZN8JSObject10isCallableEv","__ZN2js8Debugger22getOnDebuggerStatementEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger22setOnDebuggerStatementEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger20getOnExceptionUnwindEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger20setOnExceptionUnwindEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger14getOnNewScriptEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger14setOnNewScriptEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger15getOnEnterFrameEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger15setOnEnterFrameEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger24getUncaughtExceptionHookEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger24setUncaughtExceptionHookEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger22unwrapDebuggeeArgumentEP9JSContextRKN2JS5ValueE","__ZNK8JSObject15getProxyPrivateEv","__ZN2js8Debugger11addDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger17addDebuggeeGlobalEP9JSContextPNS_12GlobalObjectE","__ZN2js8Debugger14removeDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger11hasDebuggeeEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger12getDebuggeesEP9JSContextjPN2JS5ValueE","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE5countEv","__ZN8JSObject33ensureDenseArrayInitializedLengthEP9JSContextjj","__ZN2js8Debugger14getNewestFrameEP9JSContextjPN2JS5ValueE","__ZNK2js8Debugger13observesFrameEPNS_10StackFrameE","__ZN2js8Debugger19clearAllBreakpointsEP9JSContextjPN2JS5ValueE","__ZN2js8Debugger9constructEP9JSContextjPN2JS5ValueE","__ZNK2js12CallReceiver6calleeEv","__ZN8JSObject11getPropertyEP9JSContextPN2js12PropertyNameEPN2JS5ValueE","__ZN9JSContext4new_IN2js8DebuggerEPS_P8JSObjectEEPT_T0_T1_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEixEj","__ZN2jsL4FindINS_6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEEEEPNT_11ElementTypeERS6_RKS7_","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6lengthEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE7popBackEv","__ZNK10JSFunction6scriptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1ISC_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE5eraseEPS2_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv","__ZL20DebuggerScript_traceP8JSTracerP8JSObject","__ZN2js8Debugger17newDebuggerScriptEP9JSContextP8JSScriptP8JSObject","__ZN2JSL12PrivateValueEPv","__ZN2js8Debugger18wrapFunctionScriptEP9JSContextP10JSFunction","__ZN2js8Debugger15wrapJSAPIScriptEP9JSContextP8JSObject","__ZNK8JSObject9getScriptEv","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js8Debugger23slowPathOnDestroyScriptEP8JSScript","__ZN2js8Debugger20destroyNonHeldScriptEP8JSScript","__ZNK2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZL19ClearScriptReferentP8JSObject","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZL21DebuggerScript_getUrlP9JSContextjPN2JS5ValueE","__ZL27DebuggerScript_getStartLineP9JSContextjPN2JS5ValueE","__ZL27DebuggerScript_getLineCountP9JSContextjPN2JS5ValueE","__ZL22DebuggerScript_getLiveP9JSContextjPN2JS5ValueE","__ZL30DebuggerScript_getChildScriptsP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_getAllOffsetsP9JSContextjPN2JS5ValueE","__ZL29DebuggerScript_getLineOffsetsP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_getOffsetLineP9JSContextjPN2JS5ValueE","__ZL28DebuggerScript_setBreakpointP9JSContextjPN2JS5ValueE","__ZL29DebuggerScript_getBreakpointsP9JSContextjPN2JS5ValueE","__ZL30DebuggerScript_clearBreakpointP9JSContextjPN2JS5ValueE","__ZL34DebuggerScript_clearAllBreakpointsP9JSContextjPN2JS5ValueE","__ZN2js15EvaluateInScopeEP9JSContextP8JSObjectPNS_10StackFrameEPKtjPKcjPN2JS5ValueE","__ZN2js11ComputeThisEP9JSContextPNS_10StackFrameE","__ZN8JSObject10principalsEP9JSContext","__ZNK9JSContext11findVersionEv","__ZNK2js10StackFrame9thisValueEv","__ZL26DebuggerFrame_getArgumentsP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getCalleeP9JSContextjPN2JS5ValueE","__ZL29DebuggerFrame_getConstructingP9JSContextjPN2JS5ValueE","__ZL26DebuggerFrame_getGeneratorP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getLiveP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getOffsetP9JSContextjPN2JS5ValueE","__ZL22DebuggerFrame_getOlderP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getScriptP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getThisP9JSContextjPN2JS5ValueE","__ZL21DebuggerFrame_getTypeP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_getOnStepP9JSContextjPN2JS5ValueE","__ZL23DebuggerFrame_setOnStepP9JSContextjPN2JS5ValueE","__ZL18DebuggerFrame_evalP9JSContextjPN2JS5ValueE","__ZL30DebuggerFrame_evalWithBindingsP9JSContextjPN2JS5ValueE","__ZL20DebuggerObject_traceP8JSTracerP8JSObject","__ZL23DebuggerObject_getProtoP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_getClassP9JSContextjPN2JS5ValueE","__ZL26DebuggerObject_getCallableP9JSContextjPN2JS5ValueE","__ZL22DebuggerObject_getNameP9JSContextjPN2JS5ValueE","__ZL32DebuggerObject_getParameterNamesP9JSContextjPN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEptEv","__ZNK2js7MoveRefIP8JSScriptEcvRS2_Ev","__ZL24DebuggerObject_getScriptP9JSContextjPN2JS5ValueE","__ZL39DebuggerObject_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE","__ZL34DebuggerObject_getOwnPropertyNamesP9JSContextjPN2JS5ValueE","__ZL29DebuggerObject_definePropertyP9JSContextjPN2JS5ValueE","__ZL31DebuggerObject_definePropertiesP9JSContextjPN2JS5ValueE","__ZL29DebuggerObject_deletePropertyP9JSContextjPN2JS5ValueE","__ZL19DebuggerObject_sealP9JSContextjPN2JS5ValueE","__ZL21DebuggerObject_freezeP9JSContextjPN2JS5ValueE","__ZL32DebuggerObject_preventExtensionsP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_isSealedP9JSContextjPN2JS5ValueE","__ZL23DebuggerObject_isFrozenP9JSContextjPN2JS5ValueE","__ZL27DebuggerObject_isExtensibleP9JSContextjPN2JS5ValueE","__ZL20DebuggerObject_applyP9JSContextjPN2JS5ValueE","__ZL19DebuggerObject_callP9JSContextjPN2JS5ValueE","_JS_DefineDebuggerObject","__ZL23DebuggerFrame_constructP9JSContextjPN2JS5ValueE","__ZL24DebuggerScript_constructP9JSContextjPN2JS5ValueE","__ZL24DebuggerObject_constructP9JSContextjPN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js18RuntimeAllocPolicy5free_EPv","__ZN9JSRuntime5free_EPv","__ZN2js10Foreground5free_EPv","_js_free","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEEEC1ERS9_","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSScriptP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1ERS6_","__ZN2js4MoveIP8JSScriptEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10isLiveHashEj","__ZN2js13PointerHasherIP8JSScriptLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP8JSScriptLj2EE4hashERKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10isLiveHashEj","__ZNK2js7MoveRefIP8JSObjectEcvRS2_Ev","__ZN2js7MoveRefIP8JSObjectEC2ERS2_","__ZN2js7MoveRefIP8JSScriptEC2ERS2_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEv","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12hasCollisionEv","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEaSERKS5_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE12setCollisionEj","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC2ERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setLiveEj","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setFreeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12hasCollisionEv","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSERKS5_","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEptEv","__ZNK2js7MoveRefIPNS_10StackFrameEEcvRS2_Ev","__ZN2js7MoveRefIPNS_10StackFrameEEC2ERS2_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js7MoveRefIP8JSObjectEC1ERS2_","__ZN2js7MoveRefIP8JSScriptEC1ERS2_","__ZN2js18RuntimeAllocPolicy7malloc_Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEEC2Ev","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1Ev","__ZN9JSRuntime7malloc_EjP9JSContext","__ZN9JSRuntime19updateMallocCounterEj","_js_malloc","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSScriptP8JSObjectEEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13relookupOrAddERNSE_6AddPtrERKS4_RKS7_","__ZN2js12HashMapEntryIP8JSScriptP8JSObjectEC1ERKS2_RKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrERKS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setFreeEv","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEEEC1ERS9_","__ZN2js12HashMapEntryIPNS_10StackFrameEP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1ERS6_","__ZN2js4MoveIPNS_10StackFrameEEENS_7MoveRefIT_EERKS4_","__ZN2js7MoveRefIPNS_10StackFrameEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2ISC_EERT_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10isLiveHashEj","__ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIPNS_12GlobalObjectELj2EE4hashERKS2_","__ZNK7mozilla14AlignedStorageILj1EE4addrEv","__ZN7mozilla14AlignedStorageILj1EE4addrEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEptEv","__ZNK2js7MoveRefIPNS_12GlobalObjectEEcvRS2_Ev","__ZN2js7MoveRefIPNS_12GlobalObjectEEC2ERS2_","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isFreeEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC2Ev","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrdeEv","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9isRemovedEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE7setLiveEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE9matchHashEj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEE12setCollisionEj","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2jsL4FindIP13JSCompartmentEEPT_S4_S4_RKS3_","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryIKPNS_12GlobalObjectEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js17SystemAllocPolicy5free_EPv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_12GlobalObjectEEEEC1ERS6_","__ZN2js4MoveIPNS_12GlobalObjectEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_12GlobalObjectEEC1ERS2_","__ZN2js17SystemAllocPolicy7malloc_Ej","__ZN2js6detail14HashTableEntryIKPNS_12GlobalObjectEEC1Ev","__ZNK2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js17SystemAllocPolicy8realloc_EPvjj","_js_realloc","__ZN2js11RoundUpPow2Ej","__ZN2js10VectorImplIPNS_8DebuggerELj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js15TempAllocPolicy8realloc_EPvjj","__ZN2js15TempAllocPolicy7malloc_Ej","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEED2Ev","__ZN2js15TempAllocPolicy5free_EPv","__ZN2js6VectorIP13JSCompartmentLj0ENS_15TempAllocPolicyEEC2ES3_","__ZN9JSContext7malloc_Ej","__ZN9JSContext5free_EPv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZNK7mozilla14AlignedStorageILj32EE4addrEv","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE5beginEv","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js12HashMapEntryIP8JSObjectS2_EC2ERKS2_S5_","__ZN2js12HashMapEntryIP8JSObjectS2_EaSERKS3_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj8ES3_EEj","__ZN2js10VectorImplIP8JSObjectLj8ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIPNS_10BreakpointELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIPNS_10BreakpointELj0ENS_15TempAllocPolicyEEC2ES3_","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS4_EESF_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS4_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS5_","__ZN2js12HashMapEntryIP8JSObjectS2_EC1ERKS2_S5_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS5_EEEEEC1ERS7_","__ZN2js12HashMapEntryIP8JSObjectS2_EaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectS3_EEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC1ERS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js13PointerHasherIP8JSObjectLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP8JSObjectLj2EE4hashERKS2_","__ZN2js13PointerHasherIPNS_10StackFrameELj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIPNS_10StackFrameELj2EE4hashERKS2_","__ZNK7mozilla14AlignedStorageILj64EE4addrEv","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectS3_EEEptEv","__ZN2js12HashMapEntryIP8JSObjectS2_EC2Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE12setCollisionEj","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefIN2JS5ValueEEcvRS2_Ev","__ZN2js7MoveRefIN2JS5ValueEEC2ERS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEEE7setLiveEj","__ZN2js2gcL15GetGCObjectKindEjb1","__ZNK8JSObject9getParentEv","__ZNK2js5Class8isNativeEv","__ZN8JSObject6setMapEPN2js5ShapeE","__ZNK8JSObject8numSlotsEv","__ZN2js11KidsPointer7setNullEv","__ZN2js4MoveIP8JSObjectEENS_7MoveRefIT_EERKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectS2_EC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj8ES3_EEj","__ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIN2JS5ValueEEC1ERS2_","__ZN2js10VectorImplIN2JS5ValueELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveIN2JS5ValueEEENS_7MoveRefIT_EERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN8JSObject10getNewTypeEP9JSContextP10JSFunctionb","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE","__ZN8JSObject21setSharedNonNativeMapEv","__ZN2js5types10TypeObject20canProvideEmptyShapeEPNS_5ClassE","__ZN2js5types10TypeObject13getEmptyShapeEP9JSContextPNS_5ClassENS_2gc9AllocKindE","__ZN2js10EmptyShape6createEP9JSContextPNS_5ClassE","__ZN2js10EmptyShapeC1EP13JSCompartmentPNS_5ClassE","__ZN2js10EmptyShapeC2EP13JSCompartmentPNS_5ClassE","__ZN2js5ShapeC2EP13JSCompartmentPNS_5ClassE","__ZN9JSContext7calloc_Ej","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10isLiveHashEj","__ZNK2js10EmptyShape8getClassEv","__ZNK8JSObject12isDenseArrayEv","__ZN2js5types10TypeObject17unknownPropertiesEv","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js11WeakMapBaseC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE12hasCollisionEv","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC2EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC2ERS8_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2ERS5_","__ZNK2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEptEv","__ZNK2js7MoveRefIPhEcvRS1_Ev","__ZNK2js7MoveRefIPNS_14BreakpointSiteEEcvRS2_Ev","__ZN2js7MoveRefIPNS_14BreakpointSiteEEC2ERS2_","__ZN2js7MoveRefIPhEC2ERS1_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEv","__ZN9JSRuntime7calloc_EjP9JSContext","_js_calloc","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEEC2EP9JSContext","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES5_","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15nonMarkingTraceEP8JSTracer","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE15markIterativelyEP8JSTracer","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEE5sweepEP8JSTracer","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_EC1EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC1INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9keyMarkedES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectS4_EEE7setFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_E4EnumC2INS_7WeakMapIS4_S4_S8_NS_17DefaultMarkPolicyIS4_S4_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E15markEntryIfLiveES2_S2_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E11valueMarkedES2_","__ZN2js17DefaultMarkPolicyIP8JSObjectS2_E9markEntryES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrcvMSE_FvvEEv","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEEEC1ERS8_","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1ERS5_","__ZN2js4MoveIPhEENS_7MoveRefIT_EERKS3_","__ZN2js4MoveIPNS_14BreakpointSiteEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_14BreakpointSiteEEC1ERS2_","__ZN2js7MoveRefIPhEC1ERS1_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr7nonNullEv","__ZN2js13PointerHasherIPhLj2EE5matchERKS1_S4_","__ZN2js13PointerHasherIPhLj2EE4hashERKS1_","__ZNK2js5Shape8isNativeEv","__ZN7mozilla14AlignedStorageILj32EE4addrEv","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12hasCollisionEv","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEaSERKS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE12setCollisionEj","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S3_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZNK2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5emptyEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js8CallArgs4argvEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK8JSObject12isExtensibleEv","__ZN2js11ErrorCopierC2ERNS_15AutoCompartmentEP8JSObject","__ZN2js12AutoGCRooterD2Ev","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js12AutoGCRooterC2EP9JSContexti","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEEC2Ev","__ZN2js12HashMapEntryIPhPNS_14BreakpointSiteEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj","__ZL11ApplyOrCallP9JSContextjPN2JS5ValueE15ApplyOrCallMode","__ZL24DebuggerObject_checkThisP9JSContextRKN2js8CallArgsEPKc","__ZNK2JS5Value17isNullOrUndefinedEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE6growByEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPN2JS5ValueES2_","__ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZL29DebuggerObject_isSealedHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc","__ZN2js11ErrorCopierC1ERNS_15AutoCompartmentEP8JSObject","__ZN8JSObject8isSealedEP9JSContextPb","__ZN8JSObject8isFrozenEP9JSContextPb","__ZL25DebuggerObject_sealHelperP9JSContextjPN2JS5ValueE12SealHelperOpPKc","__ZN8JSObject4sealEP9JSContext","__ZN8JSObject6freezeEP9JSContext","__ZN2js12AutoIdVectorC1EP9JSContext","__ZN8JSObject17preventExtensionsEP9JSContextPN2js12AutoIdVectorE","__ZN2js12AutoIdVectorD1Ev","__ZN2js12AutoIdVectorD2Ev","__ZN2js16AutoVectorRooterIiED2Ev","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZNK8JSObject6getOpsEv","__ZNK8JSObject8isNativeEv","__ZN8JSObject21extensibleShapeChangeEP9JSContext","__ZN2js12AutoIdVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIiEC2EP9JSContexti","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC1ES1_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEC2ES1_","__ZN8JSObject14deletePropertyEP9JSContextiPN2JS5ValueEi","__ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiNS0_4TypeE","__ZN2js5types4Type13UndefinedTypeEv","__ZN2js5types26MarkTypePropertyConfiguredEP9JSContextP8JSObjecti","__ZN2js5types8Property7keyBitsEi","_JSID_IS_INT","_JSID_IS_STRING","_JSID_TO_FLAT_STRING","__ZN8JSString6asFlatEv","__ZN8JSString11asDependentEv","__ZN8JSString6asRopeEv","__ZNK7mozilla14AlignedStorageILj40EE4addrEv","__ZN7mozilla14AlignedStorageILj40EE4addrEv","__ZNK8JSObject4typeEv","__ZNK8JSObject11hasLazyTypeEv","__ZNK8JSObject16hasSingletonTypeEv","__ZNK2js5types10TypeObject17basePropertyCountEv","__ZN2js5types8Property6getKeyEPS1_","__ZNK14JSLinearString5charsEv","__ZNK8JSString6isFlatEv","__ZNK8JSString11isDependentEv","__ZN2js5types4TypeC2Ej","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE5beginEv","__ZNK8JSObject13isObjectProxyEv","__ZNK8JSObject15isFunctionProxyEv","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE3endEv","__ZNK2js7MoveRefINS_8PropDescEEcvRS1_Ev","__ZN2js7MoveRefINS_8PropDescEEC2ERS1_","__ZN2js5types10MakeTypeIdEP9JSContexti","__ZN2js5types18TrackPropertyTypesEP9JSContextP8JSObjecti","__ZN2js5types10TypeObject16maybeGetPropertyEP9JSContexti","__ZN2js5typesL13HashSetLookupIiNS0_8PropertyES2_EEPT0_PS4_jT_","__ZN2js5typesL15HashSetCapacityEj","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_","__ZN8JSString9getCharsZEP9JSContext","__ZN8JSString10ensureFlatEP9JSContext","__ZN2js5types4TypeC1Ej","__ZN2js8ToObjectEP9JSContextPN2JS5ValueE","__ZN2js23AutoPropDescArrayRooterC1EP9JSContext","__ZNK2js16AutoVectorRooterIiE6lengthEv","__ZL14UnwrapPropDescP9JSContextPN2js8DebuggerEP8JSObjectPNS1_8PropDescE","__ZN2js23AutoPropDescArrayRooterixEj","__ZL17WrapIdAndPropDescP9JSContextP8JSObjectPiPN2js8PropDescE","__ZN2js16AutoVectorRooterIiEixEj","__ZN2js23AutoPropDescArrayRooterD1Ev","__ZN2js23AutoPropDescArrayRooterD2Ev","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj","__ZNK8JSObject7isProxyEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEixEj","__ZL19CheckArgCompartmentP9JSContextP8JSObjectRKN2JS5ValueEPKcS8_","__ZN2js8PropDesc11checkGetterEP9JSContext","__ZN2js8PropDesc11checkSetterEP9JSContext","__ZN2js23AutoPropDescArrayRooterC2EP9JSContext","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC1ES2_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEEC2ES2_","__ZN2js23AutoPropDescArrayRooter6appendEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6appendIS1_EEbT_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj1ES2_EEj","__ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_8PropDescEEC1ERS1_","_JSID_TO_INT","_JSID_TO_STRING","_JSID_TO_OBJECT","_JSVAL_TO_STRING_IMPL","_JSVAL_IS_STRING_IMPL","_INT_TO_JSID","__ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiPN2JS5ValueEE","__ZN2jsL16CastAsPropertyOpEP8JSObject","__ZN2js12CastAsObjectEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject","__ZN8JSString8asLinearEv","_DOUBLE_TO_JSVAL_IMPL","_JSDOUBLE_IS_NEGZERO","_STRING_TO_JSVAL_IMPL","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE8shrinkByEj","__ZNK8JSObject10isFunctionEv","__ZNK10JSFunction4kindEv","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK8JSObject8getProtoEv","__ZNK2js10StackFrame22isNonEvalFunctionFrameEv","__ZNK2js10StackFrame10hasCallObjEv","__ZNK8JSString6lengthEv","__ZN2JS6AnchorIP8JSStringEC2ES2_","__ZNK8JSString8isLinearEv","__ZNK2js10StackFrame13isGlobalFrameEv","__ZNK2js10StackFrame15isFunctionFrameEv","__ZNK2js10StackFrame3funEv","__ZNK2js10StackFrame4prevEv","__ZNK2js10StackFrame12isDummyFrameEv","__ZNK2js10StackFrame16isGeneratorFrameEv","__ZNK2js10StackFrame14isConstructingEv","__ZNK2js10StackFrame10hasArgsObjEv","__ZNK2js10StackFrame7argsObjEv","__ZN2js10VectorImplINS_8PropDescELj1ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveINS_8PropDescEEENS_7MoveRefIT_EERKS3_","__ZN2js16AutoVectorRooterIN2JS5ValueEE6resizeEj","__ZN2JSL10Int32ValueEi","__ZN2js16AutoVectorRooterIN2JS5ValueEEixEj","__ZN2JS5Value9setStringEP8JSString","__ZL12JSID_IS_ATOMi","__ZNK2js16AutoVectorRooterIN2JS5ValueEE6lengthEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEixEj","__ZN2js28AutoPropertyDescriptorRooterC1EP9JSContext","__ZN2JSL17ObjectOrNullValueEP8JSObject5","__ZN2js28AutoPropertyDescriptorRooterD1Ev","__ZN2js28AutoPropertyDescriptorRooterD2Ev","__ZN2js28AutoPropertyDescriptorRooterC2EP9JSContext","__ZNK8JSObject18getFunctionPrivateEv","__ZNK10JSFunction13isInterpretedEv","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEixEj","__ZN2JSL11StringValueEP8JSString","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEC2ES3_","__ZL17DebuggerFrameEvalP9JSContextjPN2JS5ValueE16EvalBindingsMode","__ZL14CheckThisFrameP9JSContextRKN2js8CallArgsEPKcb","__ZNK2JS5Value8isStringEv","__ZNK2JS5Value8toStringEv","__ZN8JSString12ensureLinearEP9JSContext","__ZN8JSObject10getGenericEP9JSContextPS_iPN2JS5ValueE","__ZN2JS6AnchorIP8JSStringEC1ES2_","__ZL11IsValidHookRKN2JS5ValueE","__ZNK2js10StackFrame6calleeEv","__ZNK2js10StackFrame7calleevEv","__ZNK2js10StackFrame14mutableCalleevEv","__ZNK2js10StackFrame10formalArgsEv","__ZNK2js10StackFrame13numFormalArgsEv","__ZN2JS5Value9setNumberEd","_JSDOUBLE_IS_INT32","__ZN2JS5Value9setDoubleEd","__ZN2JSL9NullValueEv","__ZNK2js10StackFrame7hasArgsEv","__ZNK2js10StackFrame13numActualArgsEv","__ZL24DebuggerArguments_getArgP9JSContextjPN2JS5ValueE","__ZNK2JS5Value7toInt32Ev","__ZNK2js10StackFrame18canonicalActualArgEj","__ZNK2js10StackFrame9formalArgEj","__ZNK2js10StackFrame10actualArgsEv","__ZNK2js15ArgumentsObject13initialLengthEv","_JSVAL_TO_INT32_IMPL","__ZN2js13FlowsIntoNextE4JSOp","_JSVAL_IS_DOUBLE_IMPL","_JSVAL_IS_NUMBER_IMPL","_JSVAL_TO_PRIVATE_PTR_IMPL","__ZNK2JS5Value8toDoubleEv","__ZNK8JSObject13numFixedSlotsEv","__ZNK8JSScript10getVersionEv","__ZNK2js12StackSegment9maybeRegsEv","__ZN2js20CallReceiverFromArgvEPN2JS5ValueE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv","__ZNK2js13BytecodeRange5emptyEv","__ZNK2js13BytecodeRange11frontOffsetEv","__ZNK28BytecodeRangeWithLineNumbers15frontLineNumberEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js13BytecodeRange7frontPCEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js13BytecodeRangeC2EP9JSContextP8JSScript","__ZN8JSScript5notesEv","__ZNK10JSCodeSpec4typeEv","__ZNK8JSObject7getSlotEj","__ZNK2js12ContextStack5hasfpEv","__ZNK10JSFunction12inStrictModeEv","__ZNK2js10StackFrame12callReceiverEv","__ZL24DebuggerScript_checkThisP9JSContextRKN2js8CallArgsEPKcb","__ZL17GetScriptReferentP8JSObject","__ZL20DebuggerScript_checkP9JSContextRKN2JS5ValueEPKcS6_b","__ZL12ScriptOffsetP9JSContextP8JSScriptRKN2JS5ValueEPj","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_","__ZNK2JS5Value8isNumberEv","__ZNK2JS5Value8toNumberEv","__ZNK2JS5Value8isDoubleEv","__ZL15GetScriptHolderP8JSObject","__ZNK2js8Debugger13observesScopeEP8JSObject","__ZL11ScriptScopeP9JSContextP8JSScriptP8JSObject","__ZN9JSRuntime4new_IN2js10BreakpointEPNS1_8DebuggerEPNS1_14BreakpointSiteEP8JSObjectEEPT_T0_T1_T2_","__ZNK2js10StackFrame11maybeScriptEv","__ZNK2JS5Value9toPrivateEv","__ZN2JS5Value9setNumberEj","__ZN16FlowGraphSummaryC1EP9JSContext","__ZN16FlowGraphSummary8populateEP9JSContextP8JSScript","__ZN28BytecodeRangeWithLineNumbersC1EP9JSContextP8JSScript","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj","__ZN2JSL11NumberValueEd","__ZN28BytecodeRangeWithLineNumbers8popFrontEv","__ZN16FlowGraphSummaryD1Ev","__ZN16FlowGraphSummaryD2Ev","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js13BytecodeRange8popFrontEv","__ZN28BytecodeRangeWithLineNumbers10updateLineEv","__ZN28BytecodeRangeWithLineNumbersC2EP9JSContextP8JSScript","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6growByEj","__ZNK2js13BytecodeRange11frontOpcodeEv","__ZN16FlowGraphSummary7addEdgeEjj","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj","__ZL14JSID_FROM_BITSj","__ZN8JSScript13isValidOffsetEh","_JSVAL_IS_NULL_IMPL","_JSVAL_TO_OBJECT_IMPL","_JSVAL_IS_OBJECT_IMPL","_JSVAL_IS_UNDEFINED_IMPL","__ZNK2js2gc4Cell7addressEv","__ZN7mozilla14AlignedStorageILj64EE4addrEv","__ZN8JSObject8asGlobalEv","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE10initializeEPjS3_","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_","__ZN8JSScript7objectsEv","_PRIVATE_PTR_TO_JSVAL_IMPL","__ZN2js5types10TypeObject11hasAllFlagsEj","_BOOLEAN_TO_JSVAL_IMPL","__ZN2js16CallArgsFromArgvEjPN2JS5ValueE","_INT32_TO_JSVAL_IMPL","__ZN2js15TempAllocPolicyC2EP9JSContext","__ZNK2js12StackSegment4regsEv","__ZNK2JS5ValueeqERKS0_","__ZNK2js9FrameRegs2fpEv","__ZNK2js5Shape12isEmptyShapeEv","__ZN2js10AutoLockGCC2EP9JSRuntime","__ZN2js18RuntimeAllocPolicyC2EP9JSContext","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj0ES1_EEj","__ZN2js10VectorImplIjLj0ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_","__ZN16FlowGraphSummaryC2EP9JSContext","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC2ES1_","__ZN8JSObject14definePropertyEP9JSContextiRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej","__ZN2JS5Value10setPrivateEPv","__ZN8JSObject10getGenericEP9JSContextiPN2JS5ValueE","__ZN8JSObject23markDenseArrayNotPackedEP9JSContext","__ZN2js5types19MarkTypeObjectFlagsEP9JSContextP8JSObjectj","__ZN2js16AutoObjectVectorD2Ev","__ZN2js16AutoVectorRooterIP8JSObjectED2Ev","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEED2Ev","__ZN2js16AutoObjectVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIP8JSObjectEC2EP9JSContexti","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEEC2ES3_","__ZNK2js12ContextStack4regsEv","__ZNK2js8Debugger17observesNewScriptEv","__ZN2jsL4FindIN2JS5ValueEEEPT_S4_S4_RKS3_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE","__ZNK9JSContext5hasfpEv","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE","__ZN2js15AutoValueVectorD2Ev","__ZN2js16AutoVectorRooterIN2JS5ValueEED2Ev","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js12ContextStack2fpEv","__ZNK2js12StackSegment2fpEv","__ZN2js15AutoValueVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIN2JS5ValueEEC2EP9JSContexti","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEEC2ES3_","__ZN8JSObject7setSlotEjRKN2JS5ValueE","__ZN8JSObject10getSlotRefEj","__ZN8JSObject14getSlotAddressEj","__ZNK8JSObject11nativeEmptyEv","__ZN2js7HashSetIPNS_12GlobalObjectENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_12GlobalObjectENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js7HashMapIPNS_10StackFrameEP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPNS_10StackFrameEP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js7WeakMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S2_EEED2Ev","__ZN2js7HashMapIP8JSObjectS2_NS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectS4_EENS_7HashMapIS4_S4_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js7HashMapIP8JSScriptP8JSObjectNS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSScriptP8JSObjectEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZNK2js2gc4Cell11arenaHeaderEv","__Z18js_InitObjectClassP9JSContextP8JSObject","__ZNK2js12GlobalObject32functionObjectClassesInitializedEv","__ZN10JSFunction19setConstructorClassEPN2js5ClassE","__ZN2js2gcL15GetGCObjectKindEjb135","__ZN2js12GlobalObject28initFunctionAndObjectClassesEP9JSContext","__ZNK2js12GlobalObject18getObjectPrototypeEv","__Z20js_InitFunctionClassP9JSContextP8JSObject","__ZNK2js12GlobalObject20getFunctionPrototypeEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_123","__ZN8JSObject16setSingletonTypeEP9JSContext","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN8JSObject7getTypeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom124","__ZL12JSID_TO_ATOMi","__ZN2js12GlobalObject21setObjectClassDetailsEP10JSFunctionP8JSObject","__ZN2js12GlobalObject23setFunctionClassDetailsEP10JSFunctionP8JSObject","__ZN2js27LinkConstructorAndPrototypeEP9JSContextP8JSObjectS3_","__ZN2js24DefinePropertiesAndBrandEP9JSContextP8JSObjectP14JSPropertySpecP14JSFunctionSpec","__ZN8JSObject15addDataPropertyEP9JSContextijj","__ZN2js12GlobalObject15setOriginalEvalEP8JSObject","__ZL14ThrowTypeErrorP9JSContextjPN2JS5ValueE","__ZN2js12GlobalObject17setThrowTypeErrorEP10JSFunction","__ZN2js12GlobalObject6createEP9JSContextPNS_5ClassE","__ZN8JSObject19syncSpecialEqualityEv","__ZN2jsL24regexp_statics_constructEP9JSContextPNS_12GlobalObjectE","__ZN2JSL11ObjectValueER8JSObject125","__ZN2js12GlobalObject8setFlagsEi","__ZN2js12GlobalObject19initStandardClassesEP9JSContext","__ZN2JSL14UndefinedValueEv126","__ZN2js12GlobalObject5clearEP9JSContext","__ZN8JSObject7unbrandEP9JSContext","__ZN2js13RegExpStatics11extractFromEPNS_12GlobalObjectE","__ZN2js13RegExpStatics5clearEv","__ZN2JSL10Int32ValueEi127","__ZN2js12GlobalObject23isRuntimeCodeGenEnabledEP9JSContext","__ZN2JSL12BooleanValueEb","__ZNK2JS5Value7isFalseEv","__ZN2js12GlobalObject17createConstructorEP9JSContextPFiS2_jPN2JS5ValueEEPNS_5ClassEP6JSAtomj","__ZN2js12GlobalObject20createBlankPrototypeEP9JSContextPNS_5ClassE","__ZN2jsL16CreateBlankProtoEP9JSContextPNS_5ClassER8JSObjectRNS_12GlobalObjectE","__ZN2js12GlobalObject30createBlankPrototypeInheritingEP9JSContextPNS_5ClassER8JSObject","__ZN8JSObject5brandEP9JSContext","__ZN2js24GlobalDebuggees_finalizeEP9JSContextP8JSObject","__ZN9JSContext7delete_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEvPT_","__ZN2js12GlobalObject12getDebuggersEv","__ZN2js12GlobalObject20getOrCreateDebuggersEP9JSContext","__ZN9JSContext4new_IN2js6VectorIPNS1_8DebuggerELj0ENS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js12GlobalObject11addDebuggerEP9JSContextPNS_8DebuggerE","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIPNS_8DebuggerELj0ENS_17SystemAllocPolicyEED2Ev","__ZL14JSID_FROM_BITSj151","__ZN2js12ParseMapPool15checkInvariantsEv","_JSVAL_IS_SPECIFIC_BOOLEAN","_JSID_TO_STRING150","__ZN7mozilla14AlignedStorageILj80EE4addrEv","__ZN2js12ParseMapPool9asAtomMapEPv","__ZNK2js12DefnOrHeader8isHeaderEv","__ZNK2js12DefnOrHeader6headerEv","__ZL26js_IsPropertyCacheDisabledP9JSContext","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE5clearEv","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE6lengthEv","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_","__ZN8JSObject7brandedEv","__ZN8JSObject10setGenericEv","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5beginEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js12DefnOrHeader4defnEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE136","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE139","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__Z16js_NewGCFunctionP9JSContext","__Z10NewGCThingI10JSFunctionEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js13RegExpStatics12aboutToWriteEv","__ZN2js13RegExpStatics6copyToERS0_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE16infallibleAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiLj20ES1_EEvRKNS0_IT_XT0_ET1_EE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE14internalAppendIiEEvPKT_j","__ZNK2js12GlobalObject16getRegExpStaticsEv","__ZN9JSContext4new_IN2js13RegExpStaticsEEEPT_v","__ZN2js13RegExpStaticsC1Ev","__ZN2js13RegExpStaticsC2Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC1ES1_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEC2ES1_","__ZN2js12GlobalObject16setDetailsForKeyE10JSProtoKeyP8JSObjectS3_","__ZN2js12ParseMapPool8purgeAllEv","__ZN9JSContext7delete_IN2js9InlineMapIP6JSAtomjLj24EEEEEvPT_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12clearAndFreeEv","__ZN2js12ParseMapPool13allocateFreshEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7reserveEj","__ZN9JSContext4new_IN2js9InlineMapIP6JSAtomjLj24EEEPS_EEPT_T0_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE16infallibleAppendERKS1_","__ZN2js9AtomDecls9allocNodeEP12JSDefinition","__ZN2js12AtomDeclNodeC1EP12JSDefinition","__ZN2js9AtomDecls9addShadowEP6JSAtomP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrcvPPPPPPPS5_Ev","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3addERNS4_6AddPtrERKS2_RKS3_","__ZN2js12DefnOrHeaderC1EPNS_12AtomDeclNodeE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5valueEv","__ZN2js9AtomDecls10lastAsNodeEPNS_12DefnOrHeaderE","__ZN2js9AtomDecls8addHoistEP6JSAtomP12JSDefinition","__ZN2js9InlineMapIP6JSAtomjLj24EEC1EP9JSContext","__ZN2js9InlineMapIP6JSAtomjLj24EEC2EP9JSContext","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10isLiveHashEj","__ZN2js13PointerHasherIP6JSAtomLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP6JSAtomLj2EE4hashERKS2_","__ZNK7mozilla14AlignedStorageILj128EE4addrEv","__ZN7mozilla14AlignedStorageILj128EE4addrEv","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13copyConstructIS1_EEvPS1_PKT_S8_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5clearEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC2ERS8_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2ERS5_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEptEv","__ZNK2js7MoveRefIP6JSAtomEcvRS2_Ev","__ZNK2js7MoveRefINS_12DefnOrHeaderEEcvRS1_Ev","__ZN2js7MoveRefINS_12DefnOrHeaderEEC2ERS1_","__ZN2js7MoveRefIP6JSAtomEC2ERS2_","__ZN2js12DefnOrHeaderC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE8usingMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5countEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11initializedEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2EPNS4_10InlineElemEb","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS1_Lj32ES2_EEj","__ZN2js10VectorImplIPvLj32ENS_17SystemAllocPolicyELb1EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js9InlineMapIP6JSAtomjLj24EED1Ev","__ZN2js9InlineMapIP6JSAtomjLj24EED2Ev","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE12switchAndAddERKS2_RKS3_","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS2_RKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11createTableERSA_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12destroyTableERSA_PNS0_14HashTableEntryIS6_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEEEC1ERS8_","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1ERS5_","__ZN2js4MoveIP6JSAtomEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveINS_12DefnOrHeaderEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_12DefnOrHeaderEEC1ERS1_","__ZN2js7MoveRefIP6JSAtomEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC1Ev","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEC2Ev","__ZN2js12DefnOrHeaderC1Ev","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS3_","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5matchERNS0_14HashTableEntryIS6_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5countEv","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5clearEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC1EPNS4_10InlineElemEb","__ZN2js10StackFrame10prevpcSlowEPPNS_13JSInlinedSiteE","__ZN2js12ContextStackD2Ev","__ZN2jsL3MaxIPN2JS5ValueEEET_S4_S4_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E6AddPtrE","__ZN2js12DefnOrHeaderC2EPNS_12AtomDeclNodeE","__ZN2js12AtomDeclNodeC2EP12JSDefinition","__ZNK2js9FrameRegs7inlinedEv","__ZNK2js10StackFrame10annotationEv","__ZN2js10StackFrame13setAnnotationEPv","__ZN2js10StackFrame22setScopeChainNoCallObjER8JSObject","__Z16js_IsNamedLambdaP10JSFunction","__ZNK8JSObject17isNormalArgumentsEv","__ZN2js10StackFrame6prevpcEPPNS_13JSInlinedSiteE","__ZNK2js12StackSegment10slotsBeginEv","__ZNK2js8CallArgs3endEv","__ZN2js12StackSegment8pushRegsERNS_9FrameRegsE","__ZN2js12StackSegment7popRegsEPNS_9FrameRegsE","__ZN2js12StackSegment8pushCallERNS_12CallArgsListE","__ZN2js12StackSegment11pointAtCallERNS_12CallArgsListE","__ZN2js12StackSegment7popCallEv","__ZN2js10StackSpaceC2Ev","__ZNK2js12StackSegment12prevInMemoryEv","__ZNK2js10StackFrame5slotsEv","__ZNK9JSRuntime17trustedPrincipalsEv","__ZN2js10StackSpace13committedSizeEv","__ZN2js12ContextStack11threadResetEv","__ZNK2js12StackSegment13prevInContextEv","__ZNK2js12StackSegment10maybeCallsEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE14internalAppendIS1_EEvT_","__ZN2js10StackFrame16initExecuteFrameEP8JSScriptPS0_PNS_9FrameRegsERKN2JS5ValueER8JSObjectNS_11ExecuteTypeE","__ZN2JSL9NullValueEv158","__ZN2js10StackFrame14initDummyFrameEP9JSContextR8JSObject","__ZN2jsL7PodZeroINS_10StackFrameEEEvPT_","__ZN2js10StackFrame8initPrevEP9JSContext","__ZN2js10StackFrame18stealFrameAndSlotsEPN2JS5ValueEPS0_S3_S3_","__ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j","__ZNK2js10StackFrame7callObjEv","__ZN2js15ArgumentsObject13setStackFrameEPNS_10StackFrameE","__ZN2js10StackFrame11pcQuadraticERKNS_12ContextStackEPS0_PPNS_13JSInlinedSiteE","__ZNK2js10StackSpace17containingSegmentEPKNS_10StackFrameE","__ZNK2js12StackSegment16computeNextFrameEPKNS_10StackFrameE","__ZNK2js12StackSegment8containsEPKNS_10StackFrameE","__ZNK2js12StackSegment7maybefpEv","__ZNK2js12StackSegment8containsEPKNS_9FrameRegsE","__ZNK2js12StackSegment8containsEPKNS_12CallArgsListE","__ZNK2js12StackSegment3endEv","__ZN2js10StackSpace4initEv","__ZN2js10StackSpaceD2Ev","__ZN2js10StackSpace4markEP8JSTracer","__ZNK2js10StackSpace11firstUnusedEv","__ZNK2js10StackSpace15ensureSpaceSlowEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment","__ZN2js10StackSpace12tryBumpLimitEP9JSContextPN2JS5ValueEjPS5_","__ZNK2js10StackSpace11ensureSpaceEP9JSContextNS_16MaybeReportErrorEPN2JS5ValueEiP13JSCompartment","__ZN2js12ContextStackC2EP9JSContext","__ZNK2js12ContextStack5onTopEv","__ZNK2js12ContextStack12containsSlowEPKNS_10StackFrameE","__ZN2js12ContextStack11ensureOnTopEP9JSContextNS_16MaybeReportErrorEjNS0_11MaybeExtendEPbP13JSCompartment","__ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE","__ZN2js12ImplicitCastINS_8CallArgsENS_15InvokeArgsGuardEEERT_RT0_","__ZN2js15InvokeArgsGuard9setPushedERNS_12ContextStackE","__ZNK2js8CallArgs4argcEv","__ZN2js10FrameGuard9setPushedERNS_12ContextStackE","__ZNK2js9StackIter8isScriptEv","__ZNK2js9StackIter2fpEv","__ZN9JSContext14setCompartmentEP13JSCompartment","__ZN11JSGenerator13floatingFrameEv","__ZN2js10StackFrame22unsetFloatingGeneratorEv","__ZN2js10StackFrame20setFloatingGeneratorEv","__ZN2js9StackIter10poisonRegsEv","__ZNK2js10StackFrame22isFramePushedByExecuteEv","__ZNK2js12CallArgsList4prevEv","__ZNK2js12CallReceiver4baseEv","__ZN2js12StackSegmentC1EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE","__ZN2js12ContextStack10popSegmentEv","__ZN9JSContext27maybeMigrateVersionOverrideEv","__ZN2js12ContextStack14pushInvokeArgsEP9JSContextjPNS_15InvokeArgsGuardE","__ZN2js12ContextStack13popInvokeArgsERKNS_15InvokeArgsGuardE","__ZN2js12ContextStack15pushInvokeFrameEP9JSContextRKNS_8CallArgsENS_17InitialFrameFlagsEPNS_16InvokeFrameGuardE","__ZNK2js12ContextStack12getCallFrameEP9JSContextNS_16MaybeReportErrorERKNS_8CallArgsEP10JSFunctionP8JSScriptPNS_10StackFrame5FlagsE","__ZN2js10StackFrame13initCallFrameEP9JSContextR8JSObjectP10JSFunctionP8JSScriptjNS0_5FlagsE","__ZN2js9FrameRegs12prepareToRunERNS_10StackFrameEP8JSScript","__ZN2js12ContextStack16pushExecuteFrameEP9JSContextP8JSScriptRKN2JS5ValueER8JSObjectNS_11ExecuteTypeEPNS_10StackFrameEPNS_17ExecuteFrameGuardE","__ZN2js9StackIterppEv","__ZNK2js12ContextStack7maybefpEv","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj","__ZN2js12ContextStack14pushDummyFrameEP9JSContextP13JSCompartmentR8JSObjectPNS_15DummyFrameGuardE","__ZN2js9FrameRegs14initDummyFrameERNS_10StackFrameE","__ZN2js12ContextStack8popFrameERKNS_10FrameGuardE","__ZN2js10StackFrame16functionEpilogueEv","__ZN2js12ContextStack18pushGeneratorFrameEP9JSContextP11JSGeneratorPNS_19GeneratorFrameGuardE","__ZNK2js10StackFrame8numSlotsEv","__ZN2js10StackFrame18resetGeneratorPrevEP9JSContext","__ZN2js9FrameRegs12rebaseFromToERKS0_RNS_10StackFrameE","__ZN2js12ContextStack17popGeneratorFrameERKNS_19GeneratorFrameGuardE","__ZN2js12ContextStack14saveFrameChainEv","__ZN2js12ContextStack17restoreFrameChainEv","__ZN2js9StackIter8popFrameEv","__ZNK2js10StackFrame13actualArgsEndEv","__ZN2js9StackIter7popCallEv","__ZN2js9StackIter18settleOnNewSegmentEv","__ZN2js9StackIter14startOnSegmentEPNS_12StackSegmentE","__ZN8JSString19buildLengthAndFlagsEjj","__ZNK8JSString12asExtensibleEv","__ZN8JSString7asFixedEv","__ZNK2js12CallArgsList6activeEv","__ZNK2js12CallReceiver7calleevEv","__ZNK2js9StackIter4doneEv","__ZNK2js9StackIter10nativeArgsEv","__ZNK8JSScript7nestingEv","__ZNK9JSContext19isVersionOverriddenEv","__ZN9JSContext20clearVersionOverrideEv","__ZN2js12StackSegmentC2EPS0_S1_PNS_9FrameRegsEPNS_12CallArgsListE","__ZNK8JSObject6isCallEv","__ZNK8JSString12isExtensibleEv","__ZNK17JSDependentString4baseEv","__ZNK8JSString6isRopeEv","__ZNK18JSExtensibleString8capacityEv","__ZNK6JSRope9leftChildEv","__ZN2js9StackIter16settleOnNewStateEv","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh161","__ZNK2js10StackFrame4baseEv","__ZL18CrashIfInvalidSlotPN2js10StackFrameEPN2JS5ValueE","__ZN2jsL16IsNativeFunctionERKN2JS5ValueE","__ZN2js9StackIterC2EP9JSContextNS0_11SavedOptionE","__ZNK2js9StackItereqERKS0_","__ZN2js13AllFramesIterC2ERNS_10StackSpaceE","__ZN2js13AllFramesIterppEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction","__ZNK10JSFunction8isNativeEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject","__ZNK2js10StackFrame20maintainNestingStateEv","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_","__ZNK9JSContext9maybeRegsEv","__ZNK2js12ContextStack9maybeRegsEv","__ZNK8JSString7isShortEv","__ZNK2js2gc4Cell12getAllocKindEv","__ZNK8JSString7isFixedEv","__ZNK8JSString8isInlineEv","__ZNK8JSString10isExternalEv","__ZN14JSLinearString4markEP8JSTracer","__ZNK2js2gc4Cell14markIfUnmarkedEj","__ZN8JSString13charsHeapSizeEPFjPvE","__ZN6JSRope7flattenEP9JSContext","__ZL10AllocCharsP9JSContextjPPtPj","__ZN2jsL7PodCopyItEEvPT_PKS1_j","__ZN13JSShortString10lengthFitsEj","__ZNK2js2gc4Cell5chunkEv","__ZNK8JSString6asAtomEv","__ZNK7mozilla9RangedPtrIKtEdeEv","__ZN2js13StaticStrings15fitsInSmallCharEt","__ZNK7mozilla9RangedPtrIKtEeqIS1_EEbRKNS0_IT_EE","__ZN7mozilla9RangedPtrIKtEaSIS1_EERS2_RKNS0_IT_EE","__ZN7mozilla9RangedPtrIKtEC2EPS1_S3_j","__ZN7mozilla9RangedPtrIKtEC2EPS1_j","__ZN2js19PreserveCompartmentD2Ev","__ZN2js19PreserveCompartmentC2EP9JSContext","__ZNK2js2gc11ArenaHeader12getAllocKindEv","__ZN2v88internal6VectorIcEC2EPci","__ZNK2v88internal13StringBuilder12is_finalizedEv","__ZNK2v88internal6VectorIcEixEi","__Z16js_ConcatStringsP9JSContextP8JSStringS2_","__Z19js_NewGCShortStringP9JSContext","__ZN8JSString8getCharsEP9JSContext","__ZN14JSInlineString4initEj","__ZN6JSRope4new_EP9JSContextP8JSStringS3_j","__ZN17JSDependentString8undependEP9JSContext","__ZNK12JSFlatString7isIndexEPj","__ZNK12JSFlatString6charsZEv","__ZN7mozilla9RangedPtrIKtEC1EPS1_j","__ZN7mozilla9RangedPtrIKtEC1EPS1_S3_j","__ZN7mozilla9RangedPtrIKtEppEi","__ZNK7mozilla9RangedPtrIKtEneIS1_EEbRKNS0_IT_EE","__ZN2js13StaticStrings4initEP9JSContext","__ZN2js19SwitchToCompartmentC1EP9JSContextP13JSCompartment","__ZN13JSFixedString27morphAtomizedStringIntoAtomEv","__ZN2js19SwitchToCompartmentD1Ev","__ZN2js13StaticStrings5traceEP8JSTracer","__ZN2js13StaticStrings8isStaticEP6JSAtom","__ZN7mozilla9RangedPtrIKtEppEv","__ZN7mozilla9RangedPtrIKtEpLEj","__ZN7mozilla9RangedPtrIKtEplEj","__ZNK7mozilla9RangedPtrIKtE6createEPS1_","__ZN2js19SwitchToCompartmentD2Ev","__ZN2js19SwitchToCompartmentC2EP9JSContextP13JSCompartment","_js_malloc181","__Z14js_NewGCStringP9JSContext","__ZN6JSRope4initEP8JSStringS1_j","__Z10NewGCThingI8JSStringEPT_P9JSContextN2js2gc9AllocKindEj","__Z10NewGCThingI13JSShortStringEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js11OffTheBooks7malloc_Ej","__ZN2js2gc11ChunkBitmap14markIfUnmarkedEPKNS0_4CellEj","__ZN2js2gc11ChunkBitmap18getMarkWordAndMaskEPKNS0_4CellEjPPjS5_","_V8_Fatal","__ZN2v88internal15DoubleToCStringEdPci","__ZN2v88internal13StringBuilderC1EPci","__ZN2v88internal13StringBuilder12AddCharacterEc","__ZN2v88internal6VectorIcEC1EPci","__ZN2v88internal13StringBuilderD1Ev","__ZN2v88internal13StringBuilderD2Ev","__ZN2v88internal13StringBuilderC2EPci","__ZN2v88internalL15BiggestPowerTenEjiPjPi","__ZN2js7analyzeL7ArgSlotEj","__ZN2v88internal5DiyFp8MultiplyERKS1_","__ZNK2v88internal5DiyFp1fEv","__ZNK2v88internal5DiyFp1eEv","__ZN2v88internal5DiyFp5set_fEy","__ZN2v88internal5DiyFp5set_eEi","__ZN2v88internal5DiyFp9NormalizeEv","__ZNK2v88internal6Double8AsUint64Ev","__ZN2v88internal5DiyFpC2Ev","__ZN2v88internal7BitCastIydEET_RKT0_","__ZN2v88internal5DiyFp8SubtractERKS1_","__ZN2v88internal5DiyFpC2Eyi","__ZN8JSScript7getAtomEj","__ZN2v88internal9RoundWeedENS0_6VectorIcEEiyyyyy","__ZN2v88internal8DigitGenENS0_5DiyFpES1_S1_NS0_6VectorIcEEPiS4_","__ZN2v88internal5DiyFpC1Eyi","__ZN2v88internal5DiyFp5MinusERKS1_S3_","__ZN2v88internal6grisu3EdNS0_6VectorIcEEPiS3_","__ZN2v88internal6DoubleC1Ed","__ZNK2v88internal6Double17AsNormalizedDiyFpEv","__ZN2v88internal5DiyFpC1Ev","__ZNK2v88internal6Double20NormalizedBoundariesEPNS0_5DiyFpES3_","__ZN2v88internalL14GetCachedPowerEiiiPiPNS0_5DiyFpE","__ZN2v88internal5DiyFp5TimesERKS1_S3_","__ZN2v88internal8FastDtoaEdNS0_6VectorIcEEPiS3_","__ZNK2v88internal6Double7AsDiyFpEv","__ZN2v88internal5DiyFp9NormalizeERKS1_","__ZNK2v88internal6Double11SignificandEv","__ZNK2v88internal6Double8ExponentEv","__ZNK2v88internal6Double10IsDenormalEv","__ZN2v88internal6DoubleC2Ed","__ZN2v88internalL16double_to_uint64Ed","__ZN2js15TempAllocPolicy13onOutOfMemoryEPvj","__ZNK2js15TempAllocPolicy19reportAllocOverflowEv","__ZN2js7analyze8Bytecode12mergeDefinesEP9JSContextPNS0_14ScriptAnalysisEbjPjj","__ZN2js10ArenaArrayIjEEPT_R11JSArenaPoolj","__ZN2js7analyze14ScriptAnalysis6setOOMEP9JSContext","__ZN2js7analyze14ScriptAnalysis16checkAliasedNameEP9JSContextPh","__ZN8JSScript11getFunctionEj","__ZN2js7analyzeL9LocalSlotEP8JSScriptj","__ZN2js7analyze14ScriptAnalysis15analyzeBytecodeEP9JSContext","__ZN2js7analyzeL21BytecodeNoFallThroughE4JSOp","__ZN2js5types10TypeScript9typeArrayEv","__ZNK8JSScript8functionEv","__ZN8JSScript12getClosedArgEj","__ZN2js7analyze14ScriptAnalysis8setLocalEjj","__ZN8JSScript12getClosedVarEj","__ZNK10JSFunction13isHeavyweightEv","__ZN2js7analyze14ScriptAnalysis9maybeCodeEj","__ZN2js7analyzeL13GetJumpOffsetEPhS1_","__ZN2js7analyze14ScriptAnalysis7getCodeEj","__ZN8JSScript8trynotesEv","__ZN2js7analyzeL10TotalSlotsEP8JSScript","__ZN2js10ArenaArrayIPNS_7analyze8BytecodeEEEPT_R11JSArenaPoolj","__ZN2js10ArenaArrayIhEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_7analyze8BytecodeEEEvPT_j","__ZN2jsL7PodZeroIhEEvPT_j","__ZN2js8ArenaNewINS_7analyze8BytecodeEEEPT_R11JSArenaPool","__ZN2js7analyze12UntrapOpcodeC1EP9JSContextP8JSScriptPh","__ZN2js7analyzeL17GetBytecodeLengthEPh","__ZN2js7analyzeL11GetUseCountEP8JSScriptj","__ZN2js7analyzeL11GetDefCountEP8JSScriptj","__ZN2js7analyze14ScriptAnalysis7addJumpEP9JSContextjPjS4_jS4_j","__ZN2js7analyze14ScriptAnalysis10jumpTargetEPKh","__ZN2js7analyze14ScriptAnalysis12localDefinedEjj","__ZN2js7analyze12UntrapOpcodeD1Ev","__ZN2js7analyze14ScriptAnalysis11ranBytecodeEv","__ZN2js7analyze14ScriptAnalysis6failedEv","__ZN2js7analyze14ScriptAnalysis14ensureVariableERNS0_16LifetimeVariableEj","__ZN2js7analyze14ScriptAnalysis11slotEscapesEj","__ZN2js7analyze14ScriptAnalysis16analyzeLifetimesEP9JSContext","__ZN2js10ArenaArrayINS_7analyze16LifetimeVariableEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_7analyze16LifetimeVariableEEEvPT_j","__ZN2js7analyze14ScriptAnalysis14extendVariableEP9JSContextRNS0_16LifetimeVariableEjj","__ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh","__ZN2js7analyze14ScriptAnalysis11addVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj","__ZNK2js7analyze16LifetimeVariable4liveEj","__ZN2js7analyze14ScriptAnalysis12killVariableEP9JSContextRNS0_16LifetimeVariableEjRPPS4_Rj","__ZN2js8ArenaNewINS_7analyze8LifetimeEjjPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js7analyzeL12FollowBranchEP9JSContextP8JSScriptj","__ZN2js8ArenaNewINS_7analyze12LoopAnalysisEEEPT_R11JSArenaPool","__ZN2jsL7PodZeroINS_7analyze12LoopAnalysisEEEvPT_","__ZN2js7analyze14ScriptAnalysis16clearAllocationsEv","__ZN2js7analyze14ScriptAnalysis12ranLifetimesEv","__ZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContext","__ZN2js7analyze14ScriptAnalysis9trackSlotEj","__ZN2js7analyze8SSAValue11initInitialEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEEC1ES1_","__ZN2js7analyze14ScriptAnalysis9maybeCodeEPKh","__ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_j","__ZN2js7analyzeL11ExtendedDefEPh","__ZNK2js7analyze8SSAValue4kindEv","__ZNK2js7analyze8SSAValue9phiOffsetEv","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyze14ScriptAnalysis8livenessEj","__ZNK2js7analyze8SSAValue7phiNodeEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE7popBackEv","__ZN2js7analyze14ScriptAnalysis18removeBranchTargetERNS_6VectorIjLj0ENS_15TempAllocPolicyEEEj","__ZN9JSContext4new_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEixEj","__ZNK2js7analyze16LifetimeVariable10firstWriteEPNS0_12LoopAnalysisE","__ZN2js7analyze14ScriptAnalysis7makePhiEP9JSContextjjPNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis9insertPhiEP9JSContextRNS0_8SSAValueERKS4_","__ZN2js7analyze14ScriptAnalysis10mergeValueEP9JSContextjRKNS0_8SSAValueEPNS0_9SlotValueE","__ZN2js7analyze14ScriptAnalysis17mergeBranchTargetEP9JSContextRKNS0_8SSAValueEjRKNS_6VectorIjLj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js7analyze9SlotValueC1EjRKNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis15freezeNewValuesEP9JSContextj","__ZN2js7analyzeL11ExtendedUseEPh","__ZN2js10ArenaArrayINS_7analyze8SSAValueEEEPT_R11JSArenaPoolj","__ZN2js7analyze8SSAValue5clearEv","__ZN2js10ArenaArrayINS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_j","__ZN2js7analyze14ScriptAnalysis13trackUseChainERKNS0_8SSAValueE","__ZN2js7analyze14ScriptAnalysis8useChainERKNS0_8SSAValueE","__ZN2js7analyze8SSAValue10initPushedEjj","__ZN2js10ArenaArrayIPNS_7analyze11SSAUseChainEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_7analyze11SSAUseChainEEEvPT_j","__ZN2js7analyze8SSAValue11initWrittenEjj","__ZN2js7analyze14ScriptAnalysis17checkBranchTargetEP9JSContextjRNS_6VectorIjLj0ENS_15TempAllocPolicyEEEPNS0_8SSAValueEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js8ArenaNewINS_7analyze10SSAPhiNodeEEEPT_R11JSArenaPool","__ZN2js7analyzeL15PhiNodeCapacityEj","__ZN2js7analyze8SSAValue7initPhiEjPNS0_10SSAPhiNodeE","__ZNK2js7analyze8SSAValue6equalsERKS1_","__ZN2js8ArenaNewINS_7analyze11SSAUseChainEEEPT_R11JSArenaPool","__ZN2jsL7PodCopyINS_7analyze8SSAValueEEEvPT_PKS3_j","__ZN2js7analyze14ScriptAnalysis17checkPendingValueEP9JSContextRKNS0_8SSAValueEjPNS_6VectorINS0_9SlotValueELj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE6appendIjEEbT_","__ZN2js7analyzeL9StackSlotEP8JSScriptj","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE4backEv","__ZN9JSContext7delete_IN2js6VectorINS1_7analyze9SlotValueELj0ENS1_15TempAllocPolicyEEEEEvPT_","__ZN2js10ArenaArrayINS_7analyze9SlotValueEEEPT_R11JSArenaPoolj","__ZNK2js7analyze8SSAValue7varSlotEv","__ZNK2js7analyze8SSAValue12pushedOffsetEv","__ZN8JSScript8analysisEv","__ZNK2js7analyze8SSAValue10varInitialEv","__ZNK2js7analyze14ScriptAnalysis14numReturnSitesEv","__ZNK2js7analyze8SSAValue11pushedIndexEv","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js5types7TypeSetC2Ev","__ZNK2js7MoveRefINS_7analyze9SlotValueEEcvRS2_Ev","__ZN2js7MoveRefINS_7analyze9SlotValueEEC2ERS2_","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js7analyze8LifetimeC2EjjPS1_","__ZNK2js7analyze8SSAValue9varOffsetEv","__ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyze13CrossSSAValueC2EjRKNS0_8SSAValueE","__ZN2jsL7PodZeroINS_7analyze8SSAValueEEEvPT_","__ZN2js7analyze9SlotValueC2EjRKNS0_8SSAValueE","__ZNK2js7analyze16LifetimeVariable10firstWriteEjj","__ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesC2ES3_PNS0_8SSAValueE","__ZN2js7analyze12UntrapOpcode6retrapEv","__ZN2js7analyze14CrossScriptSSA9foldValueERKNS0_13CrossSSAValueE","__ZN2js7analyze14CrossScriptSSA8getFrameEj","__ZN2js7analyze14ScriptAnalysis11poppedValueEPKhj","__ZN2js7analyze13CrossSSAValueC1EjRKNS0_8SSAValueE","__ZN2js7analyze14CrossScriptSSA9numFramesEv","__ZN2js7analyze14CrossScriptSSA9iterFrameEj","__ZN2js7analyze14ScriptAnalysis13getValueTypesERKNS0_8SSAValueE","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIjLj0ENS_15TempAllocPolicyEE14internalAppendIjEEvT_","__ZN2js7analyze11SSAUseChainC1Ev","__ZN2js7analyze11SSAUseChainC2Ev","__ZN2jsL7PodZeroINS_7analyze11SSAUseChainEEEvPT_","__ZN2js7analyze10SSAPhiNodeC1Ev","__ZN2js7analyze10SSAPhiNodeC2Ev","__ZN2js5types7TypeSetC1Ev","__ZN2jsL7PodZeroINS_7analyze10SSAPhiNodeEEEvPT_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_7analyze9SlotValueEEC1ERS2_","__ZN2js10VectorImplINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_7analyze9SlotValueEEENS_7MoveRefIT_EERKS4_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorINS_7analyze9SlotValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js7analyze8LifetimeC1EjjPS1_","__ZN2js7analyze8BytecodeC1Ev","__ZN2js7analyze8BytecodeC2Ev","__ZN2jsL7PodZeroINS_7analyze8BytecodeEEEvPT_","__ZN2js7analyze14ScriptAnalysis11pushedTypesEjj","__ZN2js5types10TypeScript9SlotTypesEP8JSScriptj","__ZN2js6VectorINS_7analyze14CrossScriptSSA5FrameELj0ENS_15TempAllocPolicyEEixEj","__ZN2js7analyze14ScriptAnalysis11poppedValueEjj","__ZZN2js7analyze14ScriptAnalysis10analyzeSSAEP9JSContextEN13FreeSSAValuesD2Ev","__ZN2js8ArenaNewINS_7analyze8LifetimeEjiPS2_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js7analyze12UntrapOpcodeD2Ev","__ZN2js7analyze14ScriptAnalysis20localHasUseBeforeDefEj","__ZN2js7analyze8Bytecode9isDefinedEj","__ZN2js7analyze14ScriptAnalysis10jumpTargetEj","__ZL13IMPL_TO_JSVAL12jsval_layout","_BUILD_JSVAL225","_JS_GetNaNValue","_JS_GetNegativeInfinityValue","_JS_GetPositiveInfinityValue","_JS_GetEmptyString","__Z28js_GetVariableBytecodeLengthPh","__ZN2js7analyze12UntrapOpcodeC2EP9JSContextP8JSScriptPh","__ZN8JSScript9getObjectEj","___cxx_global_var_init","___cxx_global_var_init1","___cxx_global_var_init2","___cxx_global_var_init3","___cxx_global_var_init4","___cxx_global_var_init5","_JS_Now","_JS_GetEmptyStringValue","_STRING_TO_JSVAL","_JS_ConvertArguments","_JS_ConvertArgumentsVA","__ZN12JSValueArrayC1EPN2JS5ValueEj","__ZN16JSAutoByteStringC1Ev","__ZN2js20GetFunctionNameBytesEP9JSContextP10JSFunctionP16JSAutoByteString","_JS_ReportErrorNumber","__ZN16JSAutoByteStringD1Ev","_JS_ValueToUint16","_JS_ValueToECMAInt32","_JS_ValueToECMAUint32","_JS_ValueToInt32","_JS_ValueToNumber","__ZL18js_DoubleToIntegerd","__ZN8JSString11ensureFixedEP9JSContext","_OBJECT_TO_JSVAL","__ZL20TryArgumentFormatterP9JSContextPPKciPPN2JS5ValueEPPc","_JS_AddArgumentFormatter","_JS_RemoveArgumentFormatter","_JS_ConvertValue","_DOUBLE_TO_JSVAL","_BOOLEAN_TO_JSVAL","_JS_ValueToObject","_JS_ValueToFunction","_JS_ValueToConstructor","_JS_ShutDown","_JS_BeginRequest","_JS_EndRequest","_JS_YieldRequest","_JS_SuspendRequest","_JS_ResumeRequest","_JS_IsInRequest","_JS_Lock","_JS_Unlock","_JS_GetImplementationVersion","_JS_PropertyStub","_JS_StrictPropertyStub","_JS_EnumerateStub","_JS_ResolveStub","__ZN2jsL13VersionNumberE9JSVersion","__ZN2js8ValueifyEP12JSStackFrame","__ZNK2js15AutoValueRooter5valueEv","_JS_GetTypeName","_JS_GetRuntimePrivate","_JS_SetRuntimePrivate","_JS_SetContextCallback","_JS_GetContextPrivate","_JS_SetContextPrivate","_JS_GetRuntime","_JS_VersionToString","_JS_SetCompartmentCallback","_JS_SetWrapObjectCallbacks","_JS_SetCompartmentPrivate","_JS_GetCompartmentPrivate","_JS_ValueToString","_JS_ValueToSource","__ZN2js15AutoValueRooterC1EP9JSContextRKN2JS5ValueE","__ZN2js8ToNumberEP9JSContextRKN2JS5ValueEPd","__ZN2js15AutoValueRooterD1Ev","_JS_DoubleIsInt32","_JSDOUBLE_IS_INT32228","_JS_DoubleToInt32","__ZL20js_DoubleToECMAInt32d","_JS_DoubleToUint32","__ZN2js16ValueToECMAInt32EP9JSContextRKN2JS5ValueEPi","__ZN2js17ValueToECMAUint32EP9JSContextRKN2JS5ValueEPj","__ZN2js12ValueToInt32EP9JSContextRKN2JS5ValueEPi","__ZN2js13ValueToUint16EP9JSContextRKN2JS5ValueEPt","_JS_ValueToBoolean","_JS_TypeOfValue","_JS_StrictlyEqual","_JS_LooselyEqual","_JS_SameValue","_JS_IsBuiltinEvalFunction","_JS_IsBuiltinFunctionConstructor","__ZN9JSRuntimeC2Ev","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC1ES3_","__ZN11JSAtomStateC1Ev","__ZN2js13StaticStringsC1Ev","__ZN9JSRuntime4initEj","__ZN9JSRuntime4new_I13JSCompartmentPS_EEPT_T0_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js10Foreground7delete_I13JSCompartmentEEvPT_","__ZN9JSRuntimeD2Ev","__ZN11JSAtomStateD1Ev","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED1Ev","_JS_Init","__ZN2js11OffTheBooks7calloc_Ej","_JS_Finish","__ZN2js10Foreground7delete_I9JSRuntimeEEvPT_","_JS_NewContext","_JS_DestroyContext","_JS_DestroyContextNoGC","_JS_DestroyContextMaybeGC","_JS_ContextIterator","_JS_GetVersion","_JS_SetVersion","__ZN2jsL16VersionCopyFlagsEP9JSVersionS0_","__ZN9JSContext20maybeOverrideVersionE9JSVersion","_JS_StringToVersion","_JS_GetOptions","__ZNK9JSContext10allOptionsEv","_JS_SetOptions","__ZL16SetOptionsCommonP9JSContextj","_JS_ToggleOptions","_JS_EnterCrossCompartmentCall","__ZN9JSContext4new_IN2js15AutoCompartmentEPS_P8JSObjectEEPT_T0_T1_","__ZN2js10Foreground7delete_INS_15AutoCompartmentEEEvPT_","_JS_ConvertStub","_JS_EnterCrossCompartmentCallScript","_JS_NewGlobalObject","_JS_EnterCrossCompartmentCallStackFrame","_JS_LeaveCrossCompartmentCall","__ZN22JSAutoEnterCompartment5enterEP9JSContextP8JSObject","__ZNK8JSObject14getCompartmentEv","__ZN22JSAutoEnterCompartment20enterAndIgnoreErrorsEP9JSContextP8JSObject","__ZN2JS26AutoEnterScriptCompartment5enterEP9JSContextP8JSScript","__ZN2JS25AutoEnterFrameCompartment5enterEP9JSContextP12JSStackFrame","_JS_WrapObject","_JS_WrapValue","_JSID_TO_STRING243","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6lengthEv","_JS_GetGlobalObject","_JS_TransplantObject","__ZN2JSL11ObjectValueER8JSObject239","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E3PtrE","__ZN2js16AutoVectorRooterIN2JS5ValueEE7reserveEj","__ZN2js16AutoVectorRooterIN2JS5ValueEE16infallibleAppendERKS2_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE6removeERKS2_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3putERKS2_S7_","_js_TransplantObjectWithWrapper","_JS_SetGlobalObject","_JS_InitStandardClasses","_JS_ResolveStandardClass","__ZL12JSID_IS_ATOMi242","__ZL12ATOM_TO_JSIDP6JSAtom244","__ZN2JSL14UndefinedValueEv245","__ZL13StdNameToAtomP9JSContextP9JSStdName","_JS_EnumerateStandardClasses","__ZN8JSObject14nativeContainsEP9JSContexti","__ZN2js10NewIdArrayEP9JSContexti","_JS_EnumerateResolvedStandardClasses","__ZL19EnumerateIfResolvedP9JSContextP8JSObjectP6JSAtomP9JSIdArrayPiS7_","__ZL14AddAtomToArrayP9JSContextP6JSAtomP9JSIdArrayPi","__ZL16SetIdArrayLengthP9JSContextP9JSIdArrayi","_JS_GetClassObject","_JS_GetScopeChain","_JS_GetGlobalForObject","_JS_GetGlobalForScopeChain","__ZN2jsL22GetGlobalForScopeChainEP9JSContext","_JS_AnchorPtr","_JS_SetGCParameterForThread","_JS_GetGCParameterForThread","_JS_FlushCaches","_JS_FinalizeStub","_JS_CANONICALIZE_NAN","_OBJECT_TO_JSID","__ZN8JSString10asExternalEv","__ZN2jsL8ValueifyEP7JSClass","_JS_SetExtraGCRoots","_JS_IsGCMarkingTracer","_JS_SetGCCallbackRT","__ZN16JSExternalString15changeFinalizerEPFvP9JSContextP8JSStringES5_","__ZNK16JSExternalString15externalClosureEv","_JS_SetThreadStackLimit","_JS_SetNativeStackQuota","__ZNK8JSObject9isNewbornEv","__ZNK8JSObject8slotSpanEv","_JS_ComputeThis","__ZN2js18CallReceiverFromVpEPN2JS5ValueE","_JS_malloc","_JS_realloc","__ZN9JSContext8realloc_EPvj","_JS_free","_JS_updateMallocCounter","_JS_strdup","_JS_NewNumberValue","_JS_AddValueRoot","_JS_AddStringRoot","_JS_AddObjectRoot","_JS_AddGCThingRoot","_JS_AddNamedValueRoot","_JS_AddNamedStringRoot","_JS_AddNamedObjectRoot","_JS_AddNamedScriptRoot","_JS_AddNamedGCThingRoot","_JS_RemoveValueRoot","_JS_RemoveStringRoot","_JS_RemoveObjectRoot","_JS_RemoveScriptRoot","_JS_RemoveGCThingRoot","_JS_MapGCRoots","_JS_LockGCThing","_JS_ReportOutOfMemory","_JS_LockGCThingRT","_JS_UnlockGCThing","_JS_UnlockGCThingRT","_JS_TraceRuntime","_JS_CallTracer","_JS_CompartmentGC","_JS_GC","_JS_MaybeGC","_JS_SetGCCallback","_JS_IsAboutToBeFinalized","_JS_SetGCParameter","__ZN9JSRuntime19setGCMaxMallocBytesEj","_JS_GetGCParameter","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5countEv","_JS_AddExternalStringFinalizer","_JS_RemoveExternalStringFinalizer","_JS_NewExternalString","__ZN16JSExternalString4new_EP9JSContextPKtjiPv","_JS_NewExternalStringWithClosure","_JS_IsExternalString","_JS_GetExternalStringClosure","_JS_DestroyIdArray","_JS_ValueToId","_JS_IdToValue","__ZN2jsL9IdToJsvalEi","_JS_InitClass","_JS_GetClass","__ZNK8JSObject10getJSClassEv","_JS_InstanceOf","_JS_HasInstance","_JS_GetPrivate","_JS_SetPrivate","_JS_GetInstancePrivate","_JS_GetPrototype","_JS_SetPrototype","_JS_GetParent","_JS_SetParent","_JS_GetConstructor","__ZN18JSAutoResolveFlagsC1EP9JSContextj","__ZN18JSAutoResolveFlagsD1Ev","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject246","_JS_GetObjectId","_JS_NewCompartmentAndGlobalObject","__ZN19AutoHoldCompartmentC1EP13JSCompartment","__ZN19AutoHoldCompartmentD1Ev","_JS_NewObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","__ZN2js5types31MarkTypeObjectUnknownPropertiesEP9JSContextPNS0_10TypeObjectEb","_JS_NewObjectWithGivenProto","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_247","_JS_NewObjectForConstructor","_JSVAL_TO_OBJECT","_JS_IsExtensible","_JS_IsNative","_JS_FreezeObject","_JS_DeepFreezeObject","__ZNK2JS5Value11isPrimitiveEv","_JS_ConstructObject","_JS_ConstructObjectWithArguments","_JS_LookupPropertyById","__ZL18LookupPropertyByIdP9JSContextP8JSObjectijPS2_PP10JSProperty","__ZL12LookupResultP9JSContextP8JSObjectS2_iP10JSPropertyPN2JS5ValueE","_JS_LookupElement","__ZN2js9IndexToIdEP9JSContextjPi","_JS_LookupProperty","_JS_LookupUCProperty","_JS_LookupPropertyWithFlagsById","__ZN8JSObject14lookupPropertyEP9JSContextiPPS_PP10JSProperty","_JS_LookupPropertyWithFlags","_JS_HasPropertyById","_JS_HasElement","_JS_HasProperty","_JS_HasUCProperty","_JS_AlreadyHasOwnPropertyById","_JS_AlreadyHasOwnElement","_JS_AlreadyHasOwnProperty","_JS_AlreadyHasOwnUCProperty","_JS_DefinePropertyById","__ZL18DefinePropertyByIdP9JSContextP8JSObjectiRKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ejji","_JS_DefineElement","_JS_DefineProperty","__ZL14DefinePropertyP9JSContextP8JSObjectPKcRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji","_JS_DefinePropertyWithTinyId","_JS_DefineUCProperty","__ZL16DefineUCPropertyP9JSContextP8JSObjectPKtjRKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ejji","_JS_DefineUCPropertyWithTinyId","_JS_DefineOwnProperty","_JS_DefineObject","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_","_JS_DefineConstDoubles","__ZN2JSL11DoubleValueEd","_JS_DefineProperties","_JS_GetPropertyDescriptorById","__ZL25GetPropertyDescriptorByIdP9JSContextP8JSObjectijiP20JSPropertyDescriptor","_JS_GetPropertyAttrsGetterAndSetterById","_JS_GetPropertyAttributes","_JS_GetUCPropertyAttributes","_JS_GetPropertyAttrsGetterAndSetter","_JS_GetUCPropertyAttrsGetterAndSetter","_JS_GetOwnPropertyDescriptor","_JS_SetPropertyAttributes","_INT_TO_JSID250","__ZNK2js5Shape10enumerableEv","_JS_SetRuntimeSecurityCallbacks","_JS_GetRuntimeSecurityCallbacks","_JS_SetContextSecurityCallbacks","_JS_GetSecurityCallbacks","__ZN9JSRuntime20setTrustedPrincipalsEP12JSPrincipals","__ZN8JSScript6upvarsEv","__ZNK2js11UpvarCookie5levelEv","__ZNK2js5Shape5Range5frontEv","__ZN2js5Shape5Range8popFrontEv","_JS_GetFunctionObject","_JS_GetFunctionId","_JS_GetFunctionFlags","_JS_GetFunctionArity","__ZL25SetPropertyAttributesByIdP9JSContextP8JSObjectijPi","_JS_SetUCPropertyAttributes","_JS_GetPropertyById","_JS_GetPropertyByIdDefault","_JS_GetElement","_JS_GetProperty","_JS_GetPropertyDefault","_JS_GetUCProperty","_JS_GetMethodById","_JS_GetMethod","_JS_SetPropertyById","__ZN8JSObject11setPropertyEP9JSContextiPN2JS5ValueEi","_JS_SetElement","_JS_SetProperty","_JS_SetUCProperty","_JS_DeletePropertyById2","_JS_DeleteElement2","_JS_DeleteProperty2","_JS_DeleteUCProperty2","_JS_DeletePropertyById","_JS_DeleteElement","_JS_DeleteProperty","_JS_ClearScope","__ZNK8JSObject8isGlobalEv","_JS_Enumerate","__ZL18prop_iter_finalizeP9JSContextP8JSObject","__ZL15prop_iter_traceP8JSTracerP8JSObject","_JS_NewPropertyIterator","__ZN2js16AutoObjectRooterC1EP9JSContextP8JSObject","__ZN2js16AutoObjectRooterD1Ev","__ZN2JSL10Int32ValueEi251","_JS_NextProperty","_JS_GetReservedSlot","_JS_SetReservedSlot","_JS_NewArrayObject","_JS_IsArrayObject","__ZNK8JSObject7isArrayEv","_JS_GetArrayLength","_JS_SetArrayLength","_JS_CheckAccess","_JS_SetTrustedPrincipals","_JS_NewFunction","_JS_NewFunctionById","__ZL12JSID_TO_ATOMi254","_JS_CloneFunctionObject","__Z19CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectb","__ZNK10JSFunction13isFlatClosureEv","__ZN2js5Shape5RangeC1EPKS0_","__ZNK8JSObject20getFlatClosureUpvarsEv","_JS_ObjectIsFunction","_JS_ObjectIsCallable","__ZNK14AutoVersionAPI7versionEv","_JS_SetErrorReporter","__ZN2js11TokenStream15isUnexpectedEOFEv","_JS_GetObjectFromScript","__ZNK16JSAutoByteString3ptrEv","_JS_SetOperationCallback","_JS_GetOperationCallback","_JS_DefineFunctions","__ZL35js_generic_native_method_dispatcherP9JSContextjPN2JS5ValueE","__ZN2JSL12PrivateValueEPv257","_JS_DefineFunction","_JS_DefineUCFunction","_JS_DefineFunctionById","_JS_CompileUCScriptForPrincipalsVersion","__ZN14AutoVersionAPIC1EP9JSContext9JSVersion","__ZL34CompileUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcj9JSVersion","__ZN14AutoVersionAPID1Ev","_JS_CompileUCScriptForPrincipals","_JS_CompileUCScript","_JS_CompileScriptForPrincipalsVersion","_JS_CompileScriptForPrincipals","_JS_CompileScript","_JS_BufferIsCompilableUnit","_JS_SaveExceptionState","_JS_RestoreExceptionState","_JS_CompileFile","__ZN18AutoLastFrameCheckC1EP9JSContext","__ZL17CompileFileHelperP9JSContextP8JSObjectP12JSPrincipalsPKcP7__sFILE","__ZN18AutoLastFrameCheckD1Ev","_JS_CompileFileHandleForPrincipals","_JS_CompileFileHandleForPrincipalsVersion","_JS_CompileFileHandle","_JS_CompileUCFunctionForPrincipalsVersion","__ZL36CompileUCFunctionForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKcjPS6_PKtjS6_j9JSVersion","_JS_CompileUCFunctionForPrincipals","_JS_CompileUCFunction","_JS_CompileFunctionForPrincipals","_JS_CompileFunction","_JS_DecompileScript","_JS_DecompileFunction","_JS_DecompileFunctionBody","_JS_ExecuteScript","_JS_ExecuteScriptVersion","__Z35EvaluateUCScriptForPrincipalsCommonP9JSContextP8JSObjectP12JSPrincipalsPKtjPKcjPN2JS5ValueE9JSVersion","_JS_EvaluateUCScriptForPrincipalsVersion","_JS_EvaluateUCScriptForPrincipals","_JS_EvaluateUCScript","_JS_EvaluateScriptForPrincipals","_JS_EvaluateScriptForPrincipalsVersion","_JS_EvaluateScript","_JS_CallFunction","__ZN2JSL17ObjectOrNullValueEP8JSObject258","_JS_CallFunctionName","_JS_CallFunctionValue","__ZN2JS4CallEP9JSContextNS_5ValueES2_jPS2_S3_","_JS_New","__ZN2js15InvokeArgsGuardC1Ev","__ZN2js17InvokeConstructorEP9JSContextRNS_15InvokeArgsGuardE","__ZN2js15InvokeArgsGuardD1Ev","_JS_TriggerOperationCallback","_JS_TriggerAllOperationCallbacks","_JS_IsRunning","__ZNK9JSContext7maybefpEv","_JS_SaveFrameChain","_JS_SetCStringsAreUTF8","_JS_CStringsAreUTF8","__ZNK8JSString6isAtomEv","__ZN27JSAutoStructuredCloneBuffer5stealEPPyPjS2_","__ZN27JSAutoStructuredCloneBuffer4swapERS_","_JS_SetStructuredCloneCallbacks","__ZN23JSStructuredCloneReader5inputEv","__ZN23JSStructuredCloneWriter6outputEv","__ZNK8JSObject6isDateEv","_JS_RestoreFrameChain","_JS_NewStringCopyN","_JS_NewStringCopyZ","_JS_StringHasBeenInterned","_JS_InternJSString","_JS_InternString","_JS_NewUCString","_JS_NewUCStringCopyN","_JS_NewUCStringCopyZ","_JS_InternUCStringN","_JS_InternUCString","_JS_GetStringLength","_JS_GetStringCharsZ","_JS_GetStringCharsZAndLength","_JS_GetStringCharsAndLength","_JS_GetInternedStringChars","_JS_GetInternedStringCharsAndLength","_JS_FlattenString","_JS_GetFlatStringChars","_JS_CompareStrings","_JS_StringEqualsAscii","_JS_FlatStringEqualsAscii","_JS_PutEscapedFlatString","__ZN2js16PutEscapedStringEPcjP14JSLinearStringj","_JS_PutEscapedString","_JS_FileEscapedString","__ZN2js17FileEscapedStringEP7__sFILEP14JSLinearStringj","_JS_NewGrowableString","_JS_NewDependentString","_JS_ConcatStrings","_JS_UndependString","_JS_MakeStringImmutable","_JS_EncodeCharacters","_JS_DecodeBytes","_JS_DecodeUTF8","_JS_EncodeString","_JS_GetStringEncodingLength","_JS_EncodeStringToBuffer","__ZN2jsL7PodZeroIcEEvPT_j","_JS_Stringify","__ZN2js12StringBufferC1EP9JSContext","__ZNK2js12StringBuffer5emptyEv","__ZN2js12StringBuffer5beginEv","__ZNK2js12StringBuffer6lengthEv","__ZN2js12StringBufferD1Ev","_JS_ParseJSON","__ZN2JSL9NullValueEv259","_JS_ParseJSONWithReviver","_JS_ReadStructuredClone","_JS_WriteStructuredClone","_JS_StructuredClone","__ZN27JSAutoStructuredCloneBufferC1Ev","__ZN27JSAutoStructuredCloneBuffer5writeEP9JSContextN2JS5ValueEPK26JSStructuredCloneCallbacksPv","__ZNK27JSAutoStructuredCloneBuffer4readEP9JSContextPN2JS5ValueEPK26JSStructuredCloneCallbacksPv","__ZN27JSAutoStructuredCloneBufferD1Ev","__ZN27JSAutoStructuredCloneBuffer5clearEv","__ZN27JSAutoStructuredCloneBuffer5adoptEPyjj","__ZN27JSAutoStructuredCloneBuffer4copyEPKyjj","_JS_ReadUint32Pair","_JS_ReadBytes","_JS_WriteUint32Pair","_JS_WriteBytes","_JS_ReportError","_JS_ReportErrorNumberUC","_JS_ReportWarning","_JS_ReportErrorFlagsAndNumber","_JS_ReportErrorFlagsAndNumberUC","_JS_ReportAllocationOverflow","_JS_NewDateObject","_JS_NewDateObjectMsec","_JS_ObjectIsDate","_JS_NewRegExpObject","__ZN2js6RegExp12createObjectEP9JSContextPNS_13RegExpStaticsEPKtjjPNS_11TokenStreamE","_JS_NewUCRegExpObject","_JS_SetRegExpInput","__ZN2js13RegExpStatics5resetEP8JSStringb","_JS_ClearRegExpStatics","_JS_ExecuteRegExp","__ZN2js6RegExp11extractFromEP8JSObject","__ZN2js6RegExp7executeEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE","_JS_NewRegExpObjectNoStatics","__ZN2js6RegExp21createObjectNoStaticsEP9JSContextPKtjjPNS_11TokenStreamE","_JS_NewUCRegExpObjectNoStatics","_JS_ExecuteRegExpNoStatics","__ZN2js6RegExp16executeNoStaticsEP9JSContextP8JSStringPjbPN2JS5ValueE","_JS_ObjectIsRegExp","_JS_GetContextThread","_JS_SetContextThread","_JS_ClearContextThread","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10isLiveHashEj","__ZNK8JSObject8isRegExpEv","__ZNK2js6RegExp8getFlagsEv","__ZNK2js6RegExp9getSourceEv","_JS_SetLocaleCallbacks","_JS_GetLocaleCallbacks","__ZN2js2gcL15GetGCObjectKindEjb264","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5countEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEptEv","__ZN2js12HashMapEntryIN2JS5ValueES2_EC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12setCollisionEj","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S2_EE","_JS_GetRegExpFlags","_JS_GetRegExpSource","_JS_IsExceptionPending","_JS_GetPendingException","_JS_SetPendingException","_JS_ClearPendingException","_JS_ReportPendingException","_JSVAL_IS_GCTHING","_JS_DropExceptionState","_JS_ErrorFromException","_JS_ThrowReportedError","_JS_ThrowStopIteration","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE267","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE271","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S2_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_SF_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","_js_free272","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES5_EEEEEC1ERS7_","__ZN2js12HashMapEntryIN2JS5ValueES2_EaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIN2JS5ValueES3_EEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIN2JS5ValueES3_EEEC1ERS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEEC2Ev","__ZN2js12HashMapEntryIN2JS5ValueES2_EC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js13WrapperHasher5matchERKN2JS5ValueES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","_JSVAL_IS_GCTHING_IMPL","__ZNK2JS5Value9asRawBitsEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE12hasCollisionEv","__ZN2js12HashMapEntryIN2JS5ValueES2_EaSERKS3_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZL13JSVAL_TO_IMPLN2JS5ValueE","__ZNK2js6RegExp6stickyEv","_STRING_TO_JSVAL_IMPL277","__ZN2js18RegExpMatchBuilderC2EP9JSContextP8JSObject","_BOOLEAN_TO_JSVAL_IMPL278","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE8shrinkByEj","__ZN2js13WrapperHasher4hashEN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE16infallibleAppendERKS2_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7reserveEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIN2JS5ValueES4_EEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","_js_realloc274","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEED2Ev","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_EC1ES7_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js6RegExp15executeInternalEP9JSContextPNS_13RegExpStaticsEP8JSStringPjbPN2JS5ValueE","__ZN2js6RegExp9initArenaEP9JSContext","__ZN2js18AutoArenaAllocatorC1EP11JSArenaPool","__ZN2js18AutoArenaAllocator5allocIiEEPT_j","__ZN2js13RegExpStatics15updateFromMatchEP9JSContextP14JSLinearStringPij","__ZN2JSL12BooleanValueEb275","__ZN2js6RegExp12createResultEP9JSContextP8JSStringPij","__ZN2js18AutoArenaAllocatorD1Ev","__ZN2js18AutoArenaAllocatorD2Ev","__ZN2js18RegExpMatchBuilderC1EP9JSContextP8JSObject","__ZN2js18RegExpMatchBuilder6appendEjN2JS5ValueE","__ZN2JSL11StringValueEP8JSString276","__ZN2js18RegExpMatchBuilder8setIndexEi","__ZN2js18RegExpMatchBuilder8setInputEP8JSString","__ZN2js18RegExpMatchBuilder11setPropertyEP6JSAtomN2JS5ValueE","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19resizeUninitializedEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE10growByImplILb0EEEbj","__ZNK7mozilla14AlignedStorageILj80EE4addrEv","__ZN2js18AutoArenaAllocatorC2EP11JSArenaPool","__ZNK2js15AlreadyIncRefedINS_6RegExpEEcvPPPPPS1_Ev","__ZNK2js15AlreadyIncRefedINS_6RegExpEE3getEv","__ZNK2js15AlreadyIncRefedINS_6RegExpEEptEv","__ZN8JSObject15setLastPropertyEPKN2js5ShapeE","__ZNK2js6RegExp6globalEv","__ZNK2js6RegExp10ignoreCaseEv","__ZNK2js6RegExp9multilineEv","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE12beginNoCheckEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE11allocPolicyEv","__ZNK2js18ContextAllocPolicy7contextEv","__ZN2js6RegExpC2EP14JSLinearStringjP13JSCompartment","__ZN2js15AlreadyIncRefedINS_6RegExpEEC2EPS1_","__ZNK2js13RegExpStatics8getFlagsEv","__ZN27JSAutoStructuredCloneBufferC2Ev","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE6lengthEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5beginEv","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE5emptyEv","__ZN2js18ContextAllocPolicyC2EP9JSContext","__ZNK2js15InvokeArgsGuard6pushedEv","__ZN2js12CallArgsList9setActiveEv","__ZN2js12CallArgsList11setInactiveEv","_OBJECT_TO_JSVAL_IMPL284","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIiLj20ES1_EEj","__ZN2js10VectorImplIiLj20ENS_17SystemAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_","__ZN2js6RegExp6createEP9JSContextP8JSStringjPNS_11TokenStreamE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE279","__ZN8JSObject10initRegExpEP9JSContextPN2js6RegExpE","__ZN2js6RegExp6decrefEP9JSContext","__ZN9JSContext7delete_IN2js6RegExpEEEvPT_","__ZN2js6RegExpD1Ev","__ZN2js6RegExpD2Ev","__ZN8JSObject19zeroRegExpLastIndexEv","__ZN8JSObject15setRegExpSourceEP8JSString","__ZN8JSObject15setRegExpGlobalEb","__ZN8JSObject19setRegExpIgnoreCaseEb","__ZN8JSObject18setRegExpMultilineEb","__ZN8JSObject15setRegExpStickyEb","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE280","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE281","__ZN2js15AlreadyIncRefedINS_6RegExpEEC1EPS1_","__ZN9JSContext4new_IN2js6RegExpEP14JSLinearStringjP13JSCompartmentEEPT_T0_T1_T2_","__ZN2js6RegExp7compileEP9JSContextPNS_11TokenStreamE","__ZN2js10Foreground7delete_INS_6RegExpEEEvPT_","__ZN2js6RegExp13compileHelperEP9JSContextR14JSLinearStringPNS_11TokenStreamE","__ZN2js12StringBuffer7reserveEj","__ZN2js12StringBuffer16infallibleAppendEPKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvPKT_j","__ZN2js12StringBuffer11checkLengthEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7reserveEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE13growStorageByEj","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj","__ZN2js18ContextAllocPolicy8realloc_EPvjj","__ZN9JSContext8realloc_EPvjj","__ZN9JSRuntime8realloc_EPvjjP9JSContext","__ZNK2js18ContextAllocPolicy19reportAllocOverflowEv","__ZN2js18ContextAllocPolicy7malloc_Ej","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2jsL17CheckStringLengthEP9JSContextj","__ZNK2js12StringBuffer7contextEv","__ZN2js6RegExpC1EP14JSLinearStringjP13JSCompartment","__ZN2js13RegExpStatics12setMultilineEb","__ZN27JSAutoStructuredCloneBufferD2Ev","__ZN2js12StringBufferD2Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED1Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEED2Ev","__ZN2js18ContextAllocPolicy5free_EPv","__ZN2js12StringBufferC2EP9JSContext","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC1ES1_","__ZN2js18ContextAllocPolicyC1EP9JSContext","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEEC2ES1_","__ZN2js15InvokeArgsGuardD2Ev","__ZL14JSID_FROM_BITSj300","_JSID_IS_INT292","_JSID_IS_STRING293","_JSVAL_IS_PRIMITIVE_IMPL","_JSVAL_TO_OBJECT_IMPL296","_JSID_TO_INT297","_JSID_IS_OBJECT","_JSID_TO_OBJECT298","__ZN2jsL13VersionSetXMLEP9JSVersionb","__ZN2jsL13OptionsHasXMLEj","__ZN2jsL13VersionHasXMLE9JSVersion","__ZN2jsL19VersionExtractFlagsE9JSVersion","_JSVAL_IS_INT32_IMPL","__ZN2jsL8JsvalifyEPNS_5ClassE","__ZL18JSDOUBLE_IS_FINITEd","_JSDOUBLE_IS_NEGZERO301","__ZL15JSDOUBLE_IS_NaNd","__ZNK9JSContext12hasRunOptionEj","__ZN18AutoLastFrameCheckC2EP9JSContext","__ZN9JSContext17setDefaultVersionE9JSVersion","__ZN9JSContext15overrideVersionE9JSVersion","__ZNK9JSContext17getDefaultVersionEv","__ZN2js5Shape5RangeC2EPKS0_","__ZNK8JSObject11isSlowArrayEv","__ZNK2js5Shape10attributesEv","__ZNK2js5Shape8isMethodEv","__ZNK2js5Shape12methodObjectEv","__ZNK2js5Shape6getterEv","__ZNK2js5Shape6setterEv","__ZN19AutoHoldCompartmentD2Ev","__ZN19AutoHoldCompartmentC2EP13JSCompartment","__ZN18JSAutoResolveFlagsD2Ev","__ZN18JSAutoResolveFlagsC2EP9JSContextj","__ZN9JSRuntime18resetGCMallocBytesEv","__ZNK2js5Shape8hasTableEv","__ZNK2js5Shape8getTableEv","__ZN9JSContext13setRunOptionsEj","__ZNK9JSContext13getRunOptionsEv","__ZN2js13StaticStringsC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN16JSAutoByteStringC2Ev","__ZN12JSValueArrayC2EPN2JS5ValueEj","_JS_InitArenaPool","__ZN2js15InvokeArgsGuardC2Ev","__ZN2js8BindingsC1EP9JSContext","__ZN2js8Bindings11addArgumentEP9JSContextP6JSAtomPt","__ZN2js8BindingsC2EP9JSContext","__ZN18AutoLastFrameCheckD2Ev","__ZL21JS_OPTIONS_TO_TCFLAGSP9JSContext","__ZN14AutoVersionAPID2Ev","__ZN14AutoVersionAPIC2EP9JSContext9JSVersion","__ZNK8JSObject12getFixedSlotEj","__ZN2js16AutoObjectRooterD2Ev","__ZN2js16AutoObjectRooterC2EP9JSContextP8JSObject","__ZN8JSObject13setAttributesEP9JSContextiPj","__ZNK8JSObject12containsSlotEj","__ZNK8JSObject13nativeGetSlotEj","__ZN8JSObject13getAttributesEP9JSContextiPj","__ZN8JSObject17methodReadBarrierEP9JSContextRKN2js5ShapeEPN2JS5ValueE","__Z19CloneFunctionObjectP9JSContextP10JSFunction","__ZN8JSObject12setMethodObjERS_","__ZN8JSObject13nativeSetSlotEjRKN2JS5ValueE","__ZN2jsL9IdToValueEi","__Z22js_NewGCExternalStringP9JSContext","__ZN16JSExternalString4initEPKtjiPv","__Z10NewGCThingI16JSExternalStringEPT_P9JSContextN2js2gc9AllocKindEj","__ZN9JSRuntime8realloc_EPvjP9JSContext","_js_calloc299","__ZN8JSObject12nativeLookupEP9JSContexti","__ZN8JSObject12nativeSearchEP9JSContextib","__ZN2js5Shape6searchEP9JSContextPPS0_ib","__ZN9JSContext17setCompileOptionsEj","__ZNK9JSContext17getCompileOptionsEv","__ZN2jsL20OptionFlagsToVersionEj9JSVersion","__ZN2jsL21VersionFlagsToOptionsE9JSVersion","__ZNK9JSContext20canSetDefaultVersionEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZN11JSAtomStateD2Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS5_EEj","__ZN11JSAtomStateC2Ev","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZNK2JS5Value7isInt32Ev","__ZN2js15AutoValueRooterD2Ev","__ZN2js15AutoValueRooterC2EP9JSContextRKN2JS5ValueE","__ZN16JSAutoByteStringD2Ev","__ZN16JSAutoByteString6encodeEP9JSContextP8JSString","__GLOBAL__I_a","_JS_ArenaAllocate","_JS_ArenaFinish","_JS_ArenaShutDown","__ZN8JSObject11asArgumentsEv","__ZN2js15AutoValueRooter4addrEv","__ZN8JSObject30getDenseArrayInitializedLengthEv","__ZN8JSObject21getDenseArrayElementsEv","__ZN8JSObject20getDenseArrayElementEj","__ZNK8JSObject9isIndexedEv","_JS_ArenaRealloc","__ZN2js11OffTheBooks8realloc_EPvj","_JS_ArenaGrow","_JS_ArenaRelease","__ZL13FreeArenaListP11JSArenaPoolP7JSArena","_JS_FreeArenaPool","_JS_FinishArenaPool","_js_realloc311","__Z20js_GetLengthPropertyP9JSContextP8JSObjectPj","__ZNK8JSObject14getArrayLengthEv","__ZNK8JSObject11isArgumentsEv","__ZNK2js15ArgumentsObject19hasOverriddenLengthEv","__ZN2js15AutoValueRooterC1EP9JSContext","__ZN2js18StringIsArrayIndexEP14JSLinearStringPj","__ZN8JSObject22willBeSparseDenseArrayEjj","__ZNK2JS5Value7isMagicE10JSWhyMagic","__ZN8JSObject22arrayGetOwnDataElementEP9JSContextjPN2JS5ValueE","__ZL9IndexToIdP9JSContextP8JSObjectdPiS3_i","__ZN2js11GetElementsEP9JSContextP8JSObjectjPN2JS5ValueE","__Z32js_PrototypeHasIndexedPropertiesP9JSContextP8JSObject","__ZN2JSL14UndefinedValueEv351","__ZN2js15ArgumentsObject11getElementsEjjPN2JS5ValueE","__ZN2jsL15GetElementsSlowEP9JSContextP8JSObjectjPN2JS5ValueE","__Z20js_SetLengthPropertyP9JSContextP8JSObjectd","__ZL12ATOM_TO_JSIDP6JSAtom354","__Z28js_GetDenseArrayElementValueP9JSContextP8JSObjectiPN2JS5ValueE","__Z12js_IdIsIndexiPj","__ZN2js20array_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej","__ZL12JSID_IS_ATOMiP6JSAtom","__ZN8JSObject24ensureDenseArrayElementsEP9JSContextjj","__ZN8JSObject19setDenseArrayLengthEj","__ZN8JSObject28setDenseArrayElementWithTypeEP9JSContextjRKN2JS5ValueE","__ZL26array_getElementAttributesP9JSContextP8JSObjectjPj","__ZL12array_typeOfP9JSContextP8JSObject","__ZN8JSObject18makeDenseArraySlowEP9JSContext","__ZN2js19array_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ej","__ZN2js20array_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2JSL10MagicValueE10JSWhyMagic","__ZN2js19array_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL11array_traceP8JSTracerP8JSObject","__ZL20array_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL19array_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL19array_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL19array_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL16array_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL17array_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL16array_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL16array_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL17array_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL16array_setElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL16array_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL19array_getAttributesP9JSContextP8JSObjectiPj","__ZL26array_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19array_setAttributesP9JSContextP8JSObjectiPj","__ZL26array_setElementAttributesP9JSContextP8JSObjectjPj","__ZL26array_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19array_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL9array_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL21slowarray_addPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE359","__ZN8JSObject23backfillDenseArrayHolesEP9JSContext","__ZN8JSObject21getDenseArrayCapacityEv","__ZNK8JSObject24denseArrayHasInlineSlotsEv","__ZN2js14AutoValueArrayC1EP9JSContextPN2JS5ValueEj","__ZL17AddLengthPropertyP9JSContextP8JSObject","__ZN2JSL10Int32ValueEi360","__ZN2js14AutoValueArrayD1Ev","__ZN2js15AutoArrayRooter12changeLengthEj","__Z12js_MergeSortPvjjPFiS_PKvS1_PiES_S_19JSMergeSortElemType","__ZL11MergeArraysP9MSortArgsPvS1_jj","__ZN2js10array_sortEP9JSContextjPN2JS5ValueE","__ZN2js15AutoArrayRooterC1EP9JSContextjPN2JS5ValueE","__ZL10GetElementP9JSContextP8JSObjectdPiPN2JS5ValueE","__ZN2jsL15MakeRangeGCSafeEPN2JS5ValueEj","__ZN2js15AutoArrayRooter11changeArrayEPN2JS5ValueEj","__ZL20sort_compare_stringsPvPKvS1_Pi","__ZN11CompareArgsC1EP9JSContextN2JS5ValueE","__ZL12sort_comparePvPKvS1_Pi","__ZN11CompareArgsD1Ev","__ZL17InitArrayElementsP9JSContextP8JSObjectjjPN2JS5ValueEb","__ZN2js15AutoArrayRooterD1Ev","__ZL15SetArrayElementP9JSContextP8JSObjectdRKN2JS5ValueE","__ZL18DeleteArrayElementP9JSContextP8JSObjectdb","__Z19js_NewbornArrayPushP9JSContextP8JSObjectRKN2JS5ValueE","__Z20NewbornArrayPushImplP9JSContextP8JSObjectRKN2JS5ValueE","__ZN2js10array_pushEP9JSContextjPN2JS5ValueE","__ZL17array_push_slowlyP9JSContextP8JSObjectjPN2JS5ValueES5_","__ZL17array_push1_denseP9JSContextP8JSObjectRKN2JS5ValueEPS4_","__ZN2js9array_popEP9JSContextjPN2JS5ValueE","__ZL15array_pop_denseP9JSContextP8JSObjectPN2JS5ValueE","__ZL16array_pop_slowlyP9JSContextP8JSObjectPN2JS5ValueE","__ZL14array_toSourceP9JSContextjPN2JS5ValueE","__ZL14array_toStringP9JSContextjPN2JS5ValueE","__ZL20array_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL10array_joinP9JSContextjPN2JS5ValueE","__ZL13array_reverseP9JSContextjPN2JS5ValueE","__ZL11array_shiftP9JSContextjPN2JS5ValueE","__ZL13array_unshiftP9JSContextjPN2JS5ValueE","__ZL12array_spliceP9JSContextjPN2JS5ValueE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE382","__ZN8JSObject30setDenseArrayInitializedLengthEj","__ZN2js2gcL15GetGCObjectKindEjb374","__ZL12array_concatP9JSContextjPN2JS5ValueE","__ZL11array_sliceP9JSContextjPN2JS5ValueE","__ZL13array_indexOfP9JSContextjPN2JS5ValueE","__ZL17array_lastIndexOfP9JSContextjPN2JS5ValueE","__ZL13array_forEachP9JSContextjPN2JS5ValueE","__ZL9array_mapP9JSContextjPN2JS5ValueE","__ZL12array_reduceP9JSContextjPN2JS5ValueE","__ZL17array_reduceRightP9JSContextjPN2JS5ValueE","__ZL12array_filterP9JSContextjPN2JS5ValueE","__ZL10array_someP9JSContextjPN2JS5ValueE","__ZL11array_everyP9JSContextjPN2JS5ValueE","__ZL13array_isArrayP9JSContextjPN2JS5ValueE","__Z8js_ArrayP9JSContextjPN2JS5ValueE","__ZN2js5types23GetTypeCallerInitObjectEP9JSContext10JSProtoKey","__ZL14InitArrayTypesP9JSContextPN2js5types10TypeObjectEPKN2JS5ValueEj","__ZN2js18NewDenseEmptyArrayEP9JSContextP8JSObject","__ZN2js19NewDenseCopiedArrayEP9JSContextjPKN2JS5ValueEP8JSObject","__ZN2js24NewDenseUnallocatedArrayEP9JSContextjP8JSObject","__ZN8JSObject14setArrayLengthEP9JSContextj","__Z17js_InitArrayClassP9JSContextP8JSObject","__ZN2js29DefineConstructorAndPrototypeEP9JSContextPNS_12GlobalObjectE10JSProtoKeyP8JSObjectS6_","__ZN2jsL8NewArrayILb0EEEP8JSObjectP9JSContextjS2_","__ZN2js22NewDenseAllocatedArrayEP9JSContextjP8JSObject","__ZN2jsL8NewArrayILb1EEEP8JSObjectP9JSContextjS2_","__ZN2js27NewDenseAllocatedEmptyArrayEP9JSContextjP8JSObject","__ZN8JSObject22copyDenseArrayElementsEjPKN2JS5ValueEj","__ZN2js17NewSlowEmptyArrayEP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_373","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE375","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_376","__ZN2jsL17GuessObjectGCKindEjb","__ZN8JSObject11ensureSlotsEP9JSContextj","__ZN2JSL11ObjectValueER8JSObject383","__ZN2js5types17AddTypePropertyIdEP9JSContextP8JSObjectiRKN2JS5ValueE","__ZN2js5types13TypeObjectKey6getKeyEPS1_","_JSID_IS_INT387","_JSID_IS_STRING388","__ZN2js5types17PrimitiveTypeFlagE11JSValueType","__ZN2js5types13TypeObjectKey7keyBitsEPS1_","_JSVAL_EXTRACT_NON_DOUBLE_TYPE_IMPL","__ZNK2js5types7TypeSet7unknownEv","__ZNK2js5types4Type9isUnknownEv","__ZNK2js5types7TypeSet9baseFlagsEv","__ZNK2js5types4Type11isPrimitiveEv","__ZNK2js5types4Type9primitiveEv","__ZNK2js5types4Type11isAnyObjectEv","__ZNK2js5types7TypeSet15baseObjectCountEv","__ZNK2js5types4Type9objectKeyEv","__ZN2js5types7TypeSet18setBaseObjectCountEj","__ZNK2js5types4Type10typeObjectEv","__ZNK2js5types4Type8isObjectEv","__ZN2js5types10TypeObject20setBasePropertyCountEj","__ZN2js5typesL15HashSetCapacityEj385","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_386","__ZN2js5types4Type10DoubleTypeEv","__ZN2js5types22AutoEnterTypeInferenceC1EP9JSContextb","__ZN2js5types10TypeObject11getPropertyEP9JSContextib","__ZN2js5types12GetValueTypeEP9JSContextRKN2JS5ValueE","__ZN2js5types7TypeSet7addTypeEP9JSContextNS0_4TypeE","__ZN2js5types22AutoEnterTypeInferenceD1Ev","__ZN2js5types22AutoEnterTypeInferenceD2Ev","__ZN2js5types7TypeSet12clearObjectsEv","__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_","__ZNK2js5types4Type12isTypeObjectEv","__ZN2js5types4Type13AnyObjectTypeEv","__ZN2js5types15TypeCompartment10addPendingEP9JSContextPNS0_14TypeConstraintEPNS0_7TypeSetENS0_4TypeE","__ZN2js5types15TypeCompartment14resolvePendingEP9JSContext","__ZN2js10ArenaArrayIPNS_5types13TypeObjectKeyEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j","__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_","__ZN2js5types4Type10ObjectTypeEP8JSObject","__ZN2js5types4Type13PrimitiveTypeE11JSValueType","__ZNK2JS5Value20extractNonDoubleTypeEv","__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_","__ZN2js5types4Type11UnknownTypeEv","__ZN2js5types7TypeSet14setOwnPropertyEP9JSContextb","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js5types22AutoEnterTypeInferenceC2EP9JSContextb","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEj","__ZN2js5types17AllocationSiteKey5matchERKS1_S3_","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js5types17AllocationSiteKey4hashES1_","__ZN2jsL7PodZeroINS_5types17AllocationSiteKeyEEEvPT_","__ZN2js10ArenaArrayIPNS_5types8PropertyEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j","__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_","__ZNK2js12ContextStack13currentScriptEPPh","__ZN2js5types10TypeScript10InitObjectEP9JSContextP8JSScriptPKh10JSProtoKey","__ZN2js5types16GetTypeNewObjectEP9JSContext10JSProtoKey","__ZNK8JSScript9hasGlobalEv","__ZN2js5types17AllocationSiteKeyC1Ev","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js5types17AllocationSiteKeyC2Ev","__ZNK2js12GlobalObject9isClearedEv","__ZL11array_extraP9JSContext14ArrayExtraModejPN2JS5ValueE","__ZN2js6InvokeEP9JSContextRNS_15InvokeArgsGuardENS_14MaybeConstructE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","_INT_TO_JSID398","__ZN2jsL3MinIjEET_S1_S1_","__ZN2js6detail14HashTableEntryIKP8JSObjectE10isLiveHashEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZL18JSDOUBLE_IS_FINITEd396","__ZL15JSDOUBLE_IS_NaNd397","__ZN8JSObject18isPackedDenseArrayEv","__ZN22AutoArrayCycleDetector10foundCycleEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE6isFreeEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE9matchHashEj","__ZNK2js6detail14HashTableEntryIKP8JSObjectE9isRemovedEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZL19array_indexOfHelperP9JSContextijPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd","__ZL18js_DoubleToIntegerd395","__ZL17TryReuseArrayTypeP8JSObjectS0_","__ZL15InitArrayObjectP9JSContextP8JSObjectjPKN2JS5ValueE","__ZN8JSObject22moveDenseArrayElementsEjjj","__ZL23SetOrDeleteArrayElementP9JSContextP8JSObjectdiRKN2JS5ValueE","__ZL18array_toString_subP9JSContextP8JSObjectiP8JSStringPN2JS5ValueE","__ZN22AutoArrayCycleDetectorC1EP9JSContextP8JSObject","__ZN22AutoArrayCycleDetector4initEv","__ZN2js19ValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer6appendEPKtj","__ZN22AutoArrayCycleDetectorD1Ev","__ZN22AutoArrayCycleDetectorD2Ev","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE10generationEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6removeERKS2_","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE6isLiveEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","_JSID_IS_VOID","_JSVAL_IS_SPECIFIC_BOOLEAN407","__ZN2JS5Value12getDoubleRefEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKP8JSObjectE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKP8JSObjectE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEptEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE12setCollisionEv","__ZN2js6detail14HashTableEntryIKP8JSObjectEC2Ev","__ZNK2js6detail14HashTableEntryIKP8JSObjectE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE10setRemovedEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE7setFreeEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10generationEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN2js6detail14HashTableEntryIKP8JSObjectE7setLiveEj","__ZN22AutoArrayCycleDetectorC2EP9JSContextP8JSObject","__ZNK18ArraySharpDetector14initiallySharpEv","__ZN18ArraySharpDetector14takeSharpCharsEv","__ZNK18ArraySharpDetector13hasSharpCharsEv","__ZN18ArraySharpDetector9makeSharpEv","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_","__ZN18ArraySharpDetectorC2EP9JSContext","__ZN2js12AutoIdRooter4addrEv","__ZN2js12AutoIdRooter2idEv","__ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorC2ES1_RS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKP8JSObjectEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKP8JSObjectEEEENS_7MoveRefIT_EERS8_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryIKP8JSObjectEEEC1ERS6_","__ZN2js6detail14HashTableEntryIKP8JSObjectEC1Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbPKT_S6_","__ZN2js12StringBuffer6appendEP8JSString","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZL13js_IsCallableRKN2JS5ValueE405","__ZN18ArraySharpDetectorC1EP9JSContext","__ZN18ArraySharpDetector4initEP8JSObject","__ZN2js12StringBuffer16replaceRawBufferEPtj","__ZN2js12StringBuffer6appendEt","__ZN2js12StringBuffer6appendILj3EEEbRAT__Kc","__ZN2JSL11StringValueEP8JSString406","__ZN18ArraySharpDetectorD1Ev","__ZN18ArraySharpDetectorD2Ev","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbPKT_S6_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvPKT_j","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendItEEbT_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendItEEvT_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16replaceRawBufferEPtj","__ZN2js12AutoIdRooterC1EP9JSContexti","__ZNK2JS5Value6isTrueEv","__ZN2js12AutoIdRooterD1Ev","__ZN2js12AutoIdRooterD2Ev","__ZN2js12AutoIdRooterC2EP9JSContexti","__ZZN2js10array_sortEP9JSContextjPN2JS5ValueEEN14AutoFreeVectorD2Ev","__ZN2js15AutoArrayRooterD2Ev","__ZN2JSL11DoubleValueEd408","__Z18js_ValueToStringIdP9JSContextRKN2JS5ValueEPi","__Z14js_ValueToAtomP9JSContextRKN2JS5ValueEPP6JSAtom","__ZN11CompareArgsD2Ev","__ZN11CompareArgsC2EP9JSContextN2JS5ValueE","__ZN2jsL7PodZeroIN2JS5ValueEEEvPT_j412","__ZN2js15ArgumentsObject10getElementEjPN2JS5ValueE","__ZNK2js15ArgumentsObject7elementEj","__ZNK2js15ArgumentsObject7onTraceEv","__ZNK2js15ArgumentsObject15maybeStackFrameEv","__ZNK2js15ArgumentsObject4dataEv","__ZN2js15AutoArrayRooterC2EP9JSContextjPN2JS5ValueE","__ZN2js14AutoValueArrayD2Ev","__ZL19array_length_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE","__ZL14JSID_FROM_BITSj423","__ZN11JSAtomState21checkStaticInvariantsEv","_JSID_TO_INT420","_JSID_TO_STRING422","_JSVAL_IS_MAGIC_IMPL","__ZNK2js10StackFrame13formalArgsEndEv","__ZN6JSAtom14asPropertyNameEv","__ZN2js6detail17CopyNonHoleArgsToC2EPNS_15ArgumentsObjectEPN2JS5ValueE","__ZNK8JSObject17isStrictArgumentsEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZNK2js18TaggedPointerEntryI6JSAtomE5asPtrEv","__ZN11JSAtomState16commonAtomsStartEv","__Z20js_FinishCommonAtomsP9JSContext","__ZNK2js18TaggedPointerEntryI6JSAtomE8isTaggedEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrptEv","__ZNK2js18TaggedPointerEntryI6JSAtomE9setTaggedEb","__ZL19array_length_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject24shrinkDenseArrayElementsEP9JSContextj","__ZN2js14AutoValueArrayC2EP9JSContextPN2JS5ValueEj","__Z13js_GetElementP9JSContextP8JSObjectjPN2JS5ValueE","__Z14js_GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17IsDenseArrayIndexP8JSObjectj","__ZN8JSObject13lookupElementEP9JSContextjPPS_PP10JSProperty","__ZL14IsDenseArrayIdP9JSContextP8JSObjecti","__ZL12JSID_TO_ATOMi421","__ZN8JSObject10getElementEP9JSContextjPN2JS5ValueE","__ZNK2js15ArgumentsObject8elementsEv","__ZN2js10StackFrame25forEachCanonicalActualArgINS_6detail17CopyNonHoleArgsToEEEbT_jj","__ZN2js6detail17CopyNonHoleArgsToC1EPNS_15ArgumentsObjectEPN2JS5ValueE","__ZN2js6detail17CopyNonHoleArgsToclEjPN2JS5ValueE","__ZL12BigIndexToIdP9JSContextP8JSObjectjiPi","__ZL18ReallyBigIndexToIdP9JSContextdPi","__ZN2js15AutoValueRooterC2EP9JSContext","__ZN2JSL9NullValueEv429","__Z24js_AtomToPrintableStringP9JSContextP6JSAtomP16JSAutoByteString","__ZN2JSL11StringValueEP8JSString478","__Z16js_InitAtomStateP9JSRuntime","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE4initEj","__Z18js_FinishAtomStateP9JSRuntime","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE11initializedEv","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE3allEv","__ZN6JSAtom8finalizeEP9JSRuntime","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__Z18js_InitCommonAtomsP9JSContext","__Z10js_AtomizeP9JSContextPKcjN2js14InternBehaviorENS3_13FlationCodingE","__ZN11JSAtomState14clearLazyAtomsEv","__Z17js_TraceAtomStateP8JSTracer","__ZN2js18TaggedPointerEntryI6JSAtomEC1ERKS2_","__Z17js_SweepAtomStateP9JSContext","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4Enum11removeFrontEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD1Ev","__Z14AtomIsInternedP9JSContextP6JSAtom","__ZN2js24AutoLockAtomsCompartmentC1EP9JSContext","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6lookupERKNS4_6LookupE","__ZN2js10AtomHasher6LookupC1EPK6JSAtom","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__Z16js_AtomizeStringP9JSContextP8JSStringN2js14InternBehaviorE","__ZL7AtomizeP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior","__ZN2jsL17CheckStringLengthEP9JSContextj489","__Z15js_AtomizeCharsP9JSContextPKtjN2js14InternBehaviorE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_","_INT_TO_JSID501","_OBJECT_TO_JSID502","_JSID_TO_STRING504","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10isLiveHashEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZNK2js9InlineMapIP6JSAtomjLj24EE5asMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE8asInlineEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE9inlineEndEv","__ZNK7mozilla9RangedPtrItE3getEv","__ZNK7mozilla9RangedPtrItEmiERKS1_","__ZNK8JSObject5isXMLEv","__ZNK7mozilla9RangedPtrItEdeEv","__ZN7mozilla9RangedPtrItEaSItEERS1_RKNS0_IT_EE","__ZN7mozilla9RangedPtrItEC2EPtS2_j","__ZN7mozilla9RangedPtrItEC2EPtS2_S2_","__ZNK2js9InlineMapIP6JSAtomjLj24EE8usingMapEv","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isFreeEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9matchHashEj","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE9isRemovedEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js9HashCharsEPKtj","__ZL13AtomizeInlineP9JSContextPPKtjN2js14InternBehaviorE16OwnCharsBehavior","__Z24js_GetExistingStringAtomP9JSContextPKtj","__ZN2js13StaticStrings6lookupEPKtj","__ZN2js10AtomHasher6LookupC1EPKtj","__Z14js_InitAtomMapP9JSContextPN2js9InlineMapIP6JSAtomjLj24EEEPS4_","__ZNK2js9InlineMapIP6JSAtomjLj24EE5isMapEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js13IndexToIdSlowEP9JSContextjPi","__ZN7mozilla9RangedPtrItEC1EPtS2_S2_","__ZN2js25BackfillIndexInCharBufferItEEN7mozilla9RangedPtrIT_EEjS4_","__ZL12ATOM_TO_JSIDP6JSAtom496","__Z22js_CheckForStringIndexi","__ZL12JSID_IS_ATOMi499","__ZL12JSID_TO_ATOMi500","__Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPi","__Z28js_InternNonIntElementIdSlowP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_","__ZN2jsL9IdToValueEi503","__ZN7mozilla9RangedPtrItEmmEv","__ZN7mozilla9RangedPtrItEmIEj","__ZN7mozilla9RangedPtrItEmiEj","__ZNK7mozilla9RangedPtrItE6createEPt","__ZN7mozilla9RangedPtrItEC1EPtS2_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE6isLiveEv","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERKNS7_6LookupEjj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERKNS7_6LookupE","__ZN2js10AtomHasher5matchERKNS_18TaggedPointerEntryI6JSAtomEERKNS0_6LookupE","__ZN2jsL8PodEqualIKtEEbPT_S3_j","__ZN2js10AtomHasher4hashERKNS0_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZL14JSID_FROM_BITSj522","_JSVAL_TO_BOOLEAN_IMPL","_JSID_IS_STRING508","_JSID_IS_INT509","_JSID_TO_INT511","_JSID_IS_OBJECT512","_JSID_TO_OBJECT514","__ZL15JSDOUBLE_IS_NaNd535","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12hasCollisionEv","__ZN2js18TaggedPointerEntryI6JSAtomEC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEptEv","__ZNK2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEcvRS3_Ev","__ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC2ERS3_","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE12setCollisionEv","__ZN2js18TaggedPointerEntryI6JSAtomEC2ERKS2_","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11initializedEv","__ZN2js10AtomHasher6LookupC2EPKtj","__ZN2js13StaticStrings7getUnitEt","__ZN2js13StaticStrings10getLength2Ett","__ZN2js13StaticStrings7getUintEj","__ZN2js18TaggedPointerEntryI6JSAtomEC2EPS1_b","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setLiveEj","__ZN2js24AutoLockAtomsCompartmentC2EP9JSContext","__Z18js_BooleanToStringP9JSContexti","__ZN2js2gcL15GetGCObjectKindEjb560","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEE7setFreeEv","__ZN2js18TaggedPointerEntryI6JSAtomEC1Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumD2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEEEC1ERS7_","__ZN2js4MoveINS_18TaggedPointerEntryI6JSAtomEEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_18TaggedPointerEntryI6JSAtomEEEC1ERS3_","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC1Ev","__ZN2js6detail14HashTableEntryIKNS_18TaggedPointerEntryI6JSAtomEEEC2Ev","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4EnumC2IS9_EERT_","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2JSL10Int32ValueEi510","__ZN2JSL11ObjectValueER8JSObject513","__ZN2JSL14UndefinedValueEv515","__ZN2js13StaticStrings6getIntEi","__ZNK2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE12lookupForAddERKNS4_6LookupE","__ZN2js7HashSetINS_18TaggedPointerEntryI6JSAtomEENS_10AtomHasherENS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERKNS4_6LookupERS9_","__ZN2js18TaggedPointerEntryI6JSAtomEC1EPS1_b","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13relookupOrAddERNSB_6AddPtrERKNS7_6LookupERS5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERKNS7_6LookupE","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableIKNS_18TaggedPointerEntryI6JSAtomEENS_7HashSetIS4_NS_10AtomHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js10AtomHasher6LookupC2EPK6JSAtom","__ZN12JSFlatString8finalizeEP9JSRuntime","__ZL13bool_toSourceP9JSContextjPN2JS5ValueE","__ZL13bool_toStringP9JSContextjPN2JS5ValueE","__ZL12bool_valueOfP9JSContextjPN2JS5ValueE","__Z19js_InitBooleanClassP9JSContextP8JSObject","__ZN8JSObject16setPrimitiveThisERKN2JS5ValueE","__ZN2JSL12BooleanValueEb532","__ZL7BooleanP9JSContextjPN2JS5ValueE","__ZN2js21BooleanToStringBufferEP9JSContextiRNS_12StringBufferE","__ZN2js12StringBuffer6appendILj5EEEbRAT__Kc","__ZN2js12StringBuffer6appendILj6EEEbRAT__Kc","__Z17js_ValueToBooleanRKN2JS5ValueE","__ZNK2JS5Value9toBooleanEv","__ZN2jsL14IsConstructingEPKN2JS5ValueE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE558","__ZL9SwapBytesy","_JSVAL_IS_MAGIC_IMPL571","_JSVAL_IS_BOOLEAN_IMPL","__ZL12PairToUInt64jj","_JSID_IS_INT594","_JSID_TO_INT595","_JSID_TO_STRING596","__ZL14ArrayTypeToTagj","__ZL25ReinterpretDoubleAsUInt64d","__ZN2js7SCInputC2EP9JSContextPKyj","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE561","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE562","__ZNK2JS5Value7isMagicEv","__ZN2js16GetPrimitiveThisIbEEbP9JSContextPN2JS5ValueEPT_","__ZN2js6detail17PrimitiveBehaviorIbE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIbE7extractERKN2JS5ValueE","__ZNK8JSObject16getPrimitiveThisEv","__ZNK2JS5Value9isBooleanEv","__Z14js_GetSCOffsetP23JSStructuredCloneWriter","__ZN2js8SCOutput5countEv","__ZN2js20WriteStructuredCloneEP9JSContextRKN2JS5ValueEPPyPjPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneWriterC1ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneWriter4initEv","__ZN23JSStructuredCloneWriter5writeERKN2JS5ValueE","__ZN2js8SCOutput13extractBufferEPPyPj","__ZN23JSStructuredCloneWriterD1Ev","__ZN2js8SCOutputD1Ev","__ZN2js19ReadStructuredCloneEP9JSContextPKyjPN2JS5ValueEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneReaderC1ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv","__ZN23JSStructuredCloneReader4readEPN2JS5ValueE","__ZN23JSStructuredCloneReaderD1Ev","__ZN2js7SCInput3eofEv","__ZN2js7SCInput4readEPy","__ZN2js7SCInput8readPairEPjS1_","__ZN2js7SCInput10readDoubleEPd","__ZL15CanonicalizeNand","__ZN2js7SCInput9readBytesEPvj","__ZN2js7SCInput9readArrayIhEEbPT_j","__ZN2js7SCInput9readCharsEPtj","__ZN2js7SCInput9readArrayItEEbPT_j","__ZN2js8SCOutputC2EP9JSContext","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC1ES1_","__ZN2js8SCOutput5writeEy","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE6appendIyEEbT_","__ZN2js8SCOutput9writePairEjj","__ZN2js8SCOutput11writeDoubleEd","__ZN2js8SCOutput10writeBytesEPKvj","__ZN2js8SCOutput10writeArrayIhEEbPKT_j","__ZN2js8SCOutput10writeCharsEPKtj","__ZN2js8SCOutput10writeArrayItEEbPKT_j","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE16extractRawBufferEv","__ZN23JSStructuredCloneWriter11writeStringEjP8JSString","__ZN23JSStructuredCloneWriter7contextEv","__ZN23JSStructuredCloneWriter7writeIdEi","__ZN23JSStructuredCloneWriter15writeTypedArrayEP8JSObject","__ZN2js10TypedArray7getTypeEP8JSObject","__ZN2js10TypedArray9getLengthEP8JSObject","__ZN2js10TypedArray13getDataOffsetEP8JSObject","__ZN2js8SCOutput10writeArrayIjEEbPKT_j","__ZN2js8SCOutput10writeArrayIyEEbPKT_j","__ZN23JSStructuredCloneWriter16writeArrayBufferEP8JSObject","_JSID_IS_STRING598","_JSVAL_IS_DOUBLE_IMPL599","__ZL14TagToArrayTypej","__ZN8JSObject21arrayBufferByteLengthEv","__ZN8JSObject21arrayBufferDataOffsetEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2jsL7ReverseIiEEvPT_S2_","__ZNK8JSObject9isBooleanEv","__ZNK8JSObject8isNumberEv","__ZNK8JSObject8isStringEv","__ZNK2js6VectorIjLj0ENS_15TempAllocPolicyEE5emptyEv","__ZN5Chars3getEv","__ZN5Chars6forgetEv","__ZN23JSStructuredCloneWriter11startObjectEP8JSObject","__ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj","__ZNK2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js16AutoVectorRooterIiE5beginEv","__ZN2js16AutoVectorRooterIiE3endEv","__ZN2JSL11ObjectValueER8JSObject597","__ZN23JSStructuredCloneWriter10startWriteERKN2JS5ValueE","__ZNK2js16AutoVectorRooterIN2JS5ValueEE4backEv","__ZNK2js16AutoVectorRooterIiE4backEv","__ZN2js16AutoVectorRooterIiE7popBackEv","__ZN2js16AutoVectorRooterIN2JS5ValueEE7popBackEv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN23JSStructuredCloneReader11checkDoubleEd","__ZN23JSStructuredCloneReader7contextEv","__ZN23JSStructuredCloneReader10readStringEj","__ZN5CharsC1Ev","__ZN5Chars8allocateEP9JSContextj","__ZN5CharsD1Ev","__ZN23JSStructuredCloneReader14readTypedArrayEjjPN2JS5ValueE","__ZN2js7SCInput9readArrayIjEEbPT_j","__ZN2js7SCInput9readArrayIyEEbPT_j","__ZN23JSStructuredCloneReader15readArrayBufferEjPN2JS5ValueE","__ZL9SwapBytesj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","_INT_TO_JSID603","_JSID_IS_VOID605","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10isLiveHashEj","__ZL18JSDOUBLE_IS_FINITEd600","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE5clearEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE7popBackEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE3endEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEptEv","__ZNK2js7MoveRefIjEcvRjEv","__ZN2js7MoveRefIjEC2ERj","__ZN2js12HashMapEntryIP8JSObjectjEC2Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv","__ZN23JSStructuredCloneReader9startReadEPN2JS5ValueE","__ZL18js_DoubleToIntegerd601","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE602","__ZL23ReinterpretPairAsDoublejj","__ZN23JSStructuredCloneReader6readIdEPi","__ZL12ATOM_TO_JSIDP6JSAtom604","__ZN2js16AutoVectorRooterIN2JS5ValueEE5clearEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEE4backEv","__ZNK2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEEEC1ERS7_","__ZN2js12HashMapEntryIP8JSObjectjEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectjEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectjEEEC1ERS4_","__ZN2js4MoveIjEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIjEC1ERj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectjEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZL9SwapBytest","__ZL14JSID_FROM_BITSj609","__Z16js_FinishThreadsP9JSRuntime","_JS_CANONICALIZE_NAN644","__ZL25ReinterpretUInt64AsDoubley","__ZL15JSDOUBLE_IS_NaNd628","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectjEEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE","__ZNK2js8SCOutput7contextEv","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13copyConstructIyEEvPyPKT_S7_","__ZN2js2gcL15GetGCObjectKindEjb613","__ZN5CharsC2Ev","__ZNK2js7SCInput7contextEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js10ThreadData24triggerOperationCallbackEP9JSRuntime","__Z20js_CurrentThreadDataP9JSRuntime","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIyLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIyLj0ES1_EEj","__ZN2js10VectorImplIyLj0ENS_15TempAllocPolicyELb1EE13moveConstructIyEEvPyPKT_S7_","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEE14internalAppendIyEEvT_","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEEC2ES1_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE614","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE615","__ZN5CharsD2Ev","__ZN23JSStructuredCloneReaderD2Ev","__ZN23JSStructuredCloneReaderC2ERN2js7SCInputEPK26JSStructuredCloneCallbacksPv","__ZN2js8SCOutputD2Ev","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIyLj0ENS_15TempAllocPolicyEED2Ev","__ZN23JSStructuredCloneWriterD2Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN23JSStructuredCloneWriterC2ERN2js8SCOutputEPK26JSStructuredCloneCallbacksPv","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP8JSObjectjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js10ThreadDataC2Ev","__ZN2js8GSNCacheC1Ev","__ZN2js13PropertyCacheC1Ev","__ZN2js18GetNativeStackBaseEv","__ZN2js24ConservativeGCThreadDataC1Ev","__ZN2js10ThreadDataD2Ev","__ZN2js8GSNCacheD1Ev","__ZN2js10ThreadData4initEv","__Z19js_GetCurrentScriptP9JSContext","__Z14js_InitThreadsP9JSRuntime","__Z15js_PurgeThreadsP9JSContext","__ZN2js10ThreadData5purgeEP9JSContext","__Z13js_NewContextP9JSRuntimej","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js10Foreground7delete_I9JSContextEEvPT_","__ZN9JSContext13fromLinkFieldEP10JSCListStr","__ZNK2js13AutoResolving18alreadyStartedSlowEv","__Z18js_GetErrorMessagePvPKcj","__Z17js_DestroyContextP9JSContext20JSDestroyContextMode","__Z18js_ContextIteratorP9JSRuntimeiPP9JSContext","__ZN7mozilla5MaybeIN2js10AutoLockGCEEC1Ev","__ZN7mozilla5MaybeIN2js10AutoLockGCEE9constructIP9JSRuntimeEEvRKT_","__Z20js_NextActiveContextP9JSRuntimeP9JSContext","__Z20js_ReportOutOfMemoryP9JSContext","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_","__ZL19PopulateReportBlameP9JSContextP13JSErrorReport","__ZN2js19AutoAtomicIncrementC1EPi","__ZN2js19AutoAtomicIncrementD1Ev","__Z21js_ReportOverRecursedP9JSContext","__Z27js_ReportAllocationOverflowP9JSContext","__Z16js_ReportErrorVAP9JSContextjPKcPc","__ZL16checkReportFlagsP9JSContextPj","__ZL11ReportErrorP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_","__Z23js_ExpandErrorArgumentsP9JSContextPFPK19JSErrorFormatStringPvPKcjES4_jPPcP13JSErrorReportbS9_","__Z22js_ReportErrorNumberVAP9JSContextjPFPK19JSErrorFormatStringPvPKcjES4_jiPc","__Z19js_ReportErrorAgainP9JSContextPKcP13JSErrorReport","__Z21js_ReportIsNotDefinedP9JSContextPKc","__Z22js_CurrentPCIsInImacroP9JSContext","__ZN9JSContext22thisDuringConstructionEv","__ZN9JSContext16updateJITEnabledEv","__ZN2js10LeaveTraceEP9JSContext","__ZN2js13CanLeaveTraceEP9JSContext","__ZNK7mozilla14AlignedStorageILj8EE4addrEv","__ZN7mozilla14AlignedStorageILj8EE4addrEv","__ZN7mozilla15AlignedStorage2IN2js10AutoLockGCEE4addrEv","__ZNK2js14ThreadDataIter5emptyEv","__ZNK2js14ThreadDataIter10threadDataEv","__ZN2js14ThreadDataIter8popFrontEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6lengthEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE5beginEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN7mozilla5MaybeIN2js10AutoLockGCEEC2Ev","__ZN14DSTOffsetCache5purgeEv","__ZNK2js10StackFrame11hasImacropcEv","__ZNK2js10StackFrame8imacropcEv","__ZN2js14ThreadDataIterC2EP9JSRuntime","__ZN2js19AutoAtomicIncrementD2Ev","__ZN2js19AutoAtomicIncrementC2EPi","__ZNK2js9StackIter2pcEv","__Z26js_ReportIsNullOrUndefinedP9JSContextiRKN2JS5ValueEP8JSString","__ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString","__Z19js_ReportMissingArgP9JSContextRKN2JS5ValueEj","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE","__Z24js_ReportValueErrorFlagsP9JSContextjjiRKN2JS5ValueEP8JSStringPKcS8_","__Z16checkOutOfMemoryP9JSRuntime","__Z26js_InvokeOperationCallbackP9JSContext","__Z27js_HandleExecutionInterruptP9JSContext","__ZN2js24TriggerOperationCallbackEP9JSContext","__ZN2js28TriggerAllOperationCallbacksEP9JSRuntime","__ZN2js14ThreadDataIterC1EP9JSRuntime","__Z20js_GetScriptedCallerP9JSContextPN2js10StackFrameE","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind","__Z23js_GetCurrentBytecodePCP9JSContext","__ZNK2js10StackFrame13maybeImacropcEv","__ZN9JSContextC2EP9JSRuntime","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN14DSTOffsetCacheC1Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC1ES3_","__ZN9JSContextD2Ev","__ZN2js10Foreground7delete_INS_12ParseMapPoolEEEvPT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN9JSContext16resetCompartmentEv","__Z19OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject","__ZN9JSContext20wrapPendingExceptionEv","__ZNK9JSContext12generatorForEPN2js10StackFrameE","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE4backEv","__ZN11JSGenerator9liveFrameEv","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEixEj","__ZNK9JSContext28runningWithTrustedPrincipalsEv","__ZN9JSRuntime15onTooMuchMallocEv","__ZN9JSRuntime13onOutOfMemoryEPvjP9JSContext","__ZN9JSContext5purgeEv","__ZL13FreeOldArenasP9JSRuntimeP11JSArenaPool","__ZN2js12ParseMapPoolD1Ev","_js_free816","__ZN2js12ParseMapPoolD2Ev","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEED2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEED2Ev","__ZNK2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEEC2ES3_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN14DSTOffsetCacheC2Ev","__ZNK9JSContext15hasStrictOptionEv","__ZNK9JSContext15hasWErrorOptionEv","__ZN2js13FrameRegsIterC1EP9JSContextNS_9StackIter11SavedOptionE","__ZNK2js13FrameRegsIter4doneEv","__ZNK2js13FrameRegsIter2fpEv","__ZNK2js13FrameRegsIter2pcEv","__ZN2js13FrameRegsIterppEv","__ZN2js13FrameRegsIter6settleEv","__ZN2js13FrameRegsIterC2EP9JSContextNS_9StackIter11SavedOptionE","__ZN2js8GSNCacheD2Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN13JSCompartment11thisForCtorEv","_JSID_IS_INT844","__ZN2jsL16CastAsPropertyOpEP8JSObject846","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject847","__ZN2js24ConservativeGCThreadDataC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZNK8JSObject15isStopIterationEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js13PropertyCacheC2Ev","__ZN2jsL7PodZeroINS_13PropertyCacheEEEvPT_","__ZN2js8GSNCacheC2Ev","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN13JSCompartmentC2EP9JSRuntime","__ZN2js2gc10ArenaListsC1Ev","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js12PropertyTreeC1EP13JSCompartment","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js15NativeIterCacheC1Ev","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC1Ev","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js9DtoaCacheC1Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC1ES6_","__ZN2js18RuntimeAllocPolicyC1EP9JSRuntime","__ZN2jsL12PodArrayZeroIP8JSScriptLj64EEEvRAT0__T_","__ZN13JSCompartmentD2Ev","__ZN2js10Foreground7delete_INS_9MathCacheEEEvPT_","__ZN2js10Foreground7delete_INS_13WatchpointMapEEEvPT_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED1Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED1Ev","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED1Ev","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED1Ev","__ZN2js2gc10ArenaListsD1Ev","__ZN13JSCompartment4initEP9JSContext","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE4initEj","__ZN9JSRuntime4new_IN3WTF20BumpPointerAllocatorEEEPT_v","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE4initEj","__ZN13JSCompartment4wrapEP9JSContextPN2JS5ValueE","__ZNK2JS5Value10isMarkableEv","__ZL25IsCrossCompartmentWrapperP8JSObject","__ZN13JSCompartment4wrapEP9JSContextPP8JSObject","__ZN13JSCompartment4wrapEP9JSContextPP8JSString","__ZN2JSL11StringValueEP8JSString840","__ZN2JSL11ObjectValueER8JSObject841","__ZN13JSCompartment6wrapIdEP9JSContextPi","__ZN2jsL9IdToValueEi845","__ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiPN2JS5ValueEE","__ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiPN2JS5ValueEE","__ZN13JSCompartment4wrapEP9JSContextPPFiS1_P8JSObjectiiPN2JS5ValueEE","__ZN2js17CastAsObjectJsvalEPFiP9JSContextP8JSObjectiiPN2JS5ValueEE","__ZN13JSCompartment4wrapEP9JSContextP20JSPropertyDescriptor","__ZN13JSCompartment4wrapEP9JSContextRN2js12AutoIdVectorE","__ZN13JSCompartment28markCrossCompartmentWrappersEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev","__ZNK2js2gc12CellIterImpl4doneEv","__ZNK2js2gc12CellIterImpl3getI8JSScriptEEPT_v","__ZNK2js2gc12CellIterImpl3getI8JSObjectEEPT_v","__ZNK2js2gc12CellIterImpl3getINS_5types10TypeObjectEEEPT_v","__ZN8JSScript13clearAnalysisEv","__ZN2js9DtoaCache5purgeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__ZNK2js18ThreadContextRange5emptyEv","__ZN2js18ThreadContextRange8popFrontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3PtrptEv","__ZN13JSCompartment9markTypesEP8JSTracer","__ZN2js2gc15CellIterUnderGCC1EP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc12CellIterImpl4nextEv","__ZN13JSCompartment5sweepEP9JSContextj","__ZNK2JS5Value9toGCThingEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv","__ZN13JSCompartment16sweepBreakpointsEP9JSContext","__ZN2js13MoveArenaPoolEP11JSArenaPoolS1_","__ZN13JSCompartment5purgeEP9JSContext","__ZN2js2gc10ArenaLists5purgeEv","__ZN2js15NativeIterCache5purgeEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE20destroyIfConstructedEv","__ZN13JSCompartment14allocMathCacheEP9JSContext","__ZN9JSContext4new_IN2js9MathCacheEEEPT_v","__ZNK13JSCompartment13backEdgeCountEPh","__ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN13JSCompartment16incBackEdgeCountEPh","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj","__ZN13JSCompartment17hasScriptsOnStackEP9JSContext","__ZN13JSCompartment17setDebugModeFromCEP9JSContextb","__ZN13JSCompartment18updateForDebugModeEP9JSContext","__ZN2js18ThreadContextRangeC1EP9JSContext","__ZN13JSCompartment11addDebuggeeEP9JSContextPN2js12GlobalObjectE","__ZN13JSCompartment14removeDebuggeeEP9JSContextPN2js12GlobalObjectEPNS2_6detail9HashTableIKS4_NS2_7HashSetIS4_NS2_13DefaultHasherIS4_EENS2_17SystemAllocPolicyEE6SetOpsESB_E4EnumE","__ZN13JSCompartment17getBreakpointSiteEPh","__ZN13JSCompartment25getOrCreateBreakpointSiteEP9JSContextP8JSScriptPhP8JSObject","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10isLiveHashEj","__ZN7mozilla15AlignedStorage2IN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE4addrEv","__ZNK2js14BreakpointSite7hasTrapEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhPNS_14BreakpointSiteEEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC2ERS3_","__ZNK2js7MoveRefINS_12HashMapEntryIPhjEEEptEv","__ZN2js12HashMapEntryIPhjEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE12setCollisionEj","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE","__ZNK7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE5emptyEv","__ZN9JSRuntime4new_IN2js14BreakpointSiteEP8JSScriptPhEEPT_T0_T1_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S3_EENS7_13MapHashPolicyES6_E6AddPtrERKS1_RKS3_","__ZN13JSCompartment18clearBreakpointsInEP9JSContextPN2js8DebuggerEP8JSScriptP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC1ISB_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD1Ev","__ZN13JSCompartment10clearTrapsEP9JSContextP8JSScript","__ZN13JSCompartment27markTrapClosuresIterativelyEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumD2Ev","_js_free864","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4EnumC2ISB_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E3addERNSD_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZNK2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS5_13MapHashPolicyES4_E6AddPtrERKS1_RKj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEENS_7MoveRefIT_EERS8_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhjEEEEEC1ERS6_","__ZN2js12HashMapEntryIPhjEaSENS_7MoveRefIS2_EE","__ZN2js4MoveINS_12HashMapEntryIPhjEEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_12HashMapEntryIPhjEEEC1ERS3_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhjEEEC2Ev","__ZN2js12HashMapEntryIPhjEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE7destroyEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3refEv","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE3asTEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_","__ZNK2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEE3allEv","__ZN2js2gc8FreeSpan13encodeOffsetsEjj","_JSVAL_TO_GCTHING_IMPL","__ZNK2js2gc11ArenaHeader7addressEv","_JSID_IS_STRING869","_JSID_TO_STRING870","_JSID_TO_INT872","_JSID_IS_OBJECT873","_JSID_TO_OBJECT874","_JSVAL_IS_TRACEABLE_IMPL","__ZN2js2gc5Chunk11fromAddressEj","__ZN3WTF20BumpPointerAllocatorC2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEEC2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC2ESA_","__ZN2js18ThreadContextRangeC2EP9JSContext","__ZNK2js2gc8FreeSpan7isEmptyEv","__ZN2js2gc8FreeSpan11initAsEmptyEj","__ZNK2js2gc8FreeSpan21arenaAddressUncheckedEv","__ZNK2js2gc8FreeSpan7hasNextEv","__ZNK2js2gc8FreeSpan8nextSpanEv","__ZN2js2gc8FreeSpanC2Ejj","__ZN2js2gc5Arena16firstThingOffsetENS0_9AllocKindE","__ZNK2js2gc10ArenaLists13getFirstArenaENS0_9AllocKindE","__ZNK9JSWrapper5flagsEv","__ZN2js18RuntimeAllocPolicyC2EP9JSRuntime","__ZN2js9DtoaCacheC2Ev","__ZN2js12PropertyTreeC2EP13JSCompartment","__ZN2js2gc10ArenaLists9ArenaList5clearEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN3WTF20BumpPointerAllocatorC1Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN2js13WatchpointMapD1Ev","__ZN2js13WatchpointMapD2Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEED2Ev","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEEC2ES6_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_EC1ESA_","__ZN2jsL12PodArrayZeroIP8JSObjectLj256EEEvRAT0__T_","__ZNK2js2gc8FreeSpan11arenaHeaderEv","__ZN2js2gc11ArenaHeader16setFirstFreeSpanEPKNS0_8FreeSpanE","__ZNK2js2gc8FreeSpan15encodeAsOffsetsEv","__ZNK2js2gc8FreeSpan12arenaAddressEv","__ZNK2js2gc11ArenaHeader16getFirstFreeSpanEv","__ZNK2js2gc11ArenaHeader12arenaAddressEv","__ZN2js2gc8FreeSpan13decodeOffsetsEjj","__ZN2js2gc8FreeSpanC1Ejj","__ZN2js2gc15CellIterUnderGCC2EP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc12CellIterImpl4initEP13JSCompartmentNS0_9AllocKindE","__ZN2JSL17ObjectOrNullValueEP8JSObject866","__ZN2JSL10Int32ValueEi871","__ZN2JSL14UndefinedValueEv875","__ZN2js2gc10ArenaListsD2Ev","__ZNK2js2gc11ArenaHeader5chunkEv","__ZN2js7HashMapIN2JS5ValueES2_NS_13WrapperHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIN2JS5ValueES4_EENS_7HashMapIS4_S4_NS_13WrapperHasherENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js7HashSetIPNS_10EmptyShapeENS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKPNS_10EmptyShapeENS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZN2js7HashMapIPhjNS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhjEENS_7HashMapIS3_jNS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_ED2Ev","__ZN2js15NativeIterCacheC2Ev","__ZN2js2gc10ArenaListsC2Ev","__ZN2js2gc10ArenaLists9ArenaListC1Ev","__ZN2js2gc10ArenaLists9ArenaListC2Ev","__ZN2js5crash5StackC2Ey","__ZN2js5crash10CrashStackC2Ey","__ZN2js5crash5Stack8snapshotEv","__ZN2js5crash4RingC2Ey","__ZN2js5crash9CrashRingC2Ey","__ZN2js5crash4Ring4pushEyPvj","__ZN2js5crash15SnapshotGCStackEv","__ZN2js5crash18SnapshotErrorStackEv","__ZN2js5crash13SaveCrashDataEyPvj","_JS_EnumerateDiagnosticMemoryRegions","__ZN2js5crash4Ring9copyBytesEPvj","___cxx_global_var_init888","___cxx_global_var_init1889","___cxx_global_var_init2890","__ZN2js5crash11CrashHeaderC1Ey","__ZN2js5crash11CrashHeaderC2Ey","__GLOBAL__I_a891","__ZL12date_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL8date_UTCP9JSContextjPN2JS5ValueE","__ZL10date_parseP9JSContextjPN2JS5ValueE","__ZL8date_nowP9JSContextjPN2JS5ValueE","__ZL12date_getTimeP9JSContextjPN2JS5ValueE","__ZL22date_getTimezoneOffsetP9JSContextjPN2JS5ValueE","__ZL12date_getYearP9JSContextjPN2JS5ValueE","__ZL16date_getFullYearP9JSContextjPN2JS5ValueE","__ZL19date_getUTCFullYearP9JSContextjPN2JS5ValueE","__ZL13date_getMonthP9JSContextjPN2JS5ValueE","__ZL16date_getUTCMonthP9JSContextjPN2JS5ValueE","__ZL12date_getDateP9JSContextjPN2JS5ValueE","__ZL15date_getUTCDateP9JSContextjPN2JS5ValueE","__ZL11date_getDayP9JSContextjPN2JS5ValueE","__ZL14date_getUTCDayP9JSContextjPN2JS5ValueE","__ZL13date_getHoursP9JSContextjPN2JS5ValueE","__ZL16date_getUTCHoursP9JSContextjPN2JS5ValueE","__ZL15date_getMinutesP9JSContextjPN2JS5ValueE","__ZL18date_getUTCMinutesP9JSContextjPN2JS5ValueE","__ZL18date_getUTCSecondsP9JSContextjPN2JS5ValueE","__ZL23date_getUTCMillisecondsP9JSContextjPN2JS5ValueE","__ZL12date_setTimeP9JSContextjPN2JS5ValueE","__ZL12date_setYearP9JSContextjPN2JS5ValueE","__ZL16date_setFullYearP9JSContextjPN2JS5ValueE","__ZL19date_setUTCFullYearP9JSContextjPN2JS5ValueE","__ZL13date_setMonthP9JSContextjPN2JS5ValueE","__ZL16date_setUTCMonthP9JSContextjPN2JS5ValueE","__ZL12date_setDateP9JSContextjPN2JS5ValueE","__ZL15date_setUTCDateP9JSContextjPN2JS5ValueE","__ZL13date_setHoursP9JSContextjPN2JS5ValueE","__ZL16date_setUTCHoursP9JSContextjPN2JS5ValueE","__ZL15date_setMinutesP9JSContextjPN2JS5ValueE","__ZL18date_setUTCMinutesP9JSContextjPN2JS5ValueE","__ZL15date_setSecondsP9JSContextjPN2JS5ValueE","__ZL18date_setUTCSecondsP9JSContextjPN2JS5ValueE","__ZL20date_setMillisecondsP9JSContextjPN2JS5ValueE","__ZL23date_setUTCMillisecondsP9JSContextjPN2JS5ValueE","__ZL16date_toGMTStringP9JSContextjPN2JS5ValueE","__ZL19date_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL23date_toLocaleDateStringP9JSContextjPN2JS5ValueE","__ZL23date_toLocaleTimeStringP9JSContextjPN2JS5ValueE","__ZL19date_toLocaleFormatP9JSContextjPN2JS5ValueE","__ZL17date_toDateStringP9JSContextjPN2JS5ValueE","__ZL18JSDOUBLE_IS_FINITEd1004","__ZL17date_toTimeStringP9JSContextjPN2JS5ValueE","__ZL16date_toISOStringP9JSContextjPN2JS5ValueE","__ZL11date_toJSONP9JSContextjPN2JS5ValueE","__ZL13date_toSourceP9JSContextjPN2JS5ValueE","__ZL13date_toStringP9JSContextjPN2JS5ValueE","__ZL12date_valueOfP9JSContextjPN2JS5ValueE","__Z7js_DateP9JSContextjPN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE1003","__ZL11date_formatP9JSContextd10formatspecPN2JS5ValueE","__ZL11NowAsMillisv","__ZL18js_DoubleToIntegerd1005","__ZL15JSDOUBLE_IS_NaNd1014","__ZL16date_parseStringP14JSLinearStringPdP9JSContext","__ZL17date_msecFromArgsP9JSContextjPN2JS5ValueEPd","__ZL3UTCdP9JSContext","__Z20js_NewDateObjectMsecP9JSContextd","__Z16js_InitDateClassP9JSContextP8JSObject","__ZL12SetDateToNaNP9JSContextP8JSObjectPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1010","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1011","__ZL10SetUTCTimeP9JSContextP8JSObjectdPN2JS5ValueE","__Z16js_NewDateObjectP9JSContextiiiiii","__ZL17date_msecFromDateddddddd","__Z14js_DateIsValidP9JSContextP8JSObject","__ZL10GetUTCTimeP9JSContextP8JSObjectPN2JS5ValueEPd","__Z14js_DateGetYearP9JSContextP8JSObject","__ZL20GetAndCacheLocalTimeP9JSContextP8JSObjectPN2JS5ValueEPd","__ZL12YearFromTimed","__Z15js_DateGetMonthP9JSContextP8JSObject","__ZL13MonthFromTimed","__ZL14JSID_FROM_BITSj1046","__ZL10IsLeapYeari","__ZN2js2gcL15GetGCObjectKindEjb1026","__Z14js_DateGetDateP9JSContextP8JSObject","__ZL12DateFromTimed","__Z15js_DateGetHoursP9JSContextP8JSObject","__ZL12HourFromTimed","__Z17js_DateGetMinutesP9JSContextP8JSObject","__ZL11MinFromTimed","__Z17js_DateGetSecondsP9JSContextP8JSObject","__ZL11SecFromTimed","__Z24js_DateGetMsecSinceEpochP9JSContextP8JSObject","__Z14js_IntervalNowv","__ZL14DaysInFebruaryi","__ZL10DaysInYeari","__ZL14FillLocalTimesP9JSContextP8JSObject","__ZNK8JSObject14getDateUTCTimeEv","__ZN2JSL11DoubleValueEd1017","__ZL9LocalTimedP9JSContext","__ZN2JSL10Int32ValueEi1018","__ZL7WeekDayd","__ZL10AdjustTimedP9JSContext","__ZL16DaylightSavingTAdP9JSContext","__ZL20EquivalentYearForDSTi","__ZL7MakeDayddd","__ZL13TimeWithinDayd","__ZN2JSL14UndefinedValueEv1024","__ZN8JSObject14setDateUTCTimeERKN2JS5ValueE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1027","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1028","__ZN2JSL11ObjectValueER8JSObject1038","__ZN2js7unicode8CharInfoEt","__ZL10fractionalPdPKtPjj","__ZL6digitsPjPKtS_j","__ZNK16JSAutoByteStringntEv","__ZL19date_parseISOStringP14JSLinearStringPdP9JSContext","__ZL18date_regionMatchesPKciPKtiii","__ZN2js7unicode11ToLowerCaseEt","__ZL7ndigitsjPjPKtS_j","__ZL11DaysInMonthii","__ZL11new_explodedP8PRMJTimeP9JSContext","__ZL10msFromTimed","__ZL14GetThisUTCTimeP9JSContextPN2JS5ValueEPd","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE1052","__ZN8JSObject12defaultValueEP9JSContext6JSTypePN2JS5ValueE","__ZL15date_utc_formatP9JSContextPN2JS5ValueEPFvPcjdE","__ZL16print_iso_stringPcjd","__ZN16JSAutoByteStringC1EP9JSContextP8JSString","__ZL19date_toLocaleHelperP9JSContextP8JSObjectPKcPN2JS5ValueE","__ZN16JSAutoByteStringC2EP9JSContextP8JSString","__ZL16print_gmt_stringPcjd","_JSID_IS_INT1059","__ZN2jsL8JsvalifyEPNS_10StackFrameE","_JS_SetRuntimeDebugMode","__ZN2js10StackFrame11setHookDataEPv","__ZN2js11GetGSNCacheEP9JSContext","_JS_SetInterrupt","_JS_ClearInterrupt","__ZL13date_makeTimeP9JSContextjijPN2JS5ValueE","__ZL13date_makeDateP9JSContextjijPN2JS5ValueE","_JS_GetDebugMode","_JS_SetDebugMode","_JS_SetDebugModeForCompartment","__ZN2js19ScriptDebugPrologueEP9JSContextPNS_10StackFrameE","__ZN2js8Debugger12onEnterFrameEP9JSContext","__ZN2js19ScriptDebugEpilogueEP9JSContextPNS_10StackFrameEb","__ZNK2js10StackFrame13maybeHookDataEv","__ZN2js8Debugger12onLeaveFrameEP9JSContext","_JS_SetSingleStepMode","__ZL14CheckDebugModeP9JSContext","_js_UntrapScriptCode","_JS_SetTrap","_JS_GetTrapOpcode","_JS_ClearTrap","_JS_ClearScriptTraps","_JS_ClearAllTrapsForCompartment","_JS_SetWatchPoint","_JS_LocalNameToAtom","__ZN2jsL13VersionNumberE9JSVersion1066","__ZN2js15AutoValueRooter3setEN2JS5ValueE","_JS_EndPC","_JS_GetFunctionArgumentCount","__ZNK2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE6lengthEv","_JS_AtomKey","_JS_GetScriptPrincipals","__ZNK2js10StackFrame15isDebuggerFrameEv","_JS_GetScriptFilename","_JS_GetScriptSourceMap","_JS_GetScriptBaseLineNumber","_JS_SetNewScriptHookProc","_JS_SetDestroyScriptHookProc","__ZN2jsL9IdToValueEi1060","__ZN9JSRuntime4new_IN2js13WatchpointMapEEEPT_v","_JS_ClearWatchPoint","_JS_ClearWatchPointsForObject","_JS_ClearAllWatchPoints","_JS_PCToLineNumber","_JS_LineNumberToPC","_JS_GetLinePCs","_JS_FunctionHasLocalNames","__ZNK2js8Bindings13hasLocalNamesEv","_JS_GetFunctionLocalNameArray","_JS_ReleaseFunctionLocalNameArray","_JS_GetFunctionScript","__ZNK10JSFunction11maybeScriptEv","_JS_GetFunctionNative","__ZNK10JSFunction11maybeNativeEv","_JS_FrameIterator","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1065","_JS_GetFrameScript","_JS_GetFramePC","_JS_GetScriptedCaller","_JS_GetFrameAnnotation","_JS_SetFrameAnnotation","_JS_GetFramePrincipalArray","_JS_IsScriptFrame","_JS_GetFrameObject","_JS_GetFrameScopeChain","_JS_GetFrameCallObject","_JS_GetFrameThis","_JS_GetFrameFunction","__ZNK2js10StackFrame8maybeFunEv","_JS_GetFrameFunctionObject","_JS_IsConstructorFrame","_JS_GetFrameCalleeObject","__ZNK2js10StackFrame12maybeCalleevEv","_JS_GetValidFrameCalleeObject","_JS_IsDebuggerFrame","_JS_IsGlobalFrame","_JS_GetFrameReturnValue","__ZN2js10StackFrame11returnValueEv","_JS_SetFrameReturnValue","__ZN2js10StackFrame14setReturnValueERKN2JS5ValueE","_JS_GetScriptLineExtent","_JS_GetScriptVersion","_JS_EvaluateUCInStackFrame","_JS_EvaluateInStackFrame","_JS_PropertyIterator","_JS_UnsafeGetLastProfilingError","_JS_StartProfiling","_JS_StopProfiling","_JS_DumpProfile","_JS_DefineProfilingFunctions","_JS_DumpBytecode","__ZL26DumpBytecodeScriptCallbackP9JSContextPvS1_13JSGCTraceKindj","__ZL16ControlProfilersb","_JSID_IS_STRING1077","_JSID_TO_STRING1080","_JSID_TO_INT1082","_JSID_IS_OBJECT1083","_JSID_TO_OBJECT1085","_JS_DHashVoidPtrKeyStub","__ZNK2js5Shape8writableEv","__ZNK2js5Shape12configurableEv","__ZNK2js5Shape5Range5emptyEv","_JS_SetDebuggerHandler","_JS_SetSourceHandler","_JS_SetExecuteHook","_JS_SetCallHook","_JS_SetThrowHook","_JS_SetDebugErrorHook","__ZN8JSScript7regexpsEv","__ZNK8JSObject8isSystemEv","__ZN8JSObject9setSystemEv","_JS_GetGlobalDebugHooks","_JS_SetContextDebugHooks","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js10StackFrame15markReturnValueEv","__ZNK10JSFunction6nativeEv","__ZNK2js8Bindings15countLocalNamesEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhPNS_14BreakpointSiteEEENS_7HashMapIS3_S5_NS_13DefaultHasherIS3_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESA_E5emptyEv","__ZNK2js10StackFrame11hasHookDataEv","_JS_DHashStringKey","_JS_GetPropertyDesc","__ZN2jsL9IdToJsvalEi1067","__ZN2JSL14UndefinedValueEv1068","__ZNK2js5Shape3allEv","_JS_GetPropertyDescArray","__ZNK8JSObject13propertyCountEv","_JS_PutPropertyDescArray","_JS_GetObjectTotalSize","__ZNK8JSObject18slotsAndStructSizeEv","_JS_GetFunctionTotalSize","_JS_GetScriptTotalSize","__ZL16GetAtomTotalSizeP9JSContextP6JSAtom","_JS_IsSystemObject","_JS_MakeSystemObject","_js_RevertVersion","_JS_ClearContextDebugHooks","_JS_PauseProfilers","_JS_ResumeProfilers","_JS_DumpCompartmentBytecode","__ZN2js13WatchpointMapC1Ev","__ZN2js13WatchpointMapC2Ev","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZNK8JSObject10structSizeEv","__ZNK2js5Shape10entryCountEv","__ZN2JSL11StringValueEP8JSString1079","__ZN2JSL10Int32ValueEi1081","__ZN2JSL11ObjectValueER8JSObject1084","__ZNK2js7HashMapIPhPNS_14BreakpointSiteENS_13DefaultHasherIS1_EENS_18RuntimeAllocPolicyEE5emptyEv","_JS_DHashAllocTable","_JS_DHashFreeTable","_JS_DHashFinalizeStub","_JS_DHashGetStubOps","_JS_DHashMatchEntryStub","_JS_DHashTableSetAlphaBounds","__ZL13FindFreeEntryP12JSDHashTablej","_JS_DHashMatchStringKey","_JS_DHashMoveEntryStub","_JS_DHashClearEntryStub","_JS_DHashFreeStringKey","_JS_NewDHashTable","_JS_DHashTableInit","_JS_DHashTableDestroy","_JS_DHashTableFinish","_JS_DHashTableOperate","__ZL11SearchTableP12JSDHashTablePKvj15JSDHashOperator","__ZL11ChangeTableP12JSDHashTablei","_JS_DHashTableRawRemove","_JS_DHashTableEnumerate","_js_strtod_harder","__strtod","_js_dtostr","_dtoa","__ZL6divremP6Bigintj","__ZL7quorem2P6Biginti","_cmp","_freedtoa","_js_dtobasestr","_d2b","_lshift","_Bfree","_i2b","_multadd","_diff","_js_NewDtoaState","_newdtoa","_js_DestroyDtoaState","_destroydtoa","__Z9dtoa_freePv","__Z11dtoa_mallocj","_lo0bits","_hi0bits","_ulp","_Balloc","_nrv_alloc","_rv_alloc","_pow5mult","_mult","_quorem","_s2b","_ratio","_b2d","__ZN13JSTreeContext5traceEP8JSTracer","__ZN15JSCodeGeneratorC2EPN2js6ParserEj","__ZN13JSTreeContextC2EPN2js6ParserE","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC1EP9JSContext","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES7_","__ZN13JSGCConstListC1EP9JSContext","__ZN14JSCGObjectListC1Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC1ES2_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC1ES1_","__ZN15JSCodeGenerator4initEP9JSContextN13JSTreeContext12InitBehaviorE","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE4initEv","__ZN13JSTreeContext4initEP9JSContextNS_12InitBehaviorE","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZL10GetSpanDepP15JSCodeGeneratorPh","__ZN13JSTreeContext11inStatementE10JSStmtType","__ZNK13JSTreeContext10inFunctionEv","__ZNK2js8Bindings9countVarsEv","__ZN13JSTreeContext18skipSpansGeneratorEj","__ZN13JSTreeContext7blockidEv","__ZN13JSTreeContext10blockChainEv","_js_PopStatement","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE9ensureMapEP9JSContext","__ZN15JSCodeGeneratorD2Ev","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED1Ev","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED1Ev","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED1Ev","__ZN13JSGCConstListD1Ev","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN13JSTreeContextD2Ev","_js_Emit1","__ZL9EmitCheckP9JSContextP15JSCodeGeneratori","__ZL11UpdateDepthP9JSContextP15JSCodeGeneratori","_js_Emit2","_js_Emit3","_js_Emit5","_js_EmitN","_js_SetJumpOffset","__ZL17BuildSpanDepTableP9JSContextP15JSCodeGenerator","__ZL16SetSpanDepTargetP9JSContextP15JSCodeGeneratorP9JSSpanDepi","__ZN13JSTreeContext16ensureSharpSlotsEv","__ZN2js8Bindings11addVariableEP9JSContextP6JSAtom","_js_PushStatement","_js_PushBlockScope","_js_PopStatementCG","__ZL9BackPatchP9JSContextP15JSCodeGeneratoriPhh","_js_DefineCompileTimeConstant","__ZNK11JSParseNode6isKindEN2js9TokenKindE","__ZNK11JSParseNode6isDefnEv","__ZNK13JSTreeContext9callsEvalEv","__ZN15JSCodeGenerator7contextEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv","__ZN2js11UpvarCookie3setEtt","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3putERKS2_RKS4_","__ZN2JSL11NumberValueEd1149","_js_LexicalLookup","__ZL12ATOM_TO_JSIDP6JSAtom1150","__ZN15JSCodeGenerator20shouldNoteClosedNameEP11JSParseNode","__ZNK11JSParseNode8isClosedEv","__ZN15JSCodeGenerator12addGlobalUseEP6JSAtomjPN2js11UpvarCookieE","__ZN2js9InlineMapIP6JSAtomjLj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtrcvPPPPPPPS4_Ev","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtr5valueEv","__ZN2js11UpvarCookie8makeFreeEv","__ZN15JSCodeGenerator13makeAtomIndexEP6JSAtomPj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js9InlineMapIP6JSAtomjLj24EE3addERNS3_6AddPtrERKS2_RKj","_js_EmitFunctionScript","__ZNK13JSTreeContext19needsEagerArgumentsEv","_js_EmitTree","_INT_TO_JSID1151","_INT_FITS_IN_JSID","__ZNK11JSParseNode7getKindEv","__ZNK11JSParseNode5getOpEv","__ZNK13JSFunctionBox8functionEv","__ZN13JSTreeContext11setFunctionEP10JSFunction","__ZN14JSCGObjectList5indexEP11JSObjectBox","__ZNK2js11UpvarCookie6isFreeEv","__ZNK2js11UpvarCookie4slotEv","__ZNK11JSParseNode4lastEv","__ZN11JSParseNode16getConstantValueEP9JSContextbPN2JS5ValueE","__ZN2js5types12FixArrayTypeEP9JSContextP8JSObject","__ZN2jsL17GuessObjectGCKindEjb1152","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1153","__Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPi","__ZN2js5types13FixObjectTypeEP9JSContextP8JSObject","__ZN16EmitLevelManagerC1EP15JSCodeGenerator","_js_NewSrcNote2","_js_NewSrcNote","__ZNK11JSParseNode7isArityE16JSParseNodeArity","__ZL18EmitFunctionDefNopP9JSContextP15JSCodeGeneratorj","__ZN9JSContext4new_I15JSCodeGeneratorPN2js6ParserEjEEPT_T0_T1_","__ZN2js8Bindings8transferEP9JSContextPS0_","__ZN9JSContext7delete_I15JSCodeGeneratorEEvPT_","__ZL11EmitIndexOpP9JSContext4JSOpjP15JSCodeGeneratorPS1_","__ZL14EmitBlockChainP9JSContextP15JSCodeGenerator","__ZL10BindGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeP6JSAtom","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendItEEbT_","__ZL15EmitSlotIndexOpP9JSContext4JSOpjjP15JSCodeGenerator","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE8clearMapEv","__ZL14BindNameToSlotP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE10releaseMapEP9JSContext","_js_SetSrcNoteOffset","__ZL8EmitJumpP9JSContextP15JSCodeGenerator4JSOpi","__ZL8EmitGotoP9JSContextP15JSCodeGeneratorP10JSStmtInfoPij13JSSrcNoteType","__ZL10EmitSwitchP9JSContextP15JSCodeGeneratorP11JSParseNodeP10JSStmtInfo","__ZL11EmitTraceOpP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZN12TempPopScopeC1Ev","__ZN2jsL15TokenKindIsDeclENS_9TokenKindE","__ZNK11JSParseNode4exprEv","__ZNK2js11UpvarCookie9asIntegerEv","__ZL12CheckTypeSetP9JSContextP15JSCodeGenerator4JSOp","__ZN12TempPopScope8popBlockEP9JSContextP15JSCodeGenerator","__ZN12TempPopScope11repushBlockEP9JSContextP15JSCodeGenerator","__ZL14EmitAssignmentP9JSContextP15JSCodeGeneratorP11JSParseNode4JSOpS4_","__ZNK11JSParseNode4isOpE4JSOp","__ZL24MaybeEmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePS3_","__ZL10NewTryNoteP9JSContextP15JSCodeGenerator13JSTryNoteKindjjj","__ZL15EmitBackPatchOpP9JSContextP15JSCodeGenerator4JSOpPi","__ZL19EmitKnownBlockChainP9JSContextP15JSCodeGeneratorP11JSObjectBox","__ZL14EmitLeaveBlockP9JSContextP15JSCodeGenerator4JSOpP11JSObjectBox","__ZL21UpdateLineNumberNotesP9JSContextP15JSCodeGeneratorj","__ZL20EmitDestructuringOpsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZN11JSParseNode5setOpE4JSOp","__ZNK11JSParseNode25isDirectivePrologueMemberEv","__ZL13EmitVariablesP9JSContextP15JSCodeGeneratorP11JSParseNodeiPi","__ZL21EmitNonLocalJumpFixupP9JSContextP15JSCodeGeneratorP10JSStmtInfo","__ZL16CheckSideEffectsP9JSContextP15JSCodeGeneratorP11JSParseNodePi","__ZL17SetBackPatchDeltaP9JSContextP15JSCodeGeneratorPhi","__ZL13GetJumpOffsetP15JSCodeGeneratorPh","__ZL10EmitAtomOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratorPS3_","__ZL11EmitXMLNameP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL14EmitNameIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZNK11JSParseNode7isConstEv","__ZL14EmitPropIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL14EmitElemIncDecP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL10EmitPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGeneratoriPS3_","__ZL10EmitElemOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL10EmitNameOpP9JSContextP15JSCodeGeneratorP11JSParseNodei","__ZL19FitsWithoutBigIndexj","__ZNK15JSCodeGenerator9hasSharpsEv","__ZNK13JSTreeContext12compileAndGoEv","__ZL14EmitEnterBlockP9JSContextP11JSParseNodeP15JSCodeGenerator","__ZL15AdjustBlockSlotP9JSContextP15JSCodeGeneratori","__ZL11EmitNewInitP9JSContextP15JSCodeGenerator10JSProtoKeyP11JSParseNodei","__ZL11EmitEndInitP9JSContextP15JSCodeGeneratorj","__ZN15JSCodeGenerator21checkSingletonContextEv","__ZL24EmitSingletonInitialiserP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZL12EmitNumberOpP9JSContextdP15JSCodeGenerator","__ZN2JSL14UndefinedValueEv1154","__ZNK8JSObject16inDictionaryModeEv","__ZL12EmitObjectOpP9JSContextP11JSObjectBox4JSOpP15JSCodeGenerator","_js_SrcNoteLength","_js_GetSrcNoteOffset","__ZL16OptimizeSpanDepsP9JSContextP15JSCodeGenerator","__ZN16EmitLevelManagerD1Ev","__ZL12AllocSrcNoteP9JSContextP15JSCodeGenerator","_js_NewSrcNote3","_js_AddToSrcNoteDelta","__ZL12GrowSrcNotesP9JSContextP15JSCodeGenerator","__ZL23ReportStatementTooLargeP9JSContextP15JSCodeGenerator","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN14JSCGObjectList6finishEP13JSObjectArray","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE3endEv","__ZN9JSContext12parseMapPoolEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13copyConstructIjEEvPjPKT_S7_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_15GlobalSlotArray5EntryEEcvRS2_Ev","__ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC2ERS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEptEv","_js_FinishTakingSrcNotes","_js_FinishTakingTryNotes","__ZN13JSGCConstList6finishEP12JSConstArray","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEE","__ZN2js12ParseMapPool7recycleEPv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIjLj8ES1_EEj","__ZN2js10VectorImplIjLj8ENS_15TempAllocPolicyELb1EE13moveConstructIjEEvPjPKT_S7_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_15GlobalSlotArray5EntryEEC1ERS2_","__ZN2js10VectorImplINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_15GlobalSlotArray5EntryEEENS_7MoveRefIT_EERKS4_","__ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEEEC1ERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEptEv","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZNK2js6VectorIPvLj32ENS_17SystemAllocPolicyEE5emptyEv","__ZN2js9InlineMapIP6JSAtomjLj24EE5clearEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popBackEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE8clearMapEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEptEv","__ZN2js12HashMapEntryIP6JSAtomjEC2Ev","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1ERS6_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomN2JS5ValueEEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomN2JS5ValueEEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomjLj24EEEEEPT_v","__ZN2js12ParseMapPool8allocateEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE7popCopyEv","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEE4backEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEED2Ev","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE10releaseMapEP9JSContext","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomjLj24EEE","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEC2ES1_","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEC2ES2_","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZN2js20OwnedAtomThingMapPtrINS_15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEEEC2EP9JSContext","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE4initEv","__ZN2js9InlineMapIP6JSAtomjLj24EE12switchAndAddERKS2_RKj","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEEEC1ERS7_","__ZN2js12HashMapEntryIP6JSAtomjEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomjEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomjEEEC1ERS4_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomjEC1Ev","__ZN2js9InlineMapIP6JSAtomjLj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKj","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","_JSDOUBLE_IS_NEGZERO1166","__ZN11JSParseNode7setKindEN2js9TokenKindE","__ZN11JSParseNode8setArityE16JSParseNodeArity","__ZNK11JSParseNode8getArityEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomjEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_jEE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5countEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11initializedEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2EPNS3_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE","__ZL13StatementNameP15JSCodeGenerator","__ZN16EmitLevelManagerD2Ev","__ZL18FindNearestSpanDepP15JSCodeGeneratoriiP9JSSpanDep","__ZNK2js5Shape12inDictionaryEv","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK13JSTreeContext12inStrictModeEv","__ZNK13JSTreeContext16mutatesParameterEv","__ZL21UpdateDecomposeLengthP15JSCodeGeneratorj","__ZNK11JSParseNode4testEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js9InlineMapIP6JSAtomjLj24EE5countEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZNK2js9InlineMapIP6JSAtomjLj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomjLj24EE6AddPtrC1EPNS3_10InlineElemEb","__ZL17UpdateJumpTargetsP12JSJumpTargetii","__ZL15FreeJumpTargetsP15JSCodeGeneratorP12JSJumpTarget","_JSDOUBLE_IS_INT321163","__ZN13JSGCConstList6appendEN2JS5ValueE","__ZN2JSL11DoubleValueEd1164","__ZNK13JSGCConstList6lengthEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIN2JS5ValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN13JSTreeContext16needStrictChecksEv","__ZNK11JSParseNode9frameSlotEv","__ZN2JSL12BooleanValueEb1168","__ZN8JSObject16setBlockOwnShapeEP9JSContext","__ZL14EmitElemOpBaseP9JSContextP15JSCodeGenerator4JSOp","__ZN11JSParseNode9maybeExprEv","__ZL17EmitSpecialPropOpP9JSContextP11JSParseNode4JSOpP15JSCodeGenerator","__ZL9FlushPopsP9JSContextP15JSCodeGeneratorPi","__ZL22EmitDestructuringDeclsP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZL12OpToDeclType4JSOp","__ZN13JSTreeContext15asCodeGeneratorEv","__ZNK11JSParseNode6isUsedEv","__ZN12TempPopScopeC2Ev","__ZNK13JSTreeContext10scopeChainEv","__ZNK2js5Shape16hasDefaultGetterEv","__ZL16MaybeEmitVarDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodePj","__ZL21EmitDestructuringDeclP9JSContextP15JSCodeGenerator4JSOpP11JSParseNode","__ZL26EmitDestructuringOpsHelperP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZL20EmitDestructuringLHSP9JSContextP15JSCodeGeneratorP11JSParseNode","__ZNK11JSParseNode13isInitializedEv","__ZL18EmitBigIndexPrefixP9JSContextP15JSCodeGeneratorj","__ZL19EmitGroupAssignmentP9JSContextP15JSCodeGenerator4JSOpP11JSParseNodeS5_","__ZL25LookupCompileTimeConstantP9JSContextP15JSCodeGeneratorP6JSAtomPN2JS5ValueE","__ZL22AllocateSwitchConstantP9JSContext","__ZL17AddSwitchSpanDepsP9JSContextP15JSCodeGeneratorPh","__ZL10AddSpanDepP9JSContextP15JSCodeGeneratorPhS3_i","__ZNK2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZNK2js8Bindings10hasBindingEP9JSContextP6JSAtom","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK11JSParseNode13isDeoptimizedEv","__ZN12JSDefinition4kindEv","__ZNK11JSParseNode10isTopLevelEv","__ZNK12JSDefinition8isGlobalEv","__ZL14JSID_FROM_BITSj1189","__ZNK13JSTreeContext16mightAliasLocalsEv","__ZNK13JSTreeContext3funEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEptEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5emptyEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE11allocPolicyEv","__ZNK2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js7MoveRefINS_11UpvarCookieEEcvRS1_Ev","__ZN2js7MoveRefINS_11UpvarCookieEEC2ERS1_","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE8usingMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5countEv","__ZN13JSTreeContext8compilerEv","__ZNK2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEE5beginEv","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2EPNS3_10InlineElemE","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE","__ZN16EmitLevelManagerC2EP15JSCodeGenerator","__ZN2js2gcL15GetGCObjectKindEjb1183","__ZNK13JSTreeContext13usesArgumentsEv","__ZL18BalanceJumpTargetsPP12JSJumpTarget","__ZNK2js11TokenStream11getFilenameEv","__ZL17TryConvertToGnameP15JSCodeGeneratorP11JSParseNodeP4JSOp","__ZN2js8Bindings8addUpvarEP9JSContextP6JSAtom","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5countEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE16replaceRawBufferEPS1_j","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEEixEj","__ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERKS3_","__ZN2js7MoveRefINS_11UpvarCookieEEC1ERS1_","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_11UpvarCookieELj8ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj8ES2_EEj","__ZN2js4MoveINS_11UpvarCookieEEENS_7MoveRefIT_EERS3_","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5countEv","__ZNK11JSParseNode5isLetEv","__ZL15BindKnownGlobalP9JSContextP15JSCodeGeneratorP11JSParseNodeS4_P6JSAtom","__ZN2js9InlineMapIP6JSAtomjLj24EE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomjLj24EE3Ptr5valueEv","__ZN2js6VectorINS_15GlobalSlotArray5EntryELj16ENS_15TempAllocPolicyEEixEj","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_jEENS_7HashMapIS2_jNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESC_E3PtrE","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomjLj24EE3PtrC1EPNS3_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1177","__ZL13AddJumpTargetP17AddJumpTargetArgsPP12JSJumpTarget","_js_GetStackUses","__ZN2JSL10Int32ValueEi1190","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED1Ev","__ZN2js9AtomDeclsD1Ev","__ZN2js9AtomDeclsD2Ev","__ZN2js12ParseMapPool7releaseEPNS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEE","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEED2Ev","__ZN2js7HashMapIP6JSAtomN2JS5ValueENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN13JSGCConstListD2Ev","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN14JSCGObjectListC2Ev","__ZN2js9AtomDeclsC2EP9JSContext","__ZNK8JSObject7isErrorEv","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js9AtomDecls4initEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE9ensureMapEP9JSContext","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEEEPT_v","__ZN2js12ParseMapPool7acquireINS_9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EEEEEPT_v","__ZN13JSGCConstListC2EP9JSContext","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js9AtomDeclsC1EP9JSContext","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC1EP9JSContext","__ZN2js20OwnedAtomThingMapPtrINS_14AtomDefnMapPtrEEC2EP9JSContext","__ZL11exn_resolveP9JSContextP8JSObjectijPS2_","__ZL12exn_finalizeP9JSContextP8JSObject","__ZL9exn_traceP8JSTracerP8JSObject","__Z21js_ErrorFromExceptionP9JSContextN2JS5ValueE","_JSVAL_IS_PRIMITIVE","_JSVAL_TO_OBJECT1203","__ZL13GetExnPrivateP8JSObject","__ZL12exn_toSourceP9JSContextjPN2JS5ValueE","__ZL12exn_toStringP9JSContextjPN2JS5ValueE","__Z23js_InitExceptionClassesP9JSContextP8JSObject","__ZL14InitErrorClassP9JSContextPN2js12GlobalObjectEiR8JSObject","__Z27js_GetLocalizedErrorMessageP9JSContextPvPKcj","__ZL20GetExceptionProtoKeyi","__Z19js_ErrorToExceptionP9JSContextPKcP13JSErrorReportPFPK19JSErrorFormatStringPvS2_jES8_","__ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_","_OBJECT_TO_JSVAL1210","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_","_STRING_TO_JSVAL1211","__ZL14InitExnPrivateP9JSContextP8JSObjectP8JSStringS4_jP13JSErrorReporti","__Z26js_ReportUncaughtExceptionP9JSContext","__ZN2jsL12PodArrayZeroIN2JS5ValueELj5EEEvRAT0__T_","_JSVAL_IS_STRING","__ZN16JSAutoByteString5clearEv","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_1214","_JSVAL_TO_STRING","__Z18js_CopyErrorObjectP9JSContextP8JSObjectS2_","__ZL14JSID_FROM_BITSj1226","_JSVAL_TO_STRING_IMPL1217","_JSVAL_IS_STRING_IMPL1221","_JSVAL_TO_OBJECT_IMPL1225","__ZL13JSVAL_TO_IMPLN2JS5ValueE1218","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN9AppendArgC2ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE3endEv","__ZNK2js7MoveRefI16JSStackTraceElemEcvRS1_Ev","__ZN2js7MoveRefI16JSStackTraceElemEC2ERS1_","__ZL13IMPL_TO_JSVAL12jsval_layout1228","_STRING_TO_JSVAL_IMPL1229","__ZN2js2gcL15GetGCObjectKindEjb1230","_OBJECT_TO_JSVAL_IMPL1238","__ZL15CopyErrorReportP9JSContextP13JSErrorReport","__ZZ18js_CopyErrorObjectP9JSContextP8JSObjectS2_EN8AutoFreeD2Ev","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC1ES2_","__ZN19SuppressErrorsGuardC1EP9JSContext","__ZNK2js10StackFrame11compartmentEv","__ZN2JSL9NullValueEv1222","__ZL12ATOM_TO_JSIDP6JSAtom1223","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE6growByEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE4backEv","__ZN2js10StackFrame25forEachCanonicalActualArgI9AppendArgEEbT_jj","__ZN9AppendArgC1ERN2js6VectorIN2JS5ValueELj0ENS0_15TempAllocPolicyEEE","__ZN19SuppressErrorsGuardD1Ev","__ZN2jsL7PodCopyI16JSStackTraceElemEEvPT_PKS2_j","__ZN2jsL7PodCopyIN2JS5ValueEEEvPT_PKS3_j1224","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN19SuppressErrorsGuardD2Ev","__ZN9AppendArgclEjPN2JS5ValueE","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE10growByImplILb1EEEbj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE10initializeEPS1_S4_","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj","__ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefI16JSStackTraceElemEC1ERS1_","__ZN2js10VectorImplI16JSStackTraceElemLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveI16JSStackTraceElemEENS_7MoveRefIT_EERKS3_","__ZN19SuppressErrorsGuardC2EP9JSContext","__ZN2js6VectorI16JSStackTraceElemLj0ENS_15TempAllocPolicyEEC2ES2_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1231","__ZN2JSL11StringValueEP8JSString1239","__ZN2JSL10Int32ValueEi1240","_JSID_IS_STRING1247","_JSVAL_IS_PRIMITIVE_IMPL1252","_JSID_TO_STRING1254","_JSVAL_TO_GCTHING_IMPL1256","_JSVAL_IS_TRACEABLE_IMPL1257","_INT32_TO_JSVAL_IMPL1251","__ZL24GetStackTraceValueBufferP12JSExnPrivate","_JS_GetAnonymousString","_JS_GetCompartmentPrincipals","__ZN2JS23AutoPreserveCompartmentC2EP9JSContext","__ZN2JS23AutoPreserveCompartmentD2Ev","__ZL9ExceptionP9JSContextjPN2JS5ValueE","__ZL16FilenameToStringP9JSContextPKc","__ZL12JSID_IS_ATOMi1253","_INT_TO_JSVAL","__ZL18StackTraceToStringP9JSContextP12JSExnPrivate","__ZL18ValueToShortSourceP9JSContextRKN2JS5ValueE","_JSVAL_IS_TRACEABLE","_JSVAL_TO_GCTHING","_JSVAL_TRACE_KIND","_JSVAL_TRACE_KIND_IMPL","_JS_FindCompilationScope","_JS_UnwrapObject","_JS_GetFrameScopeChainRaw","_JS_SplicePrototype","_JS_NewObjectWithUniqueType","_JS_ObjectCountDynamicSlots","__ZNK8JSObject13hasSlotsArrayEv","__ZNK8JSObject15numDynamicSlotsEj","_JS_WrapPropertyDescriptor","__ZN2JS21AutoSwitchCompartmentC2EP9JSContextP13JSCompartment","__ZN2JS21AutoSwitchCompartmentC2EP9JSContextP8JSObject","_JS_GetE4XObjectsCreated","_JS_SetProtoCalled","_JS_GetCustomIteratorCount","_JSID_IS_INT1285","_JSID_TO_INT1286","__ZN2JS21AutoSwitchCompartmentD2Ev","__ZNK2js10StackFrame17hasOverriddenArgsEv","__ZNK2js10StackFrame16isEvalInFunctionEv","__ZN2js10StackFrame10setArgsObjERNS_15ArgumentsObjectE","__ZN2jsL20CallObjectLambdaNameEP10JSFunction","__ZN2js10StackFrame27setScopeChainWithOwnCallObjERNS_10CallObjectE","__Z15js_GetArgsValueP9JSContextPN2js10StackFrameEPN2JS5ValueE","__Z16js_GetArgsObjectP9JSContextPN2js10StackFrameE","__Z18js_GetArgsPropertyP9JSContextPN2js10StackFrameEiPN2JS5ValueE","__ZNK2js10StackFrame12maybeArgsObjEv","__ZNK2js10StackFrame14functionScriptEv","__ZL12JSID_IS_ATOMiP6JSAtom1287","__ZN2js15ArgumentsObject6createEP9JSContextjR8JSObject","__ZN2js10EmptyShape22getEmptyArgumentsShapeEP9JSContext","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueEj1288","__ZN2js15ArgumentsObject16setInitialLengthEj","__ZN2js15ArgumentsObject16setCalleeAndDataER8JSObjectPNS_13ArgumentsDataE","__ZN2js10StackFrame25forEachCanonicalActualArgI6PutArgEEbT_jj","__ZN6PutArgC1EPN2JS5ValueE","__Z16js_PutArgsObjectPN2js10StackFrameE","__ZL16args_delPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14args_enumerateP9JSContextP8JSObject","__ZL12args_resolveP9JSContextP8JSObjectijPS2_","__ZL13args_finalizeP9JSContextP8JSObject","__ZL10args_traceP8JSTracerP8JSObject","__ZL20strictargs_enumerateP9JSContextP8JSObject","__ZL18strictargs_resolveP9JSContextP8JSObjectijPS2_","__ZN2js19CreateFunCallObjectEP9JSContextPNS_10StackFrameE","__ZL16NewDeclEnvObjectP9JSContextPN2js10StackFrameE","__ZL12ATOM_TO_JSIDP6JSAtom1293","__ZN2JSL11ObjectValueER8JSObject1294","__ZN2js10CallObject13setStackFrameEPNS_10StackFrameE","__ZN2js20CreateEvalCallObjectEP9JSContextPNS_10StackFrameE","__Z26js_CreateCallObjectOnTraceP9JSContextP10JSFunctionP8JSObjectS4_","__ZeqRK8JSObjectS1_","__ZNK2js8Bindings9countArgsEv","__ZN10JSFunction14compiledFunObjEv","__ZN8JSObject16hasMethodBarrierEv","__ZNK2js5Shape7hasSlotEv","__ZN8JSObject11clearParentEv","__ZN8JSObject9clearTypeEv","__Z16js_PutCallObjectPN2js10StackFrameE","__ZN2js10CallObject12setArgumentsERKN2JS5ValueE","__ZNK2js10CallObject9isForEvalEv","__ZN2js10CallObject10copyValuesEjPN2JS5ValueEjS3_","__ZN2js10CallObject6setArgEjRKN2JS5ValueE","__ZN2js10CallObject6setVarEjRKN2JS5ValueE","__ZN2js10CallObject8argArrayEv","__ZN2js10CallObject8varArrayEv","__Z23js_PutCallObjectOnTraceP8JSObjectjPN2JS5ValueEjS3_","__ZN2js10GetCallArgEP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK2js10CallObject15maybeStackFrameEv","__ZNK2js10CallObject3argEj","__ZN2js10SetCallArgEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZNK2js10CallObject17getCalleeFunctionEv","__ZN8JSScript14ensureHasTypesEP9JSContextP10JSFunction","__ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjRKN2JS5ValueE","__ZN2js12GetCallUpvarEP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK2js10CallObject9getCalleeEv","__ZN8JSObject19getFlatClosureUpvarEj","__ZN2js12SetCallUpvarEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject19setFlatClosureUpvarEjRKN2JS5ValueE","__ZN2js10GetCallVarEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js10StackFrame7varSlotEj","__ZNK2js10CallObject3varEj","__ZN2js10SetCallVarEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjRKN2JS5ValueE","__ZL12call_resolveP9JSContextP8JSObjectijPS2_","__ZL10call_traceP8JSTracerP8JSObject","__ZN2js10StackFrame20getValidCalleeObjectEP9JSContextPN2JS5ValueE","__ZNK2js10StackFrame12functionThisEv","__ZNK10JSFunction10methodAtomEv","__ZN2js10StackFrame15overwriteCalleeER8JSObject","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1303","__ZNK8JSObject12hasMethodObjERKS_","__Z20js_XDRFunctionObjectP10JSXDRStatePP8JSObject","__Z14js_NewFunctionP9JSContextP8JSObjectPFiS0_jPN2JS5ValueEEjjS2_P6JSAtom","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZL13fun_enumerateP9JSContextP8JSObject","__ZL11fun_resolveP9JSContextP8JSObjectijPS2_","__ZL12fun_finalizeP9JSContextP8JSObject","__ZL15fun_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL9fun_traceP8JSTracerP8JSObject","__Z18fun_toStringHelperP9JSContextP8JSObjectj","__ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN7mozilla5MaybeIN2js7HashMapIP10JSFunctionP8JSStringNS1_13DefaultHasherIS4_EENS1_17SystemAllocPolicyEEEE9constructEv","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3putERKS2_RKS4_","__Z11js_fun_callP9JSContextjPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE1306","__Z12js_fun_applyP9JSContextjPN2JS5ValueE","__ZN2js28CallOrConstructBoundFunctionEP9JSContextjPN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE1307","__ZNK8JSObject29getBoundFunctionArgumentCountEv","__ZNK8JSObject22getBoundFunctionTargetEv","__ZNK8JSObject20getBoundFunctionThisEv","__ZNK8JSObject24getBoundFunctionArgumentEj","__ZL12fun_toSourceP9JSContextjPN2JS5ValueE","__ZL12fun_toStringP9JSContextjPN2JS5ValueE","__ZL8fun_bindP9JSContextjPN2JS5ValueE","__ZL15fun_isGeneratorP9JSContextjPN2JS5ValueE","__ZN2jsL3MinIPN2JS5ValueEEET_S4_S4_","__ZNK2js11TokenStream12currentTokenEv","__ZN2JS6AnchorIP8JSStringE3setERKS2_","__ZNK2js8Bindings11countUpvarsEv","__ZNK2js8Bindings9hasUpvarsEv","__ZNK8JSObject10isDelegateEv","__ZN8JSObject13clearDelegateEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js8FunctionEP9JSContextjPN2JS5ValueE","__ZN2js24CurrentScriptFileAndLineEP9JSContextPjNS_10LineOptionE","__ZN2js18AutoArenaAllocator5allocItEEPT_j","__ZN2js11TokenStream8getTokenEv","__ZL11OnBadFormalP9JSContextN2js9TokenKindE","__ZN2js28IsBuiltinFunctionConstructorEP10JSFunction","__ZN2js34LookupInterpretedFunctionPrototypeEP9JSContextP8JSObject","__ZL35ResolveInterpretedFunctionPrototypeP9JSContextP8JSObject","__ZN2jsL11NewFunctionEP9JSContextP8JSObject","__Z22js_CloneFunctionObjectP9JSContextP10JSFunctionP8JSObjectS4_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_1314","__ZN2js8Debugger11onNewScriptEP9JSContextP8JSScriptP8JSObjectNS0_13NewScriptKindE","__Z19js_AllocFlatClosureP9JSContextP10JSFunctionP8JSObject","__ZN8JSObject20setFlatClosureUpvarsEPN2JS5ValueE","__Z17js_NewFlatClosureP9JSContextP10JSFunction4JSOpj","__Z17js_DefineFunctionP9JSContextP8JSObjectiPFiS0_jPN2JS5ValueEEjj","__ZL12JSID_IS_ATOMi1319","__ZL12JSID_TO_ATOMi1320","__Z18js_ValueToFunctionP9JSContextPKN2JS5ValueEj","__Z22js_ReportIsNotFunctionP9JSContextPKN2JS5ValueEj","__Z24js_ValueToFunctionObjectP9JSContextPN2JS5ValueEj","__Z24js_ValueToCallableObjectP9JSContextPN2JS5ValueEj","__ZNK2js13FrameRegsIter2spEv","__ZNK2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","_JSVAL_TO_PRIVATE_UINT32_IMPL","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10isLiveHashEj","__ZN2js13PointerHasherIP10JSFunctionLj2EE5matchERKS2_S5_","__ZN2js13PointerHasherIP10JSFunctionLj2EE4hashERKS2_","_JSID_TO_STRING1332","_JSID_IS_STRING1333","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE1345","__ZN2jsL16CastAsPropertyOpEP8JSObject1357","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject1358","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEptEv","__ZNK2js7MoveRefIP10JSFunctionEcvRS2_Ev","__ZNK2js7MoveRefIP8JSStringEcvRS2_Ev","__ZN2js7MoveRefIP8JSStringEC2ERS2_","__ZN2js7MoveRefIP10JSFunctionEC2ERS2_","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE12setCollisionEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZNK2js9StackIter2spEv","__ZN2js2gcL15GetGCObjectKindEjb1337","_PRIVATE_UINT32_TO_JSVAL_IMPL","__ZNK8JSObject15isBoundFunctionEv","__ZNK10JSFunction19isFunctionPrototypeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEEEC1ERS9_","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP10JSFunctionP8JSStringEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1ERS6_","__ZN2js4MoveIP10JSFunctionEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIP8JSStringEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIP8JSStringEC1ERS2_","__ZN2js7MoveRefIP10JSFunctionEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP10JSFunctionP8JSStringEEEC2Ev","__ZN2js12HashMapEntryIP10JSFunctionP8JSStringEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC1ES7_","__ZN2js7HashMapIP10JSFunctionP8JSStringNS_13DefaultHasherIS2_EENS_17SystemAllocPolicyEEC2ES7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP10JSFunctionP8JSStringEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_17SystemAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZN6PutArgclEjPN2JS5ValueE","__ZN2JSL12PrivateValueEPv1335","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1338","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1342","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_1343","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1344","__ZN2JSL12BooleanValueEb1348","__ZN2JSL14UndefinedValueEv1350","__ZN8JSObject17initBoundFunctionEP9JSContextRKN2JS5ValueEPS4_j","__ZN2JSL18PrivateUint32ValueEj","__ZN2JS5Value16setPrivateUint32Ej","__ZNK2JS5Value15toPrivateUint32Ev","__ZN8JSObject27finalizeUpvarsIfFlatClosureEv","__ZNK8JSObject17getThrowTypeErrorEv","__ZL14JSID_FROM_BITSj1372","__ZN2js2gc5Arena13staticAssertsEv","__ZN2js7analyzeL7ArgSlotEj1371","_INT_TO_JSID1373","__ZN8JSObject17asStrictArgumentsEv","__ZN8JSObject17asNormalArgumentsEv","__ZNK10JSFunction8joinableEv","__ZNK2js10StackFrame19isFloatingGeneratorEv","__ZN2js10StackFrame17setOverriddenArgsEv","__ZN6PutArgC2EPN2JS5ValueE","__ZN2js2gc11ArenaHeader17setAsNotAllocatedEv","__ZN2js2gc11ArenaHeader4initEP13JSCompartmentNS0_9AllocKindE","__ZNK2js2gc5Chunk18hasAvailableArenasEv","__ZN2js2gc5Chunk23removeFromAvailableListEv","__ZL15fun_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1359","__ZNK2js12GlobalObject17getThrowTypeErrorEv","__ZN8JSObject11hasPropertyEP9JSContextiPbj","__ZL18MaybeMarkGeneratorP8JSTracerP8JSObject","__ZN2jsL16GetCallArgumentsEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2jsL16SetCallArgumentsEP9JSContextP8JSObjectiiPN2JS5ValueE","__ZNK2js10CallObject12getArgumentsEv","__ZN2js5types10TypeScript8SetLocalEP9JSContextP8JSScriptjNS0_4TypeE","__ZN2js5types10TypeScript10LocalTypesEP8JSScriptj","__ZN2js5types7TypeSet7hasTypeENS0_4TypeE","__ZN2js5typesL15HashSetCapacityEj1366","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1367","__ZN2js5typesL13HashSetLookupIPNS0_13TypeObjectKeyES2_S2_EEPT0_PS5_jT_","__ZN2js7analyzeL9LocalSlotEP8JSScriptj1368","__ZN2js5types10TypeScript11SetArgumentEP9JSContextP8JSScriptjNS0_4TypeE","__ZN2js5types10TypeScript8ArgTypesEP8JSScriptj","__ZN2js10EmptyShape20getEmptyDeclEnvShapeEP9JSContext","__ZN2js10EmptyShape6ensureEP9JSContextPNS_5ClassEPPS0_","__ZL15StrictArgGetterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL15StrictArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2js15ArgumentsObject10setElementEjRKN2JS5ValueE","__ZNK2js21NormalArgumentsObject6calleeEv","__ZL9ArgGetterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL9ArgSetterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2JSL10MagicValueE10JSWhyMagic1374","__ZN2js15ArgumentsObject20markLengthOverriddenEv","__ZN2js21NormalArgumentsObject11clearCalleeEv","__ZN2JSL10Int32ValueEi1375","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1378","__ZN2js2gc5Chunk4initEv","__ZN2js2gc11ChunkBitmap5clearEv","__ZN2js2gc5Chunk13allocateArenaEP13JSCompartmentNS0_9AllocKindE","__ZN2jsL3MaxIjEET_S1_S1_","__ZN2jsL3MinIfEET_S1_S1_","__ZNK2JS5Value11payloadWordEv","__ZNK2js2gc5Chunk6unusedEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE5clearEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5emptyEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN9JSRuntime20reduceGCTriggerBytesEj","__ZN13JSCompartment20reduceGCTriggerBytesEj","__ZN2js2gc11IsGCAllowedEP9JSContext","__ZN2js20TriggerCompartmentGCEP13JSCompartment","__ZN2js2gc5Chunk12releaseArenaEPNS0_11ArenaHeaderE","__ZN2js2gc5Chunk18addToAvailableListEP13JSCompartment","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeERKS3_","__Z20IsAboutToBeFinalizedP9JSContextPKv","__ZNK2js2gc4Cell8isMarkedEj","__Z18js_GCThingIsMarkedPvj","__Z9js_InitGCP9JSRuntimej","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE4initEj","__ZN9JSRuntime14setGCLastBytesEj18JSGCInvocationKind","__ZN2js28MarkStackRangeConservativelyEP8JSTracerPN2JS5ValueES4_","__ZN2jsL23MarkRangeConservativelyEP8JSTracerPKjS3_","__ZN2js26MarkConservativeStackRootsEP8JSTracer","__ZN2jsL28MarkThreadDataConservativelyEP8JSTracerPNS_10ThreadDataE","__ZN2js24ConservativeGCThreadData14recordStackTopEv","__Z11js_FinishGCP9JSRuntime","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3allEv","__Z14ReleaseGCChunkP9JSRuntimePN2js2gc5ChunkE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5Range8popFrontEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE5clearEv","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE5clearEv","__Z10js_AddRootP9JSContextPN2JS5ValueEPKc","_js_AddRootRT","__Z17js_AddGCThingRootP9JSContextPPvPKc","_js_AddGCThingRootRT","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_","__ZN2js8RootInfoC1EPKc12JSGCRootType","_js_RemoveRoot","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeERKS1_","__Z13js_MapGCRootsP9JSRuntimePFiPv12JSGCRootTypePKcS1_ES1_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN13JSCompartment14setGCLastBytesEj18JSGCInvocationKind","__ZN2js2gc10ArenaLists15finalizeObjectsEP9JSContext","__ZN2js2gc10ArenaLists11finalizeNowEP9JSContextNS0_9AllocKindE","__ZN2js2gc10ArenaLists13finalizeLaterEP9JSContextNS0_9AllocKindE","__ZN2js2gc10ArenaLists15finalizeStringsEP9JSContext","__ZN2js2gc10ArenaLists14finalizeShapesEP9JSContext","__ZN2js2gc10ArenaLists15finalizeScriptsEP9JSContext","__ZN2js2gc10ArenaLists14refillFreeListEP9JSContextNS0_9AllocKindE","__ZN2js2gcL14RunLastDitchGCEP9JSContext","__ZN2js2gc10ArenaLists17allocateFromArenaEP13JSCompartmentNS0_9AllocKindE","__ZN2js9TriggerGCEP9JSRuntime","__Z22js_GetGCThingTraceKindPv","__ZN2js2gc19GetGCThingTraceKindEPKv","__ZN2js8GCMarkerD2Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrptEv","__ZNK2js2gc11ArenaHeader21getNextDelayedMarkingEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range5frontEv","__ZNK2js2gc18GCCompartmentsIter4doneEv","__ZN2js2gc18GCCompartmentsIter4nextEv","__Z16js_LockGCThingRTP9JSRuntimePv","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE17lookupWithDefaultERKS1_RKj","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrcvMSB_FvvEEv","__Z18js_UnlockGCThingRTP9JSRuntimePv","__ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6lookupERKS1_","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E3PtrE","__ZN2js8GCMarkerC2EP9JSContext","__ZN2js9MarkStackIP8JSObjectEC1EPPvj","__ZN2js9MarkStackIP6JSRopeEC1EPPvj","__ZN2js9MarkStackIPNS_5types10TypeObjectEEC1EPPvj","__ZN2js9MarkStackIP5JSXMLEC1EPPvj","__ZN2js9MarkStackINS_13LargeMarkItemEEC1EPPvj","__ZN2js8GCMarker20delayMarkingChildrenEPKv","__ZN2js2gc11ArenaHeader21setNextDelayedMarkingEPNS0_5ArenaE","__ZN2js2gc11ArenaHeader8getArenaEv","__ZN2js8GCMarker19markDelayedChildrenEv","__ZN2jsL19MarkDelayedChildrenEPNS_8GCMarkerEPNS_2gc5ArenaE","__Z18js_TraceStackFrameP8JSTracerPN2js10StackFrameE","__ZN2js19AutoEnumStateRooter5traceEP8JSTracer","__ZN2js11MarkContextEP8JSTracerP9JSContext","__ZN2js12AutoGCRooter5traceEP8JSTracer","__ZN2js11MarkRuntimeEP8JSTracer","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv","__ZL17gc_root_traversalP8JSTracerRKN2js12HashMapEntryIPvNS1_8RootInfoEEE","__ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3allEv","__ZL17gc_lock_traversalRKN2js12HashMapEntryIPvjEEP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5Range8popFrontEv","__ZN2js2gc18GCCompartmentsIterC1EP9JSRuntime","__ZNK2js2gc18GCCompartmentsIterptEv","__ZN2js10ThreadData4markEP8JSTracer","__ZN2js7MaybeGCEP9JSContext","__ZN2js2gc10RunDebugGCEP9JSContext","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10isLiveHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5hash2Ejjj","__ZN13AutoGCSessionC2EP9JSContext","__ZN13AutoGCSessionD2Ev","__ZN2js2gcL19MapAllocToTraceKindENS0_9AllocKindE","__ZNK2js2gc12CellIterImpl7getCellEv","__ZN2js9MarkStackINS_13LargeMarkItemEEC2EPPvj","__ZN2js9MarkStackIP5JSXMLEC2EPPvj","__ZN2js9MarkStackIPNS_5types10TypeObjectEEC2EPPvj","__ZN2js9MarkStackIP6JSRopeEC2EPPvj","__ZN2js9MarkStackIP8JSObjectEC2EPPvj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC2ERS3_","__ZNK2js7MoveRefINS_12HashMapEntryIPvjEEEptEv","__ZNK2js7MoveRefIPvEcvRS1_Ev","__ZN2js7MoveRefIPvEC2ERS1_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEv","__Z5js_GCP9JSContextP13JSCompartment18JSGCInvocationKind","__ZN2jsL25RecordNativeStackTopForGCEP9JSContext","__ZL7GCCycleP9JSContextP13JSCompartment18JSGCInvocationKindRN2js7GCTimerE","__ZN2js12TraceRuntimeEP8JSTracer","__ZN2js24AutoCopyFreeListToArenasC1EP9JSRuntime","__ZN2js24AutoCopyFreeListToArenasD1Ev","__ZN2js30IterateCompartmentsArenasCellsEP9JSContextPvPFvS1_S2_P13JSCompartmentEPFvS1_S2_PNS_2gc5ArenaE13JSGCTraceKindjEPFvS1_S2_S2_SA_jE","__ZN2js12AutoUnlockGCC1EP9JSRuntime","__ZN2js22IterateArenaCallbackOpC1EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j","__ZN2js21IterateCellCallbackOpC1EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j","__ZN2js2gc19ForEachArenaAndCellINS_22IterateArenaCallbackOpENS_21IterateCellCallbackOpEEEvP13JSCompartmentNS0_9AllocKindET_T0_","__ZN2js12IterateCellsEP9JSContextP13JSCompartmentNS_2gc9AllocKindEPvPFvS1_S6_S6_13JSGCTraceKindjE","__ZN2js2gc14NewCompartmentEP9JSContextP12JSPrincipals","__ZN9JSContext4new_I13JSCompartmentP9JSRuntimeEEPT_T0_","__Z11js_NewGCXMLP9JSContext","__Z10NewGCThingI5JSXMLEPT_P9JSContextN2js2gc9AllocKindEj","__ZN2js22IterateArenaCallbackOpclEPNS_2gc5ArenaE","__ZN2js2gc5Arena11thingsStartENS0_9AllocKindE","__ZN2js21IterateCellCallbackOpclEPNS_2gc4CellE","__ZNK2js2gc5Arena7addressEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE6isLiveEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeENSA_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11createTableERS7_j","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvjEEEEEC1ERS6_","__ZN2js12HashMapEntryIPvjEaSENS_7MoveRefIS2_EE","__ZN2js4MoveINS_12HashMapEntryIPvjEEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_12HashMapEntryIPvjEEEC1ERS3_","__ZN2js4MoveIPvEENS_7MoveRefIT_EERKS3_","__ZN2js7MoveRefIPvEC1ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEEC2Ev","__ZN2js12HashMapEntryIPvjEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js11GCPtrHasher5matchEPvS1_","__ZN2js11GCPtrHasher4hashEPv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js13PointerHasherIPvLj2EE5matchERKS1_S4_","__ZN2js13PointerHasherIPvLj2EE4hashERKS1_","__ZN2js12HashMapEntryIPvjEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12hasCollisionEv","__ZN2js12HashMapEntryIPvjEaSERKS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE12setCollisionEj","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_jEE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12hasCollisionEv","__ZN2js12HashMapEntryIPvNS_8RootInfoEEaSERKS3_","__ZN2js12HashMapEntryIPvNS_8RootInfoEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEptEv","__ZNK2js7MoveRefINS_8RootInfoEEcvRS1_Ev","__ZN2js7MoveRefINS_8RootInfoEEC2ERS1_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9matchHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE9isRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE12setCollisionEj","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvjEEE7setFreeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E11prepareHashERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5matchERNS0_14HashTableEntryIS4_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E10isLiveHashEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3Ptr5foundEv","__ZNK2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPvjNS_11GCPtrHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_jEENS4_13MapHashPolicyES3_E6AddPtrERKS1_RKj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrEPPS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E3addERNSA_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setFreeEv","__ZN2js12HashMapEntryIPvNS_8RootInfoEEC1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEC1ERS7_","__ZN2js12HashMapEntryIPvNS_8RootInfoEEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIPvNS_8RootInfoEEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIPvNS_8RootInfoEEEEC1ERS4_","__ZN2js4MoveINS_8RootInfoEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_8RootInfoEEC1ERS1_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZNK2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPvNS_8RootInfoENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS3_","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10isLiveHashEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZN2js13GCChunkHasher5matchEPNS_2gc5ChunkES3_","__ZN2js13GCChunkHasher4hashEPNS_2gc5ChunkE","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEE7setLiveEj","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC2Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEptEv","__ZNK2js7MoveRefIPNS_2gc5ChunkEEcvRS3_Ev","__ZN2js7MoveRefIPNS_2gc5ChunkEEC2ERS3_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10getKeyHashEv","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isFreeEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEv","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setFreeEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9matchHashEj","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE9isRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE12setCollisionEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js21IterateCellCallbackOpC2EP9JSContextPvPFvS2_S3_S3_13JSGCTraceKindjES4_j","__ZN2js22IterateArenaCallbackOpC2EP9JSContextPvPFvS2_S3_PNS_2gc5ArenaE13JSGCTraceKindjES7_j","__ZN2js12AutoUnlockGCC2EP9JSRuntime","__ZN2js2gc11ArenaHeader14setAsFullyUsedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E5clearEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPvNS_8RootInfoEEEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5clearEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEEC1Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEC1ERS7_","__ZN2js4MoveIPNS_2gc5ChunkEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefIPNS_2gc5ChunkEEC1ERS3_","__ZNK2js6detail14HashTableEntryIKPNS_2gc5ChunkEE6isLiveEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3allEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC1EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5RangeC2EPNS0_14HashTableEntryIS5_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPvjEENS_7HashMapIS3_jNS_11GCPtrHasherENS_17SystemAllocPolicyEE13MapHashPolicyES7_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPvNS_8RootInfoEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E4initEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6lookupERKS3_","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS3_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_2gc5ChunkEEEEENS_7MoveRefIT_EERS9_","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E11prepareHashERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6lookupERS5_jj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS5_EERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN2js24AutoCopyFreeListToArenasD2Ev","__ZN2js2gc10ArenaLists22clearFreeListsInArenasEv","__ZN2js2gc10ArenaLists20clearFreeListInArenaENS0_9AllocKindE","__ZN2js24AutoCopyFreeListToArenasC2EP9JSRuntime","__ZN2js2gc10ArenaLists21copyFreeListsToArenasEv","__ZN2js2gc10ArenaLists19copyFreeListToArenaENS0_9AllocKindE","__ZL12MarkAndSweepP9JSContext18JSGCInvocationKindRN2js7GCTimerE","__ZNK2js2gc10ArenaLists18arenaListsAreEmptyEv","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE8shrinkByEj","__ZN2js10VectorImplIP13JSCompartmentLj0ENS_17SystemAllocPolicyELb1EE10initializeEPS2_S5_","__ZNK2js2gc18GCCompartmentsIter3getEv","__ZZ5js_GCP9JSContextP13JSCompartment18JSGCInvocationKindEN11AutoGCProbeC2ES2_","__ZNK2js6VectorINS_8PropDescELj1ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIP8JSObjectLj8ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js14AutoValueArray6lengthEv","__ZNK2js14AutoValueArray5startEv","__ZN2js2gc8FreeSpan18infallibleAllocateEj","__ZNK2js10AutoLockGC6lockedEv","__ZN2js10AutoLockGC4lockEP9JSRuntime","__ZN2js2gc8FreeSpan20allocateFromNewArenaEjjj","__Z21GetAvailableChunkListP13JSCompartment","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_2gc5ChunkEE7setLiveEj","__ZN2js13AutoKeepAtomsD2Ev","__ZN2js13AutoKeepAtomsC2EP9JSRuntime","__ZL14BeginMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZL12EndMarkPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZL10SweepPhaseP9JSContextPN2js8GCMarkerE18JSGCInvocationKindRNS1_7GCTimerE","__ZNK2js2gc18GCCompartmentsItercvP13JSCompartmentEv","__ZL25ComputeJitReleaseIntervalP9JSContext","__ZL17SweepCompartmentsP9JSContext18JSGCInvocationKind","__ZL14ExpireGCChunksP9JSRuntime18JSGCInvocationKind","__ZN9JSContext7delete_I13JSCompartmentEEvPT_","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6resizeEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE6growByEj","__ZN2js6VectorIP13JSCompartmentLj0ENS_17SystemAllocPolicyEE10growByImplILb1EEEbj","__ZN2js2gc18GCCompartmentsIterC2EP9JSRuntime","__ZN2js2gc5Arena9thingsEndEv","__ZL9PickChunkP13JSCompartment","__Z15AllocateGCChunkP9JSRuntime","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE12lookupForAddERKS3_","__ZN2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS3_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E12lookupForAddERS5_","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableIKPNS_2gc5ChunkENS_7HashSetIS4_NS_13GCChunkHasherENS_17SystemAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js13AutoKeepAtomsC1EP9JSRuntime","__ZN2js13AutoKeepAtomsD1Ev","__ZNK2js2gc11ArenaHeader13hasFreeThingsEv","__ZNK2js2gc8FreeSpan17nextSpanUncheckedEj","__ZNK16JSExternalString12externalTypeEv","__ZN2js2gcL14FinalizeArenasEP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSObjectEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSScriptEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasINS_5ShapeEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasINS_5types10TypeObjectEEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI5JSXMLEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI8JSStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI13JSShortStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc19FinalizeTypedArenasI16JSExternalStringEEvP9JSContextPNS0_10ArenaLists9ArenaListENS0_9AllocKindE","__ZN2js2gc5Arena8finalizeI16JSExternalStringEEbP9JSContextNS0_9AllocKindEj","__ZN16JSExternalString8finalizeEP9JSContext","__ZN2js2gc5Arena8finalizeI13JSShortStringEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSStringEEbP9JSContextNS0_9AllocKindEj","__ZN8JSString8finalizeEP9JSContext","__ZN2js2gc5Arena8finalizeI5JSXMLEEbP9JSContextNS0_9AllocKindEj","__ZN5JSXML8finalizeEP9JSContext","__ZN2js2gc5Arena8finalizeINS_5types10TypeObjectEEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Chunk17withinArenasRangeEj","__ZN2js2gc5Chunk10arenaIndexEj","__ZN2js14FindChunkStartEPv","_JSID_IS_STRING1510","_JSID_TO_STRING1511","_JSID_IS_OBJECT1512","_JSID_TO_OBJECT1513","__ZN2js8RootInfoC2EPKc12JSGCRootType","__ZNK2js2gc11ArenaHeader9allocatedEv","__ZN2js2gc5Arena8finalizeINS_5ShapeEEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSScriptEEbP9JSContextNS0_9AllocKindEj","__ZN2js2gc5Arena8finalizeI8JSObjectEEbP9JSContextNS0_9AllocKindEj","__ZN8JSObject8finalizeEP9JSContext","__ZN8JSObject6finishEP9JSContext","__ZN2jsL22MarkWordConservativelyEP8JSTracerj","__ZN2js17MarkIfGCThingWordEP8JSTracerj","__ZNK2js7HashSetIPNS_2gc5ChunkENS_13GCChunkHasherENS_17SystemAllocPolicyEE3hasERKS3_","__ZN2js10InFreeListEPNS_2gc11ArenaHeaderEj","__ZN2js2gc11ChunkBitmap8isMarkedEPKNS0_4CellEj","__ZN2jsL12PodArrayZeroIjLj4032EEEvRAT0__T_","__ZN2js12AllocGCChunkEv","__ZL8MapPagesPvj","__ZL10UnmapPagesPvj","__ZN2js11FreeGCChunkEPv","__ZN2js2gc10MarkStringEP8JSTracerP8JSString","__ZN2js2gc4MarkI8JSStringEEvP8JSTracerPT_","__ZN2js2gc10MarkStringEP8JSTracerP8JSStringPKc","__ZN2js2gc10MarkObjectEP8JSTracerR8JSObjectPKc","__ZN2js2gc4MarkI8JSObjectEEvP8JSTracerPT_","__ZN2js2gc26MarkCrossCompartmentObjectEP8JSTracerR8JSObjectPKc","__ZN2js2gc21MarkObjectWithPrinterEP8JSTracerR8JSObjectPFvS2_PcjEPKvj","__ZN2js2gc10MarkScriptEP8JSTracerP8JSScriptPKc","__ZN2js2gc4MarkI8JSScriptEEvP8JSTracerPT_","__ZN2js2gc9MarkShapeEP8JSTracerPKNS_5ShapeEPKc","__ZN2js2gc4MarkIKNS_5ShapeEEEvP8JSTracerPT_","__ZN2js2gc14MarkTypeObjectEP8JSTracerPNS_5types10TypeObjectEPKc","__ZN2js2gc4MarkINS_5types10TypeObjectEEEvP8JSTracerPT_","__ZN2js2gc7MarkXMLEP8JSTracerP5JSXMLPKc","__ZN2js2gc4MarkI5JSXMLEEvP8JSTracerPT_","__ZN2js2gc15MarkObjectRangeEP8JSTracerjPP8JSObjectPKc","__ZN2js2gc12MarkXMLRangeEP8JSTracerjPP5JSXMLPKc","__ZN2js2gc6MarkIdEP8JSTraceri","__ZN2js2gc6MarkIdEP8JSTraceriPKc","__ZN2js2gc11MarkIdRangeEP8JSTracerPiS3_PKc","__ZN2js2gc11MarkIdRangeEP8JSTracerjPiPKc","__ZN2js2gc8MarkKindEP8JSTracerPv13JSGCTraceKind","__ZNK8JSObject10typeFromGCEv","__ZNK6JSRope10rightChildEv","__ZN8JSScript6constsEv","__ZNK2js5Shape14hasGetterValueEv","__ZNK2js5Shape12getterObjectEv","__ZNK2js5Shape14hasSetterValueEv","__ZNK2js5Shape12setterObjectEv","__ZN2js9MarkStackIP6JSRopeE7isEmptyEv","__ZN2js9MarkStackIP6JSRopeE3popEv","__ZN2js9MarkStackIP8JSObjectE7isEmptyEv","__ZN2js2gc4MarkINS_5ShapeEEEvP8JSTracerPT_","__ZN2js2gc12MarkValueRawEP8JSTracerRKN2JS5ValueE","__ZNK2JS5Value6gcKindEv","__ZN2js2gc9MarkValueEP8JSTracerRKN2JS5ValueEPKc","__ZN2js2gc25MarkCrossCompartmentValueEP8JSTracerRKN2JS5ValueEPKc","__ZN2js2gc14MarkValueRangeEP8JSTracerPKN2JS5ValueES6_PKc","__ZN2js2gc14MarkValueRangeEP8JSTracerjPKN2JS5ValueEPKc","__ZN2js2gc14MarkShapeRangeEP8JSTracerPPKNS_5ShapeES6_PKc","__ZN2js2gc14MarkShapeRangeEP8JSTracerjPPKNS_5ShapeEPKc","__ZN2js2gc11MarkGCThingEP8JSTracerPv13JSGCTraceKind","__ZN2js2gc11MarkGCThingEP8JSTracerPv","__ZN2js2gc11MarkGCThingEP8JSTracerPvPKc","__ZN2js2gc11MarkGCThingEP8JSTracerPvPKcj","__ZN2js2gc4MarkEP8JSTracerPv13JSGCTraceKindPKc","__ZN2js2gc8MarkRootEP8JSTracerP8JSObjectPKc","__ZN2js2gc8MarkRootEP8JSTracerP8JSStringPKc","__ZN2js2gc8MarkRootEP8JSTracerP8JSScriptPKc","__ZN2js2gc8MarkRootEP8JSTracerPKNS_5ShapeEPKc","__ZN2js2gc8MarkRootEP8JSTracerPNS_5types10TypeObjectEPKc","__ZN2js2gc8MarkRootEP8JSTracerP5JSXMLPKc","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSObject","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSString","__ZN2js2gc12MarkChildrenEP8JSTracerP8JSScript","__ZN2js2gcL13MarkAtomRangeEP8JSTracerjPP6JSAtomPKc","__ZN2js5types10TypeScript5traceEP8JSTracer","__ZN2js2gc12MarkChildrenEP8JSTracerPKNS_5ShapeE","__ZN2js2gc12MarkChildrenEP8JSTracerPNS_5types10TypeObjectE","__ZN2js5types10TypeObject16getPropertyCountEv","__ZN2js5types10TypeObject11getPropertyEj","__ZN2js2gc12MarkChildrenEP8JSTracerP5JSXML","__ZN2js8GCMarker14drainMarkStackEv","__ZN2js8GCMarker16isMarkStackEmptyEv","__ZN2js2gcL8ScanRopeEPNS_8GCMarkerEP6JSRope","__ZN2js2gcL10ScanObjectEPNS_8GCMarkerEP8JSObject","_JSVAL_IS_STRING_IMPL1546","__ZN2js9MarkStackIP8JSObjectE3popEv","__ZN2js9MarkStackIPNS_5types10TypeObjectEE7isEmptyEv","__ZN2js9MarkStackIPNS_5types10TypeObjectEE3popEv","__ZN2js9MarkStackIP5JSXMLE7isEmptyEv","__ZN2js9MarkStackIP5JSXMLE3popEv","__ZN2js9MarkStackINS_13LargeMarkItemEE7isEmptyEv","__ZN2js9MarkStackINS_13LargeMarkItemEE4peekEv","__ZN2js9MarkStackINS_13LargeMarkItemEE3popEv","__ZNK2js8GCMarker12getMarkColorEv","__ZL23js_RegenerateShapeForGCP9JSRuntime","__ZN2js9MarkStackIP8JSObjectE4pushES2_","__ZN2js9MarkStackIP5JSXMLE4pushES2_","__ZN2js9MarkStackIPNS_5types10TypeObjectEE4pushES3_","__ZN2js9MarkStackINS_13LargeMarkItemEE4pushES1_","__ZNK8JSObject11hasOwnShapeEv","__ZN2js13LargeMarkItemC2EP8JSObject","__ZN2js9MarkStackIP6JSRopeE4pushES2_","__ZN2js5types10TypeScript8hasScopeEv","_JS_GetGCInfoEnabled","_JS_SetGCInfoEnabled","_JS_GCInfoFront","_JS_GCInfoPopFront","__ZN2js2gcL14ScanTypeObjectEPNS_8GCMarkerEPNS_5types10TypeObjectE","__ZN2js2gcL15ScanLargeObjectEPNS_8GCMarkerERNS_13LargeMarkItemE","_JS_TraceChildren","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPKNS_5ShapeE","__ZN2js2gcL9ScanShapeEPNS_8GCMarkerEPKNS_5ShapeE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSString","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSObject","__ZN2js8GCMarker10pushObjectEP8JSObject","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP5JSXML","__ZN2js8GCMarker7pushXMLEP5JSXML","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEPNS_5types10TypeObjectE","__ZN2js8GCMarker8pushTypeEPNS_5types10TypeObjectE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP8JSScript","__ZN2js2gcL9ScanValueEPNS_8GCMarkerERKN2JS5ValueE","__ZN2js2gcL13PushMarkStackEPNS_8GCMarkerEP10JSFunction","__ZN2js13LargeMarkItemC1EP8JSObject","__ZN8JSObject9scanSlotsEPN2js8GCMarkerE","__ZN2js8GCMarker8pushRopeEP6JSRope","__ZN2js5typesL15HashSetCapacityEj1539","__ZN2js2gc4MarkI6JSAtomEEvP8JSTracerPT_","_JSVAL_TRACE_KIND_IMPL1545","_JS_CompareValues","__ZN9JSRuntime6GCData14isTimerEnabledEv","__ZN9JSRuntime6GCData13setFirstEnterEy","_JS_HashString","__ZN2js7GCTimerC2EP9JSRuntimeP13JSCompartment","__ZN2js7GCTimer15clearTimestampsEv","__ZN2js7GCTimer13getFirstEnterEv","__ZN2js7GCTimer6finishEb","_JS_NewHashTable","_JS_HashTableDestroy","_JS_HashTableRawLookup","_JS_HashTableRawAdd","__ZL6ResizeP11JSHashTablej","_JS_HashTableAdd","_JS_HashTableRawRemove","_JS_HashTableRemove","_JS_HashTableLookup","_JS_HashTableEnumerateEntries","_JS_HashTableDump","__ZL17DefaultAllocTablePvj","__ZL16DefaultFreeTablePvS_j","__ZL17DefaultAllocEntryPvPKv","__ZL16DefaultFreeEntryPvP11JSHashEntryj","__ZN2js5types11TypeFailureEP9JSContextPKcz","__ZN2js5types15TypeCompartment5printEP9JSContextb","__ZN2js5types7TypeSet4makeEP9JSContextPKc","__ZN2js8ArenaNewINS_5types7TypeSetEEEPT_R11JSArenaPool","__ZN2js5types15TypeCompartment19setPendingNukeTypesEP9JSContext","__ZNK2js5types7TypeSet18isDefinitePropertyEv","__ZNK2js5types7TypeSet12definiteSlotEv","__ZN2js5types7TypeSet5printEP9JSContext","__ZN2js5types7TypeSet14getObjectCountEv","__ZN2js5types7TypeSet9getObjectEj","__ZN2js5types4Type10ObjectTypeEPNS0_13TypeObjectKeyE","__ZN2js5types7TypeSet9addSubsetEP9JSContextPS1_","__ZN2js5types7TypeSet3addEP9JSContextPNS0_14TypeConstraintEb","__ZN2js8ArenaNewI20TypeConstraintSubsetPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet14addGetPropertyEP9JSContextP8JSScriptPhPS1_i","__ZN2js8ArenaNewI18TypeConstraintPropP8JSScriptPhPNS_5types7TypeSetEibEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_","__ZN2js5types7TypeSet14addSetPropertyEP9JSContextP8JSScriptPhPS1_i","__ZN2js5types7TypeSet15addCallPropertyEP9JSContextP8JSScriptPhi","__ZN2js7analyze14ScriptAnalysis9getCallPCEPh","__ZN2js8ArenaNewI22TypeConstraintCallPropP8JSScriptPhiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js5types7TypeSet13addSetElementEP9JSContextP8JSScriptPhPS1_S7_","__ZN2js8ArenaNewI24TypeConstraintSetElementP8JSScriptPhPNS_5types7TypeSetES7_EEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js5types7TypeSet7addCallEP9JSContextPNS0_12TypeCallsiteE","__ZN2js8ArenaNewI18TypeConstraintCallPNS_5types12TypeCallsiteEEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet8addArithEP9JSContextPS1_S4_","__ZN2js8ArenaNewI19TypeConstraintArithPNS_5types7TypeSetES4_EEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet16addTransformThisEP9JSContextP8JSScriptPS1_","__ZN2js8ArenaNewI27TypeConstraintTransformThisP8JSScriptPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet16addPropagateThisEP9JSContextP8JSScriptPhNS0_4TypeEPS1_","__ZN2js8ArenaNewI27TypeConstraintPropagateThisP8JSScriptPhNS_5types4TypeEPNS5_7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js5types7TypeSet19addFilterPrimitivesEP9JSContextPS1_NS1_10FilterKindE","__ZN2js8ArenaNewI29TypeConstraintFilterPrimitivePNS_5types7TypeSetENS3_10FilterKindEEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js7analyze14ScriptAnalysis17pruneTypeBarriersEP9JSContextj","__ZNK2js5types4Type11isPrimitiveE11JSValueType","__ZN2js5types7TypeSet21hasPropagatedPropertyEv","__ZL17GetSingletonShapeP9JSContextP8JSObjecti","__ZN2js7analyze14ScriptAnalysis17breakTypeBarriersEP9JSContextjb","__ZN2js7analyze14ScriptAnalysis20breakTypeBarriersSSAEP9JSContextRKNS0_8SSAValueE","__ZN2js5types7TypeSet16addSubsetBarrierEP9JSContextP8JSScriptPhPS1_","__ZN2js8ArenaNewI27TypeConstraintSubsetBarrierP8JSScriptPhPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN2js5types7TypeSet16addLazyArgumentsEP9JSContextPS1_","__ZN2js8ArenaNewI27TypeConstraintLazyArgumentsPNS_5types7TypeSetEEEPT_R11JSArenaPoolRKT0_","__ZN18TypeConstraintProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZL21UnknownPropertyAccessP8JSScriptN2js5types4TypeE","__ZN2js5types15TypeCompartment15monitorBytecodeEP9JSContextP8JSScriptjb","__ZL25MarkPropertyAccessUnknownP9JSContextP8JSScriptPhPN2js5types7TypeSetE","__ZL9id_lengthP9JSContext","__ZN2js5types4Type9Int32TypeEv","__ZL17GetPropertyObjectP9JSContextP8JSScriptN2js5types4TypeE","__ZL14PropertyAccessP9JSContextP8JSScriptPhPN2js5types10TypeObjectEbPNS5_7TypeSetEi","__ZN22TypeConstraintCallProp7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5types10TypeObject17getFromPrototypesEP9JSContextiPNS0_7TypeSetEb","__ZN24TypeConstraintSetElement7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN18TypeConstraintCall7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZL25GetValueTypeFromTypeFlagsj","__ZNK2js5types4Type12singleObjectEv","__ZNK2js5types7TypeSet13unknownObjectEv","__ZN2js5types10TypeObject11hasAnyFlagsEj","__ZNK2js5types4Type14isSingleObjectEv","__ZN2js5types4Type10ObjectTypeEPNS0_10TypeObjectE","__ZN2js5types10TypeScript9ThisTypesEP8JSScript","__ZN2js5types10TypeScript11ReturnTypesEP8JSScript","__ZN27TypeConstraintPropagateThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN19TypeConstraintArith7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZNK2js5types7TypeSet10hasAnyFlagEj","__ZN2js5types4Type10StringTypeEv","__ZN27TypeConstraintTransformThis7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5types10TypeScript12StandardTypeEP9JSContextP8JSScript10JSProtoKey","__ZN2js5types7TypeSet9addFreezeEP9JSContext","__ZN2js8ArenaNewI20TypeConstraintFreezeP8JSScriptEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet15getKnownTypeTagEP9JSContext","__ZN2js8ArenaNewI27TypeConstraintFreezeTypeTagP8JSScriptEEPT_R11JSArenaPoolRKT0_","__ZN2js5types7TypeSet14hasObjectFlagsEP9JSContextj","__ZN2js5types7TypeSet13getTypeObjectEj","__ZN2js5types7TypeSet15getSingleObjectEj","__ZN2js8ArenaNewI34TypeConstraintFreezeObjectFlagsSetP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet14HasObjectFlagsEP9JSContextPNS0_10TypeObjectEj","__ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types20MarkArgumentsCreatedEP9JSContextP8JSScript","__ZN8JSScript17ensureRanAnalysisEP9JSContextP10JSFunctionP8JSObject","__ZN2js7analyze14ScriptAnalysis7getCodeEPKh","__ZNK2JS5Value12isMagicCheckE10JSWhyMagic","__ZN2js5types7TypeSet22WatchObjectStateChangeEP9JSContextPNS0_10TypeObjectE","__ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptiEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types15TypeCompartment19addPendingRecompileEP9JSContextP8JSScript","__ZN2jsL3MaxIjEET_S1_S1_1674","__ZNK2js5types7TypeSet13isOwnPropertyEb","__ZNK8JSScript6globalEv","__ZN2js5types7TypeSet13isOwnPropertyEP9JSContextPNS0_10TypeObjectEb","__ZL24CheckNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunction","__ZN2js8ArenaNewI31TypeConstraintFreezeOwnPropertyP8JSScriptbEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types7TypeSet13knownNonEmptyEP9JSContext","__ZN2js5types7TypeSet17getTypedArrayTypeEP9JSContext","__ZN2js5types7TypeSet12getSingletonEP9JSContextb","__ZN2js5types7TypeSet15hasGlobalObjectEP9JSContextP8JSObject","__ZL13TypeHasGlobalN2js5types4TypeEP8JSObject","__ZN2js8ArenaNewI26TypeConstraintFreezeGlobalP8JSScriptP8JSObjectEEPT_R11JSArenaPoolRKT0_RKT1_","__ZN2js5types10TypeObjectC1EP8JSObjectbb","__ZN2js5types15TypeCompartment4initEP9JSContext","__ZN2jsL7PodZeroINS_5types15TypeCompartmentEEEvPT_","__ZN2js5types15TypeCompartment13newTypeObjectEP9JSContextP8JSScript10JSProtoKeyP8JSObjectb","__Z10NewGCThingIN2js5types10TypeObjectEEPT_P9JSContextNS0_2gc9AllocKindEj","__ZN2js5types10TypeObject15setFlagsFromKeyEP9JSContext10JSProtoKey","__ZN2js5types15TypeCompartment27newAllocationSiteTypeObjectEP9JSContextRKNS0_17AllocationSiteKeyE","__ZN9JSContext4new_IN2js7HashMapINS1_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZN2js5types10TypeObject21addDefinitePropertiesEP9JSContextP8JSObject","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_","__ZN2js5types10UseNewTypeEP9JSContextP8JSScriptPh","__ZL9GetAtomIdP9JSContextP8JSScriptPKhj","__ZL12id_prototypeP9JSContext","__ZN2js5types15TypeCompartment16growPendingArrayEP9JSContext","__ZN2js5types15TypeCompartment24processPendingRecompilesEP9JSContext","__ZN9JSContext7delete_IN2js6VectorIP8JSScriptLj0ENS1_15TempAllocPolicyEEEEEvPT_","__ZN2js5types15TypeCompartment9nukeTypesEP9JSContext","__ZN2js7analyzeL11ExtendedDefEPh1682","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN8JSScript11hasAnalysisEv","__ZN2js7analyze14ScriptAnalysis12ranInferenceEv","__ZNK2js5types4TypeeqES1_","__ZN2js5types15TypeCompartment11compartmentEv","__ZNK2js5types4TypeneES1_","__ZL17ObjectStateChangeP9JSContextPN2js5types10TypeObjectEbb","__ZN2js5types15TypeCompartment15markSetsUnknownEP9JSContextPNS0_10TypeObjectE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC1ES4_","__ZN2js2gc8CellIterC1EP9JSContextP13JSCompartmentNS0_9AllocKindE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js2gc8CellIterD1Ev","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEixEj","__ZN2js5types10TypeScript11NumTypeSetsEP8JSScript","__ZN2js7analyzeL11GetDefCountEP8JSScriptj1681","__ZN2js7analyze14ScriptAnalysis11pushedTypesEPKhj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js7analyze14ScriptAnalysis14addTypeBarrierEP9JSContextPKhPNS_5types7TypeSetENS6_4TypeE","__ZN2js8ArenaNewINS_5types11TypeBarrierEPNS1_7TypeSetENS1_4TypeEP8JSObjectiEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_","__ZN2js7analyze14ScriptAnalysis23addSingletonTypeBarrierEP9JSContextPKhPNS_5types7TypeSetEP8JSObjecti","__ZL15InferSpewActiveN2js5types11SpewChannelE","__ZN2js7analyze14ScriptAnalysis10printTypesEP9JSContext","__ZN2js5types15TypeCompartment12fixArrayTypeEP9JSContextP8JSObject","__ZN9JSContext4new_IN2js7HashMapINS1_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE4initEj","__ZL20GetValueTypeForTableP9JSContextRKN2JS5ValueE","_JSID_IS_EMPTY","_JSID_IS_VOID1691","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__ZN2js5types7TypeSet21setPropagatedPropertyEv","__ZN2js5types7TypeSet11setDefiniteEj","__ZL11NumberTypesN2js5types4TypeES1_","__ZN2js5types13ArrayTableKeyC1Ev","__ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiNS0_4TypeE","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13relookupOrAddERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKS4_","__ZN2js5types15TypeCompartment13fixObjectTypeEP9JSContextP8JSObject","__ZN9JSContext4new_IN2js7HashMapINS1_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS1_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE4initEj","__ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE12lookupForAddERKP8JSObject","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS5_13MapHashPolicyES4_E6AddPtrERKS2_RKS3_","__ZN2js5types10TypeObject11addPropertyEP9JSContextiPPNS0_8PropertyE","__ZN2js8ArenaNewINS_5types8PropertyEiEEPT_R11JSArenaPoolRKT0_","__ZL18UpdatePropertyTypeP9JSContextPN2js5types7TypeSetEP8JSObjectPKNS1_5ShapeEb","__ZN8JSObject11isFixedSlotEj","__ZN2js5types10TypeObject23matchDefinitePropertiesEP8JSObject","__Z21InlineAddTypePropertyP9JSContextPN2js5types10TypeObjectEiNS2_4TypeE","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextiRKN2JS5ValueE","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcNS0_4TypeE","__ZL12ATOM_TO_JSIDP6JSAtom1694","__ZN2js5types10TypeObject15addPropertyTypeEP9JSContextPKcRKN2JS5ValueE","__ZN2js5types10TypeObject22markPropertyConfiguredEP9JSContexti","__ZN2js5types10TypeObject15markStateChangeEP9JSContext","__ZN2js5types10TypeObject8setFlagsEP9JSContextj","__ZN2js5types10TypeObject11markUnknownEP9JSContext","__ZN2js7analyzeL7ArgSlotEj1706","__ZN2js7analyze14ScriptAnalysis16addsScopeObjectsEv","__ZN2jsL20CallObjectLambdaNameEP10JSFunction1708","__ZN2js5types10TypeObject14clearNewScriptEP9JSContext","__ZN2js5types10TypeObject5printEP9JSContext","__ZN2js7analyze14ScriptAnalysis17resolveNameAccessEP9JSContextib","__ZN2jsL7PodZeroINS_7analyze14ScriptAnalysis10NameAccessEEEvPT_","__ZL12JSID_IS_ATOMi1703","__ZL12JSID_TO_ATOMi1704","__ZN8JSScript18ensureRanInferenceEP9JSContext","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh1705","__ZN2js7analyzeL9LocalSlotEP8JSScriptj1707","__ZN2js7analyze14ScriptAnalysis20analyzeTypesBytecodeEP9JSContextjRNS1_18TypeInferenceStateE","__ZN2js7analyze14ScriptAnalysis3OOMEv","__ZN2js7analyze14ScriptAnalysis6ranSSAEv","__ZNK2js7analyze14ScriptAnalysis14usesScopeChainEv","__ZN2js7analyze14ScriptAnalysis12extendsScopeEv","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js7analyze14ScriptAnalysis16localsAliasStackEv","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN2js10ArenaArrayINS_5types7TypeSetEEEPT_R11JSArenaPoolj","__ZN2jsL7PodZeroINS_5types7TypeSetEEEvPT_j","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js5types4Type11BooleanTypeEv","__ZN2js5types4Type8NullTypeEv","__ZL15GetScriptObjectP9JSContextP8JSScriptPKhj","__ZN2js7analyze14ScriptAnalysis11poppedTypesEPKhj","__ZN2js7analyze14ScriptAnalysis13bytecodeTypesEPKh","__ZL13CheckNextTestPh","__ZN2js7analyzeL15GetBytecodeSlotEP8JSScriptPh1709","__ZN2js7analyzeL10TotalSlotsEP8JSScript1710","__ZN2js5types4Type12LazyArgsTypeEv","__ZN2js7analyzeL11GetUseCountEP8JSScriptj1711","__ZN2js8ArenaNewINS_5types12TypeCallsiteEP9JSContextP8JSScriptPhbjEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_RKT3_RKT4_","__ZL18GetInitializerTypeP9JSContextP8JSScriptPh","__ZL12id___proto__P9JSContext","__ZN2js12GlobalObject29getOrCreateGeneratorPrototypeEP9JSContext","__ZN2js7analyze14ScriptAnalysis12analyzeTypesEP9JSContext","__ZNK8JSScript16hasClearedGlobalEv","__ZL19DetachNestingParentP8JSScript","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC1EP9JSContext","__ZN2js7analyzeL17GetBytecodeLengthEPh1712","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC1ES3_","__ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextRKNS0_8SSAValueEPNS_6VectorIS4_Lj0ENS_15TempAllocPolicyEEE","__ZN2js7analyze8SSAValue11PushedValueEjj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD1Ev","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js7analyze14ScriptAnalysis23followEscapingArgumentsEP9JSContextPNS0_11SSAUseChainEPNS_6VectorINS0_8SSAValueELj0ENS_15TempAllocPolicyEEE","__ZN2js7analyze8SSAValue8PhiValueEjPNS0_10SSAPhiNodeE","__ZN2js7analyze8SSAValue10WrittenVarEjj","__ZN2js7analyze17AutoEnterAnalysisC1EP9JSContext","__ZN2js7analyze17AutoEnterAnalysisD1Ev","__ZN2js5types23MarkIteratorUnknownSlowEP9JSContext","__ZN9JSContext4new_IN2js5types10TypeResultEjNS2_4TypeEEEPT_T0_T1_","__ZN2js5types19TypeMonitorCallSlowEP9JSContextP8JSObjectRKNS_8CallArgsEb","__ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptRKN2JS5ValueE","__ZN2JSL14UndefinedValueEv1713","__ZN2js5types17TypeDynamicResultEP9JSContextP8JSScriptPhNS0_4TypeE","__ZN9JSContext4new_IN2js5types10TypeResultEiNS2_4TypeEEEPT_T0_T1_","__ZN2js5types17TypeMonitorResultEP9JSContextP8JSScriptPhRKN2JS5ValueE","__ZN2js5types10TypeScript8SetScopeEP9JSContextP8JSScriptP8JSObject","__ZNK10JSFunction13isNullClosureEv","__ZN9JSContext4new_IN2js5types17TypeScriptNestingEEEPT_v","__ZN2js5types17TypeScriptNestingD2Ev","__ZN2js5types18ClearActiveNestingEP8JSScript","__ZN2js5types15NestingPrologueEP9JSContextPNS_10StackFrameE","__ZN2js5typesL18CheckNestingParentEP9JSContextP8JSObjectP8JSScript","__ZN2js5types15NestingEpilogueEPNS_10StackFrameE","__ZN2js2gc12EmptyArenaOpEPNS0_5ArenaE","_JSID_IS_STRING1730","_JSID_TO_STRING1731","__ZNK8JSObject18hasSpecialEqualityEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range5frontEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN8JSScript9makeTypesEP9JSContextP10JSFunction","__ZN2js5types10TypeScriptC1EP10JSFunction","__ZN8JSScript12makeAnalysisEP9JSContext","__ZN2js8ArenaNewINS_7analyze14ScriptAnalysisEP8JSScriptEEPT_R11JSArenaPoolRKT0_","__ZN8JSScript15typeSetFunctionEP9JSContextP10JSFunctionb","__ZN8JSObject21shouldSplicePrototypeEP9JSContext","__ZN8JSObject15splicePrototypeEP9JSContextPS_","__ZN8JSObject12makeLazyTypeEP9JSContext","__ZN8JSObject11makeNewTypeEP9JSContextP10JSFunctionb","__Z16SweepTypeObjectsP9JSContextP13JSCompartment","__ZN17SweepTypeObjectOpC1EP9JSContext","__ZN2js2gc19ForEachArenaAndCellIPFvPNS0_5ArenaEE17SweepTypeObjectOpEEvP13JSCompartmentNS0_9AllocKindET_T0_","__ZN2js5types15TypeCompartment5sweepEP9JSContext","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC1IS9_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js5types14TypeConstraint16newPropertyStateEP9JSContextPNS0_7TypeSetE","__ZN2js5types14TypeConstraint14newObjectStateEP9JSContextPNS0_10TypeObjectEb","__ZN2js18ArenaAllocatedSizeERK11JSArenaPool","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13allocatedSizeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13allocatedSizeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12hasCollisionEv","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv","__ZN2js5types15TypeCompartmentD2Ev","__ZN2js10Foreground7delete_INS_7HashMapINS_5types13ArrayTableKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js10Foreground7delete_INS_7HashMapINS_5types14ObjectTableKeyENS3_16ObjectTableEntryES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js10Foreground7delete_INS_7HashMapINS_5types17AllocationSiteKeyEPNS3_10TypeObjectES4_NS_17SystemAllocPolicyEEEEEvPT_","__ZN2js5types10TypeScript5SweepEP9JSContextP8JSScript","__ZN2js5types7TypeSet5sweepEP9JSContextP13JSCompartment","__ZN2js5typesL20IsAboutToBeFinalizedEP9JSContextPNS0_13TypeObjectKeyE","__ZN9JSContext7delete_IN2js5types10TypeResultEEEvPT_","__ZN2js5types10TypeScript7destroyEv","__ZN2js10Foreground7delete_INS_5types10TypeResultEEEvPT_","__ZN2js10Foreground7delete_INS_5types17TypeScriptNestingEEEvPT_","_JS_GetTypeInferenceMemoryStats","__ZL20GetScriptMemoryStatsP8JSScriptP24TypeInferenceMemoryStats","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv","__ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13allocatedSizeEv","__ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13allocatedSizeEv","_JS_GetTypeInferenceObjectStats","__ZN2js5types10TypeObject11dynamicSizeEv","_js_free1736","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12destroyTableERS8_PNS0_14HashTableEntryIS6_EEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED1Ev","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC1Ev","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEptEv","__ZNK2js7MoveRefINS_5types17AllocationSiteKeyEEcvRS2_Ev","__ZNK2js7MoveRefIPNS_5types10TypeObjectEEcvRS3_Ev","__ZN2js7MoveRefIPNS_5types10TypeObjectEEC2ERS3_","__ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC2ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE12setCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC2ERS8_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC2ERS5_","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEptEv","__ZNK2js7MoveRefINS_5types14ObjectTableKeyEEcvRS2_Ev","__ZNK2js7MoveRefINS_5types16ObjectTableEntryEEcvRS2_Ev","__ZN2js7MoveRefINS_5types16ObjectTableEntryEEC2ERS2_","__ZN2js7MoveRefINS_5types14ObjectTableKeyEEC2ERS2_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12hasCollisionEv","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSERKS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEptEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS4_10TypeObjectEEEEEEC1ERS9_","__ZN2js12HashMapEntryINS_5types17AllocationSiteKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS2_10TypeObjectEEEEC1ERS6_","__ZN2js4MoveINS_5types17AllocationSiteKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveIPNS_5types10TypeObjectEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefIPNS_5types10TypeObjectEEC1ERS3_","__ZN2js7MoveRefINS_5types17AllocationSiteKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZNK2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSERKS4_","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC1Ev","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEaSENS_7MoveRefIS7_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEENS_7MoveRefIT_EERSA_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS4_16ObjectTableEntryEEEEEEC1ERS8_","__ZN2js12HashMapEntryINS_5types14ObjectTableKeyENS1_16ObjectTableEntryEEaSENS_7MoveRefIS4_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEENS_7MoveRefIT_EERS7_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types14ObjectTableKeyENS2_16ObjectTableEntryEEEEC1ERS5_","__ZN2js4MoveINS_5types14ObjectTableKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js4MoveINS_5types16ObjectTableEntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_5types16ObjectTableEntryEEC1ERS2_","__ZN2js7MoveRefINS_5types14ObjectTableKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4EnumC2IS9_EERT_","__ZNK2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC1EPNS0_14HashTableEntryIS6_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5RangeC2EPNS0_14HashTableEntryIS6_EESF_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setFreeEv","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1Ev","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2Ev","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS4_10TypeObjectEEEEEEC1ERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEptEv","__ZNK2js7MoveRefINS_5types13ArrayTableKeyEEcvRS2_Ev","__ZN2js7MoveRefINS_5types13ArrayTableKeyEEC2ERS2_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEv","__ZN8JSObject14revertLazyTypeEv","__ZN2js5types10TypeResultC2EjNS0_4TypeE","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_7analyze8SSAValueEEcvRS2_Ev","__ZN2js7MoveRefINS_7analyze8SSAValueEEC2ERS2_","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS2_10TypeObjectEEEEC1ERS6_","__ZN2js4MoveINS_5types13ArrayTableKeyEEENS_7MoveRefIT_EERKS4_","__ZN2js7MoveRefINS_5types13ArrayTableKeyEEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZNK2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS7_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS7_EESG_","__ZN17SweepTypeObjectOpclEPN2js2gc4CellE","__ZN2js5types10TypeObject5sweepEP9JSContext","__ZN2js5types10TypeObject15clearPropertiesEv","__ZN2js5typesL15HashSetCapacityEj1739","__ZN2js8ArenaNewINS_5types8PropertyES2_EEPT_R11JSArenaPoolRKT0_","__ZN2js5typesL13HashSetInsertIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1740","__ZN2jsL7PodZeroIPNS_5types8PropertyEEEvPT_j1741","__ZN2js5typesL16HashSetInsertTryIiNS0_8PropertyES2_EEPPT0_P13JSCompartmentRS5_RjT_1742","__ZN2js5typesL7HashKeyIiNS0_8PropertyEEEjT_1743","__ZN2js5types8PropertyC1ERKS1_","__ZN2js5types8PropertyC2ERKS1_","__ZN2js7analyze14ScriptAnalysisC1EP8JSScript","__ZN2js7analyze14ScriptAnalysisC2EP8JSScript","__ZN2jsL7PodZeroINS_7analyze14ScriptAnalysisEEEvPT_","__ZN2js5types17TypeScriptNestingC1Ev","__ZN2js5types17TypeScriptNestingC2Ev","__ZN2jsL7PodZeroINS_5types17TypeScriptNestingEEEvPT_","__ZN2js5types10TypeResultC1EjNS0_4TypeE","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_7analyze8SSAValueEEC1ERS2_","__ZN2js10VectorImplINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_7analyze8SSAValueEEENS_7MoveRefIT_EERKS4_","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorINS_7analyze8SSAValueELj0ENS_15TempAllocPolicyEEC2ES3_","__ZN2js5types12TypeCallsiteC1EP9JSContextP8JSScriptPhbj","__ZN2js5types12TypeCallsiteC2EP9JSContextP8JSScriptPhbj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS6_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEEE12setCollisionEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S3_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC2ES8_","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC2ERKS2_RKS4_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE7setLiveEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEEE12setCollisionEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZNK2js5types4Type3rawEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js5types11TypeBarrierC2EPNS0_7TypeSetENS0_4TypeEP8JSObjecti","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE5beginEv","__ZN2js10ArenaArrayIPNS_5types7TypeSetEEEPT_R11JSArenaPoolj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZNK2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js10VectorImplIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js5types8PropertyC1Ei","__ZN2js5types8PropertyC2Ei","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS6_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKP8JSObject","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKP8JSObjectjj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS6_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS6_EERKP8JSObject","__ZN2js5types14ObjectTableKey5matchERKS1_P8JSObject","__ZN2js5types14ObjectTableKey4hashEP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashMapINS_5types14ObjectTableKeyENS1_16ObjectTableEntryES2_NS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types14ObjectTableKeyENS3_16ObjectTableEntryEEENS_7HashMapIS4_S5_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES8_EC1ES8_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E13relookupOrAddERNSC_6AddPtrERKS4_RKS7_","__ZN2js12HashMapEntryINS_5types13ArrayTableKeyEPNS1_10TypeObjectEEC1ERKS2_RKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrERKS7_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js5types13ArrayTableKey5matchERKS1_S3_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js5types13ArrayTableKey4hashERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_5types13ArrayTableKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types13ArrayTableKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN2js5types11TypeBarrierC1EPNS0_7TypeSetENS0_4TypeEP8JSObjecti","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN31TypeConstraintFreezeOwnProperty7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN31TypeConstraintFreezeObjectFlags7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN27TypeConstraintLazyArguments7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZN2js5types14TypeConstraintC2EPKc","__ZN20TypeConstraintFreeze7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZNK2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js10VectorImplIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIPNS_5types7TypeSetELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP8JSScriptLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC1ES5_","__ZN2js7HashMapINS_5types17AllocationSiteKeyEPNS1_10TypeObjectES2_NS_17SystemAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_5types17AllocationSiteKeyEPNS3_10TypeObjectEEENS_7HashMapIS4_S6_S4_NS_17SystemAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZN26TypeConstraintFreezeGlobalC1EP8JSScriptP8JSObject","__ZN26TypeConstraintFreezeGlobalC2EP8JSScriptP8JSObject","__ZN26TypeConstraintFreezeGlobal7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN31TypeConstraintFreezeOwnPropertyC1EP8JSScriptb","__ZN31TypeConstraintFreezeOwnPropertyC2EP8JSScriptb","__ZN31TypeConstraintFreezeOwnProperty16newPropertyStateEP9JSContextPN2js5types7TypeSetE","__ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptj","__ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptj","__ZN31TypeConstraintFreezeObjectFlags14newObjectStateEP9JSContextPN2js5types10TypeObjectEb","__ZN34TypeConstraintFreezeObjectFlagsSetC1EP8JSScriptj","__ZN34TypeConstraintFreezeObjectFlagsSetC2EP8JSScriptj","__ZN34TypeConstraintFreezeObjectFlagsSet7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js8ArenaNewI31TypeConstraintFreezeObjectFlagsP8JSScriptjPbEEPT_R11JSArenaPoolRKT0_RKT1_RKT2_","__ZN31TypeConstraintFreezeObjectFlagsC1EP8JSScriptjPb","__ZN31TypeConstraintFreezeObjectFlagsC2EP8JSScriptjPb","__ZN27TypeConstraintFreezeTypeTagC1EP8JSScript","__ZN27TypeConstraintFreezeTypeTagC2EP8JSScript","__ZN27TypeConstraintFreezeTypeTag7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN20TypeConstraintFreezeC1EP8JSScript","__ZN20TypeConstraintFreezeC2EP8JSScript","__ZN27TypeConstraintLazyArgumentsC1EPN2js5types7TypeSetE","__ZN27TypeConstraintLazyArgumentsC2EPN2js5types7TypeSetE","__ZN27TypeConstraintLazyArguments14newObjectStateEP9JSContextPN2js5types10TypeObjectEb","__ZN27TypeConstraintSubsetBarrierC1EP8JSScriptPhPN2js5types7TypeSetE","__ZN27TypeConstraintSubsetBarrierC2EP8JSScriptPhPN2js5types7TypeSetE","__ZN27TypeConstraintSubsetBarrier7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN29TypeConstraintFilterPrimitiveC1EPN2js5types7TypeSetENS2_10FilterKindE","__ZN29TypeConstraintFilterPrimitiveC2EPN2js5types7TypeSetENS2_10FilterKindE","__ZN29TypeConstraintFilterPrimitive7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN27TypeConstraintPropagateThisC1EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE","__ZN27TypeConstraintPropagateThisC2EP8JSScriptPhN2js5types4TypeEPNS4_7TypeSetE","__ZN27TypeConstraintTransformThisC1EP8JSScriptPN2js5types7TypeSetE","__ZN27TypeConstraintTransformThisC2EP8JSScriptPN2js5types7TypeSetE","__ZN19TypeConstraintArithC1EPN2js5types7TypeSetES3_","__ZN19TypeConstraintArithC2EPN2js5types7TypeSetES3_","__ZN18TypeConstraintCallC1EPN2js5types12TypeCallsiteE","__ZN18TypeConstraintCallC2EPN2js5types12TypeCallsiteE","__ZN24TypeConstraintSetElementC1EP8JSScriptPhPN2js5types7TypeSetES6_","__ZN24TypeConstraintSetElementC2EP8JSScriptPhPN2js5types7TypeSetES6_","__ZN22TypeConstraintCallPropC1EP8JSScriptPhi","__ZN22TypeConstraintCallPropC2EP8JSScriptPhi","__ZN18TypeConstraintPropC1EP8JSScriptPhPN2js5types7TypeSetEib","__ZN17SweepTypeObjectOpC2EP9JSContext","__ZN2js5types10TypeScriptC2EP10JSFunction","__ZN2js7analyze17AutoEnterAnalysis5leaveEv","__ZN2js7analyze17AutoEnterAnalysisC2EP9JSContext","__ZN2js2gcL15GetGCObjectKindEjb1752","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6lengthEv","__ZN18TypeConstraintPropC2EP8JSScriptPhPN2js5types7TypeSetEib","__ZN20TypeConstraintSubsetC1EPN2js5types7TypeSetE","__ZN20TypeConstraintSubsetC2EPN2js5types7TypeSetE","__ZN20TypeConstraintSubset7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js5types7TypeSet11dynamicSizeEv","__ZN2js5typesL13HashSetInsertIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1745","__ZN2jsL7PodZeroIPNS_5types13TypeObjectKeyEEEvPT_j1746","__ZN2js5typesL16HashSetInsertTryIPNS0_13TypeObjectKeyES2_S2_EEPPT0_P13JSCompartmentRS6_RjT_1747","__ZN2js5typesL7HashKeyIPNS0_13TypeObjectKeyES2_EEjT_1748","__ZN2js5types10TypeScript7SetThisEP9JSContextP8JSScriptNS0_4TypeE","__ZN2js7analyze17AutoEnterAnalysisD2Ev","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1751","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC1ES4_","__ZL26AnalyzeNewScriptPropertiesP9JSContextPN2js5types10TypeObjectEP10JSFunctionPP8JSObjectPNS1_6VectorINS2_13TypeNewScript11InitializerELj0ENS1_15TempAllocPolicyEEE","__ZN2js5types13TypeNewScript11InitializerC1ENS2_4KindEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2jsL7PodCopyINS_5types13TypeNewScript11InitializerEEEvPT_PKS4_j","__ZL14JSID_FROM_BITSj1765","__ZN2jsL12PodArrayZeroIbLj2EEEvRAT0__T_","__ZN2js5types17TypeFlagPrimitiveEj","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js7MoveRefINS_5types13TypeNewScript11InitializerEEcvRS3_Ev","__ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC2ERS3_","__ZN2js5types13TypeNewScript11InitializerC2ENS2_4KindEj","__ZL22UsePropertyTypeBarrierPh","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS3_Lj0ES4_EEj","__ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_5types13TypeNewScript11InitializerEEC1ERS3_","__ZN2js10VectorImplINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyELb0EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js4MoveINS_5types13TypeNewScript11InitializerEEENS_7MoveRefIT_EERKS5_","__ZL14id_constructorP9JSContext","__ZN2js8ArenaNewI33TypeConstraintClearDefiniteSetterPNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_","__ZN2js8ArenaNewI33TypeConstraintClearDefiniteSinglePNS_5types10TypeObjectEEEPT_R11JSArenaPoolRKT0_","__ZN33TypeConstraintClearDefiniteSingleC1EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSingleC2EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSingle7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN33TypeConstraintClearDefiniteSetterC1EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSetterC2EPN2js5types10TypeObjectE","__ZN33TypeConstraintClearDefiniteSetter7newTypeEP9JSContextPN2js5types7TypeSetENS3_4TypeE","__ZN2js6VectorINS_5types13TypeNewScript11InitializerELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1753","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateD2Ev","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEED2Ev","__ZN2js7analyze14ScriptAnalysis18TypeInferenceStateC2EP9JSContext","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC1ES4_","__ZN2js6VectorIPNS_7analyze10SSAPhiNodeELj0ENS_15TempAllocPolicyEEC2ES4_","__ZN8JSScript12clearNestingEv","__ZNK2js5Shape26hasDefaultGetterOrIsMethodEv","__ZN2js5types13ArrayTableKeyC2Ev","__ZN2js2gc8CellIterD2Ev","__ZN2js2gc8CellIterC2EP9JSContextP13JSCompartmentNS0_9AllocKindE","__ZN2js2gc10ArenaLists22isSynchronizedFreeListENS0_9AllocKindE","__ZN2js5types10TypeObjectC2EP8JSObjectbb","__ZN2jsL7PodZeroINS_5types10TypeObjectEEEvPT_","__ZN2js5types10TypeObject9getGlobalEv","__ZN2js13GetScopeChainEP9JSContext","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind1790","__ZN2js13GetScopeChainEP9JSContextPNS_10StackFrameE","__ZN2js13GetBlockChainEP9JSContextPNS_10StackFrameE","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh1793","__ZN2js17GetBlockChainFastEP9JSContextPNS_10StackFrameE4JSOpj","__ZL17GetScopeChainFullP9JSContextPN2js10StackFrameEP8JSObject","__ZN2js17GetScopeChainFastEP9JSContextPNS_10StackFrameE4JSOpj","__ZN2js24ReportIncompatibleMethodEP9JSContextPN2JS5ValueEPNS_5ClassE","__ZN2js16BoxNonStrictThisEP9JSContextRKNS_12CallReceiverE","__ZN8JSObject10thisObjectEP9JSContext","__ZL20no_such_method_traceP8JSTracerP8JSObject","__ZN2js15OnUnknownMethodEP9JSContextPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1798","__ZN2js5types10TypeScript14MonitorUnknownEP9JSContextP8JSScriptPh","__ZN2jsL9IdToValueEi1799","__ZN2js9RunScriptEP9JSContextP8JSScriptPNS_10StackFrameE","__ZN2js9InterpretEP9JSContextPNS_10StackFrameENS_10InterpModeE","__ZN2jsL13ToReportFlagsENS_17InitialFrameFlagsE","__ZNK2JS5Value18payloadAsRawUint32Ev","__ZNK8JSScript7isEmptyEv","__ZN2js12InvokeKernelEP9JSContextRKNS_8CallArgsENS_14MaybeConstructE","__ZL12NoSuchMethodP9JSContextjPN2JS5ValueE","__ZN2js12CallJSNativeEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE","__ZN2js5types15TypeMonitorCallEP9JSContextRKNS_8CallArgsEb","__ZN2js16InvokeFrameGuardC1Ev","__ZNK2js10FrameGuard2fpEv","__ZN2js10StackFrame16functionPrologueEP9JSContext","__ZN2js23AutoPreserveEnumeratorsC1EP9JSContext","__ZN2js23AutoPreserveEnumeratorsD1Ev","__ZN2js16InvokeFrameGuardD1Ev","__ZN2js6InvokeEP9JSContextRKN2JS5ValueES5_jPS3_S6_","__ZN2js17InvokeConstructorEP9JSContextRKN2JS5ValueEjPS3_S6_","__ZN2js20InvokeGetterOrSetterEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_","__ZN2JSL11ObjectValueER8JSObject1804","__ZN2js13ExecuteKernelEP9JSContextP8JSScriptR8JSObjectRKN2JS5ValueENS_11ExecuteTypeEPNS_10StackFrameEPS7_","__ZN2js17ExecuteFrameGuardC1Ev","__ZNK2js10StackFrame17isStrictEvalFrameEv","__ZL14InitSharpSlotsP9JSContextPN2js10StackFrameE","__ZN2js17ExecuteFrameGuardD1Ev","__ZN2js7ExecuteEP9JSContextP8JSScriptR8JSObjectPN2JS5ValueE","__ZN2js18CheckRedeclarationEP9JSContextP8JSObjectij","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE1809","__ZN2js11HasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZN2js12LooselyEqualEP9JSContextRKN2JS5ValueES5_Pi","__ZN2JS8SameTypeERKNS_5ValueES2_","__ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE","__ZeqRK8JSObjectS1_1816","_INT_FITS_IN_JSID1825","_INT_TO_JSID1826","_OBJECT_TO_JSID1827","__ZNK10JSFunction13isConstructorEv","__ZNK8JSObject7isXMLIdEv","__ZNK8JSObject6isWithEv","__ZNK8JSObject7isBlockEv","__ZN8JSScript15stepModeEnabledEv","__ZNK23GenericInterruptEnablerIiE16enableInterruptsEv","__ZN12JSPCCounters3getEi","__ZNK2js10StackFrame18loweredCallOrApplyEv","__ZN2js13StrictlyEqualEP9JSContextRKN2JS5ValueES5_Pi","__ZN2js9SameValueEP9JSContextRKN2JS5ValueES5_Pi","__ZL14IsNegativeZeroRKN2JS5ValueE","__ZL5IsNaNRKN2JS5ValueE","__ZN2js11TypeOfValueEP9JSContextRKN2JS5ValueE","__ZN8JSObject6typeOfEP9JSContext","__ZN2js23InvokeConstructorKernelEP9JSContextRKNS_8CallArgsE","__ZN2JS5Value31setMagicWithObjectOrNullPayloadEP8JSObject","__ZN2js23CallJSNativeConstructorEP9JSContextPFiS1_jPN2JS5ValueEERKNS_8CallArgsE","__ZNK10JSFunction24isInterpretedConstructorEv","__ZN2js30InvokeConstructorWithGivenThisEP9JSContextP8JSObjectRKN2JS5ValueEjPS5_S8_","__ZN2js9ValueToIdEP9JSContextRKN2JS5ValueEPi","__ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi","__ZN2js19IsActiveWithOrBlockEP9JSContextR8JSObjecti","__Z27js_FloatingFrameIfGeneratorP9JSContextPN2js10StackFrameE","__ZN2js11UnwindScopeEP9JSContextii","__ZL9LeaveWithP9JSContext","__ZN2js8GetUpvarEP9JSContextjNS_11UpvarCookieE","__ZN2js14FindUpvarFrameEP9JSContextj","__ZNK2js10StackFrame8numFixedEv","__ZN23GenericInterruptEnablerIiEC1EPii","__ZN2js17PreserveRegsGuardC1EP9JSContextRNS_9FrameRegsE","__ZN2js17InterpreterFramesC1EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE","__ZNK2js10StackFrame15maybeFormalArgsEv","__ZN2js31ScriptPrologueOrGeneratorResumeEP9JSContextPNS_10StackFrameEb","__ZN2js5types17UseNewTypeAtEntryEP9JSContextPNS_10StackFrameE","__ZL9EnterWithP9JSContexti4JSOpj","__ZN2js14ScriptEpilogueEP9JSContextPNS_10StackFrameEb","__ZN2js12ContextStack14popInlineFrameERNS_9FrameRegsE","__ZN2jsL13FrameAtomBaseEP9JSContextPNS_10StackFrameE","__ZN2js5types10TypeScript7MonitorEP9JSContextP8JSScriptPhRKN2JS5ValueE","__Z24js_InternNonIntElementIdP9JSContextP8JSObjectRKN2JS5ValueEPiPS4_","__ZL12IteratorMoreP9JSContextP8JSObjectPbPN2JS5ValueE","_JSID_IS_VOID1831","__ZL24CanIncDecWithoutOverflowi","_JSID_IS_STRING1834","_JSID_IS_INT1835","_JSID_TO_INT1836","__ZN2JS5Value11getInt32RefEv","__ZN2jsL16CastAsPropertyOpEP8JSObject1842","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject1843","__ZN2JS5Value4swapERS0_","__ZNK2js5PCVal6isSlotEv","__ZNK2js5PCVal6toSlotEv","__ZN2jsL18GetDecomposeLengthEPhj","__ZNK2js5PCVal8isFunObjEv","__ZNK2js5PCVal8toFunObjEv","__ZNK2js5PCVal7toShapeEv","__ZNK2js18PropertyCacheEntry7vcapTagEv","__ZNK8JSObject5shapeEv","__ZNK2js18PropertyCacheEntry6vshapeEv","__ZNK2js5Shape16hasDefaultSetterEv","__ZN8JSObject25brandedOrHasMethodBarrierEv","__ZNK2js12CallReceiver11spAfterCallEv","__ZNK2js5Shape20isAccessorDescriptorEv","__ZN2js23AdvanceOverBlockchainOpEPh","__ZN2js10StackFrame11setYieldingEv","__ZL12IteratorNextP9JSContextP8JSObjectPN2JS5ValueE","__ZN2js10StackFrame6varObjEv","__ZN2js13PropertyCache4testEP9JSContextPhRP8JSObjectS6_RPNS_18PropertyCacheEntryERP6JSAtom","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE1830","__ZN2js5types10TypeScript15MonitorOverflowEP9JSContextP8JSScriptPh","__ZL5IsXMLRKN2JS5ValueE","__ZN2js5types10TypeScript13MonitorStringEP9JSContextP8JSScriptPh","__ZN2js9NumberDivEdd","__ZL7js_fmoddd","__ZN2js8ToNumberEP9JSContextPN2JS5ValueE","__ZN2JSL10Int32ValueEi1832","__ZL8DoIncDecP9JSContextPK10JSCodeSpecPN2JS5ValueES6_","__ZN2JSL11NumberValueEd1833","__Z23js_GetProtoIfDenseArrayP8JSObject","__ZN2js13PropertyCache10testForSetEP9JSContextPhP8JSObjectPPNS_18PropertyCacheEntryEPS5_PP6JSAtom","__ZNK2js18PropertyCacheEntry6addingEv","__ZN8JSObject21nativeSetSlotWithTypeEP9JSContextPKN2js5ShapeERKN2JS5ValueE","__ZN8JSObject6extendEP9JSContextPKN2js5ShapeEb","__Z18js_PurgeScopeChainP9JSContextP8JSObjecti","__ZN2js13StaticStrings23getUnitStringForElementEP9JSContextP8JSStringj","__ZN2js19ValuePropertyBearerEP9JSContextRKN2JS5ValueEi","__ZN2js5types10TypeScript13MonitorAssignEP9JSContextP8JSScriptPhP8JSObjectiRKN2JS5ValueE","__ZN2js14CallArgsFromSpEjPN2JS5ValueE","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction1837","__ZN2js12ContextStack15pushInlineFrameEP9JSContextRNS_9FrameRegsERKNS_8CallArgsER8JSObjectP10JSFunctionP8JSScriptNS_17InitialFrameFlagsE","__ZN2js14ScriptPrologueEP9JSContextPNS_10StackFrameEb","__ZN2js19ComputeImplicitThisEP9JSContextP8JSObjectRKN2JS5ValueEPS5_","__Z19js_UnwrapWithObjectP9JSContextP8JSObject","__ZN8JSScript8getConstEj","__ZN8JSScript9getRegExpEj","__ZN2JSL10MagicValueE10JSWhyMagic1838","__ZN2JSL14UndefinedValueEv1839","__ZN10JSFunction13setMethodAtomEP6JSAtom","__ZNK8JSObject20canHaveMethodBarrierEv","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject1840","__ZL13js_IsCallableRKN2JS5ValueE1841","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1845","__ZN2jsL21CopyInitializerObjectEP9JSContextP8JSObjectPNS_5types10TypeObjectE","__ZN2js13PropertyCache11testForInitEP9JSRuntimePhP8JSObjectPPKNS_5ShapeEPPNS_18PropertyCacheEntryE","__ZNK2JS5Value14isObjectOrNullEv","__ZN2js8Debugger19onDebuggerStatementEP9JSContextPN2JS5ValueE","__ZN2JSL11StringValueEP8JSString1846","_JSVAL_TO_OBJECT1847","__ZN2jsL24SetValueRangeToUndefinedEPN2JS5ValueES2_1848","__ZN2jsL12ToFrameFlagsENS_17InitialFrameFlagsE1859","__ZL14JSID_FROM_BITSj1904","__ZL17iterator_iteratorP9JSContextP8JSObjecti","_JSVAL_TO_OBJECT_IMPL1849","_JSVAL_IS_OBJECT_OR_NULL_IMPL","__ZN2js13PropertyCache4hashEPhj","_JSID_TO_STRING1867","_JSVAL_SAME_TYPE_IMPL","_JSID_IS_OBJECT1900","_JSID_TO_OBJECT1901","__ZL15JSDOUBLE_IS_NaNd1870","__ZL15JSDOUBLE_IS_NEGd","_JSDOUBLE_IS_NEGZERO1872","__ZN8JSScript4mainEv","__ZN2js10StackFrame24setFinishedInInterpreterEv","__ZN2js17InterpreterFrames20InterruptEnablerBaseC2Ev","__ZN2js12StackSegment11repointRegsEPNS_9FrameRegsE","__ZN2js17InterpreterFramesD2Ev","__ZN2js10StackFrame10isYieldingEv","__ZL13JSVAL_TO_IMPLN2JS5ValueE1850","__ZN2js2gcL25GetGCObjectFixedSlotsKindEj","__ZNK8JSObject9isDeclEnvEv","__ZN8JSObject10setIndexedEv","__ZN8JSObject16setMethodBarrierEv","__ZNK8JSObject8isVarObjEv","__ZNK8JSObject10isIteratorEv","__ZNK2js14NativeIterator9isKeyIterEv","__ZNK2js14NativeIterator7currentEv","__ZN2js14NativeIterator9incCursorEv","__ZN2js17InterpreterFramesC2EP9JSContextPNS_9FrameRegsERKNS0_20InterruptEnablerBaseE","_MAGIC_OBJ_TO_JSVAL_IMPL","__ZNK2js10FrameGuard6pushedEv","__ZN2js10FrameGuardC2Ev","__ZN2js23AutoPreserveEnumeratorsD2Ev","__ZN2js23AutoPreserveEnumeratorsC2EP9JSContext","__ZNK2js14NativeIterator5beginEv","__ZNK2js14NativeIterator3endEv","__ZN2js8Debugger17onExceptionUnwindEP9JSContextPN2JS5ValueE","__ZN2js10StackFrame16clearReturnValueEv","__ZN2js30ScriptEpilogueOrGeneratorYieldEP9JSContextPNS_10StackFrameEb","__ZN2js17InterpreterFramesD1Ev","__ZN2js17PreserveRegsGuardD1Ev","__ZN23GenericInterruptEnablerIiEC2EPii","__ZN2js17PreserveRegsGuardD2Ev","__ZN2js12ContextStack11repointRegsEPNS_9FrameRegsE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1852","__ZNK8JSObject11isPrimitiveEv","__ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject","__ZN8JSObject11updateFlagsEPKN2js5ShapeEb","__ZN8JSObject11updateShapeEP9JSContext","_JSDOUBLE_IS_INT321871","__ZN2js13PropertyCache10matchShapeEP9JSContextP8JSObjectj","__ZNK8JSObject17getNativeIteratorEv","__ZL12JSID_IS_ATOMi1876","__ZN2js9FrameRegs8popFrameEPN2JS5ValueE","__ZNK2js10StackFrame15constructorThisEv","__ZN2js17PreserveRegsGuardC2EP9JSContextRNS_9FrameRegsE","__ZN2js17ExecuteFrameGuardD2Ev","__ZN2js10FrameGuardD2Ev","__ZN2js17ExecuteFrameGuardC2Ev","__ZN2js16InvokeFrameGuardD2Ev","__ZN2js16InvokeFrameGuardC2Ev","__ZL17iterator_finalizeP9JSContextP8JSObject","__ZL14iterator_traceP8JSTracerP8JSObject","__ZN2js14NativeIterator4markEP8JSTracer","__ZN2js15VectorToIdArrayEP9JSContextRNS_12AutoIdVectorEPP9JSIdArray","__ZN2js16GetPropertyNamesEP9JSContextP8JSObjectjPNS_12AutoIdVectorE","__ZL8SnapshotP9JSContextP8JSObjectjPN2js12AutoIdVectorE","__ZN2js14NativeIterator16allocateIteratorEP9JSContextjRKNS_12AutoIdVectorE","__ZNK2js16AutoVectorRooterIiE5beginEv","__ZN2js19VectorToKeyIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZL19VectorToKeyIteratorP9JSContextP8JSObjectjRN2js12AutoIdVectorEjjPN2JS5ValueE","__ZN2js21VectorToValueIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZL17NewIteratorObjectP9JSContextj","__ZN2js14NativeIterator4initEP8JSObjectjjj","__ZL18RegisterEnumeratorP9JSContextP8JSObjectPN2js14NativeIteratorE","__ZN2jsL20UpdateNativeIteratorEPNS_14NativeIteratorEP8JSObject","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE5clearEv","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE6lengthEv","__ZL7CompareIjEbPT_S1_j","__ZNK2js6VectorIjLj8ENS_15TempAllocPolicyEE5beginEv","__ZNK8JSObject11isGeneratorEv","__ZN8JSObject17setNativeIteratorEPN2js14NativeIteratorE","__ZN2js28EnumeratedIdVectorToIteratorEP9JSContextP8JSObjectjRNS_12AutoIdVectorEPN2JS5ValueE","__ZN2js11GetIteratorEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js5types19MarkIteratorUnknownEP9JSContext","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE6appendIjEEbT_","__ZNK2js15NativeIterCache3getEj","__ZL17GetCustomIteratorP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js15NativeIterCache3setEjP8JSObject","__Z21js_ThrowStopIterationP9JSContext","__ZL13iterator_nextP9JSContextjPN2JS5ValueE","__Z18js_ValueToIteratorP9JSContextjPN2JS5ValueE","__Z16js_CloseIteratorP9JSContextP8JSObject","__ZL14CloseGeneratorP9JSContextP8JSObject","__Z26js_SuppressDeletedPropertyP9JSContextP8JSObjecti","__ZL29SuppressDeletedPropertyHelperI17SingleIdPredicateEbP9JSContextP8JSObjectT_","__ZN17SingleIdPredicateC1Ei","__Z25js_SuppressDeletedElementP9JSContextP8JSObjectj","__Z33js_SuppressDeletedIndexPropertiesP9JSContextP8JSObjectii","__ZN2js13StaticStrings6hasIntEi","_JSID_IS_INT1957","_JSID_TO_INT1958","_JSID_IS_STRING1965","__ZN2js10StackFrame21initFloatingGeneratorEv","__ZN2js2gcL15GetGCObjectKindEjb1947","__ZNK2js16AutoObjectRooter6objectEv","__ZN2js16AutoObjectRooter4addrEv","__ZN17SingleIdPredicateclEi","__ZL29SuppressDeletedPropertyHelperI19IndexRangePredicateEbP9JSContextP8JSObjectT_","__ZN19IndexRangePredicateC1Eii","__Z15js_IteratorMoreP9JSContextP8JSObjectPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom1935","__ZN2JSL11ObjectValueER8JSObject1936","__ZN2jsL15IsStopIterationERKN2JS5ValueE","__ZL15NewKeyValuePairP9JSContextiRKN2JS5ValueEPS2_","__Z15js_IteratorNextP9JSContextP8JSObjectPN2JS5ValueE","__ZN2jsL9IdToValueEi1939","__ZL20stopiter_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL18generator_finalizeP9JSContextP8JSObject","__ZL15generator_traceP8JSTracerP8JSObject","__Z15js_NewGeneratorP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_1942","__Z27js_FloatingFrameToGeneratorPN2js10StackFrameE","__ZL14generator_nextP9JSContextjPN2JS5ValueE","__ZL14generator_sendP9JSContextjPN2JS5ValueE","__ZL15generator_throwP9JSContextjPN2JS5ValueE","__ZL15generator_closeP9JSContextjPN2JS5ValueE","__ZN2js12GlobalObject18initGeneratorClassEP9JSContext","__Z22js_InitIteratorClassesP9JSContextP8JSObject","__ZL17InitIteratorClassP9JSContextPN2js12GlobalObjectE","__ZL22InitStopIterationClassP9JSContextPN2js12GlobalObjectE","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE1948","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE1951","__ZN19IndexRangePredicateclEi","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEE14internalAppendIjEEvT_","__ZN2JSL14UndefinedValueEv1961","__ZL8IteratorP9JSContextjPN2JS5ValueE","__ZL14JSID_FROM_BITSj1979","_JSID_TO_STRING1974","_JSID_IS_OBJECT1976","_JSID_TO_OBJECT1977","_INT_TO_JSID1982","__ZN2js15NativeIterCache8getIndexEj","__ZN2js10StackFrame13clearYieldingEv","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7popBackEv","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN19IndexRangePredicateC2Eii","__ZN17SingleIdPredicateC2Ei","__ZL12generator_opP9JSContext13JSGeneratorOpPN2JS5ValueEj","__ZL15SendToGeneratorP9JSContext13JSGeneratorOpP8JSObjectP11JSGeneratorRKN2JS5ValueE","__ZN2JSL17ObjectOrNullValueEP8JSObject1967","__ZN9JSContext25ensureGeneratorStackSpaceEv","__ZN2JSL10MagicValueE10JSWhyMagic1968","__ZN2js19GeneratorFrameGuardC1Ev","__ZN9JSContext14enterGeneratorEP11JSGenerator","__ZN9JSContext14leaveGeneratorEP11JSGenerator","__ZN2js19GeneratorFrameGuardD1Ev","__ZN2js19GeneratorFrameGuardD2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj2ES3_EEj","__ZN2js10VectorImplIP11JSGeneratorLj2ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js19GeneratorFrameGuardC2Ev","__ZN2js6VectorIP11JSGeneratorLj2ENS_17SystemAllocPolicyEE7reserveEj","__ZN2JSL11StringValueEP8JSString1973","__ZN2JSL10Int32ValueEi1975","__ZN2JSL12BooleanValueEb1988","__ZN2js10EmptyShape23getEmptyEnumeratorShapeEP9JSContext","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE1991","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE1992","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE1993","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC1ES2_","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE4initEj","__ZL25EnumerateNativePropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZL29EnumerateDenseArrayPropertiesP9JSContextP8JSObjectS2_jRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZL9EnumerateP9JSContextP8JSObjectS2_ibjRN2js7HashSetIi12IdHashPolicyNS3_15TempAllocPolicyEEEPNS3_12AutoIdVectorE","__ZN8JSObject9enumerateEP9JSContext11JSIterateOpPN2JS5ValueEPi","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED1Ev","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED1Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_ED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12destroyTableERS5_PNS0_14HashTableEntryIS2_EEj","__ZNK2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE12lookupForAddERKi","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrcvMS9_FvvEEv","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS3_6SetOpsES2_E6AddPtrERS6_","__ZN2js16AutoVectorRooterIiE6appendERKi","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE6appendIiEEbT_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE14internalAppendIiEEvT_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr7nonNullEv","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOps6getKeyERKi","__ZN12IdHashPolicy4hashEi","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash1Ejj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5hash2Ejjj","__ZN2js6detail14HashTableEntryIKiE10isLiveHashEj","__ZN12IdHashPolicy5matchEii","_JSID_IS_DEFAULT_XML_NAMESPACE","__ZL15JSDOUBLE_IS_NaNd2026","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13copyConstructIiEEvPiPKT_S7_","__ZNK2js6detail14HashTableEntryIKiE9isRemovedEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10overloadedEv","__ZN2js6detail14HashTableEntryIKiE7setLiveEj","__ZNK2js6detail14HashTableEntryIKiE6isFreeEv","__ZN2js6detail14HashTableEntryIKiE12setCollisionEv","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKiE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKiE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC2ERS4_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKiEEEptEv","__ZNK2js7MoveRefIiEcvRiEv","__ZN2js7MoveRefIiEC2ERi","__ZN2js6detail14HashTableEntryIKiEC2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3PtrC2ERNS0_14HashTableEntryIS2_EE","__ZN2js6detail14HashTableEntryIKiE9matchHashEj","__ZN2js6detail14HashTableEntryIKiE12setCollisionEj","__ZN2jsL7ReverseIiEEvPT_S2_1995","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC2ES5_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIiLj8ES1_EEj","__ZN2js10VectorImplIiLj8ENS_15TempAllocPolicyELb1EE13moveConstructIiEEvPiPKT_S7_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3addERNS8_6AddPtrE","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E15changeTableSizeEi","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E13findFreeEntryEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11createTableERS5_j","__ZNK2js6detail14HashTableEntryIKiE6isLiveEv","__ZN2js6detail14HashTableEntryIKiEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKiEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKiEEEC1ERS4_","__ZN2js4MoveIiEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIiEC1ERi","__ZN2js6detail14HashTableEntryIKiEC1Ev","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E12lookupForAddERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E11prepareHashERS2_","__ZNK2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6lookupERS2_jj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E5matchERNS0_14HashTableEntryIS2_EERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E10isLiveHashEj","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_E4initEj","__ZN2js7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEEC2ES2_","__ZN2js6detail9HashTableIKiNS_7HashSetIi12IdHashPolicyNS_15TempAllocPolicyEE6SetOpsES5_EC1ES5_","_JS_CeilingLog2","_JS_FloorLog2","__ZN2js9MathCacheC2Ev","__Z11js_math_absP9JSContextjPN2JS5ValueE","__Z17js_math_ceil_impld","__Z12js_math_ceilP9JSContextjPN2JS5ValueE","__Z18js_math_floor_impld","__Z13js_math_floorP9JSContextjPN2JS5ValueE","__Z11js_math_maxP9JSContextjPN2JS5ValueE","__Z11js_math_minP9JSContextjPN2JS5ValueE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2046","__ZL18JSDOUBLE_IS_FINITEd2027","__ZN2js9MathCache4hashEd","__ZL20JSDOUBLE_IS_INFINITEd","__ZL14random_setSeedP9JSContextx","__Z17js_IsMathFunctionPFiP9JSContextjPN2JS5ValueEE","__ZN2js2gcL15GetGCObjectKindEjb2034","__ZL13IMPL_TO_JSVAL12jsval_layout2047","_OBJECT_TO_JSVAL_IMPL2048","__ZL11random_nextP9JSContexti","__Z11js_math_powP9JSContextjPN2JS5ValueE","__ZL4powidi","__Z13js_InitRandomP9JSContext","__Z18js_math_round_impld","__Z13js_math_roundP9JSContextjPN2JS5ValueE","__Z12js_math_sqrtP9JSContextjPN2JS5ValueE","__ZN2jsL12GetMathCacheEP9JSContext","__ZN2js9MathCache6lookupEPFddEd","__ZL13math_toSourceP9JSContextjPN2JS5ValueE","__ZL9math_acosP9JSContextjPN2JS5ValueE","__ZL9math_asinP9JSContextjPN2JS5ValueE","__ZL9math_atanP9JSContextjPN2JS5ValueE","__ZL10math_atan2P9JSContextjPN2JS5ValueE","__ZL8math_cosP9JSContextjPN2JS5ValueE","__ZL8math_expP9JSContextjPN2JS5ValueE","__ZL8math_logP9JSContextjPN2JS5ValueE","__ZL11math_randomP9JSContextjPN2JS5ValueE","__ZL8math_sinP9JSContextjPN2JS5ValueE","__ZL8math_tanP9JSContextjPN2JS5ValueE","__Z16js_InitMathClassP9JSContextP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2032","_OBJECT_TO_JSVAL2033","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2035","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2036","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2039","__ZL17random_nextDoubleP9JSContext","__ZL13math_exp_bodyd","__ZL17math_atan2_kerneldd","__ZN13JSCompartment12getMathCacheEP9JSContext","__ZN2js22GetNativeStackBaseImplEv","__ZN2js16GetPrefixIntegerEP9JSContextPKtS3_iPS3_Pd","__ZN2js12ToCStringBufC2Ev","__ZN2js9DtoaCache6lookupEid","__ZN13JSShortString23inlineStorageBeforeInitEv","__ZN2js9DtoaCache5cacheEidP13JSFixedString","__ZL29ComputeAccurateDecimalIntegerP9JSContextPKtS2_Pd","__ZL32ComputeAccurateBinaryBaseIntegerP9JSContextPKtS2_i","__ZL9num_isNaNP9JSContextjPN2JS5ValueE","__ZL12num_isFiniteP9JSContextjPN2JS5ValueE","__ZL14num_parseFloatP9JSContextjPN2JS5ValueE","__ZL12num_parseIntP9JSContextjPN2JS5ValueE","__ZN2js12ToCStringBufD2Ev","__Z14js_IntToStringP9JSContexti","__ZN13JSShortString20initAtOffsetInBufferEPKtj","__Z14js_num_valueOfP9JSContextjPN2JS5ValueE","__ZN2js16GetPrimitiveThisIdEEbP9JSContextPN2JS5ValueEPT_","__ZL12num_toSourceP9JSContextjPN2JS5ValueE","__ZL12num_toStringP9JSContextjPN2JS5ValueE","__ZL18num_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL11num_toFixedP9JSContextjPN2JS5ValueE","__ZL17num_toExponentialP9JSContextjPN2JS5ValueE","__ZL15num_toPrecisionP9JSContextjPN2JS5ValueE","__ZN2js22InitRuntimeNumberStateEP9JSRuntime","__ZN2js24FinishRuntimeNumberStateEP9JSRuntime","__ZN2js13StaticStrings7hasUintEj","__ZN8JSObject8asNumberEv","__ZL18JSDOUBLE_IS_FINITEd2111","__ZL15JSDOUBLE_IS_NaNd2114","__Z18js_InitNumberClassP9JSContextP8JSObject","__ZN2js12NumberObject17setPrimitiveValueEd","__ZL6NumberP9JSContextjPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom2097","__ZN2js15NumberToCStringEP9JSContextPNS_12ToCStringBufEdi","_JSDOUBLE_IS_INT322100","__ZL12IntToCStringPN2js12ToCStringBufEii","__ZN2jsL19FracNumberToCStringEP9JSContextPNS_12ToCStringBufEdi","__Z17js_NumberToStringP9JSContextd","__ZL25js_NumberToStringWithBaseP9JSContextdi","__ZN2js14NumberToStringEP9JSContextd","__ZN2js13IndexToStringEP9JSContextj","__ZN2js25NumberValueToStringBufferEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer14appendInflatedEPKcj","__ZN2js12ToNumberSlowEP9JSContextN2JS5ValueEPd","__ZN2jsL18StringToNumberTypeIdEEbP9JSContextP8JSStringPT_","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE2103","__ZN2js20ValueToECMAInt32SlowEP9JSContextRKN2JS5ValueEPi","__ZL20js_DoubleToECMAInt32d2106","__ZN2js21ValueToECMAUint32SlowEP9JSContextRKN2JS5ValueEPj","__Z21js_DoubleToECMAUint32d","__ZN2js16ValueToInt32SlowEP9JSContextRKN2JS5ValueEPi","__ZN2js17ValueToUint16SlowEP9JSContextRKN2JS5ValueEPt","__ZN2js12NumberTraitsIdE10toSelfTypeEd","__ZL14JSID_FROM_BITSj2143","__ZN2js12NumberTraitsIdE3NaNEv","_JSDOUBLE_IS_NEGZERO2132","__ZNK2js7unicode13CharacterInfo7isSpaceEv","__ZNK7mozilla9RangedPtrIcEdeEv","__ZN7mozilla9RangedPtrIcEaSERKS1_","__ZNK7mozilla9RangedPtrIcE3getEv","__ZN7mozilla9RangedPtrIcEaSIcEERS1_RKNS0_IT_EE","__ZN7mozilla9RangedPtrIcEC2EPcS2_j","__ZN2js2gcL15GetGCObjectKindEjb2146","__ZN17BinaryDigitReader9nextDigitEv","__ZN17BinaryDigitReaderC2EiPKtS1_","__Z9js_strtodP9JSContextPKtS2_PS2_Pd","__ZN2jsL9SkipSpaceEPKtS1_","__ZN2js7unicode7IsSpaceEt","__ZN2js6detail17PrimitiveBehaviorIdE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIdE7extractERKN2JS5ValueE","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE19growByUninitializedEj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE10growByImplILb0EEEbj","__ZN7mozilla9RangedPtrIcEC1EPcS2_j","__ZN2js25BackfillIndexInCharBufferIcEEN7mozilla9RangedPtrIT_EEjS4_","__ZN7mozilla9RangedPtrIcEmmEv","__ZN7mozilla9RangedPtrIcEmIEj","__ZN7mozilla9RangedPtrIcEmiEj","__ZNK7mozilla9RangedPtrIcE6createEPc","__ZN2jsL14IsConstructingEPKN2JS5ValueE2144","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2145","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2147","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2148","__ZN2JSL11NumberValueEd2157","__ZL6num_toP9JSContext12JSDToStrModeS1_iiijPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2159","__ZL18js_DoubleToIntegerd2161","__ZL20ParseIntDoubleHelperd","__ZL20ParseIntStringHelperP9JSContextPKtS2_ibPd","__ZN17BinaryDigitReaderC1EiPKtS1_","_js_ObjectToOuterObject","__Z19OBJ_TO_OUTER_OBJECTP9JSContextRP8JSObject","__Z28NULLABLE_OBJ_TO_INNER_OBJECTP9JSContextRP8JSObject","__ZL12obj_getProtoP9JSContextP8JSObjectiPN2JS5ValueE","__ZL12obj_setProtoP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL14js_hash_objectPKv","__Z19js_EnterSharpObjectP9JSContextP8JSObjectPP9JSIdArrayPPt","__ZL16MarkSharpObjectsP9JSContextP8JSObjectPP9JSIdArray","__Z19js_LeaveSharpObjectP9JSContextPP9JSIdArray","__Z16js_TraceSharpMapP8JSTracerP16JSSharpObjectMap","__ZL27gc_sharp_table_entry_markerP11JSHashEntryiPv","__ZN2js18obj_toStringHelperEP9JSContextP8JSObject","__ZN2js13NonNullObjectEP9JSContextRKN2JS5ValueE","__ZN2js21InformalValueTypeNameERKN2JS5ValueE","__ZN2js4evalEP9JSContextjPN2JS5ValueE","__ZL17WarnOnTooManyArgsP9JSContextRKN2js8CallArgsE","__ZL10EvalKernelP9JSContextRKN2js8CallArgsE8EvalTypePNS1_10StackFrameER8JSObject","__ZNK8JSObject9getGlobalEv","__ZN2js10DirectEvalEP9JSContextRKNS_8CallArgsE","__ZN2js21AutoFunctionCallProbeC1EP9JSContextP10JSFunctionP8JSScript","__ZN2js21IsBuiltinEvalForScopeEP8JSObjectRKN2JS5ValueE","__ZNK2js12GlobalObject15getOriginalEvalEv","__ZN2js16IsAnyBuiltinEvalEP10JSFunction","__ZN2js25PrincipalsForCompiledCodeERKNS_8CallArgsEP9JSContext","__ZN2jsL16CastAsPropertyOpEP8JSObject2286","__ZN2jsL22CastAsStrictPropertyOpEP8JSObject2289","__Z23js_HasOwnPropertyHelperP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyEjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv2280","__Z17js_HasOwnPropertyP9JSContextPFiS0_P8JSObjectiPS2_PP10JSPropertyES2_iS3_S6_","__Z17js_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__Z23js_PropertyIsEnumerableP9JSContextP8JSObjectiPN2JS5ValueE","__Z19js_obj_defineGetterP9JSContextjPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE2285","__ZN2js11CheckAccessEP9JSContextP8JSObjecti12JSAccessModePN2JS5ValueEPj","__Z19js_obj_defineSetterP9JSContextjPN2JS5ValueE","__Z18obj_getPrototypeOfP9JSContextjPN2JS5ValueE","__ZN2jsL23DecompileValueGeneratorEP9JSContextiRKN2JS5ValueEP8JSString2290","__ZL12ATOM_TO_JSIDP6JSAtom2291","__ZN2js27NewPropertyDescriptorObjectEP9JSContextPK20JSPropertyDescriptorPN2JS5ValueE","__ZN2js8PropDesc26initFromPropertyDescriptorERK20JSPropertyDescriptor","__ZN2js8PropDesc10makeObjectEP9JSContext","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2296","__ZN2JSL12BooleanValueEb2297","__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js24GetOwnPropertyDescriptorEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js8PropDescC2Ev","__ZN2js8PropDesc10initializeEP9JSContextRKN2JS5ValueEb","__ZL11HasPropertyP9JSContextP8JSObjectiPN2JS5ValueEPb","__ZN2js14DefinePropertyEP9JSContextP8JSObjectRKiRKNS_8PropDescEbPb","__ZL21DefinePropertyOnArrayP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb","__ZL6RejectP9JSContextP8JSObjectjbPb","__ZL22DefinePropertyOnObjectP9JSContextP8JSObjectRKiRKN2js8PropDescEbPb","__Z20js_DefineOwnPropertyP9JSContextP8JSObjectiRKN2JS5ValueEPi","__ZN2js23ReadPropertyDescriptorsEP9JSContextP8JSObjectbPNS_12AutoIdVectorEPNS_23AutoPropDescArrayRooterE","__Z17js_PopulateObjectP9JSContextP8JSObjectS2_","__ZL16DefinePropertiesP9JSContextP8JSObjectS2_","__ZN8JSObject16sizeOfSlotsArrayEPFjPvE","__ZN8JSObject12sealOrFreezeEP9JSContextNS_16ImmutabilityTypeE","__ZN8JSObject16isSealedOrFrozenEP9JSContextNS_16ImmutabilityTypeEPb","__ZL12obj_toSourceP9JSContextjPN2JS5ValueE","__ZL12obj_toStringP9JSContextjPN2JS5ValueE","__ZL18obj_toLocaleStringP9JSContextjPN2JS5ValueE","__ZL11obj_valueOfP9JSContextjPN2JS5ValueE","__ZL9obj_watchP9JSContextjPN2JS5ValueE","__ZL11obj_unwatchP9JSContextjPN2JS5ValueE","__ZL18obj_hasOwnPropertyP9JSContextjPN2JS5ValueE","__ZL17obj_isPrototypeOfP9JSContextjPN2JS5ValueE","__ZL24obj_propertyIsEnumerableP9JSContextjPN2JS5ValueE","__ZL16obj_lookupGetterP9JSContextjPN2JS5ValueE","__ZN2jsL15NewObjectGCKindEP9JSContextPNS_5ClassE","_JSID_IS_EMPTY2321","__ZL16obj_lookupSetterP9JSContextjPN2JS5ValueE","__ZL28obj_getOwnPropertyDescriptorP9JSContextjPN2JS5ValueE","__ZL8obj_keysP9JSContextjPN2JS5ValueE","__ZL18obj_definePropertyP9JSContextjPN2JS5ValueE","__ZL20obj_definePropertiesP9JSContextjPN2JS5ValueE","__ZL10obj_createP9JSContextjPN2JS5ValueE","__ZL23obj_getOwnPropertyNamesP9JSContextjPN2JS5ValueE","__ZL16obj_isExtensibleP9JSContextjPN2JS5ValueE","__ZL21obj_preventExtensionsP9JSContextjPN2JS5ValueE","__ZL10obj_freezeP9JSContextjPN2JS5ValueE","__ZL12obj_isFrozenP9JSContextjPN2JS5ValueE","__ZL8obj_sealP9JSContextjPN2JS5ValueE","__ZL12obj_isSealedP9JSContextjPN2JS5ValueE","__Z9js_ObjectP9JSContextjPN2JS5ValueE","__Z22js_ValueToObjectOrNullP9JSContextRKN2JS5ValueEPP8JSObject","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2318","__ZN2js17NewReshapedObjectEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindEPKNS_5ShapeE","__ZN2jsL17NewObjectWithTypeEP9JSContextPNS_5types10TypeObjectEP8JSObjectNS_2gc9AllocKindE","__ZL11with_TypeOfP9JSContextP8JSObject","__ZN2js20DefineNativePropertyEP9JSContextP8JSObjectiRKN2JS5ValueEPFiS1_S3_iPS5_EPFiS1_S3_iiS8_Ejjij","__Z13js_CreateThisP9JSContextP8JSObject","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2326","__Z33js_CreateThisForFunctionWithProtoP9JSContextP8JSObjectS2_","__ZL29CreateThisForFunctionWithTypeP9JSContextPN2js5types10TypeObjectEP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","__Z24js_CreateThisForFunctionP9JSContextP8JSObjectb","__Z9DetectingP9JSContextPh","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh2329","__Z13js_InferFlagsP9JSContextj","__ZL19with_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL18with_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL18with_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL15with_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL16with_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL15with_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL15with_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL16with_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL15with_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL15with_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL18with_GetAttributesP9JSContextP8JSObjectiPj","__ZL25with_GetElementAttributesP9JSContextP8JSObjectjPj","__ZL25with_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL18with_SetAttributesP9JSContextP8JSObjectiPj","__ZL25with_SetElementAttributesP9JSContextP8JSObjectjPj","__ZL25with_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19with_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL18with_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL18with_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL14with_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZL15with_ThisObjectP9JSContextP8JSObject","__Z16js_NewWithObjectP9JSContextP8JSObjectS2_i","__ZN2js10EmptyShape17getEmptyWithShapeEP9JSContext","__ZN2JSL10Int32ValueEi2332","__ZN8JSObject11setWithThisEPS_","__ZN2js2gcL15GetGCObjectKindEjb2335","__ZNK8JSObject7watchedEv","__ZN8JSObject16updateFixedSlotsEj","__Z17js_NewBlockObjectP9JSContext","__ZN2js10EmptyShape18getEmptyBlockShapeEP9JSContext","__Z19js_CloneBlockObjectP9JSContextP8JSObjectPN2js10StackFrameE","__ZN8JSObject15initClonedBlockEP9JSContextPN2js5types10TypeObjectEPNS2_10StackFrameE","__ZN8JSObject27ensureInstanceReservedSlotsEP9JSContextj","__Z17js_PutBlockObjectP9JSContexti","__ZN8JSObject13copySlotRangeEjPKN2JS5ValueEj","__ZN8JSObject19defineBlockVariableEP9JSContextii","__ZL17block_getPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17block_setPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN8JSObject9growSlotsEP9JSContextj","__ZN8JSObject20nonNativeSetPropertyEP9JSContextiPN2JS5ValueEi","__ZN8JSObject19nonNativeSetElementEP9JSContextjPN2JS5ValueEi","__ZN8JSObject18copyPropertiesFromEP9JSContextPS_","__ZN2js15AutoShapeVectorC1EP9JSContext","__ZN2js16AutoVectorRooterIPKNS_5ShapeEE6appendERKS3_","__ZNK2js16AutoVectorRooterIPKNS_5ShapeEE6lengthEv","__ZN2js16AutoVectorRooterIPKNS_5ShapeEEixEj","__ZN2js15AutoShapeVectorD1Ev","__ZN8JSObject5cloneEP9JSContextPS_S2_","__ZN2jsL9NewObjectILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE2346","__ZL9CopySlotsP9JSContextP8JSObjectS2_","__ZN8JSObject19ReserveForTradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE7reserveEj","__ZN2jsL3MaxIjEET_S1_S1_2347","__Z15FindObjectIndexP13JSObjectArrayP8JSObject","__ZNK2JS5ValueneERKS0_","__ZN8JSObject9TradeGutsEP9JSContextPS_S2_RNS_17TradeGutsReservedE","__ZN2js6VectorIN2JS5ValueELj0ENS_15TempAllocPolicyEE16infallibleAppendERKS2_","__ZN8JSObject14clearSlotRangeEjj","__ZN8JSObject4swapEP9JSContextPS_","__ZN8JSObject17TradeGutsReservedC1EP9JSContext","__ZN8JSObject17TradeGutsReservedD1Ev","__Z17js_XDRBlockObjectP10JSXDRStatePP8JSObject","__ZN2js16AutoVectorRooterIPKNS_5ShapeEE6growByEj","__ZL12JSID_TO_ATOMi2352","__ZN2js29DefineConstructorAndPrototypeEP9JSContextP8JSObject10JSProtoKeyP6JSAtomS3_PNS_5ClassEPFiS1_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSF_SH_PS3_","__ZN2jsL9NewObjectILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2353","__ZL18DefineStandardSlotP9JSContextP8JSObject10JSProtoKeyP6JSAtomRKN2JS5ValueEjRb","__ZN2JSL11ObjectValueER8JSObject2354","__ZN2jsL14SetClassObjectEP9JSContextP8JSObject10JSProtoKeyS3_S3_","__ZN2JSL17ObjectOrNullValueEP8JSObject2355","__ZN2jsL16ClearClassObjectEP9JSContextP8JSObject10JSProtoKey","__ZN2js23IsStandardClassResolvedEP8JSObjectPNS_5ClassE","__ZN2js35MarkStandardClassInitializedNoProtoEP8JSObjectPNS_5ClassE","__ZN2js2gcL14GetGCKindSlotsENS0_9AllocKindE2367","__ZN2js2gcL21TryIncrementAllocKindEPNS0_9AllocKindE","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2381","__Z12js_InitClassP9JSContextP8JSObjectS2_PN2js5ClassEPFiS0_jPN2JS5ValueEEjP14JSPropertySpecP14JSFunctionSpecSC_SE_PS2_","__Z20js_GetClassPrototypeP9JSContextP8JSObject10JSProtoKeyPS2_PN2js5ClassE","__ZN2jsL15ClearValueRangeEPN2JS5ValueEjb2364","__ZN8JSObject10allocSlotsEP9JSContextj","__ZN2js5types21MarkObjectStateChangeEP9JSContextP8JSObject","__ZN8JSObject11shrinkSlotsEP9JSContextj","__ZN2js8SetProtoEP9JSContextP8JSObjectS3_b","__Z17js_GetClassObjectP9JSContextP8JSObject10JSProtoKeyPS2_","__ZN2js13AutoResolvingC1EP9JSContextP8JSObjectiNS0_4KindE","__ZNK2js13AutoResolving14alreadyStartedEv","__ZN2js13AutoResolvingD1Ev","__Z18js_FindClassObjectP9JSContextP8JSObject10JSProtoKeyPN2JS5ValueEPN2js5ClassE","__ZN2js23LookupPropertyWithFlagsEP9JSContextP8JSObjectijPS3_PP10JSProperty","__Z18js_ConstructObjectP9JSContextPN2js5ClassEP8JSObjectS5_jPN2JS5ValueE","__ZN8JSObject9allocSlotEP9JSContextPj","__ZN8JSObject8freeSlotEP9JSContextj","__ZN2JSL18PrivateUint32ValueEj2384","__Z24js_PurgeScopeChainHelperP9JSContextP8JSObjecti","__ZL15PurgeProtoChainP9JSContextP8JSObjecti","__Z20js_AddNativePropertyP9JSContextP8JSObjectiPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS5_Ejjji","__Z28js_ChangeNativePropertyAttrsP9JSContextP8JSObjectPKN2js5ShapeEjjPFiS0_S2_iPN2JS5ValueEEPFiS0_S2_iiS9_E","__Z17js_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__Z16js_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZN8JSObject18methodWriteBarrierEP9JSContextRKN2js5ShapeERKN2JS5ValueE","__ZL19CallAddPropertyHookP9JSContextPN2js5ClassEP8JSObjectPKNS1_5ShapeEPN2JS5ValueE","__ZL29LookupPropertyWithFlagsInlineP9JSContextP8JSObjectijPS2_PP10JSProperty","__Z16js_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__Z21js_FindPropertyHelperP9JSContextibbPP8JSObjectS3_PP10JSProperty","__ZNK2js12ContextStack25currentScriptedScopeChainEv","__ZN2jsL25IsCacheableNonGlobalScopeEP8JSObject2396","__Z15js_FindPropertyP9JSContextibPP8JSObjectS3_PP10JSProperty","__Z21js_FindIdentifierBaseP9JSContextP8JSObjecti","__Z12js_NativeGetP9JSContextP8JSObjectS2_PKN2js5ShapeEjPN2JS5ValueE","__ZL18js_NativeGetInlineP9JSContextP8JSObjectS2_S2_PKN2js5ShapeEjPN2JS5ValueE","__Z12js_NativeSetP9JSContextP8JSObjectPKN2js5ShapeEbbPN2JS5ValueE","__ZN8JSObject18methodWriteBarrierEP9JSContextjRKN2JS5ValueE","__Z29js_ReportGetterOnlyAssignmentP9JSContext","__ZNK2js5Shape3setEP9JSContextP8JSObjectbPN2JS5ValueE","__ZN8JSObject14nativeContainsEP9JSContextRKN2js5ShapeE","__Z20js_GetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueE","__ZL26js_GetPropertyHelperInlineP9JSContextP8JSObjectS2_ijPN2JS5ValueE","__Z14js_GetPropertyP9JSContextP8JSObjectS2_iPN2JS5ValueE","__Z13js_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","_JSID_TO_STRING2421","__ZeqRK8JSObjectS1_2422","__ZNK2js5Shape10hasShortIDEv","__ZN2js18GetPropertyDefaultEP9JSContextP8JSObjectiRKN2JS5ValueEPS5_","__Z12js_GetMethodP9JSContextP8JSObjectijPN2JS5ValueE","__Z31js_CheckUndeclaredVarAssignmentP9JSContextP8JSString","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2415","__ZN8JSObject14reportReadOnlyEP9JSContextij","__ZN2jsL9IdToValueEi2416","__ZN8JSObject21reportNotConfigurableEP9JSContextij","__ZN8JSObject19reportNotExtensibleEP9JSContextj","__ZN8JSObject10callMethodEP9JSContextijPN2JS5ValueES4_","__Z20js_SetPropertyHelperP9JSContextP8JSObjectijPN2JS5ValueEi","__ZN2js10CallSetterEP9JSContextP8JSObjectiPFiS1_S3_iiPN2JS5ValueEEjjiS6_","__ZNK2js5Shape10shadowableEv","__ZL25CloneFunctionForSetMethodP9JSContextPN2JS5ValueE","__Z19js_SetElementHelperP9JSContextP8JSObjectjjPN2JS5ValueEi","__Z16js_GetAttributesP9JSContextP8JSObjectiPj","__Z23js_GetElementAttributesP9JSContextP8JSObjectjPj","__ZN8JSObject20getElementAttributesEP9JSContextjPj","__Z22js_SetNativeAttributesP9JSContextP8JSObjectPN2js5ShapeEj","__Z16js_SetAttributesP9JSContextP8JSObjectiPj","__Z23js_SetElementAttributesP9JSContextP8JSObjectjPj","__ZN8JSObject20setElementAttributesEP9JSContextjPj","_INT_TO_JSID2431","__ZN2jsL8JsvalifyEPNS_5ClassE2452","__ZN2jsL8ValueifyEP7JSClass2453","__ZN2js2gcL6GCPokeEP9JSContextN2JS5ValueE","__Z17js_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js16CallJSPropertyOpEP9JSContextPFiS1_P8JSObjectiPN2JS5ValueEES3_iS6_","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject2432","__Z16js_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js15HasDataPropertyEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js12DefaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE","__ZN2jsL15MaybeCallMethodEP9JSContextP8JSObjectiPN2JS5ValueE","__Z12js_EnumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__Z9js_TypeOfP9JSContextP8JSObject","__Z13js_IsDelegateP9JSContextP8JSObjectRKN2JS5ValueE","__ZN2js18FindClassPrototypeEP9JSContextP8JSObject10JSProtoKeyPS3_PNS_5ClassE","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE2445","__Z17PrimitiveToObjectP9JSContextRKN2JS5ValueE","__ZN2js12StringObject6createEP9JSContextP8JSString","__ZN2js12NumberObject6createEP9JSContextd","__Z20js_PrimitiveToObjectP9JSContextPN2JS5ValueE","__ZN2js12ToObjectSlowEP9JSContextPN2JS5ValueE","__Z23js_ValueToNonNullObjectP9JSContextRKN2JS5ValueE","__Z12js_XDRObjectP10JSXDRStatePP8JSObject","__Z14js_ClearNativeP9JSContextP8JSObject","__ZL21LastConfigurableShapeP8JSObject","__Z18js_GetReservedSlotP9JSContextP8JSObjectjPN2JS5ValueE","__ZL16js_InitNullClassP9JSContextP8JSObject","_JSID_IS_STRING2486","_JSID_IS_INT2487","_JSID_TO_INT2488","_JSID_IS_OBJECT2489","_JSID_TO_OBJECT2490","__ZN8JSObject8asStringEv","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE3endEv","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13copyConstructIS3_EEvPS3_PKT_SA_","__ZNK2js5Shape8setterOpEv","__ZNK2js5Shape8getterOpEv","__ZN2js13AutoResolvingD2Ev","__ZN2js13AutoResolvingC2EP9JSContextP8JSObjectiNS0_4KindE","__Z18js_SetReservedSlotP9JSContextP8JSObjectjRKN2JS5ValueE","__ZN2JSL9NullValueEv2460","__Z25js_GetterOnlyPropertyStubP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPPKNS_5ShapeES3_","__ZN2jsL7PodZeroIPKNS_5ShapeEEEvPT_j","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE13growStorageByEj","__ZNK2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS3_Lj8ES4_EEj","__ZN2js10VectorImplIPKNS_5ShapeELj8ENS_15TempAllocPolicyELb1EE13moveConstructIS3_EEvPS3_PKT_SA_","__ZN2js6detailL9NewObjectILb1ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2464","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2465","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2468","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEixEj","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE6appendIS3_EEbT_","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEE14internalAppendIS3_EEvT_","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2469","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2470","__ZN2js6detailL9NewObjectILb0ELb1EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2471","__ZN2js12StringObject4initEP9JSContextP8JSString","__ZN2js12StringObject13setStringThisEP8JSString","__ZN2JSL11StringValueEP8JSString2480","__ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction2483","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction2484","__ZN2js22CallJSPropertyOpSetterEP9JSContextPFiS1_P8JSObjectiiPN2JS5ValueEES3_iiS6_","__ZL12JSID_IS_ATOMiP6JSAtom2491","__ZNK2js5Shape11setterValueEv","__ZL18ChangesMethodValueRKN2JS5ValueES2_","__ZNK2js5Shape3getEP9JSContextP8JSObjectS4_S4_PN2JS5ValueE","__ZNK2js5Shape11getterValueEv","__ZL13CallResolveOpP9JSContextP8JSObjectS2_ijPS2_PP10JSPropertyPb","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE2500","__ZL14JSID_FROM_BITSj2517","__ZNK2js8PropDesc16isDataDescriptorEv","__ZNK2js8PropDesc20isAccessorDescriptorEv","__ZNK2js8PropDesc11getterValueEv","__ZNK2js8PropDesc11setterValueEv","__ZNK2js8PropDesc8writableEv","__ZNK2js8PropDesc12configurableEv","__ZNK2js8PropDesc10enumerableEv","__ZN2js21AutoFunctionCallProbeC2EP9JSContextP10JSFunctionP8JSScript","__ZN15EvalScriptGuard11foundScriptEv","__ZN15EvalScriptGuard12setNewScriptEP8JSScript","__ZNK15EvalScriptGuard6scriptEv","__ZN8JSObject17TradeGutsReservedD2Ev","__ZN8JSObject17TradeGutsReservedC2EP9JSContext","__ZN2js15AutoShapeVectorD2Ev","__ZN2js16AutoVectorRooterIPKNS_5ShapeEED2Ev","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEED2Ev","__ZN2js15AutoShapeVectorC2EP9JSContext","__ZN2js16AutoVectorRooterIPKNS_5ShapeEEC2EP9JSContexti","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC1ES4_","__ZN2js6VectorIPKNS_5ShapeELj8ENS_15TempAllocPolicyEEC2ES4_","__Z23js_LiveFrameIfGeneratorPN2js10StackFrameE","__ZN8JSObject15getFixedSlotRefEj","__ZNK8JSObject11getWithThisEv","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2510","__ZL24GetFirstArgumentAsObjectP9JSContextjPN2JS5ValueEPKcPP8JSObject","__ZL12JSID_IS_ATOMi2511","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2514","__ZL17obj_watch_handlerP9JSContextP8JSObjectiN2JS5ValueEPS4_Pv","__ZN2jsL12PodArrayZeroIN2JS5ValueELj4EEEvRAT0__T_2515","__ZNK2js8PropDesc19isGenericDescriptorEv","__ZNK2js8PropDesc6getterEv","__ZNK2js8PropDesc6setterEv","__ZNK2js5Shape17getterOrUndefinedEv","__ZNK2js5Shape17setterOrUndefinedEv","__ZL6RejectP9JSContextjbiPb","__ZNK2js8PropDesc12setterObjectEv","__ZNK2js8PropDesc12getterObjectEv","__ZN10JSONParserC1EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE","__ZN15EvalScriptGuardC1EP9JSContextP14JSLinearString","__ZN15EvalScriptGuard17lookupInEvalCacheEPN2js10StackFrameEjP12JSPrincipalsR8JSObject","__ZN15EvalScriptGuardD1Ev","__ZN15EvalScriptGuardD2Ev","__ZL15EvalCacheLookupP9JSContextP14JSLinearStringPN2js10StackFrameEjP12JSPrincipalsR8JSObjectPP8JSScript","__ZN8JSScript17getCallerFunctionEv","__ZN15EvalScriptGuardC2EP9JSContextP14JSLinearString","__ZL13EvalCacheHashP9JSContextP14JSLinearString","__ZN10JSONParserC2EP9JSContextPKtjNS_11ParsingModeENS_13ErrorHandlingE","__Z13js_json_parseP9JSContextjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv2537","__ZN2js20ParseJSONWithReviverEP9JSContextPKtjRKN2JS5ValueEPS5_12DecodingMode","__Z17js_json_stringifyP9JSContextjPN2JS5ValueE","_INT_FITS_IN_JSID2543","_INT_TO_JSID2544","__ZN2js2gcL15GetGCObjectKindEjb2555","__Z12js_StringifyP9JSContextPN2JS5ValueEP8JSObjectS2_RN2js12StringBufferE","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC1ES3_","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE4initEj","__ZN2jsL16ValueFitsInInt32ERKN2JS5ValueEPi2542","__ZNK2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE12lookupForAddERKi","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrcvMSA_FvvEEv","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKiNS4_6SetOpsES3_E6AddPtrERS7_","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED1Ev","__ZN2JSL11NumberValueEd2545","__ZN2JSL11StringValueEP8JSString2546","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd2547","__ZN2js12StringBuffer7appendNEtj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2548","__ZL12ATOM_TO_JSIDP6JSAtom2549","__ZN16StringifyContextC1EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE","__ZN16StringifyContext4initEv","__ZL15PreprocessValueIiEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext","__ZL15IsFilteredValueRKN2JS5ValueE","__ZL3StrP9JSContextRKN2JS5ValueEP16StringifyContext","__ZN16StringifyContextD1Ev","__ZL13js_IsCallableRKN2JS5ValueE2550","__ZL6ReviveP9JSContextRKN2JS5ValueEPS2_","__ZL13json_toSourceP9JSContextjPN2JS5ValueE","__Z16js_InitJSONClassP9JSContextP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_2553","_OBJECT_TO_JSVAL2554","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr7nonNullEv","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOps6getKeyERKi","__ZN2js13DefaultHasherIiE4hashERKi","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE2566","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash1Ejj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5hash2Ejjj","__ZN2js13DefaultHasherIiE5matchERKiS3_","_JSID_IS_STRING2575","_JSID_TO_STRING2576","_JSID_IS_INT2577","_JSID_TO_INT2578","_JSID_IS_OBJECT2581","_JSID_TO_OBJECT2582","_JSDOUBLE_IS_NEGZERO2573","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10overloadedEv","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3PtrC2ERNS0_14HashTableEntryIS2_EE","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC2ES6_","_OBJECT_TO_JSVAL_IMPL2574","__ZL13IMPL_TO_JSVAL12jsval_layout2583","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE2556","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_2557","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE2560","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3addERNS9_6AddPtrE","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E15changeTableSizeEi","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E13findFreeEntryEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11createTableERS6_j","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12destroyTableERS6_PNS0_14HashTableEntryIS2_EEj","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E12lookupForAddERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E11prepareHashERS2_","__ZNK2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6lookupERS2_jj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC1ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E6AddPtrC2ERNS0_14HashTableEntryIS2_EEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E5matchERNS0_14HashTableEntryIS2_EERS2_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E10isLiveHashEj","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_E4initEj","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEEC2ES3_","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_EC1ES6_","__ZN14KeyStringifierIiE8toStringEP9JSContexti","__ZN2JSL11ObjectValueER8JSObject2569","_JSDOUBLE_IS_INT322570","__ZN2jsL10IdToStringEP9JSContexti","__ZN2jsL9IdToValueEi2579","__ZN2JSL10Int32ValueEi2580","__ZL4WalkP9JSContextP8JSObjectiRKN2JS5ValueEPS4_","__ZN16StringifyContextD2Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED1Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_ED2Ev","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12destroyTableERS8_PNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr7nonNullEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6SetOps6getKeyERKS2_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash1Ejj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5hash2Ejjj","__ZL18JSDOUBLE_IS_FINITEd2585","__ZN7mozilla15AlignedStorage2IN2js12AutoIdVectorEE4addrEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11underloadedEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16setTableSizeLog2Ej","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE3endEv","__ZN7mozilla5MaybeIN2js12AutoIdVectorEEC2Ev","__ZL5QuoteP9JSContextRN2js12StringBufferEP8JSString","__ZL2JAP9JSContextP8JSObjectP16StringifyContext","__ZL2JOP9JSContextP8JSObjectP16StringifyContext","__ZN13CycleDetectorC1EP16StringifyContextP8JSObject","__ZN13CycleDetector4initEP9JSContext","__ZN7mozilla5MaybeIN2js12AutoIdVectorEEC1Ev","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE9constructIP9JSContextEEvRKT_","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE4addrEv","__ZNK2js16AutoVectorRooterIiEixEj","__ZL11WriteIndentP9JSContextP16StringifyContextj","__ZN7mozilla5MaybeIN2js12AutoIdVectorEED1Ev","__ZN13CycleDetectorD1Ev","__ZN13CycleDetectorD2Ev","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeERKS2_","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS6_6SetOpsES5_E3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeENSB_3PtrE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E15changeTableSizeEi","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11createTableERS8_j","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E13findFreeEntryEj","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E11prepareHashERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6lookupERS4_jj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E5matchERNS0_14HashTableEntryIS4_EERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10isLiveHashEj","__ZN7mozilla5MaybeIN2js12AutoIdVectorEED2Ev","__ZN7mozilla5MaybeIN2js12AutoIdVectorEE3asTEv","__ZN2js12StringBuffer6appendEPKtS2_","__ZNK2js12StringBuffer5beginEv","__ZNK2js12StringBuffer3endEv","__ZNK2js6VectorIiLj8ENS_15TempAllocPolicyEEixEj","__ZNK2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS6_6SetOpsES5_E6AddPtrERS9_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrERS4_","__ZL14JSID_FROM_BITSj2592","__ZN10JSONParser5tokenENS_5TokenE","__ZL23IsQuoteSpecialCharactert","__ZL15JSDOUBLE_IS_NaNd2597","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E10overloadedEv","__ZN13CycleDetectorC2EP16StringifyContextP8JSObject","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC2ES8_","__ZN2js10VectorImplItLj32ENS_18ContextAllocPolicyELb1EE14copyConstructNEPtjRKt","__ZN10JSONParser11errorReturnEv","__ZNK7mozilla9RangedPtrIKtEltIS1_EEbRKNS0_IT_EE","__ZNK7mozilla9RangedPtrIKtE3getEv","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E3addERNSB_6AddPtrE","__ZNK2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E12lookupForAddERS4_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZL15PreprocessValueIjEbP9JSContextP8JSObjectT_PN2JS5ValueEP16StringifyContext","__ZN14KeyStringifierIjE8toStringEP9JSContextj","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_E4initEj","__ZN16StringifyContextC2EP9JSContextRN2js12StringBufferERKS3_P8JSObjectRKNS2_12AutoIdVectorE","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashSetIP8JSObjectNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableIKP8JSObjectNS_7HashSetIS3_NS_13DefaultHasherIS3_EENS_15TempAllocPolicyEE6SetOpsES8_EC1ES8_","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2593","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2594","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE7appendNERKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE15internalAppendNERKtj","__ZL18js_DoubleToIntegerd2596","__ZN2js7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED1Ev","__ZN2js6detail9HashTableIKiNS_7HashSetIiNS_13DefaultHasherIiEENS_15TempAllocPolicyEE6SetOpsES6_ED2Ev","__ZN10JSONParser5errorEPKc","__ZN10JSONParser10readNumberEv","__ZN10JSONParser11numberTokenEd","__ZL16IsJSONWhitespacet","__ZNK7mozilla9RangedPtrIKtEgeIS1_EEbRKNS0_IT_EE","__ZNK7mozilla9RangedPtrIKtEmiERKS2_","__ZN10JSONParser7advanceEv","__ZN10JSONParser10readStringILNS_10StringTypeE1EEENS_5TokenEv","__ZNK7mozilla9RangedPtrIKtEixEi","__ZN10JSONParser22advanceAfterObjectOpenEv","__ZNK10JSONParser11stringValueEv","__ZNK10JSONParser11numberValueEv","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE5emptyEv","__ZN10JSONParser10readStringILNS_10StringTypeE0EEENS_5TokenEv","__ZN10JSONParser24advanceAfterArrayElementEv","__ZN10JSONParser19advancePropertyNameEv","__ZN10JSONParser20advancePropertyColonEv","__ZN10JSONParser20advanceAfterPropertyEv","__ZN10JSONParser5parseEPN2JS5ValueE","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC1ES2_","__ZN2JSL14UndefinedValueEv2637","__ZN2js16AutoVectorRooterIN2JS5ValueEE7popCopyEv","__ZL12ATOM_TO_JSIDP6JSAtom2638","__ZNK10JSONParser9atomValueEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE6appendIS1_EEbT_","__ZN2JSL12BooleanValueEb2639","__ZN2JSL9NullValueEv2640","__ZN2JSL11ObjectValueER8JSObject2641","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE2642","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE4backEv","__ZL14JSID_FROM_BITSj2665","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefI11ParserStateEcvRS1_Ev","__ZN2js7MoveRefI11ParserStateEC2ERS1_","__ZN7mozilla9RangedPtrIKtEaSERKS2_","__ZN2js2gcL15GetGCObjectKindEjb2650","__Z28js_GetVariableBytecodeLength4JSOpPh","_js_GetVariableStackUses","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE14internalAppendIS1_EEvT_","__ZNK2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS1_Lj0ES2_EEj","__ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefI11ParserStateEC1ERS1_","__ZN2js10VectorImplI11ParserStateLj0ENS_15TempAllocPolicyELb0EE13moveConstructIS1_EEvPS1_PKT_S8_","__ZN2js4MoveI11ParserStateEENS_7MoveRefIT_EERKS3_","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorIN2JS5ValueELj8ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorI11ParserStateLj0ENS_15TempAllocPolicyEEC2ES2_","__ZN10JSONParser11stringTokenEP8JSString","__ZN2JSL11StringValueEP8JSString2648","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE2651","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE2652","__ZN2JSL11NumberValueEd2666","_js_GetIndexFromBytecode","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh2825","_js_GetEnterBlockStackDefs","__ZN2js19SprintReserveAmountEPNS_8SprinterEj","__ZL18SprintEnsureBufferPN2js8SprinterEj","__ZN2js9SprintPutEPNS_8SprinterEPKcj","__ZN2js13SprintCStringEPNS_8SprinterEPKc","__ZN2js12SprintStringEPNS_8SprinterEP8JSString","__ZN2js6SprintEPNS_8SprinterEPKcz","_js_QuoteString","__ZL11QuoteStringPN2js8SprinterEP8JSStringj","_js_NewPrinter","__ZN9JSContext4new_IN2js6VectorIP6JSAtomLj0ENS1_15TempAllocPolicyEEEPS_EEPT_T0_","_js_DestroyPrinter","__ZN2js10Foreground7delete_INS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEEEEvPT_","_js_GetPrinterOutput","_js_printf","_js_puts","__Z8GetLocalP11SprintStacki","__ZL6GetStrP11SprintStackj","__ZL12JSID_IS_ATOMi2840","__ZL12JSID_TO_ATOMi2841","_js_DecompileScript","__ZL13DecompileBodyP9JSPrinterP8JSScriptPh","_js_DecompileToString","_js_DecompileFunctionBody","_js_DecompileFunction","__ZN19AutoScriptUntrapperC1EP9JSContextP8JSScriptPPh","__ZL10StackDepthP8JSScript","__ZN2js10StackFrame13clearImacropcEv","__ZN2js10StackFrame11setImacropcEPh","__ZN2js17CallResultEscapesEPh","__ZL15GetArgOrVarAtomP9JSPrinterj","__ZL15InitSprintStackP9JSContextP11SprintStackP9JSPrinterj","__ZL22DecompileDestructuringP11SprintStackPhS1_","__ZL6PopStrP11SprintStack4JSOp","__ZN19AutoScriptUntrapperD1Ev","_js_DecompileValueGenerator","__ZL19js_GetTopStackFrameP9JSContext15FrameExpandKind2852","__ZL18ReconstructPCStackP9JSContextP8JSScriptPhPS3_","__ZL19DecompileExpressionP9JSContextP8JSScriptP10JSFunctionPh","_js_ReconstructStackDepth","__ZL13GetJumpOffsetPhS_","__ZN2js17GetBytecodeLengthEP9JSContextP8JSScriptPh","__ZN2js21IsValidBytecodeOffsetEP9JSContextP8JSScriptj","__ZN2js13BytecodeRangeC1EP9JSContextP8JSScript","_js_free2859","__ZL10SimulateOpP9JSContextP8JSScript4JSOpPK10JSCodeSpecPhPS7_Rj","_js_GetStackUses2860","_js_GetStackDefs","__ZL13DecompileCodeP9JSPrinterP8JSScriptPhjj","__ZL9DecompileP11SprintStackPhi4JSOp","_JSVAL_TO_INT32_IMPL2866","__ZL15IsInitializerOph","_JSVAL_IS_STRING_IMPL2869","_JSVAL_IS_DOUBLE_IMPL2870","_JSVAL_TO_STRING_IMPL2873","_JSDOUBLE_IS_NEGZERO2875","__ZL18JSDOUBLE_IS_FINITEd2876","__ZL15JSDOUBLE_IS_NaNd2877","__ZL9IsVarSlotP9JSPrinterPhPi","__ZN2jsL18GetDecomposeLengthEPhj2861","__ZL14CompareOffsetsPvPKvS1_Pi","__ZL13JSVAL_TO_IMPLN2JS5ValueE2867","__ZL13IMPL_TO_JSVAL12jsval_layout2871","_INT32_TO_JSVAL_IMPL2872","__ZL6PopOffP11SprintStack4JSOp","__ZL10PopOffPrecP11SprintStackh","__ZL6GetOffP11SprintStackj","__ZL10PopStrPrecP11SprintStackh","__ZL24DecompileGroupAssignmentP11SprintStackPhS1_S1_Pi","__ZL7PushOffP11SprintStacki4JSOp","__ZL9VarPrefixPh","__ZL12AddParenSlopP11SprintStack","_DOUBLE_TO_JSVAL2862","__ZL17SprintDoubleValuePN2js8SprinterEN2JS5ValueEP4JSOp","__ZN2JSL11ObjectValueER8JSObject2863","_JSVAL_TO_STRING2864","_INT_TO_JSVAL2865","__ZL15DecompileSwitchP11SprintStackP10TableEntryjPhiii","_JSVAL_TO_INT","_JSVAL_IS_DOUBLE","_JSVAL_IS_STRING2868","_JSVAL_TO_DOUBLE","_JSID_TO_STRING2878","_JSID_IS_STRING2879","__ZN2js6Parser13setPrincipalsEP12JSPrincipals","__ZNK13JSFunctionBox17inAnyDynamicScopeEv","__ZNK13JSFunctionBox17scopeIsExtensibleEv","__ZNK13JSFunctionBox13shouldUnbrandEjj","__ZL25DecompileDestructuringLHSP11SprintStackPhS1_Pi","__ZN19AutoScriptUntrapperD2Ev","__ZN19AutoScriptUntrapperC2EP9JSContextP8JSScriptPPh","__ZN11JSParseNode6becomeEPS_","__ZN11JSParseNode5clearEv","__ZN2js6ParserC2EP9JSContextP12JSPrincipalsPNS_10StackFrameEb","__ZN2jsL12PodArrayZeroIPvLj6EEEvRAT0__T_","__ZN2js6Parser4initEPKtjPKcj9JSVersion","__ZN9JSContext18ensureParseMapPoolEv","__ZN2js6ParserD2Ev","__ZN2js6Parser12newObjectBoxEP8JSObject","__ZN2js6Parser14newFunctionBoxEP8JSObjectP11JSParseNodeP13JSTreeContext","__ZNK13JSFunctionBox8joinableEv","__ZN2js6Parser5traceEP8JSTracer","__ZN2js6Parser17cleanFunctionListEPP13JSFunctionBox","__ZN11JSParseNode8initListEPS_","__ZN11JSParseNode6appendEPS_","__ZN13JSTreeContext13setScopeChainEP8JSObject","__ZL17AddNodeToFreeListP11JSParseNodePN2js6ParserE","__ZN11JSParseNode6createE16JSParseNodeArityP13JSTreeContext","__ZN11JSParseNode6createE16JSParseNodeArityN2js9TokenKindE4JSOpRKNS1_8TokenPosEP13JSTreeContext","__ZL17NewOrRecycledNodeP13JSTreeContext","__ZN11JSParseNode4initEN2js9TokenKindE4JSOp16JSParseNodeArity","__ZN11JSParseNode17newBinaryOrAppendEN2js9TokenKindE4JSOpPS_S3_P13JSTreeContext","__ZL11RecycleTreeP11JSParseNodeP13JSTreeContext","__ZN2js8NameNode6createEP6JSAtomP13JSTreeContext","__ZN2js8NameNode10initCommonEP13JSTreeContext","__ZN2js6Parser5parseEP8JSObject","__ZN13JSTreeContextC1EPN2js6ParserE","__ZL15GenerateBlockIdP13JSTreeContextRj","__ZN2js6Parser10statementsEv","__ZN2js11TokenStream10matchTokenENS_9TokenKindE","__ZN2js6Parser17reportErrorNumberEP11JSParseNodejjz","_js_FoldConstants","__ZN13JSTreeContextD1Ev","__ZN2js8CompilerC2EP9JSContextP12JSPrincipalsPNS_10StackFrameE","__ZNK2js11TokenStream9getLinenoEv","__ZN2js8Compiler13compileScriptEP9JSContextP8JSObjectPNS_10StackFrameEP12JSPrincipalsjPKtjPKcj9JSVersionP8JSStringj","__ZN2js8Compiler4initEPKtjPKcj9JSVersion","__ZN2js11GlobalScopeC1EP9JSContextP8JSObjectP15JSCodeGenerator","__ZL14SetStaticLevelP13JSTreeContextj","__ZN2js11TokenStream13setStrictModeEb","__ZN2js11TokenStream23setOctalCharacterEscapeEb","__ZN2js11TokenStream9peekTokenEj","__ZN2jsL13TreeTypeIsXMLENS_9TokenKindE","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6Parser9statementEv","__ZN2js6Parser26recognizeDirectivePrologueEP11JSParseNodePb","__ZN2js6Parser16analyzeFunctionsEP13JSTreeContext","__ZNK15JSCodeGenerator10sharpSlotsEv","__ZN2js8Compiler13defineGlobalsEP9JSContextRNS_11GlobalScopeEP8JSScript","__ZN2js11GlobalScopeD1Ev","__ZN2js8CompilerD1Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEixEj","__ZL12ATOM_TO_JSIDP6JSAtom2903","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE7popBackEv","__ZN8JSScript7globalsEv","__ZN10JSFunction11setArgCountEt","__ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED1Ev","__Z21CheckStrictAssignmentP9JSContextP13JSTreeContextP11JSParseNode","__Z18CheckStrictBindingP9JSContextP13JSTreeContextP6JSAtomP11JSParseNode","__ZN2js6Parser12functionBodyEv","__ZN2js9UnaryNode6createEP13JSTreeContext","__ZN2js6Parser10assignExprEv","__ZL15ReportBadReturnP9JSContextP13JSTreeContextP11JSParseNodejjj","__ZL16CheckFinalReturnP9JSContextP13JSTreeContextP11JSParseNode","__ZN2js8Compiler19compileFunctionBodyEP9JSContextP10JSFunctionP12JSPrincipalsPNS_8BindingsEPKtjPKcj9JSVersion","__ZN2js12FunctionNode6createEP13JSTreeContext","__ZL9DefineArgP11JSParseNodeP6JSAtomjP13JSTreeContext","__ZL21CheckStrictParametersP9JSContextP13JSTreeContext","__ZN2js6Parser11newFunctionEP13JSTreeContextP6JSAtomNS_18FunctionSyntaxKindE","__ZN2js6Parser11markFunArgsEP13JSFunctionBox","__ZN2js6Parser30markExtensibleScopeDescendantsEP13JSFunctionBoxb","__ZN18JSFunctionBoxQueue4pullEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry5valueEv","__ZN11JSParseNode9setFunArgEv","__ZN18JSFunctionBoxQueue4pushEP13JSFunctionBox","__ZN10JSFunction7setKindEt","__ZN2js8Bindings20setExtensibleParentsEv","__ZN12JSDefinition10kindStringENS_4KindE","__ZN2js6Parser16setFunctionKindsEP13JSFunctionBoxPj","__ZN18JSFunctionBoxQueueC1Ev","__ZN18JSFunctionBoxQueue4initEj","__ZL11FindFunArgsP13JSFunctionBoxiP18JSFunctionBoxQueue","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3allEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5emptyEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range5frontEv","__ZN12JSDefinition7resolveEv","__ZNK12JSDefinition9isFreeVarEv","__ZNK11JSParseNode8isFunArgEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range8popFrontEv","__ZN18JSFunctionBoxQueueD1Ev","__ZL18ConsiderUnbrandingP13JSFunctionBox","__ZL15CanFlattenUpvarP12JSDefinitionP13JSFunctionBoxj","__ZL16FlagHeavyweightsP12JSDefinitionP13JSFunctionBoxPj","__ZN10JSFunction11setJoinableEv","__ZN11JSParseNode7setDefnEb","__ZN11JSParseNode9makeEmptyEv","__ZN13JSTreeContext11atBodyLevelEv","__ZN2js6Parser17functionArgumentsER13JSTreeContextP13JSFunctionBoxPP11JSParseNode","__ZN8BindDataC1Ev","__ZL20BindDestructuringArgP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZN2js6Parser17destructuringExprEP8BindDataNS_9TokenKindE","__ZN2js8Bindings16addDestructuringEP9JSContextPt","__ZN2js8ListNode6createEP13JSTreeContext","__ZN2js9AtomDecls11lookupFirstEP6JSAtom","__ZN2js6Parser11functionDefEP6JSAtomNS0_12FunctionTypeENS_18FunctionSyntaxKindE","__ZN2js11TokenStream17mungeCurrentTokenENS_9TokenKindE4JSOp","__ZN2js9AtomDecls11updateFirstEP6JSAtomP12JSDefinition","__ZN2js11TokenStream10ungetTokenEv","__ZN13JSTreeContext13noteCallsEvalEv","__ZN13JSTreeContext20noteMightAliasLocalsEv","__ZNK13JSTreeContext9compilingEv","__ZL14MakeDefIntoUseP12JSDefinitionP11JSParseNodeP6JSAtomP13JSTreeContext","__ZN2js14AtomDefnMapPtr10lookupDefnEP6JSAtom","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeERKS2_","__ZL6DefineP11JSParseNodeP6JSAtomP13JSTreeContextb","__ZL13EnterFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE","__ZN2js13AtomDeclsIterC1EPNS_9AtomDeclsE","__ZN2js13AtomDeclsIterclEv","__ZL17BindLocalVariableP9JSContextP13JSTreeContextP11JSParseNodeN2js11BindingKindE","__ZN2js11TokenStream8getTokenEj","__ZL22MatchOrInsertSemicolonP9JSContextPN2js11TokenStreamE","__ZL12DefineGlobalP11JSParseNodeP15JSCodeGeneratorP6JSAtom","__ZNK11JSParseNode10isInParensEv","__ZNK2js11TokenStream23hasOctalCharacterEscapeEv","__ZNK2js11TokenStream5isEOFEv","__ZN13JSTreeContext22noteHasExtensibleScopeEv","__ZL13LeaveFunctionP11JSParseNodeP13JSTreeContextP6JSAtomN2js18FunctionSyntaxKindE","__ZN2js6Parser12functionStmtEv","__ZN2js6Parser12functionExprEv","__ZNK11JSParseNode21isStringExprStatementEv","__ZNK11JSParseNode25isEscapeFreeStringLiteralEv","__ZN2js11TokenStream16setUnexpectedEOFEb","__ZN2js6Parser9conditionEv","__ZN2js6Parser9parenExprEPi","__ZN2js6Parser11primaryExprENS_9TokenKindEi","__ZL18CheckDestructuringP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZN2js6Parser13returnOrYieldEb","__ZN2js11TokenStream17peekTokenSameLineEj","__ZN2js6Parser4exprEv","__ZN2js6Parser8letBlockEi","__ZN2js10BinaryNode6createEP13JSTreeContext","__ZL16PushLexicalScopeP9JSContextPN2js11TokenStreamEP13JSTreeContextP10JSStmtInfo","__ZN2js6Parser9variablesEb","__ZN2js11TokenStream10matchTokenENS_9TokenKindEj","__ZL12PopStatementP13JSTreeContext","__ZN2js6Parser15switchStatementEv","__ZL26GenerateBlockIdForStmtNodeP11JSParseNodeP13JSTreeContext","__ZN2jsL15TokenKindIsDeclENS_9TokenKindE2906","__ZN2js6Parser12forStatementEv","__ZN2js11TokenStream9peekTokenEv","__ZN2js11TernaryNode6createEP13JSTreeContext","__ZNK2js6Parser13versionNumberEv","__ZL17CloneLeftHandSideP11JSParseNodeP13JSTreeContext","__ZN2js6Parser19setAssignmentLhsOpsEP11JSParseNode4JSOp","__ZL10NoteLValueP9JSContextP11JSParseNodeP13JSTreeContextj","__ZN2js6Parser12tryStatementEv","__ZL22PushBlocklikeStatementP10JSStmtInfo10JSStmtTypeP13JSTreeContext","__ZL7BindLetP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZL14NewBindingNodeP6JSAtomP13JSTreeContextb","__ZN2js6Parser13withStatementEv","__ZL20DeoptimizeUsesWithinP12JSDefinitionRKN2js8TokenPosE","__ZN2js6Parser12letStatementEv","__ZN2js16LexicalScopeNode6createEP13JSTreeContext","__ZN2js6Parser19expressionStatementEv","__ZL9ForgetUseP11JSParseNode","__ZN2js11NullaryNode6createEP13JSTreeContext","__ZL10MatchLabelP9JSContextPN2js11TokenStreamEP11JSParseNode","__ZL14BindVarOrConstP9JSContextP8BindDataP6JSAtomP13JSTreeContext","__ZL22UndominateInitializersP11JSParseNodeRKN2js8TokenPtrEP13JSTreeContext","__ZL14MakeAssignmentP11JSParseNodeS0_P13JSTreeContext","__ZN13JSTreeContext16noteArgumentsUseEP11JSParseNode","__ZN2js6Parser9mulExpr1nEv","__ZN2js6Parser9mulExpr1iEv","__ZN2js6Parser9addExpr1nEv","__ZN2js6Parser9addExpr1iEv","__ZN2js6Parser11shiftExpr1nEv","__ZN2js6Parser11shiftExpr1iEv","__ZN2js6Parser9relExpr1nEv","__ZN2js6Parser9relExpr1iEv","__ZN2js6Parser8eqExpr1nEv","__ZN2js6Parser8eqExpr1iEv","__ZN2js6Parser12bitAndExpr1nEv","__ZN2js6Parser12bitAndExpr1iEv","__ZN2js6Parser12bitXorExpr1nEv","__ZN2js6Parser12bitXorExpr1iEv","__ZN2js6Parser11bitOrExpr1nEv","__ZN2js6Parser11bitOrExpr1iEv","__ZN2js6Parser9andExpr1nEv","__ZN13JSTreeContext17countArgumentsUseEP11JSParseNode","__ZNK2js11TokenStream13onCurrentLineERKNS_8TokenPosE","__ZN11GenexpGuard7endBodyEv","__ZN2js6Parser9andExpr1iEv","__ZL11MakeSetCallP9JSContextP11JSParseNodeP13JSTreeContextj","__ZN2js6Parser9condExpr1Ev","__ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindE","__ZNK11JSParseNode10isAssignedEv","__ZN2js6Parser9unaryExprEv","__ZN2js6Parser10memberExprEi","__ZL11SetIncOpKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_NS1_9TokenKindEi","__ZL13AdjustBlockIdP11JSParseNodejP13JSTreeContext","__ZN11GenexpGuard14checkValidBodyEP11JSParseNode","__ZN11GenexpGuard18maybeNoteGeneratorEP11JSParseNode","__ZN20CompExprTransplanter10transplantEP11JSParseNode","__ZN2js8TokenPosgeERKS0_","__ZL15BumpStaticLevelP11JSParseNodeP13JSTreeContext","__ZNK11JSParseNode13isPlaceholderEv","__ZN2js8TokenPosltERKS0_","__ZL15MakePlaceholderP11JSParseNodeP13JSTreeContext","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3putERKS2_RKS4_","__ZN2js6Parser17comprehensionTailEP11JSParseNodejbNS_9TokenKindE4JSOp","__ZN20CompExprTransplanterC1EP11JSParseNodeP13JSTreeContextbj","__ZN11GenexpGuardC1EP13JSTreeContext","__ZN2js11TernaryNode6createENS_9TokenKindE4JSOpP11JSParseNodeS4_S4_P13JSTreeContext","__ZN2jsL14TokenKindIsXMLENS_9TokenKindE","__ZN11JSParseNode11setInParensEb","__ZN2js11TokenStream12isXMLTagModeEv","__ZN2js6Parser13generatorExprEP11JSParseNode","__ZN2js6Parser12argumentListEP11JSParseNode","__ZL32CheckForImmediatelyAppliedLambdaP11JSParseNode","__ZN2js6Parser13bracketedExprEv","__ZN2js6Parser16endBracketedExprEv","__ZN2js6Parser16propertySelectorEv","__ZN2js6Parser15qualifiedSuffixEP11JSParseNode","__ZN2js6Parser19qualifiedIdentifierEv","__ZN2js6Parser19attributeIdentifierEv","__ZN2js6Parser7xmlExprEi","__ZN2js11TokenStream13setXMLTagModeEb","__ZN2js6Parser11xmlAtomNodeEv","__ZN2js6Parser11xmlNameExprEv","__ZN2js6Parser13xmlTagContentENS_9TokenKindEPP6JSAtom","__ZN2js6Parser17xmlElementContentEP11JSParseNode","__ZL15JSDOUBLE_IS_NaNd2908","__ZN2js11TokenStream6setXMLEb","__ZNK2js14MultiDeclRange5emptyEv","__ZN2js14MultiDeclRange5frontEv","__ZN2js14MultiDeclRange8popFrontEv","__ZNK2js11TokenStream11getTokenbufEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5beginEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE6lengthEv","__ZN2js6Parser16xmlElementOrListEi","__ZN2js6Parser20xmlElementOrListRootEi","__ZNK2js11TokenStream6hasXMLEv","__ZN2js6Parser12parseXMLTextEP8JSObjectb","__ZN2js11TokenStream14setXMLOnlyModeEb","__ZN11JSParseNode10isConstantEv","__ZN2JSL11DoubleValueEd2907","__ZN2js9AtomDecls11lookupMultiEP6JSAtom","__ZL14BlockIdInScopejP13JSTreeContext","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12lookupForAddERKS2_","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrcvPPPPPPPS6_Ev","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5valueEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3addERNS5_6AddPtrERKS2_RKS4_","__ZL12LinkUseToDefP11JSParseNodeP12JSDefinitionP13JSTreeContext","__ZN9JSContext13regExpStaticsEv","__ZL12ContainsStmtP11JSParseNodeN2js9TokenKindE","__ZL7BoolishP11JSParseNode","__ZL8FoldTypeP9JSContextP11JSParseNodeN2js9TokenKindE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEptEv","__ZNK2js7MoveRefIP12JSDefinitionEcvRS2_Ev","__ZN2js7MoveRefIP12JSDefinitionEC2ERS2_","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC2Ev","__ZL17FoldBinaryNumericP9JSContext4JSOpP11JSParseNodeS3_S3_P13JSTreeContext","__ZL20js_DoubleToECMAInt32d2909","__ZL16FoldXMLConstantsP9JSContextP11JSParseNodeP13JSTreeContext","__ZN2JSL11StringValueEP8JSString2910","__ZL22PrepareNodeForMutationP11JSParseNodeP13JSTreeContext","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE12switchAndAddERKS2_RKS4_","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEEEC1ERS9_","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1ERS6_","__ZN2js4MoveIP12JSDefinitionEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIP12JSDefinitionEC1ERS2_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEC1Ev","_js_malloc2912","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11initializedEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2EPNS5_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC2ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range13isInlineRangeEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC2ERKS2_RKS4_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range16advancePastNullsEPNS5_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE12hasCollisionEv","__ZN2js12HashMapEntryIP6JSAtomP12JSDefinitionEaSERKS5_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2EPNS5_10InlineElemE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE3endEv","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE5beginEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE11switchToMapEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6putNewERKS2_RKS4_","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE11initializedEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5clearEv","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5clearEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1ERKNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E6AddPtrE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6AddPtrC1EPNS5_10InlineElemEb","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5EntryC1ERKS2_RKS4_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Range10bumpCurPtrEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC1EPKNS5_10InlineElemES9_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2EPKNS5_10InlineElemES9_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E5RangeE","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6lookupERKS2_","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrcvPPPPPPPS6_Ev","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE6removeENS5_3PtrE","__ZN2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomP12JSDefinitionEEE7setFreeEv","__ZNK2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS_7HashMapIS2_S4_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESE_E3PtrE","__ZNK2js7HashMapIP6JSAtomP12JSDefinitionNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3PtrC1EPNS5_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomP12JSDefinitionEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js10VectorImplIP8JSScriptLj16ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorIP8JSScriptLj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js9NodeStackC1Ev","__ZN2jsL13VersionNumberE9JSVersion2944","__ZN2jsL13VersionHasXMLE9JSVersion2945","_JSID_IS_STRING2948","_JSID_TO_STRING2950","__ZL18JSDOUBLE_IS_FINITEd2916","__ZL15JSDOUBLE_IS_NEGd2917","__ZN11JSParseNode7setUsedEb","__ZN2js9NodeStack5emptyEv","__ZN2js9NodeStack3popEv","__ZN2js9NodeStack8pushListEP11JSParseNode","__ZN2js9NodeStack4pushEP11JSParseNode","__ZN2js9NodeStackC2Ev","__ZN2js14MultiDeclRangeC2EPNS_12AtomDeclNodeE","__ZN2js14MultiDeclRangeC2EP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2EPNS4_10InlineElemE","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE","__ZN2js11TokenStream7setFlagEbNS_16TokenStreamFlagsE","__ZN11GenexpGuardC2EP13JSTreeContext","__ZN20CompExprTransplanterC2EP11JSParseNodeP13JSTreeContextbj","__ZN2js8TokenPtrltERKS0_","__ZNK11JSParseNode6lexdefEv","__ZN2js8TokenPtrleERKS0_","__ZL16PushNodeChildrenP11JSParseNodePN2js9NodeStackE","__ZL17AddNodeToFreeListP11JSParseNodeP13JSTreeContext","__ZN2js9NodeStack14pushUnlessNullEP11JSParseNode","__ZN2js16AutoStringRooterC1EP9JSContextP8JSString","__ZN2js16AutoStringRooterD1Ev","__ZN2js16AutoStringRooterD2Ev","__ZN2js16AutoStringRooterC2EP9JSContextP8JSString","__ZL7js_fmoddd2918","__ZN2JSL14UndefinedValueEv2937","__ZN2jsL22GetGlobalForScopeChainEP9JSContext2940","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6lookupERKS2_","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrcvPPPPPPPS5_Ev","__ZN2js14MultiDeclRangeC1EP12JSDefinition","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5valueEv","__ZN2js14MultiDeclRangeC1EPNS_12AtomDeclNodeE","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3Ptr5foundEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E3PtrE","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6lookupERKS2_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3PtrC1EPNS4_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3PtrC1ERNS0_14HashTableEntryIS6_EE","__ZN2jsL21VersionShouldParseXMLE9JSVersion","__ZNK2js11TokenStream13versionNumberEv","__ZL12JSID_TO_ATOMi2949","__ZL10SetLvalKidP9JSContextPN2js11TokenStreamEP13JSTreeContextP11JSParseNodeS7_PKc","__ZN2js6Parser7orExpr1Ev","__ZNK2js11TokenStream18isCurrentTokenTypeENS_9TokenKindES1_","__ZL8OuterLetP13JSTreeContextP10JSStmtInfoP6JSAtom","__ZL17BindFunctionLocalP9JSContextP8BindDataRN2js14MultiDeclRangeEP13JSTreeContext","__ZL15BindTopLevelVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZN2js8TokenPtrgeERKS0_","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE3Ptr5valueEv","__ZN2JSL12PrivateValueEPv2951","__ZNK11JSParseNode12isBlockChildEv","__ZNK11JSParseNode10frameLevelEv","__ZNK7mozilla14AlignedStorageILj192EE4addrEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E11underloadedEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE12hasCollisionEv","__ZN2js12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEaSERKS4_","__ZN2js11TokenStream7FlaggerD2Ev","__ZN2js11TokenStream7FlaggerC2EPS0_j","__ZNK15JSCodeGenerator16compilingForEvalEv","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZNK2js7MoveRefINS_11GlobalScope9GlobalDefEEcvRS2_Ev","__ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC2ERS2_","__ZN2js11GlobalScope9GlobalDefC2EP6JSAtomP13JSFunctionBox","__ZN2js11GlobalScope9GlobalDefC2Ej","__ZN2js9InlineMapIP6JSAtomP12JSDefinitionLj24EE5Entry3keyEv","__ZL14CloneParseTreeP11JSParseNodeP13JSTreeContext","__ZN2js10BinaryNode6createENS_9TokenKindE4JSOpRKNS_8TokenPosEP11JSParseNodeS7_P13JSTreeContext","__ZN2js9AtomDecls6removeEP6JSAtom","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE6removeENS4_3PtrE","__ZN2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeENSD_3PtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E6removeERNS0_14HashTableEntryIS6_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E16checkUnderloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEEE7setFreeEv","__ZN2js11TokenStream7FlaggerC1EPS0_j","__ZN2js11TokenStream7FlaggerD1Ev","__ZL20BindDestructuringVarP9JSContextP8BindDataP11JSParseNodeP13JSTreeContext","__ZL20BindDestructuringLHSP9JSContextP11JSParseNodeP13JSTreeContext","__ZN2js11GlobalScope9GlobalDefC1Ej","__ZN2js11GlobalScope9GlobalDefC1EP6JSAtomP13JSFunctionBox","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZNK2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefINS_11GlobalScope9GlobalDefEEC1ERS2_","__ZN2js10VectorImplINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyELb0EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js4MoveINS_11GlobalScope9GlobalDefEEENS_7MoveRefIT_EERKS4_","__ZN2js11NameSetNode6createEP13JSTreeContext","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5emptyEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10isLiveHashEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Entry5valueEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range13isInlineRangeEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range16advancePastNullsEPNS4_10InlineElemE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5frontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC2ERKS2_RKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range5emptyEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2Ev","__ZN2js12DefnOrHeaderC2EP12JSDefinition","__ZN2js11TokenStream17mungeCurrentTokenE4JSOp","__ZN8BindDataC2Ev","__ZN18JSFunctionBoxQueue6lengthEv","__ZN18JSFunctionBoxQueueC2Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEptEv","__ZNK2js7MoveRefIbEcvRbEv","__ZN2js7MoveRefIbEC2ERb","__ZN2js12HashMapEntryIP6JSAtombEC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE9matchHashEj","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range5frontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5Range10bumpCurPtrEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5Range8popFrontEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5EntryC1ERKS2_RKS3_","__ZN2js13AtomDeclsIterC2EPNS_9AtomDeclsE","__ZN2js9AtomDecls3allEv","__ZNK2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE3allEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE","__ZNK2js7HashMapIP6JSAtomNS_12DefnOrHeaderENS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3allEv","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC1EPKNS4_10InlineElemES8_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2EPKNS4_10InlineElemES8_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC1EPNS0_14HashTableEntryIS6_EESH_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtomNS_12DefnOrHeaderEEENS_7HashMapIS4_S5_NS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyESA_E5RangeC2EPNS0_14HashTableEntryIS6_EESH_","__ZN2js9InlineMapIP6JSAtomNS_12DefnOrHeaderELj24EE5RangeC2ENS_6detail9HashTableINS_12HashMapEntryIS2_S3_EENS_7HashMapIS2_S3_NS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicyESD_E5RangeE","__ZN2js9AtomDecls9addUniqueEP6JSAtomP12JSDefinition","__ZN2js12DefnOrHeaderC1EP12JSDefinition","__ZN12JSDefinition13isBindingFormEv","__ZN2JSL9NullValueEv2953","__ZL10MinBlockIdP11JSParseNodej","__ZN18JSFunctionBoxQueueD2Ev","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC1ES5_","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE4initEj","__ZL12JSID_IS_ATOMi2955","__ZL18ReportBadParameterP9JSContextP13JSTreeContextP6JSAtomj","__ZNK2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_bEENS6_13MapHashPolicyES5_E6AddPtrERKS2_RKb","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED1Ev","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12destroyTableERS9_PNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEENS_7MoveRefIT_EERS9_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEEEC1ERS7_","__ZN2js12HashMapEntryIP6JSAtombEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryIP6JSAtombEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryIP6JSAtombEEEC1ERS4_","__ZN2js4MoveIbEENS_7MoveRefIT_EERS2_","__ZN2js7MoveRefIbEC1ERb","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEEC2Ev","__ZN2js12HashMapEntryIP6JSAtombEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS4_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS4_","__ZL14JSID_FROM_BITSj2961","__ZN2js11UpvarCookie15isLevelReservedEt","_JSVAL_TO_OBJECT_IMPL3001","_JSVAL_IS_PRIMITIVE_IMPL3003","__ZN7mozilla14AlignedStorageILj192EE4addrEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP6JSAtombEEE12setCollisionEj","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_bEE","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC2ES9_","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomP12JSDefinitionLj24EEEE6hasMapEv","__ZL13JSVAL_TO_IMPLN2JS5ValueE3002","__ZL13IMPL_TO_JSVAL12jsval_layout3004","_INT32_TO_JSVAL_IMPL3005","_OBJECT_TO_JSVAL_IMPL3007","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZN2js7HashMapIP6JSAtombNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEEC2ES5_","__ZN2js6detail9HashTableINS_12HashMapEntryIP6JSAtombEENS_7HashMapIS4_bNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_EC1ES9_","__ZL14HasFinalReturnP11JSParseNode","__ZN2js8CompilerD2Ev","__ZN2js11GlobalScopeD2Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEED2Ev","__ZN2js11GlobalScopeC2EP9JSContextP8JSObjectP15JSCodeGenerator","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorINS_11GlobalScope9GlobalDefELj16ENS_15TempAllocPolicyEEC2ES3_","__ZN2js11OffTheBooks4new_INS_12ParseMapPoolEP9JSContextEEPT_T0_","__ZN2js12ParseMapPoolC1EP9JSContext","__ZN2js12ParseMapPoolC2EP9JSContext","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC1ES2_","__ZN2js6VectorIPvLj32ENS_17SystemAllocPolicyEEC2ES2_","__ZL8pm_startP9JSContextjPN2JS5ValueE","__ZL7pm_stopP9JSContextjPN2JS5ValueE","__ZL8pm_resetP9JSContextjPN2JS5ValueE","__ZL22pm_canMeasureSomethingP9JSContextjPN2JS5ValueE","__ZL11pm_finalizeP9JSContextP8JSObject","__ZN2JS23RegisterPerfMeasurementEP9JSContextP8JSObject","__ZL12pm_constructP9JSContextjPN2JS5ValueE","_INT_TO_JSVAL2997","__ZN2JS22ExtractPerfMeasurementENS_5ValueE","_JSVAL_IS_PRIMITIVE2998","_JSVAL_TO_OBJECT2999","__ZL17pm_get_cpu_cyclesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19pm_get_instructionsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23pm_get_cache_referencesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19pm_get_cache_missesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL26pm_get_branch_instructionsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20pm_get_branch_missesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL17pm_get_bus_cyclesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL18pm_get_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL24pm_get_major_page_faultsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23pm_get_context_switchesP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21pm_get_cpu_migrationsP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21pm_get_eventsMeasuredP9JSContextP8JSObjectiPN2JS5ValueE","__ZL5GetPMP9JSContextP8JSObjectPKc","__ZN9JSContext4new_IN2JS15PerfMeasurementENS2_9EventMaskEEEPT_T0_","_OBJECT_TO_JSVAL3006","__ZN9JSContext7delete_IN2JS15PerfMeasurementEEEvPT_","__ZL13GetPMFromThisP9JSContextPN2JS5ValueE","_BOOLEAN_TO_JSVAL_IMPL3011","__ZL10LimitStuffP15SprintfStateStrPKcj","_BOOLEAN_TO_JSVAL3010","_JS_THIS","_JS_sxprintf","_JS_vsxprintf","__ZL9FuncStuffP15SprintfStateStrPKcj","__ZL9dosprintfP15SprintfStateStrPKcPc","_JS_smprintf","_JS_vsmprintf","_JS_smprintf_free","__ZL9GrowStuffP15SprintfStateStrPKcj","_JS_snprintf","_JS_vsnprintf","_JS_sprintf_append","_JS_vsprintf_append","__ZL13BuildArgArrayPKcPcPiP11NumArgState","__ZL5cvt_lP15SprintfStateStrliiiiiPKc","__ZL6cvt_llP15SprintfStateStrxiiiiiPKc","__ZL5cvt_fP15SprintfStateStrdPKcS2_","__ZL6cvt_wsP15SprintfStateStrPKtiii","__ZL5cvt_sP15SprintfStateStrPKciii","__ZL5fill2P15SprintfStateStrPKciii","__ZL6fill_nP15SprintfStateStrPKciiiii","__ZL26js_IsPropertyCacheDisabledP9JSContext3032","__ZN2js5PCVal9setFunObjER8JSObject","__ZN8JSObject7genericEv","__ZN2js5PCVal7setSlotEj","__ZN2js5PCVal8setShapeEPKNS_5ShapeE","__ZN2js18PropertyCacheEntry6assignEPhjjjjNS_5PCValE","__ZN2js13PropertyCache14purgeForScriptEP9JSContextP8JSScript","__ZNK2js11KidsPointer6isNullEv","__ZN2js5Shape9setParentEPS0_","__ZN2js11KidsPointer8setShapeEPNS_5ShapeE","__ZNK2js11KidsPointer7toShapeEv","__ZN2js11KidsPointer7setHashEPNS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEE","__ZNK2js11KidsPointer6toHashEv","__ZNK2js11KidsPointer6isHashEv","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv","__ZN2js13PropertyCache4fillEP9JSContextP8JSObjectjS4_PKNS_5ShapeEi","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh3033","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3034","__ZN2js13PropertyCache8fullTestEP9JSContextPhPP8JSObjectS6_PNS_18PropertyCacheEntryE","__ZL19GetAtomFromBytecodeP9JSContextPh4JSOpRK10JSCodeSpec","__ZN2js13PropertyCache5purgeEP9JSContext","__ZN2jsL12PodArrayZeroINS_18PropertyCacheEntryELj4096EEEvRAT0__T_","__ZN2js13PropertyCache7restoreEPNS_18PropertyCacheEntryE","__ZN2js12PropertyTree8newShapeEP9JSContext","__Z13js_NewGCShapeP9JSContext","__ZN2js12PropertyTree11insertChildEP9JSContextPNS_5ShapeES4_","__ZNK2js11KidsPointer7isShapeEv","__ZL12HashChildrenPN2js5ShapeES1_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6putNewERKS2_","__ZN2js5Shape11removeChildEPS0_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeERKPKS1_","__ZN2js12PropertyTree8getChildEP9JSContextPNS_5ShapeERKS3_","__ZNK2js5Shape7matchesEPKS0_","__ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6lookupERKPKS1_","__ZN2js5ShapeC1EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj","__ZN2js5Shape8finalizeEP9JSContext","__ZN9JSContext7delete_IN2js7HashSetIPNS1_5ShapeENS1_11ShapeHasherENS1_17SystemAllocPolicyEEEEEvPT_","__ZN2js5Shape9freeTableEP9JSContext","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED1Ev","_js_free3045","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEED2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED1Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_ED2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12destroyTableERS7_PNS0_14HashTableEntryIS4_EEj","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv","__ZN2js14JSProxyHandlerD2Ev","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10isLiveHashEj","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isFreeEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE9matchHashEj","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE9isRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZNK2js5Shape4hashEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEptEv","__ZNK2js7MoveRefIPNS_5ShapeEEcvRS2_Ev","__ZN2js7MoveRefIPNS_5ShapeEEC2ERS2_","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE12setCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC2Ev","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setFreeEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEE7setLiveEj","__ZNK2js5Shape8setTableEPNS_13PropertyTableE","__ZNK2js5Shape20matchesParamsAfterIdEPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjji","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC2ES7_","__ZN2js14JSProxyHandlerC2EPv","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKS2_jj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKS2_","__ZN2js11ShapeHasher5matchEPNS_5ShapeEPKS1_","__ZN2js11ShapeHasher4hashEPKNS_5ShapeE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableIKS2_NS5_6SetOpsES4_E3PtrE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeENSA_3PtrE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11createTableERS7_j","__ZNK2js6detail14HashTableEntryIKPNS_5ShapeEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_5ShapeEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_5ShapeEEEEC1ERS6_","__ZN2js4MoveIPNS_5ShapeEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_5ShapeEEC1ERS2_","__ZN2js6detail14HashTableEntryIKPNS_5ShapeEEC1Ev","_js_malloc3046","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv","__ZNK2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKS1_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKS2_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN9JSContext7delete_IN2js13PropertyTableEEEvPT_","__ZN2js13PropertyTableD1Ev","__ZN2js13PropertyTableD2Ev","__ZN2js5ShapeC2EiPFiP9JSContextP8JSObjectiPN2JS5ValueEEPFiS2_S4_iiS7_Ejjjijj","__ZN2js11OffTheBooks4new_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEPT_v","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEE4initEj","__ZN2js10Foreground7delete_INS_7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEEEEvPT_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4initEj","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC1ES4_","__ZN2js7HashSetIPNS_5ShapeENS_11ShapeHasherENS_17SystemAllocPolicyEEC2ES4_","__ZN2js6detail9HashTableIKPNS_5ShapeENS_7HashSetIS3_NS_11ShapeHasherENS_17SystemAllocPolicyEE6SetOpsES7_EC1ES7_","__Z10NewGCThingIN2js5ShapeEEPT_P9JSContextNS0_2gc9AllocKindEj","__ZN2js14JSProxyHandlerD0Ev","__ZN2js14JSProxyHandler3hasEP9JSContextP8JSObjectiPb","__ZN2js14JSProxyHandler6hasOwnEP9JSContextP8JSObjectiPb","__ZN2js14JSProxyHandler8finalizeEP9JSContextP8JSObject","__ZN2js14JSProxyHandler5traceEP8JSTracerP8JSObject","_INT_TO_JSID3072","__ZL24IndicatePropertyNotFoundP9JSContextP20JSPropertyDescriptor","__ZN2js14JSProxyHandler3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js14JSProxyHandler3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE","__ZNK8JSObject15getProxyHandlerEv","__ZN2js14JSProxyHandler4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js16AutoVectorRooterIiE6resizeEj","__ZN2js14JSProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js14JSProxyHandler12obj_toStringEP9JSContextP8JSObject","__ZN2js14JSProxyHandler12fun_toStringEP9JSContextP8JSObjectj","__ZL7GetCallP8JSObject","__ZN2js14JSProxyHandler12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2js14JSProxyHandler4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js14JSProxyHandler9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_","__ZL12GetConstructP8JSObject","__ZN2JSL14UndefinedValueEv3073","__ZN2js14JSProxyHandler11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN2JSL11ObjectValueER8JSObject3074","__ZN2js14JSProxyHandler6typeOfEP9JSContextP8JSObject","__ZN22JSScriptedProxyHandlerC2Ev","__ZN22JSScriptedProxyHandlerD0Ev","__ZN22JSScriptedProxyHandler21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZL21GetProxyHandlerObjectP9JSContextP8JSObject","__ZL18GetFundamentalTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZL5Trap1P9JSContextP8JSObjectN2JS5ValueEiPS4_","__ZL31ReturnedValueMustNotBePrimitiveP9JSContextP8JSObjectP6JSAtomRKN2JS5ValueE","__ZL29ParsePropertyDescriptorObjectP9JSContextP8JSObjectiRKN2JS5ValueEP20JSPropertyDescriptor","__ZN22JSScriptedProxyHandler24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN22JSScriptedProxyHandler14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZL5Trap2P9JSContextP8JSObjectN2JS5ValueEiS4_PS4_","__ZN22JSScriptedProxyHandler19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZL4TrapP9JSContextP8JSObjectN2JS5ValueEjPS4_S5_","__ZL15ArrayToIdVectorP9JSContextRKN2JS5ValueERN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler7delete_EP9JSContextP8JSObjectiPb","__ZL11ValueToBoolP9JSContextRKN2JS5ValueEPb","__ZN22JSScriptedProxyHandler9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN22JSScriptedProxyHandler3hasEP9JSContextP8JSObjectiPb","__ZL14GetDerivedTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZL13js_IsCallableRKN2JS5ValueE3075","__ZN22JSScriptedProxyHandler6hasOwnEP9JSContextP8JSObjectiPb","__ZN22JSScriptedProxyHandler3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN2jsL9IdToValueEi3076","__ZN2JSL11StringValueEP8JSString3077","__ZN2JSL17ObjectOrNullValueEP8JSObject3078","__ZN22JSScriptedProxyHandler3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN22JSScriptedProxyHandler4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN22JSScriptedProxyHandler7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25AutoPendingProxyOperationC1EP9JSContextP8JSObject","__ZN25AutoPendingProxyOperationD1Ev","__ZN2js7JSProxy21getPropertyDescriptorEP9JSContextP8JSObjectibPN2JS5ValueE","__ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN2js7JSProxy24getOwnPropertyDescriptorEP9JSContextP8JSObjectibPN2JS5ValueE","__ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js7JSProxy14definePropertyEP9JSContextP8JSObjectiRKN2JS5ValueE","__ZN2js7JSProxy19getOwnPropertyNamesEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy7delete_EP9JSContextP8JSObjectiPb","__ZN2js7JSProxy9enumerateEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN2js7JSProxy3hasEP9JSContextP8JSObjectiPb","__ZN2js7JSProxy6hasOwnEP9JSContextP8JSObjectiPb","__ZN2js7JSProxy3getEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js7JSProxy3setEP9JSContextP8JSObjectS4_ibPN2JS5ValueE","__ZN2js7JSProxy4keysEP9JSContextP8JSObjectRNS_12AutoIdVectorE","__ZN2js7JSProxy7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN2js7JSProxy9constructEP9JSContextP8JSObjectjPN2JS5ValueES7_","__ZN2js7JSProxy11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN2js7JSProxy6typeOfEP9JSContextP8JSObject","__ZN2js14JSProxyHandler13isOuterWindowEv","__ZL19OperationInProgressP9JSContextP8JSObject","__ZN2js2gcL15GetGCObjectKindEjb3110","__ZN2js7JSProxy12obj_toStringEP9JSContextP8JSObject","__ZN2js7JSProxy12fun_toStringEP9JSContextP8JSObjectj","__ZN2js7JSProxy12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL13proxy_ConvertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZL14proxy_FinalizeP9JSContextP8JSObject","__ZL17proxy_HasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL17proxy_TraceObjectP8JSTracerP8JSObject","__ZL20proxy_LookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL19proxy_LookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL19proxy_LookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL20proxy_DefinePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL19proxy_DefineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL19proxy_DefineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL16proxy_GetGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL17proxy_GetPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL16proxy_GetElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL16proxy_GetSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL17proxy_SetPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL16proxy_SetElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL16proxy_SetSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL19proxy_GetAttributesP9JSContextP8JSObjectiPj","__ZL26proxy_GetElementAttributesP9JSContextP8JSObjectjPj","__ZL26proxy_GetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL19proxy_SetAttributesP9JSContextP8JSObjectiPj","__ZL26proxy_SetElementAttributesP9JSContextP8JSObjectjPj","__ZL26proxy_SetSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL20proxy_DeletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL19proxy_DeleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL19proxy_DeleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL12proxy_TypeOfP9JSContextP8JSObject","__ZL9proxy_FixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL17proxy_innerObjectP9JSContextP8JSObject","__ZL10proxy_CallP9JSContextjPN2JS5ValueE","__ZL15proxy_ConstructP9JSContextjPN2JS5ValueE","__ZL19proxy_TraceFunctionP8JSTracerP8JSObject","__ZN2js14NewProxyObjectEP9JSContextPNS_14JSProxyHandlerERKN2JS5ValueEP8JSObjectS9_S9_S9_","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3103","__ZN2JSL12PrivateValueEPv3104","__ZL12proxy_createP9JSContextjPN2JS5ValueE","__ZL20proxy_createFunctionP9JSContextjPN2JS5ValueE","__Z18callable_ConstructP9JSContextjPN2JS5ValueE","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3105","__ZL13callable_CallP9JSContextjPN2JS5ValueE","__ZN2js8FixProxyEP9JSContextP8JSObjectPi","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_NS_2gc9AllocKindE","_js_InitProxyClass","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3108","_OBJECT_TO_JSVAL3109","__ZL14JSID_FROM_BITSj3130","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3133","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3121","_JSID_IS_STRING3137","_JSID_TO_STRING3138","_JSID_IS_INT3139","_JSID_TO_INT3141","_JSID_IS_OBJECT3142","_JSID_TO_OBJECT3143","_INT_TO_JSID3398","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE8shrinkByEj","__ZL13IMPL_TO_JSVAL12jsval_layout3125","_OBJECT_TO_JSVAL_IMPL3126","__ZN25AutoPendingProxyOperationD2Ev","__ZN25AutoPendingProxyOperationC2EP9JSContextP8JSObject","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3111","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3112","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3115","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3122","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZN2jsL15MakeRangeGCSafeEPiS0_","__ZN2js6VectorIiLj8ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3127","__ZL12ATOM_TO_JSIDP6JSAtom3129","__ZNK8JSObject13getProxyExtraEv","__ZN2JSL10Int32ValueEi3140","__ZL7GetTrapP9JSContextP8JSObjectP6JSAtomPN2JS5ValueE","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3397","__ZN2js11NodeBuilder10setNodeLocEP8JSObjectPNS_8TokenPosE","__ZN2js11NodeBuilder9atomValueEPKcPN2JS5ValueE","__ZN2js11NodeBuilder11setPropertyEP8JSObjectPKcN2JS5ValueE","__ZN2js11NodeBuilder8newArrayERNS_15AutoValueVectorEPN2JS5ValueE","__ZN2js11NodeBuilder10newNodeLocEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder9newObjectEPP8JSObject","__ZN2JSL11ObjectValueER8JSObject3399","__ZN2JSL9NullValueEv3400","__ZN2js11NodeBuilder7programERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8listNodeENS_7ASTTypeEPKcRNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14blockStatementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder19expressionStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueEPS7_","__ZN2js11NodeBuilder14emptyStatementEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8callbackEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11ifStatementEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder3optEN2JS5ValueE","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder14breakStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17continueStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16labeledStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_PS7_","__ZN2js11NodeBuilder14throwStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15returnStatementEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder12forStatementEN2JS5ValueES2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder14forInStatementEN2JS5ValueES2_S2_bPNS_8TokenPosEPS2_","__ZN2JSL12BooleanValueEb3401","__ZN2js11NodeBuilder13withStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder14whileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16doWhileStatementEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15switchStatementEN2JS5ValueERNS_15AutoValueVectorEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder12tryStatementEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17debuggerStatementEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder16binaryExpressionENS_14BinaryOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_","__ZN2js11NodeBuilder15unaryExpressionENS_13UnaryOperatorEN2JS5ValueEPNS_8TokenPosEPS3_","__ZN2js11NodeBuilder20assignmentExpressionENS_18AssignmentOperatorEN2JS5ValueES3_PNS_8TokenPosEPS3_","__ZN2js11NodeBuilder16updateExpressionEN2JS5ValueEbbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder17logicalExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder21conditionalExpressionEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder18sequenceExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14callExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder13newExpressionEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16memberExpressionEbN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15arrayExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder15propertyPatternEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19propertyInitializerEN2JS5ValueES2_NS_8PropKindEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder16objectExpressionERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder14thisExpressionEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder15yieldExpressionEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder18comprehensionBlockEN2JS5ValueES2_bPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder23comprehensionExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19generatorExpressionEN2JS5ValueERNS_15AutoValueVectorES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder15graphExpressionEiN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2JSL11NumberValueEd3402","__ZN2js11NodeBuilder20graphIndexExpressionEiPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder13letExpressionERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_","__ZN2js11NodeBuilder12letStatementERNS_15AutoValueVectorEN2JS5ValueEPNS_8TokenPosEPS4_","__ZN2js11NodeBuilder19variableDeclarationERNS_15AutoValueVectorENS_11VarDeclKindEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder18variableDeclaratorEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js13ASTSerializer3aopE4JSOp","__ZN2js13ASTSerializer4unopENS_9TokenKindE4JSOp","__ZN2js11NodeBuilder10switchCaseEN2JS5ValueERNS_15AutoValueVectorEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder11catchClauseEN2JS5ValueES2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7literalEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10identifierEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder13objectPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder12arrayPatternERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder8functionENS_7ASTTypeEPNS_8TokenPosEN2JS5ValueERNS_15AutoValueVectorES5_bbPS5_","__ZN2js11NodeBuilder8callbackEN2JS5ValueES2_S2_S2_S2_S2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7newNodeENS_7ASTTypeEPNS_8TokenPosEPKcN2JS5ValueES5_S7_S5_S7_S5_S7_S5_S7_PS7_","__ZN2js11NodeBuilder10xmlAnyNameEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder19xmlEscapeExpressionEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19xmlFilterExpressionEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js11NodeBuilder19xmlDefaultNamespaceEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder20xmlAttributeSelectorEN2JS5ValueEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder30xmlFunctionQualifiedIdentifierEN2JS5ValueEbPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder22xmlQualifiedIdentifierEN2JS5ValueES2_bPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10xmlElementERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder7xmlTextEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7xmlListERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11xmlStartTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder9xmlEndTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder11xmlPointTagERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder7xmlNameEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder7xmlNameERNS_15AutoValueVectorEPNS_8TokenPosEPN2JS5ValueE","__ZN2js11NodeBuilder12xmlAttributeEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder8xmlCdataEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder10xmlCommentEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder5xmlPIEN2JS5ValueEPNS_8TokenPosEPS2_","__ZN2js11NodeBuilder5xmlPIEN2JS5ValueES2_PNS_8TokenPosEPS2_","__ZN2js13ASTSerializer5binopENS_9TokenKindE4JSOp","__ZN2js13ASTSerializer10statementsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer13sourceElementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer11expressionsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer10expressionEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer4xmlsEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer3xmlEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer14blockStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7programEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer9statementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer11declarationEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer8functionEP11JSParseNodeNS_7ASTTypeEPN2JS5ValueE","__ZN2js13ASTSerializer19variableDeclarationEP11JSParseNodebPN2JS5ValueE","__ZN2js13ASTSerializer7patternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer18variableDeclaratorEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer13optExpressionEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7letHeadEP11JSParseNodeRNS_15AutoValueVectorE","__ZN2js13ASTSerializer10switchCaseEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer15switchStatementEP11JSParseNodePN2JS5ValueE","__ZN2JSL14UndefinedValueEv3403","__ZN2js13ASTSerializer11catchClauseEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12tryStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12optStatementEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7forInitEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer13optIdentifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE","__ZN2js13ASTSerializer10identifierEP6JSAtomPNS_8TokenPosEPN2JS5ValueE","__ZN2js13ASTSerializer13leftAssociateEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer18comprehensionBlockEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer13comprehensionEP11JSParseNodePN2JS5ValueE","__ZN2JSL10MagicValueE10JSWhyMagic3404","__ZN2js13ASTSerializer19generatorExpressionEP11JSParseNodePN2JS5ValueE","__ZNK11JSParseNode15isGeneratorExprEv","__ZN2js2gcL15GetGCObjectKindEjb3408","__ZNK11JSParseNode13generatorExprEv","__ZN2js13ASTSerializer8propertyEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer10identifierEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer7literalEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12atomContentsEP6JSAtom","__ZN2js13ASTSerializer12propertyNameEP11JSParseNodePN2JS5ValueE","__ZN2js13ASTSerializer12arrayPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer13objectPatternEP11JSParseNodePNS_11VarDeclKindEPN2JS5ValueE","__ZN2js13ASTSerializer19functionArgsAndBodyEP11JSParseNodeRNS_15AutoValueVectorEPN2JS5ValueE","__ZN2js13ASTSerializer12functionArgsEP11JSParseNodeS2_S2_S2_RNS_15AutoValueVectorE","__ZN2js13ASTSerializer12functionBodyEP11JSParseNodePNS_8TokenPosEPN2JS5ValueE","__ZL13reflect_parseP9JSContextjPN2JS5ValueE","_JS_InitReflect","_OBJECT_TO_JSVAL3405","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3409","__ZL14JSID_FROM_BITSj3426","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3418","__ZL13IMPL_TO_JSVAL12jsval_layout3419","_OBJECT_TO_JSVAL_IMPL3420","__ZN2js11NodeBuilderC2EP9JSContextbPKc","__ZN2js22AutoReleaseNullablePtrC2EP9JSContextPv","__ZN2js6RegExp6increfEP9JSContext","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3410","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3413","__ZN2js22AutoReleaseNullablePtrC1EP9JSContextPv","__ZL12ATOM_TO_JSIDP6JSAtom3421","__ZN2js22AutoReleaseNullablePtr5resetEPv","__ZN2JSL10Int32ValueEi3422","__ZN2js13ASTSerializerC1EP9JSContextbPKcj","__ZN2js13ASTSerializer4initEP8JSObject","__ZN2js22AutoReleaseNullablePtrD1Ev","__ZN2js22AutoReleaseNullablePtrD2Ev","__ZN2js11NodeBuilder4initEP8JSObject","__ZN2js13ASTSerializerC2EP9JSContextbPKcj","__ZN2js11NodeBuilderC1EP9JSContextbPKc","__ZN2JSL11StringValueEP8JSString3435","__ZN2js11NodeBuilder9setResultEP8JSObjectPN2JS5ValueE","__ZL13resc_finalizeP9JSContextP8JSObject","__ZL10resc_traceP8JSTracerP8JSObject","__Z20js_CloneRegExpObjectP9JSContextP8JSObjectS2_","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_3476","__Z17js_ObjectIsRegExpP8JSObject","__ZN2js6RegExp15reportPCREErrorEP9JSContexti","__ZN2js6RegExp15reportYarrErrorEP9JSContextPNS_11TokenStreamEN3JSC4Yarr9ErrorCodeE","__ZN2js6RegExp10parseFlagsEP9JSContextP8JSStringPj","__ZN2js6RegExp13createFlaggedEP9JSContextP8JSStringS4_PNS_11TokenStreamE","__ZN8JSObject24assignInitialRegExpShapeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom3481","__ZL19static_input_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL19static_input_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL23static_multiline_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23static_multiline_setterP9JSContextP8JSObjectiiPN2JS5ValueE","__ZL23static_lastMatch_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL23static_lastParen_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL25static_leftContext_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL26static_rightContext_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren1_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren2_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren3_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren4_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren5_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren6_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE6lengthEv","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE5emptyEv","__ZL20static_paren7_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren8_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL20static_paren9_getterP9JSContextP8JSObjectiPN2JS5ValueE","__Z18js_XDRRegExpObjectP10JSXDRStatePP8JSObject","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3482","__ZL15regexp_finalizeP9JSContextP8JSObject","__Z18js_regexp_toStringP9JSContextP8JSObjectPN2JS5ValueE","__ZN2JSL11StringValueEP8JSString3485","__ZN2js12StringBuffer16infallibleAppendEt","__ZN2js12StringBuffer6appendILj7EEEbRAT__Kc","__Z14js_regexp_execP9JSContextjPN2JS5ValueE","__ZL13ExecuteRegExpP9JSContext8ExecTypejPN2JS5ValueE","__Z14js_regexp_testP9JSContextjPN2JS5ValueE","__ZL15regexp_toStringP9JSContextjPN2JS5ValueE","__ZL14regexp_compileP9JSContextjPN2JS5ValueE","__Z18js_InitRegExpClassP9JSContextP8JSObject","__ZL16regexp_constructP9JSContextjPN2JS5ValueE","__ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcNS0_4TypeE","__ZN2JSL11ObjectValueER8JSObject3490","__ZN2JSL14UndefinedValueEv3491","__ZN2jsL14IsConstructingEPKN2JS5ValueE3500","__ZL20CompileRegExpAndSwapP9JSContextP8JSObjectjPN2JS5ValueES5_","__ZL19SwapRegExpInternalsP9JSContextP8JSObjectPN2JS5ValueEP8JSStringj","__ZL16SwapObjectRegExpP9JSContextP8JSObjectN2js15AlreadyIncRefedINS3_6RegExpEEE","__ZL25EscapeNakedForwardSlashesP9JSContextP8JSString","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC1ES1_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE7reserveEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16infallibleAppendItEEvPKT_j","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendIcEEbT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE6appendItEEbT_","_JSVAL_TO_BOOLEAN_IMPL3536","__ZL14JSID_FROM_BITSj3545","_JSVAL_IS_BOOLEAN_IMPL3538","_JSVAL_TO_STRING_IMPL3543","_JSVAL_IS_STRING_IMPL3544","__ZNK7mozilla14AlignedStorageILj256EE4addrEv","__ZN7mozilla14AlignedStorageILj256EE4addrEv","__ZL18JSDOUBLE_IS_FINITEd3520","__ZL15JSDOUBLE_IS_NaNd3521","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","_BOOLEAN_TO_JSVAL_IMPL3507","__ZN2js11NeedsIncRefINS_6RegExpEEC2EPS1_","__ZNK2js11NeedsIncRefINS_6RegExpEE3getEv","__ZN2js2gcL15GetGCObjectKindEjb3527","__ZL13JSVAL_TO_IMPLN2JS5ValueE3537","__ZNK2js13RegExpStatics9multilineEv","__ZL13IMPL_TO_JSVAL12jsval_layout3540","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE16extractRawBufferEv","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorItLj128ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj128ES1_EEj","__ZN2js10VectorImplItLj128ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEE14internalAppendItEEvPKT_j","__ZN2js6VectorItLj128ENS_15TempAllocPolicyEEC2ES1_","__ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContextNS_11NeedsIncRefIS1_EE","__ZN2js11NeedsIncRefINS_6RegExpEEC1EPS1_","__ZNK8JSObject18getRegExpLastIndexEv","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3509","__ZN2JSL9NullValueEv3510","__ZN8JSObject18setRegExpLastIndexEd","__ZN2js12AutoRefCountINS_6RegExpEED1Ev","__ZN2js12AutoRefCountINS_6RegExpEED2Ev","__ZN2JSL11NumberValueEd3511","__ZL18js_DoubleToIntegerd3519","__ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContextNS_11NeedsIncRefIS1_EE","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendERKt","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE3528","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE3529","__ZNK2js13RegExpStatics11createParenEP9JSContextjPN2JS5ValueE","__ZNK2js13RegExpStatics9pairCountEv","__ZNK2js13RegExpStatics9makeMatchEP9JSContextjjPN2JS5ValueE","__ZNK2js6VectorIiLj20ENS_17SystemAllocPolicyEEixEj","__ZNK2js13RegExpStatics15createDependentEP9JSContextjjPN2JS5ValueE","__ZNK2js13RegExpStatics3getEjb","__ZNK2js13RegExpStatics18createRightContextEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics17createLeftContextEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics15createLastParenEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics15createLastMatchEP9JSContextPN2JS5ValueE","_JSVAL_IS_BOOLEAN","_JSVAL_TO_BOOLEAN","_BOOLEAN_TO_JSVAL3539","_JSVAL_IS_STRING3541","__ZN2js13RegExpStatics15setPendingInputEP8JSString","_JSVAL_TO_STRING3542","__ZNK2js13RegExpStatics18createPendingInputEP9JSContextPN2JS5ValueE","__ZNK2js13RegExpStatics4markEP8JSTracer","__ZN9JSContext7delete_IN2js13RegExpStaticsEEEvPT_","__ZN2js13RegExpStaticsD1Ev","__ZN2js13RegExpStaticsD2Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEED2Ev","__ZN2jsL13VersionHasXMLE9JSVersion3598","__ZN2js11FindKeywordEPKtj","__ZN2js11TokenStream8TokenBuf4initEPKtj","__ZNK2js11TokenStream8TokenBuf11hasRawCharsEv","__ZN2js11TokenStream8TokenBuf10getRawCharEv","__ZN2js11TokenStream8TokenBuf12matchRawCharEt","__Z15js_IsIdentifierP14JSLinearString","__ZN2js7unicode17IsIdentifierStartEt","__ZN2js7unicode16IsIdentifierPartEt","__ZN2js11TokenStreamC2EP9JSContext","__ZN2js11TokenStream8TokenBufC1Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC1ES1_","__ZN2js11TokenStream4initEPKtjPKcj9JSVersion","__ZN2js11TokenStreamD2Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEED1Ev","__Z8js_fgetsPciP7__sFILE","__ZN2js11TokenStream7getCharEv","__ZN2js11TokenStream8TokenBuf12isRawEOLCharEi","__ZN2js11TokenStream8TokenBuf12ungetRawCharEv","__ZNK2js11TokenStream8TokenBuf7atStartEv","__ZN2js11TokenStream8TokenBuf21matchRawCharBackwardsEt","__ZN2js11TokenStream12isStrictModeEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE8shrinkByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE3endEv","__ZN2js11TokenStream20updateLineInfoForEOLEv","__ZN2js11TokenStream16getCharIgnoreEOLEv","__ZN2js11TokenStream9ungetCharEi","__ZN2js11TokenStream18ungetCharIgnoreEOLEi","__ZN2js11TokenStream9peekCharsEiPt","__ZN2js11TokenStream8TokenBuf7findEOLEv","__ZN2js11TokenStream26reportCompileErrorNumberVAEP11JSParseNodejjPc","__ZN2jsL7PodZeroI13JSErrorReportEEvPT_3601","__ZN2js21ReportStrictModeErrorEP9JSContextPNS_11TokenStreamEP13JSTreeContextP11JSParseNodejz","__ZN2js24ReportCompileErrorNumberEP9JSContextPNS_11TokenStreamEP11JSParseNodejjz","__ZN2js11TokenStream12getXMLEntityEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIiEEbT_","__ZN2js7unicode10IsXMLSpaceEt","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE5clearEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE5emptyEv","__ZN2js11TokenStream15getXMLTextOrTagEPNS_9TokenKindEPPNS_5TokenE","__ZN2js11TokenStream8newTokenEi","__ZN2js11TokenStream7atomizeEP9JSContextRNS_6VectorItLj32ENS_15TempAllocPolicyEEE","__ZN2js7unicode19IsXMLNamespaceStartEt","__ZN2js7unicode13IsXMLNamePartEt","__ZN2js11TokenStream8peekCharEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_j","__ZN2js11TokenStream9matchCharEi","__ZN2js11TokenStream12getXMLMarkupEPNS_9TokenKindEPPNS_5TokenE","__ZN2js11TokenStream9skipCharsEi","__ZN2js7unicode18IsXMLNamespacePartEt","__ZN2js11TokenStream17peekUnicodeEscapeEPi","__ZN2js11TokenStream25matchUnicodeEscapeIdStartEPi","__ZN2js11TokenStream23matchUnicodeEscapeIdentEPi","__ZN2js11TokenStream9getAtLineEv","__ZL10CharsMatchPKtPKc","__ZN2js11TokenStream8TokenBuf20addressOfNextRawCharEv","__ZN2js11TokenStream8TokenBuf23setAddressOfNextRawCharEPKt","__ZN2js7unicode13IsSpaceOrBOM2Et","__ZN2js11TokenStream21getAtSourceMappingURLEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendItEEbT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEixEj","__ZN2js11TokenStream18putIdentInTokenbufEPKt","__ZN2js11TokenStream16getTokenInternalEv","__ZN2js13PropertyTable13sizeOfEntriesEj","__ZN2jsL6HashIdEi","__ZN2js11TokenStream17updateFlagsForEOLEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructItEEvPtPKT_S7_","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13copyConstructIcEEvPtPKT_S7_","__ZNK2js7unicode13CharacterInfo8isLetterEv","__ZNK2js7unicode13CharacterInfo15isEnclosingMarkEv","__ZNK2js7unicode13CharacterInfo22isCombiningSpacingMarkEv","__ZN2js11TokenStream8TokenBufC2Ev","__ZNK2js7unicode13CharacterInfo16isIdentifierPartEv","__ZNK2js13PropertyTable8capacityEv","__ZNK2js5Shape6frozenEv","__ZN2js7unicode8IsLetterEt","__ZNK9JSContext15hasAtLineOptionEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendItEEvT_","__ZNK2js6VectorItLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorItLj32ES1_EEj","__ZN2js10VectorImplItLj32ENS_15TempAllocPolicyELb1EE13moveConstructItEEvPtPKT_S7_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE6appendIcEEbPKT_S6_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvPKT_j","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIiEEvT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEED2Ev","__ZN2js6VectorItLj32ENS_15TempAllocPolicyEEC2ES1_","__Z16js_GenerateShapeP9JSRuntime","__Z16js_GenerateShapeP9JSContext","__ZN8JSObject38ensureClassReservedSlotsForEmptyObjectEP9JSContext","__ZN2js13PropertyTable4initEP9JSRuntimePNS_5ShapeE","__ZN2js13PropertyTable6searchEib","__ZN2js5Shape7hashifyEP9JSContext","__ZN9JSRuntime4new_IN2js13PropertyTableEjEEPT_T0_","__ZN2js13PropertyTable6changeEiP9JSContext","__ZN2js13PropertyTable4growEP9JSContext","__ZN2js5Shape8getChildEP9JSContextRKS0_PPS0_","__ZNK2js13PropertyTable11needsToGrowEv","__ZN2js5Shape18newDictionaryShapeEP9JSContextRKS0_PPS0_","__ZN2js5Shape17newDictionaryListEP9JSContextPPS0_","__ZN8JSObject16getChildPropertyEP9JSContextPN2js5ShapeERS3_","__ZL24NormalizeGetterAndSetterP9JSContextP8JSObjectijjRPFiS0_S2_iPN2JS5ValueEERPFiS0_S2_iiS5_E","__ZN8JSObject13clearOwnShapeEv","__ZN8JSObject18removeLastPropertyEv","__ZNK2js5Shape20removeFromDictionaryEP8JSObject","__ZN2js5Shape20insertIntoDictionaryEPPS0_","__ZN8JSObject16toDictionaryModeEP9JSContext","__ZN8JSObject11addPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji","__ZN8JSObject19addPropertyInternalEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_EjjjiPPN2js5ShapeE","__ZN8JSObject11putPropertyEP9JSContextiPFiS1_PS_iPN2JS5ValueEEPFiS1_S2_iiS5_Ejjji","__Z19CheckCanChangeAttrsP9JSContextP8JSObjectPKN2js5ShapeEPj","__ZN2JSL14UndefinedValueEv3631","__ZN8JSObject14changePropertyEP9JSContextPKN2js5ShapeEjjPFiS1_PS_iPN2JS5ValueEEPFiS1_S6_iiS9_E","__ZN8JSObject14removePropertyEP9JSContexti","__ZN2JSL18PrivateUint32ValueEj3636","__ZN8JSObject5clearEP9JSContext","__ZN8JSObject18rollbackPropertiesEP9JSContextj","__ZN8JSObject16generateOwnShapeEP9JSContext","__ZN8JSObject19deletingShapeChangeEP9JSContextRKN2js5ShapeE","_INT_TO_JSID3676","__ZNK2js5Shape8getFlagsEv","__ZNK8JSObject20getMethodThrashCountEv","__ZN8JSObject20setMethodThrashCountEj","__ZL26js_IsPropertyCacheDisabledP9JSContext3652","__ZN2js13PropertyTableC2Ej","__ZNK2js8Bindings9lastUpvarEv","__ZN2js5Shape9setFrozenEv","__ZN8JSObject17methodShapeChangeEP9JSContextRKN2js5ShapeE","__ZN8JSObject17methodShapeChangeEP9JSContextj","__ZN8JSObject16protoShapeChangeEP9JSContext","__ZN8JSObject20shadowingShapeChangeEP9JSContextRKN2js5ShapeE","__ZN8JSObject26globalObjectOwnShapeChangeEP9JSContext","__ZN2js13PropertyTableC1Ej","__ZNK2js8Bindings6lookupEP9JSContextP6JSAtomPj","__ZL12ATOM_TO_JSIDP6JSAtom3673","__ZN2js8Bindings3addEP9JSContextP6JSAtomNS_11BindingKindE","__ZN2js8Bindings11ensureShapeEP9JSContext","__ZN2js8Bindings17getLocalNameArrayEP9JSContextPNS_6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEEE","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE19growByUninitializedEj","__ZL12JSID_IS_ATOMi3679","__ZL12JSID_TO_ATOMi3680","__ZNK2js8Bindings12lastArgumentEv","__ZNK2js8Bindings12lastVariableEv","__ZN2js8Bindings13sharpSlotBaseEP9JSContext","__ZN2js8Bindings13makeImmutableEv","__ZN2js8Bindings5traceEP8JSTracer","__Z12js_XDRScriptP10JSXDRStatePP8JSScript","__Z21js_MarkScriptFilenamePKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5emptyEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range5frontEv","__ZN2jsL7PodZeroIjEEvPT_j","__ZN8JSScript8numNotesEv","__ZN8JSScript9NewScriptEP9JSContextjjjjjjjjjttj9JSVersion","__ZL18SaveScriptFilenameP9JSContextPKc","__ZN12JSPCCounters4initEP9JSContextj","__ZN12JSPCCounters7destroyEP9JSContext","__ZL12script_traceP8JSTracerP8JSObject","__Z23js_SweepScriptFilenamesP13JSCompartment","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC1IS8_EERT_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4Enum11removeFrontEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5Range8popFrontEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD1Ev","__Z14js_NewGCScriptP9JSContext","__ZN2jsL7PodZeroI8JSScriptEEvPT_","__ZN8JSScript14setOwnerObjectEP8JSObject","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6hasMapEv","__ZN2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEE6getMapEv","__ZN2js11TokenStream16releaseSourceMapEv","__ZN2js6VectorINS_11UpvarCookieELj8ENS_15TempAllocPolicyEE5clearEv","__ZN8JSScript15NewScriptFromCGEP9JSContextP15JSCodeGenerator","__ZNK15JSCodeGenerator7versionEv","__ZNK15JSCodeGenerator15hasUpvarIndicesEv","__ZN2js6VectorIjLj8ENS_15TempAllocPolicyEEixEj","__Z18js_NewScriptObjectP9JSContextP8JSScript","__Z20js_CallNewScriptHookP9JSContextP8JSScriptP10JSFunction","__ZN8JSScript8dataSizeEv","__ZN8JSScript8dataSizeEPFjPvE","__Z24js_CallDestroyScriptHookP9JSContextP8JSScript","__ZN2js8Debugger15onDestroyScriptEP8JSScript","__ZN8JSScript8finalizeEP9JSContext","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_3707","__ZN2js8GSNCache5purgeEv","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE11initializedEv","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6finishEv","__ZN8JSScript20recompileForStepModeEP9JSContext","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrptEv","__ZNK14AutoJSXDRStatecvP10JSXDRStateEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10overloadedEv","__Z19js_GetSrcNoteCachedP9JSContextP8JSScriptPh","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrcvMSC_FvvEEv","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE4initEj","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3putERKS1_S7_","__Z22js_FramePCToLineNumberP9JSContextPN2js10StackFrameEPh","__Z17js_PCToLineNumberP9JSContextP8JSScriptPh","__ZL12js_GetOpcodeP9JSContextP8JSScriptPh3716","__Z17js_LineNumberToPCP8JSScriptj","__Z22js_GetScriptLineExtentP8JSScript","__ZN2js11CurrentLineEP9JSContext","__ZN2js28CurrentScriptFileAndLineSlowEP9JSContextPj","__Z14js_CloneScriptP9JSContextP8JSScript","__ZN14AutoJSXDRStateC1EP10JSXDRState","__ZN28DisablePrincipalsTranscodingC1EP9JSContext","__ZN14AutoJSXDRStateD1Ev","__ZN28DisablePrincipalsTranscodingD1Ev","__ZN8JSScript17copyClosedSlotsToEPS_","__ZN8JSScript14tryNewStepModeEP9JSContextj","__ZN2js17InterpreterFrames25enableInterruptsIfRunningEP8JSScript","__ZN8JSScript15setStepModeFlagEP9JSContextb","__ZN8JSScript19changeStepModeCountEP9JSContexti","__ZNK2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S1_EENS5_13MapHashPolicyES4_E6AddPtrERKS1_SF_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrEPPS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3addERNSB_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10isLiveHashEj","__ZN2js13PointerHasherIPhLj0EE5matchERKS1_S4_","__ZN2js13PointerHasherIPhLj0EE4hashERKS1_","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE3741","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10isLiveHashEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash1Ejj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC2ERS3_","__ZNK2js7MoveRefINS_12HashMapEntryIPhS2_EEEptEv","__ZN2js12HashMapEntryIPhS1_EC2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE12setCollisionEj","__ZN2js7HashMapIPhS1_NS_13PointerHasherIS1_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S1_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11initializedEv","__ZN2js2gcL15GetGCObjectKindEjb3731","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12hasCollisionEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10setRemovedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setFreeEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11underloadedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC2ERS6_","__ZNK2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEptEv","__ZNK2js7MoveRefIPNS_19ScriptFilenameEntryEEcvRS2_Ev","__ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC2ERS2_","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isFreeEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11createTableERS8_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIPhS4_EEEEEC1ERS6_","__ZN2js12HashMapEntryIPhS1_EaSENS_7MoveRefIS2_EE","__ZN2js4MoveINS_12HashMapEntryIPhS2_EEEENS_7MoveRefIT_EERS5_","__ZN2js7MoveRefINS_12HashMapEntryIPhS2_EEEC1ERS3_","__ZN2js4MoveIPhEENS_7MoveRefIT_EERS3_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIPhS3_EEEC2Ev","__ZN2js12HashMapEntryIPhS1_EC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E11prepareHashERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E5matchERNS0_14HashTableEntryIS4_EERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E4initEj","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E3PtrC1ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail9HashTableINS_12HashMapEntryIPhS3_EENS_7HashMapIS3_S3_NS_13PointerHasherIS3_Lj0EEENS_17SystemAllocPolicyEE13MapHashPolicyES8_E6finishEv","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE3732","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_3733","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE3736","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6removeERNS0_14HashTableEntryIS4_EE","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE6isLiveEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumD2Ev","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E16checkUnderloadedEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E15changeTableSizeEi","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E13findFreeEntryEj","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEEEEC1ERS6_","__ZN2js4MoveIPNS_19ScriptFilenameEntryEEENS_7MoveRefIT_EERS4_","__ZN2js7MoveRefIPNS_19ScriptFilenameEntryEEC1ERS2_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E4EnumC2IS8_EERT_","__ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3allEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3allEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC1EPNS0_14HashTableEntryIS4_EESE_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5RangeC2EPNS0_14HashTableEntryIS4_EESE_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr7nonNullEv","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOps6getKeyERKS2_","__ZL14JSID_FROM_BITSj3746","_JSID_TO_STRING3744","_JSID_IS_STRING3745","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN28DisablePrincipalsTranscodingD2Ev","__ZN14AutoJSXDRStateC2EP10JSXDRState","__ZNK2js15AtomThingMapPtrINS_9InlineMapIP6JSAtomjLj24EEEEptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP6JSAtomjEENS_7HashMapIS4_jNS_13DefaultHasherIS4_EENS_15TempAllocPolicyEE13MapHashPolicyES9_E5emptyEv","__ZNK2js11TokenStream16versionWithFlagsEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrdeEv","__ZNK2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9isRemovedEv","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10overloadedEv","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE7setLiveEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrC2ERNS0_14HashTableEntryIS4_EE","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE9matchHashEj","__ZN2js6detail14HashTableEntryIKPNS_19ScriptFilenameEntryEE12setCollisionEj","__ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkC2EP11JSArenaPool","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE10growByImplILb0EEEbj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP6JSAtomLj0ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj0ES3_EEj","__ZN2js10VectorImplIP6JSAtomLj0ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN14AutoJSXDRStateD2Ev","__ZN28DisablePrincipalsTranscodingC2EP9JSContext","__ZNK2js9InlineMapIP6JSAtomjLj24EE5emptyEv","__ZNK2js7HashMapIP6JSAtomjNS_13DefaultHasherIS2_EENS_15TempAllocPolicyEE5emptyEv","__ZNK2js6Parser16versionWithFlagsEv","__Z10NewGCThingI8JSScriptEPT_P9JSContextN2js2gc9AllocKindEj","__ZNK2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE12lookupForAddERKPKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3PtrcvMSB_FvvEEv","__ZN2js7HashSetIPNS_19ScriptFilenameEntryENS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableIKS2_NS5_6SetOpsES4_E6AddPtrERS8_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrERS4_","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3addERNSA_6AddPtrE","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E3Ptr5foundEv","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E12lookupForAddERKPKc","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E11prepareHashERKPKc","__ZNK2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6lookupERKPKcjj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC1ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E6AddPtrC2ERNS0_14HashTableEntryIS4_EEj","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E5matchERNS0_14HashTableEntryIS4_EERKPKc","__ZN2js20ScriptFilenameHasher5matchEPKNS_19ScriptFilenameEntryEPKc","__ZN2js20ScriptFilenameHasher4hashEPKc","__ZN2js6detail9HashTableIKPNS_19ScriptFilenameEntryENS_7HashSetIS3_NS_20ScriptFilenameHasherENS_17SystemAllocPolicyEE6SetOpsES7_E10isLiveHashEj","__ZZ12js_XDRScriptP10JSXDRStatePP8JSScriptEN8AutoMarkD2Ev","__ZN2js10EmptyShape17getEmptyCallShapeEP9JSContext","__ZL10str_escapeP9JSContextjPN2JS5ValueE","__ZL12str_unescapeP9JSContextjPN2JS5ValueE","__ZL10str_unevalP9JSContextjPN2JS5ValueE","__ZL13str_decodeURIP9JSContextjPN2JS5ValueE","__ZL13str_encodeURIP9JSContextjPN2JS5ValueE","__ZL23str_decodeURI_ComponentP9JSContextjPN2JS5ValueE","__ZL23str_encodeURI_ComponentP9JSContextjPN2JS5ValueE","__ZL13str_enumerateP9JSContextP8JSObject","__ZL11str_resolveP9JSContextP8JSObjectijPS2_","__Z15js_str_toStringP9JSContextjPN2JS5ValueE","__ZN2js16GetPrimitiveThisIP8JSStringEEbP9JSContextPN2JS5ValueEPT_","__Z14js_toLowerCaseP9JSContextP8JSString","__Z12js_NewStringP9JSContextPtj","__Z14js_toUpperCaseP9JSContextP8JSString","__ZN2js7unicode11ToUpperCaseEt","__Z13js_str_charAtP9JSContextjPN2JS5ValueE","__ZL26ThisToStringForStringProtoP9JSContextPN2JS5ValueE","__ZN2jsL9ToIntegerEP9JSContextRKN2JS5ValueEPd3824","__Z17js_str_charCodeAtP9JSContextjPN2JS5ValueE","__Z21js_BoyerMooreHorspoolPKtjS0_j","__Z15js_strchr_limitPKttS0_","__ZNK9FlatMatch5matchEv","__ZN2js11str_replaceEP9JSContextjPN2JS5ValueE","__ZN11ReplaceDataC1EP9JSContext","__ZN11RegExpGuard4initEjPN2JS5ValueEb","__ZL13js_IsCallableRKN2JS5ValueE3827","__ZN2JSL14UndefinedValueEv3828","__ZL17ArgToRootedStringP9JSContextjPN2JS5ValueEj","__ZN11RegExpGuard12tryFlatMatchEP9JSContextP8JSStringjjb","__ZL18str_replace_regexpP9JSContextjPN2JS5ValueER11ReplaceData","__ZL23str_replace_flat_lambdaP9JSContextjPN2JS5ValueER11ReplaceDataRK9FlatMatch","__ZL22BuildDollarReplacementP9JSContextP8JSStringP14JSLinearStringPKtRK9FlatMatchPN2JS5ValueE","__ZL20BuildFlatReplacementP9JSContextP8JSStringS2_RK9FlatMatchPN2JS5ValueE","__ZN11ReplaceDataD1Ev","__ZL9str_quoteP9JSContextjPN2JS5ValueE","__ZL12str_toSourceP9JSContextjPN2JS5ValueE","__ZL13str_substringP9JSContextjPN2JS5ValueE","__ZL15str_toLowerCaseP9JSContextjPN2JS5ValueE","__ZL15str_toUpperCaseP9JSContextjPN2JS5ValueE","__ZL11str_indexOfP9JSContextjPN2JS5ValueE","__ZL15str_lastIndexOfP9JSContextjPN2JS5ValueE","__ZL8str_trimP9JSContextjPN2JS5ValueE","__ZL12str_trimLeftP9JSContextjPN2JS5ValueE","__ZL13str_trimRightP9JSContextjPN2JS5ValueE","__ZL21str_toLocaleLowerCaseP9JSContextjPN2JS5ValueE","__ZL21str_toLocaleUpperCaseP9JSContextjPN2JS5ValueE","__ZL17str_localeCompareP9JSContextjPN2JS5ValueE","__ZL9str_matchP9JSContextjPN2JS5ValueE","__ZL10str_searchP9JSContextjPN2JS5ValueE","__ZL9str_splitP9JSContextjPN2JS5ValueE","__ZL10str_substrP9JSContextjPN2JS5ValueE","__ZNK2js6VectorItLj32ENS_18ContextAllocPolicyEE8capacityEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE5clearEv","__ZL10str_concatP9JSContextjPN2JS5ValueE","__ZL9str_sliceP9JSContextjPN2JS5ValueE","__ZL8str_boldP9JSContextjPN2JS5ValueE","__ZL11str_italicsP9JSContextjPN2JS5ValueE","__ZL9str_fixedP9JSContextjPN2JS5ValueE","__ZL12str_fontsizeP9JSContextjPN2JS5ValueE","__ZL13str_fontcolorP9JSContextjPN2JS5ValueE","__ZL8str_linkP9JSContextjPN2JS5ValueE","__ZL10str_anchorP9JSContextjPN2JS5ValueE","__ZL10str_strikeP9JSContextjPN2JS5ValueE","__ZL9str_smallP9JSContextjPN2JS5ValueE","__ZL7str_bigP9JSContextjPN2JS5ValueE","__ZL9str_blinkP9JSContextjPN2JS5ValueE","__ZL7str_supP9JSContextjPN2JS5ValueE","__ZL7str_subP9JSContextjPN2JS5ValueE","__Z9js_StringP9JSContextjPN2JS5ValueE","__Z16js_ValueToStringP9JSContextRKN2JS5ValueE","__ZN2jsL14IsConstructingEPKN2JS5ValueE3833","__ZL16str_fromCharCodeP9JSContextjPN2JS5ValueE","__ZN2js12StringObject18assignInitialShapeEP9JSContext","__ZL12ATOM_TO_JSIDP6JSAtom3836","__Z18js_InitStringClassP9JSContextP8JSObject","__ZN2jsL17CheckStringLengthEP9JSContextj3839","__ZN13JSFixedString4new_EP9JSContextPKtj","__ZN2js12StringBuffer16extractWellSizedEv","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16extractRawBufferEv","__ZN2js12StringBuffer12finishStringEv","__ZL14NewShortStringP9JSContextPKtj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE6appendIcEEbT_","__ZN2js12StringBuffer10finishAtomEv","__Z21js_NewDependentStringP9JSContextP8JSStringjj","__ZN17JSDependentString4new_EP9JSContextP14JSLinearStringPKtj","__Z17js_NewStringCopyNP9JSContextPKtj","__Z17js_NewStringCopyNP9JSContextPKcj","_JSDOUBLE_IS_NEGZERO3865","__Z9js_strlenPKt","__Z9js_strchrPKtt","__ZL14NewShortStringP9JSContextPKcj","__ZN2js13InflateStringEP9JSContextPKcPjNS_13FlationCodingE","__Z17js_NewStringCopyZP9JSContextPKt","__Z17js_NewStringCopyZP9JSContextPKc","__Z19js_ValueToPrintableP9JSContextRKN2JS5ValueEP16JSAutoByteStringb","__Z16js_ValueToSourceP9JSContextRKN2JS5ValueE","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE3862","__ZN2js23ValueToStringBufferSlowEP9JSContextRKN2JS5ValueERNS_12StringBufferE","__ZN2js12StringBuffer6appendEP6JSAtom","__ZN2JSL9NullValueEv3866","__ZN2js12EqualStringsEP9JSContextP8JSStringS3_Pi","__ZN2jsL8PodEqualIKtEEbPT_S3_j3869","__ZN2js12EqualStringsEP14JSLinearStringS1_","__Z22js_EqualStringsOnTraceP9JSContextP8JSStringS2_","__ZN2js14CompareStringsEP9JSContextP8JSStringS3_Pi","__ZN2jsL18CompareStringsImplEP9JSContextP8JSStringS3_Pi","__Z24js_CompareStringsOnTraceP9JSContextP8JSStringS2_","__ZN2js17StringEqualsAsciiEP14JSLinearStringPKc","__ZN2js25InflateUTF8StringToBufferEP9JSContextPKcjPtPjNS_13FlationCodingE","__ZN2js13DeflateStringEP9JSContextPKtj","__ZN2js23GetDeflatedStringLengthEP9JSContextPKtj","__ZN2js21DeflateStringToBufferEP9JSContextPKtjPcPj","__Z20js_OneUcs4ToUtf8CharPhj","__ZL17Utf8ToOneUcs4CharPKhi","__ZN2js27GetDeflatedUTF8StringLengthEP9JSContextPKtjNS_13FlationCodingE","__ZN2js25DeflateStringToUTF8BufferEP9JSContextPKtjPcPjNS_13FlationCodingE","__ZN2js21InflateStringToBufferEP9JSContextPKcjPtPj","__ZN2js20PutEscapedStringImplEPcjP7__sFILEP14JSLinearStringj","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE14internalAppendIcEEvT_","__ZN2js6detail17PrimitiveBehaviorIP8JSStringE6isTypeERKN2JS5ValueE","__ZN2js6detail17PrimitiveBehaviorIP8JSStringE7extractERKN2JS5ValueE","__ZL6EncodeP9JSContextP8JSStringPKtS4_PN2JS5ValueE","__ZL22TransferBufferToStringP9JSContextRN2js12StringBufferEPN2JS5ValueE","__ZL14JSID_FROM_BITSj3911","__ZN14JSInlineString10lengthFitsEj","_JSID_IS_INT3906","__ZN2js13StaticStrings7hasUnitEt","__ZNK16SplitMatchResult9isFailureEv","__ZNK16SplitMatchResult6lengthEv","__ZNK16SplitMatchResult8endIndexEv","__ZL6DecodeP9JSContextP8JSStringPKtPN2JS5ValueE","__ZN14JSInlineString4new_EP9JSContext","__ZN13JSShortString4new_EP9JSContext","__ZN14JSInlineString11resetLengthEj","__ZN17JSDependentString4initEP14JSLinearStringPKtj","__ZN2jsL7PodCopyItEEvPT_PKS1_j3900","__ZN13JSFixedString4initEPKtj","__ZN2JSL11ObjectValueER8JSObject3902","__ZN2JSL11StringValueEP8JSString3909","__ZN2JSL10Int32ValueEi3910","__ZL6tagifyP9JSContextPKcP14JSLinearStringS2_PN2JS5ValueE","__ZL12tagify_valueP9JSContextjPN2JS5ValueEPKcS5_","__Z19ValueToIntegerRangeP9JSContextRKN2JS5ValueEPi","__ZL15VALUE_IS_REGEXPP9JSContextN2JS5ValueE","__ZL11SplitHelperI18SplitRegExpMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE","__ZN18SplitRegExpMatcherC1EPN2js6RegExpEPNS0_13RegExpStaticsE","__ZL11SplitHelperI18SplitStringMatcherEP8JSObjectP9JSContextP14JSLinearStringjT_PN2js5types10TypeObjectE","__ZN18SplitStringMatcherC1EP14JSLinearString","__ZN18SplitStringMatcherC2EP14JSLinearString","__ZN18SplitStringMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult","__ZL11StringMatchPKtjS0_j","__ZN2js6RegExp10isMetaCharEt","__ZL15JSDOUBLE_IS_NaNd3930","__ZL18JSDOUBLE_IS_FINITEd3932","__ZN16SplitMatchResult10setFailureEv","__ZN16SplitMatchResult9setResultEjj","__ZN9ManualCmp13computeExtentEPKtj","__ZN9ManualCmp5matchEPKtS1_S1_","__ZN18SplitRegExpMatcherC2EPN2js6RegExpEPNS0_13RegExpStaticsE","__ZNK2js12AutoRefCountINS_6RegExpEEdeEv","__ZNK2js12AutoRefCountINS_6RegExpEE4nullEv","__ZN9FlatMatchC2Ev","__ZN2js12AutoRefCountINS_6RegExpEEC2EP9JSContext","__ZNK10RegExpPair5reobjEv","__ZNK9FlatMatch7patternEv","__ZNK9FlatMatch13patternLengthEv","__ZNK2js18StringSegmentRange5emptyEv","__ZNK2js18StringSegmentRange5frontEv","__ZN2js11RopeBuilder6resultEv","__ZL13UnrolledMatchI9ManualCmpEiPKtjS2_j","__ZN18SplitRegExpMatcherclEP9JSContextP14JSLinearStringjP16SplitMatchResult","__ZNK2js13RegExpStatics10parenCountEv","__ZNK2js13RegExpStatics13pairIsPresentEj","__ZNK2js13RegExpStatics8getParenEjP11JSSubString","__ZN2js5types15AddTypePropertyEP9JSContextPNS0_10TypeObjectEPKcRKN2JS5ValueE","__ZNK2js13RegExpStatics14getParenLengthEj","__ZNK2js13RegExpStatics12getLastMatchEP11JSSubString","__ZN11RegExpGuardC1EP9JSContext","__ZN11RegExpGuard15normalizeRegExpEbjjPN2JS5ValueE","__ZNK10RegExpPair2reEv","__ZNK2js13RegExpStatics10matchStartEv","__ZN11RegExpGuardD1Ev","__ZN11RegExpGuardD2Ev","__ZN10RegExpPairD1Ev","__ZN10RegExpPairD2Ev","__ZNK10RegExpPair9hasRegExpEv","__ZN11RegExpGuard14flattenPatternEP9JSContextP14JSLinearString","__ZN10RegExpPair5resetEN2js15AlreadyIncRefedINS0_6RegExpEEE","__ZN2js12AutoRefCountINS_6RegExpEE5resetENS_15AlreadyIncRefedIS1_EE","__ZN11RegExpGuardC2EP9JSContext","__ZN10RegExpPairC1EP9JSContext","__ZN9FlatMatchC1Ev","__ZN10RegExpPairC2EP9JSContext","__ZN2js12AutoRefCountINS_6RegExpEEC1EP9JSContext","__ZL19BuildFlatMatchArrayP9JSContextP8JSStringRK9FlatMatchPN2JS5ValueE","__ZL7DoMatchP9JSContextPN2js13RegExpStaticsEP8JSStringRK10RegExpPairPFbS0_S3_jPvES9_17MatchControlFlagsPN2JS5ValueE","__ZL13MatchCallbackP9JSContextPN2js13RegExpStaticsEjPv","__ZN8JSObject13defineElementEP9JSContextjRKN2JS5ValueEPFiS1_PS_iPS3_EPFiS1_S6_iiS7_Ej","__ZL7MatchedbRKN2JS5ValueE","__ZNK2js13RegExpStatics7matchedEv","__ZL13js_TrimStringP9JSContextPN2JS5ValueEii","__ZL18js_DoubleToIntegerd3931","__ZN11ReplaceDataD2Ev","__ZN2js11RopeBuilderC1EP9JSContext","__ZN2js18StringSegmentRangeC1EP9JSContext","__ZN2js18StringSegmentRange4initEP8JSString","__ZN2js11RopeBuilder6appendEP8JSString","__ZN2js18StringSegmentRange8popFrontEv","__ZN2js18StringSegmentRangeD1Ev","__ZN2js18StringSegmentRangeD2Ev","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE10endNoCheckEv","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE5emptyEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popBackEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE3endEv","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN2js11RopeBuilderC2EP9JSContext","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED1Ev","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEED2Ev","__ZNK2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE18usingInlineStorageEv","__ZN2js18StringSegmentRange6settleEP8JSString","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE7popCopyEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE4backEv","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj32ES3_EEj","__ZN2js10VectorImplIP8JSStringLj32ENS_15TempAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js18StringSegmentRangeC2EP9JSContext","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC1ES3_","__ZN2js6VectorIP8JSStringLj32ENS_15TempAllocPolicyEEC2ES3_","__ZN2js12StringBuffer16infallibleAppendEPKtS2_","__ZN2js6VectorItLj32ENS_18ContextAllocPolicyEE16infallibleAppendItEEvPKT_S6_","__ZL21ReplaceRegExpCallbackP9JSContextPN2js13RegExpStaticsEjPv","__ZNK2js13RegExpStatics15getRightContextEP11JSSubString","__ZNK2js13RegExpStatics10matchLimitEv","__ZL17FindReplaceLengthP9JSContextPN2js13RegExpStaticsER11ReplaceDataPj","__ZL9DoReplaceP9JSContextPN2js13RegExpStaticsER11ReplaceData","__ZL15InterpretDollarP9JSContextPN2js13RegExpStaticsEPKtS5_R11ReplaceDataP11JSSubStringPj","__ZNK2js13RegExpStatics12getLastParenEP11JSSubString","__ZNK2js13RegExpStatics14getLeftContextEP11JSSubString","__ZN2js21PreserveRegExpStaticsC1EPNS_13RegExpStaticsE","__ZN2js21PreserveRegExpStatics4initEP9JSContext","__ZN2jsL33ValueToString_TestForStringInlineEP9JSContextRKN2JS5ValueE","__ZN2js21PreserveRegExpStaticsD1Ev","__ZN2js21PreserveRegExpStaticsD2Ev","__ZN2js13RegExpStatics7restoreEv","__ZN2js13RegExpStatics4saveEP9JSContextPS0_","__ZN2js6VectorIiLj20ENS_17SystemAllocPolicyEE7reserveEj","__ZN2js21PreserveRegExpStaticsC2EPNS_13RegExpStaticsE","__ZN2js13RegExpStaticsC1ENS0_10InitBufferE","__ZN2js13RegExpStaticsC2ENS0_10InitBufferE","__ZN2js11ArrayBufferD2Ev","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE3983","_JSID_TO_INT3948","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE5beginEv","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE3endEv","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE12beginNoCheckEv","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE10endNoCheckEv","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13copyConstructIS2_EEvPS2_PKT_S9_","__ZN8JSObject8setClassEPN2js5ClassE","__ZN2js6RegExp12hasMetaCharsEPKtj","__ZL9RopeMatchP9JSContextP8JSStringPKtjPi","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC1ES3_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE6appendIS2_EEbT_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED1Ev","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEED2Ev","__ZNK2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE18usingInlineStorageEv","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE13growStorageByEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE14internalAppendIS2_EEvT_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20convertToHeapStorageEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE17growHeapStorageByEj","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEE20calculateNewCapacityEjjRj","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE6growToERNS_6VectorIS2_Lj16ES3_EEj","__ZN2js10VectorImplIP14JSLinearStringLj16ENS_17SystemAllocPolicyELb1EE13moveConstructIS2_EEvPS2_PKT_S9_","__ZN2js6VectorIP14JSLinearStringLj16ENS_17SystemAllocPolicyEEC2ES3_","__ZN10RegExpPair5resetER8JSObject","__ZN2js12AutoRefCountINS_6RegExpEE5resetENS_11NeedsIncRefIS1_EE","__ZN11ReplaceDataC2EP9JSContext","__ZN2jsL19ClassMethodIsNativeEP9JSContextP8JSObjectPNS_5ClassEiPFiS1_jPN2JS5ValueEE3938","__ZN2jsL16IsNativeFunctionERKN2JS5ValueEPFiP9JSContextjPS1_E3939","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP10JSFunction3940","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObjectPP10JSFunction3941","__ZN2jsL16IsFunctionObjectERKN2JS5ValueEPP8JSObject3942","__ZN2js11ArrayBuffer14getArrayBufferEP8JSObject","__Z16js_IsArrayBufferP8JSObject","__ZN2js11ArrayBuffer18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN2js11ArrayBuffer17class_constructorEP9JSContextjPN2JS5ValueE","__ZN2js11ArrayBuffer6createEP9JSContexti","__ZN8JSObject24allocateArrayBufferSlotsEP9JSContextj","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE3981","__ZN2js11ArrayBuffer9obj_traceEP8JSTracerP8JSObject","__ZN2js11ArrayBuffer18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty","__ZL12JSID_IS_ATOMiP6JSAtom3982","__ZL14DelegateObjectP9JSContextP8JSObject","__ZN2js11ArrayBuffer17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty","__ZN2js11ArrayBuffer17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty","__ZN2js11ArrayBuffer18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN2js11ArrayBuffer17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN2js11ArrayBuffer17obj_defineSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS7_EPFiS2_S4_iiSA_Ej","__ZN2js11ArrayBuffer14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN2js11ArrayBuffer15obj_getPropertyEP9JSContextP8JSObjectS4_PNS_12PropertyNameEPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom3984","__ZN2js11ArrayBuffer14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN2js11ArrayBuffer14obj_getSpecialEP9JSContextP8JSObjectS4_NS_9SpecialIdEPN2JS5ValueE","__ZN2js11ArrayBuffer10obj_typeOfEP9JSContextP8JSObject","__ZN2js10TypedArray24obj_getElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js10TypedArray10dataOffsetEv","__ZN8JSObject18getFixedSlotOffsetEj","__Z32js_TypedArray_uint8_clamp_doubled","__ZL15JSDOUBLE_IS_NaNd3989","__ZN2js11ArrayBuffer15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js11ArrayBuffer14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js11ArrayBuffer14obj_setSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_getAttributesEP9JSContextP8JSObjectiPj","__ZN2js11ArrayBuffer24obj_getElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js11ArrayBuffer24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js11ArrayBuffer17obj_setAttributesEP9JSContextP8JSObjectiPj","__ZN2js11ArrayBuffer24obj_setElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js11ArrayBuffer24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js11ArrayBuffer18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN2js11ArrayBuffer17obj_deleteSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPN2JS5ValueEi","__ZN2js11ArrayBuffer13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN2js10TypedArray13getTypedArrayEP8JSObject","__Z15js_IsTypedArrayP8JSObject","__ZN2js10TypedArray14prop_getBufferEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z14getBufferValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18prop_getByteOffsetEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z18getByteOffsetValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18prop_getByteLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z18getByteLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray14prop_getLengthEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN16TypedArrayGetterIXadL_Z14getLengthValueP8JSObjectEEE3getEP9JSContextS1_iPN2JS5ValueE","__ZN2js10TypedArray18obj_lookupPropertyEP9JSContextP8JSObjectiPS4_PP10JSProperty","__ZN2js10TypedArray12isArrayIndexEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray17obj_lookupElementEP9JSContextP8JSObjectjPS4_PP10JSProperty","__ZN2js10TypedArray17obj_lookupSpecialEP9JSContextP8JSObjectNS_9SpecialIdEPS4_PP10JSProperty","__ZN2js10TypedArray17obj_getAttributesEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray24obj_getSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js10TypedArray17obj_setAttributesEP9JSContextP8JSObjectiPj","__ZN2js10TypedArray24obj_setElementAttributesEP9JSContextP8JSObjectjPj","__ZN2js10TypedArray24obj_setSpecialAttributesEP9JSContextP8JSObjectNS_9SpecialIdEPj","__ZN2js10TypedArray12lengthOffsetEv","__ZN18TypedArrayTemplateIiE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIjE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIfE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIdE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIaE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE12fun_subarrayEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE7fun_setEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIaE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIaE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIaE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIaE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIaE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIaE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIaE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIaE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIhE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIsE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIaE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIhE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIhE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIhE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIhE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIhE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIhE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIhE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIhE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIhE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIsE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIsE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIsE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIsE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIsE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIsE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIsE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIsE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIsE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateItE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateItE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateItE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateItE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateItE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIiE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateItE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateItE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateItE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateItE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateItE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateItE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateItE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateItE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateItE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIiE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIiE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIiE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIiE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIiE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIiE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIiE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIiE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIiE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIjE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIjE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIjE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIjE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIjE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIjE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIjE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIjE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIjE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIfE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIdE10obj_typeOfEP9JSContextP8JSObject","__ZN18TypedArrayTemplateIjE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIfE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIfE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIfE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIfE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIfE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIfE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIfE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIfE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIfE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateIdE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateIdE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIdE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS2_S4_iPS6_EPFiS2_S4_iiS9_Ej","__ZN18TypedArrayTemplateIdE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS2_S4_iPS8_EPFiS2_S4_iiSB_Ej","__ZN18TypedArrayTemplateIdE14obj_getGenericEP9JSContextP8JSObjectS4_iPN2JS5ValueE","__ZN18TypedArrayTemplateIdE15obj_getPropertyEP9JSContextP8JSObjectS4_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateIdE14obj_getElementEP9JSContextP8JSObjectS4_jPN2JS5ValueE","__ZN18TypedArrayTemplateIdE14obj_getSpecialEP9JSContextP8JSObjectS4_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateIdE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZN18TypedArrayTemplateI13uint8_clampedE9obj_traceEP8JSTracerP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE18obj_definePropertyEP9JSContextP8JSObjectiPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineElementEP9JSContextP8JSObjectjPKN2JS5ValueEPFiS3_S5_iPS7_EPFiS3_S5_iiSA_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_defineSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS3_S5_iPS9_EPFiS3_S5_iiSC_Ej","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getGenericEP9JSContextP8JSObjectS5_iPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE15obj_getPropertyEP9JSContextP8JSObjectS5_PN2js12PropertyNameEPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE10obj_typeOfEP9JSContextP8JSObject","__ZN2js21IsFastTypedArrayClassEPKNS_5ClassE","__ZNK8JSObject13isArrayBufferEv","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getElementEP9JSContextP8JSObjectS5_jPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_getSpecialEP9JSContextP8JSObjectS5_N2js9SpecialIdEPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE15obj_setPropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_setElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE14obj_setSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE18obj_deletePropertyEP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteElementEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE17obj_deleteSpecialEP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE13obj_enumerateEP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__Z24js_InitTypedArrayClassesP9JSContextP8JSObject","__ZL19InitTypedArrayClassI9Int8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Uint8ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Int16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI11Uint16ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI10Int32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI11Uint32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI12Float32ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI12Float64ArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL19InitTypedArrayClassI17Uint8ClampedArrayEP8JSObjectP9JSContextPN2js12GlobalObjectE","__ZL20InitArrayBufferClassP9JSContextPN2js12GlobalObjectE","__Z27JS_GetArrayBufferByteLengthP8JSObject","__Z21JS_GetArrayBufferDataP8JSObject","__Z20js_CreateArrayBufferP9JSContextj","__Z19js_CreateTypedArrayP9JSContextij","__ZN2JSL10Int32ValueEi3996","__ZL19TypedArrayConstructP9JSContextijPN2JS5ValueE","__Z28js_CreateTypedArrayWithArrayP9JSContextiP8JSObject","_INT_TO_JSID4006","__ZL18JSDOUBLE_IS_FINITEd4011","__ZN13uint8_clampedaSERKS_","__ZN13uint8_clampedaSEj","__ZN13uint8_clampedaSEi","__ZN2JSL11ObjectValueER8JSObject3997","__Z29js_CreateTypedArrayWithBufferP9JSContextiP8JSObjectii","__Z22JS_GetTypedArrayLengthP8JSObject","__Z26JS_GetTypedArrayByteOffsetP8JSObject","__Z26JS_GetTypedArrayByteLengthP8JSObject","__Z20JS_GetTypedArrayTypeP8JSObject","__Z22JS_GetTypedArrayBufferP8JSObject","__Z20JS_GetTypedArrayDataP8JSObject","__ZN18TypedArrayTemplateI13uint8_clampedE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE6createEP9JSContextjPN2JS5ValueE","__ZL13ValueIsLengthP9JSContextRKN2JS5ValueEPj","__ZN18TypedArrayTemplateI13uint8_clampedE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateI13uint8_clampedE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateI13uint8_clampedE18copyFromTypedArrayEP9JSContextP8JSObjectS5_j","__ZN18TypedArrayTemplateI13uint8_clampedE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateI13uint8_clampedE13copyFromArrayEP9JSContextP8JSObjectS5_jj","__ZN18TypedArrayTemplateI13uint8_clampedE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN13uint8_clampedC1Ei","__ZN13uint8_clampedC1Ed","__ZN13uint8_clampedC1Ej","__ZL20js_DoubleToECMAInt32d4007","__ZN13uint8_clampedC2Ej","__ZN13uint8_clampedC2Ed","__ZN13uint8_clampedaSEd","__ZN13uint8_clampedC2Ei","__ZN2js10TypedArray9getBufferEP8JSObject","__ZN13uint8_clampedaSEt","__ZN13uint8_clampedaSEs","__ZN13uint8_clampedaSEh","__ZN13uint8_clampedaSEa","__ZN18TypedArrayTemplateI13uint8_clampedE19copyFromWithOverlapEP9JSContextP8JSObjectS5_j","__ZN2js10TypedArray13getByteLengthEP8JSObject","__ZN13uint8_clampedC1Ea","__ZN13uint8_clampedC1Eh","__ZN13uint8_clampedC1Es","__ZN13uint8_clampedC1Et","__ZN13uint8_clampedC2Et","__ZN13uint8_clampedC2Es","__ZN13uint8_clampedC2Eh","__ZN13uint8_clampedC2Ea","__ZN18TypedArrayTemplateIdE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIdE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIdE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIdE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIdE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIdE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIdE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIdE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIfE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIfE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIfE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIfE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIfE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIfE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIfE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIfE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIjE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIjE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIjE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIjE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIjE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIjE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIjE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIjE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIiE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIiE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIiE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIiE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIiE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIiE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIiE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIiE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateItE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateItE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateItE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateItE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateItE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateItE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateItE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateItE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIsE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIsE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIsE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIsE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIsE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIsE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIsE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIhE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIhE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIhE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIhE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIhE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIhE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZN18TypedArrayTemplateIhE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIaE17class_constructorEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE6createEP9JSContextjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE28createBufferWithSizeAndCountEP9JSContextj","__ZN18TypedArrayTemplateIaE16createTypedArrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIaE18copyFromTypedArrayEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateIaE32createTypedArrayWithOffsetLengthEP9JSContextP8JSObjectii","__ZN18TypedArrayTemplateIaE13copyFromArrayEP9JSContextP8JSObjectS4_jj","__ZN18TypedArrayTemplateIaE15nativeFromValueEP9JSContextRKN2JS5ValueE","__ZNK13uint8_clampedcvhEv","__ZN13uint8_clampedC2ERKS_","__ZN18TypedArrayTemplateIaE19copyFromWithOverlapEP9JSContextP8JSObjectS4_j","__ZN18TypedArrayTemplateI13uint8_clampedE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateI13uint8_clampedE8setIndexEP8JSObjectjS0_","__ZN18TypedArrayTemplateI13uint8_clampedE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateI13uint8_clampedE8getIndexEP8JSObjectj","__ZN13uint8_clampedC1ERKS_","__ZN18TypedArrayTemplateIdE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIdE8setIndexEP8JSObjectjd","__ZN18TypedArrayTemplateIfE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIfE8setIndexEP8JSObjectjf","__ZN18TypedArrayTemplateIjE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIjE8setIndexEP8JSObjectjj","__ZN18TypedArrayTemplateIiE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIiE8setIndexEP8JSObjectji","__ZN18TypedArrayTemplateItE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateItE8setIndexEP8JSObjectjt","__ZN18TypedArrayTemplateItE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateItE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIsE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIsE8setIndexEP8JSObjectjs","__ZN18TypedArrayTemplateIsE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIsE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIhE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIhE8setIndexEP8JSObjectjh","__ZN18TypedArrayTemplateIhE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIhE8getIndexEP8JSObjectj","__ZN18TypedArrayTemplateIaE14setElementTailEP9JSContextP8JSObjectjPN2JS5ValueEi","__ZN18TypedArrayTemplateIaE8setIndexEP8JSObjectja","__ZN18TypedArrayTemplateIaE16copyIndexToValueEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN18TypedArrayTemplateIaE8getIndexEP8JSObjectj","__ZL14JSID_FROM_BITSj4031","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10isLiveHashEj","__ZN2js2gcL15GetGCObjectKindEjb4033","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range5frontEv","__ZN18TypedArrayTemplateI13uint8_clampedE14createSubarrayEP9JSContextP8JSObjectjj","__ZN2js10TypedArray13getByteOffsetEP8JSObject","__ZN18TypedArrayTemplateIdE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIfE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIjE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIiE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateItE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIsE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIhE14createSubarrayEP9JSContextP8JSObjectjj","__ZN18TypedArrayTemplateIaE14createSubarrayEP9JSContextP8JSObjectjj","__Z14getLengthValueP8JSObject","__Z18getByteLengthValueP8JSObject","__Z18getByteOffsetValueP8JSObject","__Z14getBufferValueP8JSObject","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4032","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4034","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4037","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4041","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4042","_JS_Assert","__ZL9CrashInJSv","__ZN2js13WatchpointMap4initEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE4initEj","__ZN2js13WatchpointMap5watchEP9JSContextP8JSObjectiPFiS2_S4_iN2JS5ValueEPS6_PvES4_","__ZN8JSObject10setWatchedEP9JSContext","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3putERKS1_RKS2_","__ZN2js8WatchKeyC1EP8JSObjecti","__ZN2js13WatchpointMap7unwatchEP8JSObjectiPPFiP9JSContextS2_iN2JS5ValueEPS6_PvEPS2_","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6lookupERKS1_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrcvMSD_FvvEEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E3PtrE","__ZN2js13WatchpointMap13unwatchObjectEP8JSObject","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC1ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD1Ev","__ZN2js13WatchpointMap5clearEv","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE5clearEv","__ZN2js13WatchpointMap17triggerWatchpointEP9JSContextP8JSObjectiPN2JS5ValueE","__ZN15AutoEntryHolderC1ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2JSL11ObjectValueER8JSObject4064","__ZN15AutoEntryHolderD1Ev","__ZN2js13WatchpointMap18markAllIterativelyEP8JSTracer","__ZN2js13WatchpointMap15markIterativelyEP8JSTracer","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3allEv","__ZN2js13WatchpointMap8sweepAllEP9JSContext","__ZN2js13WatchpointMap5sweepEP9JSContext","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC1EPNS0_14HashTableEntryIS5_EESG_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5RangeC2EPNS0_14HashTableEntryIS5_EESG_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isLiveEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5clearEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEaSENS_7MoveRefIS6_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERKS9_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2Ev","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC1Ev","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEC2Ev","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC1ERS7_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5hash2Ejjj","__ZN2jsL6HashIdEi4071","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEC2ERS7_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC2ERS4_","__ZNK2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEptEv","__ZNK2js7MoveRefINS_8WatchKeyEEcvRS1_Ev","__ZNK2js7MoveRefINS_10WatchpointEEcvRS1_Ev","__ZN2js7MoveRefINS_10WatchpointEEC2ERS1_","__ZN2js7MoveRefINS_8WatchKeyEEC2ERS1_","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12hasCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11underloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10getKeyHashEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setLiveEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC2ERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE12setCollisionEj","__ZN2js13DefaultHasherINS_8WatchKeyEE5matchERKS1_S4_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS1_S2_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10generationEv","__ZN2js8WatchKeyC2EP8JSObjecti","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSENS_7MoveRefIS3_EE","__ZN2js4MoveINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEENS_7MoveRefIT_EERS6_","__ZN2js7MoveRefINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEC1ERS4_","__ZN2js4MoveINS_8WatchKeyEEENS_7MoveRefIT_EERKS3_","__ZN2js4MoveINS_10WatchpointEEENS_7MoveRefIT_EERS3_","__ZN2js7MoveRefINS_10WatchpointEEC1ERS1_","__ZN2js7MoveRefINS_8WatchKeyEEC1ERS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeERNS0_14HashTableEntryIS5_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEE7setFreeEv","__ZN2js12HashMapEntryINS_8WatchKeyENS_10WatchpointEEaSERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11createTableERS9_j","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E13findFreeEntryEj","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEEEEEENS_7MoveRefIT_EERS9_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4EnumC2ISA_EERT_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6removeENSC_3PtrE","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE12lookupForAddERKS1_","__ZN2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS1_S2_EENS6_13MapHashPolicyES5_E6AddPtrERKS1_RKS2_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrEPPS5_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3addERNSC_6AddPtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E12lookupForAddERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E11prepareHashERKS3_","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_jj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC1ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6AddPtrC2ERNS0_14HashTableEntryIS5_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E5matchERNS0_14HashTableEntryIS5_EERKS3_","__ZN2js13DefaultHasherINS_8WatchKeyEE4hashERKS1_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E10isLiveHashEj","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E4initEj","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E6lookupERKS3_","__ZN2js6detail9HashTableINS_12HashMapEntryINS_8WatchKeyENS_10WatchpointEEENS_7HashMapIS3_S4_NS_13DefaultHasherIS3_EENS_17SystemAllocPolicyEE13MapHashPolicyES9_E3PtrC1ERNS0_14HashTableEntryIS5_EE","__ZN15AutoEntryHolderD2Ev","__ZNK2js7HashMapINS_8WatchKeyENS_10WatchpointENS_13DefaultHasherIS1_EENS_17SystemAllocPolicyEE10generationEv","__ZN15AutoEntryHolderC2ERN2js7HashMapINS0_8WatchKeyENS0_10WatchpointENS0_13DefaultHasherIS2_EENS0_17SystemAllocPolicyEEENS0_6detail9HashTableINS0_12HashMapEntryIS2_S3_EENS7_13MapHashPolicyES6_E3PtrE","__ZN2js11WeakMapBase18markAllIterativelyEP8JSTracer","__ZN2js11WeakMapBase8sweepAllEP8JSTracer","__ZL16WeakMap_finalizeP9JSContextP8JSObject","__ZL12WeakMap_markP8JSTracerP8JSObject","__ZL11WeakMap_hasP9JSContextjPN2JS5ValueE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr7nonNullEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash1Ejj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5hash2Ejjj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10isLiveHashEj","__ZN2js2gcL15GetGCObjectKindEjb4109","__ZNK8JSObject9isWeakMapEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrptEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrdeEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9isRemovedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10overloadedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setLiveEj","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isFreeEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16setTableSizeLog2Ej","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE14unsetCollisionEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10getKeyHashEv","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC2ERS9_","__ZNK2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEptEv","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2ERS6_","__ZNK2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEptEv","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC2Ev","__ZL11WeakMap_getP9JSContextjPN2JS5ValueE","__ZL14WeakMap_deleteP9JSContextjPN2JS5ValueE","__ZL11WeakMap_setP9JSContextjPN2JS5ValueE","__Z19js_InitWeakMapClassP9JSContextP8JSObject","__ZL17WeakMap_constructP9JSContextjPN2JS5ValueE","__ZN2JSL14UndefinedValueEv4098","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4108","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4110","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4111","__ZL13NonNullObjectP9JSContextPN2JS5ValueE","__ZL12GetObjectMapP8JSObject","__ZN9JSContext4new_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEPS_EEPT_T0_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE4initEj","__ZN9JSContext7delete_IN2js7WeakMapIP8JSObjectN2JS5ValueENS1_13DefaultHasherIS4_EENS1_17DefaultMarkPolicyIS4_S6_EEEEEEvPT_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3putERKS2_RKS4_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE12lookupForAddERKS2_","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrcvMSF_FvvEEv","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3addERNS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E6AddPtrERKS2_RKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrEPPS7_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3addERNSE_6AddPtrE","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E15changeTableSizeEi","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E13findFreeEntryEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11createTableERSB_j","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE6isLiveEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEaSENS_7MoveRefIS8_EE","__ZN2js4MoveINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEENS_7MoveRefIT_EERSB_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12destroyTableERSB_PNS0_14HashTableEntryIS7_EEj","__ZN2js7MoveRefINS_6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEEEC1ERS9_","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSENS_7MoveRefIS5_EE","__ZN2js4MoveINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEENS_7MoveRefIT_EERS8_","__ZN2js7MoveRefINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1ERS6_","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC1Ev","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEEC2Ev","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEC1Ev","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3Ptr5foundEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E12lookupForAddERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11prepareHashERKS4_","__ZN9JSWrapper16getWrapperFamilyEv","__ZN9JSWrapperD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC2ERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE9matchHashEj","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12setCollisionEj","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE13MapHashPolicy6getKeyERNS_12HashMapEntryIS2_S4_EE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5emptyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range5frontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E11underloadedEv","__ZNK2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE12hasCollisionEv","__ZN2js12HashMapEntryIP8JSObjectN2JS5ValueEEaSERKS5_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC2EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC2ESB_","__ZN2js14JSProxyHandler6familyEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_jj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC1ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6AddPtrC2ERNS0_14HashTableEntryIS7_EEj","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5matchERNS0_14HashTableEntryIS7_EERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E10isLiveHashEj","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED1Ev","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEED2Ev","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_ED2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4initEj","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC1EP9JSContext","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEEC2EP9JSContext","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEEC2ES7_","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15nonMarkingTraceEP8JSTracer","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE15markIterativelyEP8JSTracer","__ZN2js7WeakMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_17DefaultMarkPolicyIS2_S4_EEE5sweepEP8JSTracer","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEEC1EP8JSTracer","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC1INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9keyMarkedES2_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4Enum11removeFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5Range8popFrontEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD1Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumD2Ev","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E16checkUnderloadedEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeERNS0_14HashTableEntryIS7_EE","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE10setRemovedEv","__ZN2js6detail14HashTableEntryINS_12HashMapEntryIP8JSObjectN2JS5ValueEEEE7setFreeEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E4EnumC2INS_7WeakMapIS4_S6_SA_NS_17DefaultMarkPolicyIS4_S6_EEEEEERT_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE3allEv","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3allEv","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC1EPNS0_14HashTableEntryIS7_EESI_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E5RangeC2EPNS0_14HashTableEntryIS7_EESI_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE15markEntryIfLiveES2_RKS4_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE17markUnmarkedValueERKS4_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE18overrideKeyMarkingES2_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE11valueMarkedERKS4_","__ZN2js17DefaultMarkPolicyIP8JSObjectN2JS5ValueEE9markEntryERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_EC1ESB_","__ZNK2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6lookupERKS2_","__ZN2js7HashMapIP8JSObjectN2JS5ValueENS_13DefaultHasherIS2_EENS_18RuntimeAllocPolicyEE6removeENS_6detail9HashTableINS_12HashMapEntryIS2_S4_EENS8_13MapHashPolicyES7_E3PtrE","__ZN2JSL12BooleanValueEb4125","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6removeENSE_3PtrE","__ZNK2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E6lookupERKS4_","__ZN2js6detail9HashTableINS_12HashMapEntryIP8JSObjectN2JS5ValueEEENS_7HashMapIS4_S6_NS_13DefaultHasherIS4_EENS_18RuntimeAllocPolicyEE13MapHashPolicyESB_E3PtrC1ERNS0_14HashTableEntryIS7_EE","__ZNK8JSObject9isWrapperEv","__ZNK8JSObject25isCrossCompartmentWrapperEv","__ZNK8JSObject17getWrapperHandlerEv","__ZN8JSObject6unwrapEPj","__ZN9JSWrapperC2Ej","__ZN9JSWrapperD0Ev","__ZN9JSWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN9JSWrapper13wrappedObjectEPK8JSObject","__ZN9JSWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZL24GetOwnPropertyDescriptorP9JSContextP8JSObjectijP20JSPropertyDescriptor","__ZN9JSWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN9JSWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper7delete_EP9JSContextP8JSObjectiPb","__ZL14ValueToBooleanPN2JS5ValueEPb","__ZN9JSWrapper5enterEP9JSContextP8JSObjectiNS_6ActionEPb","__ZN9JSWrapper5leaveEP9JSContextP8JSObject","__ZL4CondiPb","__ZN2js10ForceFrameC2EP9JSContextP8JSObject","__ZN9JSWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper3fixEP9JSContextP8JSObjectPN2JS5ValueE","__ZN9JSWrapper3hasEP9JSContextP8JSObjectiPb","__ZN9JSWrapper6hasOwnEP9JSContextP8JSObjectiPb","__ZN9JSWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN9JSWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN9JSWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN9JSWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN9JSWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN9JSWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_","__ZN9JSWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN9JSWrapper6typeOfEP9JSContextP8JSObject","__ZN2JSL11ObjectValueER8JSObject4137","__ZN9JSWrapper12obj_toStringEP9JSContextP8JSObject","__ZN9JSWrapper12fun_toStringEP9JSContextP8JSObjectj","__ZN9JSWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2jsL11ToPrimitiveEP9JSContextPN2JS5ValueE4138","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4139","__ZN9JSWrapper5traceEP8JSTracerP8JSObject","__ZN9JSWrapper14wrapperHandlerEPK8JSObject","__ZN9JSWrapper3NewEP9JSContextP8JSObjectS3_S3_PS_","_TransparentObjectWrapper","__ZN2js10ForceFrameD2Ev","__ZN9JSContext7delete_IN2js15DummyFrameGuardEEEvPT_","__ZN2js10ForceFrame5enterEv","__ZN9JSContext4new_IN2js15DummyFrameGuardEEEPT_v","__ZN2js15AutoCompartmentC2EP9JSContextP8JSObject","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC1Ev","__ZN2js15AutoCompartmentD2Ev","__ZN2js15AutoCompartment5leaveEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEED1Ev","__ZN2js15AutoCompartment5enterEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE9constructEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3refEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE7destroyEv","__ZN2js11ErrorCopierD2Ev","__ZN25JSCrossCompartmentWrapperC2Ej","__ZN25JSCrossCompartmentWrapperD0Ev","__ZN25JSCrossCompartmentWrapper21getPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper24getOwnPropertyDescriptorEP9JSContextP8JSObjectibP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper14definePropertyEP9JSContextP8JSObjectiP20JSPropertyDescriptor","__ZN2js28AutoPropertyDescriptorRooterC1EP9JSContextP20JSPropertyDescriptor","__ZN25JSCrossCompartmentWrapper19getOwnPropertyNamesEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN7mozilla15AlignedStorage2IN2js15DummyFrameGuardEE4addrEv","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEEC2Ev","__ZN17AutoCloseIterator5clearEv","__ZN17AutoCloseIteratorC2EP9JSContextP8JSObject","_JS_XDRInitBase","_JS_XDRMemGetData","_JS_XDRMemSetData","_JS_XDRMemDataLeft","_JS_XDRMemResetData","__ZN25JSCrossCompartmentWrapper7delete_EP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper9enumerateEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN25JSCrossCompartmentWrapper3hasEP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper6hasOwnEP9JSContextP8JSObjectiPb","__ZN25JSCrossCompartmentWrapper3getEP9JSContextP8JSObjectS3_iPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper3setEP9JSContextP8JSObjectS3_ibPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper4keysEP9JSContextP8JSObjectRN2js12AutoIdVectorE","__ZN25JSCrossCompartmentWrapper7iterateEP9JSContextP8JSObjectjPN2JS5ValueE","__ZL8CanReifyPN2JS5ValueE","__ZL5ReifyP9JSContextP13JSCompartmentPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper4callEP9JSContextP8JSObjectjPN2JS5ValueE","__ZN25JSCrossCompartmentWrapper9constructEP9JSContextP8JSObjectjPN2JS5ValueES6_","__ZN25JSCrossCompartmentWrapper11hasInstanceEP9JSContextP8JSObjectPKN2JS5ValueEPb","__ZN25JSCrossCompartmentWrapper12obj_toStringEP9JSContextP8JSObject","__ZN25JSCrossCompartmentWrapper12fun_toStringEP9JSContextP8JSObjectj","__ZN25JSCrossCompartmentWrapper12defaultValueEP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN25JSCrossCompartmentWrapper5traceEP8JSTracerP8JSObject","__ZN2js15DummyFrameGuardD1Ev","__ZN2js15DummyFrameGuardD2Ev","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEE3asTEv","__ZN2js15DummyFrameGuardC1Ev","__ZN2js15DummyFrameGuardC2Ev","__ZN7mozilla5MaybeIN2js15DummyFrameGuardEED2Ev","__ZN17AutoCloseIteratorC1EP9JSContextP8JSObject","__ZNK2js14NativeIterator7numKeysEv","__ZN17AutoCloseIteratorD1Ev","__ZN17AutoCloseIteratorD2Ev","__ZN2js28AutoPropertyDescriptorRooterC2EP9JSContextP20JSPropertyDescriptor","_JS_XDRNewMem","_JS_XDRDestroy","_JS_XDRUint8","_JS_XDRUint32","_JS_XDRUint16","__ZN2js14XDRScriptStateC2EP10JSXDRState","_JS_XDRBytes","_JS_XDRCString","_JS_XDRCStringOrNull","_JS_XDRString","__ZL8XDRCharsP10JSXDRStatePtj","_JS_XDRStringOrNull","_JS_XDRDouble","__ZL14XDRDoubleValueP10JSXDRStatePd","_JS_XDRValue","__ZL9GetXDRTagN2JS5ValueE","__ZL12XDRValueBodyP10JSXDRStatejPN2JS5ValueE","_js_XDRAtom","__ZN2js14XDRScriptStateD2Ev","_JS_XDRScript","_JS_XDRRegisterClass","_JSVAL_TO_INT32_IMPL4206","_JSVAL_TO_BOOLEAN_IMPL4209","_JSVAL_TO_OBJECT_IMPL4211","_JSVAL_TO_STRING_IMPL4213","_JSVAL_IS_STRING_IMPL4216","_JSVAL_IS_DOUBLE_IMPL4217","_JSVAL_IS_INT32_IMPL4218","_JSVAL_IS_OBJECT_OR_NULL_IMPL4219","_JSVAL_IS_UNDEFINED_IMPL4220","_JSVAL_IS_NULL_IMPL4221","_JS_XDRFindClassById","__ZL13IMPL_TO_JSVAL12jsval_layout4204","_INT32_TO_JSVAL_IMPL4205","__ZL13JSVAL_TO_IMPLN2JS5ValueE4207","_BOOLEAN_TO_JSVAL_IMPL4208","_OBJECT_TO_JSVAL_IMPL4210","_STRING_TO_JSVAL_IMPL4212","__ZL8mem_tellP10JSXDRState","_JS_XDRFindClassIdByName","_JSVAL_TO_STRING4194","_STRING_TO_JSVAL4195","_JSVAL_TO_DOUBLE4196","_DOUBLE_TO_JSVAL4197","_JSVAL_TO_OBJECT4198","_OBJECT_TO_JSVAL4199","_JSVAL_TO_BOOLEAN4200","_BOOLEAN_TO_JSVAL4201","_JSVAL_TO_INT4202","_INT_TO_JSVAL4203","_JSVAL_IS_NULL","_JSVAL_IS_VOID","_JSVAL_IS_OBJECT","_JSVAL_IS_INT","_JSVAL_IS_DOUBLE4214","_JSVAL_IS_STRING4215","__ZL9mem_get32P10JSXDRStatePj","__ZL9mem_set32P10JSXDRStatePj","__ZL12mem_getbytesP10JSXDRStatePcj","__ZL12mem_setbytesP10JSXDRStatePcj","__ZL7mem_rawP10JSXDRStatej","__ZL8mem_seekP10JSXDRStatei11JSXDRWhence","__ZL12mem_finalizeP10JSXDRState","__ZL18namespace_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL18namespace_toStringP9JSContextjPN2JS5ValueE","__ZL14qname_equalityP9JSContextP8JSObjectPKN2JS5ValueEPi","_JSID_IS_OBJECT4314","_JSID_TO_OBJECT4315","__ZNK8JSObject7isQNameEv","__ZN16JSXMLArrayCursor10disconnectEv","__ZL14qname_toStringP9JSContextjPN2JS5ValueE","__Z26js_ConstructXMLQNameObjectP9JSContextRKN2JS5ValueES4_","__Z12js_IsXMLNameP9JSContextN2JS5ValueE","_JSVAL_IS_PRIMITIVE4303","_JSVAL_TO_OBJECT4304","__ZNK8JSObject17getQNameLocalNameEv","__ZL9IsXMLNamePKtj","__ZN16JSXMLArrayCursor5traceEP8JSTracer","__ZN10JSXMLArray11setCapacityEP9JSContextj","__ZN10JSXMLArray4trimEv","__ZN10JSXMLArray6finishEP9JSContext","__Z32js_GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext","__ZL29GetLocalNameFromFunctionQNameP8JSObjectPiP9JSContext","__Z11xml_convertP9JSContextP8JSObject6JSTypePN2JS5ValueE","__ZN2JS6AnchorIP8JSObjectEC1ES2_","__ZL19xml_toString_helperP9JSContextP5JSXML","__ZN2JSL11StringValueEP8JSString4311","__Z15js_GetXMLMethodP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14GetXMLFunctionP9JSContextP8JSObjectiPN2JS5ValueE","__Z18js_TestXMLEqualityP9JSContextRKN2JS5ValueES4_Pi","__ZL6EqualsP9JSContextP5JSXMLN2JS5ValueEPi","_OBJECT_TO_JSVAL4318","__ZL15xml_hasInstanceP9JSContextP8JSObjectPKN2JS5ValueEPi","__ZL16HasSimpleContentP5JSXML","__ZN2JSL11ObjectValueER8JSObject4319","__ZL9XMLEqualsP9JSContextP5JSXMLS2_Pi","_JSVAL_IS_STRING4320","_JSVAL_IS_NUMBER","_JSVAL_TO_STRING4321","_STRING_TO_JSVAL4322","_JSVAL_IS_INT4323","_JSVAL_TO_INT4324","_JSVAL_TO_DOUBLE4325","__Z17js_ConcatenateXMLP9JSContextP8JSObjectS2_PN2JS5ValueE","__Z15js_NewXMLObjectP9JSContext10JSXMLClass","__ZL6AppendP9JSContextP5JSXMLS2_","__ZL12xml_finalizeP9JSContextP8JSObject","__ZL9xml_traceP8JSTracerP8JSObject","__ZL18xml_lookupPropertyP9JSContextP8JSObjectiPS2_PP10JSProperty","__ZL17xml_lookupElementP9JSContextP8JSObjectjPS2_PP10JSProperty","__ZL17xml_lookupSpecialP9JSContextP8JSObjectN2js9SpecialIdEPS2_PP10JSProperty","__ZL18xml_definePropertyP9JSContextP8JSObjectiPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL17xml_defineElementP9JSContextP8JSObjectjPKN2JS5ValueEPFiS0_S2_iPS4_EPFiS0_S2_iiS7_Ej","__ZL17xml_defineSpecialP9JSContextP8JSObjectN2js9SpecialIdEPKN2JS5ValueEPFiS0_S2_iPS6_EPFiS0_S2_iiS9_Ej","__ZL14xml_getGenericP9JSContextP8JSObjectS2_iPN2JS5ValueE","__ZL15xml_getPropertyP9JSContextP8JSObjectS2_PN2js12PropertyNameEPN2JS5ValueE","__ZL14xml_getElementP9JSContextP8JSObjectS2_jPN2JS5ValueE","__ZL14xml_getSpecialP9JSContextP8JSObjectS2_N2js9SpecialIdEPN2JS5ValueE","__ZL15xml_setPropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL14xml_setElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL14xml_setSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL17xml_getAttributesP9JSContextP8JSObjectiPj","__ZL24xml_getElementAttributesP9JSContextP8JSObjectjPj","__ZL24xml_getSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL17xml_setAttributesP9JSContextP8JSObjectiPj","__ZL24xml_setElementAttributesP9JSContextP8JSObjectjPj","__ZL24xml_setSpecialAttributesP9JSContextP8JSObjectN2js9SpecialIdEPj","__ZL10xml_typeOfP9JSContextP8JSObject","__ZL7xml_fixP9JSContextP8JSObjectPbPN2js12AutoIdVectorE","__ZL9xml_clearP9JSContextP8JSObject","__ZL18xml_deletePropertyP9JSContextP8JSObjectiPN2JS5ValueEi","__ZL17xml_deleteElementP9JSContextP8JSObjectjPN2JS5ValueEi","__ZL17xml_deleteSpecialP9JSContextP8JSObjectN2js9SpecialIdEPN2JS5ValueEi","__ZL13xml_enumerateP9JSContextP8JSObject11JSIterateOpPN2JS5ValueEPi","__ZL16xml_addNamespaceP9JSContextjPN2JS5ValueE","__ZL15xml_appendChildP9JSContextjPN2JS5ValueE","__ZL13xml_attributeP9JSContextjPN2JS5ValueE","__ZL14xml_attributesP9JSContextjPN2JS5ValueE","__ZL9xml_childP9JSContextjPN2JS5ValueE","__ZL14xml_childIndexP9JSContextjPN2JS5ValueE","__ZL12xml_childrenP9JSContextjPN2JS5ValueE","__ZL12xml_commentsP9JSContextjPN2JS5ValueE","__ZL12xml_containsP9JSContextjPN2JS5ValueE","__ZL8xml_copyP9JSContextjPN2JS5ValueE","__ZL15xml_descendantsP9JSContextjPN2JS5ValueE","__ZL12xml_elementsP9JSContextjPN2JS5ValueE","__ZL18xml_hasOwnPropertyP9JSContextjPN2JS5ValueE","__ZL21xml_hasComplexContentP9JSContextjPN2JS5ValueE","__ZL20xml_hasSimpleContentP9JSContextjPN2JS5ValueE","__ZL21xml_inScopeNamespacesP9JSContextjPN2JS5ValueE","__ZL20xml_insertChildAfterP9JSContextjPN2JS5ValueE","__ZL21xml_insertChildBeforeP9JSContextjPN2JS5ValueE","__ZL10xml_lengthP9JSContextjPN2JS5ValueE","__ZL13xml_localNameP9JSContextjPN2JS5ValueE","__ZL8xml_nameP9JSContextjPN2JS5ValueE","__ZL13xml_namespaceP9JSContextjPN2JS5ValueE","__ZL25xml_namespaceDeclarationsP9JSContextjPN2JS5ValueE","__ZL12xml_nodeKindP9JSContextjPN2JS5ValueE","__ZL13xml_normalizeP9JSContextjPN2JS5ValueE","__ZL10xml_parentP9JSContextjPN2JS5ValueE","__ZL26xml_processingInstructionsP9JSContextjPN2JS5ValueE","__ZL16xml_prependChildP9JSContextjPN2JS5ValueE","__ZL24xml_propertyIsEnumerableP9JSContextjPN2JS5ValueE","__ZL19xml_removeNamespaceP9JSContextjPN2JS5ValueE","__ZL11xml_replaceP9JSContextjPN2JS5ValueE","__ZL15xml_setChildrenP9JSContextjPN2JS5ValueE","__ZL16xml_setLocalNameP9JSContextjPN2JS5ValueE","__ZL11xml_setNameP9JSContextjPN2JS5ValueE","__ZN10JSXMLArray4initEv","__ZL16xml_setNamespaceP9JSContextjPN2JS5ValueE","__ZL8xml_textP9JSContextjPN2JS5ValueE","__ZL12xml_toSourceP9JSContextjPN2JS5ValueE","__ZL12xml_toStringP9JSContextjPN2JS5ValueE","__ZL15xml_toXMLStringP9JSContextjPN2JS5ValueE","__ZL11xml_valueOfP9JSContextjPN2JS5ValueE","__ZL12xml_settingsP9JSContextjPN2JS5ValueE","__ZL15xml_setSettingsP9JSContextjPN2JS5ValueE","__ZL19xml_defaultSettingsP9JSContextjPN2JS5ValueE","__Z9js_NewXMLP9JSContext10JSXMLClass","_js_TraceXML","__ZL16xml_trace_vectorP8JSTracerPP5JSXMLj","__ZL19XMLArrayCursorTraceP8JSTracerP16JSXMLArrayCursor","__ZN2js13AutoXMLRooterC1EP9JSContextP5JSXML","__Z15js_GetXMLObjectP9JSContextP5JSXML","__ZN2js13AutoXMLRooterD1Ev","__ZL12NewXMLObjectP9JSContextP5JSXML","__Z21js_InitNamespaceClassP9JSContextP8JSObject","__ZN8JSObject13setNamePrefixEP14JSLinearString","__ZN8JSObject10setNameURIEP14JSLinearString","__ZL9NamespaceP9JSContextjPN2JS5ValueE","__Z17js_InitQNameClassP9JSContextP8JSObject","__ZL12InitXMLQNameP9JSContextP8JSObjectP14JSLinearStringS4_P6JSAtom","__ZL5QNameP9JSContextjPN2JS5ValueE","__Z15js_InitXMLClassP9JSContextP8JSObject","__ZL3XMLP9JSContextjPN2JS5ValueE","_OBJECT_TO_JSID4356","__ZL21SetDefaultXMLSettingsP9JSContextP8JSObject","__ZL7XMLListP9JSContextjPN2JS5ValueE","__ZL12ATOM_TO_JSIDP6JSAtom4336","__ZL13xml_isXMLNameP9JSContextjPN2JS5ValueE","__Z17js_InitXMLClassesP9JSContextP8JSObject","__ZN2js12GlobalObject20getFunctionNamespaceEP9JSContextPN2JS5ValueE","__ZL15NewXMLNamespaceP9JSContextP14JSLinearStringS2_i","__Z25js_GetDefaultXMLNamespaceP9JSContextPN2JS5ValueE","__ZN8JSObject10getSpecialEP9JSContextN2js9SpecialIdEPN2JS5ValueE","__ZN2js9SpecialId19defaultXMLNamespaceEv","__Z25js_SetDefaultXMLNamespaceP9JSContextRKN2JS5ValueE","__Z18js_ToAttributeNameP9JSContextPN2JS5ValueE","__ZL15ToAttributeNameP9JSContextN2JS5ValueE","__Z23js_EscapeAttributeValueP9JSContextP8JSStringi","__ZL20EscapeAttributeValueP9JSContextRN2js12StringBufferEP8JSStringi","__Z19js_AddAttributePartP9JSContextiP8JSStringS2_","__Z21js_EscapeElementValueP9JSContextP8JSString","__ZL18EscapeElementValueP9JSContextRN2js12StringBufferEP8JSStringj","__Z19js_ValueToXMLStringP9JSContextRKN2JS5ValueE","__ZL11ToXMLStringP9JSContextN2JS5ValueEj","__Z13js_GetAnyNameP9JSContextPi","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE1EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4355","_JSID_IS_VOID4359","__ZN16JSXMLArrayCursor7getNextEv","__Z18js_FindXMLPropertyP9JSContextRKN2JS5ValueEPP8JSObjectPi","__ZL16HasNamedPropertyP5JSXMLP8JSObject","__ZL19HasFunctionPropertyP9JSContextP8JSObjectiPi","__ZL20ConvertQNameToStringP9JSContextP8JSObject","__Z20js_GetXMLDescendantsP9JSContextP8JSObjectN2JS5ValueEPS4_","__ZL10GetPrivateP9JSContextP8JSObjectPKc","__ZL11DescendantsP9JSContextP5JSXMLN2JS5ValueE","__Z24js_DeleteXMLListElementsP9JSContextP8JSObject","__ZL17DeleteListElementP9JSContextP5JSXMLj","__ZL18xmlfilter_finalizeP9JSContextP8JSObject","__ZL15xmlfilter_traceP8JSTracerP8JSObject","__Z20js_StepXMLListFilterP9JSContexti","__ZN2jsL22GetGlobalForScopeChainEP9JSContext4366","__ZN9JSContext4new_I11JSXMLFilterP5JSXMLP10JSXMLArrayEEPT_T0_T1_","__Z19js_ValueToXMLObjectP9JSContextRKN2JS5ValueE","__ZN16JSXMLArrayCursorC2EP10JSXMLArray","__ZN2JS6AnchorIP8JSObjectEC2ES2_","__ZN2js2gcL15GetGCObjectKindEjb4379","__ZNK8JSString5emptyEv","__ZL5ToXMLP9JSContextN2JS5ValueE","__Z23js_ValueToXMLListObjectP9JSContextRKN2JS5ValueE","__ZL9ToXMLListP9JSContextN2JS5ValueE","__Z22js_NewXMLSpecialObjectP9JSContext10JSXMLClassP8JSStringS3_","__ZL18GetXMLSettingFlagsP9JSContextPj","__ZL11NewXMLQNameP9JSContextP14JSLinearStringS2_P6JSAtom","__Z21js_MakeXMLCDATAStringP9JSContextP8JSString","__ZL18MakeXMLCDATAStringP9JSContextRN2js12StringBufferEP8JSString","__Z23js_MakeXMLCommentStringP9JSContextP8JSString","__ZL20MakeXMLCommentStringP9JSContextRN2js12StringBufferEP8JSString","__Z18js_MakeXMLPIStringP9JSContextP8JSStringS2_","__ZL15MakeXMLPIStringP9JSContextRN2js12StringBufferEP8JSStringS5_","__ZN11JSXMLFilterC1EP5JSXMLP10JSXMLArray","__ZN11JSXMLFilterC2EP5JSXMLP10JSXMLArray","__ZN16JSXMLArrayCursorC1EP10JSXMLArray","__ZN2js6detailL9NewObjectILb1ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4380","__ZN2jsL18InitScopeForObjectEP9JSContextP8JSObjectPNS_5ClassEPNS_5types10TypeObjectENS_2gc9AllocKindE4383","__ZL20MakeXMLSpecialStringP9JSContextRN2js12StringBufferEP8JSStringS5_PKtjS7_j","__ZL26NewBuiltinClassInstanceXMLP9JSContextPN2js5ClassE","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassE4392","__ZN2jsL23NewBuiltinClassInstanceEP9JSContextPNS_5ClassENS_2gc9AllocKindE4393","__ZN2jsL22NewNativeClassInstanceEP9JSContextPNS_5ClassEP8JSObjectS5_NS_2gc9AllocKindE4394","__ZL20GetBooleanXMLSettingP9JSContextPKcPi","__ZL13GetXMLSettingP9JSContextPKcPN2JS5ValueE","_JSVAL_IS_NULL4395","_JSVAL_IS_VOID4396","__ZL14ParseXMLSourceP9JSContextP8JSString","__ZL14OrphanXMLChildP9JSContextP5JSXMLj","__ZL17XMLArrayAddMemberP9JSContextP10JSXMLArrayjPv","__ZN8JSObject20setNamespaceDeclaredEN2JS5ValueE","__ZNK8JSObject10getNameURIEv","__ZN2js18AutoNamespaceArrayC1EP9JSContext","__ZL12IS_XML_CHARSPKt","__ZL16HAS_NS_AFTER_XMLPKt","__ZL14ParseNodeToXMLPN2js6ParserEP11JSParseNodeP10JSXMLArrayj","__ZN2js18AutoNamespaceArrayD1Ev","__ZN2js18AutoNamespaceArrayD2Ev","__ZL18ChompXMLWhitespaceP9JSContextP8JSString","__ZL16XMLArrayTruncateP9JSContextP10JSXMLArrayj","__ZL18XMLArrayFindMemberPK10JSXMLArrayPvPFiPKvS4_E","__ZL18namespace_identityPKvS0_","_JSVAL_TO_STRING_IMPL4397","_JSVAL_IS_UNDEFINED_IMPL4398","_JSVAL_IS_NULL_IMPL4400","_JSID_IS_INT4401","_JSID_TO_INT4402","_JSID_IS_STRING4403","_JSID_TO_STRING4405","_JS_ASSERT_STRING_IS_FLAT","__ZL13JSVAL_TO_IMPLN2JS5ValueE4399","__ZL14XMLArrayDeleteP9JSContextP10JSXMLArrayji","__ZN2js16AutoObjectRooter9setObjectEP8JSObject","__ZL16ParseNodeToQNamePN2js6ParserEP11JSParseNodeP10JSXMLArrayi","__ZNK8JSObject13getNamePrefixEv","__ZN2js18AutoNamespaceArrayC2EP9JSContext","__ZN9JSContext7delete_I11JSXMLFilterEEvPT_","__ZN11JSXMLFilterD1Ev","__ZN11JSXMLFilterD2Ev","__ZN16JSXMLArrayCursorD1Ev","__ZN16JSXMLArrayCursorD2Ev","__ZL19DeleteNamedPropertyP9JSContextP5JSXMLP8JSObjecti","__ZL13DeleteByIndexP9JSContextP5JSXMLj","__ZL13MatchAttrNameP8JSObjectP5JSXML","__ZL13MatchElemNameP8JSObjectP5JSXML","__ZL9ToXMLNameP9JSContextN2JS5ValueEPi","__ZL17DescendantsHelperP9JSContextP5JSXMLP8JSObjectS2_","__ZL16ReportBadXMLNameP9JSContextRKN2JS5ValueE","__ZN2JSL14UndefinedValueEv4406","_JSVAL_IS_BOOLEAN4407","__ZN2jsL11ToPrimitiveEP9JSContext6JSTypePN2JS5ValueE4408","__ZNK2js18AutoNamespaceArray6lengthEv","__ZL14XMLToXMLStringP9JSContextP5JSXMLPK10JSXMLArrayj","__ZL10IsDeclaredPK8JSObject","__ZL12GetNamespaceP9JSContextP8JSObjectPK10JSXMLArray","__ZN2jsL17SPECIALID_TO_JSIDERKNS_9SpecialIdE4414","__ZL14JSID_FROM_BITSj4418","_JSVAL_IS_PRIMITIVE_IMPL4409","_JSVAL_IS_BOOLEAN_IMPL4410","_JSVAL_IS_STRING_IMPL4412","_MAGIC_JSVAL_TO_OBJECT_OR_NULL_IMPL","_STRING_TO_JSVAL_IMPL4413","__ZN2js9SpecialIdC2Ej","__ZL13IMPL_TO_JSVAL12jsval_layout4416","_BOOLEAN_TO_JSVAL_IMPL4417","_INT32_TO_JSVAL_IMPL4422","__ZL14GeneratePrefixP9JSContextP14JSLinearStringP10JSXMLArray","__ZL15namespace_matchPKvS0_","__ZL20AppendAttributeValueP9JSContextRN2js12StringBufferEP8JSString","__ZL19GetUint32XMLSettingP9JSContextPKcPj","__ZNK8JSObject20getNamespaceDeclaredEv","__ZL19NewXMLAttributeNameP9JSContextP14JSLinearStringS2_P6JSAtom","__ZN2js9SpecialIdC1Ej","_BOOLEAN_TO_JSVAL4415","__ZN2jsL14IsConstructingEPKN2JS5ValueE4419","_INT_TO_JSVAL4421","__ZL8DeepCopyP9JSContextP5JSXMLP8JSObjectj","__ZL13DeepCopyInLRSP9JSContextP5JSXMLj","__ZL16DeepCopySetInLRSP9JSContextP10JSXMLArrayS2_P5JSXMLj","__ZN2jsL42IsConstructing_PossiblyWithGivenThisObjectEPKN2JS5ValueEPP8JSObject","__ZL11QNameHelperP9JSContextP8JSObjectiPN2JS5ValueES5_","__ZNK8JSObject20getQNameLocalNameValEv","__ZNK2JS5Value27getMagicObjectOrNullPayloadEv","__ZN8JSObject17setQNameLocalNameEP6JSAtom","__ZN2jsL16GetClassProtoKeyEPNS_5ClassE4430","__ZL19QNameNameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL21QNameLocalName_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK8JSObject13getNameURIValEv","__ZL17NamePrefix_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZL14NameURI_getterP9JSContextP8JSObjectiPN2JS5ValueE","__ZNK8JSObject16getNamePrefixValEv","__ZL15NamespaceHelperP9JSContextP8JSObjectiPN2JS5ValueES5_","__ZN8JSObject15clearNamePrefixEv","__ZN2jsL14NewNonFunctionILNS_9WithProto1eE0EEEP8JSObjectP9JSContextPNS_5ClassES4_S4_4427","__ZN2js6detailL9NewObjectILb0ELb0EEEP8JSObjectP9JSContextPNS_5ClassES3_S3_NS_2gc9AllocKindE4428","__ZN2jsL9FindProtoEP9JSContextPNS_5ClassEP8JSObjectPS5_4429","__ZN2js13AutoXMLRooterD2Ev","__ZN2js13AutoXMLRooterC2EP9JSContextP5JSXML","__ZL15CopyXMLSettingsP9JSContextP8JSObjectS2_","__ZL15xml_text_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE","__ZL15xml_list_helperP9JSContextP5JSXMLPN2JS5ValueE","__ZL21StartNonListXMLMethodP9JSContextPN2JS5ValueEPP8JSObject","__ZL11CopyOnWriteP9JSContextP5JSXMLP8JSObject","__ZL19AddInScopeNamespaceP9JSContextP5JSXMLP8JSObject","__ZL11PutPropertyP9JSContextP8JSObjectiiPN2JS5ValueE","__ZN16JSXMLArrayCursor10getCurrentEv","__ZN2jsL9IdToJsvalEi4431","__ZN2jsL9IdToValueEi4432","__ZL12ResolveValueP9JSContextP5JSXMLPS2_","__ZL11GetPropertyP9JSContextP8JSObjectiPN2JS5ValueE","__ZL6InsertP9JSContextP5JSXMLjN2JS5ValueE","__ZL7ReplaceP9JSContextP5JSXMLjN2JS5ValueE","__ZL14XMLArrayInsertP9JSContextP10JSXMLArrayjj","__ZL11KidToStringP9JSContextP5JSXMLj","__ZL10CheckCycleP9JSContextP5JSXMLS2_","__ZL16GetNamedPropertyP9JSContextP5JSXMLP8JSObjectS2_","__ZL21SyncInScopeNamespacesP9JSContextP5JSXML","__ZN2JSL10Int32ValueEi4433","_INT_TO_JSID4434","__ZL18HasIndexedPropertyP5JSXMLj","__ZL12IdValIsIndexP9JSContextN2JS5ValueEPjPb","__ZL26xml_removeNamespace_helperP9JSContextP5JSXMLP8JSObject","__ZL20namespace_full_matchPKvS0_","__ZL33xml_processingInstructions_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE","__ZL20xml_normalize_helperP9JSContextP8JSObjectP5JSXML","__ZL17NormalizingDeleteP9JSContextP5JSXMLj","__ZL19NamespacesToJSArrayP9JSContextP10JSXMLArrayPN2JS5ValueE","__ZL21FindInScopeNamespacesP9JSContextP5JSXMLP10JSXMLArray","_DOUBLE_TO_JSVAL4435","__ZL11HasPropertyP9JSContextP8JSObjectN2JS5ValueEPi","__ZL19xml_elements_helperP9JSContextP8JSObjectP5JSXMLS2_PN2JS5ValueE","_JSVAL_TO_INT32_IMPL4444","_INT_FITS_IN_JSID4436","_JSVAL_IS_SPECIFIC_INT32_IMPL","_JSID_IS_DEFAULT_XML_NAMESPACE4441","_JSVAL_IS_INT32_IMPL4445","_JSVAL_IS_NUMBER_IMPL4446","_JSVAL_TO_OBJECT_IMPL4449","_OBJECT_TO_JSVAL_IMPL4443","__ZNK8JSObject11isNamespaceEv","__ZL19xml_comments_helperP9JSContextP8JSObjectP5JSXMLPN2JS5ValueE","__ZL16xml_child_helperP9JSContextP8JSObjectP5JSXMLN2JS5ValueEPS6_","__ZL9ValueToIdP9JSContextN2JS5ValueEPN2js12AutoIdRooterE","__ZN9JSContext4new_I16JSXMLArrayCursorP10JSXMLArrayEEPT_T0_","__ZNK2JS5Value7isInt32Ei","__ZN9JSContext7delete_I16JSXMLArrayCursorEEvPT_","__ZN2JSL11DoubleValueEd4439","__ZL14xml_setGenericP9JSContextP8JSObjectiPN2JS5ValueEi","__ZN2jsL16IsFunctionObjectERKN2JS5ValueE4442","__ZL13attr_identityPKvS0_","__ZL14qname_identityP8JSObjectS0_","__Z15jsRegExpCompilePKti24JSRegExpIgnoreCaseOption23JSRegExpMultilineOptionPjPi","__ZN11CompileDataC1Ev","__ZL11returnError9ErrorCodePi","__ZL30calculateCompiledPatternLengthPKti24JSRegExpIgnoreCaseOptionR11CompileDataR9ErrorCode","__ZN2js11OffTheBooks9array_newIcEEPT_j","__ZL13compileBranchiPiPPhPPKtS3_P9ErrorCodeS_S_R11CompileData","__ZL13get2ByteValuePKh","__ZL13get3ByteValuePKh","__ZL13put2ByteValuePhi","__ZL8flipCaseh","__ZL22firstSignificantOpcodePKh","__ZL13put3ByteValuePhi","__ZL18classBitmapForCharh","__ZL10encodeUTF8iPh","__ZL14compileBracketiPiPPhPPKtS3_P9ErrorCodeiS_S_R11CompileData","__ZN2js10Foreground12array_deleteIcEEvPT_","__ZL17bracketIsAnchoredPKh","__ZL16branchIsAnchoredPKh","__ZL33bracketFindFirstAssertedCharacterPKhb","__ZL32branchFindFirstAssertedCharacterPKhb","__ZL21bracketNeedsLineStartPKhjj","__ZL20branchNeedsLineStartPKhjj","__Z12jsRegExpFreeP8JSRegExp","_js_free4455","_js_malloc4456","__ZL12getLinkValuePKh","__ZL21getLinkValueAllowZeroPKh","__ZL40firstSignificantOpcodeSkippingAssertionsPKh","__ZL21advanceToEndOfBracketRPKh","__ZL21putLinkValueAllowZeroPhi","__ZL12putLinkValuePhi","__ZL15isCountedRepeatPKtS0_","__ZL11checkEscapePPKtS0_P9ErrorCodeib","__ZL17getOthercaseRangePiiS_S_","__ZN3WTF12isASCIIDigitEt","__ZN3WTF15isASCIIHexDigitEt","__ZN3WTF12isASCIIAlphaEi","__ZN3WTF19isASCIIAlphanumericEi","__ZN3WTF12toASCIIUpperEi","__ZL25multiplyWithOverflowCheckii","__ZL19safelyCheckNextCharPKtS0_t","__ZN11CompileDataC2Ev","__ZL11toLowerCaseh","__ZL8flipCaseh4460","__ZL27tryRequiredByteOptimizationRPKtS0_iibbS1_","__ZL16readRepeatCountsPKtPiS1_P9ErrorCode","__ZL23put2ByteValueAndAdvanceRPhi","__ZL31putLinkValueAllowZeroAndAdvanceRPhi","__ZL22putLinkValueAndAdvanceRPhi","__Z15jsRegExpExecuteP9JSContextPK8JSRegExpPKtiiPii","__ZL24tryFirstByteOptimizationRPKtS0_ibbS0_","__ZL5matchP11JSArenaPoolPKtPKhiR9MatchData","__ZL9isNewlinet","__ZN2JS15PerfMeasurementD2Ev","__ZN2JS15PerfMeasurement5startEv","__ZN2JS15PerfMeasurement4stopEv","__ZN2JS15PerfMeasurement19canMeasureSomethingEv","__ZL13get2ByteValuePKh4462","__ZN3WTF12isASCIIDigitEi","__ZL13get3ByteValuePKh4465","__ZN10MatchFrame13startNewGroupEb","__ZN10LinearFlag12readAndClearEv","__ZN9MatchData13setOffsetPairEjii","__ZN10LinearFlag3setEv","__ZN10MatchFrame14restoreOffsetsEiiPii","__ZN10MatchFrame14clobberOffsetsEiiPii","__ZL38repeatInformationFromInstructionOffsetsRbRiS0_","__ZL29getUTF8CharAndIncrementLengthRiPKhS_","__ZL15charTypeForCharh","__ZN10MatchStack29canUseStackBufferForNextFrameEv","__ZN10MatchFrame4initEP11JSArenaPool","__ZN10MatchFrameC2Ev","__ZN10LinearFlagC2Ev","__Z22jsc_pcre_ucp_othercasej","__ZL28getUTF8CharAndAdvancePointerRiRPKh","__ZN10MatchStackC1EP11JSArenaPool","__ZN10LinearFlagC1Ev","__ZL10matchErroriR10MatchStack","__ZN10MatchFrame15extractBracketsEPKh","__ZN10MatchStack12pushNewFrameEPKhP16BracketChainNodei","__ZN10MatchStack15popCurrentFrameEv","__ZL12getLinkValuePKh4461","__ZL21advanceToEndOfBracketRPKh4463","__ZN10MatchFrame11saveOffsetsEiiPii","__ZL10isWordChart","__ZL11isSpaceChart","__ZL8matchRefiPKtiRK9MatchData","__ZN10MatchStackD1Ev","__ZN10MatchStackD2Ev","__ZL21getLinkValueAllowZeroPKh4464","__ZN2js10Foreground7delete_I10MatchFrameEEvPT_","_js_free4466","__ZN10MatchStack17allocateNextFrameEv","__ZN2js11OffTheBooks4new_I10MatchFrameEEPT_v","_js_malloc4467","__ZN10MatchFrameC1Ev","__ZN10MatchStack12popAllFramesEv","__ZN10MatchStackC2EP11JSArenaPool","__Z15jsc_pcre_xclassiPKh","__ZN2v88internal7ceilingEd","__ZN2v88internal2OS5AbortEv","__ZN2JS15PerfMeasurementC2ENS0_9EventMaskE","__ZN2JS15PerfMeasurement5resetEv","_PRMJ_LocalGMTDifference","__ZL16ComputeLocalTimelP2tm","__ZN14DSTOffsetCache11sanityCheckEv","__ZNK2v88internal6VectorIcE5startEv","_PRMJ_Now","_PRMJ_FormatTime","__ZN14DSTOffsetCache28computeDSTOffsetMillisecondsEx","__ZN14DSTOffsetCache24getDSTOffsetMillisecondsExP9JSContext","__ZN2v88internal13StringBuilder9AddStringEPKc","__ZN2v88internal13StringBuilder12AddSubstringEPKci","__ZN2v88internal9StrLengthEPKc","__ZN2v88internal13StringBuilder10AddIntegerEi","__ZN2v88internal13StringBuilder10AddPaddingEci","__ZN2v88internal13StringBuilder8FinalizeEv","__ZN2v88internal13DoubleToAsciiEdNS0_8DtoaModeEiNS0_6VectorIcEEPiS4_S4_","__ZNK2v88internal6Double4SignEv","_malloc","_tmalloc_small","_tmalloc_large","_sys_alloc","_sys_trim","_free","_malloc_footprint","_malloc_max_footprint","_release_unused_segments","_calloc","_realloc","_memalign","_internal_memalign","_independent_calloc","_ialloc","_independent_comalloc","_valloc","_pvalloc","_malloc_trim","_mallinfo","_internal_mallinfo","_malloc_stats","_internal_malloc_stats","_mallopt","_change_mparam","_internal_realloc","_init_mparams","_malloc_usable_size","_mmap_resize","_segment_holding","_init_top","_init_bins","_prepend_alloc","__ZNKSt9bad_alloc4whatEv","__ZNKSt20bad_array_new_length4whatEv","__ZSt15get_new_handlerv","__ZSt15set_new_handlerPFvvE","__ZNSt9bad_allocC2Ev","__ZdlPv","__ZdlPvRKSt9nothrow_t","__ZdaPv","__ZdaPvRKSt9nothrow_t","__ZNSt9bad_allocD0Ev","__ZNSt9bad_allocD2Ev","__ZNSt20bad_array_new_lengthC2Ev","__ZNSt20bad_array_new_lengthD0Ev","_add_segment","__Znwj","__ZnwjRKSt9nothrow_t","__Znaj","__ZnajRKSt9nothrow_t","__ZSt17__throw_bad_allocv"]

